diff --git a/Makefile b/Makefile
index 23c3a54..df5b55d 100644
--- a/Makefile
+++ b/Makefile
@@ -33,10 +33,6 @@ TAR:=tar
 TOUCH:=touch
 UNCOMPRESS:=gunzip
 
-##### noweb
-TANGLE:=${SPADBIN}/lib/notangle
-WEAVE:=${SPADBIN}/lib/noweave
-
 ##### lisp related variables
 BYE:=bye
 #GCLVERSION=gcl-2.4.1
@@ -129,16 +125,14 @@ WEAVE=${WEAVE} \
 XLIB=${XLIB} \
 ZIPS=${ZIPS} 
 
-all: tangle noweb ${MNT}/${SYS}/bin/document
-	@ echo p1 making a parallel system build
+all: rootdirs tangle ${MNT}/${SYS}/bin/document
 	@ echo 1 making a ${SYS} system, PART=${PART} SUBPART=${SUBPART}
 	@ echo 2 Environment ${ENV}
-	@ ${TANGLE} -t8 -RMakefile.${SYS} Makefile.pamphlet >Makefile.${SYS}
-	@ ${DOCUMENT} Makefile
-	@ mkdir -p ${MNT}/${SYS}/doc/src
+	@ ${BOOKS}/tangle Makefile.pamphlet "Makefile.${SYS}" >Makefile.${SYS}
 	@ cp books/dvipdfm.def ${MNT}/${SYS}/doc
 	@ cp books/changepage.sty ${MNT}/${SYS}/doc
-	@ cp Makefile.dvi ${MNT}/${SYS}/doc/src/root.Makefile.dvi
+	@ ${EXTRACT} Makefile.pamphlet
+	@ cp Makefile.pdf ${MNT}/${SYS}/doc/src/root.Makefile.pdf
 	@ if [ "${RUNTYPE}" = "parallel" ] ; then \
 	   ( echo p4 starting parallel make of input files ; \
 	     ${ENV} ${MAKE} input ${NOISE} & ) ; \
@@ -186,6 +180,15 @@ all: tangle noweb ${MNT}/${SYS}/bin/document
 	@ ${ENV} $(MAKE) -f Makefile.${SYS} 
 	@ echo 3 finished system build on `date` | tee >lastBuildDate
 
+rootdirs:
+	@ echo 11 checking directory structure
+	@ mkdir -p ${TMP}
+	@ mkdir -p ${INT}/doc/lsp
+	@ mkdir -p ${INT}/doc/src
+	@ mkdir -p ${OBJ}/${SYS}
+	@ mkdir -p ${MNT}/${SYS}/bin/lib
+	@ mkdir -p ${MNT}/${SYS}/doc/src
+
 input:
 	@ echo p9 making input documents
 	@ if [ "${BUILD}" = "full" ] ; then \
@@ -227,28 +230,6 @@ tangle: books/tangle.c
 	@echo t01 making tangle from tangle.c
 	@( cd books ; gcc -o tangle tangle.c )
 
-noweb:
-	@echo 13 making noweb
-	@mkdir -p ${OBJ}/noweb
-	@mkdir -p ${TMP}
-	@mkdir -p ${MNT}/${SYS}/bin/lib
-	@( cd ${OBJ}/noweb ; \
-	tar -zxf ${ZIPS}/noweb-2.10a.tgz ; \
-	cd ${OBJ}/noweb/src/c ; \
-	${PATCH} <${ZIPS}/noweb.modules.c.patch ; \
-	cd ${OBJ}/noweb/src ; \
-	${PATCH} <${ZIPS}/noweb.src.Makefile.patch ; \
-	./awkname ${AWK} ; \
-	${ENV} ${MAKE} BIN=${MNT}/${SYS}/bin/lib LIB=${MNT}/${SYS}/bin/lib \
-                MAN=${MNT}/${SYS}/bin/man \
-                TEXINPUTS=${MNT}/${SYS}/bin/tex all install >${TMP}/trace )
-	@echo The file marks the fact that noweb has been made > noweb
-
-nowebclean:
-	@echo 14 cleaning ${OBJ}/noweb
-	@rm -rf ${OBJ}/noweb
-	@rm -f noweb
-
 ${MNT}/${SYS}/bin/document:
 	@echo 0 ${ENV}
 	@echo 10 copying ${SRC}/scripts to ${MNT}/${SYS}/bin
@@ -272,10 +253,10 @@ install:
 	@echo 
 
 
-document: noweb ${MNT}/${SYS}/bin/document
+document: ${MNT}/${SYS}/bin/document
 	@ echo 4 making a ${SYS} system, PART=${PART} SUBPART=${SUBPART}
 	@ echo 5 Environment ${ENV}
-	@ ${TANGLE} -t8 -RMakefile.${SYS} Makefile.pamphlet >Makefile.${SYS}
+	@ ${BOOKS}/tangle Makefile.pamphlet "Makefile.${SYS}" >Makefile.${SYS}
 	@ ${ENV} $(MAKE) -f Makefile.${SYS} document
 	@echo 6 finished system build on `date` | tee >lastBuildDate
 
@@ -302,7 +283,6 @@ clean:
 	@ rm -f lsp/Makefile.dvi
 	@ rm -f lsp/Makefile
 	@ rm -rf lsp/gcl*
-	@ rm -f noweb 
 	@ rm -f trace
 	@ rm -f Makefile.${SYS}
 	@ rm -f Makefile.dvi
diff --git a/Makefile.pamphlet b/Makefile.pamphlet
index 5b1e64f..dc190ff 100644
--- a/Makefile.pamphlet
+++ b/Makefile.pamphlet
@@ -9,6 +9,56 @@
 \eject
 \tableofcontents
 \newpage
+\section{The overall build process}
+
+Makefiles are responsible for building all of their subdirectories
+and then themselves. The system is built in the following order
+\begin{enumerate}
+\item books       -- building pdf files
+\item src/scripts -- building scripts
+\item src/lib     -- building lib files
+\item lsp         -- building gcl common lisp
+\item src         -- building src
+\item src/interp  -- building interpreter files
+\item src/share   -- building share files
+\item src/algebra -- building help files
+\item src/algebra -- building input files
+\item src/algebra -- building xhtml files
+\item src/algebra -- building algebra files
+\begin{itemize}
+\item algebra bootstrap complete
+\item layer 0 of 24 complete
+\item layer 1 of 24 complete
+\item layer 2 of 24 complete
+\item layer 3 of 24 complete
+\item layer 4 of 24 complete
+\item layer 5 of 24 complete
+\item layer 6 of 24 complete
+\item layer 7 of 24 complete
+\item layer 8 of 24 complete
+\item layer 9 of 24 complete
+\item layer 10 of 24 complete
+\item layer 11 of 24 complete
+\item layer 12 of 24 complete
+\item layer 13 of 24 complete
+\item layer 14 of 24 complete
+\item layer 15 of 24 complete
+\item layer 16 of 24 complete
+\item layer 17 of 24 complete
+\item layer 18 of 24 complete
+\item layer 19 of 24 complete
+\item layer 20 of 24 complete
+\item layer 21 of 24 complete
+\item layer 22 of 24 complete
+\item layer 23 of 24 complete
+\item layer 0 copy complete
+\end{itemize}
+\item src/etc   -- building etc
+\item src/clef  -- building clef
+\item src/doc   -- building doc files
+\item src/input -- running regression tests
+\end{enumerate}
+
 \section{General Makefile Structure}
 
 Makefiles are responsible for four things. First, they have to set up
@@ -37,17 +87,15 @@ getting make to build in parallel reliably.
 Note that make cannot handle recursively calling itself in the same
 directory so we have to expand the serial forms inline. Cheesy.
 
-<<parallel>>=
-all: tangle noweb ${MNT}/${SYS}/bin/document
-	@ echo p1 making a parallel system build
+\begin{chunk}{parallel}
+all: rootdirs tangle ${MNT}/${SYS}/bin/document
 	@ echo 1 making a ${SYS} system, PART=${PART} SUBPART=${SUBPART}
 	@ echo 2 Environment ${ENV}
-	@ ${TANGLE} -t8 -RMakefile.${SYS} Makefile.pamphlet >Makefile.${SYS}
-	@ ${DOCUMENT} Makefile
-	@ mkdir -p ${MNT}/${SYS}/doc/src
+	@ ${BOOKS}/tangle Makefile.pamphlet "Makefile.${SYS}" >Makefile.${SYS}
 	@ cp books/dvipdfm.def ${MNT}/${SYS}/doc
 	@ cp books/changepage.sty ${MNT}/${SYS}/doc
-	@ cp Makefile.dvi ${MNT}/${SYS}/doc/src/root.Makefile.dvi
+	@ ${EXTRACT} Makefile.pamphlet
+	@ cp Makefile.pdf ${MNT}/${SYS}/doc/src/root.Makefile.pdf
 	@ if [ "${RUNTYPE}" = "parallel" ] ; then \
 	   ( echo p4 starting parallel make of input files ; \
 	     ${ENV} ${MAKE} input ${NOISE} & ) ; \
@@ -95,6 +143,15 @@ all: tangle noweb ${MNT}/${SYS}/bin/document
 	@ ${ENV} $(MAKE) -f Makefile.${SYS} 
 	@ echo 3 finished system build on `date` | tee >lastBuildDate
 
+rootdirs:
+	@ echo 11 checking directory structure
+	@ mkdir -p ${TMP}
+	@ mkdir -p ${INT}/doc/lsp
+	@ mkdir -p ${INT}/doc/src
+	@ mkdir -p ${OBJ}/${SYS}
+	@ mkdir -p ${MNT}/${SYS}/bin/lib
+	@ mkdir -p ${MNT}/${SYS}/doc/src
+
 input:
 	@ echo p9 making input documents
 	@ if [ "${BUILD}" = "full" ] ; then \
@@ -111,22 +168,21 @@ input:
 	     rm -f *.toc ; \
 	     rm -f *.aux ) ; fi
 
-@
+\end{chunk}
 
-<<*>>=
-<<ENVDEFAULTS>>
-<<ENV>>
-<<parallel>>
-<<book>>
-<<tangle.c>>
-<<noweb>>
-<<literate commands>>
-<<install>>
+\begin{chunk}{*}
+\getchunk{ENVDEFAULTS}
+\getchunk{ENVAR}
+\getchunk{parallel}
+\getchunk{book}
+\getchunk{tangle.c}
+\getchunk{literate commands}
+\getchunk{install}
 
-document: noweb ${MNT}/${SYS}/bin/document
+document: ${MNT}/${SYS}/bin/document
 	@ echo 4 making a ${SYS} system, PART=${PART} SUBPART=${SUBPART}
 	@ echo 5 Environment ${ENV}
-	@ ${TANGLE} -t8 -RMakefile.${SYS} Makefile.pamphlet >Makefile.${SYS}
+	@ ${BOOKS}/tangle Makefile.pamphlet "Makefile.${SYS}" >Makefile.${SYS}
 	@ ${ENV} $(MAKE) -f Makefile.${SYS} document
 	@echo 6 finished system build on `date` | tee >lastBuildDate
 
@@ -153,7 +209,6 @@ clean:
 	@ rm -f lsp/Makefile.dvi
 	@ rm -f lsp/Makefile
 	@ rm -rf lsp/gcl*
-	@ rm -f noweb 
 	@ rm -f trace
 	@ rm -f Makefile.${SYS}
 	@ rm -f Makefile.dvi
@@ -166,20 +221,20 @@ clean:
 	@ rm -f lastBuildDate
 	@ rm -f books/tangle
 
-@
+\end{chunk}
 
 \subsection{Literate Commands}
 Since this is the first build message that gets generated we echo
 the ENV variable for debugging purposes. We use the specific file,
 Makefile in the mnt/sys/bin directory as the trigger to prevent
 duplicate execution of this stanza.
-<<literate commands>>=
+\begin{chunk}{literate commands}
 ${MNT}/${SYS}/bin/document:
 	@echo 0 ${ENV}
 	@echo 10 copying ${SRC}/scripts to ${MNT}/${SYS}/bin
 	@cp -pr ${SRC}/scripts/* ${MNT}/${SYS}/bin
 
-@
+\end{chunk}
 
 \subsection{Environment}
 
@@ -189,16 +244,16 @@ in the banner at startup time. I can be anything but is intended
 to be a unique way of identifying the CVS version so we can 
 reference bug reports to versions.
 
-The VERSION variable is used in the [[src/interp/Makefile]]
-to set a lisp variable [[boot::*build-version*]]. This variable
+The VERSION variable is used in the src/interp/Makefile
+to set a lisp variable boot::*build-version*. This variable
 is used by the {\tt yearweek} function to construct the banner.
 
 The banner also contains a build timestamp so we can determine
 when the image is compiled. We touch the file 
-called [[${MNT}/${SYS}/timestamp]] and using a formatted form
+called \verb|${MNT}/${SYS}/timestamp| and using a formatted form
 of its file information. See the YEARWEEK variable in the
-[[src/interp/Makefile.pamphlet]] and the {\tt yearweek} function in 
-[[src/interp/util.lisp.pamphlet]].
+src/interp/Makefile.pamphlet and the {\tt yearweek} function in 
+src/interp/util.lisp.pamphlet.
 
 \subsubsection{SPAD}
 The SPAD environment variable is normally specified.
@@ -239,14 +294,15 @@ file lookup is in conditional lisp code so other lisps will not
 see the file load. The collectfn.lsp code is used by GCL to generate
 the ``.fn'' files which are used to optimize function calling.
 
-Also, [[lsp/sys-proclaims.lisp]] is a file generated 
+Also, lsp/sys-proclaims.lisp is a file generated 
 during the GCL build which contains type information about lisp
 functions, allowing fast-function calling behavior. 
 
 When defining the environment, the SPD variable is defined as the
 current directory. SYS is taken as the last non-directory part of
-the environment variable [[$AXIOM]] (e.g. if [[$AXIOM=/(a-path)/mnt/linux]]
-then [[SYS=linux]]). It is {\bf mandatory} that [[$AXIOM]] does
+the environment variable \verb|$AXIOM| (e.g. if 
+\verb|$AXIOM=/(a-path)/mnt/linux|
+then SYS=linux). It is {\bf mandatory} that \verb|$AXIOM| does
 {\bf not} contain any trailing slash, because the {\tt notdir} function
 will return the string following the final slash and would thus return
 the empty string.
@@ -281,7 +337,7 @@ time by compilers for each specific system.
 The MNT subdirectory is a complete, working copy of Axiom.
 This directory contains everything that is needed to run Axiom and
 can be copied anywhere. Everything in this directory takes its required
-information from the [[$AXIOM]] shell variable. Once this directory is
+information from the \verb|$AXIOM| shell variable. Once this directory is
 copied the SRC, INT, and OBJ subdirectories can be erased.
 
 \subsubsection{ZIPS}
@@ -369,7 +425,7 @@ It is possible to be more specific with a directory using SUBPART.
 
 
 \subsubsection{DESTDIR and COMMAND}
-The install directory is [[/usr/local/axiom]] by default 
+The install directory is /usr/local/axiom by default 
 but this can be changed on the command line by typing:
 \begin{verbatim}
 make DESTDIR=/yourabsolutepath COMMAND=fullPathAndCommand install
@@ -382,7 +438,7 @@ The DOCUMENT variable is now set to replace the direct call
 to the document command. This will allow it to be
 changed on the command line.
 \section{The Environment}
-<<ENVDEFAULTS>>=
+\begin{chunk}{ENVDEFAULTS}
 VERSION:="Axiom (May 2012)"
 
 ##### special paths
@@ -418,15 +474,11 @@ TAR:=tar
 TOUCH:=touch
 UNCOMPRESS:=gunzip
 
-##### noweb
-TANGLE:=${SPADBIN}/lib/notangle
-WEAVE:=${SPADBIN}/lib/noweave
-
 ##### lisp related variables
 BYE:=bye
-<<GCLVERSION>>
+\getchunk{GCLVERSION}
 GCLDIR:=${LSP}/${GCLVERSION}
-<<GCLOPTS-LOCBFD>>
+\getchunk{GCLOPTS-LOCBFD}
 LISP:=lsp
 
 ##### C related variables
@@ -449,9 +501,10 @@ RUNTYPE:=serial
 TESTSET:=regresstests
 BUILD:=full
 
-@
+\end{chunk}
+
 \subsection{The ENV variable}
-<<ENV>>=
+\begin{chunk}{ENVAR}
 
 ENV:= \
 AWK=${AWK} \
@@ -500,29 +553,7 @@ WEAVE=${WEAVE} \
 XLIB=${XLIB} \
 ZIPS=${ZIPS} 
 
-@
-\subsection{rootdirs}
-Note that the -p (parent) option to mkdir will make all intermediate
-directories as well if they don't exist.
-
-We need [[${MNT}/${SYS}/doc/src]] so the various Makefile.dvi files
-can be copied.
-
-We need to make the [[${MNT}/${SYS}/bin/lib]] path because on certain
-systems, such as freebsd, we do not build noweb. The noweb stanza
-would normally create this but might not have been executed.
-<<rootdirs>>=
-rootdirs: ${MNT}/${SYS}/bin/document
-	@echo 11 checking directory structure
-	@echo 12 Environment: ${ENV}
-	@mkdir -p ${INT}
-	@mkdir -p ${OBJ}/${SYS}
-	@mkdir -p ${TMP}
-	@mkdir -p ${MNT}/${SYS}/bin/lib
-	@mkdir -p ${MNT}/${SYS}/doc/src
-#	@cp -pr ${SRC}/scripts/* ${MNT}/${SYS}/bin
-
-@
+\end{chunk}
 
 \subsection{book}
 This stanza constructs the book from the original pamphlet file.
@@ -531,7 +562,7 @@ and straight latex (intentionally). Thus we just need to make
 sure the correct directories are in place, copy the files, and
 run latex over the pamphlet file.
 
-<<book>>=
+\begin{chunk}{book}
 book:
 	@ echo 79 building the book as ${MNT}/${SYS}/doc/book.dvi 
 	@ mkdir -p ${TMP}
@@ -552,91 +583,16 @@ book:
 	  rm book.aux )
 	@ echo 80 The book is at ${MNT}/${SYS}/doc/book.dvi 
 
-@
+\end{chunk}
 \subsection{tangle.c}
-<<tangle.c>>=
+\begin{chunk}{tangle.c}
 
 tangle: books/tangle.c
 	@echo t01 making tangle from tangle.c
 	@( cd books ; gcc -o tangle tangle.c )
 
-@
-
-\subsection{noweb}
-
-Note that this stanza echos a line into a file called noweb.
-Makefile semantics says that when this file exists we will
-skip this stanza. So in a clean system where the noweb file
-does not exist we will execute this once and never again
-(unless someone deletes the noweb file).
-
-Never add anything after the colon otherwise the noweb
-build will depend on it rather than the noweb flag file
-in the current directory.
+\end{chunk}
 
-We have added a patch to the [[${SPAD}/obj/noweb/src/c/modules.c]]
-file that causes noweb to output undefined chunk names exactly
-as they exist in the original file. This gets around the most
-common failure of boxing up a file into a pamphlet. The patch
-file lives in the [[ZIPS]] directory and will be applied
-after noweb is untarred but before the make occurs.
-
-We have added a patch to the [[${SPAD}/obj/noweb/src/Makefile]]
-which does two things. First it uses [[${TMP}/null]] rather than
-[[/dev/null]] as we do not wish to write outside our own build tree.
-
-We also patch the use of [[make]] to use [[${MAKE}]]. BSD style
-systems use [[gmake]] rather than [[make]] so we need to pass this
-information from above for the build to succeed.
-
-\subsection{Noweb patch skipped}
-We tried to applied this noweb patch but the function [[tempfile]]
-used in all of the patches does not exist therefore this patch
-has been removed pending a fix. The referenced patch files still
-exist in the zips directory.
-
-\begin{verbatim}
-The [[mv noweb.src.awkname.patch]] file,
-the [[noweb.src.awk.totex.nw.patch]] file,
-the [[noweb.src.lib.toascii.patch]] file,
-the [[noweb.src.shell.cpif.patch]] file,
-the [[noweb.src.shell.nonu.patch]] file,
-the [[noweb.src.shell.roff.nw.patch]] file,
-the [[noweb.src.shell.noroff.patch]] file,
-the [[noweb.src.shell.toroff.patch]] file,
-the [[noweb.src.lib.toascii.nw.patch]] file, and
-the [[noweb.src.shell.roff.mm.patch]] file remove 
-the insecure temp file problem.
-
-We removed the same patch to 
-[[noweb.src.lib.toascii.patch]] 
-because this is not a source file.
-
-\end{verbatim}
-<<noweb>>=
-noweb:
-	@echo 13 making noweb
-	@mkdir -p ${OBJ}/noweb
-	@mkdir -p ${TMP}
-	@mkdir -p ${MNT}/${SYS}/bin/lib
-	@( cd ${OBJ}/noweb ; \
-	tar -zxf ${ZIPS}/noweb-2.10a.tgz ; \
-	cd ${OBJ}/noweb/src/c ; \
-	${PATCH} <${ZIPS}/noweb.modules.c.patch ; \
-	cd ${OBJ}/noweb/src ; \
-	${PATCH} <${ZIPS}/noweb.src.Makefile.patch ; \
-	./awkname ${AWK} ; \
-	${ENV} ${MAKE} BIN=${MNT}/${SYS}/bin/lib LIB=${MNT}/${SYS}/bin/lib \
-                MAN=${MNT}/${SYS}/bin/man \
-                TEXINPUTS=${MNT}/${SYS}/bin/tex all install >${TMP}/trace )
-	@echo The file marks the fact that noweb has been made > noweb
-
-nowebclean:
-	@echo 14 cleaning ${OBJ}/noweb
-	@rm -rf ${OBJ}/noweb
-	@rm -f noweb
-
-@
 \subsection{src}
 We should recompile the world with the .fn information but not here.
 \begin{verbatim}
@@ -647,8 +603,9 @@ We should recompile the world with the .fn information but not here.
 	@echo 15a remaking ${SRC}/interp for performance
 	@(cd src ; ${ENV} ${MAKE} )
 \end{verbatim}
-<<src>>=
-srcdir: rootdirs ${SPD}/src/Makefile
+
+\begin{chunk}{src}
+srcdir: ${SPD}/src/Makefile
 	@echo 15 making ${SPD}/src 
 	@( cd src ; ${ENV} ${MAKE} )
 
@@ -661,19 +618,19 @@ ${SPD}/src/Makefile: ${SPD}/src/Makefile.pamphlet
 libspadclean:
 	@echo 17 cleaning ${OBJ}/${SYS}/lib	
 	@rm -rf ${OBJ}/${SYS}/lib	
-	@( cd src ; ${DOCUMENT} Makefile )
+	@( cd src ; ${EXTRACT} Makefile )
 	@( cd src ; ${ENV} ${MAKE} clean )
 	@rm -f ${SPD}/src/Makefile ${SPD}/src/Makefile.dvi
 
-@
+\end{chunk}
 
 \subsection{src setup}
-<<srcsetup>>=
-srcsetup: rootdirs ${SPD}/src/Makefile
+\begin{chunk}{srcsetup}
+srcsetup: ${SPD}/src/Makefile
 	@echo 18 making ${SPD}/src 
 	@( cd src ; ${ENV} ${MAKE} setup )
 
-@
+\end{chunk}
 
 \subsection{lsp}
 We delegate the details of constructing common lisp to the Makefiles in
@@ -684,7 +641,7 @@ called gcldir. This file has the same name as the stanza to create
 GCL and thus will prevent GCL from rebuilding. We need to do this
 since we have no control over the GCL makefiles.
 
-The [[${OBJ}/${SYS}/bin]] directory is where the lisps get built.
+The \verb|${OBJ}/${SYS}/bin| directory is where the lisps get built.
 \subsubsection{LSPMakefile}
 We need to specialize the Makefile stanza based on the version
 of Lisp we plan to use. At the moment there are 3 GCL versions
@@ -694,33 +651,32 @@ the lsp/Makefile.pamphlet file. Here we just decide which section
 to choose. The default is 2.4.1 but if the GCLVERSION is changed
 then the Makefile is rewritten to extract the later version.
 It looks for a chunk name that matches the version number.
-<<LSPMakefile>>=
+\begin{chunk}{LSPMakefile}
 ${LSP}/Makefile: ${LSP}/Makefile.pamphlet
 	@echo 20 making ${LSP}/Makefile from ${LSP}/Makefile.pamphlet
 	@( cd lsp ; \
-	 ${DOCUMENT} Makefile ; \
+	 ${EXTRACT} Makefile.pamphlet ; \
 	 if [ "${GCLVERSION}" != "gcl-2.4.1" ] ; then \
-	 ${TANGLE} -t8 -R"${GCLVERSION}" Makefile.pamphlet >Makefile ; \
-         fi )
-	@cp Makefile.dvi ${MNT}/${SYS}/doc/src
+	 ${BOOKS}/tangle Makefile.pamphlet ${GCLVERSION} >Makefile ; \
+         fi ; \
+	 cp Makefile.pdf ${MNT}/${SYS}/doc/src/lsp.Makefile.pdf )
 
+\end{chunk}
+Here we add mkdir -p \verb|${OBJ}/${SYS}/lsp| because we need to rename the
+\verb|gcl_collectfn.lsp| back to collectfn.lsp. We also start adding support
+for sys-proclaim.lsp and other dynamically collected proclaim information.
 
-@
-Here we add [[mkdir -p ${OBJ}/${SYS}/lsp]] because we need to rename the
-[[gcl_collectfn.lsp]] back to collectfn.lsp. We also start adding support
-for [[sys-proclaim.lsp]] and other dynamically collected proclaim information.
-
-The [[obj/sys/bin]] dir is necessary to keep the compiled lisp image.
-The [[obj/sys/lsp]] dir is necessary to keep collectfn and sys-proclaims.
+The obj/sys/bin dir is necessary to keep the compiled lisp image.
+The obj/sys/lsp dir is necessary to keep collectfn and sys-proclaims.
 The collectfn.lsp file is a special extension to GCL to collect type
 information during a compile-file. This information gets written out
-to a [[.fn]] file. These [[.fn]] files can be loaded and written out
+to a .fn file. These .fn files can be loaded and written out
 as a file containing proclaims information. If this proclaims information
 is available at compile time then the resulting function calls are much
-more efficient. The [[sys-proclaims]] file contains type information 
+more efficient. The sys-proclaims file contains type information 
 about standard common lisp function calls.
-<<lsp>>=
-lspdir: rootdirs ${MNT}/${SYS}/bin/document ${LSP}/Makefile
+\begin{chunk}{lsp}
+lspdir: ${MNT}/${SYS}/bin/document ${LSP}/Makefile
 	@echo 19 making ${LSP}
 	@mkdir -p ${OBJ}/${SYS}/bin
 	@mkdir -p ${OBJ}/${SYS}/lsp
@@ -730,7 +686,7 @@ lspdir: rootdirs ${MNT}/${SYS}/bin/document ${LSP}/Makefile
 	@(cd lsp ; ${ENV} ${MAKE} gcldir ) 1>/dev/null 2>/dev/null
 #	@(cd lsp ; ${ENV} ${MAKE} ccldir )
 
-<<LSPMakefile>>
+\getchunk{LSPMakefile}
 lspclean:
 	@echo 21 cleaning ${OBJ}/${SYS}/ccl
 	@rm -rf ${LSP}/${GCLVERSION}
@@ -739,9 +695,9 @@ lspclean:
 	@rm -rf ${LSP}/gcldir
 	@rm -f ${LSP}/Makefile ${LSP}/Makefile.dvi
 
-@
+\end{chunk}
 \subsection{install}
-<<install>>=
+\begin{chunk}{install}
 install:
 	@echo 78 installing Axiom in ${DESTDIR}
 	@mkdir -p ${DESTDIR}
@@ -759,36 +715,33 @@ install:
 	@echo Start Axiom with the command $(shell basename ${COMMAND})
 	@echo 
 
-@
+\end{chunk}
 \subsection{document}
 
 Each file in the system is in pamphlet form. This stanza, which is not
 executed by default, will walk the directories generating the
 documentation for each file. These are dvi files and since they are
-system-independent and machine-generated they live in the [[INT]]
-subdirectory. In particular, we will build an [[INT/DOC]] subtree
-mirroring the [[LSP]] and [[SRC]] subtrees. The [[INT/DOC]]
+system-independent and machine-generated they live in the INT
+subdirectory. In particular, we will build an INT/DOC subtree
+mirroring the LSP and SRC subtrees. The INT/DOC
 subtree can be removed with no ill effect. Since all of the pamphlet
-files live in either the [[LSP]] or [[SRC]] subdirectories we make
-sure the [[INT/DOC/LSP]] and [[INT/DOC/SRC]] directories exist.
+files live in either the LSP or SRC subdirectories we make
+sure the INT/DOC/LSP and INT/DOC/SRC directories exist.
 
-<<document>>=
-document: rootdirs
+\begin{chunk}{document}
+document: 
 	@echo 22 documenting files
-	@mkdir -p ${INT}/doc/lsp
-	@mkdir -p ${INT}/doc/src
 	@(cd lsp ; ${ENV} ${MAKE} document )
 	@(cd src ; ${ENV} ${MAKE} document )
 
-@
+\end{chunk}
 \subsection{clean}
-<<clean>>=
+\begin{chunk}{clean}
 clean: 
 	@ echo 7 making a ${SYS} system, PART=${PART} SUBPART=${SUBPART}
 	@ echo 8 Environment ${ENV}
 	@ rm -f lsp/Makefile.dvi
 	@ rm -f lsp/Makefile
-	@ rm -f noweb 
 	@ rm -f trace
 	@ rm -f *~
 	@ rm -f Makefile.${SYS}
@@ -799,7 +752,7 @@ clean:
 	@ for i in `find src -name "Makefile"` ; do rm -f $i ; done
 	@ for i in `find src -name "Makefile.dvi"` ; do rm -f $i ; done
 
-@
+\end{chunk}
 \section{The Platform Makefiles}
 
 The Top Level Makefile examines the SPAD variable to determine
@@ -808,38 +761,38 @@ of the world. Then it invokes one of these platform Makefiles.
 Each of these Makefiles sets several
 environment variables that are specific to this platform.
 
-\subsubsection{The [[LDF]] variable }
+\subsubsection{The LDF variable }
 
 The LDF variable is the generic loader flags. This gives information
 about where various libraries are located on specific platforms. On
-linux, for instance, the library [[libXpm.a]] is used by the graphics
-routines. This library is usually found in [[/usr/X11R6/bin/libXpm.a]]. 
+linux, for instance, the library libXpm.a is used by the graphics
+routines. This library is usually found in /usr/X11R6/bin/libXpm.a. 
 Thus, on the linux platform LDF is defined as
 \begin{verbatim}
 LDF=" -L/usr/X11R6/lib -L/usr/lib ${XLIB}/libXpm.a -lXpm"
 \end{verbatim}
 
-\subsubsection{The [[AWK]] variable }
+\subsubsection{The AWK variable }
 
 On most systems the gnu toolset is the default. Thus we can just use
 'awk' and the program works. However, on some systems we need to
 specify that we are using the gnu toolset, and we need to use
-[[gawk]] instead of [[awk]].
+gawk instead of awk.
 
-\subsubsection{The [[PATCH]] variable }
+\subsubsection{The PATCH variable }
 
 On most systems the gnu toolset is the default. Thus we can just use
 'patch' and the program works. However, on some systems we need to
 specify that we are using the gnu toolset, and we need to use
-[[gpatch]] instead of [[patch]].
+gpatch instead of patch.
 
-\subsubsection{The [[O]] variable }
+\subsubsection{The O variable }
 Various Common Lisp systems prefer certain filename extensions.
 This defaults to ``o'' so a compile of foo.lisp becomes foo.o
 but other systems prefer .fasl so a compile of foo.lisp becomes
 foo.fasl. Change this based on the target lisp.
 
-\subsubsection{The [[LISP]] variable }
+\subsubsection{The LISP variable }
 There are 3 kinds of "lisp" files in the Axiom build process.
 The first are the "clisp" files. These are common lisp files
 generated by the boot compiler. The second are the "lisp" files.
@@ -848,41 +801,41 @@ files. These are files generated by GNU Common Lisp. The LISP
 variable is used to name the third kind of files as this may
 change when the underlying common lisp is changed.
 
-\subsubsection{The [[DAASE]] variable}
+\subsubsection{The DAASE variable}
 Axiom uses 5 files, the *.daase files, which are called ``the
 databases''. They contain cross-reference, signatures,
 and other information needed by the interpreter and compiler.
 When the system is being built from scratch these databases
 need to exist. However, they get dynamically rebuilt after
 the algebra files are compiled. The bootstrap versions of these
-databases live in the [[src/share]] subdirectory. Axiom will
-use the value of the shell variable [[DAASE]] to find its 
+databases live in the src/share subdirectory. Axiom will
+use the value of the shell variable DAASE to find its 
 databases. If this variable is unbound it uses the standard
-[[${MNT}/${SYS}]] path. Note that Axiom will append the string
-[[/algebra]] to the value of [[DAASE]]. The default value setting
+\verb|${MNT}/${SYS}| path. Note that Axiom will append the string
+/algebra to the value of DAASE. The default value setting
 given here is:
 
-[[DAASE=${SRC}/share]]
+\verb|DAASE=${SRC}/share|
 
-so [[${SRC}/share/algebra/*.daase]] will be the
+so \verb|${SRC}/share/algebra/*.daase| will be the
 Axiom bootstrap database files.
 
 \subsubsection{The XLIB variable}
 The XLIB variable tells us where the X11 libraries live.
 Axiom needs to use libXpm.a to build the graph subdirectory.
 
-\subsubsection{The [[SRCDIRS]] variable}
-The [[SRCDIRS]] variable is used in the [[src/Makefile.pamphlet]]
+\subsubsection{The SRCDIRS variable}
+The SRCDIRS variable is used in the src/Makefile.pamphlet
 to decide what directories to build on a given platform. This is
 needed at the moment because certain functions do not yet work on
 all platforms. 
 
-\subsubsection{The [[GCLVERSION]] variable }
-[[GCLVERSION]] is the name of the GCL version. The one we used to
+\subsubsection{The GCLVERSION variable }
+GCLVERSION is the name of the GCL version. The one we used to
 build the original version of the system is gcl-2.4.1. The system
-will attempt to untar a file in the [[ZIPS]] directory with the
-name [[GCLVERSION.tgz]], cd to the [[GCLVERSION]] subdirectory and
-do a [[./configure]] followed by a [[make]].
+will attempt to untar a file in the ZIPS directory with the
+name GCLVERSION.tgz, cd to the GCLVERSION subdirectory and
+do a ./configure followed by a make.
 
 The GCLVERSION variable is also used to make the GCLDIR variable.
 GCLDIR tells depsys where GCL lives. The depsys image needs to
@@ -900,7 +853,7 @@ This will cause the build to remake the lsp/Makefile from the
 lsp/Makefile.pamphlet file and get the correct version. If you
 forget to erase the lsp/Makefile the wrong patches will be applied.
 
-<<GCLVERSION>>=
+\begin{chunk}{GCLVERSION}
 #GCLVERSION=gcl-2.4.1
 #GCLVERSION=gcl-2.5
 #GCLVERSION=gcl-2.5.2
@@ -917,37 +870,37 @@ forget to erase the lsp/Makefile the wrong patches will be applied.
 #GCLVERSION=gcl-2.6.8pre3 
 #GCLVERSION=gcl-2.6.8pre4
 GCLVERSION=gcl-2.6.8pre7
-@
+\end{chunk}
 
-\subsubsection{The [[GCLOPTS]] configure variable}
-The [[GCLOPTS]] lisp requires some parameters 
+\subsubsection{The GCLOPTS configure variable}
+The GCLOPTS lisp requires some parameters 
 for building which vary from system
 to system. We create an environment variable here so we can add options
-to the configure command in the [[lsp/Makefile.pamphlet]].
+to the configure command in the lsp/Makefile.pamphlet.
 
-<<GCLOPTS>>=
+\begin{chunk}{GCLOPTS}
 GCLOPTS="--enable-vssize=65536*2 --enable-statsysbfd \
          --enable-maxpage=256*1024 --disable-xgcl --disable-tkconfig" 
-@
+\end{chunk}
 It turns out that we can successfully build GCL on many more systems
-if we set the [[GCLOPTS]] to build a local [[BFD]].
+if we set the GCLOPTS to build a local BFD.
 
 We are failing during build because "directoryp is undefined" along
 with the message
 \begin{verbatim}
 Error: Cannot get relocated section contents
 \end{verbatim}
-<<GCLOPTS-LOCBFD>>=
+\begin{chunk}{GCLOPTS-LOCBFD}
 GCLOPTS="--enable-vssize=65536*2 --enable-locbfd --disable-dynsysbfd \
          --disable-statsysbfd --enable-maxpage=512*1024 --disable-xgcl \
          --disable-tkconfig"
-@
+\end{chunk}
 For the gcl-2.6.8pre7 version we move to using the custreloc option.
-<<GCLOPTS-CUSTRELOC>>=
+\begin{chunk}{GCLOPTS-CUSTRELOC}
 GCLOPTS="--enable-vssize=65536*2 --disable-locbfd --disable-dynsysbfd \
          --disable-statsysbfd --enable-maxpage=512*1024 --disable-xgcl \
          --disable-tkconfig --enable-custreloc --disable-tkconfig"
-@
+\end{chunk}
 For the MACOSX port we need the following options. The ``--disable-nls'' means 
 that we will not be supporting natural language internationalization.
 The ``--enable-maxpage'' has been eliminated because it causes build failures.
@@ -955,576 +908,533 @@ The ``--enable-machine'' parameter appears to be used by configure from the
 setting of the ``canonical'' variable, which is in turn set by a shell script.
 We need to add ``--enable-locbfd'' and ``--disable-dlopen'' due to the error
 ``unexec: not enough room for load commands for new \_\_DATA segments''.
-<<GCLOPTS-MACPORT>>=
+\begin{chunk}{GCLOPTS-MACPORT}
 GCLOPTS="--enable-vssize=65536*2 --disable-nls  --disable-locbfd \
          --disable-statsysbfd  --enable-custreloc --disable-tkconfig \
          --enable-machine=powerpc-macosx --disable-xgcl --disable-dlopen"
-@
+\end{chunk}
 \subsection{Makefile.freebsd}
-<<Makefile.freebsd>>=
+\begin{chunk}{Makefile.freebsd}
 
-<<ENVDEFAULTS>>
+\getchunk{ENVDEFAULTS}
 PLF=BSDplatform
 CCF="-O2 -pipe -fno-strength-reduce -Wall -D_GNU_SOURCE \
      -D${PLF} -I/usr/X11R6/include -I/usr/local/include"
 LDF="-L/usr/X11R6/lib -L/usr/local/lib"
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.FreeBSD called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.windows}
 This is for the Windows port. We assume that the build will be done
 using GCC under MSYS.
 
-We've modified the [[GCLOPTS]] variable from the standard config in
-two ways. First we add [[--enable-debug]] so more information is
-available for testing and second we removed [[--enable-statsysbfd]].
+We've modified the GCLOPTS variable from the standard config in
+two ways. First we add --enable-debug so more information is
+available for testing and second we removed --enable-statsysbfd.
 
-<<Makefile.windows>>=
+\begin{chunk}{Makefile.windows}
 
-<<ENVDEFAULTS>>
+\getchunk{ENVDEFAULTS}
 AWK=awk
 PLF=MSYSplatform
 CCF="-O2 -Wall -D_GNU_SOURCE -D${PLF}"
 SRCDIRS="bootdir interpdir sharedir algebradir etcdir docdir inputdir"
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.windows called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
-
-@
-<<Makefile.slackware>>=
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-<<ENVDEFAULTS>>
-<<ENV>>
+\end{chunk}
+\begin{chunk}{Makefile.slackware}
 
+\getchunk{ENVDEFAULTS}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.slackware called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.linux}
-<<Makefile.linux>>=
+\begin{chunk}{Makefile.linux}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.mandriva}
-<<Makefile.mandriva>>=
+\begin{chunk}{Makefile.mandriva}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.mandriva called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.vector}
-<<Makefile.vector>>=
+\begin{chunk}{Makefile.vector}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.redhat72}
-<<Makefile.redhat72>>=
+\begin{chunk}{Makefile.redhat72}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.redhat9}
-<<Makefile.redhat9>>=
+\begin{chunk}{Makefile.redhat9}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.debian}
-<<Makefile.debian>>=
+\begin{chunk}{Makefile.debian}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.opensuse}
-<<Makefile.opensuse>>=
+\begin{chunk}{Makefile.opensuse}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.ubuntu}
-<<Makefile.ubuntu>>=
+\begin{chunk}{Makefile.ubuntu}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.mint}
-<<Makefile.mint>>=
+\begin{chunk}{Makefile.mint}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.ubuntu64}
-<<Makefile.ubuntu64>>=
+\begin{chunk}{Makefile.ubuntu64}
 
-<<ENVDEFAULTS>>
+\getchunk{ENVDEFAULTS}
 XLIB=/usr/lib
 LDF:=" -L/usr/X11R6/lib -L/usr/lib ${XLIB}/libXpm.a -lXpm"
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.centos}
-<<Makefile.centos>>=
+\begin{chunk}{Makefile.centos}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.macosxppc}
-<<Makefile.macosxppc>>=
+\begin{chunk}{Makefile.macosxppc}
 
-<<ENVDEFAULTS>>
+\getchunk{ENVDEFAULTS}
 PLF=MACOSXplatform
 CCF="-O2 -fno-strength-reduce -Wall -D_GNU_SOURCE -D${PLF} -I/usr/X11/include"
-<<GCLOPTS-MACPORT>>
-<<ENV>>
+\getchunk{GCLOPTS-MACPORT}
+\getchunk{ENVAR}
 
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.macosxppc called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.fedora}
-<<Makefile.fedora>>=
+\begin{chunk}{Makefile.fedora}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.fedora called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.fedora5}
-<<Makefile.fedora5>>=
-<<Makefile.fedora>>
-@
+\begin{chunk}{Makefile.fedora5}
+\getchunk{Makefile.fedora}
+\end{chunk}
 \subsection{Makefile.fedora6}
-<<Makefile.fedora6>>=
-<<Makefile.fedora>>
-@
+\begin{chunk}{Makefile.fedora6}
+\getchunk{Makefile.fedora}
+\end{chunk}
 \subsection{Makefile.fedora7}
-<<Makefile.fedora7>>=
-<<Makefile.fedora>>
-@
+\begin{chunk}{Makefile.fedora7}
+\getchunk{Makefile.fedora}
+\end{chunk}
 \subsection{Makefile.fedora8}
-<<Makefile.fedora8>>=
-<<Makefile.fedora>>
-@
+\begin{chunk}{Makefile.fedora8}
+\getchunk{Makefile.fedora}
+\end{chunk}
 \subsection{Makefile.fedora8-64}
 Fedora 8 on a 64 bit machine requires gcl-2.6.8pre2
-<<Makefile.fedora8-64>>=
+\begin{chunk}{Makefile.fedora8-64}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.fedora9}
-<<Makefile.fedora9>>=
-<<Makefile.fedora>>
-@
+\begin{chunk}{Makefile.fedora9}
+\getchunk{Makefile.fedora}
+\end{chunk}
 \subsection{Makefile.fedora10}
-<<Makefile.fedora10>>=
-<<Makefile.fedora>>
-@
+\begin{chunk}{Makefile.fedora10}
+\getchunk{Makefile.fedora}
+\end{chunk}
 \subsection{Makefile.fedora11}
-<<Makefile.fedora11>>=
-<<Makefile.fedora>>
-@
+\begin{chunk}{Makefile.fedora11}
+\getchunk{Makefile.fedora}
+\end{chunk}
 \subsection{Makefile.fedora12}
-<<Makefile.fedora12>>=
-<<Makefile.fedora>>
-@
+\begin{chunk}{Makefile.fedora12}
+\getchunk{Makefile.fedora}
+\end{chunk}
 \subsection{Makefile.fedora13}
-<<Makefile.fedora13>>=
-<<Makefile.fedora>>
-@
+\begin{chunk}{Makefile.fedora13}
+\getchunk{Makefile.fedora}
+\end{chunk}
 \subsection{Makefile.gentoo}
-<<Makefile.gentoo>>=
+\begin{chunk}{Makefile.gentoo}
 
-<<ENVDEFAULTS>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{ENVAR}
 
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.fedora64}
-<<Makefile.fedora64>>=
+\begin{chunk}{Makefile.fedora64}
 
-<<ENVDEFAULTS>>
+\getchunk{ENVDEFAULTS}
 LDF="-L/usr/X11R6/lib64 -L/usr/local/lib64 -L/usr/openwin/lib64 -L/usr/lib64 "
-<<GCLOPTS-CUSTRELOC>>
-<<ENV>>
+\getchunk{GCLOPTS-CUSTRELOC}
+\getchunk{ENVAR}
 
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.fedora3}
 Fedora Core 3 needs special GCL options for local bfd.
-<<Makefile.fedora3>>=
+\begin{chunk}{Makefile.fedora3}
 
-<<ENVDEFAULTS>>
-<<GCLOPTS-LOCBFD>>
-<<ENV>>
+\getchunk{ENVDEFAULTS}
+\getchunk{GCLOPTS-LOCBFD}
+\getchunk{ENVAR}
 
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \subsection{Makefile.MACOSX}
 On the MAC OSX someone decided (probably a BSDism) to rename the
-[[SIGCLD]] signal to [[SIGCHLD]]. In order to handle this in the 
-low level C socket code (in particular, in [[src/lib/fnct_key.c]])
-we change the platform variable to be [[MACOSXplatform]] and create
+SIGCLD signal to SIGCHLD. In order to handle this in the 
+low level C socket code (in particular, in \verb|src/lib/fnct_key.c|)
+we change the platform variable to be MACOSXplatform and create
 this new stanza.
 
 It appears that the MAC OSX does not include gawk or nawk by 
-default so we change the [[AWK]] variable to use [[awk]].
+default so we change the AWK variable to use awk.
 
-We need to add [[-I/usr/include/sys]] because {\tt malloc.h} has been
+We need to add -I/usr/include/sys because {\tt malloc.h} has been
 moved on this platform. 
 
 We need to search includes (``-I'') in /usr/include before 
 /usr/include/sys because the MAC seems to search in a
 different order than linux systems. The sys versions of 
 the include files are broken, at least for Axiom use.
-<<Makefile.MACOSX>>=
+\begin{chunk}{Makefile.MACOSX}
 
-<<ENVDEFAULTS>>
+\getchunk{ENVDEFAULTS}
 AWK=awk
 PLF=MACOSXplatform
 CCF="-O2 -fno-strength-reduce -Wall -D_GNU_SOURCE -D${PLF} \
      -I/usr/X11/include -I/usr/include -I/usr/include/sys"
-<<GCLOPTS-MACPORT>>
-<<ENV>>
+\getchunk{GCLOPTS-MACPORT}
+\getchunk{ENVAR}
 
-all: rootdirs noweb srcsetup lspdir srcdir
+all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
 	@- grep "result FAILED" int/input/*.regress
 
-<<rootdirs>>
-<<noweb>>
-<<literate commands>>
-<<srcsetup>>
-<<src>>
-<<lsp>>
-<<document>>
-<<clean>>
+\getchunk{literate commands}
+\getchunk{srcsetup}
+\getchunk{src}
+\getchunk{lsp}
+\getchunk{document}
+\getchunk{clean}
 
-@
+\end{chunk}
 \newpage
 \begin{thebibliography}{99}
 \bibitem{1} CMUCL {\bf http://www.cons.org/cmucl}
@@ -1532,7 +1442,6 @@ all: rootdirs noweb srcsetup lspdir srcdir
 \bibitem{3} Codemist Ltd, ``Alta'', Horsecombe Vale Combs Down
 Bath BA2 5QR UK Tel. +44-1225-837430 
 {\bf http://www.codemist.co.uk}
-\bibitem{4} \$SPAD/zips/noweb-2.10a.tgz, the noweb source tree
 \bibitem{5} \$SPAD/zips/advi-1.2.0.tar.gz, the advi source tree
 \end{thebibliography}
 \end{document}
diff --git a/books/bookvol11.pamphlet b/books/bookvol11.pamphlet
index f1b5e05..33da9b3 100644
--- a/books/bookvol11.pamphlet
+++ b/books/bookvol11.pamphlet
@@ -29,6 +29,32 @@ This book contains the Firefox browser AJAX routines.
  and see the new result.
 \end{verbatim}
 
+\section{The Makefile}
+This Makefile assumes that it is being run in the final target
+directory of the build system. We walk the list of PAGES and
+untangle them from this file, along with any support files
+referenced by the pages.
+\begin{chunk}{*}
+BOOK=${SPD}/books/bookvol11.pamphlet
+OUT=${MNT}/${SYS}/doc/hypertex
+
+%.xhtml: ${BOOK}
+	@ echo making $*.xhtml
+	@ ${BOOKS}/tangle ${BOOK} "$*.xhtml" > $*.xhtml
+
+\getchunk{PAGES}
+
+all: ${PAGES}
+	@ mkdir -p bitmaps
+	@ ${BOOKS}/tangle ${BOOK} axiom1.bitmap  >bitmaps/axiom1.bitmap
+	@ ${BOOKS}/tangle ${BOOK} rcm3720.input  >rcm3720.input
+	@ ${BOOKS}/tangle ${BOOK} strang.input   >strang.input
+	@ ${BOOKS}/tangle ${BOOK} signatures.txt >signatures.txt
+	@ cp ${SPD}/books/ps/doctitle.png ${OUT}/doctitle.png
+	@ cp ${SPD}/books/ps/lightbayou.png ${OUT}/lightbayou.png
+
+\end{chunk}
+
 \section{Building new pages}
 To add a new page you need to create a page with the default layout below
 and add the name of the page to the PAGES variable below.
@@ -51,9 +77,9 @@ There are several things to observe here:
 <ol>
  <li>Each page lives in its own subsection and its own chunk.</li>
  <li>The pagename and the chunkname are the same</li>
- <li>The chunk includes the getchunk{standard head}</li>
- <li>The chunk includes the getchunk{page head}</li>
- <li>The chunk includes the getchunk{page foot}</li>
+ <li>The chunk includes the <<standard head>></li>
+ <li>The chunk includes the <<page head>></li>
+ <li>The chunk includes the <<page foot>></li>
 </ol>
 The default page layout cannot communicate with Axiom.
 
@@ -62,22 +88,21 @@ If your page needs to communicate with Axiom you need to add some
 information in the header of the page.
 The default page that talks to Axiom has the form:
 \begin{verbatim}
- \subsection{pagename.xhtml}
-  \begin{chunk}{pagename.xhtml}
-    \getchunk{standard head}
-    <script type="text/javascript">
-     \getchunk{handlefreevars}
-     \getchunk{axiom talker}
-    </script>
-   </head>
-   <body onload="resetvars();">
-    \getchunk{page head}
-    <div align="center">Page subtitle goes here</div>
-    <hr/>
-     your text goes here
-     your communication blocks go here
-    \getchunk{page foot}
-  \end{chunk}
+\subsection{pagename.xhtml}
+<<pagename.xhtml>>=
+<<standard head>>
+  <script type="text/javascript">
+<<handlefreevars>>
+<<axiom talker>>
+  </script>
+ </head>
+ <body onload="resetvars();">
+<<page head>>
+  <div align="center">Page subtitle goes here</div>
+  <hr/>
+your text goes here
+your communication blocks go here
+<<page foot>>
 \end{verbatim}
 
 \subsection{Handling statements with no free variables}
@@ -747,13 +772,13 @@ body-end and html-end tags
 \end{itemize}
 So the basic layout looks like
 \begin{verbatim}
-\end{chunk}\getchunk{standard head}
+<<standard head>>
     (local and general javascript goes here)
  </head>
  <body>
-\end{chunk}\getchunk{page head}
+<<page head>>
     (local page definition goes here)
-\end{chunk}\getchunk{page foot}
+<<page foot>>
 \end{verbatim}
 So all you need to worry about are the actual page forms and the
 javascript to fetch those forms.
@@ -771,7 +796,7 @@ the local javascript:
    function commandline(arg) {
     return(document.getElementById('comm').value);
    }
-   \getchunk{axiom talker}
+<<axiom talker>>
   </script>
 
 \end{verbatim}
@@ -785,10 +810,10 @@ will be sent to the host when the ``Continue'' is pressed:
     <p>
       Type an input command line to Axiom:<br/>
       <input type="text" id="comm" name="command" size="80"/>
-      \getchuk{continue button}
+     <<continue button>>
     </p>
   </form>
-  \getchunk{answer field}
+ <<answer field>>
 \end{verbatim}
 
 Note that the commandline function takes an argument which it gets
@@ -1058,21 +1083,18 @@ the javascript can be added easily.
  <head>
   <meta http-equiv="Content-Type" content="text/html" charset="us-ascii"/>
   <title>Axiom Documentation</title>
-  \getchunk{style}
+\getchunk{style}
 \end{chunk}
-
 This is the standard page header.
 \begin{chunk}{page head}
   <div align="center"><img align="middle" src="doctitle.png"/></div>
   <hr/>
 \end{chunk}
-
 This is the standard page foot.
 \begin{chunk}{page foot}
  </body>
 </html>
 \end{chunk}
-
 This is the standard continue button
 \begin{chunk}{continue button}
    <center>
@@ -1080,7 +1102,6 @@ This is the standard continue button
        onclick="javascript:makeRequest('');"/>
    </center>
 \end{chunk}
-
 This is where to place the math answer
 \begin{chunk}{answer field}
   <div id="mathAns"><div></div></div>
@@ -1304,7 +1325,7 @@ is currently ignored.
 \getchunk{standard head}
 \getchunk{menu style}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -4387,7 +4408,7 @@ groups are constructed. Some algorithms are implemented in Axiom.
 \begin{chunk}{alggrouptheoryrepa6.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -4630,7 +4651,7 @@ Here are some sample computations using Axiom's algebraic number facilities.
 \begin{chunk}{algnumbertheorygalois.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -5307,7 +5328,7 @@ Data Structures
     } else {
      var rcnt = parseInt(document.getElementById('rowcnt').value);
      var ccnt = parseInt(document.getElementById('colcnt').value);
-     var cmdhead = 'matrix([[';
+     var cmdhead = 'matrix([';
      var cmdtail = '])';
      var formula = document.getElementById('formula1').value;
      var rowv = document.getElementById('rowvar').value;
@@ -5458,7 +5479,7 @@ Enter the size of the matrix:
 \begin{chunk}{calderivatives.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -5594,7 +5615,7 @@ You obtain the same result by first evaluating a and then differentiating.
 \begin{chunk}{calintegrals.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -5759,7 +5780,7 @@ More examples of Axiom's integration capabilities are discussed in
 \begin{chunk}{callaplace.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -5838,7 +5859,7 @@ formal transform in the answer.
 \begin{chunk}{callimits.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -6002,7 +6023,7 @@ But this limit does not.
 \begin{chunk}{calmoreintegrals.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -6241,7 +6262,7 @@ Power Series Solutions of Differential Equations</a>
 \begin{chunk}{calseries1.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -6357,7 +6378,7 @@ evaluate this expression. This is the Taylor expansion of exp(w) at w=0.
 \begin{chunk}{calseries2.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -6424,7 +6445,7 @@ all been computed.
 \begin{chunk}{calseries3.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -6481,7 +6502,7 @@ You can also compute f(x)^g(x), where f(x) and g(x) are two power series.
 \begin{chunk}{calseries4.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -6632,7 +6653,7 @@ instead of z.
 \begin{chunk}{calseries5.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -6765,7 +6786,7 @@ exclusively.
 \begin{chunk}{calseries6.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -6905,7 +6926,7 @@ kind of exponents a series has. You can't go wrong with
 \begin{chunk}{calseries7.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -6943,7 +6964,7 @@ of the partial sums.
 \begin{chunk}{calseries8.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -7219,17 +7240,17 @@ The available test suites are:
    }
    function dump(d) {
      if (d.is == "card") {
-      return("CARD"+"\n"+
-             "title:  "+d.title+"\n"+
-             "content:"+d.content+"\n"+
-             "visible:"+d.visible+"\n"+
+      return("CARD"+"\\n"+
+             "title:  "+d.title+"\\n"+
+             "content:"+d.content+"\\n"+
+             "visible:"+d.visible+"\\n"+
              "type:   "+d.type);
      }
      if (d.is == "pamphlet") {
-      return("PAMPHLET"+"\n"+
-             "title:  "+d.title+"\n"+
-             "content:"+d.content+"\n"+
-             "visible:"+d.visible+"\n"+
+      return("PAMPHLET"+"\\n"+
+             "title:  "+d.title+"\\n"+
+             "content:"+d.content+"\\n"+
+             "visible:"+d.visible+"\\n"+
              "type:   "+d.type);
      }
    }
@@ -7979,7 +8000,7 @@ The available test suites are:
 \begin{chunk}{conversionfunctions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -9644,7 +9665,7 @@ Since computing &#x3D5;(N) requires a knowledge of the factorization of
   <ul>
    <li> 
     <span class="cmd">
-     f:TextFile:=open("\full\path\to\file","input")
+     f:TextFile:=open("\\full\\path\\to\\file","input")
     </span>
    </li>
    <li> <span class="cmd">str:=""</span></li>
@@ -12435,7 +12456,7 @@ dbopwrite not implemented
 \begin{chunk}{determinantofhilbert.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -33461,7 +33482,7 @@ The fourth column is the difference of Axiom's value and the Handbook value.
 \begin{chunk}{equdifferential.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -33509,7 +33530,7 @@ and Polynomial Equations</a>.
 \begin{chunk}{equdifferentiallinear.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -33663,7 +33684,7 @@ where all the algebraic solutions are found.
 \begin{chunk}{equdifferentialnonlinear.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -33878,7 +33899,7 @@ Finally, we solve it.
 \begin{chunk}{equdifferentialpowerseries.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -34035,7 +34056,7 @@ Axiom lets you solve equations of various types:
 \begin{chunk}{equsystemlinear.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -34200,7 +34221,7 @@ factored not implemented
 \begin{chunk}{funalgebraicfunctions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -34281,7 +34302,7 @@ quantities from the denominator.
 \begin{chunk}{funelementaryfunctions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -34326,7 +34347,7 @@ instead of variables.
 \begin{chunk}{funoperatoralgebra.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -34613,7 +34634,7 @@ you convert expressions to compiled functions.
 \begin{chunk}{funpatternmatching.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -34997,7 +35018,7 @@ of objects for your application.
 \begin{chunk}{funrationalfunctions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -35059,7 +35080,7 @@ using the function <a href="dbopeval.xhtml">eval</a>. The syntax for
 \begin{chunk}{funsimplification.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -36908,7 +36929,7 @@ Here are some examples of Axiom graphics.
 \begin{chunk}{graphexamplesassorted.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -36978,7 +36999,7 @@ Implicit curves: p(x,y)=0
 \begin{chunk}{graphexamplesimplicit.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37042,7 +37063,7 @@ Cassinian Ovals: two loops
 \begin{chunk}{graphexampleslistofpoints.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37123,7 +37144,7 @@ designated as the viewport's title.
 \begin{chunk}{graphexamplesonevariable.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37165,7 +37186,7 @@ designated as the viewport's title.
 \begin{chunk}{graphexamplesparametric.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37217,7 +37238,7 @@ Another closed curve
 \begin{chunk}{graphexamplespolar.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37268,7 +37289,7 @@ A Limacon
 \begin{chunk}{graphexamplesthreed.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37406,7 +37427,7 @@ lists of points in the plane.
 \begin{chunk}{graphviewports.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37463,7 +37484,7 @@ image should start a "live graphics copy" so you can manipulate the image.
 \begin{chunk}{graph2d.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37495,7 +37516,7 @@ image should start a "live graphics copy" so you can manipulate the image.
 \begin{chunk}{graph2dimplicit.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37535,7 +37556,7 @@ curve equation.
 \begin{chunk}{graph2dlistsofpoints.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37645,7 +37666,7 @@ designated as the viewport's title.
 \begin{chunk}{graph2donevariable.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37714,7 +37735,7 @@ within the viewport title window will be clipped.
 \begin{chunk}{graph2dparametric.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37790,7 +37811,7 @@ t varies.
 \begin{chunk}{graph2dpolar.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -37880,7 +37901,7 @@ domain.
 \begin{chunk}{graph3dobjects.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -38052,7 +38073,7 @@ Create and display the viewport.
 \begin{chunk}{graph3dparametric.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -38127,7 +38148,7 @@ applies to the parameter of the functions, which in this case is t.
 \begin{chunk}{graph3dsurfaces.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -38205,7 +38226,7 @@ range specifies the u-variable and the second range specifies the v-variable.
 \begin{chunk}{graph3dtubeplots.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -38288,7 +38309,7 @@ than one cause self-intersection.
 \begin{chunk}{graph3dtwovariables.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -38389,7 +38410,7 @@ y-variable.
 \begin{chunk}{introtofloat.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -38706,7 +38727,7 @@ infinity; the step size is any positive integer.
 \begin{chunk}{linconversion.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -38877,7 +38898,7 @@ to be fractions.
 \begin{chunk}{lincreate.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -39093,7 +39114,7 @@ a new matrix by reflection across the main diagonal.
 \begin{chunk}{lineigen.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -39234,7 +39255,7 @@ of these vectors.
 \begin{chunk}{linhilbert.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -39322,7 +39343,7 @@ Reset <a href="dbopdigits.xhtml">digits</a> to its default value.
 \begin{chunk}{linintro.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -39434,7 +39455,7 @@ You can perform operations such as
 \begin{chunk}{linoperations.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -39624,7 +39645,7 @@ to display the full ist of operations defined by
 \begin{chunk}{linpermaent.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -39677,7 +39698,7 @@ Here are some derangement numbers, which you see grow quite fast.
 \begin{chunk}{linsquarematrices.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -39762,7 +39783,7 @@ to display the full list of operations defined by
 \begin{chunk}{linvectors.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -39926,7 +39947,7 @@ to display the full list of operations defined by
 \begin{chunk}{lin1darrays.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -40035,7 +40056,7 @@ Replace the first 5 elements of a with those of b.
 \begin{chunk}{lin2darrays.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -40279,27 +40300,27 @@ Enter search string (use <b>*</b> for wild card unless counter-indicated):
   <table>
    <tr>
     <td>
-     <a href="(|kSearch| '|\stringvalue{pattern}|).xhtml">
+     <a href="(|kSearch| '|\\stringvalue{pattern}|).xhtml">
       <b>Constructors</b>
      </a>
     </td>
     <td>
      Search for 
-     <a href="(|cSearch| '|\stringvalue{pattern}|)">
+     <a href="(|cSearch| '|\\stringvalue{pattern}|)">
       <b>categories</b>
      </a>,
-     <a href="(|dSearch| '|\stringvalue{pattern}|)">
+     <a href="(|dSearch| '|\\stringvalue{pattern}|)">
       <b>domains</b>
      </a>,
      or 
-     <a href="(|pSearch| '|\stringvalue{pattern}|)">
+     <a href="(|pSearch| '|\\stringvalue{pattern}|)">
       <b>packages</b>
      </a>
     </td>
    </tr>
    <tr>
     <td>
-     <a href="(|oSearch| '|\stringvalue{pattern}|).xhtml">
+     <a href="(|oSearch| '|\\stringvalue{pattern}|).xhtml">
       <b>Operations</b>
      </a>
     </td>
@@ -40307,7 +40328,7 @@ Enter search string (use <b>*</b> for wild card unless counter-indicated):
    </tr>
    <tr>
     <td>
-     <a href="(|aSearch| '|\stringvalue{pattern}|).xhtml">
+     <a href="(|aSearch| '|\\stringvalue{pattern}|).xhtml">
       <b>Attributes</b>
      </a>
     </td>
@@ -40315,7 +40336,7 @@ Enter search string (use <b>*</b> for wild card unless counter-indicated):
    </tr>
    <tr>
     <td>
-     <a href="(|aokSearch| '|\stringvalue{pattern}|).xhtml">
+     <a href="(|aokSearch| '|\\stringvalue{pattern}|).xhtml">
       <b>General</b>
      </a>
     </td>
@@ -40323,7 +40344,7 @@ Enter search string (use <b>*</b> for wild card unless counter-indicated):
    </tr>
    <tr>
     <td>
-     <a href="(|docSearch| '|\stringvalue{pattern}|).xhtml">
+     <a href="(|docSearch| '|\\stringvalue{pattern}|).xhtml">
       <b>Documentation</b>
      </a>
     </td>
@@ -40332,7 +40353,7 @@ Enter search string (use <b>*</b> for wild card unless counter-indicated):
    </tr>
    <tr>
     <td>
-     <a href="(|genSearch| '|\stringvalue{pattern}|).xhtml">
+     <a href="(|genSearch| '|\\stringvalue{pattern}|).xhtml">
       <b>Complete</b>
      </a>
     </td>
@@ -40341,7 +40362,7 @@ Enter search string (use <b>*</b> for wild card unless counter-indicated):
    </tr>
    <tr>
     <td>
-     <a href="(|detailedSearch| '|\stringvalue{pattern}|).xhtml">
+     <a href="(|detailedSearch| '|\\stringvalue{pattern}|).xhtml">
       <b>Selectable</b>
      </a>
     </td>
@@ -40351,7 +40372,7 @@ Enter search string (use <b>*</b> for wild card unless counter-indicated):
    <hr/>
    <tr>
     <td>
-     <a href="htsearch \stringvalue{pattern}.xhtml">
+     <a href="htsearch \\stringvalue{pattern}.xhtml">
       <b>Reference</b>
      </a>
     </td>
@@ -41326,7 +41347,7 @@ menusimplifytogglealgebraicflag not implemented
 \getchunk{standard head}
  </head>
  <body>
-\getchunk{page head} 
+\getchunk{page head}
 menusimplifytrigsimplification not implemented
 \getchunk{page foot}
 \end{chunk}
@@ -41336,7 +41357,7 @@ menusimplifytrigsimplification not implemented
 \begin{chunk}{numbasicfunctions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -41707,7 +41728,7 @@ Addtional topics
 \begin{chunk}{numcardinalnumbers.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -41931,7 +41952,7 @@ hypothesis in this way:
 \begin{chunk}{numcomplexnumbers.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -42096,7 +42117,7 @@ You can <a href="dbcomplexfactor.xhtml">factor</a> Gaussian integers.
 \begin{chunk}{numcontinuedfractions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -42411,7 +42432,7 @@ is the expansion of the square root of 11.
 \begin{chunk}{numexamples.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -42465,7 +42486,7 @@ Obviously, Fermat didn't have access to Axiom.
 \begin{chunk}{numfactorization.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -42686,7 +42707,7 @@ in section 8.1, and <a href="nummachinefloats.xhtml">DoubleFloat</a>
 \begin{chunk}{numfractions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -42742,7 +42763,7 @@ Additional Topics:
 \begin{chunk}{numfunctions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -43059,7 +43080,7 @@ in other packages. More examples of integers are in the following sections:
 \begin{chunk}{numintegers.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -43160,7 +43181,7 @@ Additional topics
 \begin{chunk}{nummachinefloats.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -43305,7 +43326,7 @@ to get a list of operations.
 \begin{chunk}{nummachinesizedintegers.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -43443,7 +43464,7 @@ To see other operations use the system command
 \begin{chunk}{numnumbertheoreticfunctions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -43551,7 +43572,7 @@ Although they have somewhat limited utility, Axiom provides Roman numerals.
 \begin{chunk}{numnumericfunctions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -44070,7 +44091,7 @@ values in a 6x6 rectangle centered on the origin.
 \begin{chunk}{numoctonions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -44220,7 +44241,7 @@ to display the list of operations defined by
 \begin{chunk}{numotherbases.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -44388,7 +44409,7 @@ expansions are available in
 \begin{chunk}{numpartialfractions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -44559,7 +44580,7 @@ to display the full list of operations defined by
 \begin{chunk}{numproblems.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -44694,7 +44715,7 @@ n**2-n+41 is not prime.
 \begin{chunk}{numquaternions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -44833,7 +44854,7 @@ to display the full list of operations defined by
 \begin{chunk}{numquotientfields.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -44984,7 +45005,7 @@ Conversion is discussed in detail in
 \begin{chunk}{numrationalnumbers.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -45052,7 +45073,7 @@ command:
 \begin{chunk}{numrepeatingbinaryexpansions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -45132,7 +45153,7 @@ These numbers are bona fide algebraic objects.
 \begin{chunk}{numrepeatingdecimals.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -45221,7 +45242,7 @@ to display the full list of operations defined by
 \begin{chunk}{numrepeatinghexexpansions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -45312,7 +45333,7 @@ to display the full list of operations defined by
 \begin{chunk}{numromannumerals.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -45896,7 +45917,7 @@ X transpose is just a row and X is just a column.
 \begin{chunk}{outputfunctions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -46061,7 +46082,7 @@ the output printing to the default behavior.
 \begin{chunk}{pagetwodimensionalarray.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -46306,7 +46327,7 @@ For more information on related topics, see
 \begin{chunk}{polybasicfunctions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -46509,7 +46530,7 @@ some examples.
 \begin{chunk}{polyfactorization1.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -46554,7 +46575,7 @@ Also, Axiom can factor polynomials with rational number coefficients
 \begin{chunk}{polyfactorization2.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -46600,7 +46621,7 @@ about finite fields.
 \begin{chunk}{polyfactorization3.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -46693,7 +46714,7 @@ rational numbers.
 \begin{chunk}{polyfactorization4.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -46736,7 +46757,7 @@ denominator.
 \begin{chunk}{polygcdandfriends.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -46903,7 +46924,7 @@ involved variables other than x.)
 \begin{chunk}{polyroots1.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -46995,7 +47016,7 @@ root using radicals in some cases.
 \begin{chunk}{polyroots2.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -47105,7 +47126,7 @@ defining equation is this. The other three roots are expressed in radicals.
 \begin{chunk}{polyroots3.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -47208,7 +47229,7 @@ where the denominator vanishes are discarded.
 \begin{chunk}{polyroots4.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -47379,7 +47400,7 @@ denominator vanishes are discarded.
 \begin{chunk}{polyspecifictypes1.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -47893,7 +47914,7 @@ to display the full list of operations defined by
 \begin{chunk}{polyspecifictypes2.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -48283,7 +48304,7 @@ to display the full list of operations defined by
 \begin{chunk}{polyspecifictypes3.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -48434,7 +48455,7 @@ to display the full list of operations defined by
 \begin{chunk}{polyspecifictypes4.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -48550,7 +48571,7 @@ DistributedMultivariatePolynomial</a> and
 \begin{chunk}{polysubstitutions.xhtml}
 \getchunk{standard head}
   <script type="text/javascript">
-\getchunk{handlefreevar}
+\getchunk{handlefreevars}
 \getchunk{axiom talker}
   </script>
  </head>
@@ -49860,7 +49881,7 @@ num2str(n) ==
   return concat [char(tmp.i)::String for i in 1..#tmp]
 
 superIncreasing?(lst) ==
-  reduce(/\,[lst.i>reduce(+,[lst.j for j in 1..i-1]) for i in 2..#lst])
+  reduce(/\\,[lst.i>reduce(+,[lst.j for j in 1..i-1]) for i in 2..#lst])
 
 siSolve(lst,n) ==
   local res,m,i
@@ -49953,8 +49974,8 @@ K:=k(3)
 T:=t(3)
 B:=b(3)
 
-\end{chunk}
 
+\end{chunk}
 \subsection{bitmaps/axiom1.bitmap}
 \begin{chunk}{axiom1.bitmap}
 #define axiom_width 270
@@ -50247,7 +50268,7 @@ static char axiom_bits[] = {
 \end{chunk}
 
 \section{License}
-\begin{chunk}{license}
+\begin{verbatim}
 --Copyright (c) 2007 Arthur C. Ralfs
 --All rights reserved.
 --
@@ -50279,7 +50300,7 @@ static char axiom_bits[] = {
 --NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 --SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-\end{chunk}
+\end{verbatim}
 
 \eject
 \begin{thebibliography}{99}
@@ -50290,3 +50311,4 @@ static char axiom_bits[] = {
 \end{thebibliography}
 \printindex
 \end{document}
+
diff --git a/changelog b/changelog
index d8bb028..8c3515b 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,122 @@
+20140628 tpd src/axiom-website/patches.html 20140628.01.tpd.patch
+20140628 tpd Makefile modified, noweb removed
+20140628 tpd Makefile.pamphlet modified, noweb removed
+20140628 tpd lsp/Makefile.pamphlet modified, noweb removed
+20140628 tpd src/Makefile.pamphlet modified, noweb removed
+20140628 tpd src/algebra/Makefile.pamphlet modified, noweb removed
+20140628 tpd src/clef/Makefile.pamphlet modified, noweb removed
+20140628 tpd src/doc/Makefile.pamphlet modified, noweb removed
+20140628 tpd src/etc/Makefile.pamphlet modified, noweb removed
+20140628 tpd src/input/Makefile.pamphlet modified, noweb removed
+20140628 tpd src/interp/Makefile.pamphlet modified, noweb removed
+20140628 tpd src/lib/Makefile.pamphlet modified, noweb removed
+20140628 tpd src/scripts/Makefile.pamphlet modified, noweb removed
+20140628 tpd src/share/Makefile.pamphlet modified, noweb removed
+20140628 tpd faq modified, noweb removed
+20140628 tpd books/bookvol11.pamphlet modified, noweb removed
+20140628 tpd src/clef/edible.c.pamphlet modified, noweb removed
+20140628 tpd src/doc/booklet.c.pamphlet modified, noweb removed
+20140628 tpd src/etc/asq.c.pamphlet modified, noweb removed
+20140628 tpd src/input/aseg6.as.pamphlet modified, noweb removed
+20140628 tpd src/input/aseg7.as.pamphlet modified, noweb removed
+20140628 tpd src/input/cohen.input.pamphlet modified, noweb removed
+20140628 tpd src/input/draw2dsf.data.pamphlet modified, noweb removed
+20140628 tpd src/input/draw2dsf.input.pamphlet modified, noweb removed
+20140628 tpd src/input/ecfact.as.pamphlet modified, noweb removed
+20140628 tpd src/input/hilbert.as.pamphlet modified, noweb removed
+20140628 tpd src/input/matops.as.pamphlet modified, noweb removed
+20140628 tpd src/input/pdecomp0.as.pamphlet modified, noweb removed
+20140628 tpd src/input/romnum.as.pamphlet modified, noweb removed
+20140628 tpd src/lib/bsdsignal.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/cfuns-c.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/cursor.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/edin.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/emupty.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/fnct-key.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/halloc.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/hash.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/openpty.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/pixmap.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/prt.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/sockio-c.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/spadcolors.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/util.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/wct.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/xdither.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/xshade.c.pamphlet modified, noweb removed
+20140628 tpd src/lib/xspadfill.c.pamphlet modified, noweb removed
+20140628 tpd src/input/cohen1.input new, noweb removed
+20140628 tpd src/input/dbtest.input.pamphlet new, noweb removed
+20140628 tpd src/input/diffeqex.input.pamphlet new, noweb removed
+20140628 tpd src/input/examples.input.pamphlet new, noweb removed
+20140628 tpd src/input/fresnel.input.pamphlet new, noweb removed
+20140628 tpd src/input/groebner.input.pamphlet new, noweb removed
+20140628 tpd src/input/lyapunov.input.pamphlet new, noweb removed
+20140628 tpd src/input/oktofail.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich13.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich14a.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich14b.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich14c.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich15.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich16.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich17.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich18.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich19.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich20a.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich20b.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich20c.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich21.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich22a.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich22b.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich22c.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich22d.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich23.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich24a.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich24b.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich24c.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich24d.input.pamphlet new, noweb removed
+20140628 tpd src/input/rich25.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder13.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder14a.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder14b.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder14c.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder15.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder16.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder17.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder18.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder19.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder20a.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder20b.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder20c.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder21.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder22a.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder22b.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder22c.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder22d.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder23.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder24a.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder24b.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder24c.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder24d.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder8b.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder8c.input.pamphlet new, noweb removed
+20140628 tpd src/input/richder8d.input.pamphlet new, noweb removed
+20140628 tpd src/input/series3.input.pamphlet new, noweb removed
+20140628 tpd zips/noweb-2.10a.tgz deleted, noweb removed
+20140628 tpd zips/noweb.modules.c.patch deleted, noweb removed
+20140628 tpd zips/noweb.modules.nw.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.Makefile.nw.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.Makefile.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.awk.totex.nw.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.awkname.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.lib.toascii.nw.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.lib.toascii.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.shell.cpif.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.shell.nonu.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.shell.noroff.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.shell.roff.mm.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.shell.roff.nw.patch deleted, noweb removed
+20140628 tpd zips/noweb.src.shell.toroff.patch deleted, noweb removed
 20140625 tpd src/axiom-website/patches.html 20140625.02.tpd.patch
 20140625 tpd Makefile.pamphlet extract src/Makefile using chunk syntax
 20140625 tpd src/Makefile.pamphlet extract src using chunk syntax
diff --git a/faq b/faq
index df5018b..d51ac45 100644
--- a/faq
+++ b/faq
@@ -649,7 +649,7 @@ Savannah to the floats.spad.pamphlet file.
    include the following new subsection and stanzas
 
 \subsection{negfloats}
-<<negfloats>>=
+\begin{chunk}{negfloats}
 ${OUT}/negfloats.input: ${MID}/negfloats.input
         @ echo 426 making ${OUT}/negfloats.input from ${MID}/negfloats.input
         @ cp ${MID}/negfloats.input ${OUT}/ngefloats.input
@@ -658,7 +658,7 @@ ${MID}/negfloats.input: ${IN}/negfloats.input.pamphlet
         @ echo 427 making ${MID}/negfloats.input from
 ${IN}/negfloats.input.pamphlet
         @(cd ${MID} ; \
-          ${TANGLE} ${IN}/negfloats.input.pamphlet >negfloats.input )
+          ${BOOKS}/tangle ${IN}/negfloats.input.pamphlet >negfloats.input )
 
 4) Made a new entry for negfloats in
 
@@ -668,12 +668,12 @@ FILES= ${OUT}/algaggr.input  ${OUT}/algbrbf.input    ${OUT}/algfacob.input \
        ${OUT}/negfloats.input \
        ...
 
-5) Added a reference to <<negfloats>> in <<*>>=
+5) Added a reference to chunk negfloats in the default chunk *
 
-<<*>>=
+\begin{chunk}{*}
 ...
-<<NDFtip>>
-<<negfloats>>
+\getchunk{NDFtip}
+\getchunk{negfloats}
 ...
 
 6) Did axiom 'make' to compile the revised floats domain and
diff --git a/lsp/Makefile.pamphlet b/lsp/Makefile.pamphlet
index ad6d615..2b2764e 100644
--- a/lsp/Makefile.pamphlet
+++ b/lsp/Makefile.pamphlet
@@ -17,11 +17,11 @@ over the gcl Makefiles.
 \section{Gnu Common Lisp 2.6.7}
 There is a typo in configure.in that is only detected under some
 versions of bash. The problem is a missing single-quote mark.
-<<gcl-2.6.7.configure.in.patch>>=
+\begin{chunk}{gcl-2.6.7.configure.in.patch}
 	@(cd ${GCLVERSION} ; \
 	  echo 28a applying configure.in patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.configure.in.patch )
-@
+\end{chunk}
 \section{Gnu Common Lisp 2.6.7pre}
 \subsection{run-process patch}
 The gcl-2.6.6.h.linux.h.patch has been accepted into the mainline lisp
@@ -29,70 +29,70 @@ code and is no longer needed.
 \section{Gnu Common Lisp 2.6.6}
 We need run-process to handle the new browser and graphics direction.
 \subsection{run-process patch}
-<<gcl-2.6.6.h.linux.h.patch>>=
+\begin{chunk}{gcl-2.6.6.h.linux.h.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 28a applying run-process patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.h.patch )
-@
+\end{chunk}
 This patch fixes the namestring argument to handle windows-style
 names with spaces. This patch is no longer needed as this was merged
 into the CVS HEAD for 2.6.6.
-<<gcl-2.6.6.cmpnew.gcl\_cmpmain.lsp.patch>>=
+\begin{chunk}{gcl-2.6.6.cmpnew.gcl\_cmpmain.lsp.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 1 applying cmpnew/gcl_cmpmain.lsp.patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpmain.lsp.patch )
-@
+\end{chunk}
 \section{Gnu Common Lisp 2.6.5w}
 This is a Windows port of GCL. We run under MSYS and have to make
 a few Windows specific changes.
 \subsection{mingw.defs}
-This patch adds the necessary [[.o]] files to the [[EXTRAS]] variable
+This patch adds the necessary .o files to the EXTRAS variable
 so they are available at link time.
-<<gcl-2.6.5w.h.mingw.defs.patch>>=
+\begin{chunk}{gcl-2.6.5w.h.mingw.defs.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 1 applying gcl-2.6.5.h.mingw.defs.patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.mingw.defs.patch )
-@
+\end{chunk}
 \subsection{alloc.c}
 If malloc() gets called by the C runtime before
 main starts and the shared memory is not yet
 initialised causing failure. We set
-[[SET_REAL_MAXPAGE]] which forces a call to [[init_shared_memory()]].
-<<gcl-2.6.5w.o.alloc.c.patch>>=
+\verb|SET_REAL_MAXPAGE| which forces a call to \verb|init_shared_memory()|.
+\begin{chunk}{gcl-2.6.5w.o.alloc.c.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 2 applying gcl-2.6.5w.o.alloc.c.patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.alloc.c.patch )
-@
+\end{chunk}
 \subsection{mingfile.c}
 We do not need to call truename. In fact, truename does not seem
 to be expanding pathnames properly.
-<<gcl-2.6.5w.o.mingfile.c.patch>>=
+\begin{chunk}{gcl-2.6.5w.o.mingfile.c.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 3 applying gcl-2.6.5w.o.mingfile.c.patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.mingfile.c.patch )
-@
+\end{chunk}
 \subsection{unixfsys.c}
 We have to do conversions of Windows filenames.
-<<gcl-2.6.5w.o.unixfsys.c.patch>>=
+\begin{chunk}{gcl-2.6.5w.o.unixfsys.c.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 4 applying gcl-2.6.5w.o.unixfsys.c.patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.unixfsys.c.patch )
-@
+\end{chunk}
 \section{Gnu Common Lisp 2.6.5}
 \subsection{gmp wrappers patch}
-The file [[gmp_wrappers.h]] has the declaration of the integer [[j]]
+The file \verb|gmp_wrappers.h| has the declaration of the integer $j$
 out of order. This causes the compiler to complain. This patch puts
 the declaration at the beginning of the function.
-<<gcl-2.6.5.h.gmp\_wrappers.h.patch>>=
+\begin{chunk}{gcl-2.6.5.h.gmp\_wrappers.h.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 28 applying gmp_wrappers patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.gmp_wrappers.h.patch )
-@
-<<gcl-2.6.5w.h.gmp\_wrappers.h.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.5w.h.gmp\_wrappers.h.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 6 applying gmp_wrappers patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.gmp_wrappers.h.patch )
-@
+\end{chunk}
 \section{Gnu Common Lisp 2.5.2}
 \subsubsection{socket patch}
 This patch is to {\bf h/386-linux.defs} to include two 
@@ -111,87 +111,87 @@ routines should be rewritten.
 We also need to create two .ini files, one for cfuns-c and one
 for sockio-c. These are referenced in the gcl-2.4.1 makefiles
 but, since no initialization is needed, we simply create empty files.
-<<gcl-2.5.2.socket.patch>>=
+\begin{chunk}{gcl-2.5.2.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.1.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.1.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.2.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.2.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.2a.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.2a.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.3.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.3.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.5.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.5.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.5w.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.5w.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 19 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 20 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.6.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.6.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.7pre.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.7pre.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.7.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.7.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.8pre.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch ; \
@@ -200,70 +200,70 @@ but, since no initialization is needed, we simply create empty files.
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.8pre2.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre2.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.8pre3.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre3.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
-<<gcl-2.6.8pre4.socket.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre4.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
+\end{chunk}
 As of this version we no longer use the EXTRAS variable.
 This has been changed to use the SYSTEM\_OBJS variable, per Camm (Apr 6,2012)
-<<gcl-2.6.8pre7.h.linux.defs.patch>>=
+\begin{chunk}{gcl-2.6.8pre7.h.linux.defs.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@
+\end{chunk}
 \subsubsection{read.d patch}
 The new read-char-no-hang change no longer returns EOF so we have
 no way to know when the browser is finished talking. This causes 
 AXSERV to hang waiting for more input which never comes. The browser
 hangs waiting for a response.
-<<gcl-2.6.8pre3.read.patch>>=
+\begin{chunk}{gcl-2.6.8pre3.read.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 100 applying read.d patch to o/read.d ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.read.d.patch )
-@
-<<gcl-2.6.8pre4.read.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre4.read.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 100 applying read.d patch to o/read.d ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.read.d.patch )
-@
-<<gcl-2.6.8pre7.o.read.d.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre7.o.read.d.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 100 applying read.d patch to o/read.d ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.read.d.patch )
-@
+\end{chunk}
 
 \subsubsection{fortran patch}
 Communication over sockets (basically to the NAG fortran library)
 requires us to have XDR enabled.
-<<gcl-2.5.2.fortran.patch>>=
+\begin{chunk}{gcl-2.5.2.fortran.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 5 applying HAVE_XDR patch to h/linux.h ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.h.patch )
-@
+\end{chunk}
 This patch is no longer necessary as of GCL-2.6.1 because the 
 C preparser symbol HAVE\_XDR is now the default in GCL.
 \subsubsection{libspad patch}
@@ -273,171 +273,171 @@ References from {\bf cfuns-c} and {\bf sockio-c} are resolved
 from {\bf libspad.a}
 
 Additionally this patch contains a temporary fix to the makefile
-for the windows port. Apparently the [[$^]] variable is not
+for the windows port. Apparently the \verb|$^| variable is not
 properly expanded and this works around the problem.
-<<gcl-2.5.2.libspad.patch>>=
+\begin{chunk}{gcl-2.5.2.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.1.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.1.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.2.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.2.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.2a.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.2a.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.3.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.3.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.5.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.5.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.5w.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.5w.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 28 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
+\end{chunk}
 In this version of the patch we can delete one of the two changes.
 The for-loop change has been included in the sources.
-<<gcl-2.6.6.libspad.patch>>=
+\begin{chunk}{gcl-2.6.6.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.7pre.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.7pre.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.7.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.7.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.8pre.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.8pre2.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre2.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.8pre3.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre3.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.8pre4.libspad.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre4.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
-<<gcl-2.6.8pre7.unixport.makefile.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre7.unixport.makefile.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
+\end{chunk}
 \subsubsection{toploop patch}
 This patch turns off the banner display every time GCL starts.
 We could use the -batch flag but that would be a pervasive change.
 It isn't critical to the system builds but we will later be 
 capturing stdin and stdout and we do not want extra information
 printed.
-<<gcl-2.5.2.toploop.patch>>=
+\begin{chunk}{gcl-2.5.2.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.1.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.1.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.2.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.2.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.2a.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.2a.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.3.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.3.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.5.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.5.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.6.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.6.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.7pre.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.7pre.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.7.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.7.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
+\end{chunk}
 Now, for some reason, lisp needs to tell you what the temporary directory
 for the compiler will be. We eliminate this noise as well as the banner.
-<<gcl-2.6.8pre.toploop.patch>>=
+\begin{chunk}{gcl-2.6.8pre.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.8pre2.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre2.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.8pre3.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre3.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.8pre4.toploop.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre4.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
-<<gcl-2.6.8pre7.unixport.initgcl.lsp.in.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre7.unixport.initgcl.lsp.in.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
+\end{chunk}
 \subsubsection{object to float patch}
 GCL 2.5.2 contains no reference to this function and it was removed.
 Axiom uses this function so we re-implement it here.
-<<gcl-2.5.2.objecttofloat.patch>>=
+\begin{chunk}{gcl-2.5.2.objecttofloat.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 8 applying object_to_float patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.cmpaux.c.patch )
-@
+\end{chunk}
 This patch is no longer necessary as of GCL-2.6.1 because object\_to\_float
 is now defined by default.
 \subsubsection{in-package patch}
@@ -446,35 +446,35 @@ This changes the common lisp 2.0 defined behavior of in-package
 the 1.0 defined behavior (create the package if it does not exist).
 This patch is intended to be temporary. Axiom's common lisp code
 should be fixed and this patch removed before shipment.
-<<gcl-2.5.2.in-package.patch>>=
+\begin{chunk}{gcl-2.5.2.in-package.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 9 applying in-package patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.package.d.patch )
-@
+\end{chunk}
 I believe that all instances of in-package have been fixed and 
 that this patch is no longer necessary.
 \subsubsection{EXIT and MAX\_STACK\_SIZE patchs}
 Axiom uses EXIT as a function. GCL 2.5.2 decided to make it a 
 synonym to the BYE function. We fix this for Axiom.
 We also patch the MAX\_STACK\_SIZE to be 16Mb.
-<<gcl-2.5.2.exit.patch>>=
+\begin{chunk}{gcl-2.5.2.exit.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 10 applying EXIT patch ; \
 	  echo 18 applying MAX_STACK_SIZE patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.main.c.patch )
-@
+\end{chunk}
 As of GCL-2.6.1 EXIT is no longer defined.
-<<gcl-2.6.1.exit.patch>>=
+\begin{chunk}{gcl-2.6.1.exit.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 18 applying MAX_STACK_SIZE patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.main.c.patch )
-@
+\end{chunk}
 As of GCL-2.6.1 EXIT is no longer defined.
-<<gcl-2.6.2.exit.patch>>=
+\begin{chunk}{gcl-2.6.2.exit.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 18 applying MAX_STACK_SIZE patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.main.c.patch )
-@
+\end{chunk}
 \subsubsection{tail-recursive patch}
 Bill Schelter added tail recursion for Axiom. In order to test it
 he left code in the system to print a message when the code was
@@ -485,212 +485,212 @@ usage.
 Bill Page reported that this tail-recursive patch is no longer
 necessary for recent releases of GCL. Consequently, it has
 been disabled for all versions of GCL greater than 2.6.7.
-<<gcl-2.5.2.tail-recursive.patch>>=
+\begin{chunk}{gcl-2.5.2.tail-recursive.patch}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 11 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.cmpflet.lsp.patch )
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 12 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.cmpcall.lsp.patch )
-@
+\end{chunk}
 GCL 2.6.1 renamed the files.
-<<gcl-2.6.1.tail-recursive.patch>>=
+\begin{chunk}{gcl-2.6.1.tail-recursive.patch}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 11 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpflet.lsp.patch )
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 12 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpcall.lsp.patch )
-@
-<<gcl-2.6.2.tail-recursive.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.2.tail-recursive.patch}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 11 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpflet.lsp.patch )
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 12 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpcall.lsp.patch )
-@
-<<gcl-2.6.2a.tail-recursive.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.2a.tail-recursive.patch}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 11 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpflet.lsp.patch )
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 12 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpcall.lsp.patch )
-@
-<<gcl-2.6.3.tail-recursive.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.3.tail-recursive.patch}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 11 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpflet.lsp.patch )
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 12 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpcall.lsp.patch )
-@
-<<gcl-2.6.5.tail-recursive.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.5.tail-recursive.patch}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 11 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpflet.lsp.patch )
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 12 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpcall.lsp.patch )
-@
-<<gcl-2.6.5w.tail-recursive.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.5w.tail-recursive.patch}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 54 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpflet.lsp.patch )
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 55 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpcall.lsp.patch )
-@
-<<gcl-2.6.6.tail-recursive.patch>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.6.tail-recursive.patch}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 11 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpflet.lsp.patch )
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 12 applying tail-recursive noise patch ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.cmpnew.gcl_cmpcall.lsp.patch )
-@
+\end{chunk}
 \subsubsection{collectfn fix}
 GCL-2.6.1 renamed collectfn.lsp to gcl\_collectfn.lsp.
 We rename it back into place because we have later Makefiles
 that depend on it. The alternative is to propagate the name changes thru
 all of those Makefile and they would now need to know about the GCLVERSION
 variable. 
-<<gcl-2.6.1.collectfn.fix>>=
+\begin{chunk}{gcl-2.6.1.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/collectfn.lsp )
-@
-<<gcl-2.6.2.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.2.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/collectfn.lsp )
-@
+\end{chunk}
 In this version we have created a new subdirectory for use by GCL
-during compile time at [[obj/sys/lsp]]. We copy two files from 
-GCL, the [[collectfn.lsp]] file and the [[sys-proclaim.lisp]] file. 
+during compile time at obj/sys/lsp. We copy two files from 
+GCL, the collectfn.lsp file and the sys-proclaim.lisp file. 
 The collectfn.lsp contains code which extends the GCL compiler and
 collects type information. The compile-file function writes this
-type information to a [[.fn]] file as structs. These structs can
+type information to a .fn file as structs. These structs can
 be loaded and written out as a file of lisp proclaims. The sys-proclaim.lisp
 file contains the proclaims for GCL's function definitions.
-<<gcl-2.6.2a.collectfn.fix>>=
+\begin{chunk}{gcl-2.6.2a.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.3.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.3.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.5.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.5.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.5w.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.5w.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 64 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 65 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.6.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.6.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.7pre.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.7pre.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.7.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.7.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.8pre.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.8pre2.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre2.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.8pre3.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre3.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.8pre4.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre4.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
-<<gcl-2.6.8pre7.collectfn.fix>>=
+\end{chunk}
+\begin{chunk}{gcl-2.6.8pre7.collectfn.fix}
 	@(cd ${GCLVERSION}/cmpnew ; \
 	  echo 26 copy gcl_collectfn.lsp to ${OBJ}/${SYS}/lsp/collectfn.lsp ; \
 	  cp gcl_collectfn.lsp ${OBJ}/${SYS}/lsp/collectfn.lsp )
 	@(cd ${GCLVERSION}/lsp ; \
 	  echo 27 copy sys-proclaim.lisp to ${OBJ}/${SYS}/lsp/sys-proclaim.lisp ; \
 	  cp sys-proclaim.lisp ${OBJ}/${SYS}/lsp/sys-proclaim.lisp )
-@
+\end{chunk}
 \subsection{The GCL-2.5.2 stanza}
 \subsubsection{Configure and Make GCL}
 We enable several features of GCL. 
-The [[--enable-readline]] uses GNU readline for the prompts. It has been
+The --enable-readline uses GNU readline for the prompts. It has been
 removed and replaced with clef which is Axiom's version of readline.
-The [[--enable-maxpage]] is set to allow the image to grow 4 times what it would by default. 
-The [[--enable-vssize]] allows virtual stack to grow by twice the normal size. 
-The [[--enable-statsysbfd]] uses a static system bfd library for loading and
+The --enable-maxpage is set to allow the image to grow 4 times what it would by default. 
+The --enable-vssize allows virtual stack to grow by twice the normal size. 
+The --enable-statsysbfd uses a static system bfd library for loading and
 relocating object files.
  
-Finally we load some routines for performance reasons. [[lsp/sys-proclaim]]
+Finally we load some routines for performance reasons. lsp/sys-proclaim
 contains common lisp proclaim statements for the various GCL lisp routines.
-[[cmpnew/gcl_collectfn]] contains modifications to the common lisp compiler
-to collect compile-time type information which will be written to [[.fn]]
-files as common lisp structs. These [[.fn]] files can be loaded and turned
+\verb|cmpnew/gcl_collectfn| contains modifications to the common lisp compiler
+to collect compile-time type information which will be written to .fn
+files as common lisp structs. These .fn files can be loaded and turned
 into common lisp proclaim statements which the compiler can use to generate
-faster code, mostly fast-path function calls. The call to [[compiler::emit-fn]]
-enables the [[.fn]] file generation whenever compile-file is called. We
+faster code, mostly fast-path function calls. The call to compiler::emit-fn
+enables the .fn file generation whenever compile-file is called. We
 default this code into the image so it is always avaiable.
 
-The [[./configure]] command takes a few options for building GCL.
+The ./configure command takes a few options for building GCL.
 These need to be changed for various systems so we make these into a
 variable and move them up to the top level Makefile.
 
@@ -700,7 +700,7 @@ Next we load the tangle function into a clean lisp image.
 Finally move the tangle lisp to the named lisp image.
 This means that all other lisp derived images will know how to tangle.
 
-<<gclConfigureMake>>=
+\begin{chunk}{gclConfigureMake}
 	@(cd ${GCLVERSION} ; \
 	./configure ${GCLOPTS} ; \
 	${ENV} ${MAKE} ; \
@@ -716,7 +716,7 @@ This means that all other lisp derived images will know how to tangle.
 	@mv ${OUT}/tangle ${OUT}/lisp 
 	@echo 9999 lisp tangle version created
            
-@
+\end{chunk}
 GCL 2.5.2 changes are due to David Mentre (david.mentre@wanadoo.fr).
 The key problem to solve is that 2.5.2 uses the common lisp 2.0 standard.
 In Common Lisp 1.0 if you do (in-package 'foo) and the foo package does
@@ -735,7 +735,7 @@ by GCLVERSION.
 When the GCLVERSION variable is ``gcl-2.5.2'' this stanza will be used. 
 The default version is overwritten. See the top level Makefile.pamphlet.
 
-<<gcl-2.5.2>>=
+\begin{chunk}{gcl-2.5.2}
 # gcl version 2.5.2
 OUT=${OBJ}/${SYS}/bin
 
@@ -745,11 +745,11 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.5.2.fortran.patch>>
-<<gcl-2.5.2.objecttofloat.patch>>
-<<gcl-2.5.2.in-package.patch>>
-<<gcl-2.5.2.exit.patch>>
-<<gcl-2.5.2.tail-recursive.patch>>
+\getchunk{gcl-2.5.2.fortran.patch}
+\getchunk{gcl-2.5.2.objecttofloat.patch}
+\getchunk{gcl-2.5.2.in-package.patch}
+\getchunk{gcl-2.5.2.exit.patch}
+\getchunk{gcl-2.5.2.tail-recursive.patch}
 	echo '(compiler::link (list (compile-file "${BOOKS}/tangle.lisp")) \
          "${OUT}/lisp" (format nil "(progn (let \
          ((*load-path* (cons ~S *load-path*)) (si::*load-types* ~S)) \
@@ -780,7 +780,7 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.1 stanza}
 GCL 2.6.1 has support for --enable-static for static linking.
 Axiom will eventually support static images.
@@ -795,7 +795,7 @@ When the GCLVERSION variable is ``gcl-2.6.1'' this stanza will be
 used.  It will overwrite the default version. See the top level
 Makefile.pamphlet.
 
-<<gcl-2.6.1>>=
+\begin{chunk}{gcl-2.6.1}
 # gcl version 2.6.1
 OUT=${OBJ}/${SYS}/bin
 
@@ -805,13 +805,13 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.1.socket.patch>>
-<<gcl-2.6.1.libspad.patch>>
-<<gcl-2.6.1.toploop.patch>>
-<<gcl-2.6.1.exit.patch>>
-<<gcl-2.6.1.tail-recursive.patch>>
-<<gcl-2.6.1.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.1.socket.patch}
+\getchunk{gcl-2.6.1.libspad.patch}
+\getchunk{gcl-2.6.1.toploop.patch}
+\getchunk{gcl-2.6.1.exit.patch}
+\getchunk{gcl-2.6.1.tail-recursive.patch}
+\getchunk{gcl-2.6.1.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -833,7 +833,7 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.2 stanza}
 GCL 2.6.2 has support for --enable-static for static linking.
 Axiom will eventually support static images.
@@ -848,7 +848,7 @@ When the GCLVERSION variable is ``gcl-2.6.2'' this stanza will be
 written.  It will overwrite the default version. See the top level
 Makefile.pamphlet.
 
-<<gcl-2.6.2>>=
+\begin{chunk}{gcl-2.6.2}
 # gcl version 2.6.2
 OUT=${OBJ}/${SYS}/bin
 
@@ -858,13 +858,13 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.2.socket.patch>>
-<<gcl-2.6.2.libspad.patch>>
-<<gcl-2.6.2.toploop.patch>>
-<<gcl-2.6.2.exit.patch>>
-<<gcl-2.6.2.tail-recursive.patch>>
-<<gcl-2.6.2.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.2.socket.patch}
+\getchunk{gcl-2.6.2.libspad.patch}
+\getchunk{gcl-2.6.2.toploop.patch}
+\getchunk{gcl-2.6.2.exit.patch}
+\getchunk{gcl-2.6.2.tail-recursive.patch}
+\getchunk{gcl-2.6.2.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -886,14 +886,14 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{Directory move}
 The latest version of GCL no longer uses the version number in the
 directory name. We fix that here.
-<<gcl-2.6.2a-mvdir>>=
+\begin{chunk}{gcl-2.6.2a-mvdir}
 	@echo 27 renaming gcl to ${GCLVERSION}
 	@mv gcl gcl-2.6.2a
-@
+\end{chunk}
 
 \subsection{The GCL-2.6.2a stanza}
 
@@ -906,7 +906,7 @@ on computationally intensive jobs with and without this variable set.
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.2a''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.2a>>=
+\begin{chunk}{gcl-2.6.2a}
 # gcl version 2.6.2a
 OUT=${OBJ}/${SYS}/bin
 
@@ -916,13 +916,13 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.2a-mvdir>>
-<<gcl-2.6.2a.socket.patch>>
-<<gcl-2.6.2a.libspad.patch>>
-<<gcl-2.6.2a.toploop.patch>>
-<<gcl-2.6.2a.tail-recursive.patch>>
-<<gcl-2.6.2a.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.2a-mvdir}
+\getchunk{gcl-2.6.2a.socket.patch}
+\getchunk{gcl-2.6.2a.libspad.patch}
+\getchunk{gcl-2.6.2a.toploop.patch}
+\getchunk{gcl-2.6.2a.tail-recursive.patch}
+\getchunk{gcl-2.6.2a.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -944,19 +944,19 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{Directory move}
 The latest version of GCL no longer uses the version number in the
 directory name. We fix that here.
-<<gcl-2.6.3-mvdir>>=
+\begin{chunk}{gcl-2.6.3-mvdir}
 	@echo 27 renaming gcl to ${GCLVERSION}
 	@mv gcl gcl-2.6.3
-@
+\end{chunk}
 \subsection{The GCL-2.6.3 stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.3''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.3>>=
+\begin{chunk}{gcl-2.6.3}
 # gcl version 2.6.3
 OUT=${OBJ}/${SYS}/bin
 
@@ -966,13 +966,13 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.3-mvdir>>
-<<gcl-2.6.3.socket.patch>>
-<<gcl-2.6.3.libspad.patch>>
-<<gcl-2.6.3.toploop.patch>>
-<<gcl-2.6.3.tail-recursive.patch>>
-<<gcl-2.6.3.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.3-mvdir}
+\getchunk{gcl-2.6.3.socket.patch}
+\getchunk{gcl-2.6.3.libspad.patch}
+\getchunk{gcl-2.6.3.toploop.patch}
+\getchunk{gcl-2.6.3.tail-recursive.patch}
+\getchunk{gcl-2.6.3.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -994,12 +994,12 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.5 stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.5''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.5>>=
+\begin{chunk}{gcl-2.6.5}
 # gcl version 2.6.5
 OUT=${OBJ}/${SYS}/bin
 
@@ -1009,13 +1009,13 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.5.socket.patch>>
-<<gcl-2.6.5.libspad.patch>>
-<<gcl-2.6.5.toploop.patch>>
-<<gcl-2.6.5.h.gmp\_wrappers.h.patch>>
-<<gcl-2.6.5.tail-recursive.patch>>
-<<gcl-2.6.5.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.5.socket.patch}
+\getchunk{gcl-2.6.5.libspad.patch}
+\getchunk{gcl-2.6.5.toploop.patch}
+\getchunk{gcl-2.6.5.h.gmp\_wrappers.h.patch}
+\getchunk{gcl-2.6.5.tail-recursive.patch}
+\getchunk{gcl-2.6.5.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -1037,7 +1037,7 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.5w stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.5w''. It will overwrite the default version. See the 
@@ -1046,9 +1046,9 @@ top level Makefile.pamphlet.
 This is version for Windows. We have moved forward several patches
 from the GCL standard but are not ready to accept the latest GCL
 version because it breaks Axiom. We only include the patches that
-are needed for Windows. We untar the [[gcl-2.6.5]] version and then
-rename it to [[gcl-2.6.5w]]
-<<gcl-2.6.5w>>=
+are needed for Windows. We untar the gcl-2.6.5 version and then
+rename it to gcl-2.6.5w
+\begin{chunk}{gcl-2.6.5w}
 # gcl version 2.6.5w
 OUT=${OBJ}/${SYS}/bin
 
@@ -1059,17 +1059,17 @@ gcldir:
 	@echo 111 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/gcl-2.6.5.tgz
 	@mv gcl-2.6.5 ${GCLVERSION}
-<<gcl-2.6.5w.socket.patch>>
-<<gcl-2.6.5w.libspad.patch>>
-<<gcl-2.6.5w.toploop.patch>>
-<<gcl-2.6.5w.h.gmp\_wrappers.h.patch>>
-<<gcl-2.6.5w.tail-recursive.patch>>
-<<gcl-2.6.5w.collectfn.fix>>
-<<gcl-2.6.5w.h.mingw.defs.patch>>
-<<gcl-2.6.5w.o.alloc.c.patch>>
-<<gcl-2.6.5w.o.mingfile.c.patch>>
-<<gcl-2.6.5w.o.unixfsys.c.patch>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.5w.socket.patch}
+\getchunk{gcl-2.6.5w.libspad.patch}
+\getchunk{gcl-2.6.5w.toploop.patch}
+\getchunk{gcl-2.6.5w.h.gmp\_wrappers.h.patch}
+\getchunk{gcl-2.6.5w.tail-recursive.patch}
+\getchunk{gcl-2.6.5w.collectfn.fix}
+\getchunk{gcl-2.6.5w.h.mingw.defs.patch}
+\getchunk{gcl-2.6.5w.o.alloc.c.patch}
+\getchunk{gcl-2.6.5w.o.mingfile.c.patch}
+\getchunk{gcl-2.6.5w.o.unixfsys.c.patch}
+\getchunk{gclConfigureMake}
 	@echo 112 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -1091,12 +1091,12 @@ clean:
 	@echo 116 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.6 stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.6''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.6>>=
+\begin{chunk}{gcl-2.6.6}
 # gcl version 2.6.6
 OUT=${OBJ}/${SYS}/bin
 
@@ -1106,13 +1106,13 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.6.h.linux.h.patch>>
-<<gcl-2.6.6.socket.patch>>
-<<gcl-2.6.6.libspad.patch>>
-<<gcl-2.6.6.toploop.patch>>
-<<gcl-2.6.6.tail-recursive.patch>>
-<<gcl-2.6.6.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.6.h.linux.h.patch}
+\getchunk{gcl-2.6.6.socket.patch}
+\getchunk{gcl-2.6.6.libspad.patch}
+\getchunk{gcl-2.6.6.toploop.patch}
+\getchunk{gcl-2.6.6.tail-recursive.patch}
+\getchunk{gcl-2.6.6.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -1134,12 +1134,12 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.7pre stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.7pre''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.7pre>>=
+\begin{chunk}{gcl-2.6.7pre}
 # gcl version 2.6.7pre
 OUT=${OBJ}/${SYS}/bin
 
@@ -1149,11 +1149,11 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.7pre.socket.patch>>
-<<gcl-2.6.7pre.libspad.patch>>
-<<gcl-2.6.7pre.toploop.patch>>
-<<gcl-2.6.7pre.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.7pre.socket.patch}
+\getchunk{gcl-2.6.7pre.libspad.patch}
+\getchunk{gcl-2.6.7pre.toploop.patch}
+\getchunk{gcl-2.6.7pre.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -1175,12 +1175,12 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.7 stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.7''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.7>>=
+\begin{chunk}{gcl-2.6.7}
 # gcl version 2.6.7
 OUT=${OBJ}/${SYS}/bin
 
@@ -1190,12 +1190,12 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.7.configure.in.patch>>
-<<gcl-2.6.7.socket.patch>>
-<<gcl-2.6.7.libspad.patch>>
-<<gcl-2.6.7.toploop.patch>>
-<<gcl-2.6.7.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.7.configure.in.patch}
+\getchunk{gcl-2.6.7.socket.patch}
+\getchunk{gcl-2.6.7.libspad.patch}
+\getchunk{gcl-2.6.7.toploop.patch}
+\getchunk{gcl-2.6.7.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -1217,12 +1217,12 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.8pre stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.8pre''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.8pre>>=
+\begin{chunk}{gcl-2.6.8pre}
 # gcl version 2.6.8pre
 OUT=${OBJ}/${SYS}/bin
 
@@ -1232,11 +1232,11 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.8pre.socket.patch>>
-<<gcl-2.6.8pre.libspad.patch>>
-<<gcl-2.6.8pre.toploop.patch>>
-<<gcl-2.6.8pre.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.8pre.socket.patch}
+\getchunk{gcl-2.6.8pre.libspad.patch}
+\getchunk{gcl-2.6.8pre.toploop.patch}
+\getchunk{gcl-2.6.8pre.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -1258,12 +1258,12 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.8pre2 stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.8pre2''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.8pre2>>=
+\begin{chunk}{gcl-2.6.8pre2}
 # gcl version 2.6.8pre2
 OUT=${OBJ}/${SYS}/bin
 
@@ -1273,11 +1273,11 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.8pre2.socket.patch>>
-<<gcl-2.6.8pre2.libspad.patch>>
-<<gcl-2.6.8pre2.toploop.patch>>
-<<gcl-2.6.8pre2.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.8pre2.socket.patch}
+\getchunk{gcl-2.6.8pre2.libspad.patch}
+\getchunk{gcl-2.6.8pre2.toploop.patch}
+\getchunk{gcl-2.6.8pre2.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -1299,12 +1299,12 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.8pre3 stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.8pre3''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.8pre3>>=
+\begin{chunk}{gcl-2.6.8pre3}
 # gcl version 2.6.8pre3
 OUT=${OBJ}/${SYS}/bin
 
@@ -1314,12 +1314,12 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.8pre3.socket.patch>>
-<<gcl-2.6.8pre3.libspad.patch>>
-<<gcl-2.6.8pre3.toploop.patch>>
-<<gcl-2.6.8pre3.collectfn.fix>>
-<<gcl-2.6.8pre3.read.patch>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.8pre3.socket.patch}
+\getchunk{gcl-2.6.8pre3.libspad.patch}
+\getchunk{gcl-2.6.8pre3.toploop.patch}
+\getchunk{gcl-2.6.8pre3.collectfn.fix}
+\getchunk{gcl-2.6.8pre3.read.patch}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -1341,12 +1341,12 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.8pre4 stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.8pre4''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.8pre4>>=
+\begin{chunk}{gcl-2.6.8pre4}
 # gcl version 2.6.8pre4
 OUT=${OBJ}/${SYS}/bin
 
@@ -1356,12 +1356,12 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.8pre4.socket.patch>>
-<<gcl-2.6.8pre4.libspad.patch>>
-<<gcl-2.6.8pre4.toploop.patch>>
-<<gcl-2.6.8pre4.collectfn.fix>>
-<<gcl-2.6.8pre4.read.patch>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.8pre4.socket.patch}
+\getchunk{gcl-2.6.8pre4.libspad.patch}
+\getchunk{gcl-2.6.8pre4.toploop.patch}
+\getchunk{gcl-2.6.8pre4.collectfn.fix}
+\getchunk{gcl-2.6.8pre4.read.patch}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -1383,12 +1383,12 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \subsection{The GCL-2.6.8pre7 stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.6.8pre7''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.6.8pre7>>=
+\begin{chunk}{gcl-2.6.8pre7}
 # gcl version 2.6.8pre7
 OUT=${OBJ}/${SYS}/bin
 
@@ -1398,12 +1398,12 @@ all:
 gcldir: 
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.6.8pre7.h.linux.defs.patch>>
-<<gcl-2.6.8pre7.o.read.d.patch>>
-<<gcl-2.6.8pre7.unixport.initgcl.lsp.in.patch>>
-<<gcl-2.6.8pre7.unixport.makefile.patch>>
-<<gcl-2.6.8pre7.collectfn.fix>>
-<<gclConfigureMake>>
+\getchunk{gcl-2.6.8pre7.h.linux.defs.patch}
+\getchunk{gcl-2.6.8pre7.o.read.d.patch}
+\getchunk{gcl-2.6.8pre7.unixport.initgcl.lsp.in.patch}
+\getchunk{gcl-2.6.8pre7.unixport.makefile.patch}
+\getchunk{gcl-2.6.8pre7.collectfn.fix}
+\getchunk{gclConfigureMake}
 	@echo 13 finished system build on `date` | tee >gcldir
 
 ccldir: ${LSP}/ccl/Makefile
@@ -1425,7 +1425,7 @@ clean:
 	@echo 17 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \section{Gnu Common Lisp 2.5}
 GCL 2.5 requires a different Makefile. In particular, GCL 2.5
 has a different method of building the lisp image. And, just to
@@ -1449,58 +1449,58 @@ routines should be rewritten.
 We also need to create two .ini files, one for cfuns-c and one
 for sockio-c. These are referenced in the gcl-2.4.1 makefiles
 but, since no initialization is needed, we simply create empty files.
-<<gcl-2.5.socket.patch>>=
+\begin{chunk}{gcl-2.5.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 3 applying EXTRAS patch to h/linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.defs.patch )
 	@(echo 4 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@ 
+\end{chunk} 
 \subsubsection{fortran patch}
 Communication over sockets (basically to the NAG fortran library)
 requires us to have XDR enabled.
-<<gcl-2.5.fortran.patch>>=
+\begin{chunk}{gcl-2.5.fortran.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 5 applying HAVE_XDR patch to h/linux.h ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.linux.h.patch )
-@
+\end{chunk}
 \subsubsection{libspad patch}
 The second patch changes the {\bf unixport/makefile} to reference
 the {\bf libspad.a} library when building the raw system image.
 References from {\bf cfuns-c} and {\bf sockio-c} are resolved 
 from {\bf libspad.a}
-<<gcl-2.5.libspad.patch>>=
+\begin{chunk}{gcl-2.5.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 6 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@
+\end{chunk}
 \subsubsection{toploop patch}
 This patch turns off the banner display every time GCL starts.
 We could use the -batch flag but that would be a pervasive change.
 It isn't critical to the system builds but we will later be 
 capturing stdin and stdout and we do not want extra information
 printed.
-<<gcl-2.5.toploop.patch>>=
+\begin{chunk}{gcl-2.5.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 7 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.in.patch )
-@
+\end{chunk}
 \subsubsection{xdrfuns bug patch}
 We enabled XDR only to find out that there is a missing argument
 in the call to FEerror from xdrstdio\_create. We fix this here and
 send a patch to the GCL people. It should be fixed in future releases
 and this patch should die.
-<<gcl-2.5.xdrfuns.patch>>=
+\begin{chunk}{gcl-2.5.xdrfuns.patch}
 	@(cd ${GCLVERSION}/o ; \
 	  echo 8 applying XDR patch to o/xdrfuns.c ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.o.xdrfuns.c.patch )
-@ 
+\end{chunk} 
 \subsection{The GCL-2.5 stanza}
 This stanza will be written when the GCLVERSION variable is
 ``gcl-2.5''. It will overwrite the default version. See the 
 top level Makefile.pamphlet.
-<<gcl-2.5>>=
+\begin{chunk}{gcl-2.5}
 # gcl version 2.5
 OUT=${OBJ}/${SYS}/bin
 
@@ -1511,11 +1511,11 @@ gcldir:
 	@echo 2 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
 	@mv gcl ${GCLVERSION}
-<<gcl-2.5.socket.patch>>
-<<gcl-2.5.fortran.patch>>
-<<gcl-2.5.libspad.patch>>
-<<gcl-2.5.toploop.patch>>
-<<gcl-2.5.xdrfuns.patch>>
+\getchunk{gcl-2.5.socket.patch}
+\getchunk{gcl-2.5.fortran.patch}
+\getchunk{gcl-2.5.libspad.patch}
+\getchunk{gcl-2.5.toploop.patch}
+\getchunk{gcl-2.5.xdrfuns.patch}
 	@(cd ${GCLVERSION} ; \
 	./configure --enable-vssize=65536 ; \
 	${ENV} ${MAKE} ; \
@@ -1541,7 +1541,7 @@ clean:
 	@echo 13 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
 
-@
+\end{chunk}
 \section{Gnu Common Lisp 2.4.1 (The default build)}
 \subsubsection{socket patch}
 This patch is to {\bf h/386-linux.defs} to include two 
@@ -1560,49 +1560,49 @@ routines should be rewritten.
 We also need to create two .ini files, one for cfuns-c and one
 for sockio-c. These are referenced in the gcl-2.4.1 makefiles
 but, since no initialization is needed, we simply create empty files.
-<<gcl-2.4.1.socket.patch>>=
+\begin{chunk}{gcl-2.4.1.socket.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 16 applying EXTRAS patch to h/386-linux.defs ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.386-linux.defs.patch )
 	@(echo 17 setup ini files for EXTRAS patch ; \
 	  touch ${OBJ}/${SYS}/lib/cfuns-c.ini ; \
 	  touch ${OBJ}/${SYS}/lib/sockio-c.ini )
-@ 
+\end{chunk} 
 \subsubsection{fortran patch}
 Communication over sockets (basically to the NAG fortran library)
 requires us to have XDR enabled.
-<<gcl-2.4.1.fortran.patch>>=
+\begin{chunk}{gcl-2.4.1.fortran.patch}
 	@(cd ${GCLVERSION}/h ; \
 	  echo 18 applying HAVE_XDR patch to h/386-linux.h ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.h.386-linux.h.patch )
-@ 
+\end{chunk} 
 \subsubsection{libspad patch}
 The second patch changes the {\bf unixport/makefile} to reference
 the {\bf libspad.a} library when building the raw system image.
 References from {\bf cfuns-c} and {\bf sockio-c} are resolved 
 from {\bf libspad.a}
-<<gcl-2.4.1.libspad.patch>>=
+\begin{chunk}{gcl-2.4.1.libspad.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 19 applying libspad.a patch to unixport/makefile ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.makefile.patch )
-@ 
+\end{chunk} 
 \subsubsection{toploop patch}
 This patch turns off the banner display every time GCL starts.
 We could use the -batch flag but that would be a pervasive change.
 It isn't critical to the system builds but we will later be 
 capturing stdin and stdout and we do not want extra information
 printed.
-<<gcl-2.4.1.toploop.patch>>=
+\begin{chunk}{gcl-2.4.1.toploop.patch}
 	@(cd ${GCLVERSION}/unixport ; \
 	  echo 20 applying toploop patch to unixport/init_gcl.lsp ; \
 	  ${PATCH} <${SPD}/zips/${GCLVERSION}.unixport.init_gcl.lsp.patch )
-@ 
+\end{chunk} 
 \section{The Makefile}
 \subsection{GCL already installed}
 On some systems, notably freebsd, we assume that GCL is already 
-installed and available using the command [[gcl]]. In that case
+installed and available using the command gcl. In that case
 we need to extract this Makefile instead of the standard one.
-<<gcl-system>>=
+\begin{chunk}{gcl-system}
 # locally installed GCL
 OUT=${OBJ}/${SYS}/bin
 
@@ -1642,8 +1642,8 @@ document:
 clean:
 	@echo 24 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
-@
-<<*>>=
+\end{chunk}
+\begin{chunk}{*}
 OUT=${OBJ}/${SYS}/bin
 
 all:
@@ -1652,10 +1652,10 @@ all:
 gcldir: 
 	@echo 15 building ${GCLVERSION}
 	@tar -zxf ${ZIPS}/${GCLVERSION}.tgz
-<<gcl-2.4.1.socket.patch>>
-<<gcl-2.4.1.fortran.patch>>
-<<gcl-2.4.1.libspad.patch>>
-<<gcl-2.4.1.toploop.patch>>
+\getchunk{gcl-2.4.1.socket.patch}
+\getchunk{gcl-2.4.1.fortran.patch}
+\getchunk{gcl-2.4.1.libspad.patch}
+\getchunk{gcl-2.4.1.toploop.patch}
 	@(cd ${GCLVERSION} ; \
 	./configure --enable-vssize=65536 ; \
 	${ENV} ${MAKE} ; \
@@ -1680,7 +1680,7 @@ document:
 clean:
 	@echo 25 cleaning ${LSP}/ccl
 	@( cd ccl ; ${ENV} ${MAKE} clean )
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/patch b/patch
index cb1649d..64827ff 100644
--- a/patch
+++ b/patch
@@ -1,6 +1,163 @@
-Makefile.pamphlet src/Makefile.pamphlet use chunk syntax
+remove noweb
 
-This is the src Makefile using the chunk syntax along with
-supporting build machinery. The tangle.c function can extract
-code from a pamphlet. The extract function can create the PDf
-of a pamphlet.
+This update removes all use of the noweb syntax so we can remove
+the noweb package. Axiom used four parts of noweb, the notangle
+function, the noweave function, the chunk syntax, and the [[ ]]
+quoting mechanism.
+
+The notangle function is now both at the C level, from 
+books/tangle.c and the lisp level books/tangle.lisp. This is also
+built into the Axiom image so that given
+    foo.input.pamphlet
+you can extract and run foo.input with the command
+    )tangle foo
+    )read foo
+
+The noweave function is not used. Pamphlet files are now valid latex
+files so the latex command can be used directly.
+
+The chunk syntax has been replaced
+  <<foo>>=    becomes   \begin{chunk}{foo}
+  <<foo>>     becomes   \getchunk{foo}
+  @           becomes   \end{chunk}
+
+The [[foo]] quoting syntax is replaced with \verb|foo|
+
+The primary remaining use of noweb was in the Makefiles.
+These have been rewritten to eliminate noweb use.
+
+#	modified:   Makefile
+#	modified:   Makefile.pamphlet
+#	modified:   lsp/Makefile.pamphlet
+#	modified:   src/Makefile.pamphlet
+#	modified:   src/algebra/Makefile.pamphlet
+#	modified:   src/clef/Makefile.pamphlet
+#	modified:   src/doc/Makefile.pamphlet
+#	modified:   src/etc/Makefile.pamphlet
+#	modified:   src/input/Makefile.pamphlet
+#	modified:   src/interp/Makefile.pamphlet
+#	modified:   src/lib/Makefile.pamphlet
+#	modified:   src/scripts/Makefile.pamphlet
+#	modified:   src/share/Makefile.pamphlet
+
+The src/sman directory only contained a Makefile. 
+This has been absorbed into other Makefiles and removed
+
+#	deleted:    src/sman/Makefile.pamphlet
+
+Many c and src/input file contained the original version using noweb.
+These were updated to use the chunk syntax.
+
+#	modified:   faq
+#	modified:   books/bookvol11.pamphlet
+#	modified:   src/clef/edible.c.pamphlet
+#	modified:   src/doc/booklet.c.pamphlet
+#	modified:   src/etc/asq.c.pamphlet
+#	modified:   src/input/aseg6.as.pamphlet
+#	modified:   src/input/aseg7.as.pamphlet
+#	modified:   src/input/cohen.input.pamphlet
+#	modified:   src/input/draw2dsf.data.pamphlet
+#	modified:   src/input/draw2dsf.input.pamphlet
+#	modified:   src/input/ecfact.as.pamphlet
+#	modified:   src/input/hilbert.as.pamphlet
+#	modified:   src/input/matops.as.pamphlet
+#	modified:   src/input/pdecomp0.as.pamphlet
+#	modified:   src/input/romnum.as.pamphlet
+#	modified:   src/lib/bsdsignal.c.pamphlet
+#	modified:   src/lib/cfuns-c.c.pamphlet
+#	modified:   src/lib/cursor.c.pamphlet
+#	modified:   src/lib/edin.c.pamphlet
+#	modified:   src/lib/emupty.c.pamphlet
+#	modified:   src/lib/fnct-key.c.pamphlet
+#	modified:   src/lib/halloc.c.pamphlet
+#	modified:   src/lib/hash.c.pamphlet
+#	modified:   src/lib/openpty.c.pamphlet
+#	modified:   src/lib/pixmap.c.pamphlet
+#	modified:   src/lib/prt.c.pamphlet
+#	modified:   src/lib/sockio-c.c.pamphlet
+#	modified:   src/lib/spadcolors.c.pamphlet
+#	modified:   src/lib/util.c.pamphlet
+#	modified:   src/lib/wct.c.pamphlet
+#	modified:   src/lib/xdither.c.pamphlet
+#	modified:   src/lib/xshade.c.pamphlet
+#	modified:   src/lib/xspadfill.c.pamphlet
+
+Some newer pamphlet files were still using the old syntax.
+In particular, the 'richxxx' files are the inputs for the
+computer algebra test suite (CATS) effort.
+
+#	new file:   src/input/cohen1.input
+#	new file:   src/input/dbtest.input.pamphlet
+#	new file:   src/input/diffeqex.input.pamphlet
+#	new file:   src/input/examples.input.pamphlet
+#	new file:   src/input/fresnel.input.pamphlet
+#	new file:   src/input/groebner.input.pamphlet
+#	new file:   src/input/lyapunov.input.pamphlet
+#	new file:   src/input/oktofail.input.pamphlet
+#	new file:   src/input/rich13.input.pamphlet
+#	new file:   src/input/rich14a.input.pamphlet
+#	new file:   src/input/rich14b.input.pamphlet
+#	new file:   src/input/rich14c.input.pamphlet
+#	new file:   src/input/rich15.input.pamphlet
+#	new file:   src/input/rich16.input.pamphlet
+#	new file:   src/input/rich17.input.pamphlet
+#	new file:   src/input/rich18.input.pamphlet
+#	new file:   src/input/rich19.input.pamphlet
+#	new file:   src/input/rich20a.input.pamphlet
+#	new file:   src/input/rich20b.input.pamphlet
+#	new file:   src/input/rich20c.input.pamphlet
+#	new file:   src/input/rich21.input.pamphlet
+#	new file:   src/input/rich22a.input.pamphlet
+#	new file:   src/input/rich22b.input.pamphlet
+#	new file:   src/input/rich22c.input.pamphlet
+#	new file:   src/input/rich22d.input.pamphlet
+#	new file:   src/input/rich23.input.pamphlet
+#	new file:   src/input/rich24a.input.pamphlet
+#	new file:   src/input/rich24b.input.pamphlet
+#	new file:   src/input/rich24c.input.pamphlet
+#	new file:   src/input/rich24d.input.pamphlet
+#	new file:   src/input/rich25.input.pamphlet
+#	new file:   src/input/richder13.input.pamphlet
+#	new file:   src/input/richder14a.input.pamphlet
+#	new file:   src/input/richder14b.input.pamphlet
+#	new file:   src/input/richder14c.input.pamphlet
+#	new file:   src/input/richder15.input.pamphlet
+#	new file:   src/input/richder16.input.pamphlet
+#	new file:   src/input/richder17.input.pamphlet
+#	new file:   src/input/richder18.input.pamphlet
+#	new file:   src/input/richder19.input.pamphlet
+#	new file:   src/input/richder20a.input.pamphlet
+#	new file:   src/input/richder20b.input.pamphlet
+#	new file:   src/input/richder20c.input.pamphlet
+#	new file:   src/input/richder21.input.pamphlet
+#	new file:   src/input/richder22a.input.pamphlet
+#	new file:   src/input/richder22b.input.pamphlet
+#	new file:   src/input/richder22c.input.pamphlet
+#	new file:   src/input/richder22d.input.pamphlet
+#	new file:   src/input/richder23.input.pamphlet
+#	new file:   src/input/richder24a.input.pamphlet
+#	new file:   src/input/richder24b.input.pamphlet
+#	new file:   src/input/richder24c.input.pamphlet
+#	new file:   src/input/richder24d.input.pamphlet
+#	new file:   src/input/richder8b.input.pamphlet
+#	new file:   src/input/richder8c.input.pamphlet
+#	new file:   src/input/richder8d.input.pamphlet
+#	new file:   src/input/series3.input.pamphlet
+
+And now we can delete our copy of noweb and local changes.
+
+#	deleted:    zips/noweb-2.10a.tgz
+#	deleted:    zips/noweb.modules.c.patch
+#	deleted:    zips/noweb.modules.nw.patch
+#	deleted:    zips/noweb.src.Makefile.nw.patch
+#	deleted:    zips/noweb.src.Makefile.patch
+#	deleted:    zips/noweb.src.awk.totex.nw.patch
+#	deleted:    zips/noweb.src.awkname.patch
+#	deleted:    zips/noweb.src.lib.toascii.nw.patch
+#	deleted:    zips/noweb.src.lib.toascii.patch
+#	deleted:    zips/noweb.src.shell.cpif.patch
+#	deleted:    zips/noweb.src.shell.nonu.patch
+#	deleted:    zips/noweb.src.shell.noroff.patch
+#	deleted:    zips/noweb.src.shell.roff.mm.patch
+#	deleted:    zips/noweb.src.shell.roff.nw.patch
+#	deleted:    zips/noweb.src.shell.toroff.patch
diff --git a/src/Makefile.pamphlet b/src/Makefile.pamphlet
index 4a99a93..f0b779d 100644
--- a/src/Makefile.pamphlet
+++ b/src/Makefile.pamphlet
@@ -61,8 +61,8 @@ ${SRC}/scripts/Makefile: ${SRC}/scripts/Makefile.pamphlet
 	@echo 2 making ${SRC}/scripts/Makefile from \
            ${SRC}/scripts/Makefile.pamphlet
 	@( cd scripts ; \
-           ${DOCUMENT} ${NOISE} Makefile ; \
-           cp Makefile.dvi ${MNT}/${SYS}/doc/src/scripts.Makefile.dvi )
+           ${EXTRACT} Makefile ; \
+           cp Makefile.pdf ${MNT}/${SYS}/doc/src/scripts.Makefile.pdf )
 
 scriptsdocument: ${SRC}/scripts/Makefile
 	@echo 3 documenting ${SRC}/scripts
@@ -89,8 +89,8 @@ clefdir: ${SRC}/clef/Makefile
 ${SRC}/clef/Makefile: ${SRC}/clef/Makefile.pamphlet
 	@echo 6 making ${SRC}/clef/Makefile from ${SRC}/clef/Makefile.pamphlet
 	@( cd clef ; \
-           ${DOCUMENT} ${NOISE} Makefile ; \
-           cp Makefile.dvi ${MNT}/${SYS}/doc/src/clef.Makefile.dvi )
+           ${EXTRACT} Makefile ; \
+           cp Makefile.pdf ${MNT}/${SYS}/doc/src/clef.Makefile.pdf )
 
 clefdocument: ${SRC}/clef/Makefile
 	@echo 7 documenting ${SRC}/clef
@@ -133,8 +133,8 @@ ${SRC}/share/Makefile: ${SRC}/share/Makefile.pamphlet
 	@echo 10 making ${SRC}/share/Makefile from \
            ${SRC}/share/Makefile.pamphlet
 	@( cd share ; \
-           ${DOCUMENT} ${NOISE} Makefile ; \
-           cp Makefile.dvi ${MNT}/${SYS}/doc/src/share.Makefile.dvi )
+           ${EXTRACT} Makefile ; \
+           cp Makefile.pdf ${MNT}/${SYS}/doc/src/share.Makefile.pdf )
 
 sharedocument: ${SRC}/share/Makefile
 	@echo 11 documenting ${SRC}/share
@@ -193,8 +193,8 @@ libdir: ${SRC}/lib/Makefile
 ${SRC}/lib/Makefile: ${SRC}/lib/Makefile.pamphlet
 	@echo 18 making ${SRC}/lib/Makefile from ${SRC}/lib/Makefile.pamphlet
 	@( cd lib ; \
-           ${DOCUMENT} ${NOISE} Makefile ; \
-           cp Makefile.dvi ${MNT}/${SYS}/doc/src/lib.Makefile.dvi )
+           ${EXTRACT} Makefile ; \
+           cp Makefile.pdf ${MNT}/${SYS}/doc/src/lib.Makefile.pdf )
 
 libdocument: ${SRC}/lib/Makefile
 	@echo 19 documenting ${SRC}/lib
@@ -229,8 +229,8 @@ bootdir: ${SRC}/boot/Makefile
 ${SRC}/boot/Makefile: ${SRC}/boot/Makefile.pamphlet
 	@echo 22 making ${SRC}/boot/Makefile from ${SRC}/boot/Makefile.pamphlet
 	@( cd boot ; \
-           ${DOCUMENT} ${NOISE} Makefile ; \
-           cp Makefile.dvi ${MNT}/${SYS}/doc/src/boot.Makefile.dvi )
+           ${EXTRACT} Makefile ; \
+           cp Makefile.pdf ${MNT}/${SYS}/doc/src/boot.Makefile.pdf )
 
 bootdocument: ${SRC}/boot/Makefile
 	@echo 23 documenting ${SRC}/boot
@@ -283,8 +283,8 @@ ${SRC}/interp/Makefile: ${SRC}/interp/Makefile.pamphlet
 	@echo 26 making ${SRC}/interp/Makefile from \
                  ${SRC}/interp/Makefile.pamphlet
 	@( cd interp ; \
-           ${DOCUMENT} ${NOISE} Makefile ; \
-           cp Makefile.dvi ${MNT}/${SYS}/doc/src/interp.Makefile.dvi )
+           ${EXTRACT} Makefile ; \
+           cp Makefile.pdf ${MNT}/${SYS}/doc/src/interp.Makefile.pdf )
 
 interpdocument: ${SRC}/interp/Makefile
 	@echo 27 documenting ${SRC}/interp
@@ -328,8 +328,8 @@ ${SRC}/input/Makefile: ${SRC}/input/Makefile.pamphlet
 	@echo 34 making ${SRC}/input/Makefile from \
                 ${SRC}/input/Makefile.pamphlet
 	@( cd input ; \
-           ${DOCUMENT} ${NOISE} Makefile ; \
-           cp Makefile.dvi ${MNT}/${SYS}/doc/src/input.Makefile.dvi )
+           ${EXTRACT} Makefile ; \
+           cp Makefile.pdf ${MNT}/${SYS}/doc/src/input.Makefile.pdf )
 
 inputdocument: ${SRC}/input/Makefile
 	@echo 35 documenting ${SRC}/input
@@ -361,8 +361,8 @@ etcdir: ${SRC}/etc/Makefile
 ${SRC}/etc/Makefile: ${SRC}/etc/Makefile.pamphlet
 	@echo 38 making ${SRC}/etc/Makefile from ${SRC}/etc/Makefile.pamphlet
 	@( cd etc ; \
-           ${DOCUMENT} ${NOISE} Makefile ; \
-           cp Makefile.dvi ${MNT}/${SYS}/doc/src/etc.Makefile.dvi )
+           ${EXTRACT} Makefile ; \
+           cp Makefile.pdf ${MNT}/${SYS}/doc/src/etc.Makefile.pdf )
 
 etcdocument: ${SRC}/etc/Makefile
 	@echo 39 documenting ${SRC}/etc
@@ -401,13 +401,17 @@ docdir: ${SRC}/doc/Makefile
                | ${LTANGLE} )
 	@ cp ${BOOKS}/ps/doctitle.png ${AXIOM}/doc/hypertex/doctitle.png
 	@ cp ${BOOKS}/ps/lightbayou.png ${AXIOM}/doc/hypertex/lightbayou.png
+	@(cd ${MNT}/${SYS}/doc/hypertex ; \
+	  ${BOOKS}/tangle ${SPD}/books/bookvol11.pamphlet >Makefile11 ; \
+	  ${ENV} ${MAKE} -f Makefile11 ; \
+	  rm -f Makefile11 )
 	@(cd doc ; ${ENV} ${MAKE} )
 
 ${SRC}/doc/Makefile: ${SRC}/doc/Makefile.pamphlet
 	@echo 42 making ${SRC}/doc/Makefile from ${SRC}/doc/Makefile.pamphlet
 	@( cd doc ; \
-           ${DOCUMENT} ${NOISE} Makefile ; \
-           cp Makefile.dvi ${MNT}/${SYS}/doc/src/doc.Makefile.dvi )
+           ${EXTRACT} Makefile ; \
+           cp Makefile.pdf ${MNT}/${SYS}/doc/src/doc.Makefile.pdf )
 
 docdocument: ${SRC}/doc/Makefile
 	@echo 43 documenting ${SRC}/doc
@@ -516,15 +520,15 @@ algebradir: ${SRC}/algebra/Makefile ${SPD}/books/bookvol10.pamphlet \
 ${SRC}/algebra/Makefile: ${SRC}/algebra/Makefile.pamphlet
 	@echo 30 making ${SRC}/algebra/Makefile from \
                 ${SRC}/algebra/Makefile.pamphlet
-	@( cd algebra ; ${DOCUMENT} ${NOISE} Makefile ; \
-        cp Makefile.dvi ${MNT}/${SYS}/doc/src/algebra.Makefile.dvi ; \
+	@( cd algebra ; ${EXTRACT} Makefile ; \
+        cp Makefile.pdf ${MNT}/${SYS}/doc/src/algebra.Makefile.pdf ; \
 	cp ${SPD}/books/bookvol10.2.pamphlet . ; \
 	cp ${SPD}/books/bookvol10.3.pamphlet . ; \
 	cp ${SPD}/books/bookvol10.4.pamphlet . ; \
 	cp ${SPD}/books/bookvol10.5.pamphlet . ; \
 	echo 30a extracting findAlgebraFiles from \
                  ${SRC}/algebra/Makefile.pamphlet ; \
-	${TANGLE} -t8 -RfindAlgebraFiles Makefile.pamphlet \
+	${BOOKS}/tangle Makefile.pamphlet findAlgebraFiles \
             > ${INT}/algebra/findAlgebraFiles ; \
 	echo 30b running ${INT}/algebra/findAlgebraFiles ; \
 	. ${INT}/algebra/findAlgebraFiles >> Makefile)
@@ -556,7 +560,7 @@ browserdir: ${SPD}/books/bookvol11.pamphlet
 	@echo 11 making browser from bookvol11
 #	@mkdir -p ${MNT}/${SYS}/doc/hypertex/bitmaps
 #	@(cd ${MNT}/${SYS}/doc/hypertex ; \
-#	  ${TANGLE} -t8 ${SPD}/books/bookvol11.pamphlet >Makefile11 ; \
+#	  ${BOOKS}/tangle ${SPD}/books/bookvol11.pamphlet >Makefile11 ; \
 #	  ${ENV} ${MAKE} -j 10 -f Makefile11 ; \
 #	  rm -f Makefile11 )
 
@@ -577,9 +581,14 @@ all of the lower level directories.
 
 \getchunk{environment}
 
-all: ${DIRS}
+all: announce ${DIRS}
 	@echo 49 finished ${SRC}
 
+announce:
+	@ echo ======================================
+	@ echo src BUILDING SRC
+	@ echo ======================================
+
 setup: ${SETUP}
 
 \getchunk{scriptsdir}
diff --git a/src/algebra/Makefile.pamphlet b/src/algebra/Makefile.pamphlet
index f5d42e0..ce831f5 100644
--- a/src/algebra/Makefile.pamphlet
+++ b/src/algebra/Makefile.pamphlet
@@ -132,7 +132,7 @@ Here we use BasicStochasticDifferential.output to create a set of test
 cases. These are automatically extracted as part of the build process
 by the function ``makeInputFiles''. This function is in the tangle.lisp file.
 \begin{verbatim}
-<BasicStochasticDifferential.input>>=
+
 )set break resume
 )sys rm -f BasicStochasticDifferential.output
 )spool BasicStochasticDifferential.output
@@ -159,7 +159,7 @@ g := gcd(p, q)
 
 )spool
 )lisp (bye)
- @
+
 \end{verbatim}
 
 \subsubsection{The help section}
@@ -374,7 +374,7 @@ main algebra graph.
 "FSAGG" [color="#4488FF",href="bookvol10.2.pdf#nameddest=FSAGG"]
 "BSD" -> "FSAGG"
 
-@
+\end{chunk}
 \end{verbatim}
 In order to actually create the graph this code gets wrapped with the
 graphviz information. So you pick up the above lines and insert them
@@ -472,7 +472,7 @@ is FOO.spad.
 
 Each layer is followed by a layerpic chunk which gives the graphviz
 graph information. The graphviz header information is here:
-<<layerpic>>=
+\begin{chunk}{layerpic}
 digraph pic {
  fontsize=10;
  bgcolor="\#ECEA81";
@@ -492,7 +492,7 @@ digraph pic {
 "Package" [color="\#FF4488"]
 "Package" -> "."
 
-@
+\end{chunk}
 
 \subsubsection{Completed spad files}
 Note well that none of the algebra stanzas should include these
@@ -521,7 +521,7 @@ will no longer compile so don't change it if you don't understand it.
 LAYER0BOOTSTRAP=${OUT}/XPR.o 
 \end{verbatim}
 
-<<layer0 bootstrap>>=
+\begin{chunk}{layer0 bootstrap}
 
 LAYER0BOOTSTRAP=\
   ${MID}/ABELGRP.o  ${MID}/ABELGRP-.o ${MID}/ABELMON.o  ${MID}/ABELMON-.o \
@@ -548,8 +548,8 @@ LAYER0BOOTSTRAP=\
   ${MID}/VECTOR.o \
   layer0bootstrap
 
-@
-<<layer0 copy>>=
+\end{chunk}
+\begin{chunk}{layer0 copy}
 
 LAYER0COPY=\
   ${OUT}/ABELGRP.o  ${OUT}/ABELGRP-.o ${OUT}/ABELMON.o  ${OUT}/ABELMON-.o \
@@ -576,11 +576,11 @@ LAYER0COPY=\
   ${OUT}/VECTOR.o \
   layer0copy
 
-@
+\end{chunk}
 \subsection{Layer 0}
 Depends on: Category Domain Package Bootstrap\\
 Used by next layer: BASTYPE CFCAT KOERCE KONVERT TYPE
-<<layer0>>=
+\begin{chunk}{layer0}
 
 LAYER0=\
   ${OUT}/AHYP.o     ${OUT}/ATADDVA.o  ${OUT}/ATCENRL.o  ${OUT}/ATCS.o \
@@ -600,8 +600,8 @@ LAYER0=\
   ${OUT}/RFDIST.o   ${OUT}/RIDIST.o   ${OUT}/SPFCAT.o  ${OUT}/TYPE.o \
   layer0done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 0 */
 /* depends on: Category Domain Package Bootstrap */
 /* provides: BASTYPE CFCAT KOERCE KONVERT TYPE */
@@ -752,13 +752,13 @@ LAYER0=\
 "TYPE" [color="#4488FF",href="bookvol10.2.pdf#nameddest=TYPE"]
 "TYPE"  -> "Category"
 
-@
+\end{chunk}
 \subsection{Layer 1}
 Depends on: BASTYPE CFCAT KOERCE KONVERT TYPE\\
 Used by next layer: AGG ELTAGG FINITE FORTCAT IDPC IEVALAB LMODULE 
 MONAD ORDSET PATMAB RETRACT RMODULE SGROUP 
 
-<<layer1>>=
+\begin{chunk}{layer1}
 
 LAYER1=\
   ${OUT}/AGG.o      ${OUT}/AGG-.o     ${OUT}/ANON.o     ${OUT}/ANY1.o     \
@@ -791,8 +791,8 @@ LAYER1=\
   ${OUT}/TEX1.o     ${OUT}/UDVO.o     ${OUT}/YSTREAM.o \
   layer1done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 1 */
 /* depends on: BASTYPE CFCAT KOERCE KONVERT TYPE */
 /* provides: FORTCAT RETRACT SEGCAT */
@@ -1247,13 +1247,13 @@ LAYER1=\
 "YSTREAM" -> "TYPE"
 /*"YSTREAM" -> {"INT"; "SINT"; "NNI"}*/
 
-@
+\end{chunk}
 \subsection{Layer 2}
 Depends on: AGG ELTAGG FINITE FORTCAT IDPC IEVALAB LMODULE MONAD ORDSET 
 PATMAB RETRACT RMODULE SGROUP SETCATD \\
 Used by next layer: BMODULE CACHSET ELEMFUN EVALAB GROUP IXAGG MONADWU NARNG 
 OASGP PDRING 
-<<layer2>>=
+\begin{chunk}{layer2}
 
 LAYER2=\
   ${OUT}/AFSPCAT.o  \
@@ -1277,8 +1277,8 @@ LAYER2=\
   ${OUT}/TRIGCAT-.o ${OUT}/ULS2.o     ${OUT}/UP2.o \
   layer2done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 2 */
 /* AGG ELTAGG FINITE FORTCAT IDPC IEVALAB LMODULE MONAD ORDSET */
 /* PATMAB RETRACT RMODULE SEGCAT SGROUP SETCATD */
@@ -1707,12 +1707,12 @@ LAYER2=\
 /*"UP2" -> {"SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"; "MONOID"}*/
 "UP2" -> "LMODULE/SGROUP"
 
-@
+\end{chunk}
 \subsection{Layer 3}
 Depends on: BMODULE CACHSET ELEMFUN EVALAB GROUP IXAGG MONADWU NARNG 
 OASGP PDRING\\
 Used by next layer: BGAGG BRAGG ELAGG- GRMOD MODULE OAMON 
-<<layer3>>=
+\begin{chunk}{layer3}
 
 LAYER3=\
   ${OUT}/AUTOMOR.o  ${OUT}/BGAGG.o   ${OUT}/BGAGG-.o   ${OUT}/BRAGG.o    \
@@ -1725,9 +1725,9 @@ LAYER3=\
   ${OUT}/NASRING-.o ${OUT}/OAMON.o   ${OUT}/SORTPAK.o  ${OUT}/ZMOD.o \
   layer3done
 
-@
+\end{chunk}
 
-<<layerpic>>=
+\begin{chunk}{layerpic}
 /* layer 3 */
 /* depends on: BMODULE CACHSET ELEMFUN EVALAB GROUP IXAGG MONADWU NARNG */
 /* OASGP PDRING */
@@ -1948,11 +1948,11 @@ LAYER3=\
 /*"ZMOD" -> {"RMODULE"; "FINITE"; "KONVERT"; "STEP"; "SINT"; "INT"}*/
 /*"ZMOD" -> {"PI"; "NNI"; "INS-"; "EUCDOM-"}*/
 
-@
+\end{chunk}
 \subsection{Layer 4}
 Depends on: BGAGG BRAGG ELAGG- GRMOD MODULE OAMON \\
 Used by next layer: ALGEBRA ALGEBRA- BTCAT OCAMON QUAGG SKAGG
-<<layer4>>=
+\begin{chunk}{layer4}
 
 LAYER4=\
   ${OUT}/ALGEBRA.o ${OUT}/ALGEBRA-.o ${OUT}/BTCAT.o  ${OUT}/BTCAT-.o \
@@ -1961,8 +1961,8 @@ LAYER4=\
   ${OUT}/PRQAGG.o  ${OUT}/QUAGG.o    ${OUT}/SKAGG.o  \
   layer4done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 4 */
 /* dpends on: BGAGG BRAGG GRMOD MODULE OAMON */
 
@@ -2052,12 +2052,12 @@ LAYER4=\
 /*"SKAGG" -> {"HOAGG"; "AGG"; "TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"}*/
 /*"SKAGG" -> {"EVALAB"; "IEVALAB"}*/
 
-@
+\end{chunk}
 \subsection{Layer 5}
 Depends on: ALGEBRA ALGEBRA- BTCAT OCAMON QUAGG SKAGG\\
 Used by next layer: MLO OAGROUP OAMONS PID XALG
 
-<<layer5>>=
+\begin{chunk}{layer5}
 
 LAYER5=\
   ${OUT}/BSTREE.o  ${OUT}/BTOURN.o   ${OUT}/CARD.o     ${OUT}/DRAWHACK.o \
@@ -2067,8 +2067,8 @@ LAYER5=\
   ${OUT}/PID.o     ${OUT}/RANDSRC.o  ${OUT}/UNISEG2.o  ${OUT}/XALG.o     \
   layer5done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 5 */
 /* depends on: ALGEBRA ALGEBRA- BTCAT OCAMON QUAGG SKAGG */
 
@@ -2216,12 +2216,12 @@ LAYER5=\
 "XALG" -> "ALGEBRA"
 /*"XALG" -> "MODULE"*/
 
-@
+\end{chunk}
 \subsection{Layer6}
 Depends on: MLO OAGROUP OAMONS PID XALG\\
 Used by next layer: AMR FIELD FIELD- FLAGG FLAGG- FRETRCT PADICCT RADCAT 
 XFALG
-<<layer6>>=
+\begin{chunk}{layer6}
 
 LAYER6=\
   ${OUT}/AMR.o      ${OUT}/AMR-.o     ${OUT}/DEGRED.o  ${OUT}/DIVCAT.o   \
@@ -2236,8 +2236,8 @@ LAYER6=\
   ${OUT}/RADUTIL.o  ${OUT}/UPXS2.o    ${OUT}/XFALG.o   ${OUT}/ZLINDEP.o \
   layer6done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 6 */
 /* MLO OAGROUP OAMONS PID XALG */
 
@@ -2729,12 +2729,12 @@ LAYER6=\
 /*"ZLINDEP" -> {"OASGP"; "ORDSET"; "DIFRING"; "KONVERT"; "RETRACT"}*/
 /*"ZLINDEP" -> {"PATMAB"; "CFCAT"; "REAL"; "CHARZ"; "STEP"; "OM"}*/
 
-@
+\end{chunk}
 \subsection{Layer7}
 Depends on: AMR FIELD FIELD- FLAGG FLAGG- FRETRCT PADICCT RADCAT XFALG \\
 Used by next layer: A1AGG A1AGG- ARR2CAT FAMR FPC LIECAT LZSTAGG OREPCAT PSCAT 
 TRANFUN VSPACE XPOLYC
-<<layer7>>=
+\begin{chunk}{layer7}
 
 LAYER7=\
   ${OUT}/A1AGG.o    ${OUT}/A1AGG-.o   ${OUT}/ARR2CAT.o  ${OUT}/ARR2CAT-.o \
@@ -2767,8 +2767,8 @@ LAYER7=\
   ${OUT}/VSPACE-.o  ${OUT}/XPOLYC.o   ${OUT}/XPR.o \
   layer7done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 7 */
 /* depends on: AMR FIELD FIELD- FLAGG FLAGG- FRETRCT PADICCT RADCAT XFALG */
 
@@ -4164,12 +4164,12 @@ LAYER7=\
 /*"XPR" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "ENTIRER"; "UFD"}*/
 /*"XPR" -> "DIVRING"*/
 
-@
+\end{chunk}
 \subsection{Layer8}
 Depends on: A1AGG A1AGG- ARR2CAT FAMR FPC LIECAT LZSTAGG OREPCAT PSCAT 
 TRANFUN VSPACE XPOLYC PACPERC\\
 Used by next layer: BTAGG FLALG MATCAT SRAGG VECTCAT 
-<<layer8>>=
+\begin{chunk}{layer8}
 
 LAYER8=\
   ${OUT}/AFFSP.o    \
@@ -4193,8 +4193,8 @@ LAYER8=\
   ${OUT}/XPOLY.o    ${OUT}/XRPOLY.o \
   layer8done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 8 */
 /* depends on: A1AGG A1AGG- ARR2CAT FAMR FPC LIECAT LZSTAGG OREPCAT PSCAT */
 /* TRANFUN VSPACE XPOLYC PACPREC */
@@ -4958,11 +4958,11 @@ LAYER8=\
 /*"XRPOLY" -> {"EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG"; "ELTAB"}*/
 /*"XRPOLY" -> {"CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM"}*/
 
-@
+\end{chunk}
 \subsection{Layer9}
 Depends on: BTAGG FLALG LODOCAT MATCAT SRAGG VECTCAT XF PROJSP PACFFC\\
 Used by next layer: IVECTOR PTCAT STRICAT 
-<<layer9>>=
+\begin{chunk}{layer9}
 
 LAYER9=\
   ${OUT}/AFFPL.o    ${OUT}/BITS.o     ${OUT}/DFMAT.o    ${OUT}/DFVEC.o   \
@@ -4974,8 +4974,8 @@ LAYER9=\
   ${OUT}/U8MAT.o    ${OUT}/U16MAT.o   ${OUT}/U32MAT.o \
   layer9done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 9 */
 /* Depends on: BTAGG FLALG INTCAT LODOCAT MATCAT SRAGG UPSCAT VECTCAT */
 /* AFFSP */
@@ -5262,11 +5262,11 @@ LAYER9=\
 /*"U32MAT" -> {"CHARZ"; "STEP"; "A1AGG"; "FLAGG"; "LNAGG"; "IXAGG"}*/
 /*"U32MAT" -> {"ELTAGG"; "ELTAB"; "CLAGG"; "INT"; "OM"; "FIELD"; "DIVRING"}*/
 
-@
+\end{chunk}
 \subsection{Layer10}
 Depends on: IVECTOR PTCAT STRICAT LOCPOWC\\
 Used by next layer: DIRPCAT FAXF PFECAT STRING
-<<layer10>>=
+\begin{chunk}{layer10}
 
 LAYER10=\
   ${OUT}/ASSOCEQ.o  ${OUT}/CARTEN.o   ${OUT}/CLIF.o     ${OUT}/CLIP.o    \
@@ -5282,8 +5282,8 @@ LAYER10=\
   ${OUT}/SEX.o      ${OUT}/STRING.o   ${OUT}/SYMFUNC.o  ${OUT}/VECTOR2.o \
   layer10done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 10 */
 /* depends on: IVECTOR PTCAT STRICAT */
 
@@ -5920,11 +5920,11 @@ LAYER10=\
 /*"VECTOR2" -> {"IXAGG-"; "LIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"}*/
 /*"VECTOR2" -> {"ELAGG"; "OM"; "ILIST"}*/
 
-@
+\end{chunk}
 \subsection{Layer11}
 Depends on: DIRPCAT FAXF PFECAT STRING LOP\\
 Used by next layer: DIOPS DPOLCAT FINRALG FRAC RMATCAT RRCC UPXSCAT
-<<layer11>>=
+\begin{chunk}{layer11}
 
 LAYER11=\
   ${OUT}/ASP1.o     ${OUT}/ASP10.o    ${OUT}/ASP24.o    ${OUT}/ASP4.o     \
@@ -5997,8 +5997,8 @@ LAYER11=\
   ${OUT}/VOID.o     ${OUT}/WEIER.o    ${OUT}/WP.o \
   layer11done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 11 */
 /* depends on: DIRPCAT FAXF PFECAT STRING */
 
@@ -9632,12 +9632,12 @@ LAYER11=\
 /*"WP" -> {"CLAGG-"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-"}*/
 /*"WP" -> {"BASTYPE-"; "NNI"; "BOOLEAN"; "FIELD"; "EUCDOM"; "PID"; "DIVRING"}*/
 
-@
+\end{chunk}
 \subsection{Layer12}
 Depends on: DIOPS DPOLCAT FINRALG FRAC RMATCAT RRCC UPXSCAT FFSQFR PACRATC
 PLPKCRV\\
 Used by next layer: DIAGG FRAMALG MDAGG SMATCAT UPXSCCA
-<<layer12>>=
+\begin{chunk}{layer12}
 
 LAYER12=\
   ${OUT}/DIAGG.o   ${OUT}/DIAGG-.o   ${OUT}/DSMP.o     ${OUT}/EXPUPXS.o \
@@ -9650,8 +9650,8 @@ LAYER12=\
   ${OUT}/UPXSCCA-.o \
   layer12done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 12 */
 /* depends on: DIOPS DPOLCAT FFSQFR FINRALG FRAC RMATCAT RRCC UPXSCAT */
 /*             PLPKCRV */
@@ -10025,11 +10025,11 @@ LAYER12=\
 /*"UPXSCCA-" -> {"HYPCAT";  "AHYP";  "ELEMFUN";  "FIELD";  "EUCDOM";  "PID"}*/
 /*"UPXSCCA-" -> {"GCDDOM";  "UFD";  "DIVRING";  "RETRACT";  "ULSCAT"}*/
 
-@
+\end{chunk}
 \subsection{Layer13}
 Depends on: DIAGG FRAMALG MDAGG SMATCAT UPXSCCA RFP\\
 Used by next layer: FSAGG KDAGG MSETAGG MONOGEN
-<<layer13>>=
+\begin{chunk}{layer13}
 
 LAYER13=\
   ${OUT}/AFALGGRO.o ${OUT}/AFALGRES.o \
@@ -10039,8 +10039,8 @@ LAYER13=\
   ${OUT}/MSETAGG.o  ${OUT}/MONOGEN.o ${OUT}/MONOGEN-.o ${OUT}/NFINTBAS.o \
   layer13done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 13 */
 /* depends on: DIAGG FRAMALG MDAGG SMATCAT UPXSCCA RFP*/
 
@@ -10302,11 +10302,11 @@ LAYER13=\
 /*"NFINTBAS" -> {"LNAGG"; "IXAGG"; "HOAGG"; "AGG"; "TYPE"; "ELTAGG"}*/
 /*"NFINTBAS" -> {"CLAGG"; "LIST"; "ILIST"; "PI"; "NNI"; "INS-"; "EUCDOM-"}*/
 
-@
+\end{chunk}
 \subsection{Layer14}
 Depends on: FSAGG KDAGG MSETAGG MONOGEN\\
 Used by next layer: TBAGG
-<<layer14>>=
+\begin{chunk}{layer14}
 
 LAYER14=\
   ${OUT}/BSD.o \
@@ -10319,8 +10319,8 @@ LAYER14=\
   ${OUT}/TBAGG.o    ${OUT}/TBAGG-.o   ${OUT}/VIEW3D.o  ${OUT}/WFFINTBS.o \
   layer14done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 14 */
 /* depends on: FSAGG KDAGG MSETAGG MONOGEN */
 
@@ -10751,11 +10751,11 @@ LAYER14=\
 /*"WFFINTBS" -> {"ELTAGG"; "CLAGG"}*/
 "WFFINTBS" -> "MONOGEN"
 
-@
+\end{chunk}
 \subsection{Layer15}
 Depends on: TBAGG\\
 Used by next layer: ALIST
-<<layer15>>=
+\begin{chunk}{layer15}
 
 LAYER15=\
   ${OUT}/ALIST.o   ${OUT}/EQTBL.o   ${OUT}/GSTBL.o   ${OUT}/HASHTBL.o \
@@ -10764,8 +10764,8 @@ LAYER15=\
   ${OUT}/STRTBL.o  ${OUT}/TABLE.o   ${OUT}/TBCMPPK.o  \
   layer15done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 15 */
 /* depends on: TBAGG */
 
@@ -10971,11 +10971,11 @@ LAYER15=\
 /*"TBCMPPK" -> {"EVALAB"; "IEVALAB"; "CLAGG"; "KONVERT"; "IXAGG"; "ELTAGG"}*/
 /*"TBCMPPK" -> "ELTAB"*/
 
-@
+\end{chunk}
 \subsection{Layer16}
 Depends on: ALIST\\
 Used by next layer: ACF COMPCAT FFCAT FRNAALG FS OC QUATCAT RPOLCAT UTSCAT 
-<<layer16>>=
+\begin{chunk}{layer16}
 
 LAYER16=\
   ${OUT}/ACF.o      ${OUT}/ACF-.o     ${OUT}/ACPLOT.o   ${OUT}/ANTISYM.o  \
@@ -11014,8 +11014,8 @@ LAYER16=\
   ${OUT}/SYSSOLP.o  ${OUT}/UTSCAT.o   ${OUT}/UTSCAT-.o  ${OUT}/VARIABLE.o \
   layer16done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 16 */
 /* depends on: ALIST */
 
@@ -12982,7 +12982,7 @@ LAYER16=\
 /*"VARIABLE" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
 /*"VARIABLE" -> "BOOLEAN"*/
 
-@
+\end{chunk}
 \subsection{Layer17}
 Depends on: ACF COMPCAT FFCAT FRNAALG FS OC QUATCAT RPOLCAT UTSCAT NSDPS \\
 Used by next layer: ACFS EXPRSOL FDIVCAT UFPS ULSCCAT UTSSOL 
@@ -12991,7 +12991,7 @@ The clique1.spad file is used because "MYEXPR" and "MYUP" are
 mutually dependent. Rather than add one to the bootstrap we let the
 compiler resolve them in one step. This same technique might be useful
 for other cliques in bootstrap. This needs to be investigated.
-<<layer17>>=
+\begin{chunk}{layer17}
 
 LAYER17=\
   ${OUT}/ACFS.o     ${OUT}/ACFS-.o    ${OUT}/AF.o       ${OUT}/AFFPLPS.o  \
@@ -13040,8 +13040,8 @@ LAYER17=\
   ${OUT}/UTSSOL.o   ${OUT}/UTS2.o     ${OUT}/WUTSET.o  \
   layer17done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 17 */
 /* depends on: ACF COMPCAT FFCAT FRNAALG FS OC QUATCAT RPOLCAT UTSCAT */
 
@@ -15761,11 +15761,11 @@ LAYER17=\
 /*"WUTSET" -> {"CLAGG-"; "BOOLEAN"; "HOAGG-"; "ORDSET-"; "AGG-"; "ELTAGG-"}*/
 /*"WUTSET" -> {"SETCAT-"; "BASTYPE-"; "FINITE"}*/
 
-@
+\end{chunk}
 \subsection{Layer18}
 Depends on: ACFS EXPRSOL FDIVCAT RSETCAT UFPS ULSCCAT UTSSOL 
 Used in next layer: EXPRSOL SFRTCAT
-<<layer18>>=
+\begin{chunk}{layer18}
 
 LAYER18=\
   ${OUT}/DEFINTEF.o ${OUT}/DEFINTRF.o ${OUT}/DFINTTLS.o ${OUT}/EFULS.o    \
@@ -15784,8 +15784,8 @@ LAYER18=\
   ${OUT}/UTSZ.o \
   layer18done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 18 */
 /* depends on: ACFS FDIVCAT RSETCAT UFPS ULSCCAT UTSSOL */
 
@@ -16591,11 +16591,11 @@ LAYER18=\
 "UTSZ" -> "ACFS"
 /*"UTSZ" -> {"ACF"; "FS"; "ES"; "FRETRCT"; "GROUP"; "ILIST"; "OAMONS"}*/
 
-@
+\end{chunk}
 \subsection{Layer19}
 Depends on: EXPRSOL SFRTCAT FACTEXT INTDIVP DTP\\
 Next layer depends on: RECOP
-<<layer19>>=
+\begin{chunk}{layer19}
 
 LAYER19=\
   ${OUT}/GPAFF.o    \
@@ -16605,8 +16605,8 @@ LAYER19=\
   ${OUT}/SNTSCAT.o  ${OUT}/SRDCMPK.o  ${OUT}/SREGSET.o  ${OUT}/ZDSOLVE.o \
   layer19done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 19 */
 /* EXPRSOL SFRTCAT */
 
@@ -16845,18 +16845,18 @@ LAYER19=\
 /*"ZDSOLVE" -> {"URAGG"; "RCAGG"; "LNAGG"; "IXAGG"; "ELTAGG"; "FLAGG"}*/
 /*"ZDSOLVE" -> {"ELAGG"; "OM"; "LNAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"*/
 
-@
+\end{chunk}
 \subsection{Layer20}
 Depends on: RECOP
 Next layer depends on: GUESS
-<<layer20>>=
+\begin{chunk}{layer20}
 
 LAYER20=\
   ${OUT}/GUESS.o ${OUT}/INFCLSPT.o \
   layer20done
     
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 20 */
 
 "GUESS" [color="#FF4488",href="bookvol10.4.pdf#nameddest=GUESS"]
@@ -16910,19 +16910,19 @@ LAYER20=\
 /*"INFCLSPT" -> {"SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"; "OUTFORM"}*/
 /*"INFCLSPT" -> {"PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
 
-@
+\end{chunk}
 \subsection{Layer21}
 Depends on: GUESS
 Next layer depends on: GUESSF1 INFCLSPT 
-<<layer21>>=
+\begin{chunk}{layer21}
 
 LAYER21=\
   ${OUT}/GUESSAN.o  ${OUT}/GUESSINT.o ${OUT}/GUESSF1.o  ${OUT}/GUESSP.o \
   ${OUT}/GUESSUP.o  ${OUT}/ICP.o      \
   layer21done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 21 */
 /* GUESS */
 
@@ -17022,17 +17022,16 @@ LAYER21=\
 /*"ICP" -> {"ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"}*/
 /*"ICP" -> {"ELAGG-"; "URAGG-"}*/
 
-@
+\end{chunk}
 \subsection{Layer22}
 Depends on: GUESSF1
-<<layer22>>=
+\begin{chunk}{layer22}
 
 LAYER22=\
   ${OUT}/GUESSF.o ${OUT}/INFCLSPS.o  \
   layer22done
-
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 22 */
 /* GUESSF */
 
@@ -17072,19 +17071,19 @@ LAYER22=\
 /*"INFCLSPS" -> {"OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"; "SRAGG-"}*/
 /*"INFCLSPS" -> {"FLAGG-"; "LNAGG-"; "LSAGG-"; "STAGG-"; "ELAGG-"; "URAGG-"}*/
 
-@
+\end{chunk}
 \subsection{Layer23}
 Depends on: INFCLSPS
 
 Note that PAFF and PAFFFF form clique2.spad. Each one depends on the other.
-<<layer23>>=
+\begin{chunk}{layer23}
 
 LAYER23=\
   ${MID}/clique2.spad \
   layer23done
 
-@
-<<layerpic>>=
+\end{chunk}
+\begin{chunk}{layerpic}
 /* layer 23 */
 
 "PAFF" -> "PAFFFF"
@@ -17127,18 +17126,18 @@ LAYER23=\
 /*"PAFF" -> {"OASGP"; "OAMONS"; "VSPACE"; "INS"; "OINTDOM"; "CFCAT"; "REAL"}*/
 /*"PAFF" -> {"STEP"; "PI"; "NNI"; "BOOLEAN"}*/
 
-@
+\end{chunk}
 \subsection{Order}
 The final order of the layers is determined here. The GUESS package
 is broken so we remove the layers involved until this can be resolved.
-<<order>>=
+\begin{chunk}{order}
 ORDER=\
   ${LAYER0BOOTSTRAP}     ${LAYER0}  ${LAYER1}  ${LAYER2}  ${LAYER3}  \
   ${LAYER4}   ${LAYER5}  ${LAYER6}  ${LAYER7}  ${LAYER8}  ${LAYER9}  \
   ${LAYER10}  ${LAYER11} ${LAYER12} ${LAYER13} ${LAYER14} ${LAYER15} \
   ${LAYER16}  ${LAYER17} ${LAYER18} ${LAYER19} ${LAYER20} ${LAYER21} \
   ${LAYER22}  ${LAYER23} ${LAYER0COPY}
-@
+\end{chunk}
 
 \begin{verbatim}
 ORDER=\
@@ -17156,7 +17155,7 @@ are in the same source file.
 So the idea to remove the BOOTSTRAP code is to cluster the spad
 sources into "cliqueN.spad" files and feed them all to the compiler
 at once.
-<<newcode>>=
+\begin{chunk}{newcode}
 CLIQUE1FILES = ${OUT}/MYUP.o  ${OUT}/MYEXPR.o
 
 ${MID}/clique1.spad: ${CLIQUE1FILES}
@@ -17173,12 +17172,12 @@ ${MID}/clique1.spad: ${CLIQUE1FILES}
 	@ cp ${MID}/MYUP.nrlib/code.o ${OUT}/MYUP.o
 	@ cp ${MID}/MYEXPR.nrlib/code.o ${OUT}/MYEXPR.o
 	
-@
+\end{chunk}
 Here we have the general case where two files are co-dependent, that is,
 PAFF and PAFFFF both have to be compiled together. They also have a set
 of prerequired files that must be loaded since they are not yet in the
 new database.
-<<newcode>>=
+\begin{chunk}{newcode}
 CLIQUE2FILES = ${OUT}/PAFF.o ${OUT}/PAFFFF.o
 CLIQUE2DEPS  = BLMETCT GPAFF PFORP PACOFF PROJPLPS PLACESPS NSDPS LOCPOWC \
                DIV SETCATD PLACESC DIVCAT INFCLSPS INFCLCT DSTREE DSTRCAT \
@@ -17201,8 +17200,8 @@ ${MID}/clique2.spad: ${CLIQUE2FILES}
 	@ cp ${MID}/PAFF.nrlib/code.o ${OUT}/PAFF.o
 	@ cp ${MID}/PAFFFF.nrlib/code.o ${OUT}/PAFFFF.o
 	
-@
-<<ignore>>=
+\end{chunk}
+\begin{chunk}{ignore}
 EXPRDEPS  = LF
 
 ${MID}/EXPR.nrlib/code.o: ${MID}/EXPR.spad
@@ -17211,7 +17210,7 @@ ${MID}/EXPR.nrlib/code.o: ${MID}/EXPR.spad
             echo -e ")lib ${EXPRDEPS} \n )co EXPR.spad" | ${INTERPSYS} )
 	@ cp ${MID}/EXPR.nrlib/code.o ${OUT}/EXPR.o
 	
-@
+\end{chunk}
 \section{Broken Files}
 These files are Aldor files
 \begin{verbatim}
@@ -17251,7 +17250,7 @@ The \verb|OUTSRC=${MNT}/${SYS}/src/algebra| subdirectory contains the
 algebra source files extracted from the pamphlet files. These sources 
 allow the end user to change the algebra if needed.
 
-<<environment>>=
+\begin{chunk}{environment}
 
 IN=${SRC}/algebra
 MID=${INT}/algebra
@@ -17263,35 +17262,35 @@ LISP=${OBJ}/${SYS}/bin/lisp
 LISPTANGLE=${OBJ}/${SYS}/bin/lisp
 BOOKSRC=${SPD}/books/bookvol5.pamphlet
 
-@
+\end{chunk}
 \subsection{The depsys variable}
 The {\bf depsys} image is the compile-time environment for boot and lisp
 files.
 
-<<environment>>=
+\begin{chunk}{environment}
 
 DEPSYS=${OBJ}/${SYS}/bin/depsys
 
-@
+\end{chunk}
 \subsection{The interpsys variable}
 The {\bf interpsys} image is the compile-time environment for algebra
 files.
 
-<<environment>>=
+\begin{chunk}{environment}
 
 INTERPSYS=${OBJ}/${SYS}/bin/interpsys
 
-@
+\end{chunk}
 \subsection{The shell variable}
 We use the ``-e'' flag to echo which is not supported by the ``sh''
 shell but is supported by ``bash''. The ``-e'' flag to echo causes
 it to interpret special characters, in our case newlines.
 
-<<environment>>=
+\begin{chunk}{environment}
 
 SHELL=bash
 
-@
+\end{chunk}
 \section{The Makefile Stanzas}
 A spad pamphlet can contain many Axiom categories, domains, and
 packages. 
@@ -17413,14 +17412,14 @@ The output of the compile step is saved in a file of the same name
 and extension .out in the \${MID} directory. These files are useful for
 deriving the dependencies by scanning the ``Loading ...'' messages.
 
-<<genericDotOfiles>>=
+\begin{chunk}{genericDotOfiles}
 
 ${OUT}/%.o: ${MID}/%.nrlib/code.o
 	@ echo sa06 copying $*.nrlib to $*.o
 	@ cp ${MID}/$*.nrlib/code.o ${OUT}/$*.o
 
-@ 
-<<genericnrlibfiles>>=
+\end{chunk}
+\begin{chunk}{genericnrlibfiles}
 
 .PRECIOUS: ${MID}/%.nrlib/code.o
 ${MID}/%.nrlib/code.o: ${MID}/%.spad
@@ -17433,8 +17432,8 @@ ${MID}/%.nrlib/code.o: ${MID}/%.spad
 	     echo ")co $*.spad" | ${INTERPSYS} ) 1>/dev/null 2>/dev/null ; \
 	   fi 
 
-@
-<<genericBOOTSTRAPfiles>>=
+\end{chunk}
+\begin{chunk}{genericBOOTSTRAPfiles}
 
 ${MID}/%.o: ${MID}/%.lsp
 	@ echo sa08 compiling $*.lsp to $*.o
@@ -17448,16 +17447,16 @@ ${MID}/%.o: ${MID}/%.lsp
 	  fi )
 	@ cp ${MID}/$*.o ${OUT}/$*.o
 
-@
-<<genericSPADfiles>>=
+\end{chunk}
+\begin{chunk}{genericSPADfiles}
 
 ${OUTSRC}/%.spad: ${IN}/%.pamphlet
 	@ echo sa09tangling $*.pamphlet to $*.spad
 	@(cd ${OUTSRC} ; \
 	 ${TANGLE} ${IN}/$*.pamphlet >$*.spad )
 
-@
-<<genericDOCfiles>>=
+\end{chunk}
+\begin{chunk}{genericDOCfiles}
 
 ${DOC}/%.dvi: ${IN}/%.pamphlet ${DOC}/ps
 	@ echo sa10 latexing $*.pamphlet to ${DOC}/$*.dvi
@@ -17468,30 +17467,29 @@ ${DOC}/%.dvi: ${IN}/%.pamphlet ${DOC}/ps
 	rm -f ${DOC}/$*.tex ; \
 	rm -f ${DOC}/$* )
 
-@
-<<genericRules>>=
+\end{chunk}
+\begin{chunk}{genericRules}
 
-<<genericDotOfiles>>
-<<genericnrlibfiles>>
-<<genericBOOTSTRAPfiles>>
-<<genericSPADfiles>>
-<<genericDOCfiles>>
+\getchunk{genericDotOfiles}
+\getchunk{genericnrlibfiles}
+\getchunk{genericBOOTSTRAPfiles}
+\getchunk{genericSPADfiles}
+\getchunk{genericDOCfiles}
 
-@
+\end{chunk}
 
-<<libdb.text (OUT from IN)>>=
+\begin{chunk}{libdb.text (OUT from IN)}
 ${OUT}/libdb.text: ${IN}/libdb.text
 	@ echo sa11 copying ${IN}/libdb.text to ${OUT}/libdb.text
 	@ cp ${IN}/libdb.text ${OUT}/libdb.text
 
-@
-<<ps (DOC from SRC)>>=
+\end{chunk}
+\begin{chunk}{ps (DOC from SRC)}
 ${DOC}/ps: ${SRC}/doc/ps
 	@echo sa12 making ${DOC}/ps from ${SRC}/doc/ps
 	@cp -pr ${SRC}/doc/ps ${DOC}
 
-@
-
+\end{chunk}
 
 \section{Pamphlet file structure}
 Because the individual .spad files are grouped into higher-level
@@ -17499,11 +17497,11 @@ algebra pamphlet files, the rules for extracting them are coded
 below as simple ``awk'' scripts that are called when the Makefile
 is constructed.
 
-<<findAlgebraFiles>>=
+\begin{chunk}{findAlgebraFiles}
 
-<<findSpadFiles>>
-<<findBootstrapFiles>>
-@
+\getchunk{findSpadFiles}
+\getchunk{findBootstrapFiles}
+\end{chunk}
 
 There are, at present, 2 kinds of algebra files to be handled.
 
@@ -17546,7 +17544,7 @@ Step 2 is an awk command line.
 
 \subsection{Write the Makefile stanzas for the algebra files}
 
-<<findSpadFiles>>=
+\begin{chunk}{findSpadFiles}
 
 grep -E 'begin{chunk}{category\ .*}' ${BOOKS}/bookvol10.2.pamphlet | sort | uniq | awk -F: '{
   chunk=substr($1,15,length($1)-15);
@@ -17584,7 +17582,7 @@ grep -E 'begin{chunk}{package\ .*}' ${BOOKS}/bookvol10.5.pamphlet | sort | uniq
   print "";
 }'
 
-@
+\end{chunk}
 awk processes each line of the grep output. 
 
 The awk script uses ``-F:'' which is a flag that says that a ``:'' is
@@ -17636,7 +17634,7 @@ into ``awk''.
 \subsection{Write the Makefile stanzas for the bootstrap files}
 For each of the above output lines we run an ``grep'' command:
 
-<<findBootstrapFiles>>=
+\begin{chunk}{findBootstrapFiles}
 
 grep 'begin{chunk}{.*BOOTSTRAP}' ${BOOKS}/bookvol10.2.pamphlet | sort | uniq | \
 awk -F: '{
@@ -17658,7 +17656,7 @@ awk -F: '{
   print "";
 }'
 
-@
+\end{chunk}
 
 The process is the same way as described above except that
 there are only two parts to the chunk names
@@ -17685,7 +17683,7 @@ from the source file.
 
 \section{Stage markers}
 We output these as each stage completes.
-<<stages>>=
+\begin{chunk}{stages}
 
 layer0bootstrap:
 	@ echo =====================================
@@ -17822,7 +17820,7 @@ layer24done:
 	@ echo === layer 24 of 24 complete ======
 	@ echo ==================================
 
-@
+\end{chunk}
 \subsection{Regression testing}
 
 There is a Makefile variable called REGRESS in the algebra Makefile:
@@ -17866,7 +17864,7 @@ The algebra files contain input chunks in regress format.
 This stanza is extracted by the src/input/Makefile after
 all of the other regression tests are complete. This stanza
 is put into a int/Makefile.algebra and then executed by make.
-<<algebra.regress>>=
+\begin{chunk}{algebra.regress}
 TESTSYS=  ${OBJ}/${SYS}/bin/interpsys
 
 REGRESS= \
@@ -19051,40 +19049,40 @@ announce:
 	@ echo src/algebra RUNNING REGRESSION TESTING
 	@ echo ======================================
 
-@
+\end{chunk}
 \section{The Makefile}
 
-<<*>>=
-
-<<environment>>
-
-<<layer0 bootstrap>>
-<<layer0 copy>>
-<<layer0>> 
-<<layer1>>
-<<layer2>>
-<<layer3>>
-<<layer4>>
-<<layer5>>
-<<layer6>>
-<<layer7>>
-<<layer8>>
-<<layer9>>
-<<layer10>>
-<<layer11>>
-<<layer12>>
-<<layer13>>
-<<layer14>>
-<<layer15>>
-<<layer16>>
-<<layer17>>
-<<layer18>>
-<<layer19>>
-<<layer20>>
-<<layer21>>
-<<layer22>>
-<<layer23>>
-<<order>>
+\begin{chunk}{*}
+
+\getchunk{environment}
+
+\getchunk{layer0 bootstrap}
+\getchunk{layer0 copy}
+\getchunk{layer0}
+\getchunk{layer1}
+\getchunk{layer2}
+\getchunk{layer3}
+\getchunk{layer4}
+\getchunk{layer5}
+\getchunk{layer6}
+\getchunk{layer7}
+\getchunk{layer8}
+\getchunk{layer9}
+\getchunk{layer10}
+\getchunk{layer11}
+\getchunk{layer12}
+\getchunk{layer13}
+\getchunk{layer14}
+\getchunk{layer15}
+\getchunk{layer16}
+\getchunk{layer17}
+\getchunk{layer18}
+\getchunk{layer19}
+\getchunk{layer20}
+\getchunk{layer21}
+\getchunk{layer22}
+\getchunk{layer23}
+\getchunk{order}
 
 all: fasthelp fastinput fastxhtml src ${OUT}/libdb.text \
      ${SPADBIN}/index.html gloss
@@ -19112,7 +19110,7 @@ fastxhtml:
 	@ mkdir -p ${MNT}/doc
 	@ echo "(makeXHTMLFiles)" | ${LISP}
 
-<<newcode>>
+\getchunk{newcode}
 
 ${SPADBIN}/index.html:
 	@ echo sa20 making ${SPADBIN}/index.html
@@ -19145,15 +19143,15 @@ announce:
 	@ echo src/algebra BUILDING ALGEBRA FILES
 	@ echo ======================================
 
-<<genericRules>>
-<<ps (DOC from SRC)>>
-<<libdb.text (OUT from IN)>>
-<<stages>>
+\getchunk{genericRules}
+\getchunk{ps (DOC from SRC)}
+\getchunk{libdb.text (OUT from IN)}
+\getchunk{stages}
 
 clean:
 	@echo sa24 src/algebra cleaned
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index ef90e06..1197158 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4494,10 +4494,12 @@ src/axiom-website/download.html add texlive-fonts-extra
 src/scripts/boxhead, boxtail, boxup, showdvi removed
 <a href="patches/20140623.05.tpd.patch">20140623.05.tpd.patch</a>
 Makefile, books/tangle.c set up a native tangle function
-<a href="patches/20140624.01.tpd.patch">20140624.01.tpd.patch</a>
+<a href="patches/20140625.01.tpd.patch">20140625.01.tpd.patch</a>
 Makefile books/Makefile.pamphlet books/tangle.c books/extract
-<a href="patches/20140624.02.tpd.patch">20140624.02.tpd.patch</a>
+<a href="patches/20140625.02.tpd.patch">20140625.02.tpd.patch</a>
 Makefile.pamphlet src/Makefile.pamphlet use chunk syntax
+<a href="patches/20140628.01.tpd.patch">20140628.01.tpd.patch</a>
+zips/noweb-2.10a.tgz deleted, noweb removed
  </body>
 </html>
 
diff --git a/src/clef/Makefile.pamphlet b/src/clef/Makefile.pamphlet
index 27968b2..fce74a7 100644
--- a/src/clef/Makefile.pamphlet
+++ b/src/clef/Makefile.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{Environment variables}
-<<environment>>=
+\begin{chunk}{environment}
 # this is where we are compiling from
 IN=     ${SRC}/clef
 
@@ -39,16 +39,16 @@ CLEFOBJS= ${MID}/edible.o ${LIB}/fnct-key.o ${LIB}/edin.o ${LIB}/bsdsignal.o \
 
 DOCFILES=${DOC}/edible.c.dvi
 
-@
+\end{chunk}
 \section{The clef sources, edible}
-<<edible>>=
+\begin{chunk}{edible}
 ${OUT}/clef:	${CLEFOBJS}
 	@ echo sc1 linking clef
 	@ ${CC} ${CLEFOBJS} -o ${OUT}/clef
 
 ${MID}/edible.c: ${IN}/edible.c.pamphlet
 	@ echo sc2 making ${MID}/edible.c from ${IN}/edible.c.pamphlet
-	@ (cd ${MID} ; ${TANGLE} ${IN}/edible.c.pamphlet >edible.c )
+	@ (cd ${MID} ; ${BOOKS}/tangle ${IN}/edible.c.pamphlet >edible.c )
 
 ${MID}/edible.o: ${MID}/edible.c ${INC}/edible.h
 	@ echo sc3 making ${MID}/edible.o from ${MID}/edible.c
@@ -58,14 +58,14 @@ ${DOC}/edible.c.dvi: ${IN}/edible.c.pamphlet
 	@ echo sc4 making ${DOC}/edible.c.dvi from ${IN}/edible.c.pamphlet
 	@ (cd ${DOC} ; \
 	cp ${IN}/edible.c.pamphlet ${DOC} ; \
-	${DOCUMENT} ${NOISE} edible.c ; \
+	${EXTRACT} edible.c.pamphlet >edible.c ; \
 	rm -f ${DOC}/edible.c.pamphlet ; \
 	rm -f ${DOC}/edible.c.tex ; \
 	rm -f ${DOC}/edible.c )
 
-@
-<<*>>=
-<<environment>>
+\end{chunk}
+\begin{chunk}{*}
+\getchunk{environment}
 all:	announce ${OUT}/clef ${DOCFILES}
 	@ echo sc6 finished ${IN}
 
@@ -77,8 +77,8 @@ announce:
 clean:
 	@echo sc7 cleaning ${SRC}/clef
 
-<<edible>>
-@
+\getchunk{edible}
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/clef/edible.c.pamphlet b/src/clef/edible.c.pamphlet
index 82eaaef..1242a23 100644
--- a/src/clef/edible.c.pamphlet
+++ b/src/clef/edible.c.pamphlet
@@ -9,7 +9,7 @@
 \eject
 \tableofcontents
 \eject
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -42,7 +42,7 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
+\end{verbatim}
 \section{edible Call Graph}
 This was generated by the GNU cflow program with the argument list.
 Note that the line:NNNN numbers refer to the line in the code after
@@ -174,8 +174,7 @@ cflow --emacs -l -n -b -T --omit-arguments edible.c
   121 {   1}   +-print_whole_buff()
   122 {   1}   \-do_reading()
 \end{verbatim}
-<<*>>=
-<<license>>
+\begin{chunk}{*}
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -260,10 +259,6 @@ int logfd;
 char logpath[30];
 #endif
 
-
-
-
-
 int
 main(int argc, char *argv[])
 {
@@ -729,7 +724,7 @@ set_function_chars(void)
   _EOL = childbuf.c_cc[VEOL];
   return;
 }
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/doc/Makefile.pamphlet b/src/doc/Makefile.pamphlet
index 63eb2ed..66d1aca 100644
--- a/src/doc/Makefile.pamphlet
+++ b/src/doc/Makefile.pamphlet
@@ -12,7 +12,7 @@
 
 \section{The Reference Card}
 This is the one-page, 2 sided reference card
-<<refcard>>=
+\begin{chunk}{refcard}
 ${DVI}/refcard.pdf: ${IN}/refcard.pamphlet
 	@echo sd02 making ${DVI}/refcard.dvi from ${IN}/refcard.pamphlet
 	@(cd ${MID} ; \
@@ -23,11 +23,11 @@ ${DVI}/refcard.pdf: ${IN}/refcard.pamphlet
 	rm refcard.log ; \
 	rm refcard.aux )
 
-@
+\end{chunk}
 \section{The End Papers}
 This document reproduces the diagrams on the inside covers of the
 original Jenks Axiom book but adds hyperlinks.
-<<Endpapers>>=
+\begin{chunk}{Endpapers}
 ${DVI}/endpaper.pdf: ${IN}/endpaper.pamphlet
 	@echo sd03 making ${DVI}/endpaper.pdf from ${IN}/endpaper.pamphlet
 	@(cd ${MID} ; \
@@ -42,13 +42,13 @@ ${DVI}/endpaper.pdf: ${IN}/endpaper.pamphlet
 	mkdir -p ${DVI}/ps ; \
 	cp ${IN}/ps/*ps* ${DVI}/ps )
 
-@
+\end{chunk}
 \section{rosetta}
 The rosetta document is an effort to give a command-by-command
 way of moving between various computer algebra systems. It was
 originally created for the "rosetta" series of CDs. These rosetta
 CDs contained multiple, free computer algebra systems.
-<<rosetta>>=
+\begin{chunk}{rosetta}
 ${DVI}/rosetta.pdf: ${IN}/rosetta.pamphlet
 	@echo sd04 building ${DVI}/rosetta.dvi from ${IN}/rosetta.pamphlet
 	@(cd ${MID} ; \
@@ -57,9 +57,9 @@ ${DVI}/rosetta.pdf: ${IN}/rosetta.pamphlet
 	dvipdf rosetta.dvi ; \
 	cp rosetta.pdf ${DVI} )
 
-@
+\end{chunk}
 \section{The booklet command}
-<<booklet>>=
+\begin{chunk}{booklet}
 ${OUT}/booklet: ${MID}/booklet.o
 	@echo sd05 making ${OUT}/booklet from ${MID}/booklet.o
 	@(cd ${OUT} ; \
@@ -73,12 +73,12 @@ ${MID}/booklet.o: ${INT}/booklet.c
 ${INT}/booklet.c: ${IN}/booklet.c.pamphlet
 	@echo sd07 making ${INT}/booklet.c from ${IN}/booklet.c.pamphlet
 	@(cd ${INT} ; \
-	  ${TANGLE} ${IN}/booklet.c.pamphlet >booklet.c )
+	  ${BOOKS}/tangle ${IN}/booklet.c.pamphlet >booklet.c )
 	  
-@
+\end{chunk}
 \section{The Makefile}
 We need to document the commands.
-<<*>>=
+\begin{chunk}{*}
 IN=${SRC}/doc
 MID=${INT}/doc
 OUT=${MNT}/${SYS}/bin
@@ -98,17 +98,17 @@ announce:
 	@ echo src/doc BUILDING DOC FILES
 	@ echo ======================================
 
-<<booklet>>
-<<refcard>>
-<<Endpapers>>
-<<rosetta>>
+\getchunk{booklet}
+\getchunk{refcard}
+\getchunk{Endpapers}
+\getchunk{rosetta}
 
 document:
 	@echo sd09 documenting ${SRC}/doc
 
 clean:
 	@echo sd10 cleaning ${SRC}/doc
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/doc/booklet.c.pamphlet b/src/doc/booklet.c.pamphlet
index d616889..1233b38 100644
--- a/src/doc/booklet.c.pamphlet
+++ b/src/doc/booklet.c.pamphlet
@@ -20,46 +20,41 @@ this program recognizes only one protocol specifier, the ``file:''
 protocol. This is used to specify a file which will be included into
 the file (similar to C style \#include statements). The syntax is:
 
-[[<<file:PATH-AND-FILENAME>>]]
+file:PATH-AND-FILENAME
 
 where PATH-AND-FILENAME can be any valid file system name.
 
 See appendix \ref{part:requirements} for description of what the original
 requirements were specified.
 
-<<version>>=
-"v0.1"
-
-@ 
-
 Needed includes and global variable. Nothing special.
 
-The command line allows you to specify a [[-v]] flag. If this flag
-is present then [[verbose]] is set to 1 and we print on stdout what
+The command line allows you to specify a -v flag. If this flag
+is present then verbose is set to 1 and we print on stdout what
 we are doing.
-<<*>>=
+\begin{chunk}{*}
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
 int verbose = 0;
 
-@ 
+\end{chunk} 
 
 \section{Recursive parsing and expansion}
 
 Recursive routine used to expand pamphlet files to file descriptor
-[[out]]. The input is taken from file named [[filename]].
+out. The input is taken from file named filename.
 
-Without error, it returns [[0]]. On error, it prints on stderr a trace
-and returns [[-1]].
+Without error, it returns 0. On error, it prints on stderr a trace
+and returns -1.
 
 We read input file character by character. We rely on libc buffering for
-performance. If we find the opening [[<<]] of a chunk we call [[find_url]]
+performance. If we find the opening $<<$ of a chunk we call \verb|find_url|
 to handle the chunk. Note that the two characters we swallow will be
-output by [[find_url]] if this is not a protocol chunk.
+output by \verb|find_url| if this is not a protocol chunk.
 
-<<*>>=
+\begin{chunk}{*}
 int recursive_parsing(FILE * out, char *filename)
 {
   FILE *f;
@@ -106,15 +101,15 @@ int recursive_parsing(FILE * out, char *filename)
   return 0;
 }
 
-@ 
+\end{chunk} 
 
-We define a routine that, given an [[url]], do the needed lookup to find
+We define a routine that, given an url, do the needed lookup to find
 what kind of url it is, open it and puts it content into file descriptor
-[[out]].
+out.
 
 If the chunk name does not contain a protocol specifier we recognize
 then we ignore the input.
-<<*>>=
+\begin{chunk}{*}
 
 int url_dispatch(FILE *out, unsigned char *url)
 { int i = 0;
@@ -133,22 +128,22 @@ int url_dispatch(FILE *out, unsigned char *url)
   }
   return 0;
 }
-@ 
+\end{chunk} 
 
-We define a routine that find a booklet URL in file descriptor [[f]]. We
-now that we have already found the start of URL [[<<]]. So we look for
-the end of URL sign ([[>>]]) and store the found URL in [[buf]]. Once we
+We define a routine that find a booklet URL in file descriptor f. We
+now that we have already found the start of URL $<<$. So we look for
+the end of URL sign ($>>$) and store the found URL in buf. Once we
 have our URL, we call the dispatch routine on it to expand it.
 
 If, for any reason, we do not find a valid chunk name we output the
 characters we found so the original file is unchanged. If we do find
-a valid chunk name we call [[url_dispatch]] to look for a protocol
+a valid chunk name we call \verb|url_dispatch| to look for a protocol
 specifier.
 
-We use a buffer of fixed size [[buf]] to store the search URL. {\bf
+We use a buffer of fixed size buf to store the search URL. {\bf
 FIXME: this restriction should be fixed in a later version.}
 
-<<*>>=
+\begin{chunk}{*}
 #define BUF_SIZE 1024
 
 int find_url(FILE *out, FILE *f)
@@ -193,25 +188,24 @@ int find_url(FILE *out, FILE *f)
   fprintf(stderr, "error: non terminating URL:'%s'\n", buf);
   return -1;
 }
-@ 
+\end{chunk} 
 
 Print how to use this program.
-<<*>>=
+\begin{chunk}{*}
 void print_usage(void)
 {
-  printf("booklet %s\n", <<version>>);
+  printf("booklet %s\n", "v0.1");
   printf("usage: booklet [-v] bookletfile pamphletfile\n");
 }
 
-
-@ 
+\end{chunk} 
 
 \section {main}
 
-<<print usage and exit>>=
+\begin{chunk}{print usage and exit}
 print_usage();
 exit(-1);
-@ 
+\end{chunk} 
 
 We parse command line to take our arguments, we open files and then call
 recursive expansion.
@@ -219,13 +213,14 @@ recursive expansion.
 {\bf FIXME: maybe it would be better to do output on a temporary file
   and move it to destination if no error?}
 
-<<*>>=
+\begin{chunk}{*}
 int main(int argc, char **argv) 
 {
   FILE *out;
   
   if (argc < 3 || argc > 4) 
-  { <<print usage and exit>>    
+  { 
+\getchunk{print usage and exit}
   }
   if (argc == 3) /* -v was not specified */
   { out = fopen(argv[2], "w");
@@ -243,7 +238,7 @@ int main(int argc, char **argv)
     } 
     else /* an unknown option was specified */
     { fprintf(stderr, "bad option '%s'\n", argv[1]);
-      <<print usage and exit>>
+\getchunk{print usage and exit}
     }
     out = fopen(argv[3], "w");
     if (out == NULL) /* we couldn't open the input file */
@@ -258,7 +253,7 @@ int main(int argc, char **argv)
   return 0;
 }
 
-@
+\end{chunk}
 
 \appendix
 \section{Initial requirements for booklet made by Tim Daly}
@@ -282,14 +277,17 @@ The booklet function takes as input the name of a booklet file and the
 name of a pamphlet file. 
 
 The bookletfile is any file that contains special strings of the form:
-@<<file:filename>>
+
+file:filename
+
 which we will call a booklet URL. 
 
 The booklet function replaces the whole booklet URL including the
-surrounding @<< and >> symbols by the contents of filename.
+surrounding $<<$ and $>>$ symbols by the contents of filename.
 
 The replaced text should be exact with no extra leading or trailing
-characters so that x@<<file:filename1>>@<<file:filename2>>y where filename1
+characters so that \verb|x<<file:filename1>><<file:filename2>>y| 
+where filename1
 contains a single byte 'a' and filename2 contains a single byte 'b'
 should result in the inline string 'xaby'.
 
@@ -300,7 +298,7 @@ The resulting text is output to the pamphletfile.
 
 The -v flag is optional. If supplied the booklet function write the
 replacement actions to standard output thus:
-in (filename1) replacing @<<file:filename2>> with text from (filename2)
+in (filename1) replacing \verb|<<file:filename2>>| with text from (filename2)
 where (filename1) is the file containing the booklet URL and
 filename2 is the parsed filename from the booklet URL. This will
 allow the user to trace where replacements are specified and where
@@ -326,8 +324,8 @@ things as "http:", "pamphlet:", etc).
 It should be a design criteria that each protocol specifier has it's own
 associated parser as the syntax of the booklet URL may vary based on the
 protocol specifier. Thus,
-@<<file:filename>> parses the 'filename' portion as a path and file spec.
-@<<http:web>> parses the 'web' portion as any valid URL
+\verb|<<file:filename>>| parses the 'filename' portion as a path and file spec.
+\verb|<<http:web>>| parses the 'web' portion as any valid URL
 
 Note that the booklet program should be developed as a literate program
 and be contained in a single pamphlet file that does not use booklet URLs.
diff --git a/src/etc/Makefile.pamphlet b/src/etc/Makefile.pamphlet
index 1670deb..c9747a2 100644
--- a/src/etc/Makefile.pamphlet
+++ b/src/etc/Makefile.pamphlet
@@ -16,7 +16,7 @@ This allows us to use a simple wildcard to express the fact that
 all of the algreba/*.nrlib/code.o files are required in order to build
 the databases. If any if any of these are changed, the databases must
 be re-built.
-<<dbcomplete>>=
+\begin{chunk}{dbcomplete}
 ${MNT}/${SYS}/algebra/*.daase: ${INT}/algebra/*.nrlib/code.o
 	@ echo se01 rebuilding databases...
 	@ cp ${SRC}/doc/gloss.text ${INT}/algebra
@@ -27,21 +27,21 @@ ${MNT}/${SYS}/algebra/*.daase: ${INT}/algebra/*.nrlib/code.o
            echo ')lisp (make-databases "" nil)' | ${INTERPSYS} )
 	@ cp -pr ${INT}/algebra/*.daase ${MNT}/${SYS}/algebra
 
-@
+\end{chunk}
 \section{summary}
-<<summary>>=
+\begin{chunk}{summary}
 ${LIB}/summary: ${IN}/summary
 	@echo se02 making ${LIB}/summary from ${IN}/summary
 	@cp ${IN}/summary ${LIB}/summary
 
-@
+\end{chunk}
 \section{copyright}
-<<copyright>>=
+\begin{chunk}{copyright}
 ${LIB}/copyright: ${IN}/copyright
 	@echo si03 making ${LIB}/copyright from ${IN}/copyright
 	@cp ${IN}/copyright ${LIB}/copyright
 
-@
+\end{chunk}
 \section{asq}
 asq is a command line tool to ask questions about Axiom's domains,
 packages, and categories.
@@ -62,7 +62,7 @@ searchkey can be either a domain or its abbreviation.
  e.g. %s -so Integer
  will give the source file name written to stdout
 \end{verbatim}
-<<asq>>=
+\begin{chunk}{asq}
 ${OUT}/asq: ${MID}/asq.c
 	@echo se04 making ${OUT}/asq from ${MID}/asq.c
 	@( cd ${MID} ; ${CC} ${CCF} -o asq asq.c )
@@ -71,10 +71,10 @@ ${OUT}/asq: ${MID}/asq.c
 ${MID}/asq.c: ${IN}/asq.c.pamphlet
 	@echo se05 making ${OUT}/asq from ${MID}/asq.c
 	@( cd ${MID} ; \
-	  ${TANGLE} ${IN}/asq.c.pamphlet >asq.c )
+	  ${BOOKS}/tangle ${IN}/asq.c.pamphlet >asq.c )
 
-@
-<<*>>=
+\end{chunk}
+\begin{chunk}{*}
 IN=${SRC}/etc
 MID=${OBJ}/${SYS}/etc
 OUT=${MNT}/${SYS}/bin
@@ -91,10 +91,10 @@ announce:
 	@ echo src/etc BUILDING ETC
 	@ echo ======================================
 
-<<dbcomplete>>
-<<asq>>
-<<summary>>
-<<copyright>>
+\getchunk{dbcomplete}
+\getchunk{asq}
+\getchunk{summary}
+\getchunk{copyright}
 document:
 	@echo se07 documenting ${IN}
 	@( cd ${DOC} ; \
@@ -108,7 +108,7 @@ clean:
 	@rm -rf ${DOC}
 	@rm -f Makefile Makefile.dvi
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/etc/asq.c.pamphlet b/src/etc/asq.c.pamphlet
index e980224..005f8b3 100644
--- a/src/etc/asq.c.pamphlet
+++ b/src/etc/asq.c.pamphlet
@@ -626,8 +626,7 @@ cflow --emacs -l -n -b -T --omit-arguments asq.c
   192 {   1}   +-sprintf()
   193 {   1}   \-system()
 \end{verbatim}
-<<*>>=
-<<license>>
+\begin{chunk}{*}
 
 /* asq is a mini browser for the AXIOM databases                            */
 
@@ -1734,9 +1733,9 @@ int isspace(int c);
   return(0);
 }
  
-@
+\end{chunk}
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -1769,7 +1768,7 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/input/Makefile.pamphlet b/src/input/Makefile.pamphlet
index a26026c..3229552 100644
--- a/src/input/Makefile.pamphlet
+++ b/src/input/Makefile.pamphlet
@@ -50,7 +50,7 @@ We use the special .PRECIOUS target to prevent deletion of the
 intermediate .input files which are needed during the processing of
 regress target.
 
-<<genericRules>>=
+\begin{chunk}{genericRules}
 
 ${OUT}/%.input: ${MID}/%.input
 	@ echo si01 making ${OUT}/$*.input from ${MID}/$*.input
@@ -73,7 +73,7 @@ ${OUT}/%.as: ${MID}/%.as
 ${MID}/%.as: ${IN}/%.as.pamphlet
 	@echo si04 making ${MID}/$*.as from ${IN}/$*.as.pamphlet
 	@(cd ${MID} ; \
-	  ${TANGLE} ${IN}/$*.as.pamphlet >$*.as)
+	  ${BOOKS}/tangle ${IN}/$*.as.pamphlet >$*.as)
 
 ${DOC}/axiom.sty:
 	@echo si05 making ${DOC}/axiom.sty from ${BOOKS}/axiom.sty
@@ -97,14 +97,15 @@ ${DOC}/%.as.dvi: ${IN}/%.as.pamphlet
 	@ echo si07 making ${DOC}/$*.as.dvi from ${IN}/$*.as.pamphlet
 	@ (cd ${DOC} ; \
 	cp ${IN}/$*.as.pamphlet ${DOC} ; \
-	${DOCUMENT} ${NOISE} $*.as ; \
+	${EXTRACT} $*.as.pamphlet ; \
 	rm -f ${DOC}/$*.as.pamphlet ; \
 	rm -f ${DOC}/$*.as.tex ; \
+	rm -f ${DOC}/$*.as.dvi ; \
 	rm -f ${DOC}/$*.as )
 
-@
+\end{chunk}
 \section{Testing stanzas (to be added)}
-<<testing>>=
+\begin{chunk}{testing}
 
 .SUFFIXES: .input .out
  
@@ -169,7 +170,7 @@ all:	${OUTS}
 	@ axiom -rv $*.rec
 
 
-@
+\end{chunk}
 \section{The regression testing Makefile}
 This Makefile will be notangled into the int/input subdirectory.
 It will run regression tests over all of the input files.
@@ -177,7 +178,7 @@ This will catch things we break but won't catch wrong results
 that were wrong in the past. Every input file that gets regression
 tested is assumed to have been hand-verified before it was added
 to the list.
-<<regression tests>>=
+\begin{chunk}{regression tests}
 
 .SUFFIXES: .input .output
  
@@ -415,8 +416,8 @@ REGRESSTESTS= ackermann.regress \
     unittest1.regress unittest2.regress unittest3.regress unittest4.regress \
     unit-macro.regress zimmbron.regress zimmer.regress
 
-@
-<<regression tests>>=
+\end{chunk}
+\begin{chunk}{regression tests}
 CATSTESTS= \
     kamke0.regress    kamke1.regress   kamke2.regress   kamke3.regress \
     kamke4.regress    kamke5.regress   kamke6.regress   kamke7.regress \
@@ -430,10 +431,10 @@ CATSTESTS= \
     schaum29.regress  schaum30.regress schaum31.regress schaum32.regress \
     schaum33.regress  schaum34.regress 
 
-@
+\end{chunk}
 These long-running tests have been split into a different group
 so we can run them in parallel. 
-<<regression tests>>=
+\begin{chunk}{regression tests}
 NEWRICHTESTSa= rich1a.regress rich1b.regress rich2.regress  \
                rich3a.regress rich3b.regress rich3c.regress \
                rich3d.regress rich3e.regress rich3f.regress \
@@ -523,7 +524,7 @@ all: alltests
 algebratests: ${OUTS}
 	@ echo si13 starting algebra regression testing
 	@ (cd ${MID} ; \
-	  ${TANGLE} -t8 -R"algebra.regress" ${SRC}/algebra/Makefile.pamphlet \
+	  ${BOOKS}/tangle ${SRC}/algebra/Makefile.pamphlet algebra.regress \
             >Makefile.algebra ; \
           ${MAKE} -f Makefile.algebra )
 	@ echo si14 finished ${INT}/input
@@ -564,7 +565,7 @@ notests:
          echo '(tangle "${IN}/$*.input.pamphlet" "*" "$*.input")' | \
 	  ${LISPTANGLE} 1>/dev/null 2>/dev/null)
 
-@
+\end{chunk}
 The curious use of {\tt egrep} in the pipeline is to remove the
 spurious differences caused by the Version and Timestamp lines
 in the standard Axiom banner. These cause mismatches in otherwise
@@ -572,7 +573,7 @@ identical output.
 
 The input files are not removed because this parallel builds
 create race conditions.
-<<regression tests>>=
+\begin{chunk}{regression tests}
 %.output: %.input
 	@ echo si16 running test file $* using $*tpd.input 
 	@ echo ')set message test on' > $*tpd.input 
@@ -588,7 +589,8 @@ create race conditions.
 	  fi 
 #	@ rm $*.input 
 
-@
+\end{chunk}
+
 A regression test file will run the input file. Each input file
 specifies that it creates an output file using the )spool command.
 A regression file contains the expected output in specially formatted
@@ -600,7 +602,7 @@ because in at least one case (cwmmt.regress) we have spad test
 code in the input file that needs to be extracted and compiled.
 This is done by commands within the input file itself and uses
 the built-in gclweb function (see src/interp/gclweb.lisp)
-<<regression tests>>=
+\begin{chunk}{regression tests}
 %.regress: %.input
 	@ echo si17 regression testing $*
 	@ (cd ${MID} ; \
@@ -619,10 +621,11 @@ the built-in gclweb function (see src/interp/gclweb.lisp)
 	  fi ; \
 	  fgrep "regression result" $*.regress )
 
-@
+\end{chunk}
+
 \section{The Makefile}
 This Makefile will be notangled into the src/input subdirectory.
-<<*>>=
+\begin{chunk}{*}
 
 IN=${SRC}/input
 MID=${INT}/input
@@ -1465,14 +1468,14 @@ DOCFILES= \
 all: ${FILES} ${FILES2} ${ASFILES} ${RICHINPUT} regress ${DOCFILES} 
 	@echo 1 finished ${IN}
 
-<<genericRules>>
+\getchunk{genericRules}
 
 use:
 	@echo si18 making ${OUT} from ${IN}
 
 regress:
 	@echo si19 making ${MID}
-	@ ${TANGLE} -t8 -R"regression tests" ${IN}/Makefile.pamphlet \
+	@ ${BOOKS}/tangle ${IN}/Makefile.pamphlet "regression tests" \
           >${MID}/Makefile
 	@ echo 3a tpdhere parallel making ${MID} 
 	@ echo 3b tpdhere parallel making ${MID} 
@@ -1491,7 +1494,7 @@ clean:
 	@rm -rf ${OUT}
 	@rm -f Makefile Makefile.dvi
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/input/aseg6.as.pamphlet b/src/input/aseg6.as.pamphlet
index ad7131e..2d6553d 100644
--- a/src/input/aseg6.as.pamphlet
+++ b/src/input/aseg6.as.pamphlet
@@ -11,7 +11,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 -- Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 -- All rights reserved.
 --
@@ -43,9 +43,9 @@
 -- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 -- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
+
 #include "axiom"
 
 C1: Category == with {
@@ -111,7 +111,7 @@ D5(X: Ring): Ring == X add {
 	(a: %) + (b: %): % == per(rep(a) + rep(b) + 1@Rep);
 }
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/input/aseg7.as.pamphlet b/src/input/aseg7.as.pamphlet
index 4576493..c9a7670 100644
--- a/src/input/aseg7.as.pamphlet
+++ b/src/input/aseg7.as.pamphlet
@@ -11,7 +11,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 -- Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 -- All rights reserved.
 --
@@ -43,9 +43,9 @@
 -- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 -- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
+
 #include "axiom.as"   
 
 L ==> List;           
@@ -101,7 +101,7 @@ Test3 : with {
 }
 
 foo2 : with {constPtrs? : ()-> Integer; set: Integer->Integer; resetConstPtrs: () ->Integer } ==  Test2(Integer) add {}
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/input/cohen.input.pamphlet b/src/input/cohen.input.pamphlet
index 9bbd52d..069cc29 100644
--- a/src/input/cohen.input.pamphlet
+++ b/src/input/cohen.input.pamphlet
@@ -2131,7 +2131,7 @@ CohenPolynomial(): SetCategory with
 \end{chunk}
 
 \begin{verbatim}
-<<domain CEXPR CohenExpression>>=
+
 )abbrev domain CEXPR CohenExpression
 -- Author: Timothy Daly (based on Joel Cohen's books)
 -- Date Created: 7 April 2007
diff --git a/src/input/cohen1.input b/src/input/cohen1.input
new file mode 100644
index 0000000..b2733bc
--- /dev/null
+++ b/src/input/cohen1.input
@@ -0,0 +1,13 @@
+--allfact
+u:UP(x,PF(19)) :=3*x**4+2*x**2+15*x+18
+v:UP(x,INT):= (4*x**3+2*x**2+1)*(12*x**5-x**3+12)
+w:MPOLY([x,y,z],INT) :=(x**2-y**2-z**2)*(x**2+y**2+z**2)*(z*y+3*z)
+f:MPOLY([x,y,z],FRAC INT) :=(4/9*x**2-1/16)*(x**3/27+125)
+g:DMP([x,y],FRAC POLY INT):=a**2*x**2/b**2 -c**2*y**2/d**2
+r:FRAC POLY INT:= (a**3/b**3-c**3/(b+1)**3)*(a*d+a/c)
+p:UP(x,SAEaa) :=(x**3+aa**2*x+1)*(aa*x**2+aa*x+aa)**2
+
+--arith
+u := (x+1)**6
+- b d + a c + (a d + b c)e
+                          1
diff --git a/src/input/dbtest.input.pamphlet b/src/input/dbtest.input.pamphlet
new file mode 100644
index 0000000..a2db639
--- /dev/null
+++ b/src/input/dbtest.input.pamphlet
@@ -0,0 +1,1154 @@
+\documentclass{article}
+\setlength{\textwidth}{400pt}
+\usepackage{axiom}
+\begin{document}
+\title{\$SPAD/src/input algaggr.input}
+\author{Timothy Daly}
+\maketitle
+\begin{abstract}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{verbatim}
+Building A Query Facility
+
+We now turn to an entirely different kind of application,
+building a query language for a database.
+
+Here is the practical problem to solve.  The hyperdoc facility of
+Axiom has a database for all operations and constructors which is
+stored on disk and accessed by Hyperdoc.  For our purposes here, we
+regard each line of this file as having eight fields:
+\begin{itemize}
+\item class
+\item name
+\item type
+\item nargs
+\item exposed
+\item kind
+\item origin
+\item condition
+\end{itemize}
+
+\begin{chunk}{*}
+\getchunk{ug13.ht}
+\end{chunk}
+
+Here is an example entry:
+
+begin{verbatim}
+  o`determinant`$->R`1`x`d`Matrix(R)`has(R,commutative("*"))
+end{verbatim}
+
+In English, the entry means that the operation 
+begin{verbatim}
+  determinant: $ -> R 
+end{verbatim}
+with it 1 argument, is exposed and is exported by the domain
+Matrix(R) if R has commutative("*").
+
+Our task is to create a little query language that allows us
+to get useful information from this database.
+
+First we design a simple language for accessing information from the
+database.  We have the following simple model in mind for its design.
+Think of the database as a box of index cards.  There is only one
+search operation---it takes the name of a field and a predicate (a
+boolean-valued function) defined on the fields of the index cards.
+When applied, the search operation goes through the entire box
+selecting only those index cards for which the predicate is true.  The
+result of a search is a new box of index cards.  This process can be
+repeated again and again.
+
+The predicates all have a particularly simple form: 
+begin{verbatim}
+  symbol = pattern
+end{verbatim}
+where symbol designates one of the fields, and pattern is a 
+``search string''---a string that may contain a ``*'' as a
+wildcard. Wildcards match any substring, including the empty string.
+Thus the pattern ``*ma*t'' matches ``mat'', ``doormat'' and ``smart''.
+
+To illustrate how queries are given, we give you a sneak preview
+of the facility we are about to create.
+
+Extract the database of all Axiom operations.
+begin{verbatim}
+  ops := getDatabase("o")
+end{verbatim}
+
+How many exposed three-argument ``map'' operations involving streams?
+begin{verbatim}
+  ops.(name="map").(nargs="3").(type="*Stream*")
+end{verbatim}
+
+As usual, the arguments of elt associate to the left.
+The first elt produces the set of all operations with
+name {\tt map}.
+The second elt produces the set of all map operations
+with three arguments.
+The third elt produces the set of all three-argument map
+operations having a type mentioning Stream.
+
+Another thing we'd like to do is to extract one field from each of
+the index cards in the box and look at the result.
+Here is an example of that kind of request.
+
+What constructors explicitly export a determinant operation?
+
+elt(elt(elt(elt(ops,name="determinant"),origin),sort),unique)
+
+
+The first elt produces the set of all index cards with
+name {\tt determinant}.
+The second elt extracts the {\tt origin} component from
+each index card. Each origin component
+is the name of a constructor which directly
+exports the operation represented by the index card.
+Extracting a component from each index card produces what we call
+a {\it datalist}.
+The third elt, {\tt sort}, causes the datalist of
+origins to be sorted in alphabetic
+order.
+The fourth, {\tt unique}, causes duplicates to be removed.
+
+Before giving you a more extensive demo of this facility,
+we now build the necessary domains and packages to implement it.
+%We will introduce a few of our minor conveniences.
+
+\endscroll
+\autobuttons
+\end{page}
+
+\begin{patch}{ugDomainsQueryLanguagePagePatch1}
+\begin{paste}{ugDomainsQueryLanguagePageFull1}
+{ugDomainsQueryLanguagePageEmpty1}
+\pastebutton{ugDomainsQueryLanguagePageFull1}{\hidepaste}
+\tab{5}\spadcommand{ops := getDatabase("o")\bound{o1 }}
+\indentrel{3}begin{verbatim}
+   (1)  6315
+                               Type: Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsQueryLanguagePageEmpty1}
+\begin{paste}{ugDomainsQueryLanguagePageEmpty1}
+{ugDomainsQueryLanguagePagePatch1}
+\pastebutton{ugDomainsQueryLanguagePageEmpty1}{\showpaste}
+\tab{5}\spadcommand{ops := getDatabase("o")\bound{o1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsQueryLanguagePagePatch2}
+\begin{paste}{ugDomainsQueryLanguagePageFull2}
+{ugDomainsQueryLanguagePageEmpty2}
+\pastebutton{ugDomainsQueryLanguagePageFull2}{\hidepaste}
+\tab{5}
+\spadcommand{ops.(name="map").(nargs="3").(type="*Stream*")
+\bound{o2 }\free{o1 }}
+\indentrel{3}begin{verbatim}
+   (2)  3
+                               Type: Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsQueryLanguagePageEmpty2}
+\begin{paste}{ugDomainsQueryLanguagePageEmpty2}
+{ugDomainsQueryLanguagePagePatch2}
+\pastebutton{ugDomainsQueryLanguagePageEmpty2}{\showpaste}
+\tab{5}
+\spadcommand{ops.(name="map").(nargs="3").(type="*Stream*")
+\bound{o2 }\free{o1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsQueryLanguagePagePatch3}
+\begin{paste}{ugDomainsQueryLanguagePageFull3}
+{ugDomainsQueryLanguagePageEmpty3}
+\pastebutton{ugDomainsQueryLanguagePageFull3}{\hidepaste}
+\tab{5}
+\spadcommand{elt(elt(elt(elt(ops,name="determinant"),origin),sort),unique)
+\free{o1 }}
+\indentrel{3}begin{verbatim}
+   (3)
+   ["InnerMatrixLinearAlgebraFunctions",
+    "MatrixCategory", "MatrixLinearAlgebraFunctions",
+    "SquareMatrixCategory"]
+                                  Type: DataList String
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsQueryLanguagePageEmpty3}
+\begin{paste}{ugDomainsQueryLanguagePageEmpty3}
+{ugDomainsQueryLanguagePagePatch3}
+\pastebutton{ugDomainsQueryLanguagePageEmpty3}{\showpaste}
+\tab{5}
+\spadcommand{elt(elt(elt(elt(ops,name="determinant"),origin),sort),unique)
+\free{o1 }}
+\end{paste}\end{patch}
+
+@
+\pagehead{ugDomainsDatabaseConstructorPage}{ug13.ht}
+{The Database Constructor}
+\begin{chunk}{ug13.ht}
+\begin{page}{ugDomainsDatabaseConstructorPage}
+{13.13.2. The Database Constructor}
+\beginscroll
+
+We work from the top down. First, we define a database,
+our box of index cards, as an abstract datatype.
+For sake of illustration and generality,
+we assume that an index card is some type S, and
+that a database is a box of objects of type S.
+Here is the Axiom program defining the \pspadtype{Database}
+domain.
+
+\beginImportant
+  
+\noindent
+{\tt 1.\ \ \ PI\ ==>\ PositiveInteger}\newline
+{\tt 2.\ \ \ Database(S):\ Exports\ ==\ Implementation\ where}\newline
+{\tt 3.\ \ \ \ \ S:\ Object\ with\ }\newline
+{\tt 4.\ \ \ \ \ \ \ elt:\ (\$,\ Symbol)\ ->\ String}\newline
+{\tt 5.\ \ \ \ \ \ \ display:\ \$\ ->\ Void}\newline
+{\tt 6.\ \ \ \ \ \ \ fullDisplay:\ \$\ ->\ Void}\newline
+{\tt 7.\ \ \ }\newline
+{\tt 8.\ \ \ \ \ Exports\ ==\ with}\newline
+{\tt 9.\ \ \ \ \ \ \ elt:\ (\$,QueryEquation)\ ->\ \$}\newline
+{\tt 10.\ \ \ \ \ \ elt:\ (\$,\ Symbol)\ ->\ DataList\ String}\newline
+{\tt 11.\ \ \ \ \ \ "+":\ (\$,\$)\ ->\ \$}\newline
+{\tt 12.\ \ \ \ \ \ "-":\ (\$,\$)\ ->\ \$}\newline
+{\tt 13.\ \ \ \ \ \ display:\ \$\ ->\ Void}\newline
+{\tt 14.\ \ \ \ \ \ fullDisplay:\ \$\ ->\ Void}\newline
+{\tt 15.\ \ \ \ \ \ fullDisplay:\ (\$,PI,PI)\ ->\ Void}\newline
+{\tt 16.\ \ \ \ \ \ coerce:\ \$\ ->\ OutputForm}\newline
+{\tt 17.\ \ \ \ Implementation\ ==\ add}\newline
+{\tt 18.\ \ \ \ \ \ \ \ ...}\newline
+\endImportant
+
+The domain constructor takes a parameter S, which
+stands for the class of index cards.
+We describe an index card later.
+Here think of an index card as a string which has
+the eight fields mentioned above.
+
+First, we tell Axiom what operations we are going to require
+from index cards.
+We need an elt to extract the contents of a field
+(such as {\tt name} and {\tt type}) as a string.
+For example, c.name returns a string that is the content of the
+name field on the index card c.
+We need to display an index card in two ways:
+\pspadfun{display} shows only the name and type of an
+operation;
+\pspadfun{fullDisplay} displays all fields.
+The display operations return no useful information and thus have
+return type Void.
+
+Next, we tell Axiom what operations the user can apply
+to the database.
+This part defines our little query language.
+The most important operation is
+{\frenchspacing\tt db . field = pattern} which
+returns a new database, consisting of all index
+cards of {\tt db} such that the field part of the index
+card is matched by the string pattern called pattern.
+The expression {\tt field = pattern} is an object of type
+QueryEquation (defined in the next section).
+
+Another elt is needed to produce a DataList object.
+Operation + is to merge two databases together;
+- is used to subtract away common entries in a second
+database from an initial database.
+There are three display functions.
+The \pspadfun{fullDisplay} function has two versions: one
+that prints all the records, the other that prints only a fixed
+number of records.
+A coerce to OutputForm creates a display object.
+
+The {\tt Implementation} part of Database is straightforward.
+\beginImportant
+  
+\noindent
+{\tt 1.\ \ \ \ \ Implementation\ ==\ add}\newline
+{\tt 2.\ \ \ \ \ \ \ s:\ Symbol}\newline
+{\tt 3.\ \ \ \ \ \ \ Rep\ :=\ List\ S}\newline
+{\tt 4.\ \ \ \ \ \ \ elt(db,equation)\ ==\ ...}\newline
+{\tt 5.\ \ \ \ \ \ \ 
+elt(db,key)\ ==\ [x.key\ for\ x\ in\ db]::DataList(String)}\newline
+{\tt 6.\ \ \ \ \ \ \ 
+display(db)\ ==\ \ for\ x\ in\ db\ repeat\ display\ x}\newline
+{\tt 7.\ \ \ \ \ \ \ 
+fullDisplay(db)\ ==\ for\ x\ in\ db\ repeat\ fullDisplay\ x}\newline
+{\tt 8.\ \ \ \ \ \ \ 
+fullDisplay(db,\ n,\ m)\ ==\ for\ x\ in\ db\ for\ i\ in\ 1..m}\newline
+{\tt 9.\ \ \ \ \ \ \ \ \ repeat}\newline
+{\tt 10.\ \ \ \ \ \ \ \ \ \ if\ i\ >=\ n\ then\ fullDisplay\ x}\newline
+{\tt 11.\ \ \ \ \ \ x+y\ ==\ removeDuplicates!\ merge(x,y)}\newline
+{\tt 12.\ \ \ \ \ \ x-y\ ==\ mergeDifference(copy(x::Rep),}\newline
+{\tt 13.\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
+y::Rep)\$MergeThing(S)}\newline
+{\tt 14.\ \ \ \ \ \ coerce(db):\ OutputForm\ ==\ (\#db)::\ OutputForm}
+\newline
+\endImportant
+
+The database is represented by a list of elements of S 
+(index cards).
+We leave the definition of the first elt operation
+(on line 4) until the next section.
+The second elt collects all the strings with field name
+{\it key} into a list.
+The display function and first fullDisplay function
+simply call the corresponding functions from S.
+The second fullDisplay function provides an efficient way of
+printing out a portion of a large list.
+The + is defined by using the existing
+\spadfunFrom{merge}{List} operation defined on lists, then
+removing duplicates from the result.
+The - operation requires writing a corresponding
+subtraction operation.
+A package MergeThing (not shown) provides this.
+
+The coerce function converts the database to an
+OutputForm by computing the number of index cards.
+This is a good example of the independence of
+the representation of an Axiom object from how it presents
+itself to the user. We usually do not want to look at a database---but
+do care how many ``hits'' we get for a given query.
+So we define the output representation of a database to be simply
+the number of index cards our query finds.
+\endscroll
+\autobuttons
+\end{page}
+
+\end{chunk}
+\pagehead{ugDomainsQueryEquationsPage}{ug13.ht}{Query Equations}
+\begin{chunk}{ug13.ht}
+\begin{page}{ugDomainsQueryEquationsPage}{13.13.3. Query Equations}
+\beginscroll
+
+The predicate for our search is given by an object of type
+\pspadtype{QueryEquation}.
+Axiom does not have such an object yet so we
+have to invent it.
+
+\beginImportant
+  
+\noindent
+{\tt 1.\ \ \ QueryEquation():\ Exports\ ==\ Implementation\ where}\newline
+{\tt 2.\ \ \ \ \ Exports\ ==\ with}\newline
+{\tt 3.\ \ \ \ \ \ \ equation:\ (Symbol,\ String)\ ->\ \$}\newline
+{\tt 4.\ \ \ \ \ \ \ variable:\ \$\ ->\ Symbol}\newline
+{\tt 5.\ \ \ \ \ \ \ value:\\ \\ \\ \\ \$\ ->\ String}\newline
+{\tt 6.\ \ \ }\newline
+{\tt 7.\ \ \ \ \ Implementation\ ==\ add}\newline
+{\tt 8.\ \ \ \ \ \ \ Rep\ :=\ Record(var:Symbol,\ val:String)}\newline
+{\tt 9.\ \ \ \ \ \ \ equation(x,\ s)\ ==\ [x,\ s]}\newline
+{\tt 10.\ \ \ \ \ \ variable\ q\ ==\ q.var}\newline
+{\tt 11.\ \ \ \ \ \ value\\ \\ \\ \\ q\ ==\ q.val}\newline
+\endImportant
+
+Axiom converts an input expression of the form
+{\it a} = {\it b} to equation({\it a, b}}.
+Our equations always have a symbol on the left and a string
+on the right.
+The {\tt Exports} part thus specifies an operation
+equation to create a query equation, and
+\pspadfun{variable} and \pspadfun{value} to select the left- and
+right-hand sides.
+The {\tt Implementation} part uses \pspadtype{Record} for a
+space-efficient representation of an equation.
+
+Here is the missing definition for the elt function of
+\pspadtype{Database} in the last section:
+
+\beginImportant
+  
+\noindent
+{\tt 1.\ \ \ \ \ \ \ elt(db,eq)\ ==}\newline
+{\tt 2.\ \ \ \ \ \ \ \ \ field\\ \ :=\ variable\ eq}\newline
+{\tt 3.\ \ \ \ \ \ \ \ \ value\ :=\ value\ eq}\newline
+{\tt 4.\ \ \ \ \ \ \ \ \ 
+[x\ for\ x\ in\ db\ |\ matches?(value,x.field)]}\newline
+\endImportant
+
+Recall that a database is represented by a list.
+Line 4 simply runs over that list collecting all elements
+such that the pattern (that is, value)
+matches the selected field of the element.
+
+\endscroll
+\autobuttons
+\end{page}
+
+\end{chunk}
+\pagehead{ugDomainsDataListsPage}{ug13.ht}{DataLists}
+\begin{chunk}{ug13.ht}
+\begin{page}{ugDomainsDataListsPage}{13.13.4. DataLists}
+\beginscroll
+
+Type \pspadtype{DataList} is a new type invented to hold the result
+of selecting one field from each of the index cards in the box.
+It is useful to make datalists extensions of lists---lists that
+have special elt operations defined on them for
+sorting and removing duplicates.
+
+\beginImportant
+  
+\noindent
+{\tt 1.\ \ \ DataList(S:OrderedSet)\ :\ Exports\ ==\ 
+Implementation\ where}\newline
+{\tt 2.\ \ \ \ \ Exports\ ==\ ListAggregate(S)\ with}\newline
+{\tt 3.\ \ \ \ \ \ \ elt:\ (\$,"unique")\ ->\ \$}\newline
+{\tt 4.\ \ \ \ \ \ \ elt:\ (\$,"sort")\ ->\ \$}\newline
+{\tt 5.\ \ \ \ \ \ \ elt:\ (\$,"count")\ ->\ NonNegativeInteger}\newline
+{\tt 6.\ \ \ \ \ \ \ coerce:\ List\ S\ ->\ \$}\newline
+{\tt 7.\ \ \ }\newline
+{\tt 8.\ \ \ \ \ Implementation\ ==\ \ List(S)\ add}\newline
+{\tt 9.\ \ \ \ \ \ \ Rep\ :=\ List\ S}\newline
+{\tt 10.\ \ \ \ \ \ elt(x,"unique")\ ==\ removeDuplicates(x)}\newline
+{\tt 11.\ \ \ \ \ \ elt(x,"sort")\ ==\ sort(x)}\newline
+{\tt 12.\ \ \ \ \ \ elt(x,"count")\ ==\ \#x}\newline
+{\tt 13.\ \ \ \ \ \ coerce(x:List\ S)\ ==\ x\ ::\ \$}\newline
+\endImportant
+
+The {\tt Exports} part asserts that datalists belong to the
+category ListAggregate.
+Therefore, you can use all the usual list operations on datalists,
+such as \spadfunFrom{first}{List}, \spadfunFrom{rest}{List}, and
+\spadfunFrom{concat}{List}.
+In addition, datalists have four explicit operations.
+Besides the three elt operations, there is a
+coerce operation that creates datalists from lists.
+
+The {\tt Implementation} part needs only to define four functions.
+All the rest are obtained from List(S).
+
+\endscroll
+\autobuttons
+\end{page}
+
+\end{chunk}
+\pagehead{ugDomainsDatabasePage}{ug13.ht}{Index Cards}
+\begin{chunk}{ug13.ht}
+\begin{page}{ugDomainsDatabasePage}{13.13.5. Index Cards}
+\beginscroll
+
+An index card comes from a file as one long string.  We define
+functions that extract substrings from the long string.  Each field
+has a name that is passed as a second argument to elt.
+
+\beginImportant
+  
+\noindent
+{\tt 1.\ \ \ IndexCard()\ ==\ Implementation\ where}\newline
+{\tt 2.\ \ \ \ \ Exports\ ==\ with}\newline
+{\tt 3.\ \ \ \ \ \ \ elt:\ (\$,\ Symbol)\ ->\ String}\newline
+{\tt 4.\ \ \ \ \ \ \ display:\ \$\ ->\ Void}\newline
+{\tt 5.\ \ \ \ \ \ \ fullDisplay:\ \$\ ->\ Void}\newline
+{\tt 6.\ \ \ \ \ \ \ coerce:\ String\ ->\ \$}\newline
+{\tt 7.\ \ \ \ \ Implementation\ ==\ String\ add\ ...}\newline
+\endImportant
+
+We leave the {\tt Implementation} part to the reader.
+All operations involve straightforward string manipulations.
+
+\endscroll
+\autobuttons
+\end{page}
+
+\end{chunk}
+\pagehead{ugDomainsCreatingPage}{ug13.ht}{Creating a Database}
+\begin{chunk}{ug13.ht}
+\begin{page}{ugDomainsCreatingPage}{13.13.6. Creating a Database}
+\beginscroll
+
+We must not forget one important operation: one that builds the
+database in the first place!  We'll name it \pspadfun{getDatabase} and
+put it in a package.  This function is implemented by calling the
+\Lisp{} function getBrowseDatabase(s) to get appropriate
+information from \Browse{}.  This operation takes a string indicating
+which lines you want from the database: "o" gives you all
+operation lines, and "k", all constructor lines.  Similarly,
+"c", "d", and "p" give you all category,
+domain and package lines respectively.
+
+\beginImportant
+  
+\noindent
+{\tt 1.\ \ \ OperationsQuery():\ Exports\ ==\ Implementation\ where}
+\newline
+{\tt 2.\ \ \ \ \ Exports\ ==\ with}\newline
+{\tt 3.\ \ \ \ \ \ \ getDatabase:\ String\ ->\ Database(IndexCard)}
+\newline
+{\tt 4.\ \ \ }\newline
+{\tt 5.\ \ \ \ \ Implementation\ ==\ add}\newline
+{\tt 6.\ \ \ \ \ \ \ getDatabase(s)\ ==\ getBrowseDatabase(s)\$Lisp}
+\newline
+\endImportant
+
+We do not bother creating a special name for databases of index
+cards.
+\pspadtype{Database (IndexCard)} will do.
+Notice that we used the package \pspadtype{OperationsQuery} to
+create, in effect,
+a new kind of domain: \pspadtype{Database(IndexCard)}.
+
+\endscroll
+\autobuttons
+\end{page}
+
+\end{chunk}
+\pagehead{ugDomainsPuttingPage}{ug13.ht}{Putting It All Together}
+\begin{chunk}{ug13.ht}
+\begin{page}{ugDomainsPuttingPage}{13.13.7. Putting It All Together}
+\beginscroll
+
+To create the database facility, you put all these constructors
+into one file.\footnote{You could use separate files, but we
+are putting them all together because, organizationally, that is
+the logical thing to do.}
+At the top of the file put \spadcmd{)abbrev} commands, giving the
+constructor abbreviations you created.
+
+\beginImportant
+  
+\noindent
+{\tt 1.\ \ \ )abbrev\ domain\ \ ICARD\ \ \ IndexCard}\newline
+{\tt 2.\ \ \ )abbrev\ domain\ \ QEQUAT\ \ QueryEquation}\newline
+{\tt 3.\ \ \ )abbrev\ domain\ \ MTHING\ \ MergeThing}\newline
+{\tt 4.\ \ \ )abbrev\ domain\ \ DLIST\ \ \ DataList}\newline
+{\tt 5.\ \ \ )abbrev\ domain\ \ DBASE\ \ \ Database}\newline
+{\tt 6.\ \ \ )abbrev\ package\ OPQUERY\ OperationsQuery}\newline
+\endImportant
+
+With all this in {\bf alql.spad}, for example, compile it using
+begin{verbatim}
+)compile alql
+end{verbatim}
+and then load each of the constructors:
+begin{verbatim}
+)load ICARD QEQUAT MTHING DLIST DBASE OPQUERY
+end{verbatim}
+You are ready to try some sample queries.
+
+\endscroll
+\autobuttons
+\end{page}
+
+\end{chunk}
+\pagehead{ugDomainsExamplesPage}{ug13.ht}{Example Queries}
+\begin{chunk}{ug13.ht}
+\begin{page}{ugDomainsExamplesPage}{13.13.8. Example Queries}
+\beginscroll
+
+Our first set of queries give some statistics on constructors in
+the current Axiom system.
+
+\xtc{
+How many constructors does Axiom have?
+}{
+\spadpaste{ks := getDatabase "k"\bound{q1}}
+}
+\xtc{
+Break this down into the number of categories, domains, and packages.
+}{
+\spadpaste{[ks.(kind=k) for k in ["c","d","p"]]\bound{q3}\free{q1}}
+}
+\xtc{
+What are all the domain constructors that take no parameters?
+}{
+\spadpaste{elt(ks.(kind="d").(nargs="0"),name)\bound{q4}\free{q1}}
+}
+\xtc{
+How many constructors have ``Matrix'' in their name?
+}{
+\spadpaste{mk := ks.(name="*Matrix*")\bound{q5}\free{q1}}
+}
+\xtc{
+What are the names of those that are domains?
+}{
+\spadpaste{elt(mk.(kind="d"),name)\bound{q6}\free{q5}}
+}
+\xtc{
+How many operations are there in the library?
+}{
+\spadpaste{o := getDatabase "o"\bound{o1}}
+}
+\xtc{
+Break this down into categories, domains, and packages.
+}{
+\spadpaste{[o.(kind=k) for k in ["c","d","p"]]\free{o1}}
+}
+
+The query language is helpful in getting information about a
+particular operation you might like to apply.
+While this information can be obtained with
+\Browse{}, the use of the query database gives you data that you
+can manipulate in the workspace.
+
+\xtc{
+How many operations have ``eigen'' in the name?
+}{
+\spadpaste{eigens := o.(name="*eigen*")\bound{eigens}\free{o1}}
+}
+\xtc{
+What are their names?
+}{
+\spadpaste{elt(eigens,name)\free{eigens}}
+}
+\xtc{
+Where do they come from?
+}{
+\spadpaste{elt(elt(elt(eigens,origin),sort),unique) \free{eigens}}
+}
+
+The operations + and - are useful for
+constructing small databases and combining them.
+However, remember that the only matching you can do is string
+matching.
+Thus a pattern such as {\tt "*Matrix*"} on the type field
+matches
+any type containing Matrix, MatrixCategory, SquareMatrix, and so on.
+
+\xtc{
+How many operations mention ``Matrix'' in their type?
+}{
+\spadpaste{tm := o.(type="*Matrix*")\bound{x10}\free{o1}}
+}
+\xtc{
+How many operations come from constructors with ``Matrix'' in
+their name?
+}{
+\spadpaste{fm := o.(origin="*Matrix*")\bound{x11}\free{o1}}
+}
+\xtc{
+How many operations are in fm but not in tm?
+}{
+\spadpaste{fm-tm \bound{x12}\free{x10 x11}}
+}
+\xtc{
+Display the operations that both mention ``Matrix'' in their type
+and come from a constructor having ``Matrix'' in their name.
+}{
+\spadpaste{fullDisplay(fm-\%) \bound{x13}\free{x12}}
+}
+\xtc{
+How many operations involve matrices?
+}{
+\spadpaste{m := tm+fm \bound{x14}\free{x10 x11}}
+}
+\xtc{
+Display 4 of them.
+}{
+\spadpaste{fullDisplay(m, 202, 205) \free{x14}}
+}
+\xtc{
+How many distinct names of operations involving matrices are there?
+}{
+\spadpaste{elt(elt(elt(m,name),unique),count) \free{x14}}
+}
+
+\endscroll
+\autobuttons
+\end{page}
+
+\begin{patch}{ugDomainsExamplesPagePatch1}
+\begin{paste}{ugDomainsExamplesPageFull1}{ugDomainsExamplesPageEmpty1}
+\pastebutton{ugDomainsExamplesPageFull1}{\hidepaste}
+\tab{5}\spadcommand{ks := getDatabase "k"\bound{q1 }}
+\indentrel{3}begin{verbatim}
+   (1)  1067
+                               Type: Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty1}
+\begin{paste}{ugDomainsExamplesPageEmpty1}{ugDomainsExamplesPagePatch1}
+\pastebutton{ugDomainsExamplesPageEmpty1}{\showpaste}
+\tab{5}\spadcommand{ks := getDatabase "k"\bound{q1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch2}
+\begin{paste}{ugDomainsExamplesPageFull2}{ugDomainsExamplesPageEmpty2}
+\pastebutton{ugDomainsExamplesPageFull2}{\hidepaste}
+\tab{5}\spadcommand{[ks.(kind=k) for k in ["c","d","p"]]\bound{q3 }\free{q1 }}
+\indentrel{3}begin{verbatim}
+   (2)  [205,393,469]
+                          Type: List Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty2}
+\begin{paste}{ugDomainsExamplesPageEmpty2}{ugDomainsExamplesPagePatch2}
+\pastebutton{ugDomainsExamplesPageEmpty2}{\showpaste}
+\tab{5}\spadcommand{[ks.(kind=k) for k in ["c","d","p"]]\bound{q3 }\free{q1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch3}
+\begin{paste}{ugDomainsExamplesPageFull3}{ugDomainsExamplesPageEmpty3}
+\pastebutton{ugDomainsExamplesPageFull3}{\hidepaste}
+\tab{5}\spadcommand{elt(ks.(kind="d").(nargs="0"),name)\bound{q4 }\free{q1 }}
+\indentrel{3}begin{verbatim}
+   (3)
+   ["AlgebraicNumber", "AnonymousFunction", "Any",
+    "AttributeButtons", "BasicFunctions",
+    "BasicOperator", "BinaryExpansion", "BinaryFile",
+    "Bits", "Boolean", "CardinalNumber",
+    "CharacterClass", "Character", "Color", "Commutator",
+    "DecimalExpansion", "DoubleFloat", "DrawOption",
+    "Exit", "ExtAlgBasis", "FileName", "Float",
+    "FortranCode", "FortranScalarType",
+    "FortranTemplate", "FortranType", "GraphImage",
+    "HexadecimalExpansion", "IVBaseColor", "IVBasicNode",
+    "IVCoordinate3", "IVCoordinate4", "IVFaceSet",
+    "IVField", "IVGroup", "IVIndexedLineSet",
+    "IVNodeConnection", "IVNodeObject", "IVPointSet",
+    "IVQuadMesh", "IVSeparator", "IVSimpleInnerNode",
+    "IVUtilities", "IVValue", "IndexCard",
+    "InnerAlgebraicNumber", "InputForm", "Integer",
+    "IntegrationFunctionsTable", "InventorDataSink",
+    "InventorRenderPackage", "InventorViewPort",
+    "Library", "MachineComplex", "MachineFloat",
+    "MachineInteger",
+    "NagDiscreteFourierTransformInterfacePackage",
+    "NagEigenInterfacePackage",
+    "NagOptimisationInterfacePackage",
+    "NagQuadratureInterfacePackage", "NagResultChecks",
+    "NagSpecialFunctionsInterfacePackage",
+    "NonNegativeInteger", "None",
+    "NumericalIntegrationProblem", "NumericalODEProblem",
+    "NumericalOptimizationProblem",
+    "NumericalPDEProblem", "ODEIntensityFunctionsTable",
+    "OrdSetInts", "OutputForm", "Palette", "Partition",
+    "Pi", "PlaneAlgebraicCurvePlot", "Plot3D", "Plot",
+    "PositiveInteger", "QueryEquation", "RenderTools",
+    "Result", "RomanNumeral", "RoutinesTable",
+    "SExpression", "ScriptFormulaFormat",
+    "SingleInteger", "SingletonAsOrderedSet", "String",
+    "SubSpaceComponentProperty", "Switch", "SymbolTable",
+    "Symbol", "TexFormat", "TextFile", "TheSymbolTable",
+    "ThreeDimensionalViewport", "Timer",
+    "TwoDimensionalViewport", "Void",
+    "d01TransformFunctionType", "d01ajfAnnaType",
+    "d01akfAnnaType", "d01alfAnnaType", "d01amfAnnaType",
+    "d01anfAnnaType", "d01apfAnnaType", "d01aqfAnnaType",
+    "d01asfAnnaType", "d01fcfAnnaType", "d01gbfAnnaType",
+    "d02bbfAnnaType", "d02bhfAnnaType", "d02cjfAnnaType",
+    "d02ejfAnnaType", "d03eefAnnaType", "d03fafAnnaType",
+    "e04dgfAnnaType", "e04fdfAnnaType", "e04gcfAnnaType",
+    "e04jafAnnaType", "e04mbfAnnaType", "e04nafAnnaType",
+    "e04ucfAnnaType"]
+                                  Type: DataList String
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty3}
+\begin{paste}{ugDomainsExamplesPageEmpty3}{ugDomainsExamplesPagePatch3}
+\pastebutton{ugDomainsExamplesPageEmpty3}{\showpaste}
+\tab{5}\spadcommand{elt(ks.(kind="d").(nargs="0"),name)\bound{q4 }\free{q1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch4}
+\begin{paste}{ugDomainsExamplesPageFull4}{ugDomainsExamplesPageEmpty4}
+\pastebutton{ugDomainsExamplesPageFull4}{\hidepaste}
+\tab{5}\spadcommand{mk := ks.(name="*Matrix*")\bound{q5 }\free{q1 }}
+\indentrel{3}begin{verbatim}
+   (4)  26
+                               Type: Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty4}
+\begin{paste}{ugDomainsExamplesPageEmpty4}{ugDomainsExamplesPagePatch4}
+\pastebutton{ugDomainsExamplesPageEmpty4}{\showpaste}
+\tab{5}\spadcommand{mk := ks.(name="*Matrix*")\bound{q5 }\free{q1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch5}
+\begin{paste}{ugDomainsExamplesPageFull5}{ugDomainsExamplesPageEmpty5}
+\pastebutton{ugDomainsExamplesPageFull5}{\hidepaste}
+\tab{5}\spadcommand{elt(mk.(kind="d"),name)\bound{q6 }\free{q5 }}
+\indentrel{3}begin{verbatim}
+   (5)
+   ["DenavitHartenbergMatrix",
+    "DirectProductMatrixModule", "IndexedMatrix",
+    "LieSquareMatrix", "Matrix", "RectangularMatrix",
+    "SquareMatrix", "ThreeDimensionalMatrix"]
+                                  Type: DataList String
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty5}
+\begin{paste}{ugDomainsExamplesPageEmpty5}{ugDomainsExamplesPagePatch5}
+\pastebutton{ugDomainsExamplesPageEmpty5}{\showpaste}
+\tab{5}\spadcommand{elt(mk.(kind="d"),name)\bound{q6 }\free{q5 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch6}
+\begin{paste}{ugDomainsExamplesPageFull6}{ugDomainsExamplesPageEmpty6}
+\pastebutton{ugDomainsExamplesPageFull6}{\hidepaste}
+\tab{5}\spadcommand{o := getDatabase "o"\bound{o1 }}
+\indentrel{3}begin{verbatim}
+   (6)  6315
+                               Type: Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty6}
+\begin{paste}{ugDomainsExamplesPageEmpty6}{ugDomainsExamplesPagePatch6}
+\pastebutton{ugDomainsExamplesPageEmpty6}{\showpaste}
+\tab{5}\spadcommand{o := getDatabase "o"\bound{o1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch7}
+\begin{paste}{ugDomainsExamplesPageFull7}{ugDomainsExamplesPageEmpty7}
+\pastebutton{ugDomainsExamplesPageFull7}{\hidepaste}
+\tab{5}\spadcommand{[o.(kind=k) for k in ["c","d","p"]]\free{o1 }}
+\indentrel{3}begin{verbatim}
+   (7)  [1646,2040,2629]
+                          Type: List Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty7}
+\begin{paste}{ugDomainsExamplesPageEmpty7}{ugDomainsExamplesPagePatch7}
+\pastebutton{ugDomainsExamplesPageEmpty7}{\showpaste}
+\tab{5}\spadcommand{[o.(kind=k) for k in ["c","d","p"]]\free{o1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch8}
+\begin{paste}{ugDomainsExamplesPageFull8}{ugDomainsExamplesPageEmpty8}
+\pastebutton{ugDomainsExamplesPageFull8}{\hidepaste}
+\tab{5}\spadcommand{eigens := o.(name="*eigen*")\bound{eigens }\free{o1 }}
+\indentrel{3}begin{verbatim}
+   (8)  4
+                               Type: Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty8}
+\begin{paste}{ugDomainsExamplesPageEmpty8}{ugDomainsExamplesPagePatch8}
+\pastebutton{ugDomainsExamplesPageEmpty8}{\showpaste}
+\tab{5}\spadcommand{eigens := o.(name="*eigen*")\bound{eigens }\free{o1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch9}
+\begin{paste}{ugDomainsExamplesPageFull9}{ugDomainsExamplesPageEmpty9}
+\pastebutton{ugDomainsExamplesPageFull9}{\hidepaste}
+\tab{5}\spadcommand{elt(eigens,name)\free{eigens }}
+\indentrel{3}begin{verbatim}
+   (9)
+   ["eigenMatrix", "eigenvalues", "eigenvector",
+    "eigenvectors"]
+                                  Type: DataList String
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty9}
+\begin{paste}{ugDomainsExamplesPageEmpty9}{ugDomainsExamplesPagePatch9}
+\pastebutton{ugDomainsExamplesPageEmpty9}{\showpaste}
+\tab{5}\spadcommand{elt(eigens,name)\free{eigens }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch10}
+\begin{paste}{ugDomainsExamplesPageFull10}{ugDomainsExamplesPageEmpty10}
+\pastebutton{ugDomainsExamplesPageFull10}{\hidepaste}
+\tab{5}\spadcommand{elt(elt(elt(eigens,origin),sort),unique)\free{eigens }}
+\indentrel{3}begin{verbatim}
+   (10)  ["EigenPackage","RadicalEigenPackage"]
+                                  Type: DataList String
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty10}
+\begin{paste}{ugDomainsExamplesPageEmpty10}{ugDomainsExamplesPagePatch10}
+\pastebutton{ugDomainsExamplesPageEmpty10}{\showpaste}
+\tab{5}\spadcommand{elt(elt(elt(eigens,origin),sort),unique)\free{eigens }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch11}
+\begin{paste}{ugDomainsExamplesPageFull11}{ugDomainsExamplesPageEmpty11}
+\pastebutton{ugDomainsExamplesPageFull11}{\hidepaste}
+\tab{5}\spadcommand{tm := o.(type="*Matrix*")\bound{x10 }\free{o1 }}
+\indentrel{3}begin{verbatim}
+   (11)  353
+                               Type: Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty11}
+\begin{paste}{ugDomainsExamplesPageEmpty11}{ugDomainsExamplesPagePatch11}
+\pastebutton{ugDomainsExamplesPageEmpty11}{\showpaste}
+\tab{5}\spadcommand{tm := o.(type="*Matrix*")\bound{x10 }\free{o1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch12}
+\begin{paste}{ugDomainsExamplesPageFull12}{ugDomainsExamplesPageEmpty12}
+\pastebutton{ugDomainsExamplesPageFull12}{\hidepaste}
+\tab{5}\spadcommand{fm := o.(origin="*Matrix*")\bound{x11 }\free{o1 }}
+\indentrel{3}begin{verbatim}
+   (12)  192
+                               Type: Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty12}
+\begin{paste}{ugDomainsExamplesPageEmpty12}{ugDomainsExamplesPagePatch12}
+\pastebutton{ugDomainsExamplesPageEmpty12}{\showpaste}
+\tab{5}\spadcommand{fm := o.(origin="*Matrix*")\bound{x11 }\free{o1 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch13}
+\begin{paste}{ugDomainsExamplesPageFull13}{ugDomainsExamplesPageEmpty13}
+\pastebutton{ugDomainsExamplesPageFull13}{\hidepaste}
+\tab{5}\spadcommand{fm-tm\bound{x12 }\free{x10 x11 }}
+\indentrel{3}begin{verbatim}
+   (13)  146
+                               Type: Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty13}
+\begin{paste}{ugDomainsExamplesPageEmpty13}{ugDomainsExamplesPagePatch13}
+\pastebutton{ugDomainsExamplesPageEmpty13}{\showpaste}
+\tab{5}\spadcommand{fm-tm\bound{x12 }\free{x10 x11 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch14}
+\begin{paste}{ugDomainsExamplesPageFull14}{ugDomainsExamplesPageEmpty14}
+\pastebutton{ugDomainsExamplesPageFull14}{\hidepaste}
+\tab{5}\spadcommand{fullDisplay(fm-\%)\bound{x13 }\free{x12 }}
+\indentrel{3}begin{verbatim}
+   ** : (Matrix(R),NonNegativeInteger)->Matrix(R)
+      from StorageEfficientMatrixOperations(R) (unexposed)
+   clearDenominator : (Matrix(Q))->Matrix(R)
+      from MatrixCommonDenominator(R,Q)
+   coerceP
+      : (Vector(Matrix(R)))->Vector(Matrix(Polynomial(R)))
+      from CoerceVectorMatrixPackage(R) (unexposed)
+   coerce
+      :
+      (Vector(Matrix(R)))->Vector(Matrix(Fraction(Polynom
+      ial(R))))
+      from CoerceVectorMatrixPackage(R) (unexposed)
+   coerce : (_$)->Matrix(R)
+      from RectangularMatrix(m,n,R) (unexposed)
+   coerce : (_$)->Matrix(R)
+      from SquareMatrix(ndim,R) (unexposed)
+   coerce : (Matrix(MachineFloat))->_$
+      from FortranMatrixCategory
+   commonDenominator : (Matrix(Q))->R
+      from MatrixCommonDenominator(R,Q)
+   copy! : (Matrix(R),Matrix(R))->Matrix(R)
+      from StorageEfficientMatrixOperations(R) (unexposed)
+   f01brf
+      :
+      (Integer,Integer,Integer,Integer,DoubleFloat,Boolea
+      n,Boolean,List(Boolean),Matrix(DoubleFloat),Matrix(
+      Integer),Matrix(Integer),Integer)->Result
+      from NagMatrixOperationsPackage
+   f01bsf
+      :
+      (Integer,Integer,Integer,Matrix(Integer),Matrix(Int
+      eger),Matrix(Integer),Matrix(Integer),Boolean,Doubl
+      eFloat,Boolean,Matrix(Integer),Matrix(DoubleFloat),
+      Integer)->Result
+      from NagMatrixOperationsPackage
+   f01maf
+      :
+      (Integer,Integer,Integer,Integer,List(Boolean),Matr
+      ix(DoubleFloat),Matrix(Integer),Matrix(Integer),Dou
+      bleFloat,DoubleFloat,Integer)->Result
+      from NagMatrixOperationsPackage
+   f01mcf
+      :
+      (Integer,Matrix(DoubleFloat),Integer,Matrix(Integer
+      ),Integer)->Result
+      from NagMatrixOperationsPackage
+   f01qcf
+      :
+      (Integer,Integer,Integer,Matrix(DoubleFloat),Intege
+      r)->Result
+      from NagMatrixOperationsPackage
+   f01qdf
+      :
+      (String,String,Integer,Integer,Matrix(DoubleFloat),
+      Integer,Matrix(DoubleFloat),Integer,Integer,Matrix(
+      DoubleFloat),Integer)->Result
+      from NagMatrixOperationsPackage
+   f01qef
+      :
+      (String,Integer,Integer,Integer,Integer,Matrix(Doub
+      leFloat),Matrix(DoubleFloat),Integer)->Result
+      from NagMatrixOperationsPackage
+   f01rcf
+      :
+      (Integer,Integer,Integer,Matrix(Complex(DoubleFloat
+      )),Integer)->Result
+      from NagMatrixOperationsPackage
+   f01rdf
+      :
+      (String,String,Integer,Integer,Matrix(Complex(Doubl
+      eFloat)),Integer,Matrix(Complex(DoubleFloat)),Integ
+      er,Integer,Matrix(Complex(DoubleFloat)),Integer)->R
+      esult
+      from NagMatrixOperationsPackage
+   f01ref
+      :
+      (String,Integer,Integer,Integer,Integer,Matrix(Comp
+      lex(DoubleFloat)),Matrix(Complex(DoubleFloat)),Inte
+      ger)->Result
+      from NagMatrixOperationsPackage
+   hasSolution? : (Matrix(F),Vector(F))->Boolean
+      from LinearSystemMatrixPackage1(F)
+   leftScalarTimes! : (Matrix(R),R,Matrix(R))->Matrix(R)
+      from StorageEfficientMatrixOperations(R) (unexposed)
+   minus! : (Matrix(R),Matrix(R))->Matrix(R)
+      from StorageEfficientMatrixOperations(R) (unexposed)
+   minus! : (Matrix(R),Matrix(R),Matrix(R))->Matrix(R)
+      from StorageEfficientMatrixOperations(R) (unexposed)
+   particularSolution
+      : (Matrix(F),Vector(F))->Union(Vector(F),"failed")
+      from LinearSystemMatrixPackage1(F)
+   plus! : (Matrix(R),Matrix(R),Matrix(R))->Matrix(R)
+      from StorageEfficientMatrixOperations(R) (unexposed)
+   power!
+      :
+      (Matrix(R),Matrix(R),Matrix(R),Matrix(R),NonNegativ
+      eInteger)->Matrix(R)
+      from StorageEfficientMatrixOperations(R) (unexposed)
+   rank : (Matrix(F),Vector(F))->NonNegativeInteger
+      from LinearSystemMatrixPackage1(F)
+   rectangularMatrix : (Matrix(R))->_$
+      from RectangularMatrix(m,n,R) (unexposed)
+   retractIfCan
+      : (Matrix(Expression(Float)))->Union(_$,"failed")
+      from FortranMatrixFunctionCategory
+   retractIfCan
+      : (Matrix(Expression(Integer)))->Union(_$,"failed")
+      from FortranMatrixFunctionCategory
+   retractIfCan
+      :
+      (Matrix(Fraction(Polynomial(Float))))->Union(_$,"fa
+      iled")
+      from FortranMatrixFunctionCategory
+   retractIfCan
+      :
+      (Matrix(Fraction(Polynomial(Integer))))->Union(_$,"
+      failed")
+      from FortranMatrixFunctionCategory
+   retractIfCan
+      : (Matrix(Polynomial(Float)))->Union(_$,"failed")
+      from FortranMatrixFunctionCategory
+   retractIfCan
+      : (Matrix(Polynomial(Integer)))->Union(_$,"failed")
+      from FortranMatrixFunctionCategory
+   retract : (Matrix(Expression(Float)))->_$
+      from FortranMatrixFunctionCategory
+   retract : (Matrix(Expression(Integer)))->_$
+      from FortranMatrixFunctionCategory
+   retract : (Matrix(Fraction(Polynomial(Float))))->_$
+      from FortranMatrixFunctionCategory
+   retract : (Matrix(Fraction(Polynomial(Integer))))->_$
+      from FortranMatrixFunctionCategory
+   retract : (Matrix(Polynomial(Float)))->_$
+      from FortranMatrixFunctionCategory
+   retract : (Matrix(Polynomial(Integer)))->_$
+      from FortranMatrixFunctionCategory
+   rightScalarTimes! : (Matrix(R),Matrix(R),R)->Matrix(R)
+      from StorageEfficientMatrixOperations(R) (unexposed)
+   solve
+      :
+      (Matrix(F),List(Vector(F)))->List(Record(particular
+      :Union(Vector(F),"failed"),basis:List(Vector(F))))
+      from LinearSystemMatrixPackage1(F)
+   solve
+      :
+      (Matrix(F),Vector(F))->Record(particular:Union(Vect
+      or(F),"failed"),basis:List(Vector(F)))
+      from LinearSystemMatrixPackage1(F)
+   splitDenominator
+      : (Matrix(Q))->Record(num:Matrix(R),den:R)
+      from MatrixCommonDenominator(R,Q)
+   squareMatrix : (Matrix(R))->_$
+      from SquareMatrix(ndim,R) (unexposed)
+   times! : (Matrix(R),Matrix(R),Matrix(R))->Matrix(R)
+      from StorageEfficientMatrixOperations(R) (unexposed)
+                                             Type: Void
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty14}
+\begin{paste}{ugDomainsExamplesPageEmpty14}{ugDomainsExamplesPagePatch14}
+\pastebutton{ugDomainsExamplesPageEmpty14}{\showpaste}
+\tab{5}\spadcommand{fullDisplay(fm-\%)\bound{x13 }\free{x12 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch15}
+\begin{paste}{ugDomainsExamplesPageFull15}{ugDomainsExamplesPageEmpty15}
+\pastebutton{ugDomainsExamplesPageFull15}{\hidepaste}
+\tab{5}\spadcommand{m := tm+fm\bound{x14 }\free{x10 x11 }}
+\indentrel{3}begin{verbatim}
+   (15)  499
+                               Type: Database IndexCard
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty15}
+\begin{paste}{ugDomainsExamplesPageEmpty15}{ugDomainsExamplesPagePatch15}
+\pastebutton{ugDomainsExamplesPageEmpty15}{\showpaste}
+\tab{5}\spadcommand{m := tm+fm\bound{x14 }\free{x10 x11 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch16}
+\begin{paste}{ugDomainsExamplesPageFull16}{ugDomainsExamplesPageEmpty16}
+\pastebutton{ugDomainsExamplesPageFull16}{\hidepaste}
+\tab{5}\spadcommand{fullDisplay(m, 202, 205)\free{x14 }}
+\indentrel{3}begin{verbatim}
+   elt : (_$,List(Integer),List(Integer))->_$
+      from MatrixCategory(R,Row,Col)
+   elt : (_$,Integer,Integer,R)->R
+      from RectangularMatrixCategory(m,n,R,Row,Col)
+   elt
+      :
+      (_$,NonNegativeInteger,NonNegativeInteger,NonNegati
+      veInteger)->R
+      from ThreeDimensionalMatrix(R)
+   eval
+      :
+      (Matrix(Expression(DoubleFloat)),List(Symbol),Vecto
+      r(Expression(DoubleFloat)))->Matrix(Expression(Doub
+      leFloat))
+      from d02AgentsPackage
+                                             Type: Void
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty16}
+\begin{paste}{ugDomainsExamplesPageEmpty16}{ugDomainsExamplesPagePatch16}
+\pastebutton{ugDomainsExamplesPageEmpty16}{\showpaste}
+\tab{5}\spadcommand{fullDisplay(m, 202, 205)\free{x14 }}
+\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPagePatch17}
+\begin{paste}{ugDomainsExamplesPageFull17}{ugDomainsExamplesPageEmpty17}
+\pastebutton{ugDomainsExamplesPageFull17}{\hidepaste}
+\tab{5}\spadcommand{elt(elt(elt(m,name),unique),count)\free{x14 }}
+\indentrel{3}begin{verbatim}
+   (17)  317
+                                  Type: PositiveInteger
+end{verbatim}
+\indentrel{-3}\end{paste}\end{patch}
+
+\begin{patch}{ugDomainsExamplesPageEmpty17}
+\begin{paste}{ugDomainsExamplesPageEmpty17}{ugDomainsExamplesPagePatch17}
+\pastebutton{ugDomainsExamplesPageEmpty17}{\showpaste}
+\tab{5}\spadcommand{elt(elt(elt(m,name),unique),count)\free{x14 }}
+\end{paste}\end{patch}
+\end{verbatim}
+
+\end{chunk}
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/diffeqex.input.pamphlet b/src/input/diffeqex.input.pamphlet
new file mode 100644
index 0000000..9f00f3a
--- /dev/null
+++ b/src/input/diffeqex.input.pamphlet
@@ -0,0 +1,840 @@
+\documentclass{article}
+\setlength{\textwidth}{400pt}
+\usepackage{axiom}
+\begin{document}
+\title{\$SPAD/src/input nonlinhomodiffeq.input}
+\author{jv1}
+\maketitle
+\begin{abstract}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f nonlinhomodiffeq.output
+)spool nonlinhomodiffeq.output
+)set message test on
+)set message auto off
+)clear all
+
+\end{chunk}
+Test 1: solve a simple nonlinear homogeneous differential equation
+\begin{chunk}{*}
+--S 1 of 59
+y := operator y
+--R 
+--R
+--R   (1)  y
+--R                                                          Type: BasicOperator
+--E 1
+
+--S 2 of 59
+deq1 := D(y(x),x) = 9-y(x)^2
+--R 
+--R
+--R         ,           2
+--R   (2)  y (x)= - y(x)  + 9
+--R
+--R                                            Type: Equation Expression Integer
+--E 2
+
+--S 3 of 59
+solve(deq1,y,x)
+--R 
+--R
+--R        - log(y(x) + 3) + log(y(x) - 3) + 6x
+--R   (3)  ------------------------------------
+--R                          6
+--R                                          Type: Union(Expression Integer,...)
+--E 3
+
+\end{chunk}
+Test 2: solve a class of simple nonlinear homogeneous differential equations
+\begin{chunk}{*}
+--S 4 of 59
+deq2a := D(y(x),x) = c - p*y(x)^2
+--R 
+--R
+--R         ,             2
+--R   (4)  y (x)= - p y(x)  + c
+--R
+--R                                            Type: Equation Expression Integer
+--E 4
+
+--S 5 of 59
+xpr2b := solve(deq2a,y,x)
+--R 
+--R
+--R                   2      +---+
+--R            (p y(x)  + c)\|c p  - 2c p y(x)       +---+
+--R        log(-------------------------------) + 2x\|c p
+--R                            2
+--R                      p y(x)  - c
+--R   (5)  -----------------------------------------------
+--R                              +---+
+--R                            2\|c p
+--R                                          Type: Union(Expression Integer,...)
+--E 5
+
+--S 6 of 59
+simplify(x-xpr2b)
+--R 
+--R
+--R                     2      +---+
+--R              (p y(x)  + c)\|c p  - 2c p y(x)
+--R          log(-------------------------------)
+--R                              2
+--R                        p y(x)  - c
+--R   (6)  - ------------------------------------
+--R                           +---+
+--R                         2\|c p
+--R                                                     Type: Expression Integer
+--E 6
+
+\end{chunk}
+Test 3; find general solutions for nonlinear homogeneous differential eqautions
+\begin{chunk}{*}
+--S 7 of 59
+f := operator f
+--R 
+--R
+--R   (7)  f
+--R                                                          Type: BasicOperator
+--E 7
+
+--S 8 of 59
+deq3 := D(y(x),x) = f(y(x))
+--R 
+--R
+--R         ,
+--R   (8)  y (x)= f(y(x))
+--R
+--R                                            Type: Equation Expression Integer
+--E 8
+
+--S 9 of 59
+solve(deq3,y,x)
+--R 
+--R
+--R           y(x)
+--R         ++       1
+--R   (9)   |      ----- d%P  - x
+--R        ++      f(%P)
+--R                                          Type: Union(Expression Integer,...)
+--E 9
+
+\end{chunk}
+Test 4: integration
+\begin{chunk}{*}
+--S 10 of 59
+integrate(1/(1-x^2),x)
+--R 
+--R
+--R         log(x + 1) - log(x - 1)
+--R   (10)  -----------------------
+--R                    2
+--R                                          Type: Union(Expression Integer,...)
+--E 10
+
+\end{chunk}
+Test 5: check result
+\begin{chunk}{*}
+--S 11 of 59
+xpr5 := (log(x+1)-log(x-1))/2
+--R 
+--R
+--R         log(x + 1) - log(x - 1)
+--R   (11)  -----------------------
+--R                    2
+--R                                                     Type: Expression Integer
+--E 11
+
+--S 12 of 59
+D(xpr5,x)
+--R 
+--R
+--R              1
+--R   (12)  - ------
+--R            2
+--R           x  - 1
+--R                                                     Type: Expression Integer
+--E 12
+
+\end{chunk}
+Test 6: check simplification
+\begin{chunk}{*}
+--S 13 of 59
+xpr6 := log(1+2/(x-1))/2
+--R 
+--R
+--R             x + 1
+--R         log(-----)
+--R             x - 1
+--R   (13)  ----------
+--R              2
+--R                                                     Type: Expression Integer
+--E 13
+
+--S 14 of 59
+D(xpr6,x)
+--R 
+--R
+--R              1
+--R   (14)  - ------
+--R            2
+--R           x  - 1
+--R                                                     Type: Expression Integer
+--E 14
+
+\end{chunk}
+Test 7: express y(x) as a function of x (replacing y(x) with z)
+\begin{chunk}{*}
+--S 15 of 59
+eq7a := x = (log(z+1)-log(z-1))/2
+--R 
+--R
+--R            log(z + 1) - log(z - 1)
+--R   (15)  x= -----------------------
+--R                       2
+--R                                            Type: Equation Expression Integer
+--E 15
+
+--S 16 of 59
+solve(eq7a,z)
+--R 
+--R
+--R                 - 2x
+--R             - %e     - 1
+--R   (16)  [z= ------------]
+--R                - 2x
+--R              %e     - 1
+--R                                       Type: List Equation Expression Integer
+--E 16
+
+--S 17 of 59
+xpr7b := (1+exp(-2*z))/(1-exp(-2*z))
+--R 
+--R
+--R             - 2z
+--R         - %e     - 1
+--R   (17)  ------------
+--R            - 2z
+--R          %e     - 1
+--R                                                     Type: Expression Integer
+--E 17
+
+--S 18 of 59
+simplify(xpr7b)
+--R 
+--R
+--R             - 2z
+--R         - %e     - 1
+--R   (18)  ------------
+--R            - 2z
+--R          %e     - 1
+--R                                                     Type: Expression Integer
+--E 18
+
+\end{chunk}
+Test 8 check simplified result
+\begin{chunk}{*}
+--S 19 of 59
+xpr8 := (1+exp(-2*x))/(1-exp(-2*x)) - (1+2/(exp(2*x)-1))
+--R 
+--R
+--R                    - 2x  2x
+--R               - 2%e    %e   + 2
+--R   (19)  -----------------------------
+--R            - 2x       2x     - 2x
+--R         (%e     - 1)%e   - %e     + 1
+--R                                                     Type: Expression Integer
+--E 19
+
+--S 20 of 59
+simplify(xpr8)
+--R 
+--R
+--R   (20)  0
+--R                                                     Type: Expression Integer
+--E 20
+
+\end{chunk}
+Test 9 check result by substitution in the DEQ
+\begin{chunk}{*}
+--S 21 of 59
+xpr9a := (1+2/(exp(2*x)-1))
+--R 
+--R
+--R           2x
+--R         %e   + 1
+--R   (21)  --------
+--R           2x
+--R         %e   - 1
+--R                                                     Type: Expression Integer
+--E 21
+
+--S 22 of 59
+xpr9b := D(xpr9a,x)
+--R 
+--R
+--R                     2x
+--R                  4%e
+--R   (22)  - -------------------
+--R              2x 2      2x
+--R           (%e  )  - 2%e   + 1
+--R                                                     Type: Expression Integer
+--E 22
+
+--S 23 of 59
+xpr9c := 1-(xpr9a)^2
+--R 
+--R
+--R                     2x
+--R                  4%e
+--R   (23)  - -------------------
+--R              2x 2      2x
+--R           (%e  )  - 2%e   + 1
+--R                                                     Type: Expression Integer
+--E 23
+
+\end{chunk}
+Test 10 finding the explicit solution for the deq in test 2
+\begin{chunk}{*}
+--S 24 of 59
+wcp := sqrt(c*p)
+--R 
+--R
+--R          +---+
+--R   (24)  \|c p
+--R                                                     Type: Expression Integer
+--E 24
+
+--S 25 of 59
+xpr10a := log(((p*z^2+c)*wcp-2*c*p*z)/(p*z^2-c))/(2*wcp)
+--R 
+--R
+--R                 2      +---+
+--R             (p z  + c)\|c p  - 2c p z
+--R         log(-------------------------)
+--R                         2
+--R                      p z  - c
+--R   (25)  ------------------------------
+--R                       +---+
+--R                     2\|c p
+--R                                                     Type: Expression Integer
+--E 25
+
+--S 26 of 59
+solve(x = xpr10a,z)
+--R 
+--R
+--R   (26)
+--R   [
+--R     z =
+--R                      +---+ 2              +---+
+--R                   2x\|c p       +---+  2x\|c p
+--R             (- (%e        )  + \|c p %e        )
+--R          *
+--R             ROOT
+--R                         +---+
+--R                      2x\|c p      +---+
+--R                  c %e         - c\|c p
+--R               /
+--R                            +---+ 3                 +---+ 2             +---+
+--R                         2x\|c p         +---+   2x\|c p          2  2x\|c p
+--R                    p (%e        )  - 3p\|c p (%e        )  + 3c p %e
+--R                  + 
+--R                         2 +---+
+--R                    - c p \|c p
+--R         + 
+--R           - c
+--R      /
+--R              +---+
+--R           2x\|c p     +---+
+--R         %e         - \|c p
+--R     ,
+--R
+--R     z =
+--R                    +---+ 2              +---+
+--R                 2x\|c p       +---+  2x\|c p
+--R             ((%e        )  - \|c p %e        )
+--R          *
+--R             ROOT
+--R                         +---+
+--R                      2x\|c p      +---+
+--R                  c %e         - c\|c p
+--R               /
+--R                            +---+ 3                 +---+ 2             +---+
+--R                         2x\|c p         +---+   2x\|c p          2  2x\|c p
+--R                    p (%e        )  - 3p\|c p (%e        )  + 3c p %e
+--R                  + 
+--R                         2 +---+
+--R                    - c p \|c p
+--R         + 
+--R           - c
+--R      /
+--R              +---+
+--R           2x\|c p     +---+
+--R         %e         - \|c p
+--R     ]
+--R                                       Type: List Equation Expression Integer
+--E 26
+
+--S 27 of 59
+eq10c := (p*z^2+c)*wcp - 2*c*p*z
+--R 
+--R
+--R             2      +---+
+--R   (27)  (p z  + c)\|c p  - 2c p z
+--R                                                     Type: Expression Integer
+--E 27
+
+--S 28 of 59
+solve(eq10c=0,z)
+--R 
+--R
+--R                c         c
+--R   (28)  [z= ------,z= ------]
+--R              +---+     +---+
+--R             \|c p     \|c p
+--R                                       Type: List Equation Expression Integer
+--E 28
+
+--S 29 of 59
+xpr10d := p*wcp*(z-wcp/p)^2
+--R 
+--R
+--R             2      +---+
+--R   (29)  (p z  + c)\|c p  - 2c p z
+--R                                                     Type: Expression Integer
+--E 29
+
+--S 30 of 59
+simplify(xpr10d/eq10c)
+--R 
+--R
+--R   (30)  1
+--R                                                     Type: Expression Integer
+--E 30
+
+--S 31 of 59
+xpr10e := (wcp/p)*(2/(1-exp(-2*wcp*x)/wcp)-1)
+--R 
+--R
+--R                        +---+
+--R            +---+  - 2x\|c p
+--R         - \|c p %e           - c p
+--R   (31)  --------------------------
+--R                   +---+
+--R              - 2x\|c p      +---+
+--R          p %e           - p\|c p
+--R                                                     Type: Expression Integer
+--E 31
+
+--S 32 of 59
+xpr10f := D(xpr10e,x)
+--R 
+--R
+--R                                      +---+
+--R                          +---+  - 2x\|c p
+--R                       4c\|c p %e
+--R   (32)  - -------------------------------------------
+--R                   +---+ 2                 +---+
+--R              - 2x\|c p        +---+  - 2x\|c p
+--R           (%e          )  - 2\|c p %e           + c p
+--R                                                     Type: Expression Integer
+--E 32
+
+--S 33 of 59
+xpr10g := c-p*(xpr10e)^2
+--R 
+--R
+--R                                      +---+
+--R                          +---+  - 2x\|c p
+--R                       4c\|c p %e
+--R   (33)  - -------------------------------------------
+--R                   +---+ 2                 +---+
+--R              - 2x\|c p        +---+  - 2x\|c p
+--R           (%e          )  - 2\|c p %e           + c p
+--R                                                     Type: Expression Integer
+--E 33
+
+--S 34 of 59
+simplify(xpr10f/xpr10g)
+--R 
+--R
+--R   (34)  1
+--R                                                     Type: Expression Integer
+--E 34
+
+\end{chunk}
+Test 11 non-homogeneous generalization: c as a linear function of x
+\begin{chunk}{*}
+--S 35 of 59
+deq11a := D(y(x),x) = a*x+b-p*y(x)^2
+--R 
+--R
+--R          ,             2
+--R   (35)  y (x)= - p y(x)  + a x + b
+--R
+--R                                            Type: Equation Expression Integer
+--E 35
+
+--S 36 of 59
+solve(deq11a,y,x)
+--R 
+--R
+--R   (36)  "failed"
+--R                                                    Type: Union("failed",...)
+--E 36
+
+\end{chunk}
+Test 12 non-homogeneous generalization: c as arbitrary function of x
+\begin{chunk}{*}
+--S 37 of 59
+c := operator c
+--R 
+--R
+--R   (37)  c
+--R                                                          Type: BasicOperator
+--E 37
+
+--S 38 of 59
+deq12a := D(y(x),x) = c(x) - p*y(x)^2
+--R 
+--R
+--R          ,             2
+--R   (38)  y (x)= - p y(x)  + c(x)
+--R
+--R                                            Type: Equation Expression Integer
+--E 38
+
+--S 39 of 59
+solve(deq12a,y,x)
+--R 
+--R
+--R   (39)  "failed"
+--R                                                    Type: Union("failed",...)
+--E 39
+
+\end{chunk}
+Test 13 guessing solution for deq12a
+\begin{chunk}{*}
+--S 40 of 59
+wpcx := sqrt(c(x))*sqrt(p)
+--R 
+--R
+--R          +-+ +----+
+--R   (40)  \|p \|c(x)
+--R                                                     Type: Expression Integer
+--E 40
+
+--S 41 of 59
+xpr13a := log((p*wpcx*(z-wpcx/p)^2)/(p*z^2-c(x)))/(2*wpcx)
+--R 
+--R
+--R                          2  +-+ +----+
+--R             (- c(x) - p z )\|p \|c(x)  + 2p z c(x)
+--R         log(--------------------------------------)
+--R                                     2
+--R                           c(x) - p z
+--R   (41)  -------------------------------------------
+--R                           +-+ +----+
+--R                         2\|p \|c(x)
+--R                                                     Type: Expression Integer
+--E 41
+
+--S 42 of 59
+xpr13b := (wpcx/p)*(2/(1-exp(-2*wpcx*x)/wpcx)-1)
+--R 
+--R
+--R                             +-+ +----+
+--R            +-+ +----+  - 2x\|p \|c(x)
+--R         - \|p \|c(x) %e                - p c(x)
+--R   (42)  ---------------------------------------
+--R                     +-+ +----+
+--R                - 2x\|p \|c(x)      +-+ +----+
+--R            p %e                - p\|p \|c(x)
+--R                                                     Type: Expression Integer
+--E 42
+
+--S 43 of 59
+xpr13c := D(xpr13b,x)
+--R 
+--R
+--R   (43)
+--R                          +-+ +----+ 2
+--R          +-+ ,      - 2x\|p \|c(x)
+--R       - \|p c (x)(%e               )
+--R
+--R     + 
+--R                                                                 +-+ +----+
+--R              +----+             +-+  ,             2 +-+   - 2x\|p \|c(x)
+--R       ((- 2p\|c(x)  - 4p x c(x)\|p )c (x) - 8p c(x) \|p )%e
+--R
+--R     + 
+--R              +-+ ,
+--R       p c(x)\|p c (x)
+--R
+--R  /
+--R                        +-+ +----+ 2                     +-+ +----+
+--R          +----+   - 2x\|p \|c(x)              +-+  - 2x\|p \|c(x)
+--R       2p\|c(x) (%e               )  - 4p c(x)\|p %e
+--R     + 
+--R         2     +----+
+--R       2p c(x)\|c(x)
+--R                                                     Type: Expression Integer
+--E 43
+
+--S 44 of 59
+xpr13d := c(x) - p*(xpr13b)^2
+--R 
+--R
+--R                                                +-+ +----+
+--R                               +-+ +----+  - 2x\|p \|c(x)
+--R                         4c(x)\|p \|c(x) %e
+--R   (44)  - -------------------------------------------------------------
+--R                   +-+ +----+ 2                      +-+ +----+
+--R              - 2x\|p \|c(x)        +-+ +----+  - 2x\|p \|c(x)
+--R           (%e               )  - 2\|p \|c(x) %e                + p c(x)
+--R                                                     Type: Expression Integer
+--E 44
+
+--S 45 of 59
+simplify(xpr13d/xpr13c)
+--R 
+--R
+--R   (45)
+--R                          +-+ +----+                          +-+ +----+
+--R         2    3 +-+  - 2x\|p \|c(x)       2    2 +----+  - 4x\|p \|c(x)
+--R       8p c(x) \|p %e                - 16p c(x) \|c(x) %e
+--R     + 
+--R                          +-+ +----+
+--R              2 +-+  - 6x\|p \|c(x)
+--R       8p c(x) \|p %e
+--R  /
+--R                                                                     +-+ +----+
+--R           2     +----+     2      2 +-+  ,        2    3 +-+   - 2x\|p \|c(x)
+--R       ((4p c(x)\|c(x)  + 4p x c(x) \|p )c (x) + 8p c(x) \|p )%e
+--R
+--R     + 
+--R               2       +----+           +-+  ,         2    2 +----+
+--R         ((- 8p x c(x)\|c(x)  - 4p c(x)\|p )c (x) - 16p c(x) \|c(x) )
+--R
+--R      *
+--R                +-+ +----+
+--R           - 4x\|p \|c(x)
+--R         %e
+--R     + 
+--R                                                 +-+ +----+
+--R                  +-+ ,             2 +-+   - 6x\|p \|c(x)
+--R       (4p x c(x)\|p c (x) + 8p c(x) \|p )%e
+--R
+--R     + 
+--R                       +-+ +----+
+--R        +-+ ,     - 8x\|p \|c(x)     2    2 +-+ ,
+--R       \|p c (x)%e                - p c(x) \|p c (x)
+--R
+--R                                                     Type: Expression Integer
+--E 45
+
+--S 46 of 59
+xpr13e := simplify(D((2/(1-exp(-2*wpcx*x)/wpcx)-1),x))
+--R 
+--R
+--R                                                                +-+ +----+
+--R                    +----+    +-+  ,              +----+   - 2x\|p \|c(x)
+--R             ((2p x\|c(x)  + \|p )c (x) + 4p c(x)\|c(x) )%e
+--R
+--R   (46)  ---------------------------------------------------------------------
+--R                         +-+ +----+                 +-+ +----+
+--R               +-+  - 2x\|p \|c(x)     +----+  - 4x\|p \|c(x)           +----+
+--R         2c(x)\|p %e                - \|c(x) %e                - p c(x)\|c(x)
+--R                                                     Type: Expression Integer
+--E 46
+
+--S 47 of 59
+xpr13f := (wpcx-exp(-2*wpcx*x))^2
+--R 
+--R
+--R                 +-+ +----+ 2                      +-+ +----+
+--R            - 2x\|p \|c(x)        +-+ +----+  - 2x\|p \|c(x)
+--R   (47)  (%e               )  - 2\|p \|c(x) %e                + p c(x)
+--R                                                     Type: Expression Integer
+--E 47
+
+--S 48 of 59
+xpr13g := simplify(((2*p*c(x)*x+wpcx)*D(c(x),x)+4*p*c(x)^2)/wpcx)
+--R 
+--R
+--R           +-+ +----+              ,             2
+--R         (\|p \|c(x)  + 2p x c(x))c (x) + 4p c(x)
+--R
+--R   (48)  -----------------------------------------
+--R                         +-+ +----+
+--R                        \|p \|c(x)
+--R                                                     Type: Expression Integer
+--E 48
+
+--S 49 of 59
+xpr13h := simplify((1+2*wpcx*x)*D(c(x),x)+4*wpcx*c(x))
+--R 
+--R
+--R             +-+ +----+      ,            +-+ +----+
+--R   (49)  (2x\|p \|c(x)  + 1)c (x) + 4c(x)\|p \|c(x)
+--R
+--R                                                     Type: Expression Integer
+--E 49
+
+--S 50 of 59
+simplify(xpr13h/xpr13g)
+--R 
+--R
+--R   (50)  1
+--R                                                     Type: Expression Integer
+--E 50
+
+--S 51 of 59
+xpr13i:=simplify((1/(wpcx-z)-1/(2*wpcx))*D(c(x),x)+_
+                 ((1+2*wpcx*x)*D(c(x),x)+4*wpcx*c(x))*z/(wpcx-z)^2)
+--R 
+--R
+--R   (51)
+--R                                2  +-+ +----+          2               3  ,
+--R       (((- 4p x z - p)c(x) + 3z )\|p \|c(x)  + (4p x z  - p z)c(x) - z )c (x)
+--R
+--R     + 
+--R                  2 +-+ +----+       2    2
+--R       - 8p z c(x) \|p \|c(x)  + 8p z c(x)
+--R  /
+--R                    3  +-+ +----+     2    2       2
+--R     (6p z c(x) + 2z )\|p \|c(x)  - 2p c(x)  - 6p z c(x)
+--R                                                     Type: Expression Integer
+--E 51
+
+--S 52 of 59
+w := operator w
+--R 
+--R
+--R   (52)  w
+--R                                                          Type: BasicOperator
+--E 52
+
+--S 53 of 59
+z := operator z
+--R 
+--R
+--R   (53)  z
+--R                                                          Type: BasicOperator
+--E 53
+
+--S 54 of 59
+simplify(D((2/(1-z(x)/w(x))-1)*c(x)/w(x),x))
+--R 
+--R
+--R   (54)
+--R                2 ,               2                           2  ,
+--R       2c(x)w(x) z (x) + (c(x)z(x)  - 2c(x)w(x)z(x) - c(x)w(x) )w (x)
+--R
+--R     + 
+--R                  2       3  ,
+--R       (- w(x)z(x)  + w(x) )c (x)
+--R
+--R  /
+--R         2    2        3           4
+--R     w(x) z(x)  - 2w(x) z(x) + w(x)
+--R                                                     Type: Expression Integer
+--E 54
+
+--S 55 of 59
+simplify((2*c(x)*w(x)^2*D(z(x),x)+(z(x)^2-2*w(x)*z(x)-w(x)^2)*c(x)*D(w(x),x)+_
+         (w(x)^3-w(x)*z(x)^2)*D(c(x),x))/(w(x)^2*(z(x)-w(x))^2))
+--R 
+--R
+--R   (55)
+--R                2 ,               2                           2  ,
+--R       2c(x)w(x) z (x) + (c(x)z(x)  - 2c(x)w(x)z(x) - c(x)w(x) )w (x)
+--R
+--R     + 
+--R                  2       3  ,
+--R       (- w(x)z(x)  + w(x) )c (x)
+--R
+--R  /
+--R         2    2        3           4
+--R     w(x) z(x)  - 2w(x) z(x) + w(x)
+--R                                                     Type: Expression Integer
+--E 55
+
+--S 56 of 59
+xpr13j:=simplify((2*c(x)*w(x)^2*w(x)*z(x)*(x/c(x)-1/2)+(z(x)^2-2*w(x)*z(x)-_
+                 w(x)^2)*c(x)*(-w(x)/(2*c(x)))+(w(x)^2-w(x)*z(x)^2)*D(c(x),x))_
+               /(w(x)^2*(z(x)-w(x))^2))
+--R 
+--R
+--R   (56)
+--R           2          ,          2                      2                    2
+--R   (- 2z(x)  + 2w(x))c (x) - z(x)  + ((- 2c(x) + 4x)w(x)  + 2w(x))z(x) + w(x)
+--R
+--R   ---------------------------------------------------------------------------
+--R                                  2        2            3
+--R                         2w(x)z(x)  - 4w(x) z(x) + 2w(x)
+--R                                                     Type: Expression Integer
+--E 56
+
+--S 57 of 59
+xpr13k:=simplify((1/(w(x)-z(x))-1/(2*w(x)))*D(c(x),x)+_
+                 ((1+2*w(x)*x)*D(c(x),x)+4*w(x)*c(x))*z(x)/(w(x)-z(x))^2)
+--R 
+--R
+--R                2           2                    2  ,               2
+--R         (- z(x)  + (4x w(x)  + 2w(x))z(x) + w(x) )c (x) + 8c(x)w(x) z(x)
+--R
+--R   (57)  ----------------------------------------------------------------
+--R                                  2        2            3
+--R                         2w(x)z(x)  - 4w(x) z(x) + 2w(x)
+--R                                                     Type: Expression Integer
+--E 57
+
+--S 58 of 59
+simplify(xpr13k/xpr13j)
+--R 
+--R
+--R   (58)
+--R            2             2                    2  ,               2
+--R       (z(x)  + (- 4x w(x)  - 2w(x))z(x) - w(x) )c (x) - 8c(x)w(x) z(x)
+--R
+--R   -----------------------------------------------------------------------
+--R         2          ,          2                    2                    2
+--R   (2z(x)  - 2w(x))c (x) + z(x)  + ((2c(x) - 4x)w(x)  - 2w(x))z(x) - w(x)
+--R
+--R                                                     Type: Expression Integer
+--E 58
+
+--S 59 of 59
+simplify(xpr13k-xpr13j)
+--R 
+--R
+--R   (59)
+--R            2           2                    2          ,          2
+--R       (z(x)  + (4x w(x)  + 2w(x))z(x) + w(x)  - 2w(x))c (x) + z(x)
+--R
+--R     + 
+--R                         2                    2
+--R       ((10c(x) - 4x)w(x)  - 2w(x))z(x) - w(x)
+--R  /
+--R              2        2            3
+--R     2w(x)z(x)  - 4w(x) z(x) + 2w(x)
+--R                                                     Type: Expression Integer
+--E 59
+
+)spool
+)lisp (bye)
+
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} http://axiom-wiki.newsynthesis.org/SandBox13
+\end{thebibliography}
+\end{document}
+
diff --git a/src/input/draw2dsf.data.pamphlet b/src/input/draw2dsf.data.pamphlet
index 9189f52..6bf09ec 100644
--- a/src/input/draw2dsf.data.pamphlet
+++ b/src/input/draw2dsf.data.pamphlet
@@ -10,7 +10,7 @@
 \eject
 \tableofcontents
 \eject
-<<*>>=
+\begin{chunk}{*}
   -2.4E-07 -0.00131248
 -2.395E-07 -0.00145311
  -2.39E-07 -0.000609357
@@ -1035,7 +1035,7 @@
  2.705E-07  0.0210547
   2.71E-07   0.020711
  2.715E-07  0.0217735
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/input/draw2dsf.input.pamphlet b/src/input/draw2dsf.input.pamphlet
index 5b51f61..7efc499 100644
--- a/src/input/draw2dsf.input.pamphlet
+++ b/src/input/draw2dsf.input.pamphlet
@@ -11,9 +11,9 @@
 \tableofcontents
 \eject
 \section{License}
-\begin{chunk}{license}
+\begin{verbatim}
 --Copyright The Numerical Algorithms Group Limited 1994.
-\end{chunk}
+\end{verbatim}
 \begin{chunk}{*}
 \getchunk{license}
 )clear all
@@ -41,10 +41,6 @@ pts:=readTheFile(axiom "/../../src/input/draw2dsf.data",1024);
 -- then we plot the points
 drawList(pts)
 
-
-
-
-
 \end{chunk}
 \eject
 \begin{thebibliography}{99}
diff --git a/src/input/ecfact.as.pamphlet b/src/input/ecfact.as.pamphlet
index 1fdb3ee..c78064b 100644
--- a/src/input/ecfact.as.pamphlet
+++ b/src/input/ecfact.as.pamphlet
@@ -11,7 +11,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 -- Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 -- All rights reserved.
 --
@@ -43,9 +43,9 @@
 -- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 -- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
+
 #include "axiom.as"
 #pile
 
@@ -275,7 +275,7 @@ EllipticCurveFactorization: with
             nfact
 
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/input/examples.input.pamphlet b/src/input/examples.input.pamphlet
new file mode 100644
index 0000000..93de39e
--- /dev/null
+++ b/src/input/examples.input.pamphlet
@@ -0,0 +1,223 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input examples.input}
+\author{Timothy Daly}
+\maketitle
+\begin{abstract}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f examples.output
+)spool examples.output
+)set message auto off
+)clear all
+ 
+\end{chunk}
+\section{Big Floats}
+Big Float numbers give extra precision when integer arithmetic is not
+indicated, yet single or double precision is not enough.
+\begin{chunk}{*}
+(a,b,c,d,e,p):BigFloat
+precisions 20
+p:=pi()
+\end{chunk}
+It is rumored that 
+\[e^{\pi*sqrt{163}}\]
+is an integer.
+\begin{chunk}{*}
+d:=sqrt(163)
+exp(p*d)
+precision 60
+p:-pi()
+d:=sqrt(163)
+exp(p*d)
+a:=sin(p/4)
+a*a
+b:=cos(p/4)
+c:=cos(p/12)
+16*c^4 - 16*c^2 + 1
+precision 1000
+pi()
+\end{chunk}
+\section{Matrix Computations}
+The following is a simple demonstration of matrix handling in the system.
+We first of all declare a matrix whose entries are polynomials in a..d.
+This is small and prints neatly. As we play with it, it grows until it
+can no longer be printed ``naturally'', whereupon the system switches
+to an ``item-at-a-time'' printing.
+\begin{chunk}{*}
+(m1,m2,m3): SM(2,MP([a,b,c,d],1))
+m1:=[[a,b],[c,d]]
+m2:=(m1+1)^2
+m3:=(m2+1)^2
+\end{chunk}
+We can also construct polynomials with matrix coefficients. Here again
+the printing is either ``whole matrix'' or ``item-at-a-time'' depending
+on the size of each individual matrix.
+\begin{chunk}{*}
+(p1,p2,p3):UP(x,SM(2,MP([a,b,c,d],1)))
+p1:=x*m1+m2
+p2:=p1*m1
+p3:=x*m1+m1
+p3^2
+p3^3
+p3^4
+p3:=x*m1 + transpose m1
+\end{chunk}
+Notice in the following that the coefficient of x is not divisible by 2.
+There is no reason why it should be, since polynomials over a matrix domain
+are not commutative, and the binomial theorem does not apply. The system
+in fact applies the binomial theorem to exponentiate when the 
+coefficients are commutative but not otherwise.
+\begin{chunk}{*}
+p3^2
+\end{chunk}
+We can also have matrices of matrices. Not how output may have to be nested.
+\begin{chunk}{*}
+(mm1,mm2):SM(2,(SM(2,MP([a,b,c,d],1))))
+mm1:=[[m1,m1],[m1,m1]]
+mm2:=[[m1,transpose m1],[m1,-m1]]
+mm2^2
+mm2^3
+\end{chunk}
+\section{Integer Factorization}
+This is a demonstration of the factoring of values of cyclotomic polynomials
+which are irreducible and therefore have values wich are relatively hard
+to factor
+\begin{chunk}{*}
+factor(3^17-1)
+factor(3^23-1)
+factor(3^31-1)
+factor(3^41-1)
+factor(3^53-1)
+factor(3^67-1)
+factor(111111111111111111111111)
+factor(11111111111111111111111111111111111111111111111)
+\end{chunk}
+\section{Polynomial Factorization}
+Axiom offers extensive polynomial factoring facilities. The following
+examples display some factorizations of univariate polynomials over
+finite fields and multivariate polynomials over the integers.
+
+We begin with Univariate Polynomials in x over GaloisField 2
+\begin{chunk}{*}
+u2:P[x]GF(2)
+u2:=x^51+1
+factor u2
+u2:=x^73+1
+factor u2
+\end{chunk}
+Now we have Univariate Polynomials in x over GaloisField 5
+\begin{chunk}{*}
+u5:P[x]GF5
+u5:=x^51+1
+factor u5
+\end{chunk}
+Now we look at Multivariate Polynomials in (x,y,z) over the Integers
+\begin{chunk}{*}
+f:=(x^2-y^2-z^2) * (x^2+y^2+z^2) * (z*y+3*z)
+factor f
+f:=(7*y*x^2 - 3*y^2 - 4*z^2) * (y^2 * x^2 + y^2 + z^2) * (x*z*y + 3*z)
+factor f
+f:=(x^2+y^4+z) * (x+y+z^5) * (x^2+y^4+z^3) * (x^2-y^2) * (y^2-z^2)
+factor f
+\end{chunk}
+\section{Factored Form Rings}
+Given an Algebra A over a Ring R, it is frequently more convenient
+to deal with factored expressions rather than ones multiplied out.
+In particular, denominators of fractions should usually be left factored.
+By defining the domain constructor FactoredFormRing A, one can take
+advantage of factored forms in calculation. Let's look at two
+examples, one with factored integers and another with factored P[t]I
+\begin{chunk}{*}
+i:=2^8 * 78^7 * 111^3 * 74534
+j:=2^4 * 45^3 * 162^6 * 774325
+(x,y,z):FFR I
+x:=factor i
+y:=factor j
+\end{chunk}
+Notice that the next answer stays factored
+\begin{chunk}{*}
+x*y
+\end{chunk}
+Notice that the answer is sorted by factor
+\begin{chunk}{*}
+y*x
+\end{chunk}
+Once again we will get a factored answer
+\begin{chunk}{*}
+x+y
+\end{chunk}
+Now we work in a Quotient Field
+\begin{chunk}{*}
+(r,s):QF FFR I
+\end{chunk}
+Note that there is cancellation because Integer is a Unique Factorization
+Domain.
+\begin{chunk}{*}
+r:=x/y
+s:=(x^9)/y
+FFactorial 250
+(u,v):P[x]I
+(f,g): FFR P[x]I
+u:=(x-1)^2 * (x+1)^2
+v:=x^5 + 5*x^3 - x
+HenselFactorize P[x]I
+f:=factor u
+q:=factor v
+f^67
+f*g
+(f+g)*f
+(n,m): QF FFR P[x]I
+n:=f/g
+m:=g/f
+n*m
+\end{chunk}
+\section{Simple Algebraic Extensions}
+The following example illustrates the calculation of the integral closure
+of a Simple Algebraic Extension (SAE) of a polynomial ring over the
+Rational Numbers. This is done by means of the Zassenhaus algorithm for
+integral closure as adopted by Barry Trager to polynomial rings. In all
+cases we deal with the affine coordinate ring of a plane algebraic curve.
+The examples come from the book Algebraic Curves by Fulton.
+
+First we define the original ring, display some of its properties, 
+calculate the integral closure, and display the same properties. (note,
+the actual calculation of the integral closure is not made until the
+first property of the integral closure is asked for. That's why there
+are relatively large timings for rank.)
+
+For each curve we display the rank (degress of the curve), the DiscMatrix,
+which is (trace(x[i]x[j]) where x[i] is a basis of the ring over P[x]RN.
+We then display the discriminant of the curve (which is the determinant
+of DiscMatrix).
+\begin{chunk}{*}
+f:=(x^2 + y^2)^2 + 3*x^2*y - y^3
+SS:=SAE(RN,x,y,f)
+rank$SS
+DiscMatrix$SS
+discriminant$SS
+TT:=IntegralClosure(P[x}RN,SAE(RN,x,y,f))
+rank$TT
+DiscMatrix$TT
+discriminant$TT
+\end{chunk}
+\section{Grobner Basis Computations}
+\begin{chunk}{*}
+\end{chunk}
+\begin{chunk}{*}
+
+)spool 
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/fresnel.input.pamphlet b/src/input/fresnel.input.pamphlet
new file mode 100644
index 0000000..0e7baeb
--- /dev/null
+++ b/src/input/fresnel.input.pamphlet
@@ -0,0 +1,172 @@
+\documentclass{article}
+\setlength{\textwidth}{400pt}
+\usepackage{axiom}
+\begin{document}
+\title{\$SPAD/src/input fresnel.input}
+\author{Timothy Daly}
+\maketitle
+\begin{abstract}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)spool fresnel.output
+)set message test on
+)set message auto off
+)clear all
+ 
+--S 1 of 4
+fC(z:FLOAT):FLOAT == 
+  z < 0 => error "fC not defined for negative argument"
+  z = 0 => 0
+  n := 10
+  sqrt((2/%pi)*z)*_
+   reduce(+,[(-1)^k*z^(2*k)/(factorial(2*k)*(4*k+1)) for k in 0..n])
+--E 1
+
+--S 2 of 4
+--[[z/100.0,fC(z/100.0)] for z in 1..5000]
+--E 2
+
+--S 3 of 4
+fS(z:FLOAT):FLOAT == 
+  z < 0 => error "fS not defined for negative argument"
+  z = 0 => 0
+  n := 10
+  sqrt((2/%pi)*z)*_
+   reduce(+,[(-1)^k*(z^(2*k+1))/(factorial(2*k+1)*(4*k+3)) for k in 0..n])
+--E 3
+
+--S 4 of 4
+--[[z/100.0,fS(z/100.0)] for z in 1..5000]
+--E 4
+
+--S
+pearceyC:=_
+[ [0.00, 0.0000000], [0.25, 0.3964561], [0.50, 0.5502472], [0.75, 0.6531193],_
+  [1.00, 0.7217059], [1.25, 0.762404],  [1.50, 0.779084],  [1.75, 0.774978],_
+  [2.00, 0.753302],  [2.25, 0.717446],  [2.50, 0.670986],  [2.75, 0.617615],_
+  [3.00, 0.561020],  [3.25, 0.504745],  [3.50, 0.452047],  [3.75, 0.405762],_
+  [4.00, 0.368193],  [4.25, 0.341021],  [4.50, 0.325249],  [4.75, 0.321186],_
+  [5.00, 0.328457],  [5.25, 0.346058],  [5.50, 0.372439],  [5.75, 0.405610],_
+  [6.00, 0.443274],  [6.25, 0.482966],  [6.50, 0.522202],  [6.75, 0.558620],_
+  [7.00, 0.590116],  [7.25, 0.614951],  [7.50, 0.631845],  [7.75, 0.640034],_
+  [8.00, 0.639301],  [8.25, 0.629969],  [8.50, 0.612868],  [8.75, 0.589271],_
+  [9.00, 0.560804],  [9.25, 0.529344],  [9.50, 0.496895],  [9.75, 0.465469],_
+ [10.00, 0.436964], [10.25, 0.413053], [10.50, 0.395087], [10.75, 0.384027],_
+ [11.00, 0.380390], [11.25, 0.384231], [11.50, 0.395149], [11.75, 0.412319],_
+ [12.00, 0.434555], [12.25, 0.460384], [12.50, 0.488146], [12.75, 0.516096],_
+ [13.00, 0.542511], [13.25, 0.565798], [13.50, 0.584583], [13.75, 0.597795],_
+ [14.00, 0.604721], [14.25, 0.605048], [14.50, 0.598871], [14.75, 0.586682],_
+ [15.00, 0.569335], [15.25, 0.547984], [15.50, 0.524009], [15.75, 0.498930],_
+ [16.00, 0.474310], [16.25, 0.451659], [16.50, 0.432343], [16.75, 0.417502],_
+ [17.00, 0.407985], [17.25, 0.404300], [17.50, 0.406589], [17.75, 0.414627],_
+ [18.00, 0.427837], [18.25, 0.445331], [18.50, 0.465972], [18.75, 0.488443],_
+ [19.00, 0.511332], [19.25, 0.533222], [19.50, 0.552774], [19.75, 0.568812],_
+ [20.00, 0.580389], [20.25, 0.586847], [20.50, 0.587849], [20.75, 0.583401],_
+ [21.00, 0.573842], [21.25, 0.559824], [21.50, 0.542266], [21.75, 0.522293],_
+ [22.00, 0.501167], [22.25, 0.480207], [22.50, 0.460707], [22.75, 0.443854],_
+ [23.00, 0.430662], [23.25, 0.421906], [23.50, 0.418080], [23.75, 0.419367],_
+ [24.00, 0.425635], [24.25, 0.436444], [24.50, 0.451078], [24.75, 0.468594],_
+ [25.00, 0.487880], [25.25, 0.507725], [25.50, 0.526896], [25.75, 0.544215],_
+ [26.00, 0.558626], [26.25, 0.569272], [26.50, 0.575524], [26.75, 0.577038],_
+ [27.00, 0.573766], [27.25, 0.565954], [27.50, 0.554127], [27.75, 0.539054],_
+ [28.00, 0.521695], [28.25, 0.503146], [28.50, 0.484566], [28.75, 0.467104],_
+ [29.00, 0.451832], [29.25, 0.439675], [29.50, 0.431359], [29.75, 0.427366],_
+ [30.00, 0.427908], [30.25, 0.432913], [30.50, 0.442034], [30.75, 0.454673],_
+ [31.00, 0.470019], [31.25, 0.487100], [31.50, 0.504844], [31.75, 0.522148],_
+ [32.00, 0.537944], [32.25, 0.551266], [32.50, 0.561307], [32.75, 0.567471],_
+ [33.00, 0.569407], [33.25, 0.567026], [33.50, 0.560508], [33.75, 0.550288],_
+ [34.00, 0.537026], [34.25, 0.521566], [34.50, 0.504881], [34.75, 0.488015],_
+ [35.00, 0.472012], [35.25, 0.457857], [35.50, 0.446415], [35.75, 0.438375],_
+ [36.00, 0.434212], [36.25, 0.434156], [36.50, 0.438182], [36.75, 0.446014],_
+ [37.00, 0.457140], [37.25, 0.470848], [37.50, 0.486272], [37.75, 0.502444],_
+ [38.00, 0.518359], [38.25, 0.533031], [38.50, 0.545560], [38.75, 0.555182],_
+ [39.00, 0.561321], [39.25, 0.563619], [39.50, 0.561957], [39.75, 0.556463],_
+ [40.00, 0.547503], [40.25, 0.535653], [40.50, 0.521665], [40.75, 0.506420],_
+ [41.00, 0.490870], [41.25, 0.475980], [41.50, 0.462670], [41.75, 0.451755],_
+ [42.00, 0.443897], [42.25, 0.439565], [42.50, 0.439006], [42.75, 0.442234],_
+ [43.00, 0.449025], [43.25, 0.458938], [43.50, 0.471341], [43.75, 0.485450],_
+ [44.00, 0.500382], [44.25, 0.515205], [44.50, 0.529002], [44.75, 0.540923],_
+ [45.00, 0.550239], [45.25, 0.556387], [45.50, 0.559004], [45.75, 0.557947],_
+ [46.00, 0.553301], [46.25, 0.545374], [46.50, 0.534676], [46.75, 0.521883],_
+ [47.00, 0.507802], [47.25, 0.493312], [47.50, 0.479313], [47.75, 0.466670],_
+ [48.00, 0.456160], [48.25, 0.448425], [48.50, 0.443930], [48.75, 0.442936],_
+ [49.00, 0.445486], [49.25, 0.451406], [49.50, 0.460311], [49.75, 0.471633],_
+ [50.00, 0.484658]]
+--E
+
+--S
+[[x.1,x.2,fC(x.1),fC(x.1)-x.2] for x in perceyC]
+--E
+
+--S
+pearceyS:=_
+[ [0.00, 0.0000000], [0.25, 0.0330970], [0.50, 0.0923658], [0.75, 0.1659294],_
+  [1.00, 0.2475583], [1.25, 0.332216],  [1.50, 0.415483],  [1.75, 0.493469],_
+  [2.00, 0.562849],  [2.25, 0.620944],  [2.50, 0.665787],  [2.75, 0.696174],_
+  [3.00, 0.711685],  [3.25, 0.712666],  [3.50, 0.700180],  [3.75, 0.675925],_
+  [4.00, 0.642119],  [4.25, 0.601362],  [4.50, 0.556489],  [4.75, 0.510408],_
+  [5.00, 0.465942],  [5.25, 0.425677],  [5.50, 0.391834],  [5.75, 0.366161],_
+  [6.00, 0.349852],  [6.25, 0.343503],  [6.50, 0.347099],  [6.75, 0.360040],_
+  [7.00, 0.381195],  [7.25, 0.408982],  [7.50, 0.441485],  [7.75, 0.476568],_
+  [8.00, 0.512010],  [8.25, 0.545638],  [8.50, 0.575457],  [8.75, 0.599758],_
+  [9.00, 0.617214],  [9.25, 0.626948],  [9.50, 0.628573],  [9.75, 0.622204],_
+ [10.00, 0.608436], [10.25, 0.588297], [10.50, 0.563176], [10.75, 0.534731],_
+ [11.00, 0.504784], [11.25, 0.475208], [11.50, 0.447809], [11.75, 0.424220],_
+ [12.00, 0.405810], [12.25, 0.393601], [12.50, 0.388217], [12.75, 0.389852],_
+ [13.00, 0.398268], [13.25, 0.412817], [13.50, 0.432489], [13.75, 0.455978],_
+ [14.00, 0.481770], [14.25, 0.508236], [14.50, 0.533736], [14.75, 0.556716],_
+ [15.00, 0.575803], [15.25, 0.589887], [15.50, 0.598183], [15.75, 0.600273],_
+ [16.00, 0.596126], [16.25, 0.586095], [16.50, 0.570890], [16.75, 0.551526],_
+ [17.00, 0.529259], [17.25, 0.505505], [17.50, 0.481750], [17.75, 0.459460],_
+ [18.00, 0.439989], [18.25, 0.424500], [18.50, 0.413893], [18.75, 0.408757],_
+ [19.00, 0.409336], [19.25, 0.415520], [19.50, 0.426853], [19.75, 0.442571],_
+ [20.00, 0.461646], [20.25, 0.482860], [20.50, 0.504875], [20.75, 0.526323],_
+ [21.00, 0.545885], [21.25, 0.562375], [21.50, 0.574811], [21.75, 0.582472],_
+ [22.00, 0.584939], [22.25, 0.582119], [22.50, 0.574246], [22.75, 0.561862],_
+ [23.00, 0.545782], [23.25, 0.527040], [23.50, 0.506824], [23.75, 0.486399],_
+ [24.00, 0.467029], [24.25, 0.449901], [24.50, 0.436051], [24.75, 0.426303],_
+ [25.00, 0.421217], [25.25, 0.421062], [25.50, 0.425797], [25.75, 0.435083],_
+ [26.00, 0.448300], [26.25, 0.464594], [26.50, 0.482927], [26.75, 0.502146],_
+ [27.00, 0.521054], [27.25, 0.538483], [27.50, 0.553369], [27.75, 0.564814],_
+ [28.00, 0.572142], [28.25, 0.574935], [28.50, 0.573060], [28.75, 0.566674],_
+ [29.00, 0.556212], [29.25, 0.542357], [29.50, 0.525995], [29.75, 0.508160],_
+ [30.00, 0.489969], [30.25, 0.472549], [30.50, 0.456974], [30.75, 0.444193],_
+ [31.00, 0.434973], [31.25, 0.429857], [31.50, 0.429129], [31.75, 0.432799],_
+ [32.00, 0.440605], [32.25, 0.452031], [32.50, 0.466343], [32.75, 0.482632],_
+ [33.00, 0.499873], [33.25, 0.516992], [33.50, 0.532930], [33.75, 0.546708],_
+ [34.00, 0.557490], [34.25, 0.564629], [34.50, 0.567709], [34.75, 0.566570],_
+ [35.00, 0.561313], [35.25, 0.552293], [35.50, 0.540094], [35.75, 0.525495],_
+ [36.00, 0.509417], [36.25, 0.492866], [36.50, 0.476871], [36.75, 0.462420],_
+ [37.00, 0.450396], [37.25, 0.441528], [37.50, 0.436345], [37.75, 0.435144],_
+ [38.00, 0.437971], [38.25, 0.444626], [38.50, 0.454670], [38.75, 0.467461],_
+ [39.00, 0.482187], [39.25, 0.497924], [39.50, 0.513690], [39.75, 0.528507],_
+ [40.00, 0.541464], [40.25, 0.551768], [40.50, 0.558799], [40.75, 0.562140],_
+ [41.00, 0.561608], [41.25, 0.557258], [41.50, 0.549384], [41.75, 0.538494],_
+ [42.00, 0.525282], [42.25, 0.510580], [42.50, 0.495309], [42.75, 0.480418],_
+ [43.00, 0.466829], [43.25, 0.455375], [43.50, 0.446755], [43.75, 0.441487],_
+ [44.00, 0.439878], [44.25, 0.442007], [44.50, 0.447720], [44.75, 0.456645],_
+ [45.00, 0.468209], [45.25, 0.481681], [45.50, 0.496215], [45.75, 0.510904],_
+ [46.00, 0.524837], [46.25, 0.537153], [46.50, 0.547099], [46.75, 0.554070],_
+ [47.00, 0.557650], [47.25, 0.557635], [47.50, 0.554044], [47.75, 0.547120],_
+ [48.00, 0.537309], [48.25, 0.525234], [48.50, 0.511657], [48.75, 0.497426],_
+ [49.00, 0.483428], [49.25, 0.470529], [49.50, 0.459523], [49.75, 0.451084],_
+ [50.00, 0.445722]]
+--E
+
+--S
+[[x.1,x.2,fS(x.1),fS(x.1)-x.2] for x in perceyS]
+--E
+
+)spool 
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/groebner.input.pamphlet b/src/input/groebner.input.pamphlet
new file mode 100644
index 0000000..83bfa54
--- /dev/null
+++ b/src/input/groebner.input.pamphlet
@@ -0,0 +1,538 @@
+\documentclass{article}
+\setlength{\textwidth}{400pt}
+\usepackage{axiom}
+\begin{document}
+\title{\$SPAD/src/input groebner.input}
+\author{Timothy Daly}
+\maketitle
+\begin{abstract}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{verbatim}
+Bernd Sturmfels
+\verb|math.berkeley.edu/~bernd|
+
+-- Gaussian Elimination
+eq1:= 2*x + 3*y + 4*z - 5
+eq2:= 3*x + 4*y + 5*z - 2
+-- x-z+14
+-- y+z-11
+
+-- Euclidean Algorithm
+eq3:= x^4 - 12*x^3 + 49*x^2 -78*x + 4
+eq4:= x^5 - 5*x^4 + 5*x^3 + 5*x^2 - 6*x
+gcd(eq3,eq4) -- x^2 - 3*x + 2
+
+-- Simplex Algorithm
+-- Minimize the linear function
+--  P+N+D+Q (pennies, nickels, dimes, quarters)
+-- (minimize number of coins used)
+-- subject to
+--  P>0, N>0, D>0, Q>0 and 
+--  P + 5N + 10D +25Q = 117
+-- solution is
+-- (P,N,D,Q) = (0,0,0,4.68) (117/25 == 4.68)
+
+-- Require that the unknowns be non-negative integers
+-- (P,N,D,Q) = (2,1,1,4)
+
+-- Represent a collection C of coins by a polynomial
+-- p^a * n^b * d^c * q^d in the variables p,n,d,q
+-- e.g.2 pennies and 4 dimes is represented as p^2d^4
+
+-- input set F = {p^5-n, p^10-d, p^25-q}
+-- (e.g. 5 pennies = 1 nickel,
+--      10 pennies = 1 dime,
+--      25 pennies = 1 quarter
+-- output set G = {p^5-n, n^2-d, d^2*n-q d^3-n*q}
+-- expresses a more useful set of replacement rules
+-- e.g. the expression d^3 - n*q translates to
+-- replace 3 dimes with a nickel and a quarter
+-- (e.g.  5 pennies can be replaced by a nickel)
+
+-- (objective function: we are trying to minimize the number of coins )
+-- Given a collection C of coins, we use rules encoded by G to transform
+-- (in any order) C into a set of coins C with equal monetary value but
+-- smaller number of elements
+-- Example: (solving the prior problem):
+-- p^17*n^10*d^5 -> (use p^5-n rule changing 32 coins to 28 coins)
+--  p^12*n^11*d^5 -> ... p^2*n^13*d^5 ->
+-- p^2*n^12*d^3*q -> p^2*n^13*d*q^2 .... -> p^2*n*d*q^4
+
+-- Integer Programming and Groebner Bases
+-- So Groebner Bases give a method of transforming an integer programming
+-- feasible solution using local moves into a global optimum
+-- So using the groebner basis is analogous to running the
+-- Simplex Algorithm
+
+-- To set up Groebner Basis:
+-- Let K be a field, e.g. the rational numbers Q, the real numbers R,
+-- or the complex numbers C
+-- Form the set of polynomials K[x_1,..x_n] in variables x_1,...,x_n
+-- with coefficients in K
+-- this set K[x_1,...,x_n] is a ring (also called a polynomial ring)
+-- it is also a K-vector space
+-- for short, we may also write K[x] = K[x_1,...,x_n]
+
+-- Given F, a finite set of polynomials in K[x_1,...,x_n]
+-- The ideal generated by F (an ideal for a polynomial acts like a
+-- prime number for integers) is:
+-- <F>={p_1*f_1+\cdots+p_r*f_r | f_i \in F, p_i \in K[x]}
+-- These are all the linear polynomial combinations of elements in F
+
+-- Every ideal in the polynomial ring over the field K where 
+-- K[x_1,...,x_n] is finitely generated.
+-- This means that any ideal I has the form <F> for a finite set of 
+-- polynomials F so we can write down the ideal.
+-- Note: for the 1-variable ring K[x_1], every ideal is principal;
+-- that means that I is generated by 1 polynomial. This is the
+-- Euclidean Algorithm
+
+-- For each example we have seen <F> = <G> In each example, the
+-- polynomial consequences for each set generate the same ideal (that
+-- is, the ideal generated by them are the same), but the modified
+-- generators divulge more structure
+
+-- IDEAL EQUALITY
+-- How can you check that two ideals, the ideal generated by <F>
+-- and the ideal generated by <G> are equal?
+-- We need to show that each element of F is in <G> and each element
+-- of G is in <F>.
+-- So for the coins we need to show that d^3-n*q (in G) can be written in
+-- terms of elements in F:
+-- d^3-n*q = n*(p^25-q) - (p^20+p^10*d+d^2)*(p^10-d) + p^25*(p^5-n)
+-- where p^25-q, p^10-d, and p^5-n are in <F> and d^3-n*q is in <G>
+
+-- FIRST, to write a polynomial we choose an order of the monomials
+-- this is called a "term order"
+-- A term order (or monomial order) is a total order "<" on the set of
+-- monomials x^a = (x_1^a_1)*(x_2^a_2)*...*(x_n^a_n) such that
+-- (1) it is multiplicative: x^a < x^b => x^(a+c) < x^(b+c)
+--     that is, multiplying by x^c does not change the order
+-- (2) the constant monomial is smallest, that is,
+--     1 < x^a for all a in N^n\{0}
+
+-- there are many term orders
+-- in one variable, there is only one order 1 < x < x^2 < x^3 < ....
+-- for n=2, we have
+-- Degree Lexicographic order (by total degree)
+-- 1 < x_1 < x_2 < x_1^2 < x_1*x_2 < x_2^2 < x_1^3 < x_1^2*x_2 < ...
+-- Purely Lexicographic order (ignore total degree)
+-- 1 < x_1 < x_1^2 < x_x^3 < ... < x_2 < x_1*x_2 < x_1^2*x_x < ...
+
+-- SECOND, we look at the initial monomials
+-- Every polynomial f \in K[x_1,...x_n] has an initial monomial 
+-- (depending on the order) denoted by "in<"(f)
+-- Example: if n=2 and our term order is degree-lex, then
+-- "in<"(x_1 + 2*x_1^3*x_2^2 + 5*x_2^4 + 3*x_1^2*x_2^3) = 3*x_1^2*x_2^3
+-- thus 3*x_1^2*x_2^3 is the "initial monomial"
+
+-- "INITIAL IDEAL"
+-- We can apply the same idea to compute the "Intial Ideal"
+-- For every ideal I of K[x_1,...,x_n], we can form the initial ideal 
+-- of I (with respect to "in<") generated by all initial monomials of 
+-- polynomials in I
+-- "in<"(I) = < "in<"(f) | f in in I >
+
+-- THIRD welook at infinitely many polynomials in the ideal 
+-- and look at its initial monomial of each polynomial.
+-- This set of monomials form the "Initial Ideal"
+
+-- DEFINING GROEBNER BASES
+-- A finite subset G of an ideal I is a Groebner basis of this ideal 
+-- (with respect to the term order "in<") if there is a finite set
+--      { "in<"(g) | g is in G} }
+-- generates "in<"(I), the initial ideal. This exists because Hilbert
+-- proved that EVERY ideal is finitely generated.
+
+-- Note that the word "basis" USUALLY implies a minimum generating set
+-- but there is no minimality... we could call it a 
+-- "groebner generating set"
+
+-- There are many, many groebner generating set. We can throw in 
+-- additional polynomials and still have a groebner basis. We would 
+-- like the smallest groebner basis, called a "reduced basis"
+
+-- "REDUCED GROEBNER BASIS"
+-- A groebner basis is called "reduced" if it satisfies the additional
+-- properties:
+-- (1) For each g in G, the coefficients of "in<"(g) equals 1 (monic)
+-- (2) The set {"in<"(g) | g is in G} minimally generates "in<"(I)
+--     that is, nothing can be removed
+-- (3) No trailing term of any g in G lies inside "in<"(I), that is,
+--     if there is a polynomial in the basis with a non-leading 
+--     term that is a multiple of another leading term then this 
+--     trailing polynomial can be resolved.
+
+-- "AUTO-REDUCTION" -- take any Groebner basis to a reduced 
+--                     Groebner basis
+
+-- "UNIQUENESS of Reduced Groebner Bases
+-- The reduced groebner basis is unique.
+-- Theorem: Fixing an ideal I containing K[x_1,...,x_n] and a term 
+-- order "in<", there is a unique reduced Groebner basis for I
+
+-- Question: can groebner basis be applied to cylindrical decomposition?
+
+
+-- FINDING GROEBNER BASES
+
+-- Let F be a subset of Q[x_1,...,x_n], that is, polynomials with 
+-- rational coefficients. There is a unique reduced Groebner basis 
+-- G for F.
+
+-- Algorithm: F -> G
+-- Given by Bruno Buchberger (1965) in his dissertation.
+-- His advisor was Wolfgang Groebner
+-- Applications to Algebraic Geometry
+
+-- ALGEBRAIC GEOMETRY
+-- Algebraic geometry is the study of solution sets of polynomials 
+-- in several unknowns.
+
+-- If F is a set of polynomials, the variety of F over the complex 
+-- numbers C equals:
+-- V(F) = {(z_1,...,z_n) \in C^n | f(z_1,...,z_n)=0 for all f \in F}
+-- this is called a "variety", the set of common zeros. We choose the
+-- vectors (z_1,...,z_n) which are zeros of the polynomials.
+--
+-- Note: The variety depends only on the ideal of F. That is, V(F)=V(<F>).
+-- This is true because if a polynomial is a linear combination of other
+-- polynomials then it vanishes whenever the linear combination vanishes.
+-- So if G is a Groebner basis for F, the V(G)=V(F). 
+--
+-- We work in the complex numbers so that the fundamental theorem of 
+-- algebra, that every nth degree polynomial has n roots, which is not 
+-- true in general over the reals.
+--
+
+-- Hilbert's Nullstellensatz (Theorem of zeros)
+-- Theorem (David Hilbert, 1890):
+-- V(F) is empty if and only if G={1},
+-- that is, the set of equations have no common zeros.
+-- so if the groebner basis is {1} then there are no solutions.
+
+-- Easy direction: if G={1} then V(F)=V(G)={}
+-- Example: F={x^2+x*y-10, x^3+x*y^2-25, x^4+x*y^3-70}
+-- What about the variety? Are there any points that satisfies all of 
+-- them? Here, G={1}, so there are no common solutions. 
+-- Geometrically these three equations represent 3 curves in the plane
+-- and since G={1} they have NO point in common.
+
+-- Replacing 25 by 26 we get:
+-- F={x^2+x*y-10, x^3+x*y^2-26, x^4+x*y^3-70}
+-- and thus G={x-2,y-3} and 
+-- so the "variety of G" is V(F)=V(G)={(2,3)}
+
+-- STANDARD MONOMIALS
+-- What do we do if the Groebner basis is complicated?
+-- Suppose I is a subset of Q[x_1,...,x_n] an ideal, "in<" is the term 
+-- order. A monomial x^a = x_1^a_1*x_2^a_2*...*x_n^a^n is "STANDARD" 
+-- for our ideal with respect to the given term order if and only if 
+-- it is not in the initial ideal, that is, x^a \notin "in<"(I)
+-- Another way to say this is that the monomial x^a is not a multiple 
+-- of any of the leading terms of the initial monomials
+
+-- Example: If n=3 and "in<"(I)= < x_1^3, x_2^4, x_3^5 >, the number 
+-- of "standard monomials" is 60 (= 3*4*5). So the standard monomials 
+-- are of the form x_1^a*x_2^b*x_3^c where a is at most 2, b is at 
+-- most 3, and c is at most 4.
+
+-- If "in<"(I) = < x_1^3, x_2^4, x_1*x_3^4 >, then the number of 
+-- "standard monomials" is infinite. That is, there are infinitely 
+-- many monomials NOT divisible by any of the three leading terms. 
+-- For instance, every power of x_3 is standard, 1, x_3, x_3^2, ...
+-- are all standard monomials. This is an infinite set.
+
+-- If the Groebner basis is 1 G={1} then every monomial is divisible 
+-- by 1, and is in the initial ideal.
+-- Thus, there are no standard monomials. So the variety is empty 
+-- if there are no standard monomials.
+
+-- If there ARE standard monomials then the number and structure of 
+-- these standard monomials gives us important information about 
+-- the ideal.
+
+-- FUNDAMENTAL THEOREM OF ALGEBRA
+-- A univariate polynomial of degree D always has D complex solutions.
+-- There is a natural generalization to the set of polynomials in any
+-- number of variables
+-- Theorem: The number of standard monomials equals #V(I), where the
+-- zeros are counted with multiplicity.
+
+--
+-- Look at the Ideal I and choose a term order.
+-- Calculate a Groebner basis
+-- Look at the set of initial monomials
+-- and consider the set of standard monomials,
+-- those monomials not divisible by elements of the leading terms.
+
+-- The fundamental theorem states:
+-- The number of standard monomials is equal to the complex variety
+-- defined by the system of equations where zeros have multiplicity,
+-- just like the one-dimensional case. In the 1-dimensional case,
+-- the ideal will be a single polynomial of degree d and it will be
+-- the reduced groebner basis and there are exactly d standard 
+-- monomials: {1, x, x^2, x^3, ..., x^(d-1)}
+
+-- Example: F={x^2*z-y, x^2+x*y-y*z, x*z^2+x*z-x}
+-- Then, using purely lex order x > y > z, we get the reduced groebner 
+-- basis G={ x^2-y*z-y, x*y+y, x*z^2+x*z-x, y*z^2+y*z-y, y^2-y*z }
+-- The leading terms generate the initial ideal. these are:
+-- {x^2, x*y, x*z^2, y*z^2, y^2}
+-- Every power of z is standard, that is,
+-- {1, z, z^2, ...} are standard since these does not occur as a 
+-- multiple of the leading terms so #V(F) is infinite.
+-- So "the cardinality of the complex variety V(F) is infinte"
+
+-- Replacing x^2*z-y with x^2*z-1 in F, we get
+-- G={ x-2*y*z+2*y+z, y^2+y*z+y-z-3/2, z^2+z-1 }
+-- The leading terms generate the initial ideal. these are:
+--  the leading terms are {x, y^2, z^2}
+-- so that #V(F)=4 because they are {1, y, z, y*z}
+-- so there are 4 complex points.
+
+-- There are 3 algebraic surfaces in algebraic space.
+-- Example 1 has infinite intersections, Example 2 intersects in 
+-- 4 points.
+
+-- "DIMENSION OF A VARIETY"
+-- Calculating the dimension of a variety
+-- Think of dimension intuitively: points have dimension 0, curves 
+-- have dimension 1, a surface has dimension 2, ...
+
+-- Again given a system of polynomial equations
+-- Calculate the groebner basis with respect to some term order
+-- Inspect the set of standard monomials.
+-- From that set we can read off the dimension of the variety as:
+
+-- Let S be a subset of {x_1,...,x_n} have maximal cardinality with 
+-- the property that no monomial in the variables in S appears in 
+-- "in<"(I) That is, the set S has the property that every monomial 
+-- that you can form out of the variables in S is standard. Every 
+-- monomial S is a standard monomial. 
+-- Theorem: dim V(I)=#S ("The dimension of the variety is equal to the
+-- cardinality of the largest subset of the variables with the property
+-- that every monomial in those variables is standard.
+
+-- An ideal in a ring plays the same role that a normal subgroup plays 
+-- in a group. It allows you to form quotient structures. If you have a
+-- normal subgroup in a group you can form a quotient group, likewise if
+-- you have an ideal in a ring you can form a quotient ring.
+
+-- RESIDUE RING
+-- Theorem: The set of standard monomials is a Q-vector-space-basis
+-- for the residue ring Q[x_1,...,x_n]/I. That is, modulo the ideal I,
+-- every polynomial f can be written uniquely as a Q-linear
+-- combination of standard monomials.
+
+-- The polynomial ring, and every quotient thereof by an ideal, is a
+-- Q vector space. If I is the zero ideal, if you have the entire
+-- polynomial ring, then the set of ALL monomials forms a Q vector 
+-- space basis.
+
+-- Take a residue ring modulo an ideal then the vector space becomes 
+-- smaller and you have to take a subset of monomials as a basis and 
+-- that subset will be the standard monomials with respect to any 
+-- term order that you and I agree upon.
+
+-- What does it mean to be a basis for a vector space? I means 2 
+-- things: It means you generate and you are linearly independent.
+-- To be a basis means that every vector can be written uniquely
+-- as a Q-linear combination of the basis elements.
+-- Equivalently, if we work modulo an ideal I, every polynomial f can 
+-- be written uniquely as a Q-linear combination of standard monomials.
+
+-- Given f, there is an algorithm (the division algorithm or the
+-- normal form algorithm) that produces this representation (called
+-- the normal form of f) in Q[x_1,...,x_n]
+
+-- Favorite Groebner Basis
+-- We are working in a polynomial ring of m x n variables
+-- Let G be the set of d x d subdeterminants of an m x n matrix of 
+-- unknowns. The polynomials will be homogeneous of degree d having 
+-- n! terms. There are m choose d ways of picking the rows
+-- and n choose d ways of picking the columns making the 
+-- subdeterminants.
+
+-- There is a term order which makes G the reduced Groebner basis 
+-- for the ideal it generates.
+
+-- Why do we care? What does it mean for an n x m matrix to have all of
+-- its d x d subdeterminants vanish? That means that the matrix has rank
+-- of at most d-1. So given this example,
+
+-- Example: d = n = 3, m = 4
+-- dim V(G) = 12 - 2 = 10
+-- "in<"(I) = 
+--   <x_11*x_22*x_33, x_11*x_22*x_43, x_11*x_32*x_43, x_21*x_32*x_43>
+-- S = {x_11,...,x_43}\{x_11,x_21}
+
+-- This ideal is the so-called "determinental variety" consisting of 
+-- all m x n matrices of of rank at most d-1. Lets look at the 
+-- dimension of the variety.
+
+-- If we take a 4x3 matrix then m is 4 and d is 3. So we are
+-- considering the 4 3x3 determinants we can form out of such a matrix
+-- of unknowns.  Now the way the term order works is that the leading
+-- monomials, the initial monomials, are the diagonal products. The
+-- 3x3 determinant has 6 terms, one for each permutation of the 3
+-- element set, and the leading term will be the main diagonal term
+-- and the groebner basis property says that the initial ideal will be
+-- generated by the first leading term, x_11*x_22*x33. The second
+-- determinant will be x_11*x_22*x_43, and so on.
+
+-- How many degrees of freedom do you have in forming a 4x3 matrix of
+-- rank at most 2? What is the dimension of this variety? Well,
+-- standard monomials tell you the answer. We are supposed to pick a
+-- subset S of maximal cardinality in our 12 variables with the
+-- property that every monomial in that subset is standard. The
+-- largest cardinality that you can pick is 10. So if we take the 10
+-- variables ( ,x_12,x_13,x_14, ,x_22,x_23,x_24, x_31,x_32,x_33,x_34,
+-- x_41,x_42,x_43,x_44) Every monomial that you can pick is
+-- standard. It does not lie in this initial ideal and we conclude
+-- that the dimension of this variety is 10.
+
+-- Suppose somebody gives you a set of polynomials such as the 4 3x3
+-- determinants that we just saw. And you also have a term order so
+-- you know which term is the leading term.  How can you test whether
+-- a set G of polynomials is a groebner basis?  Can you believe that
+-- those 4 3x3 determinants really are a groebner basis?  You need to
+-- be convinced that the leading monomial of any polynomial in the
+-- ideal, any of the possibly infinite polynomials of the ideal, is a
+-- multiple of one of the leading terms.
+
+-- TESTING FOR GROEBNER BASIS
+
+-- Question: How to test whether a finite set G of polynomials is a
+-- Groebner basis?  Take g,g' polynomials in G and form an
+-- Subtraction-polynomial (S-polynomial) which is the stingiest linear
+-- combination that knocks out the leading term, that is, form the
+-- S-polynomial m'g-mg' where m,m' are monomials of lowest degree such
+-- that m'*"in<"(g)=m*"in<"(g') with respect to the agreed-upon term
+-- order.  g has a leading term and g' has a leading term. We want to
+-- find the smallest (lowest degree) linear combination that kills the
+-- leading term.
+
+-- Theorem (Buchberger's Criterion): G is a Groebner basis if and only
+-- if every S-polynomial formed by the pairs g,g' from G has normal
+-- form zero with respect to G.  Normal form was the process of
+-- replacing monomials that are multiples of current leading monomials
+-- by lower stuff running the division algorithm with respect to the
+-- suspected groebner basis.
+
+-- So if you form any pair, lets say G has 5 polynomials, and you look
+-- at all 10 possible pairs and calculate the S-pair, reduce with
+-- respect to the suspected groebner basis and if all 10 reductions
+-- come out with the zero polynomial then you can be certain that the
+-- given polynomials were a groebner basis. This criterion is the
+-- basic building block of Buchberger's algorithm. The algorithm which
+-- we have used all along for transforming the input set F into the
+-- output set G that is supposed to form a groebner basis.
+
+-- BUCHBERGER'S ALGORITHM
+-- INPUT:  Finite list F of polynomials in Q[x_1,...,x_n] and 
+--         term order
+-- OUTPUT: The unique reduced Groebner basis G for the ideal generated 
+--         by <F> with respect to that term order
+-- STEP 1: Apply Buchberger's Criterion to chack whether F is a Groebner 
+--         basis
+--         A) Look at every pair
+--         B) Form the S-pair
+--         C) Reduce it
+--         D) if every reduction has a zero result then it is a 
+--            groebner basis
+-- STEP 2: If "yes", the F is a Groebner basis. Go to step 4
+-- STEP 3: If "no", we found p=normalf(m'g-mg') to be nonzero. 
+--         Buchberger's Criterion returns a "witness" for the fact 
+--         that we did not have a Groebner basis, p.
+--         Set F=F union {p} and go to Step 1
+-- STEP 4: Replace F by the reduced Groebner basis G (apply 
+--         "autoreduction") and output G. Autoreduction takes any 
+--         Groebner basis and replaces it with the corresponding 
+--         unique groebner basis. To autoreduce:
+--         A) Make all polynomials monic (leading coefficients are 1)
+--         B) Throw out unnecessary polynomials
+--         C) take trailing terms and replace them by non-trailing 
+--            terms
+--
+-- This algorithm terminates in a finite number of steps and outputs 
+-- G, a unique reduced Groebner basis with respect to the chosen 
+-- term order.
+
+-- Why must this terminate?
+-- Every ideal in a polynomial ring is finitely generated.
+-- Thus, Every initial monomial ideal is finitely generated.
+-- Hilbert's Basis Theorem implies that there is no infinite ascending 
+-- chain of ideals. Let F={f_1,...,f_d}. Each nonzero p=normalf(m'f-mf') 
+-- gives a strict inclusion: 
+-- <"in<"(f_1),...,"in<"(f_d)> is a subset of 
+-- <"in<"(f_1),...,"in<"(f_d),"in<"(p)>. This chain of strictly 
+-- contained ideals must terminate.
+
+-- Suppose Buchberger's Criterion returns a witness, a non-zero
+-- polynomial p which is a normal form not zero. If p is a nonzero
+-- normal form then each term in p has the property that it is not in
+-- the current initial ideal, none of the terms in p is divisible by a
+-- current inital monomial.  That means that if we take the initial
+-- term of p and throw it into the current initial ideal that the
+-- initial ideal gets strictly larger.  Hilbert proved that there is a
+-- finite chain. Therefore we terminate.
+
+-- AN EXAMPLE
+
+-- Take the case of polynomials in 1 variable. If you input 1 variable
+-- polynomials then the algorithm simulates the euclidean algorithm.
+-- Example: n=1, F={x^2+3*x-4, x^3-5*x+4}
+-- The initial ideal is {x^2, x^3}. There are infinitely many 
+-- polynomials in the ideal. Is it the case that the two polynomials 
+-- form a groebner basis?
+-- Is it the case that every polynomial in the ideal, of which there are
+-- infinitely many, its initial ideal is a multiple of x^2 or x^3
+
+-- STEP 1: form the S-poly
+--  Here we try to form a subtraction polynomial to knock out the leading
+--  term which happens if we multiply x^2 by x and x^3 by 1 and subtract:
+--         x*(x^2+3*x-4) - 1*(x^3-5*x+4) = 3*x^2+x-4
+--  3*x^2+x-4 is not yet in normal form with respect to the current
+--  polynomials. Indeed, the 3*x^2 is a multiple of the x^2 leading term
+--  so we can multiply the x^2 leading term polynomial by 3 and 
+--  subtract and the  result of that is the normal form
+--  That is, we compute 
+--    (3*x^2+x-4) - 3*(x^2+3*x-4) = -8*x+8
+--  and that result IS a normal form, but nonzero.
+--         It has a nonzero normal form p = -8*x+8
+-- Therefore F is not a Groebner basis
+
+-- STEP 3: We enlarge F by adding p
+--         The new set F union {p} is a groebner basis
+-- so we have
+--  F = {x^2+3*x-4, x^3-5*x+4, -8*x+8}
+--  Notice that the new leading monomial -8*x is not a multiple of either
+--  x^2 or x^3
+
+-- On the next iteration the new polynomial will pass the test and we
+-- end up going to step 4.
+
+-- STEP 4: Take the current non-reduced Groebner basis consisting of
+--           3 polynomials: {x^2+3*x-4, x^3-5*x+4, -8*x+8}
+--           and replace it by the corresponding unique reduced 
+--           groebner basis.
+--       The reduced Groebner basis is G={x-1}
+
+-- SUMMARY
+-- Groebner bases and the Buchberger algorithm are fundamental in 
+-- algebra Applications include optimization, coding, robotics, 
+-- statistics, etc
+-- Advanced algebraic geometry algorithms: elimination theory, 
+--   computing cohomology, resulution of singularities, etc.
+-- Structures that generalize polynomials also apply, such as
+--   noncommutative polynomials, differential operators
+
+\end{verbatim}
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/hilbert.as.pamphlet b/src/input/hilbert.as.pamphlet
index 1fade2f..802e653 100644
--- a/src/input/hilbert.as.pamphlet
+++ b/src/input/hilbert.as.pamphlet
@@ -11,7 +11,7 @@
 \tableofcontents
 \eject
 \section{Hilbert input tests}
-<<input>>=
+\begin{chunk}{input}
 )compile hilbert.as
 mon1 := monom(4,0,0,0)
 mon2:= monom(3,3,0,0)
@@ -34,9 +34,9 @@ idD:=[monom(2,0,0,0),monom(1,1,0,0),monom(1,0,1,0),monom(1,0,0,1),_
  monom(0,3,0,0),monom(0,2,1,0)]^4;
 #idD
 Hilbert idD
-@
+\end{chunk}
 \section{License}
-<<license>>=
+\begin{verbatim}
 -- Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 -- All rights reserved.
 --
@@ -68,11 +68,10 @@ Hilbert idD
 -- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 -- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
 
-<<input>>
+\getchunk{input}
 
 #include "axiom.as"
 #pile
@@ -311,9 +310,7 @@ MonomialIdealPackage: with
 	  odd? n => i * (i*i)^shift(n, -1)
 	  (i*i)^shift(n,-1)
 
-
-
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/input/lyapunov.input.pamphlet b/src/input/lyapunov.input.pamphlet
new file mode 100644
index 0000000..4531f5f
--- /dev/null
+++ b/src/input/lyapunov.input.pamphlet
@@ -0,0 +1,445 @@
+\documentclass{article}
+\usepackage{amsmath}
+\usepackage{amssymb}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input lyapunov.input}
+\author{Maya Ramakrishnan and Timothy Daly}
+\maketitle
+\begin{abstract}
+Maya Ramakrishnan
+``A Gentle Introduction to Lyapunov Functions''
+ORSUM August 2003\\
+\verb|www.or.ms.unimelb.edu.au/handouts/lyaptalk.1.pdf|
+
+Zoran Gaji\'c and Muhammad Tahir Javed Qureshi
+``Lyapunov Matrix Equation in System Stability and Control''
+ISBN 0-486-46668-X Dover 2008
+\end{abstract}
+\eject
+\tableofcontents
+\section{Motivation}
+Often systems can be represented or modelled using systems of
+differential equations. Given a system, questions which naturally
+arise include
+\begin{itemize}
+\item What are the equilibrium points or orbits
+\item Is the system stable?
+\item What are the dominant features of the portrait of the orbit?
+\end{itemize}
+
+Some common applications of Lyapunov functions are in the area of
+\begin{itemize}
+\item assessing the importance of non-linear terms in stability and
+instability
+\item estimating the domain of attraction of an equilibrium point
+\item designing control laws that guarantee global asymptotic stability
+\end{itemize}
+
+\noindent
+Rate control for communications networks {\sl Kelly et al} (1998)
+\begin{itemize}
+\item Proposed optimization framework
+\begin{itemize}
+\item Larger system problem decomposed into a User and a Network problem
+\end{itemize}
+\item Proposed rate control algorithm
+\begin{itemize}
+\item System of differential equations in the rate/capacity allocated
+to each user
+\end{itemize}
+\item With the correct choice of Lyapunov function, it is shown that:
+\begin{itemize}
+\item the found equilibrium point is asymptotically stable
+\item the lyapunov function closely approximates the Network's 
+optimization problem.
+\end{itemize}
+\end{itemize}
+
+Lyapunov equations have been used to determine the stability of a:
+\begin{itemize}
+\item F-8 aircraft
+\item steam power system
+\item voltage regulator
+\item synchronous machine connected to an infinite bus
+\item distillation column
+\item catalytic cracker,
+\item gas absorber
+\item industrial reactor
+\item L-1011 fighter aircraft
+\item hydroturbine governors
+\item DC motor
+\item magnetic tape control system
+\item one-dimensional diffusion process
+\item aircraft under wind disturbances
+\item chemical plant
+\end{itemize}
+
+\section{Definitions}
+
+\subsection{The continuous case}
+The general differential Lyapunov matrix equation corresponding to
+time varying continuous systems is given by 
+\begin{equation}
+A^T(t)P(t) + P(t)A(t) + Q(t) = \dot{P}(t), \quad P(t_0) = P_0
+\end{equation}
+where 
+$P(t)$ is an $n \times n$ solution matrix of unknown entries,
+$A(t)$ is an $n \times n$ system matrix, and
+$Q(t)$ is an $n \times n$ symmetric matrix chosen according to
+computational convenience and in most cases is positive semi-definite.
+If the system is time invariant then $\dot{P} = 0$ (steady state) so
+that the above equation becomes the algebraic Lyapunov matrix equation
+\[
+A^T P + P A + Q = 0
+\]
+The necessary and sufficient condition for the existence of a
+unique solution is that no two eigenvalues of $A$ add up to 0.
+\[
+\lambda_i + \lambda_j \ne 0, \quad i,j = 1,2,\ldots,n
+\]
+This condition is satisfied if $A$ is an asymptotically stable matrix
+in the continuous-time domain (all eigenvalues of $A$ are located
+in the closed left half-plane).
+
+\subsubsection{Continuous, time-invariant linear systems}
+Assuming a continous, time-invariant linear system of the form
+\[
+\dot{x}(t) = Ax(t), \quad x(t_0) = x_0
+\]
+where $x(t) \in \mathbb{R}^n$ is the system state vector and
+$A \in \mathbb{R}^{n \times x}$ is the system matrix.
+\noindent
+{\bf Definition 2.1.1:}
+The linear system is stable if all eigenvalues of the matrix $A$
+are in the closed left half of the complex plane and those on the
+imaginary axis are distinct roots of the minimal polynomial of $A$.
+
+\noindent
+{\bf Definition 2.1.2:}
+The linear system is asymptotically stable if all eigenvalues of $A$
+are in the open left half of the complex plane.
+
+
+\subsection{The discrete case}
+The corresponding Lyapunov matrix difference equation for discrete-time
+varying systems is given by
+\[
+A^T(k)P(k)A(k) + Q(k) = P(k+1), \quad P(k_0) = P_0
+\]
+and for time invariant discrete systems at the steady state,
+$(P(k+1) = P(k) = P)$, we have the discrete version of the
+algebraic Lyapunov matrix equation
+\[
+A^T P A + Q = P
+\]
+The condition for the existence of a unique solution is that
+no two eigenvalues have a product equal to 1.
+\[
+\lambda_i\lambda_j \ne 1,\quad i,j = 1,2,\ldots,n
+\]
+This conditions is satisfied if $A$ is asymptotically stable in the
+discrete-time domain (all eigenvalues of $A$ are strictly inside of
+the unit circle.
+
+\subsection{Basic Definitions}
+Consider the system 
+\[ \dot{x} = f(x) \]
+where $f$ is not necessarily a linear function of $x$.
+
+\noindent
+{\bf Definition 2.3.1:} 
+If $\overline{x}$ is an equilibrium point of the system,
+then $f(\overline{x}) = 0$.
+
+A system is stable at an equilibrium point if it responds to small changes
+from the equilibrium with only small changes in its subsequent states.
+
+\noindent
+{\bf Definition 2.3.2:} 
+An equilibrium point, $\overline{x}$, is said to be
+stable if for all $\epsilon > 0$, there exists a $\delta = \delta(\epsilon)$,
+such that
+\[
+\vert x(t_0) - \overline{x}\vert < \delta \implies
+\vert x(t) - \overline{x}\vert < \epsilon, \quad\forall t > t_0
+\]
+
+Note that a system can be locally stable.
+
+\noindent
+{\bf Definition 2.3.3:} 
+We say that $\overline{x}$ is asymptotically stable if it
+is stable and
+\[ 
+\vert x(t) - \overline{x}\vert \rightarrow 0,
+ {\rm\ as\ } t \rightarrow \infty
+\]
+
+\noindent
+{\bf Definition 2.3.4:} 
+A system is neutrally stable at $\overline{x}$
+if it is stable at $\overline{x}$, but not asymptotically stable.
+
+\noindent
+{\bf Definition 2.3.5:} 
+A system that is not stable at $\overline{x}$ is
+said to be unstable.
+\section{Methods of determining stability}
+\subsection{Indirect Method}
+Consider the system above, where $f$ is not a linear function.
+Using Taylor expanson, we have
+\[
+\dot{x} = Ax + g(x)
+\]
+where $A$ is the Jacobian matrix of $f(x)$ evaluated at $\overline{x}$, i.e.
+\[
+A = \left.\frac{\partial f}{\partial x}\right|_{\overline{x}}
+\]
+and $g(x)$ is a function of the higher order terms.
+
+The resulting linear system is given by
+\[
+\dot{x} = Ax
+\]
+
+The stability of the system can then be assessed using the following rules:
+\begin{enumerate}
+\item The equilibrium point is asymptotically stable if the linearised
+system is strictly stable.
+\item The equilibrium point is unstable if the linearised system is
+strictly unstable.
+\item If the linearised system is marginally stable, then we cannot
+conclude anything from the linear approximation.
+\end{enumerate}
+
+Consider rule 1. If all the eigenvalues of $A$ have negative real parts,
+then the linearised system is asymptotically stable. Problems include
+\begin{itemize}
+\item If some of the eigenvalues are zero, we cannot conclude anything
+about the system.
+\item The linear approximation is valid when the initial conditions are
+close to $\overline{x}$, however how ``close'' is close?
+\end{itemize}
+\subsection{Direct Method}
+Stability is determined by observing how a scalar function of the state
+variables of the system changes in time.
+
+Consider the system 
+\[
+\dot{x} = f(x)
+\]
+where
+\begin{itemize}
+\item $\overline{x}$ is the equilibrium point of the system;
+\item $f \in C^1(R)$, where $C^k(R)$ defines the class of all continuous
+functions on region $R$ with $k$th derivatives also continuous on $R$; and
+\item $x(t^0) = x^0$, $x^0 \in R$
+\end{itemize}
+
+\noindent
+{\bf Definition 2.3.6:} 
+Let $V(x)$ be a real valued scalar function
+belonging to $C^0(S)$ for some region $S$ of $R^n$. Suppose
+$V(\overline{x}) = 0$. Then,
+\begin{enumerate}
+\item $V$ is positive definite on $S$ if $V(x) > 0$, for $x \ne \overline{x}$
+\item $V$ is negative definite on $S$ if $V(x) < 0$, for $x \ne \overline{x}$
+\item If the equalities are not strict, then $V$ is considered positive and
+negative semi-definite respectively.
+\end{enumerate}
+
+\noindent
+{\bf Definition 2.3.7:} 
+Let $V(x)$ be a real valued scalar function belonging to
+$C^1(R)$. The total derivative along the solution curves of 
+$\dot{x} = f(x)$, i.e. with respect to the orbits
+$x = x(t,x^0)$ is
+\[
+\begin{array}{rcl}
+\dot{V} & = & \displaystyle\frac{d}{dt}V(x(t,x^0))\\
+        & = & \displaystyle\sum_{i=1}^n \frac{\partial V}{\partial{x_i}}
+\dot{x_i}(t,x^0)\\
+        & = & \displaystyle\nabla V(x)^T f(x)
+\end{array}
+\]
+
+\noindent
+{\bf Theorem 1:} Suppose there exists a function $V(x)$ with the following
+properties:
+\begin{enumerate}
+\item $V(\overline{x}) = 0$
+\item $V(x)$ is positive definite for $x \ne \overline{x}$
+\item $\dot{V}(x)$ is negative semi-definite along trajectories of 
+$\dot{x} = f(x)$
+\end{enumerate}
+Then $V(x)$ is known as a Lyapunov function and $\overline{x}$ is stable.
+Note that if $\dot{V}(x)$ is negative definite, then $\overline{x}$ is
+asymptotically stable.
+
+\noindent
+{\bf Proof:} This proof will assume that the equilibrium point
+$\overline{x} = 0$ for simplicity. It is easily extendable to the
+situation where this is not the case.
+
+Let
+\begin{itemize}
+\item $J_\epsilon$ be the interior of a sphere of radius $\epsilon$, whose
+center is at point 0. Further, assume $\epsilon$ is such that 
+$J_\epsilon$ lies in the region $R$.
+\item $S_\epsilon$ be the spherical surface of the sphere
+\end{itemize}
+Let $V$ be a function that satisfies properties 1-3 from above.
+
+Since $V(x)$ is continuous and positive on the closed, bounded surface
+$S_\epsilon$, by the Minimum Value Theorem for continuous functions,
+$V(x)$ has a minimum on $S_\epsilon$. Suppose this minimum is $L$. Then:
+\[
+0 < L \le V(x),\quad\forall x \in S_\epsilon
+\]
+Since $V(x)$ is continous and has value 0 at $x=0$, there exists an
+open ball $J_delta$ centered at 0, which lies entirely inside
+$J_\epsilon$.
+\begin{itemize}
+\item Choose $\delta$ such that $V(x) < L, \forall x \in J_\delta$
+\end{itemize}
+
+Let $x^0$ be a point inside $J_\delta$.
+\begin{itemize}
+\item Consider the trajectory $x(x^0,t)$ coming from point $x^0$ and
+satisfying the system of differential equations under consideration
+\item Assume the trajectory travels outside the sphere $S_\epsilon$.
+\end{itemize}
+Since the trajectory is continuous, it will intersect the boundary
+$S_\epsilon$ at some point $x^*$. 
+Recall that $V(x)$ satisfies the property
+\[
+\dot{V} = \sum_{i=0}^n \frac{\partial V}{\partial x_i}\dot{x}_i \le 0
+\]
+Hence, the function $V$ is not increasing along the trajectory of
+$x(x^0,t)$. This means that
+\[
+V(x^*) \le V(x^0) < L
+\]
+
+But $x^* \in S_\epsilon$ and therefore $L \le V(x^*)$. This yields a
+contradiction. Hence as $t$ increases, the trajectory $x(x^0,t)$
+does not pass outside the limits of $S_\epsilon$.
+
+We have shown, with $\overline{x}=0$, that for all $\epsilon > 0$, 
+there exists $\delta(\epsilon) > 0$, such that
+\[
+\vert x^0 - \overline{x}\vert < \delta \implies
+\vert x(x^0,t) - \overline{x} \vert < \epsilon
+\]
+as required.
+\section{Example}
+Consider the system
+\[
+\begin{array}{rcl}
+\dot{x}_1 & = & -x_2 + ax_1x_2^2\\
+\dot{x}_2 & = & x_1 - bx_1^2x_2
+\end{array}
+\]
+where $a \ne b$.
+
+To find the equilibrium points, set
+\[
+\begin{array}{rcl}
+\dot{x}_1 & = & 0\\
+\dot{x}_2 & = & 0
+\end{array}
+\]
+
+Basic manipulation shows that the equilibrium point is 
+$\overline{x}_1 = \overline{x}_2 = 0$
+
+Using the indirect method, consider the linearised system:
+\[
+\begin{array}{rcl}
+\dot{x}_1 & = & Ax\\
+\left[
+\begin{array}{c}
+\dot{x}_1\\
+\dot{x}_2
+\end{array}
+\right] & = &
+\left[
+\begin{array}{cc}
+0 & -1\\
+1 & 0
+\end{array}
+\right] 
+\left[
+\begin{array}{c}
+x_1\\
+x_2
+\end{array}
+\right] 
+\end{array}
+\]
+
+Next consider the eigenvalues, $\lambda$, of $A$
+\[
+det\left[
+\begin{array}{cc}
+-\lambda & -1\\
+1 & \lambda
+\end{array}
+\right] = \lambda^2 + 1 = 0
+\]
+
+Recall for asymptotic stability of the linear system, we require
+all eigenvalues to have negative real parts. The roots of this 
+equation are purely imaginary. Hence we cannot draw any conclusions
+about the stability of the non-linear system.
+
+Now using the direct method, consider the function
+\[
+V(x) = \frac{1}{2}x_1^2 + \frac{1}{2}x_2^2
+\]
+
+Clearly, $V(\overline{x}) = 0$. When $x \ne \overline{x}$, $V(x) > 0$, i.e.
+it is positive definite.
+
+Next consider $\dot{V}(x)$:
+\[
+\begin{array}{rcl}
+\dot{V}(x) & = & x_1\dot{x}_1 + x_2\dot{x}_2\\
+&=& x_1(-x_2 + ax_1x_2^2) + x_2(x_1 - bx_1^2x_2)\\
+&=&x_1^2x_2^2(a-b)
+\end{array}
+\]
+For asymptotic stability, we need $\dot{V}(x)$ to be negative definite.
+Hence, if $a<b$, then the system is asymptotically stable.
+
+\section{Conclusion}
+Lyapunov functions are useful in assessing the stability of systems and
+in particular the method can be used
+\begin{itemize}
+\item for exploring non-linear systems
+\item for time varying systems, i.e. $\dot{x} = f(x,t)$
+\item to determine both stability and asymptotic stability
+\end{itemize}
+
+The drawback is that to find a Lyapunov function is often more of an 
+art than a science.
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f lyapunov.output
+)spool lyapunov.output
+)set message test on
+)set message auto off
+)clear all
+ 
+)spool 
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/matops.as.pamphlet b/src/input/matops.as.pamphlet
index 56342ce..5052206 100644
--- a/src/input/matops.as.pamphlet
+++ b/src/input/matops.as.pamphlet
@@ -11,14 +11,14 @@
 \tableofcontents
 \eject
 \section{Input tests}
-<<input>>=
+\begin{chunk}{input}
 )compile matops.as
 )show MatrixOpSym
 matrix [[3,4],[5,6]]
 symmetricPart %
-@
+\end{chunk}
 \section{License}
-<<license>>=
+\begin{verbatim}
 -- Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 -- All rights reserved.
 --
@@ -50,9 +50,9 @@ symmetricPart %
 -- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 -- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
+
 #include "axiom.as"
 #pile
 
@@ -72,7 +72,7 @@ MatrixOpSym(R:Field) : MOD  == Definition where
         import from R
         inv(2::R) *(m+m1)
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/input/oktofail.input.pamphlet b/src/input/oktofail.input.pamphlet
new file mode 100644
index 0000000..e86a8c5
--- /dev/null
+++ b/src/input/oktofail.input.pamphlet
@@ -0,0 +1,226 @@
+\documentclass{article}
+\setlength{\textwidth}{400pt}
+\usepackage{axiom}
+\begin{document}
+\title{\$SPAD/src/input oktofail.input}
+\author{Timothy Daly}
+\maketitle
+\begin{abstract}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)spool oktofail.output
+)set message test on
+)set message auto off
+)clear all
+ 
+--S 1 of 28 from richtrig800-899
+t0866:= cos(x)/(a+b*cos(x)+c*cos(x)^2)
+--E 1
+
+--S 2 of 28 from richtrig800-899
+r0866:= -2^(1/2)*(1-b/(b^2-4*a*c)^(1/2))*atanh(1/2*(b-2*c-(b^2-4*a*c)^(1/2))_
+         *tan(1/2*x)*2^(1/2)/(-b^2+2*c*(a+c)+_
+         (b^2-4*a*c)^(1/2)*b)^(1/2))/(-b^2+2*c*(a+c)+_
+         (b^2-4*a*c)^(1/2)*b)^(1/2)-2*(1+b/(b^2-4*a*c)^(1/2))*_
+         atanh((b+(b^2-4*a*c)^(1/2)-2*c)*tan(1/2*x)/_
+         (4*c^2-(b+(b^2-4*a*c)^(1/2))^2)^(1/2))/_
+         (4*c^2-(b+(b^2-4*a*c)^(1/2))^2)^(1/2)
+--E 2
+
+--S 3 of 28 from richtrig800-899
+a0866:= integrate(t0866,x)
+--E 3
+
+--S 4 of 28 from richlog300-391
+t0341:= log(x^(1/2)+(1+x)^(1/2))
+--E 4
+
+--S 5 of 28 from richlog300-391
+r0341:= -1/2*(x/(1+x))^(1/2)*(1+x)+1/2*atanh((x/(1+x))^(1/2))+_
+        x*log(x^(1/2)+(1+x)^(1/2))
+--E 5
+
+--S 6 of 28 from richlog300-391
+a0341:= integrate(t0341,x)
+--E 6
+
+--S 7 of 28 from richlog300-391 (random value, ok to fail)
+m0341:= a0341-r0341
+--E 7
+
+--S 8 of 28 from richlog300-391 (random value, ok to fail)
+d0341:= D(m0341,x)
+--E 8
+
+--S 9 of 28
+#l
+--R 
+--R
+--R   (9)  10
+--R                                                        Type: PositiveInteger
+--E 9
+
+--S 10 of 28
+l
+--R 
+--R
+--R   (10)  [1,4,2,- 6,0,3,5,4,2,3]
+--R                                                           Type: List Integer
+--E 10
+
+--S 11 of 28
+first(l,3)
+--R 
+--R
+--R   (11)  [1,4,2]
+--R                                                           Type: List Integer
+--E 11
+
+--S 12 of 28
+rest(l,3)
+--R 
+--R
+--R   (12)  [- 6,0,3,5,4,2,3]
+--R                                                           Type: List Integer
+--E 12
+
+--S 13 of 28
+l.1
+--R 
+--R
+--R   (13)  1
+--R                                                        Type: PositiveInteger
+--E 13
+
+--S 14 of 28
+l.2
+--R 
+--R
+--R   (14)  4
+--R                                                        Type: PositiveInteger
+--E 14
+
+--S 15 of 28
+l.(#l)
+--R 
+--R
+--R   (15)  3
+--R                                                        Type: PositiveInteger
+--E 15
+
+--S 16 of 28
+l.1 := 1000000000
+--R 
+--R
+--R   (16)  1000000000
+--R                                                        Type: PositiveInteger
+--E 16
+
+--S 17 of 28
+l
+--R 
+--R
+--R   (17)  [1000000000,4,2,- 6,0,3,5,4,2,3]
+--R                                                           Type: List Integer
+--E 17
+
+--S 18 of 28
+insert(10,l,4)
+--R 
+--R
+--R   (18)  [1000000000,4,2,10,- 6,0,3,5,4,2,3]
+--R                                                           Type: List Integer
+--E 18
+
+--S 19 of 28
+insert(2,l,1)
+--R 
+--R
+--R   (19)  [2,1000000000,4,2,- 6,0,3,5,4,2,3]
+--R                                                           Type: List Integer
+--E 19
+
+--S 20 of 28
+position(-6,l)
+--R 
+--R
+--R   (20)  4
+--R                                                        Type: PositiveInteger
+--E 20
+
+--S 21 of 28
+reverse l
+--R 
+--R
+--R   (21)  [3,2,4,5,3,0,- 6,2,4,1000000000]
+--R                                                           Type: List Integer
+--E 21
+
+--S 22 of 28
+l
+--R 
+--R
+--R   (22)  [1000000000,4,2,- 6,0,3,5,4,2,3]
+--R                                                           Type: List Integer
+--E 22
+
+--S 23 of 28
+m := [4,2,3,6,5,7,-9,1,2,3,2]
+--R 
+--R
+--R   (23)  [4,2,3,6,5,7,- 9,1,2,3,2]
+--R                                                           Type: List Integer
+--E 23
+
+--S 24 of 28
+sl:SET(INT) := brace l
+--R 
+--R
+--R   (24)  {- 6,0,2,3,4,5,1000000000}
+--R                                                            Type: Set Integer
+--E 24
+
+--S 25 of 28
+sm:SET(INT) := brace m
+--R 
+--R
+--R   (25)  {- 9,1,2,3,4,5,6,7}
+--R                                                            Type: Set Integer
+--E 25
+
+--S 26 of 28
+difference(sl, sm)
+--R 
+--R
+--R   (26)  {- 6,0,1000000000}
+--R                                                            Type: Set Integer
+--E 26
+
+--S 27 of 28
+intersect(sl,sm)
+--R 
+--R
+--R   (27)  {2,3,4,5}
+--R                                                            Type: Set Integer
+--E 27
+
+--S 28 of 28
+union(sl,sm)
+--R 
+--R
+--R   (28)  {- 9,- 6,0,1,2,3,4,5,6,7,1000000000}
+--R                                                            Type: Set Integer
+--E 28
+)spool 
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/pdecomp0.as.pamphlet b/src/input/pdecomp0.as.pamphlet
index 5867b2b..e8633b9 100644
--- a/src/input/pdecomp0.as.pamphlet
+++ b/src/input/pdecomp0.as.pamphlet
@@ -11,7 +11,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 -- Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 -- All rights reserved.
 --
@@ -43,11 +43,10 @@
 -- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 -- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-@
-<<*>>=
+\end{verbatim}
+\begin{chunk}{*}
 #pile
 #include "axiom.as"
-<<license>>
 
 --% Polynomial composition and decomposition functions
 --  If f = g o h then  g = leftFactor(f, h)  &  h = rightFactor(f, g)
@@ -134,9 +133,7 @@ PolynomialDecomposition(UP:UPC F, F:Field): PDcat == PDdef where
                 h  := h + monomial(c, dh-k)
             h - monomial(coefficient(h, 0), 0) -- drop constant term
 
-
-
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/input/rich13.input.pamphlet b/src/input/rich13.input.pamphlet
new file mode 100644
index 0000000..7adc3e2
--- /dev/null
+++ b/src/input/rich13.input.pamphlet
@@ -0,0 +1,30374 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich13.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|u (a+b x+c x^2)^n (d+e x+f x^2)^p|
+There are:
+\begin{itemize}
+\item 255 integrals in this file.
+\item 255 supplied "optimal results".
+\item 307 matching answers.
+\item 0 cases where Axiom answer differs from Rubi
+\item 91 cases where Axiom supplied 2 results.
+\item 12 cases that Axiom failed to integrate.
+\item 31 that contain expressions Axiom does not recognize.
+\end{itemize}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich13.output
+)spool rich13.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 556
+t0:=sqrt(1+2*x+x^2)/sqrt(1+x^2)
+--R 
+--R
+--R         +-----------+
+--R         | 2
+--R        \|x  + 2x + 1
+--R   (1)  --------------
+--R            +------+
+--R            | 2
+--R           \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 556
+r0:=asinh(x)*sqrt(1+2*x+x^2)/(1+x)+sqrt(1+x^2)*sqrt(1+2*x+x^2)/(1+x)
+--R 
+--R
+--R          +------+             +-----------+
+--R          | 2                  | 2
+--R        (\|x  + 1  + asinh(x))\|x  + 2x + 1
+--R   (2)  ------------------------------------
+--R                        x + 1
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +------+          +------+          +------+
+--R            | 2               | 2               | 2         2
+--R        (- \|x  + 1  + x)log(\|x  + 1  - x) - x\|x  + 1  + x  + 1
+--R   (3)  ---------------------------------------------------------
+--R                               +------+
+--R                               | 2
+--R                              \|x  + 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +------+               +------+
+--R                  | 2         2          | 2
+--R       ((- x - 1)\|x  + 1  + x  + x)log(\|x  + 1  - x)
+--R     + 
+--R                         +------+                        +-----------+
+--R                         | 2                      2      | 2
+--R       ((- asinh(x) + x)\|x  + 1  + x asinh(x) - x  - 1)\|x  + 2x + 1
+--R     + 
+--R                  +------+
+--R           2      | 2         3    2
+--R       (- x  - x)\|x  + 1  + x  + x  + x + 1
+--R  /
+--R             +------+
+--R             | 2         2
+--R     (x + 1)\|x  + 1  - x  - x
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R                +-----------+
+--R                | 2              2
+--R        (x + 1)\|x  + 2x + 1  - x  - 2x - 1
+--R   (5)  -----------------------------------
+--R               +------+ +-----------+
+--R               | 2      | 2
+--R              \|x  + 1 \|x  + 2x + 1
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 556
+t0:=(a+b*x+c*x^2)^4*(A+C*x^2)
+--R 
+--R
+--R   (1)
+--R        4 10         3 9       4         3       2 2  8
+--R     C c x   + 4C b c x  + (A c  + 4C a c  + 6C b c )x
+--R   + 
+--R            3            2       3   7
+--R     (4A b c  + 12C a b c  + 4C b c)x
+--R   + 
+--R            3        2       2  2          2       4  6
+--R     (4A a c  + (6A b  + 6C a )c  + 12C a b c + C b )x
+--R   + 
+--R               2        3        2            3  5
+--R     (12A a b c  + (4A b  + 12C a b)c + 4C a b )x
+--R   + 
+--R          2 2           2       3        4       2 2  4
+--R     (6A a c  + (12A a b  + 4C a )c + A b  + 6C a b )x
+--R   + 
+--R           2            3       3   3        3        2 2      4  2       3
+--R     (12A a b c + 4A a b  + 4C a b)x  + (4A a c + 6A a b  + C a )x  + 4A a b x
+--R   + 
+--R        4
+--R     A a
+--R                                                    Type: Polynomial(Integer)
+--E 6
+
+--S 7 of 556
+r0:=a^4*A*x+2*a^3*A*b*x^2+1/3*a^2*(6*A*b^2+4*a*A*c+a^2*C)*x^3+a*b*(A*_
+   (b^2+3*a*c)+a^2*C)*x^4+1/5*(A*(b^4+12*a*b^2*c+6*a^2*c^2)+2*a^2*(3*b^2+_
+   2*a*c)*C)*x^5+2/3*b*(b^2+3*a*c)*(A*c+a*C)*x^6+1/7*(2*A*c^2*(3*b^2+2*a*c)+_
+   (b^4+12*a*b^2*c+6*a^2*c^2)*C)*x^7+1/2*b*c*(A*c^2+(b^2+3*a*c)*C)*x^8+_
+   1/9*c^2*(A*c^2+6*b^2*C+4*a*c*C)*x^9+2/5*b*c^3*C*x^10+1/11*c^4*C*x^11
+--R 
+--R
+--R   (2)
+--R      1    4 11   2      3 10    1    4   4      3   2    2 2  9
+--R     -- C c x   + - C b c x   + (- A c  + - C a c  + - C b c )x
+--R     11           5              9        9          3
+--R   + 
+--R      1      3   3        2   1    3   8
+--R     (- A b c  + - C a b c  + - C b c)x
+--R      2          2            2
+--R   + 
+--R      4      3    6    2   6    2  2   12      2    1    4  7
+--R     (- A a c  + (- A b  + - C a )c  + -- C a b c + - C b )x
+--R      7           7        7            7           7
+--R   + 
+--R              2    2    3       2      2      3  6
+--R     (2A a b c  + (- A b  + 2C a b)c + - C a b )x
+--R                   3                   3
+--R   + 
+--R      6    2 2    12      2   4    3     1    4   6    2 2  5
+--R     (- A a c  + (-- A a b  + - C a )c + - A b  + - C a b )x
+--R      5            5          5          5        5
+--R   + 
+--R          2           3      3   4    4    3        2 2   1    4  3       3   2
+--R     (3A a b c + A a b  + C a b)x  + (- A a c + 2A a b  + - C a )x  + 2A a b x
+--R                                      3                   3
+--R   + 
+--R        4
+--R     A a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 7
+
+--S 8 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    4 11   2      3 10    1    4   4      3   2    2 2  9
+--R     -- C c x   + - C b c x   + (- A c  + - C a c  + - C b c )x
+--R     11           5              9        9          3
+--R   + 
+--R      1      3   3        2   1    3   8
+--R     (- A b c  + - C a b c  + - C b c)x
+--R      2          2            2
+--R   + 
+--R      4      3    6    2   6    2  2   12      2    1    4  7
+--R     (- A a c  + (- A b  + - C a )c  + -- C a b c + - C b )x
+--R      7           7        7            7           7
+--R   + 
+--R              2    2    3       2      2      3  6
+--R     (2A a b c  + (- A b  + 2C a b)c + - C a b )x
+--R                   3                   3
+--R   + 
+--R      6    2 2    12      2   4    3     1    4   6    2 2  5
+--R     (- A a c  + (-- A a b  + - C a )c + - A b  + - C a b )x
+--R      5            5          5          5        5
+--R   + 
+--R          2           3      3   4    4    3        2 2   1    4  3       3   2
+--R     (3A a b c + A a b  + C a b)x  + (- A a c + 2A a b  + - C a )x  + 2A a b x
+--R                                      3                   3
+--R   + 
+--R        4
+--R     A a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 8
+
+--S 9 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 9
+
+--S 10 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 10
+
+)clear all
+
+--S 11 of 556
+t0:=(a+b*x+c*x^2)^3*(A+C*x^2)
+--R 
+--R
+--R   (1)
+--R        3 8         2 7       3         2       2   6
+--R     C c x  + 3C b c x  + (A c  + 3C a c  + 3C b c)x
+--R   + 
+--R            2                 3  5          2        2       2           2  4
+--R     (3A b c  + 6C a b c + C b )x  + (3A a c  + (3A b  + 3C a )c + 3C a b )x
+--R   + 
+--R                  3       2   3        2          2      3  2       2         3
+--R   (6A a b c + A b  + 3C a b)x  + (3A a c + 3A a b  + C a )x  + 3A a b x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 11
+
+--S 12 of 556
+r0:=a^3*A*x+3/2*a^2*A*b*x^2+1/3*a*(3*A*(b^2+a*c)+a^2*C)*x^3+1/4*b*(A*(b^2+_
+   6*a*c)+3*a^2*C)*x^4+3/5*(b^2+a*c)*(A*c+a*C)*x^5+1/6*b*(3*A*c^2+(b^2+_
+   6*a*c)*C)*x^6+1/7*c*(A*c^2+3*(b^2+a*c)*C)*x^7+3/8*b*c^2*C*x^8+1/9*c^3*C*x^9
+--R 
+--R
+--R   (2)
+--R     1    3 9   3      2 8    1    3   3      2   3    2   7
+--R     - C c x  + - C b c x  + (- A c  + - C a c  + - C b c)x
+--R     9          8             7        7          7
+--R   + 
+--R      1      2             1    3  6
+--R     (- A b c  + C a b c + - C b )x
+--R      2                    6
+--R   + 
+--R      3      2    3    2   3    2     3      2  5
+--R     (- A a c  + (- A b  + - C a )c + - C a b )x
+--R      5           5        5          5
+--R   + 
+--R      3           1    3   3    2   4       2         2   1    3  3   3    2   2
+--R     (- A a b c + - A b  + - C a b)x  + (A a c + A a b  + - C a )x  + - A a b x
+--R      2           4        4                              3           2
+--R   + 
+--R        3
+--R     A a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 12
+
+--S 13 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    3 9   3      2 8    1    3   3      2   3    2   7
+--R     - C c x  + - C b c x  + (- A c  + - C a c  + - C b c)x
+--R     9          8             7        7          7
+--R   + 
+--R      1      2             1    3  6
+--R     (- A b c  + C a b c + - C b )x
+--R      2                    6
+--R   + 
+--R      3      2    3    2   3    2     3      2  5
+--R     (- A a c  + (- A b  + - C a )c + - C a b )x
+--R      5           5        5          5
+--R   + 
+--R      3           1    3   3    2   4       2         2   1    3  3   3    2   2
+--R     (- A a b c + - A b  + - C a b)x  + (A a c + A a b  + - C a )x  + - A a b x
+--R      2           4        4                              3           2
+--R   + 
+--R        3
+--R     A a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 13
+
+--S 14 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 14
+
+--S 15 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 15
+
+)clear all
+
+--S 16 of 556
+t0:=(a+b*x+c*x^2)^2*(A+C*x^2)
+--R 
+--R
+--R   (1)
+--R        2 6           5       2               2  4                     3
+--R     C c x  + 2C b c x  + (A c  + 2C a c + C b )x  + (2A b c + 2C a b)x
+--R   + 
+--R                  2      2  2                 2
+--R     (2A a c + A b  + C a )x  + 2A a b x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 16
+
+--S 17 of 556
+r0:=a^2*A*x+a*A*b*x^2+1/3*(A*(b^2+2*a*c)+a^2*C)*x^3+1/2*b*(A*c+a*C)*x^4+_
+   1/5*(A*c^2+(b^2+2*a*c)*C)*x^5+1/3*b*c*C*x^6+1/7*c^2*C*x^7
+--R 
+--R
+--R   (2)
+--R     1    2 7   1        6    1    2   2         1    2  5
+--R     - C c x  + - C b c x  + (- A c  + - C a c + - C b )x
+--R     7          3             5        5         5
+--R   + 
+--R      1         1        4    2         1    2   1    2  3          2      2
+--R     (- A b c + - C a b)x  + (- A a c + - A b  + - C a )x  + A a b x  + A a x
+--R      2         2             3         3        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 17
+
+--S 18 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    2 7   1        6    1    2   2         1    2  5
+--R     - C c x  + - C b c x  + (- A c  + - C a c + - C b )x
+--R     7          3             5        5         5
+--R   + 
+--R      1         1        4    2         1    2   1    2  3          2      2
+--R     (- A b c + - C a b)x  + (- A a c + - A b  + - C a )x  + A a b x  + A a x
+--R      2         2             3         3        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 18
+
+--S 19 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 19
+
+--S 20 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 20
+
+)clear all
+
+--S 21 of 556
+t0:=(a+b*x+c*x^2)*(A+C*x^2)
+--R 
+--R
+--R             4        3               2
+--R   (1)  C c x  + C b x  + (A c + C a)x  + A b x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 21
+
+--S 22 of 556
+r0:=a*A*x+1/2*A*b*x^2+1/3*(A*c+a*C)*x^3+1/4*b*C*x^4+1/5*c*C*x^5
+--R 
+--R
+--R        1      5   1      4    1       1      3   1      2
+--R   (2)  - C c x  + - C b x  + (- A c + - C a)x  + - A b x  + A a x
+--R        5          4           3       3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 22
+
+--S 23 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1      5   1      4    1       1      3   1      2
+--R   (3)  - C c x  + - C b x  + (- A c + - C a)x  + - A b x  + A a x
+--R        5          4           3       3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 23
+
+--S 24 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 24
+
+--S 25 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 25
+
+)clear all
+
+--S 26 of 556
+t0:=(A+C*x^2)/(a+b*x+c*x^2)
+--R 
+--R
+--R              2
+--R           C x  + A
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 26
+
+--S 27 of 556
+r0:=C*x/c-1/2*b*C*log(a+b*x+c*x^2)/c^2-(2*A*c^2+(b^2-2*a*c)*C)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R              2                2          2c x + b
+--R       (- 4A c  + 4C a c - 2C b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                                            +-----------+
+--R                     2                      |          2
+--R       (- C b log(c x  + b x + a) + 2C c x)\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2               2
+--R           (2A c  - 2C a c + C b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                              +-----------+
+--R                       2                      |          2
+--R         (- C b log(c x  + b x + a) + 2C c x)\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         2 |          2
+--R       2c \|- 4a c + b
+--R     ,
+--R
+--R                                                 +---------+
+--R                                                 |        2
+--R              2                2      (2c x + b)\|4a c - b
+--R         (4A c  - 4C a c + 2C b )atan(----------------------)
+--R                                                     2
+--R                                             4a c - b
+--R       + 
+--R                                              +---------+
+--R                       2                      |        2
+--R         (- C b log(c x  + b x + a) + 2C c x)\|4a c - b
+--R    /
+--R           +---------+
+--R         2 |        2
+--R       2c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 28
+
+--S 29 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2               2
+--R         (2A c  - 2C a c + C b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R            2                2          2c x + b
+--R       (4A c  - 4C a c + 2C b )atanh(--------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+--S 31 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                               +---------+
+--R            2               2  |        2          2c x + b
+--R       (2A c  - 2C a c + C b )\|4a c - b  atanh(--------------)
+--R                                                 +-----------+
+--R                                                 |          2
+--R                                                \|- 4a c + b
+--R     + 
+--R                                                            +---------+
+--R                               +-----------+                |        2
+--R            2               2  |          2      (2c x + b)\|4a c - b
+--R       (2A c  - 2C a c + C b )\|- 4a c + b  atan(----------------------)
+--R                                                                2
+--R                                                        4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      2 |          2  |        2
+--R     c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 32
+
+)clear all
+
+--S 33 of 556
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^2
+--R 
+--R
+--R                             2
+--R                          C x  + A
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 33
+
+--S 34 of 556
+r0:=(-b*(A*c+a*C)-(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*(a+b*x+c*x^2))+_
+   4*(A*c+a*C)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                 3         2  2            2                      2       2
+--R         ((- 4A c  - 4C a c )x  + (- 4A b c  - 4C a b c)x - 4A a c  - 4C a c)
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                  +-----------+
+--R             2               2                    |          2
+--R       ((2A c  - 2C a c + C b )x + A b c + C a b)\|- 4a c + b
+--R  /
+--R                                                           +-----------+
+--R           3    2 2  2          2    3        2 2      2   |          2
+--R     ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3         2  2          2                      2       2
+--R           ((2A c  + 2C a c )x  + (2A b c  + 2C a b c)x + 2A a c  + 2C a c)
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                                    +-----------+
+--R               2               2                    |          2
+--R         ((2A c  - 2C a c + C b )x + A b c + C a b)\|- 4a c + b
+--R    /
+--R                                                             +-----------+
+--R             3    2 2  2          2    3        2 2      2   |          2
+--R       ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|- 4a c + b
+--R     ,
+--R
+--R                 3         2  2          2                      2       2
+--R           ((4A c  + 4C a c )x  + (4A b c  + 4C a b c)x + 4A a c  + 4C a c)
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                                                    +---------+
+--R               2               2                    |        2
+--R         ((2A c  - 2C a c + C b )x + A b c + C a b)\|4a c - b
+--R    /
+--R                                                             +---------+
+--R             3    2 2  2          2    3        2 2      2   |        2
+--R       ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 35
+
+--S 36 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (2A c + 2C a)
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                             2c x + b
+--R       (4A c + 4C a)atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R              2  |          2
+--R     (4a c - b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+
+--R                     |        2          2c x + b
+--R       (4A c + 4C a)\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                     +-----------+                |        2
+--R                     |          2      (2c x + b)\|4a c - b
+--R       (4A c + 4C a)\|- 4a c + b  atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 556
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + A
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 40
+
+--S 41 of 556
+r0:=1/2*(-b*(A*c+a*C)-(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2)^2)+1/2*(6*A*c^2+(b^2+2*a*c)*C)*(b+2*c*x)/(c*(b^2-4*a*c)^2*_
+   (a+b*x+c*x^2))-2*(6*A*c^2+(b^2+2*a*c)*C)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                   4         3       2 2  4
+--R           (- 24A c  - 8C a c  - 4C b c )x
+--R         + 
+--R                     3            2       3   3
+--R           (- 48A b c  - 16C a b c  - 8C b c)x
+--R         + 
+--R                     3           2        2  2          2        4  2
+--R           (- 48A a c  + (- 24A b  - 16C a )c  - 16C a b c - 4C b )x
+--R         + 
+--R                       2        2            3          2 2       3        2 2
+--R           (- 48A a b c  - 16C a b c - 8C a b )x - 24A a c  - 8C a c - 4C a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 3         2       2   3           2                  3  2
+--R           (12A c  + 4C a c  + 2C b c)x  + (18A b c  + 6C a b c + 3C b )x
+--R         + 
+--R                 2        2       2            2                    3       2
+--R         (20A a c  + (4A b  - 4C a )c + 10C a b )x + 10A a b c - A b  + 6C a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   4         3       2 2  4           3           2       3   3
+--R             (12A c  + 4C a c  + 2C b c )x  + (24A b c  + 8C a b c  + 4C b c)x
+--R           + 
+--R                     3         2       2  2         2        4  2
+--R             (24A a c  + (12A b  + 8C a )c  + 8C a b c + 2C b )x
+--R           + 
+--R                       2       2            3          2 2       3        2 2
+--R             (24A a b c  + 8C a b c + 4C a b )x + 12A a c  + 4C a c + 2C a b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                   3         2       2   3           2                  3  2
+--R             (12A c  + 4C a c  + 2C b c)x  + (18A b c  + 6C a b c + 3C b )x
+--R           + 
+--R                   2        2       2            2                    3       2
+--R           (20A a c  + (4A b  - 4C a )c + 10C a b )x + 10A a b c - A b  + 6C a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  4       2   3        3 2     5   3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R         + 
+--R               3 3        4      6  2       3   2      2 3        5        4 2
+--R           (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                3 2      2 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   4         3       2 2  4           3            2       3   3
+--R             (24A c  + 8C a c  + 4C b c )x  + (48A b c  + 16C a b c  + 8C b c)x
+--R           + 
+--R                     3         2        2  2          2        4  2
+--R             (48A a c  + (24A b  + 16C a )c  + 16C a b c + 4C b )x
+--R           + 
+--R                       2        2            3          2 2       3        2 2
+--R             (48A a b c  + 16C a b c + 8C a b )x + 24A a c  + 8C a c + 4C a b
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                   3         2       2   3           2                  3  2
+--R             (12A c  + 4C a c  + 2C b c)x  + (18A b c  + 6C a b c + 3C b )x
+--R           + 
+--R                   2        2       2            2                    3       2
+--R           (20A a c  + (4A b  - 4C a )c + 10C a b )x + 10A a b c - A b  + 6C a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 4        2 3     4 2  4       2   3        3 2     5   3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R         + 
+--R               3 3        4      6  2       3   2      2 3        5        4 2
+--R           (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                3 2      2 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 42
+
+--S 43 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2               2
+--R         (6A c  + 2C a c + C b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R             2                2          2c x + b
+--R       (12A c  + 4C a c + 2C b )atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R  /
+--R                            +-----------+
+--R         2 2       2     4  |          2
+--R     (16a c  - 8a b c + b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                 +---------+
+--R             2                2  |        2          2c x + b
+--R       (12A c  + 4C a c + 2C b )\|4a c - b  atanh(--------------)
+--R                                                   +-----------+
+--R                                                   |          2
+--R                                                  \|- 4a c + b
+--R     + 
+--R                                                              +---------+
+--R                                 +-----------+                |        2
+--R             2                2  |          2      (2c x + b)\|4a c - b
+--R       (12A c  + 4C a c + 2C b )\|- 4a c + b  atan(----------------------)
+--R                                                                  2
+--R                                                          4a c - b
+--R  /
+--R                            +-----------+ +---------+
+--R         2 2       2     4  |          2  |        2
+--R     (16a c  - 8a b c + b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 45
+
+--S 46 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 46
+
+)clear all
+
+--S 47 of 556
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^4
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + A
+--R  /
+--R        4 8       3 7        3     2 2  6           2     3   5
+--R       c x  + 4b c x  + (4a c  + 6b c )x  + (12a b c  + 4b c)x
+--R     + 
+--R          2 2        2     4  4       2          3  3      3      2 2  2
+--R       (6a c  + 12a b c + b )x  + (12a b c + 4a b )x  + (4a c + 6a b )x
+--R     + 
+--R         3       4
+--R       4a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 47
+
+--S 48 of 556
+r0:=1/3*(-b*(A*c+a*C)-(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2)^3)+1/3*(5*A*c^2+(b^2+a*c)*C)*(b+2*c*x)/(c*(b^2-4*a*c)^2*_
+   (a+b*x+c*x^2)^2)-2*(5*A*c^2+(b^2+a*c)*C)*(b+2*c*x)/((b^2-4*a*c)^3*_
+   (a+b*x+c*x^2))+8*c*(5*A*c^2+(b^2+a*c)*C)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(7/2)
+--R 
+--R
+--R   (2)
+--R                    6          5        2 4  6
+--R           (- 120A c  - 24C a c  - 24C b c )x
+--R         + 
+--R                      5            4        3 3  5
+--R           (- 360A b c  - 72C a b c  - 72C b c )x
+--R         + 
+--R                      5            2        2  4           2 3        4 2  4
+--R           (- 360A a c  + (- 360A b  - 72C a )c  - 144C a b c  - 72C b c )x
+--R         + 
+--R                        4            3         2   3           3 2        5   3
+--R           (- 720A a b c  + (- 120A b  - 144C a b)c  - 168C a b c  - 24C b c)x
+--R         + 
+--R                    2 4              2        3  3         2 2 2          4   2
+--R           (- 360A a c  + (- 360A a b  - 72C a )c  - 144C a b c  - 72C a b c)x
+--R         + 
+--R                    2   3        3   2        2 3            3 3        4 2
+--R           (- 360A a b c  - 72C a b c  - 72C a b c)x - 120A a c  - 24C a c
+--R         + 
+--R                  3 2
+--R           - 24C a b c
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 5          4        2 3  5
+--R           (60A c  + 12C a c  + 12C b c )x
+--R         + 
+--R                    4            3        3 2  4
+--R           (150A b c  + 30C a b c  + 30C b c )x
+--R         + 
+--R                    4          2        2  3          2 2        4   3
+--R           (160A a c  + (110A b  + 32C a )c  + 54C a b c  + 22C b c)x
+--R         + 
+--R                      3         3        2   2          3        5  2
+--R           (240A a b c  + (15A b  + 48C a b)c  + 51C a b c + 3C b )x
+--R         + 
+--R                       2 3           2        3  2          4        2 2
+--R                 132A a c  + (54A a b  - 12C a )c  + (- 3A b  + 66C a b )c
+--R               + 
+--R                       4
+--R                 3C a b
+--R          *
+--R             x
+--R         + 
+--R                2   2             3        3         5      2 3
+--R           66A a b c  + (- 13A a b  + 26C a b)c + A b  + C a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              3 6       2 2 5        4 4     6 3  6
+--R         (192a c  - 144a b c  + 36a b c  - 3b c )x
+--R       + 
+--R              3   5       2 3 4         5 3     7 2  5
+--R         (576a b c  - 432a b c  + 108a b c  - 9b c )x
+--R       + 
+--R              4 5       3 2 4       2 4 3        6 2     8   4
+--R         (576a c  + 144a b c  - 324a b c  + 99a b c  - 9b c)x
+--R       + 
+--R               4   4       3 3 3      2 5 2        7      9  3
+--R         (1152a b c  - 672a b c  + 72a b c  + 18a b c - 3b )x
+--R       + 
+--R              5 4       4 2 3       3 4 2      2 6        8  2
+--R         (576a c  + 144a b c  - 324a b c  + 99a b c - 9a b )x
+--R       + 
+--R              5   3       4 3 2       3 5      2 7         6 3       5 2 2
+--R         (576a b c  - 432a b c  + 108a b c - 9a b )x + 192a c  - 144a b c
+--R       + 
+--R            4 4      3 6
+--R         36a b c - 3a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 48
+
+--S 49 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   6          5        2 4  6
+--R             (60A c  + 12C a c  + 12C b c )x
+--R           + 
+--R                      5            4        3 3  5
+--R             (180A b c  + 36C a b c  + 36C b c )x
+--R           + 
+--R                      5          2        2  4          2 3        4 2  4
+--R             (180A a c  + (180A b  + 36C a )c  + 72C a b c  + 36C b c )x
+--R           + 
+--R                        4         3        2   3          3 2        5   3
+--R             (360A a b c  + (60A b  + 72C a b)c  + 84C a b c  + 12C b c)x
+--R           + 
+--R                    2 4            2        3  3        2 2 2          4   2
+--R             (180A a c  + (180A a b  + 36C a )c  + 72C a b c  + 36C a b c)x
+--R           + 
+--R                    2   3        3   2        2 3           3 3        4 2
+--R             (180A a b c  + 36C a b c  + 36C a b c)x + 60A a c  + 12C a c
+--R           + 
+--R                  3 2
+--R             12C a b c
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                   5          4        2 3  5
+--R             (60A c  + 12C a c  + 12C b c )x
+--R           + 
+--R                      4            3        3 2  4
+--R             (150A b c  + 30C a b c  + 30C b c )x
+--R           + 
+--R                      4          2        2  3          2 2        4   3
+--R             (160A a c  + (110A b  + 32C a )c  + 54C a b c  + 22C b c)x
+--R           + 
+--R                        3         3        2   2          3        5  2
+--R             (240A a b c  + (15A b  + 48C a b)c  + 51C a b c + 3C b )x
+--R           + 
+--R                       2 3           2        3  2          4        2 2
+--R                 132A a c  + (54A a b  - 12C a )c  + (- 3A b  + 66C a b )c
+--R               + 
+--R                       4
+--R                 3C a b
+--R            *
+--R               x
+--R           + 
+--R                  2   2             3        3         5      2 3
+--R             66A a b c  + (- 13A a b  + 26C a b)c + A b  + C a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                3 6       2 2 5        4 4     6 3  6
+--R           (192a c  - 144a b c  + 36a b c  - 3b c )x
+--R         + 
+--R                3   5       2 3 4         5 3     7 2  5
+--R           (576a b c  - 432a b c  + 108a b c  - 9b c )x
+--R         + 
+--R                4 5       3 2 4       2 4 3        6 2     8   4
+--R           (576a c  + 144a b c  - 324a b c  + 99a b c  - 9b c)x
+--R         + 
+--R                 4   4       3 3 3      2 5 2        7      9  3
+--R           (1152a b c  - 672a b c  + 72a b c  + 18a b c - 3b )x
+--R         + 
+--R                5 4       4 2 3       3 4 2      2 6        8  2
+--R           (576a c  + 144a b c  - 324a b c  + 99a b c - 9a b )x
+--R         + 
+--R                5   3       4 3 2       3 5      2 7         6 3       5 2 2
+--R           (576a b c  - 432a b c  + 108a b c - 9a b )x + 192a c  - 144a b c
+--R         + 
+--R              4 4      3 6
+--R           36a b c - 3a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    6          5        2 4  6
+--R             (120A c  + 24C a c  + 24C b c )x
+--R           + 
+--R                      5            4        3 3  5
+--R             (360A b c  + 72C a b c  + 72C b c )x
+--R           + 
+--R                      5          2        2  4           2 3        4 2  4
+--R             (360A a c  + (360A b  + 72C a )c  + 144C a b c  + 72C b c )x
+--R           + 
+--R                        4          3         2   3           3 2        5   3
+--R             (720A a b c  + (120A b  + 144C a b)c  + 168C a b c  + 24C b c)x
+--R           + 
+--R                    2 4            2        3  3         2 2 2          4   2
+--R             (360A a c  + (360A a b  + 72C a )c  + 144C a b c  + 72C a b c)x
+--R           + 
+--R                    2   3        3   2        2 3            3 3        4 2
+--R             (360A a b c  + 72C a b c  + 72C a b c)x + 120A a c  + 24C a c
+--R           + 
+--R                  3 2
+--R             24C a b c
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                   5          4        2 3  5
+--R             (60A c  + 12C a c  + 12C b c )x
+--R           + 
+--R                      4            3        3 2  4
+--R             (150A b c  + 30C a b c  + 30C b c )x
+--R           + 
+--R                      4          2        2  3          2 2        4   3
+--R             (160A a c  + (110A b  + 32C a )c  + 54C a b c  + 22C b c)x
+--R           + 
+--R                        3         3        2   2          3        5  2
+--R             (240A a b c  + (15A b  + 48C a b)c  + 51C a b c + 3C b )x
+--R           + 
+--R                       2 3           2        3  2          4        2 2
+--R                 132A a c  + (54A a b  - 12C a )c  + (- 3A b  + 66C a b )c
+--R               + 
+--R                       4
+--R                 3C a b
+--R            *
+--R               x
+--R           + 
+--R                  2   2             3        3         5      2 3
+--R             66A a b c  + (- 13A a b  + 26C a b)c + A b  + C a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                3 6       2 2 5        4 4     6 3  6
+--R           (192a c  - 144a b c  + 36a b c  - 3b c )x
+--R         + 
+--R                3   5       2 3 4         5 3     7 2  5
+--R           (576a b c  - 432a b c  + 108a b c  - 9b c )x
+--R         + 
+--R                4 5       3 2 4       2 4 3        6 2     8   4
+--R           (576a c  + 144a b c  - 324a b c  + 99a b c  - 9b c)x
+--R         + 
+--R                 4   4       3 3 3      2 5 2        7      9  3
+--R           (1152a b c  - 672a b c  + 72a b c  + 18a b c - 3b )x
+--R         + 
+--R                5 4       4 2 3       3 4 2      2 6        8  2
+--R           (576a c  + 144a b c  - 324a b c  + 99a b c - 9a b )x
+--R         + 
+--R                5   3       4 3 2       3 5      2 7         6 3       5 2 2
+--R           (576a b c  - 432a b c  + 108a b c - 9a b )x + 192a c  - 144a b c
+--R         + 
+--R              4 4      3 6
+--R           36a b c - 3a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 49
+
+--S 50 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               3         2       2
+--R         (20A c  + 4C a c  + 4C b c)
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R             3         2       2           2c x + b
+--R       (40A c  + 8C a c  + 8C b c)atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R  /
+--R                                        +-----------+
+--R         3 3      2 2 2        4     6  |          2
+--R     (64a c  - 48a b c  + 12a b c - b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                   +---------+
+--R             3         2       2   |        2          2c x + b
+--R       (40A c  + 8C a c  + 8C b c)\|4a c - b  atanh(--------------)
+--R                                                     +-----------+
+--R                                                     |          2
+--R                                                    \|- 4a c + b
+--R     + 
+--R                                                                +---------+
+--R                                   +-----------+                |        2
+--R             3         2       2   |          2      (2c x + b)\|4a c - b
+--R       (40A c  + 8C a c  + 8C b c)\|- 4a c + b  atan(----------------------)
+--R                                                                    2
+--R                                                            4a c - b
+--R  /
+--R                                        +-----------+ +---------+
+--R         3 3      2 2 2        4     6  |          2  |        2
+--R     (64a c  - 48a b c  + 12a b c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 53
+
+)clear all
+
+--S 54 of 556
+t0:=(1-x^2)/(1+x+x^2)^2
+--R 
+--R
+--R                   2
+--R                - x  + 1
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  + 2x  + 3x  + 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 54
+
+--S 55 of 556
+r0:=x/(1+x+x^2)
+--R 
+--R
+--R             x
+--R   (2)  ----------
+--R         2
+--R        x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 55
+
+--S 56 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R             x
+--R   (3)  ----------
+--R         2
+--R        x  + x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 56
+
+--S 57 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+--S 58 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 58
+
+)clear all
+
+--S 59 of 556
+t0:=(1+x^2)/(1+x+x^2)
+--R 
+--R
+--R           2
+--R          x  + 1
+--R   (1)  ----------
+--R         2
+--R        x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 59
+
+--S 60 of 556
+r0:=x-1/2*log(1+x+x^2)+atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                               +-+
+--R           +-+     2                  (2x + 1)\|3        +-+
+--R        - \|3 log(x  + x + 1) + 2atan(------------) + 2x\|3
+--R                                            3
+--R   (2)  ----------------------------------------------------
+--R                                  +-+
+--R                                2\|3
+--R                                                    Type: Expression(Integer)
+--E 60
+
+--S 61 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                               +-+
+--R           +-+     2                  (2x + 1)\|3        +-+
+--R        - \|3 log(x  + x + 1) + 2atan(------------) + 2x\|3
+--R                                            3
+--R   (3)  ----------------------------------------------------
+--R                                  +-+
+--R                                2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 61
+
+--S 62 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 556
+t0:=(-1+x^2)/(25-6*x+x^2)
+--R 
+--R
+--R            2
+--R           x  - 1
+--R   (1)  ------------
+--R         2
+--R        x  - 6x + 25
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 64
+
+--S 65 of 556
+r0:=x+2*atan(3/4-1/4*x)+3*log(25-6*x+x^2)
+--R 
+--R
+--R              2                    x - 3
+--R   (2)  3log(x  - 6x + 25) - 2atan(-----) + x
+--R                                     4
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                    x - 3
+--R   (3)  3log(x  - 6x + 25) - 2atan(-----) + x
+--R                                     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 66
+
+--S 67 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 68
+
+)clear all
+
+--S 69 of 556
+t0:=(-10+3*x^2)/(4-4*x+x^2)
+--R 
+--R
+--R            2
+--R          3x  - 10
+--R   (1)  -----------
+--R         2
+--R        x  - 4x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 69
+
+--S 70 of 556
+r0:=2/(2-x)+3*x+12*log(2-x)
+--R 
+--R
+--R                                   2
+--R        (12x - 24)log(- x + 2) + 3x  - 6x - 2
+--R   (2)  -------------------------------------
+--R                        x - 2
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                 2
+--R        (12x - 24)log(x - 2) + 3x  - 6x - 2
+--R   (3)  -----------------------------------
+--R                       x - 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 71
+
+--S 72 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  12log(x - 2) - 12log(- x + 2)
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 73
+
+)clear all
+
+--S 74 of 556
+t0:=(8+x^2)/(6-5*x+x^2)
+--R 
+--R
+--R            2
+--R           x  + 8
+--R   (1)  -----------
+--R         2
+--R        x  - 5x + 6
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 74
+
+--S 75 of 556
+r0:=x-12*log(2-x)+17*log(3-x)
+--R 
+--R
+--R   (2)  17log(- x + 3) - 12log(- x + 2) + x
+--R                                                    Type: Expression(Integer)
+--E 75
+
+--S 76 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  - 12log(x - 2) + 17log(x - 3) + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 76
+
+--S 77 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  - 12log(x - 2) + 17log(x - 3) - 17log(- x + 3) + 12log(- x + 2)
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 556
+t0:=(a+c*x^2)^3*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R        3 8      3 7       3         2  6         2 5          2       2   4
+--R     C c x  + B c x  + (A c  + 3C a c )x  + 3B a c x  + (3A a c  + 3C a c)x
+--R   + 
+--R         2   3        2       3  2      3       3
+--R     3B a c x  + (3A a c + C a )x  + B a x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 79
+
+--S 80 of 556
+r0:=a^3*A*x+1/2*a^3*B*x^2+1/3*a^2*(3*A*c+a*C)*x^3+3/4*a^2*B*c*x^4+3/5*a*c*_
+   (A*c+a*C)*x^5+1/2*a*B*c^2*x^6+1/7*c^2*(A*c+3*a*C)*x^7+1/8*B*c^3*x^8+_
+   1/9*c^3*C*x^9
+--R 
+--R
+--R   (2)
+--R     1    3 9   1    3 8    1    3   3      2  7   1      2 6
+--R     - C c x  + - B c x  + (- A c  + - C a c )x  + - B a c x
+--R     9          8           7        7             2
+--R   + 
+--R    3      2   3    2   5   3    2   4       2    1    3  3   1    3 2      3
+--R   (- A a c  + - C a c)x  + - B a c x  + (A a c + - C a )x  + - B a x  + A a x
+--R    5          5            4                     3           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 80
+
+--S 81 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    3 9   1    3 8    1    3   3      2  7   1      2 6
+--R     - C c x  + - B c x  + (- A c  + - C a c )x  + - B a c x
+--R     9          8           7        7             2
+--R   + 
+--R    3      2   3    2   5   3    2   4       2    1    3  3   1    3 2      3
+--R   (- A a c  + - C a c)x  + - B a c x  + (A a c + - C a )x  + - B a x  + A a x
+--R    5          5            4                     3           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 81
+
+--S 82 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 82
+
+--S 83 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 83
+
+)clear all
+
+--S 84 of 556
+t0:=(a+c*x^2)^2*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R        2 6      2 5       2           4           3                2  2      2
+--R     C c x  + B c x  + (A c  + 2C a c)x  + 2B a c x  + (2A a c + C a )x  + B a x
+--R   + 
+--R        2
+--R     A a
+--R                                                    Type: Polynomial(Integer)
+--E 84
+
+--S 85 of 556
+r0:=a^2*A*x+1/2*a^2*B*x^2+1/3*a*(2*A*c+a*C)*x^3+1/2*a*B*c*x^4+_
+   1/5*c*(A*c+2*a*C)*x^5+1/6*B*c^2*x^6+1/7*c^2*C*x^7
+--R 
+--R
+--R   (2)
+--R     1    2 7   1    2 6    1    2   2        5   1        4
+--R     - C c x  + - B c x  + (- A c  + - C a c)x  + - B a c x
+--R     7          6           5        5            2
+--R   + 
+--R      2         1    2  3   1    2 2      2
+--R     (- A a c + - C a )x  + - B a x  + A a x
+--R      3         3           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 85
+
+--S 86 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    2 7   1    2 6    1    2   2        5   1        4
+--R     - C c x  + - B c x  + (- A c  + - C a c)x  + - B a c x
+--R     7          6           5        5            2
+--R   + 
+--R      2         1    2  3   1    2 2      2
+--R     (- A a c + - C a )x  + - B a x  + A a x
+--R      3         3           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 86
+
+--S 87 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 87
+
+--S 88 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 88
+
+)clear all
+
+--S 89 of 556
+t0:=(a+c*x^2)*(A+B*x+C*x^2)
+--R 
+--R
+--R             4        3               2
+--R   (1)  C c x  + B c x  + (A c + C a)x  + B a x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 89
+
+--S 90 of 556
+r0:=a*A*x+1/2*a*B*x^2+1/3*(A*c+a*C)*x^3+1/4*B*c*x^4+1/5*c*C*x^5
+--R 
+--R
+--R        1      5   1      4    1       1      3   1      2
+--R   (2)  - C c x  + - B c x  + (- A c + - C a)x  + - B a x  + A a x
+--R        5          4           3       3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 90
+
+--S 91 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1      5   1      4    1       1      3   1      2
+--R   (3)  - C c x  + - B c x  + (- A c + - C a)x  + - B a x  + A a x
+--R        5          4           3       3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 91
+
+--S 92 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 92
+
+--S 93 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 93
+
+)clear all
+
+--S 94 of 556
+t0:=(A+B*x+C*x^2)/(a+c*x^2)
+--R 
+--R
+--R           2
+--R        C x  + B x + A
+--R   (1)  --------------
+--R              2
+--R           c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 94
+
+--S 95 of 556
+r0:=C*x/c+1/2*B*log(a+c*x^2)/c+(A*c-a*C)*atan(x*sqrt(c)/sqrt(a))/_
+   (c^(3/2)*sqrt(a))
+--R 
+--R
+--R                            +-+
+--R                          x\|c               2              +-+ +-+
+--R        (2A c - 2C a)atan(-----) + (B log(c x  + a) + 2C x)\|a \|c
+--R                            +-+
+--R                           \|a
+--R   (2)  -----------------------------------------------------------
+--R                                    +-+ +-+
+--R                                 2c\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            2      +-----+
+--R                        (c x  - a)\|- a c  + 2a c x
+--R         (A c - C a)log(---------------------------)
+--R                                     2
+--R                                  c x  + a
+--R       + 
+--R                   2              +-----+
+--R         (B log(c x  + a) + 2C x)\|- a c
+--R    /
+--R          +-----+
+--R       2c\|- a c
+--R     ,
+--R                        +---+
+--R                      x\|a c               2              +---+
+--R    (2A c - 2C a)atan(-------) + (B log(c x  + a) + 2C x)\|a c
+--R                         a
+--R    -----------------------------------------------------------]
+--R                                 +---+
+--R                              2c\|a c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 96
+
+--S 97 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                  2      +-----+
+--R                   +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R       (A c - C a)\|a \|c log(---------------------------)
+--R                                           2
+--R                                        c x  + a
+--R     + 
+--R                                     +-+
+--R                       +-----+     x\|c
+--R       (- 2A c + 2C a)\|- a c atan(-----)
+--R                                     +-+
+--R                                    \|a
+--R  /
+--R        +-----+ +-+ +-+
+--R     2c\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R                                  +---+                              +-+
+--R                    +-+ +-+     x\|a c                   +---+     x\|c
+--R        (A c - C a)\|a \|c atan(-------) + (- A c + C a)\|a c atan(-----)
+--R                                   a                                 +-+
+--R                                                                    \|a
+--R   (6)  -----------------------------------------------------------------
+--R                                   +-+ +-+ +---+
+--R                                 c\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 100
+
+)clear all
+
+--S 101 of 556
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^2
+--R 
+--R
+--R              2
+--R           C x  + B x + A
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 101
+
+--S 102 of 556
+r0:=1/2*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2))+1/2*(A*c+a*C)*_
+   atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                                           +-+
+--R        2          2              2      x\|c                          +-+ +-+
+--R   ((A c  + C a c)x  + A a c + C a )atan(-----) + ((A c - C a)x - B a)\|a \|c
+--R                                           +-+
+--R                                          \|a
+--R   ---------------------------------------------------------------------------
+--R                                  2 2     2   +-+ +-+
+--R                             (2a c x  + 2a c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                  2      +-----+
+--R              2          2              2     (c x  - a)\|- a c  + 2a c x
+--R         ((A c  + C a c)x  + A a c + C a )log(---------------------------)
+--R                                                           2
+--R                                                        c x  + a
+--R       + 
+--R                                 +-----+
+--R         ((2A c - 2C a)x - 2B a)\|- a c
+--R    /
+--R            2 2     2   +-----+
+--R       (4a c x  + 4a c)\|- a c
+--R     ,
+--R                                            +---+
+--R         2          2              2      x\|a c                          +---+
+--R    ((A c  + C a c)x  + A a c + C a )atan(-------) + ((A c - C a)x - B a)\|a c
+--R                                             a
+--R    ---------------------------------------------------------------------------]
+--R                                    2 2     2   +---+
+--R                               (2a c x  + 2a c)\|a c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 103
+
+--S 104 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                  2      +-----+
+--R                   +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R       (A c + C a)\|a \|c log(---------------------------)
+--R                                           2
+--R                                        c x  + a
+--R     + 
+--R                                     +-+
+--R                       +-----+     x\|c
+--R       (- 2A c - 2C a)\|- a c atan(-----)
+--R                                     +-+
+--R                                    \|a
+--R  /
+--R          +-----+ +-+ +-+
+--R     4a c\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+--S 106 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R                                  +---+                              +-+
+--R                    +-+ +-+     x\|a c                   +---+     x\|c
+--R        (A c + C a)\|a \|c atan(-------) + (- A c - C a)\|a c atan(-----)
+--R                                   a                                 +-+
+--R                                                                    \|a
+--R   (6)  -----------------------------------------------------------------
+--R                                     +-+ +-+ +---+
+--R                                2a c\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 107
+
+)clear all
+
+--S 108 of 556
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^3
+--R 
+--R
+--R                   2
+--R                C x  + B x + A
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3a c x  + 3a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 108
+
+--S 109 of 556
+r0:=1/4*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2)^2)+1/8*(3*A*c+a*C)*x/(a^2*c*_
+   (a+c*x^2))+1/8*(3*A*c+a*C)*atan(x*sqrt(c)/sqrt(a))/(a^(5/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                                                                         +-+
+--R             3        2  4          2       2   2       2       3      x\|c
+--R       ((3A c  + C a c )x  + (6A a c  + 2C a c)x  + 3A a c + C a )atan(-----)
+--R                                                                         +-+
+--R                                                                        \|a
+--R     + 
+--R             2          3                2         2  +-+ +-+
+--R       ((3A c  + C a c)x  + (5A a c - C a )x - 2B a )\|a \|c
+--R  /
+--R        2 3 4      3 2 2     4   +-+ +-+
+--R     (8a c x  + 16a c x  + 8a c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3        2  4          2       2   2       2       3
+--R           ((3A c  + C a c )x  + (6A a c  + 2C a c)x  + 3A a c + C a )
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R               2           3                  2         2  +-----+
+--R         ((6A c  + 2C a c)x  + (10A a c - 2C a )x - 4B a )\|- a c
+--R    /
+--R           2 3 4      3 2 2      4   +-----+
+--R       (16a c x  + 32a c x  + 16a c)\|- a c
+--R     ,
+--R
+--R                 3        2  4          2       2   2       2       3
+--R           ((3A c  + C a c )x  + (6A a c  + 2C a c)x  + 3A a c + C a )
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R               2          3                2         2  +---+
+--R         ((3A c  + C a c)x  + (5A a c - C a )x - 2B a )\|a c
+--R    /
+--R          2 3 4      3 2 2     4   +---+
+--R       (8a c x  + 16a c x  + 8a c)\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 110
+
+--S 111 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                   2      +-----+
+--R                    +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R       (3A c + C a)\|a \|c log(---------------------------)
+--R                                            2
+--R                                         c x  + a
+--R     + 
+--R                                     +-+
+--R                       +-----+     x\|c
+--R       (- 6A c - 2C a)\|- a c atan(-----)
+--R                                     +-+
+--R                                    \|a
+--R  /
+--R        2  +-----+ +-+ +-+
+--R     16a c\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R                                   +---+                               +-+
+--R                     +-+ +-+     x\|a c                    +---+     x\|c
+--R        (3A c + C a)\|a \|c atan(-------) + (- 3A c - C a)\|a c atan(-----)
+--R                                    a                                  +-+
+--R                                                                      \|a
+--R   (6)  -------------------------------------------------------------------
+--R                                   2  +-+ +-+ +---+
+--R                                 8a c\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 556
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^4
+--R 
+--R
+--R                        2
+--R                     C x  + B x + A
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        c x  + 4a c x  + 6a c x  + 4a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 115
+
+--S 116 of 556
+r0:=1/6*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2)^3)+1/24*(5*A*c+a*C)*x/(a^2*c*_
+   (a+c*x^2)^2)+1/16*(5*A*c+a*C)*x/(a^3*c*(a+c*x^2))+1/16*(5*A*c+a*C)*_
+   atan(x*sqrt(c)/sqrt(a))/(a^(7/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                 4         3  6           3       2 2  4         2 2       3   2
+--R           (15A c  + 3C a c )x  + (45A a c  + 9C a c )x  + (45A a c  + 9C a c)x
+--R         + 
+--R                3        4
+--R           15A a c + 3C a
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                 3         2  5           2       2   3         2        3
+--R           (15A c  + 3C a c )x  + (40A a c  + 8C a c)x  + (33A a c - 3C a )x
+--R         + 
+--R                 3
+--R           - 8B a
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R         3 4 6       4 3 4       5 2 2      6   +-+ +-+
+--R     (48a c x  + 144a c x  + 144a c x  + 48a c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   4         3  6           3       2 2  4
+--R             (15A c  + 3C a c )x  + (45A a c  + 9C a c )x
+--R           + 
+--R                   2 2       3   2        3        4
+--R             (45A a c  + 9C a c)x  + 15A a c + 3C a
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                   3         2  5           2        2   3         2        3
+--R             (30A c  + 6C a c )x  + (80A a c  + 16C a c)x  + (66A a c - 6C a )x
+--R           + 
+--R                    3
+--R             - 16B a
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R           3 4 6       4 3 4       5 2 2      6   +-----+
+--R       (96a c x  + 288a c x  + 288a c x  + 96a c)\|- a c
+--R     ,
+--R
+--R                   4         3  6           3       2 2  4
+--R             (15A c  + 3C a c )x  + (45A a c  + 9C a c )x
+--R           + 
+--R                   2 2       3   2        3        4
+--R             (45A a c  + 9C a c)x  + 15A a c + 3C a
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                   3         2  5           2       2   3         2        3
+--R             (15A c  + 3C a c )x  + (40A a c  + 8C a c)x  + (33A a c - 3C a )x
+--R           + 
+--R                   3
+--R             - 8B a
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R           3 4 6       4 3 4       5 2 2      6   +---+
+--R       (48a c x  + 144a c x  + 144a c x  + 48a c)\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 117
+
+--S 118 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                   2      +-----+
+--R                    +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R       (5A c + C a)\|a \|c log(---------------------------)
+--R                                            2
+--R                                         c x  + a
+--R     + 
+--R                                      +-+
+--R                        +-----+     x\|c
+--R       (- 10A c - 2C a)\|- a c atan(-----)
+--R                                      +-+
+--R                                     \|a
+--R  /
+--R        3  +-----+ +-+ +-+
+--R     32a c\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R                                   +---+                               +-+
+--R                     +-+ +-+     x\|a c                    +---+     x\|c
+--R        (5A c + C a)\|a \|c atan(-------) + (- 5A c - C a)\|a c atan(-----)
+--R                                    a                                  +-+
+--R                                                                      \|a
+--R   (6)  -------------------------------------------------------------------
+--R                                   3  +-+ +-+ +---+
+--R                                16a c\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 120
+
+--S 121 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 121
+
+)clear all
+
+--S 122 of 556
+t0:=(1+2*x+x^2)/(1+x^2)^2
+--R 
+--R
+--R          2
+--R         x  + 2x + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 122
+
+--S 123 of 556
+r0a:=(-1)/(1+x^2)+atan(x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atan(x) - 1
+--R   (2)  -------------------
+--R                2
+--R               x  + 1
+--R                                                    Type: Expression(Integer)
+--E 123
+
+--S 124 of 556
+r0b:=-1/2*(1-x)*(1+x)/(1+x^2)+atan(x)
+--R 
+--R
+--R           2                2
+--R        (2x  + 2)atan(x) + x  - 1
+--R   (3)  -------------------------
+--R                   2
+--R                 2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atan(x) - 1
+--R   (4)  -------------------
+--R                2
+--R               x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 125
+
+--S 126 of 556
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 556
+m0b:=a0-r0b
+--R 
+--R
+--R          1
+--R   (7)  - -
+--R          2
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 556
+t0:=(2+12*x+3*x^2)/(4+x^2)^2
+--R 
+--R
+--R          2
+--R        3x  + 12x + 2
+--R   (1)  -------------
+--R         4     2
+--R        x  + 8x  + 16
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 130
+
+--S 131 of 556
+r0:=1/4*(-24-5*x)/(4+x^2)+7/8*atan(1/2*x)
+--R 
+--R
+--R           2           x
+--R        (7x  + 28)atan(-) - 10x - 48
+--R                       2
+--R   (2)  ----------------------------
+--R                    2
+--R                  8x  + 32
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2           x
+--R        (7x  + 28)atan(-) - 10x - 48
+--R                       2
+--R   (3)  ----------------------------
+--R                    2
+--R                  8x  + 32
+--R                                         Type: Union(Expression(Integer),...)
+--E 132
+
+--S 133 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 134
+
+)clear all
+
+--S 135 of 556
+t0:=(a+b*x+c*x^2)^(5/2)*(A+C*x^2)
+--R 
+--R
+--R   (1)
+--R          2 6           5       2               2  4                     3
+--R       C c x  + 2C b c x  + (A c  + 2C a c + C b )x  + (2A b c + 2C a b)x
+--R     + 
+--R                    2      2  2                 2
+--R       (2A a c + A b  + C a )x  + 2A a b x + A a
+--R  *
+--R      +--------------+
+--R      |   2
+--R     \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 135
+
+--S 136 of 556
+r0:=-5/6144*(b^2-4*a*c)*(32*A*c^2+9*b^2*C-4*a*c*C)*(b+2*c*x)*_
+   (a+b*x+c*x^2)^(3/2)/c^4+1/384*(32*A*c^2+9*b^2*C-4*a*c*C)*(b+2*c*x)*_
+   (a+b*x+c*x^2)^(5/2)/c^3-1/112*C*(9*b-14*c*x)*(a+b*x+c*x^2)^(7/2)/c^2-_
+   5/32768*(b^2-4*a*c)^3*(32*A*c^2+9*b^2*C-4*a*c*C)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/c^(11/2)+5/16384*(b^2-4*a*c)^2*_
+   (32*A*c^2+9*b^2*C-4*a*c*C)*(b+2*c*x)*sqrt(a+b*x+c*x^2)/c^5
+--R 
+--R
+--R   (2)
+--R                    3 5               2 2           4  4
+--R           215040A a c  + (- 161280A a b  - 26880C a )c
+--R         + 
+--R                      4           3 2  3             6           2 4  2
+--R           (40320A a b  + 80640C a b )c  + (- 3360A b  - 50400C a b )c
+--R         + 
+--R                     6          8
+--R           11760C a b c - 945C b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                   7 7              6 6
+--R           86016C c x  + 202752C b c x
+--R         + 
+--R                     7              6            2 5  5
+--R           (114688A c  + 243712C a c  + 124416C b c )x
+--R         + 
+--R                       6                5         3 4  4
+--R           (286720A b c  + 314368C a b c  + 768C b c )x
+--R         + 
+--R                          6             2            2  5            2 4
+--R               372736A a c  + (193536A b  + 211456C a )c  + 6912C a b c
+--R             + 
+--R                       4 3
+--R               - 864C b c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                            5           3           2   4            3 3
+--R               559104A a b c  + (3584A b  + 22272C a b)c  - 9088C a b c
+--R             + 
+--R                      5 2
+--R               1008C b c
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        2 5              2           3  4
+--R               473088A a c  + (43008A a b  + 26880C a )c
+--R             + 
+--R                         4           2 2  3             4 2          6
+--R               (- 4480A b  - 38208C a b )c  + 12656C a b c  - 1260C b c
+--R          *
+--R             x
+--R         + 
+--R                    2   4                3           3   3
+--R           236544A a b c  + (- 71680A a b  - 84864C a b)c
+--R         + 
+--R                   5           2 3  2             5           7
+--R           (6720A b  + 75488C a b )c  - 21000C a b c + 1890C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R            5 +-+
+--R     688128c \|c
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                   6   8                  5 3              7   7
+--R                     - 220200960A a b c  + (- 220200960A a b  + 27525120C a b)c
+--R                   + 
+--R                                  4 5              6 3  6              5 5 5
+--R                     (151388160A a b  - 34406400C a b )c  - 80855040C a b c
+--R                   + 
+--R                                  2 9              4 7  4
+--R                     (- 9461760A a b  + 42577920C a b )c
+--R                   + 
+--R                                 11             3 9  3
+--R                     (860160A a b   + 1182720C a b )c
+--R                   + 
+--R                            13             2 11  2              13            15
+--R                   (53760A b   - 2768640C a b  )c  + 235200C a b  c + 15120C b
+--R                *
+--R                    7
+--R                   x
+--R               + 
+--R                                   7 8                   6 2              8  7
+--R                     - 440401920A a c  + (- 2642411520A a b  + 55050240C a )c
+--R                   + 
+--R                                  5 4               7 2  6
+--R                     (412876800A a b  + 206438400C a b )c
+--R                   + 
+--R                                  4 6               6 4  5
+--R                     (605552640A a b  - 794787840C a b )c
+--R                   + 
+--R                                    3 8              5 6  4               4 8 3
+--R                     (- 170311680A a b  + 40427520C a b )c  + 191600640C a b c
+--R                   + 
+--R                                  12              3 10  2            2 12
+--R                     (2257920A a b   - 47900160C a b  )c  - 282240C a b  c
+--R                   + 
+--R                                14
+--R                     635040C a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                                    7   7
+--R                     - 6606028800A a b c
+--R                   + 
+--R                                     6 3               8   6
+--R                     (- 4954521600A a b  + 825753600C a b)c
+--R                   + 
+--R                                   5 5                7 3  5
+--R                     (4459069440A a b  - 1238630400C a b )c
+--R                   + 
+--R                                    4 7                6 5  4
+--R                     (- 454164480A a b  - 1950842880C a b )c
+--R                   + 
+--R                                    3 9                5 7  3
+--R                     (- 170311680A a b  + 1310883840C a b )c
+--R                   + 
+--R                                 2 11               4 9  2              3 11
+--R                     (27095040A a b   - 106444800C a b )c  - 51287040C a b  c
+--R                   + 
+--R                               2 13
+--R                     7620480C a b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                                    8 7
+--R                     - 4404019200A a c
+--R                   + 
+--R                                      7 2               9  6
+--R                     (- 20919091200A a b  + 550502400C a )c
+--R                   + 
+--R                                   6 4                8 2  5
+--R                     (8257536000A a b  + 1376256000C a b )c
+--R                   + 
+--R                                   5 6                7 4  4
+--R                     (2339635200A a b  - 6915686400C a b )c
+--R                   + 
+--R                                     4 8                6 6  3
+--R                     (- 1324646400A a b  + 2029977600C a b )c
+--R                   + 
+--R                                  3 10               5 8  2               4 10
+--R                     (141926400A a b   + 823603200C a b )c  - 390297600C a b  c
+--R                   + 
+--R                                3 12
+--R                     39916800C a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                                     8   6
+--R                     - 26424115200A a b c
+--R                   + 
+--R                                     7 3                9   5
+--R                     (- 4404019200A a b  + 3303014400C a b)c
+--R                   + 
+--R                                    6 5                8 3  4
+--R                     (13212057600A a b  - 6881280000C a b )c
+--R                   + 
+--R                                     5 7                7 5  3
+--R                     (- 4128768000A a b  - 2890137600C a b )c
+--R                   + 
+--R                                  4 9                6 7  2                5 9
+--R                     (378470400A a b  + 4231987200C a b )c  - 1208524800C a b c
+--R                   + 
+--R                                 4 11
+--R                     106444800C a b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                                     9 6
+--R                     - 10569646080A a c
+--R                   + 
+--R                                      8 2                10  5
+--R                     (- 26424115200A a b  + 1321205760C a  )c
+--R                   + 
+--R                                    7 4               9 2  4
+--R                     (23781703680A a b  + 330301440C a b )c
+--R                   + 
+--R                                     6 6                 8 4  3
+--R                     (- 6275727360A a b  - 10404495360C a b )c
+--R                   + 
+--R                                  5 8                7 6  2                6 8
+--R                     (536739840A a b  + 7473070080C a b )c  - 1832140800C a b c
+--R                   + 
+--R                                 5 10
+--R                     150958080C a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                                     9   5
+--R                     - 24662507520A a b c
+--R                   + 
+--R                                    8 3                10   4
+--R                     (18496880640A a b  + 3082813440C a  b)c
+--R                   + 
+--R                                     7 5                9 3  3
+--R                     (- 4624220160A a b  - 9248440320C a b )c
+--R                   + 
+--R                                  6 7                8 5  2                7 7
+--R                     (385351680A a b  + 5780275200C a b )c  - 1348730880C a b c
+--R                   + 
+--R                                 6 9
+--R                     108380160C a b
+--R                *
+--R                   x
+--R               + 
+--R                                10 5                 9 2               11  4
+--R                 - 7046430720A a  c  + (5284823040A a b  + 880803840C a  )c
+--R               + 
+--R                                 8 4                10 2  3
+--R                 (- 1321205760A a b  - 2642411520C a  b )c
+--R               + 
+--R                              7 6                9 4  2               8 6
+--R                 (110100480A a b  + 1651507200C a b )c  - 385351680C a b c
+--R               + 
+--R                            7 8
+--R                 30965760C a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                            7 9                6 2             8  8
+--R                 55050240A a c  + (344064000A a b  - 6881280C a )c
+--R               + 
+--R                               5 4              7 2  7
+--R                 (- 37847040A a b  - 27525120C a b )c
+--R               + 
+--R                               4 6               6 4  6              3 8 5
+--R                 (- 85155840A a b  + 101498880C a b )c  + 21288960A a b c
+--R               + 
+--R                           2 10              4 8  4
+--R                 (591360A a b   - 26611200C a b )c
+--R               + 
+--R                               12             3 10  3
+--R                 (- 336000A a b   + 5913600C a b  )c
+--R               + 
+--R                           14            2 12  2             14          16
+--R                 (- 3360A b   + 208320C a b  )c  - 94080C a b  c - 945C b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                              7   8                 6 3               8   7
+--R                 1761607680A a b c  + (1761607680A a b  - 220200960C a b)c
+--R               + 
+--R                                 5 5               7 3  6               6 5 5
+--R                 (- 1211105280A a b  + 275251200C a b )c  + 646840320C a b c
+--R               + 
+--R                             3 9               5 7  4
+--R                 (75694080A a b  - 340623360C a b )c
+--R               + 
+--R                              2 11             4 9  3
+--R                 (- 6881280A a b   - 9461760C a b )c
+--R               + 
+--R                               13              3 11  2             2 13
+--R                 (- 430080A a b   + 22149120C a b  )c  - 1881600C a b  c
+--R               + 
+--R                              15
+--R                 - 120960C a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                              8 8                  7 2               9  7
+--R                 1761607680A a c  + (10569646080A a b  - 220200960C a )c
+--R               + 
+--R                                 6 4               8 2  6
+--R                 (- 1651507200A a b  - 825753600C a b )c
+--R               + 
+--R                                 5 6                7 4  5
+--R                 (- 2422210560A a b  + 3179151360C a b )c
+--R               + 
+--R                              4 8               6 6  4               5 8 3
+--R                 (681246720A a b  - 161710080C a b )c  - 766402560C a b c
+--R               + 
+--R                              2 12               4 10  2             3 12
+--R                 (- 9031680A a b   + 191600640C a b  )c  + 1128960C a b  c
+--R               + 
+--R                             2 14
+--R                 - 2540160C a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                               8   7                  7 3                9   6
+--R                 17616076800A a b c  + (13212057600A a b  - 2202009600C a b)c
+--R               + 
+--R                                  6 5                8 3  5
+--R                 (- 11890851840A a b  + 3303014400C a b )c
+--R               + 
+--R                               5 7                7 5  4
+--R                 (1211105280A a b  + 5202247680C a b )c
+--R               + 
+--R                              4 9                6 7  3
+--R                 (454164480A a b  - 3495690240C a b )c
+--R               + 
+--R                               3 11               5 9  2               4 11
+--R                 (- 72253440A a b   + 283852800C a b )c  + 136765440C a b  c
+--R               + 
+--R                              3 13
+--R                 - 20321280C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                              9 7                  8 2                10  6
+--R                 8808038400A a c  + (41838182400A a b  - 1101004800C a  )c
+--R               + 
+--R                                  7 4                9 2  5
+--R                 (- 16515072000A a b  - 2752512000C a b )c
+--R               + 
+--R                                 6 6                 8 4  4
+--R                 (- 4679270400A a b  + 13831372800C a b )c
+--R               + 
+--R                               5 8                7 6  3
+--R                 (2649292800A a b  - 4059955200C a b )c
+--R               + 
+--R                                4 10                6 8  2               5 10
+--R                 (- 283852800A a b   - 1647206400C a b )c  + 780595200C a b  c
+--R               + 
+--R                              4 12
+--R                 - 79833600C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                               9   6                 8 3                10   5
+--R                 42278584320A a b c  + (7046430720A a b  - 5284823040C a  b)c
+--R               + 
+--R                                  7 5                 9 3  4
+--R                 (- 21139292160A a b  + 11010048000C a b )c
+--R               + 
+--R                               6 7                8 5  3
+--R                 (6606028800A a b  + 4624220160C a b )c
+--R               + 
+--R                                5 9                7 7  2                6 9
+--R                 (- 605552640A a b  - 6771179520C a b )c  + 1933639680C a b c
+--R               + 
+--R                               5 11
+--R                 - 170311680C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                               10 6                  9 2                11  5
+--R                 14092861440A a  c  + (35232153600A a b  - 1761607680C a  )c
+--R               + 
+--R                                  8 4               10 2  4
+--R                 (- 31708938240A a b  - 440401920C a  b )c
+--R               + 
+--R                               7 6                 9 4  3
+--R                 (8367636480A a b  + 13872660480C a b )c
+--R               + 
+--R                                6 8                8 6  2                7 8
+--R                 (- 715653120A a b  - 9964093440C a b )c  + 2442854400C a b c
+--R               + 
+--R                               6 10
+--R                 - 201277440C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                               10   5
+--R                 28185722880A a  b c
+--R               + 
+--R                                  9 3                11   4
+--R                 (- 21139292160A a b  - 3523215360C a  b)c
+--R               + 
+--R                               8 5                 10 3  3
+--R                 (5284823040A a b  + 10569646080C a  b )c
+--R               + 
+--R                                7 7                9 5  2                8 7
+--R                 (- 440401920A a b  - 6606028800C a b )c  + 1541406720C a b c
+--R               + 
+--R                               7 9
+--R                 - 123863040C a b
+--R            *
+--R               x
+--R           + 
+--R                          11 5                   10 2               12  4
+--R             7046430720A a  c  + (- 5284823040A a  b  - 880803840C a  )c
+--R           + 
+--R                           9 4                11 2  3
+--R             (1321205760A a b  + 2642411520C a  b )c
+--R           + 
+--R                            8 6                10 4  2               9 6
+--R             (- 110100480A a b  - 1651507200C a  b )c  + 385351680C a b c
+--R           + 
+--R                          8 8
+--R             - 30965760C a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                              4 11               3 2 10              2 4 9
+--R                 - 22020096C a c   - 154140672C a b c   - 96337920C a b c
+--R               + 
+--R                               6 8           8 7
+--R                 - 9633792C a b c  - 86016C b c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                               4   10                3 3 9               2 5 8
+--R                 - 756547584C a b c   - 1596456960C a b c  - 535363584C a b c
+--R               + 
+--R                                7 7            9 6
+--R                 - 33718272C a b c  - 202752C b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                              4 11                  3 2               5  10
+--R                 - 29360128A a c   + (- 205520896A a b  - 767033344C a )c
+--R               + 
+--R                                2 4                4 2  9
+--R                 (- 128450560A a b  - 6885867520C a b )c
+--R               + 
+--R                                 6                3 4  8
+--R                 (- 12845056A a b  - 6177095680C a b )c
+--R               + 
+--R                             8                2 6  7                8 6
+--R                 (- 114688A b  - 1124515840C a b )c  - 40130560C a b c
+--R               + 
+--R                            10 5
+--R                 - 124416C b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                                4   10
+--R                 - 1012924416A a b c
+--R               + 
+--R                                 3 3                 5   9
+--R                 (- 2157969408A a b  - 10784342016C a b)c
+--R               + 
+--R                                2 5                 4 3  8
+--R                 (- 732168192A a b  - 26857635840C a b )c
+--R               + 
+--R                                 7                 3 5  7
+--R                 (- 46792704A a b  - 11400216576C a b )c
+--R               + 
+--R                             9                2 7  6                9 5
+--R                 (- 286720A b  - 1058168832C a b )c  - 16325632C a b c
+--R               + 
+--R                         11 4
+--R                 - 768C b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                                5 10                   4 2                6  9
+--R                 - 1034944512A a c   + (- 9408086016A a b  - 5573836800C a )c
+--R               + 
+--R                                 3 4                 5 2  8
+--R                 (- 8574074880A a b  - 53438644224C a b )c
+--R               + 
+--R                                 2 6                 4 4  7
+--R                 (- 1594392576A a b  - 51683745792C a b )c
+--R               + 
+--R                                 8                 3 6  6
+--R                 (- 58748928A a b  - 10195820544C a b )c
+--R               + 
+--R                           10               2 8  5            10 4         12 3
+--R               (- 193536A b   - 377439744C a b )c  - 8448C a b  c  + 864C b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                                 5   9
+--R                 - 14940635136A a b c
+--R               + 
+--R                                  4 3                 6   8
+--R                 (- 37879152640A a b  - 49494294528C a b)c
+--R               + 
+--R                                  3 5                  5 3  7
+--R                 (- 16457728000A a b  - 121832833024C a b )c
+--R               + 
+--R                                 2 7                 4 5  6
+--R                 (- 1578680320A a b  - 48699019264C a b )c
+--R               + 
+--R                                 9                3 7  5
+--R                 (- 25733120A a b  - 3578810368C a b )c
+--R               + 
+--R                           11           2 9  4            11 3          13 2
+--R                 (- 3584A b   + 14080C a b )c  + 6784C a b  c  - 1008C b  c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                                6 9                    5 2                 7  8
+--R                 - 7872184320A a c  + (- 76960235520A a b  - 17358716928C a )c
+--R               + 
+--R                                  4 4                  6 2  7
+--R                 (- 76296192000A a b  - 155906064384C a b )c
+--R               + 
+--R                                  3 6                  5 4  6
+--R                 (- 15558574080A a b  - 131256029184C a b )c
+--R               + 
+--R                                2 8                 4 6  5            3 8 4
+--R                 (- 604907520A a b  - 18049145856C a b )c  + 380160C a b c
+--R               + 
+--R                         12           2 10  3           12 2          14
+--R                 (4480A b   - 95040C a b  )c  - 560C a b  c  + 1260C b  c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                                 6   8
+--R                 - 73343434752A a b c
+--R               + 
+--R                                   5 3                  7   7
+--R                 (- 185403703296A a b  - 103057489920C a b)c
+--R               + 
+--R                                  4 5                  6 3  6
+--R                 (- 76665372672A a b  - 210067415040C a b )c
+--R               + 
+--R                                 3 7                 5 5  5
+--R                 (- 5888999424A a b  - 54390540288C a b )c
+--R               + 
+--R                            2 9             4 7  4
+--R                 (1182720A a b  - 5322240C a b )c
+--R               + 
+--R                               11            3 9  3
+--R                 (- 107520A a b   - 147840C a b )c
+--R               + 
+--R                           13            2 11  2             13           15
+--R                 (- 6720A b   + 346080C a b  )c  - 29400C a b  c - 1890C b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                                 7 8
+--R                 - 26658996224A a c
+--R               + 
+--R                                   6 2                 8  7
+--R                 (- 246705815552A a b  - 27671920640C a )c
+--R               + 
+--R                                   5 4                  7 2  6
+--R                 (- 215813455872A a b  - 198754304000C a b )c
+--R               + 
+--R                                  4 6                  6 4  5
+--R                 (- 31115313152A a b  - 103019642880C a b )c
+--R               + 
+--R                             3 8              5 6  4
+--R                 (65830912A a b  - 32055296C a b )c
+--R               + 
+--R                              2 10              4 8  3
+--R                 (- 1003520A a b   - 68648960C a b )c
+--R               + 
+--R                               12              3 10  2            2 12
+--R                 (- 752640A a b   + 18640384C a b  )c  - 188160C a b  c
+--R               + 
+--R                              14
+--R                 - 211680C a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                                  7   7
+--R                 - 170215342080A a b c
+--R               + 
+--R                                   6 3                  8   6
+--R                 (- 363423334400A a b  - 103356825600C a b)c
+--R               + 
+--R                                   5 5                  7 3  5
+--R                 (- 100802494464A a b  - 124546580480C a b )c
+--R               + 
+--R                              4 7                6 5  4
+--R                 (301400064A a b  + 1016709120C a b )c
+--R               + 
+--R                             3 9               5 7  3
+--R                 (78274560A a b  - 729759744C a b )c
+--R               + 
+--R                               2 11              4 9  2              3 11
+--R                 (- 13547520A a b   + 74984448C a b )c  + 23708160C a b  c
+--R               + 
+--R                             2 13
+--R                 - 3810240C a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                                 8 7
+--R                 - 47563407360A a c
+--R               + 
+--R                                   7 2                 9  6
+--R                 (- 360028569600A a b  - 22944940032C a )c
+--R               + 
+--R                                   6 4                 8 2  5
+--R                 (- 206658600960A a b  - 95297470464C a b )c
+--R               + 
+--R                                 5 6                7 4  4
+--R                 (- 1288175616A a b  + 4727439360C a b )c
+--R               + 
+--R                              4 8                6 6  3
+--R                 (825753600A a b  - 1529708544C a b )c
+--R               + 
+--R                               3 10               5 8  2               4 10
+--R                 (- 90316800A a b   - 465518592C a b )c  + 243532800C a b  c
+--R               + 
+--R                              3 12
+--R                 - 25401600C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                                  8   6
+--R                 - 192749240320A a b c
+--R               + 
+--R                                   7 3                 9   5
+--R                 (- 263580549120A a b  - 43023597568C a b)c
+--R               + 
+--R                                 6 5                8 3  4
+--R                 (- 9688842240A a b  + 5601361920C a b )c
+--R               + 
+--R                               5 7                7 5  3
+--R                 (3078225920A a b  + 1892352000C a b )c
+--R               + 
+--R                                4 9                6 7  2               5 9
+--R                 (- 283852800A a b  - 3109765120C a b )c  + 901232640C a b c
+--R               + 
+--R                              4 11
+--R                 - 79833600C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                                 9 6
+--R                 - 43218108416A a c
+--R               + 
+--R                                   8 2                10  5
+--R                 (- 200647114752A a b  - 8690597888C a  )c
+--R               + 
+--R                                  7 4               9 2  4
+--R                 (- 20038287360A a b  - 110100480C a b )c
+--R               + 
+--R                               6 6                8 4  3
+--R                 (5303173120A a b  + 8697937920C a b )c
+--R               + 
+--R                                5 8                7 6  2                6 8
+--R                 (- 454164480A a b  - 6298664960C a b )c  + 1548288000C a b c
+--R               + 
+--R                               5 10
+--R                 - 127733760C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                                 9   5
+--R                 - 84204847104A a b c
+--R               + 
+--R                                  8 3                10   4
+--R                 (- 17175674880A a b  - 2862612480C a  b)c
+--R               + 
+--R                               7 5                9 3  3
+--R                 (4293918720A a b  + 8587837440C a b )c
+--R               + 
+--R                                6 7                8 5  2                7 7
+--R                 (- 357826560A a b  - 5367398400C a b )c  + 1252392960C a b c
+--R               + 
+--R                               6 9
+--R                 - 100638720C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                                 10 5                   9 2               11  4
+--R                 - 15502147584A a  c  + (- 5284823040A a b  - 880803840C a  )c
+--R               + 
+--R                               8 4                10 2  3
+--R                 (1321205760A a b  + 2642411520C a  b )c
+--R               + 
+--R                                7 6                9 4  2               8 6
+--R                 (- 110100480A a b  - 1651507200C a b )c  + 385351680C a b c
+--R               + 
+--R                              7 8
+--R                 - 30965760C a b
+--R            *
+--R               x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                            3   11               2 3 10                5 9
+--R                 88080384C a b c   + 154140672C a b c   + 38535168C a b c
+--R               + 
+--R                           7 8
+--R                 1376256C b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                             4 11                3 2 10                2 4 9
+--R                 176160768C a c   + 1484783616C a b c   + 1211105280C a b c
+--R               + 
+--R                               6 8             8 7
+--R                 187170816C a b c  + 4620288C b c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                             3   11                2 3                4   10
+--R                 117440512A a b c   + (205520896A a b  + 3571449856C a b)c
+--R               + 
+--R                               5                3 3  9
+--R                 (51380224A a b  + 8881438720C a b )c
+--R               + 
+--R                            7                2 5  8                 7 7
+--R                 (1835008A b  + 3756261376C a b )c  + 345899008C a b c
+--R               + 
+--R                           9 6
+--R                 5234688C b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                             4 11                 3 2                5  10
+--R                 234881024A a c   + (1996488704A a b  + 2436890624C a )c
+--R               + 
+--R                               2 4                 4 2  9
+--R                 (1644167168A a b  + 24567087104C a b )c
+--R               + 
+--R                                6                 3 4  8
+--R                 (256901120A a b  + 25613041664C a b )c
+--R               + 
+--R                            8                2 6  7                 8 6
+--R                 (6422528A b  + 5753667584C a b )c  + 288112640C a b c
+--R               + 
+--R                           10 5
+--R                 2002944C b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                              4   10                  3 3                 5   9
+--R                 4844421120A a b c   + (12199133184A a b  + 28637134848C a b)c
+--R               + 
+--R                               2 5                 4 3  8
+--R                 (5240782848A a b  + 79506309120C a b )c
+--R               + 
+--R                                7                 3 5  7
+--R                 (492699648A a b  + 38800785408C a b )c
+--R               + 
+--R                            9                2 7  6                9 5
+--R                 (7684096A b  + 4365828096C a b )c  + 91211776C a b c
+--R               + 
+--R                          11 4
+--R                 - 1536C b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                              5 10                  4 2                 6  9
+--R                 3347054592A a c   + (34219229184A a b  + 11912871936C a )c
+--R               + 
+--R                                3 4                  5 2  8
+--R                 (36296458240A a b  + 124204351488C a b )c
+--R               + 
+--R                               2 6                  4 4  7
+--R                 (8336441344A a b  + 133023858688C a b )c
+--R               + 
+--R                                8                 3 6  6
+--R                 (430538752A a b  + 29865213952C a b )c
+--R               + 
+--R                            10                2 8  5             10 4
+--R                 (3153920A b   + 1316614144C a b )c  - 22528C a b  c
+--R               + 
+--R                        12 3
+--R                 2304C b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                               5   9                   4 3                 6   8
+--R                 40649097216A a b c  + (114926551040A a b  + 95506661376C a b)c
+--R               + 
+--R                                3 5                  5 3  7
+--R                 (57371525120A a b  + 254393581568C a b )c
+--R               + 
+--R                               2 7                  4 5  6
+--R                 (6649610240A a b  + 111789719552C a b )c
+--R               + 
+--R                                9                3 7  5
+--R                 (144793600A a b  + 9240756224C a b )c
+--R               + 
+--R                            11           2 9  4             11 3          13 2
+--R                 (- 14336A b   + 56320C a b )c  + 27136C a b  c  - 4032C b  c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                               6 9                   5 2                 7  8
+--R                 17351835648A a c  + (184440324096A a b  + 28835315712C a )c
+--R               + 
+--R                                 4 4                  6 2  7
+--R                 (202172006400A a b  + 275837485056C a b )c
+--R               + 
+--R                                3 6                  5 4  6
+--R                 (46693613568A a b  + 249753993216C a b )c
+--R               + 
+--R                               2 8                 4 6  5             3 8 4
+--R                 (2130100224A a b  + 37426765824C a b )c  + 3041280C a b c
+--R               + 
+--R                          12            2 10  3            12 2           14
+--R                 (35840A b   - 760320C a b  )c  - 4480C a b  c  + 10080C b  c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                                6   8
+--R                 146740084736A a b c
+--R               + 
+--R                                 5 3                  7   7
+--R                 (400969433088A a b  + 159128453120C a b)c
+--R               + 
+--R                                 4 5                  6 3  6
+--R                 (181613838336A a b  + 343283834880C a b )c
+--R               + 
+--R                                3 7                 5 5  5
+--R                 (15427371008A a b  + 94707529728C a b )c
+--R               + 
+--R                               2 9               4 7  4
+--R                 (- 23360512A a b  + 135801344C a b )c
+--R               + 
+--R                              11             3 9  3
+--R                 (2616320A a b   - 3899776C a b )c
+--R               + 
+--R                           13             2 11  2              13            15
+--R                 (100800A b   - 6897184C a b  )c  + 723240C a b  c + 28350C b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                               7 8                   6 2                 8  7
+--R                 46007320576A a c  + (453202935808A a b  + 38113116160C a )c
+--R               + 
+--R                                 5 4                  7 2  6
+--R                 (426292543488A a b  + 286238310400C a b )c
+--R               + 
+--R                                4 6                  6 4  5
+--R                 (66497019904A a b  + 154660208640C a b )c
+--R               + 
+--R                                3 8               5 6  4
+--R                 (- 356335616A a b  + 216014848C a b )c
+--R               + 
+--R                            2 10               4 8  3
+--R                 (8028160A a b   + 357591040C a b )c
+--R               + 
+--R                              12               3 10  2             2 12
+--R                 (3763200A a b   - 101222912C a b  )c  + 1787520C a b  c
+--R               + 
+--R                             14
+--R                 1058400C a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                                7   7
+--R                 271948185600A a b c
+--R               + 
+--R                                 6 3                  8   6
+--R                 (615883735040A a b  + 133975769088C a b)c
+--R               + 
+--R                                 5 5                  7 3  5
+--R                 (183377854464A a b  + 165509464064C a b )c
+--R               + 
+--R                                4 7                6 5  4
+--R                 (- 978518016A a b  - 3091415040C a b )c
+--R               + 
+--R                                3 9                5 7  3
+--R                 (- 227942400A a b  + 2263597056C a b )c
+--R               + 
+--R                             2 11               4 9  2              3 11
+--R                 (40642560A a b   - 246715392C a b )c  - 69189120C a b  c
+--R               + 
+--R                            2 13
+--R                 11430720C a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                               8 7                   7 2                 9  6
+--R                 67234693120A a c  + (532519321600A a b  + 27180138496C a )c
+--R               + 
+--R                                 6 4                  8 2  5
+--R                 (324906516480A a b  + 115557793792C a b )c
+--R               + 
+--R                               5 6                 7 4  4
+--R                 (2655256576A a b  - 10301276160C a b )c
+--R               + 
+--R                                 4 8                6 6  3
+--R                 (- 1760460800A a b  + 3402563584C a b )c
+--R               + 
+--R                              3 10               5 8  2               4 10
+--R                 (193536000A a b   + 966848512C a b )c  - 519321600C a b  c
+--R               + 
+--R                            3 12
+--R                 54432000C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                                8   6
+--R                 252585181184A a b c
+--R               + 
+--R                                 7 3                 9   5
+--R                 (361614016512A a b  + 48580001792C a b)c
+--R               + 
+--R                                6 5                8 3  4
+--R                 (16074670080A a b  - 9482403840C a b )c
+--R               + 
+--R                                 5 7                7 5  3
+--R                 (- 5124259840A a b  - 3062169600C a b )c
+--R               + 
+--R                              4 9                6 7  2                5 9
+--R                 (473088000A a b  + 5161533440C a b )c  - 1500334080C a b c
+--R               + 
+--R                             4 11
+--R                 133056000C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                               9 6                   8 2                10  5
+--R                 50969182208A a c  + (243454181376A a b  + 9130999808C a  )c
+--R               + 
+--R                                7 4               9 2  4
+--R                 (27304919040A a b  + 110100480C a b )c
+--R               + 
+--R                                 6 6                 8 4  3
+--R                 (- 7229931520A a b  - 11835801600C a b )c
+--R               + 
+--R                              5 8                7 6  2                6 8
+--R                 (619315200A a b  + 8583249920C a b )c  - 2110832640C a b c
+--R               + 
+--R                             5 10
+--R                 174182400C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                               9   5                  8 3                10   4
+--R                 91955920896A a b c  + (19818086400A a b  + 3303014400C a  b)c
+--R               + 
+--R                                 7 5                9 3  3
+--R                 (- 4954521600A a b  - 9909043200C a b )c
+--R               + 
+--R                              6 7                8 5  2                7 7
+--R                 (412876800A a b  + 6193152000C a b )c  - 1445068800C a b c
+--R               + 
+--R                             6 9
+--R                 116121600C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                               10 5                 9 2               11  4
+--R                 15502147584A a  c  + (5284823040A a b  + 880803840C a  )c
+--R               + 
+--R                                 8 4                10 2  3
+--R                 (- 1321205760A a b  - 2642411520C a  b )c
+--R               + 
+--R                              7 6                9 4  2               8 6
+--R                 (110100480A a b  + 1651507200C a b )c  - 385351680C a b c
+--R               + 
+--R                            7 8
+--R                 30965760C a b
+--R            *
+--R               x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                           3   8              2 3 7               5 6
+--R                 704643072a b c  + 1233125376a b c  + 308281344a b c
+--R               + 
+--R                          7 5
+--R                 11010048b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                            4 8              3 2 7              2 4 6
+--R                 1409286144a c  + 9512681472a b c  + 5549064192a b c
+--R               + 
+--R                             6 5
+--R                 462422016a b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          4   7               3 3 6              2 5 5  5
+--R             (21139292160a b c  + 31708938240a b c  + 5549064192a b c )x
+--R           + 
+--R                          5 7               4 2 6               3 4 5  4
+--R             (14092861440a c  + 77510737920a b c  + 29066526720a b c )x
+--R           + 
+--R                          5   6               4 3 5  3
+--R             (84557168640a b c  + 77510737920a b c )x
+--R           + 
+--R                          6 6                5 2 5  2               6   5
+--R             (33822867456a c  + 109924319232a b c )x  + 78920024064a b c x
+--R           + 
+--R                         7 5
+--R             22548578304a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                             4 9              3 2 8             2 4 7
+--R                 - 176160768a c  - 1233125376a b c  - 770703360a b c
+--R               + 
+--R                              6 6          8 5
+--R                 - 77070336a b c  - 688128b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                              4   8              3 3 7              2 5 6
+--R                 - 5637144576a b c  - 9865003008a b c  - 2466250752a b c
+--R               + 
+--R                              7 5
+--R                 - 88080384a b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                              5 8               4 2 7               3 4 6
+--R                 - 5637144576a c  - 38050725888a b c  - 22196256768a b c
+--R               + 
+--R                              2 6 5
+--R                 - 1849688064a b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            5   7               4 3 6               3 5 5  5
+--R             (- 56371445760a b c  - 84557168640a b c  - 14797504512a b c )x
+--R           + 
+--R                            6 7                5 2 6               4 4 5  4
+--R             (- 28185722880a c  - 155021475840a b c  - 58133053440a b c )x
+--R           + 
+--R                             6   6                5 3 5  3
+--R             (- 135291469824a b c  - 124017180672a b c )x
+--R           + 
+--R                            7 6                6 2 5  2               7   5
+--R             (- 45097156608a c  - 146565758976a b c )x  - 90194313216a b c x
+--R           + 
+--R                           8 5
+--R             - 22548578304a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                                 6   8                5 3              7   7
+--R                     220200960A a b c  + (220200960A a b  - 27525120C a b)c
+--R                   + 
+--R                                    4 5              6 3  6              5 5 5
+--R                     (- 151388160A a b  + 34406400C a b )c  + 80855040C a b c
+--R                   + 
+--R                                2 9              4 7  4
+--R                     (9461760A a b  - 42577920C a b )c
+--R                   + 
+--R                                   11             3 9  3
+--R                     (- 860160A a b   - 1182720C a b )c
+--R                   + 
+--R                                13             2 11  2              13
+--R                     (- 53760A b   + 2768640C a b  )c  - 235200C a b  c
+--R                   + 
+--R                               15
+--R                     - 15120C b
+--R                *
+--R                    7
+--R                   x
+--R               + 
+--R                                 7 8                 6 2              8  7
+--R                     440401920A a c  + (2642411520A a b  - 55050240C a )c
+--R                   + 
+--R                                    5 4               7 2  6
+--R                     (- 412876800A a b  - 206438400C a b )c
+--R                   + 
+--R                                    4 6               6 4  5
+--R                     (- 605552640A a b  + 794787840C a b )c
+--R                   + 
+--R                                  3 8              5 6  4               4 8 3
+--R                     (170311680A a b  - 40427520C a b )c  - 191600640C a b c
+--R                   + 
+--R                                    12              3 10  2            2 12
+--R                     (- 2257920A a b   + 47900160C a b  )c  + 282240C a b  c
+--R                   + 
+--R                                  14
+--R                     - 635040C a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                                  7   7                 6 3               8   6
+--R                     6606028800A a b c  + (4954521600A a b  - 825753600C a b)c
+--R                   + 
+--R                                     5 5                7 3  5
+--R                     (- 4459069440A a b  + 1238630400C a b )c
+--R                   + 
+--R                                  4 7                6 5  4
+--R                     (454164480A a b  + 1950842880C a b )c
+--R                   + 
+--R                                  3 9                5 7  3
+--R                     (170311680A a b  - 1310883840C a b )c
+--R                   + 
+--R                                   2 11               4 9  2              3 11
+--R                     (- 27095040A a b   + 106444800C a b )c  + 51287040C a b  c
+--R                   + 
+--R                                 2 13
+--R                     - 7620480C a b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                                  8 7                  7 2               9  6
+--R                     4404019200A a c  + (20919091200A a b  - 550502400C a )c
+--R                   + 
+--R                                     6 4                8 2  5
+--R                     (- 8257536000A a b  - 1376256000C a b )c
+--R                   + 
+--R                                     5 6                7 4  4
+--R                     (- 2339635200A a b  + 6915686400C a b )c
+--R                   + 
+--R                                   4 8                6 6  3
+--R                     (1324646400A a b  - 2029977600C a b )c
+--R                   + 
+--R                                    3 10               5 8  2
+--R                     (- 141926400A a b   - 823603200C a b )c
+--R                   + 
+--R                                 4 10               3 12
+--R                     390297600C a b  c - 39916800C a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                                   8   6
+--R                     26424115200A a b c
+--R                   + 
+--R                                   7 3                9   5
+--R                     (4404019200A a b  - 3303014400C a b)c
+--R                   + 
+--R                                      6 5                8 3  4
+--R                     (- 13212057600A a b  + 6881280000C a b )c
+--R                   + 
+--R                                   5 7                7 5  3
+--R                     (4128768000A a b  + 2890137600C a b )c
+--R                   + 
+--R                                    4 9                6 7  2
+--R                     (- 378470400A a b  - 4231987200C a b )c
+--R                   + 
+--R                                  5 9                4 11
+--R                     1208524800C a b c - 106444800C a b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                                   9 6                  8 2                10  5
+--R                     10569646080A a c  + (26424115200A a b  - 1321205760C a  )c
+--R                   + 
+--R                                      7 4               9 2  4
+--R                     (- 23781703680A a b  - 330301440C a b )c
+--R                   + 
+--R                                   6 6                 8 4  3
+--R                     (6275727360A a b  + 10404495360C a b )c
+--R                   + 
+--R                                    5 8                7 6  2
+--R                     (- 536739840A a b  - 7473070080C a b )c
+--R                   + 
+--R                                  6 8                5 10
+--R                     1832140800C a b c - 150958080C a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                                   9   5
+--R                     24662507520A a b c
+--R                   + 
+--R                                      8 3                10   4
+--R                     (- 18496880640A a b  - 3082813440C a  b)c
+--R                   + 
+--R                                   7 5                9 3  3
+--R                     (4624220160A a b  + 9248440320C a b )c
+--R                   + 
+--R                                    6 7                8 5  2
+--R                     (- 385351680A a b  - 5780275200C a b )c
+--R                   + 
+--R                                  7 7                6 9
+--R                     1348730880C a b c - 108380160C a b
+--R                *
+--R                   x
+--R               + 
+--R                              10 5                   9 2               11  4
+--R                 7046430720A a  c  + (- 5284823040A a b  - 880803840C a  )c
+--R               + 
+--R                               8 4                10 2  3
+--R                 (1321205760A a b  + 2642411520C a  b )c
+--R               + 
+--R                                7 6                9 4  2               8 6
+--R                 (- 110100480A a b  - 1651507200C a b )c  + 385351680C a b c
+--R               + 
+--R                              7 8
+--R                 - 30965760C a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                              7 9                  6 2             8  8
+--R                 - 55050240A a c  + (- 344064000A a b  + 6881280C a )c
+--R               + 
+--R                             5 4              7 2  7
+--R                 (37847040A a b  + 27525120C a b )c
+--R               + 
+--R                             4 6               6 4  6              3 8 5
+--R                 (85155840A a b  - 101498880C a b )c  - 21288960A a b c
+--R               + 
+--R                             2 10              4 8  4
+--R                 (- 591360A a b   + 26611200C a b )c
+--R               + 
+--R                             12             3 10  3
+--R                 (336000A a b   - 5913600C a b  )c
+--R               + 
+--R                         14            2 12  2             14          16
+--R                 (3360A b   - 208320C a b  )c  + 94080C a b  c + 945C b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                                7   8                   6 3               8   7
+--R                 - 1761607680A a b c  + (- 1761607680A a b  + 220200960C a b)c
+--R               + 
+--R                               5 5               7 3  6               6 5 5
+--R                 (1211105280A a b  - 275251200C a b )c  - 646840320C a b c
+--R               + 
+--R                               3 9               5 7  4
+--R                 (- 75694080A a b  + 340623360C a b )c
+--R               + 
+--R                            2 11             4 9  3
+--R                 (6881280A a b   + 9461760C a b )c
+--R               + 
+--R                             13              3 11  2             2 13
+--R                 (430080A a b   - 22149120C a b  )c  + 1881600C a b  c
+--R               + 
+--R                            15
+--R                 120960C a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                                8 8                    7 2               9  7
+--R                 - 1761607680A a c  + (- 10569646080A a b  + 220200960C a )c
+--R               + 
+--R                               6 4               8 2  6
+--R                 (1651507200A a b  + 825753600C a b )c
+--R               + 
+--R                               5 6                7 4  5
+--R                 (2422210560A a b  - 3179151360C a b )c
+--R               + 
+--R                                4 8               6 6  4               5 8 3
+--R                 (- 681246720A a b  + 161710080C a b )c  + 766402560C a b c
+--R               + 
+--R                            2 12               4 10  2             3 12
+--R                 (9031680A a b   - 191600640C a b  )c  - 1128960C a b  c
+--R               + 
+--R                           2 14
+--R                 2540160C a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                                 8   7
+--R                 - 17616076800A a b c
+--R               + 
+--R                                  7 3                9   6
+--R                 (- 13212057600A a b  + 2202009600C a b)c
+--R               + 
+--R                                6 5                8 3  5
+--R                 (11890851840A a b  - 3303014400C a b )c
+--R               + 
+--R                                 5 7                7 5  4
+--R                 (- 1211105280A a b  - 5202247680C a b )c
+--R               + 
+--R                                4 9                6 7  3
+--R                 (- 454164480A a b  + 3495690240C a b )c
+--R               + 
+--R                             3 11               5 9  2               4 11
+--R                 (72253440A a b   - 283852800C a b )c  - 136765440C a b  c
+--R               + 
+--R                            3 13
+--R                 20321280C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                                9 7                    8 2                10  6
+--R                 - 8808038400A a c  + (- 41838182400A a b  + 1101004800C a  )c
+--R               + 
+--R                                7 4                9 2  5
+--R                 (16515072000A a b  + 2752512000C a b )c
+--R               + 
+--R                               6 6                 8 4  4
+--R                 (4679270400A a b  - 13831372800C a b )c
+--R               + 
+--R                                 5 8                7 6  3
+--R                 (- 2649292800A a b  + 4059955200C a b )c
+--R               + 
+--R                              4 10                6 8  2               5 10
+--R                 (283852800A a b   + 1647206400C a b )c  - 780595200C a b  c
+--R               + 
+--R                            4 12
+--R                 79833600C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                                 9   6
+--R                 - 42278584320A a b c
+--R               + 
+--R                                 8 3                10   5
+--R                 (- 7046430720A a b  + 5284823040C a  b)c
+--R               + 
+--R                                7 5                 9 3  4
+--R                 (21139292160A a b  - 11010048000C a b )c
+--R               + 
+--R                                 6 7                8 5  3
+--R                 (- 6606028800A a b  - 4624220160C a b )c
+--R               + 
+--R                              5 9                7 7  2                6 9
+--R                 (605552640A a b  + 6771179520C a b )c  - 1933639680C a b c
+--R               + 
+--R                             5 11
+--R                 170311680C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                                 10 6
+--R                 - 14092861440A a  c
+--R               + 
+--R                                  9 2                11  5
+--R                 (- 35232153600A a b  + 1761607680C a  )c
+--R               + 
+--R                                8 4               10 2  4
+--R                 (31708938240A a b  + 440401920C a  b )c
+--R               + 
+--R                                 7 6                 9 4  3
+--R                 (- 8367636480A a b  - 13872660480C a b )c
+--R               + 
+--R                              6 8                8 6  2                7 8
+--R                 (715653120A a b  + 9964093440C a b )c  - 2442854400C a b c
+--R               + 
+--R                             6 10
+--R                 201277440C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                                 10   5
+--R                 - 28185722880A a  b c
+--R               + 
+--R                                9 3                11   4
+--R                 (21139292160A a b  + 3523215360C a  b)c
+--R               + 
+--R                                 8 5                 10 3  3
+--R                 (- 5284823040A a b  - 10569646080C a  b )c
+--R               + 
+--R                              7 7                9 5  2                8 7
+--R                 (440401920A a b  + 6606028800C a b )c  - 1541406720C a b c
+--R               + 
+--R                             7 9
+--R                 123863040C a b
+--R            *
+--R               x
+--R           + 
+--R                            11 5                 10 2               12  4
+--R             - 7046430720A a  c  + (5284823040A a  b  + 880803840C a  )c
+--R           + 
+--R                             9 4                11 2  3
+--R             (- 1321205760A a b  - 2642411520C a  b )c
+--R           + 
+--R                          8 6                10 4  2               9 6
+--R             (110100480A a b  + 1651507200C a  b )c  - 385351680C a b c
+--R           + 
+--R                        8 8
+--R             30965760C a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                              4 11              3 2 10              2 4 9
+--R                 - 11010048C a c   - 77070336C a b c   - 48168960C a b c
+--R               + 
+--R                               6 8           8 7
+--R                 - 4816896C a b c  - 43008C b c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                               4   10               3 3 9               2 5 8
+--R                 - 378273792C a b c   - 798228480C a b c  - 267681792C a b c
+--R               + 
+--R                                7 7            9 6
+--R                 - 16859136C a b c  - 101376C b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                              4 11                  3 2               5  10
+--R                 - 14680064A a c   + (- 102760448A a b  - 383516672C a )c
+--R               + 
+--R                               2 4                4 2  9
+--R                 (- 64225280A a b  - 3442933760C a b )c
+--R               + 
+--R                                6                3 4  8
+--R                 (- 6422528A a b  - 3088547840C a b )c
+--R               + 
+--R                            8               2 6  7                8 6
+--R                 (- 57344A b  - 562257920C a b )c  - 20065280C a b c
+--R               + 
+--R                           10 5
+--R                 - 62208C b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                               4   10                   3 3                5   9
+--R                 - 506462208A a b c   + (- 1078984704A a b  - 5392171008C a b)c
+--R               + 
+--R                                2 5                 4 3  8
+--R                 (- 366084096A a b  - 13428817920C a b )c
+--R               + 
+--R                                 7                3 5  7
+--R                 (- 23396352A a b  - 5700108288C a b )c
+--R               + 
+--R                           9               2 7  6               9 5         11 4
+--R               (- 143360A b  - 529084416C a b )c  - 8162816C a b c  - 384C b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                               5 10                   4 2                6  9
+--R                 - 517472256A a c   + (- 4704043008A a b  - 2786918400C a )c
+--R               + 
+--R                                 3 4                 5 2  8
+--R                 (- 4287037440A a b  - 26719322112C a b )c
+--R               + 
+--R                                2 6                 4 4  7
+--R                 (- 797196288A a b  - 25841872896C a b )c
+--R               + 
+--R                                 8                3 6  6
+--R                 (- 29374464A a b  - 5097910272C a b )c
+--R               + 
+--R                          10               2 8  5            10 4         12 3
+--R               (- 96768A b   - 188719872C a b )c  - 4224C a b  c  + 432C b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                                5   9
+--R                 - 7470317568A a b c
+--R               + 
+--R                                  4 3                 6   8
+--R                 (- 18939576320A a b  - 24747147264C a b)c
+--R               + 
+--R                                 3 5                 5 3  7
+--R                 (- 8228864000A a b  - 60916416512C a b )c
+--R               + 
+--R                                2 7                 4 5  6
+--R                 (- 789340160A a b  - 24349509632C a b )c
+--R               + 
+--R                                 9                3 7  5
+--R                 (- 12866560A a b  - 1789405184C a b )c
+--R               + 
+--R                           11          2 9  4            11 3         13 2
+--R                 (- 1792A b   + 7040C a b )c  + 3392C a b  c  - 504C b  c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                                6 9                    5 2                7  8
+--R                 - 3936092160A a c  + (- 38480117760A a b  - 8679358464C a )c
+--R               + 
+--R                                  4 4                 6 2  7
+--R                 (- 38148096000A a b  - 77953032192C a b )c
+--R               + 
+--R                                 3 6                 5 4  6
+--R                 (- 7779287040A a b  - 65628014592C a b )c
+--R               + 
+--R                                2 8                4 6  5            3 8 4
+--R                 (- 302453760A a b  - 9024572928C a b )c  + 190080C a b c
+--R               + 
+--R                         12           2 10  3           12 2         14
+--R                 (2240A b   - 47520C a b  )c  - 280C a b  c  + 630C b  c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                                 6   8
+--R                 - 36671717376A a b c
+--R               + 
+--R                                  5 3                 7   7
+--R                 (- 92701851648A a b  - 51528744960C a b)c
+--R               + 
+--R                                  4 5                  6 3  6
+--R                 (- 38332686336A a b  - 105033707520C a b )c
+--R               + 
+--R                                 3 7                 5 5  5
+--R                 (- 2944499712A a b  - 27195270144C a b )c
+--R               + 
+--R                           2 9             4 7  4
+--R                 (591360A a b  - 2661120C a b )c
+--R               + 
+--R                              11           3 9  3
+--R                 (- 53760A a b   - 73920C a b )c
+--R               + 
+--R                           13            2 11  2             13          15
+--R                 (- 3360A b   + 173040C a b  )c  - 14700C a b  c - 945C b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                                 7 8
+--R                 - 13329498112A a c
+--R               + 
+--R                                   6 2                 8  7
+--R                 (- 123352907776A a b  - 13835960320C a )c
+--R               + 
+--R                                   5 4                 7 2  6
+--R                 (- 107906727936A a b  - 99377152000C a b )c
+--R               + 
+--R                                  4 6                 6 4  5
+--R                 (- 15557656576A a b  - 51509821440C a b )c
+--R               + 
+--R                             3 8              5 6  4
+--R                 (32915456A a b  - 16027648C a b )c
+--R               + 
+--R                             2 10              4 8  3
+--R                 (- 501760A a b   - 34324480C a b )c
+--R               + 
+--R                               12             3 10  2           2 12
+--R                 (- 376320A a b   + 9320192C a b  )c  - 94080C a b  c
+--R               + 
+--R                              14
+--R                 - 105840C a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                                 7   7
+--R                 - 85107671040A a b c
+--R               + 
+--R                                   6 3                 8   6
+--R                 (- 181711667200A a b  - 51678412800C a b)c
+--R               + 
+--R                                  5 5                 7 3  5
+--R                 (- 50401247232A a b  - 62273290240C a b )c
+--R               + 
+--R                              4 7               6 5  4
+--R                 (150700032A a b  + 508354560C a b )c
+--R               + 
+--R                             3 9               5 7  3
+--R                 (39137280A a b  - 364879872C a b )c
+--R               + 
+--R                              2 11              4 9  2              3 11
+--R                 (- 6773760A a b   + 37492224C a b )c  + 11854080C a b  c
+--R               + 
+--R                             2 13
+--R                 - 1905120C a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                                 8 7
+--R                 - 23781703680A a c
+--R               + 
+--R                                   7 2                 9  6
+--R                 (- 180014284800A a b  - 11472470016C a )c
+--R               + 
+--R                                   6 4                 8 2  5
+--R                 (- 103329300480A a b  - 47648735232C a b )c
+--R               + 
+--R                                5 6                7 4  4
+--R                 (- 644087808A a b  + 2363719680C a b )c
+--R               + 
+--R                              4 8               6 6  3
+--R                 (412876800A a b  - 764854272C a b )c
+--R               + 
+--R                               3 10               5 8  2               4 10
+--R                 (- 45158400A a b   - 232759296C a b )c  + 121766400C a b  c
+--R               + 
+--R                              3 12
+--R                 - 12700800C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                                 8   6
+--R                 - 96374620160A a b c
+--R               + 
+--R                                   7 3                 9   5
+--R                 (- 131790274560A a b  - 21511798784C a b)c
+--R               + 
+--R                                 6 5                8 3  4
+--R                 (- 4844421120A a b  + 2800680960C a b )c
+--R               + 
+--R                               5 7               7 5  3
+--R                 (1539112960A a b  + 946176000C a b )c
+--R               + 
+--R                                4 9                6 7  2               5 9
+--R                 (- 141926400A a b  - 1554882560C a b )c  + 450616320C a b c
+--R               + 
+--R                              4 11
+--R                 - 39916800C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                                 9 6
+--R                 - 21609054208A a c
+--R               + 
+--R                                   8 2                10  5
+--R                 (- 100323557376A a b  - 4345298944C a  )c
+--R               + 
+--R                                  7 4              9 2  4
+--R                 (- 10019143680A a b  - 55050240C a b )c
+--R               + 
+--R                               6 6                8 4  3
+--R                 (2651586560A a b  + 4348968960C a b )c
+--R               + 
+--R                                5 8                7 6  2               6 8
+--R                 (- 227082240A a b  - 3149332480C a b )c  + 774144000C a b c
+--R               + 
+--R                              5 10
+--R                 - 63866880C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                                 9   5
+--R                 - 42102423552A a b c
+--R               + 
+--R                                 8 3                10   4
+--R                 (- 8587837440A a b  - 1431306240C a  b)c
+--R               + 
+--R                               7 5                9 3  3
+--R                 (2146959360A a b  + 4293918720C a b )c
+--R               + 
+--R                                6 7                8 5  2               7 7
+--R                 (- 178913280A a b  - 2683699200C a b )c  + 626196480C a b c
+--R               + 
+--R                              6 9
+--R                 - 50319360C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                                10 5                   9 2               11  4
+--R                 - 7751073792A a  c  + (- 2642411520A a b  - 440401920C a  )c
+--R               + 
+--R                              8 4                10 2  3
+--R                 (660602880A a b  + 1321205760C a  b )c
+--R               + 
+--R                               7 6               9 4  2               8 6
+--R                 (- 55050240A a b  - 825753600C a b )c  + 192675840C a b c
+--R               + 
+--R                              7 8
+--R                 - 15482880C a b
+--R            *
+--R               x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                            3   11              2 3 10                5 9
+--R                 44040192C a b c   + 77070336C a b c   + 19267584C a b c
+--R               + 
+--R                          7 8
+--R                 688128C b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                            4 11               3 2 10               2 4 9
+--R                 88080384C a c   + 742391808C a b c   + 605552640C a b c
+--R               + 
+--R                              6 8             8 7
+--R                 93585408C a b c  + 2310144C b c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                            3   11                2 3                4   10
+--R                 58720256A a b c   + (102760448A a b  + 1785724928C a b)c
+--R               + 
+--R                               5                3 3  9
+--R                 (25690112A a b  + 4440719360C a b )c
+--R               + 
+--R                           7                2 5  8                 7 7
+--R                 (917504A b  + 1878130688C a b )c  + 172949504C a b c
+--R               + 
+--R                           9 6
+--R                 2617344C b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                             4 11                3 2                5  10
+--R                 117440512A a c   + (998244352A a b  + 1218445312C a )c
+--R               + 
+--R                              2 4                 4 2  9
+--R                 (822083584A a b  + 12283543552C a b )c
+--R               + 
+--R                                6                 3 4  8
+--R                 (128450560A a b  + 12806520832C a b )c
+--R               + 
+--R                            8                2 6  7                 8 6
+--R                 (3211264A b  + 2876833792C a b )c  + 144056320C a b c
+--R               + 
+--R                           10 5
+--R                 1001472C b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                              4   10                 3 3                 5   9
+--R                 2422210560A a b c   + (6099566592A a b  + 14318567424C a b)c
+--R               + 
+--R                               2 5                 4 3  8
+--R                 (2620391424A a b  + 39753154560C a b )c
+--R               + 
+--R                                7                 3 5  7
+--R                 (246349824A a b  + 19400392704C a b )c
+--R               + 
+--R                            9                2 7  6                9 5
+--R                 (3842048A b  + 2182914048C a b )c  + 45605888C a b c
+--R               + 
+--R                         11 4
+--R                 - 768C b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                              5 10                  4 2                6  9
+--R                 1673527296A a c   + (17109614592A a b  + 5956435968C a )c
+--R               + 
+--R                                3 4                 5 2  8
+--R                 (18148229120A a b  + 62102175744C a b )c
+--R               + 
+--R                               2 6                 4 4  7
+--R                 (4168220672A a b  + 66511929344C a b )c
+--R               + 
+--R                                8                 3 6  6
+--R                 (215269376A a b  + 14932606976C a b )c
+--R               + 
+--R                          10               2 8  5             10 4          12 3
+--R               (1576960A b   + 658307072C a b )c  - 11264C a b  c  + 1152C b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                               5   9                  4 3                 6   8
+--R                 20324548608A a b c  + (57463275520A a b  + 47753330688C a b)c
+--R               + 
+--R                                3 5                  5 3  7
+--R                 (28685762560A a b  + 127196790784C a b )c
+--R               + 
+--R                               2 7                 4 5  6
+--R                 (3324805120A a b  + 55894859776C a b )c
+--R               + 
+--R                               9                3 7  5
+--R                 (72396800A a b  + 4620378112C a b )c
+--R               + 
+--R                           11           2 9  4             11 3          13 2
+--R                 (- 7168A b   + 28160C a b )c  + 13568C a b  c  - 2016C b  c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                              6 9                  5 2                 7  8
+--R                 8675917824A a c  + (92220162048A a b  + 14417657856C a )c
+--R               + 
+--R                                 4 4                  6 2  7
+--R                 (101086003200A a b  + 137918742528C a b )c
+--R               + 
+--R                                3 6                  5 4  6
+--R                 (23346806784A a b  + 124876996608C a b )c
+--R               + 
+--R                               2 8                 4 6  5             3 8 4
+--R                 (1065050112A a b  + 18713382912C a b )c  + 1520640C a b c
+--R               + 
+--R                          12            2 10  3            12 2          14
+--R                 (17920A b   - 380160C a b  )c  - 2240C a b  c  + 5040C b  c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                               6   8                   5 3                 7   7
+--R                 73370042368A a b c  + (200484716544A a b  + 79564226560C a b)c
+--R               + 
+--R                                4 5                  6 3  6
+--R                 (90806919168A a b  + 171641917440C a b )c
+--R               + 
+--R                               3 7                 5 5  5
+--R                 (7713685504A a b  + 47353764864C a b )c
+--R               + 
+--R                               2 9              4 7  4
+--R                 (- 11680256A a b  + 67900672C a b )c
+--R               + 
+--R                              11             3 9  3
+--R                 (1308160A a b   - 1949888C a b )c
+--R               + 
+--R                          13             2 11  2              13            15
+--R                 (50400A b   - 3448592C a b  )c  + 361620C a b  c + 14175C b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                               7 8                   6 2                 8  7
+--R                 23003660288A a c  + (226601467904A a b  + 19056558080C a )c
+--R               + 
+--R                                 5 4                  7 2  6
+--R                 (213146271744A a b  + 143119155200C a b )c
+--R               + 
+--R                                4 6                 6 4  5
+--R                 (33248509952A a b  + 77330104320C a b )c
+--R               + 
+--R                                3 8               5 6  4
+--R                 (- 178167808A a b  + 108007424C a b )c
+--R               + 
+--R                            2 10               4 8  3
+--R                 (4014080A a b   + 178795520C a b )c
+--R               + 
+--R                              12              3 10  2            2 12
+--R                 (1881600A a b   - 50611456C a b  )c  + 893760C a b  c
+--R               + 
+--R                            14
+--R                 529200C a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                                7   7
+--R                 135974092800A a b c
+--R               + 
+--R                                 6 3                 8   6
+--R                 (307941867520A a b  + 66987884544C a b)c
+--R               + 
+--R                                5 5                 7 3  5
+--R                 (91688927232A a b  + 82754732032C a b )c
+--R               + 
+--R                                4 7                6 5  4
+--R                 (- 489259008A a b  - 1545707520C a b )c
+--R               + 
+--R                                3 9                5 7  3
+--R                 (- 113971200A a b  + 1131798528C a b )c
+--R               + 
+--R                             2 11               4 9  2              3 11
+--R                 (20321280A a b   - 123357696C a b )c  - 34594560C a b  c
+--R               + 
+--R                           2 13
+--R                 5715360C a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                               8 7                   7 2                 9  6
+--R                 33617346560A a c  + (266259660800A a b  + 13590069248C a )c
+--R               + 
+--R                                 6 4                 8 2  5
+--R                 (162453258240A a b  + 57778896896C a b )c
+--R               + 
+--R                               5 6                7 4  4
+--R                 (1327628288A a b  - 5150638080C a b )c
+--R               + 
+--R                                4 8                6 6  3
+--R                 (- 880230400A a b  + 1701281792C a b )c
+--R               + 
+--R                             3 10               5 8  2               4 10
+--R                 (96768000A a b   + 483424256C a b )c  - 259660800C a b  c
+--R               + 
+--R                            3 12
+--R                 27216000C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                                8   6
+--R                 126292590592A a b c
+--R               + 
+--R                                 7 3                 9   5
+--R                 (180807008256A a b  + 24290000896C a b)c
+--R               + 
+--R                               6 5                8 3  4
+--R                 (8037335040A a b  - 4741201920C a b )c
+--R               + 
+--R                                 5 7                7 5  3
+--R                 (- 2562129920A a b  - 1531084800C a b )c
+--R               + 
+--R                              4 9                6 7  2               5 9
+--R                 (236544000A a b  + 2580766720C a b )c  - 750167040C a b c
+--R               + 
+--R                            4 11
+--R                 66528000C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                               9 6                   8 2                10  5
+--R                 25484591104A a c  + (121727090688A a b  + 4565499904C a  )c
+--R               + 
+--R                                7 4              9 2  4
+--R                 (13652459520A a b  + 55050240C a b )c
+--R               + 
+--R                                 6 6                8 4  3
+--R                 (- 3614965760A a b  - 5917900800C a b )c
+--R               + 
+--R                              5 8                7 6  2                6 8
+--R                 (309657600A a b  + 4291624960C a b )c  - 1055416320C a b c
+--R               + 
+--R                            5 10
+--R                 87091200C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                               9   5                 8 3                10   4
+--R                 45977960448A a b c  + (9909043200A a b  + 1651507200C a  b)c
+--R               + 
+--R                                 7 5                9 3  3
+--R                 (- 2477260800A a b  - 4954521600C a b )c
+--R               + 
+--R                              6 7                8 5  2               7 7
+--R                 (206438400A a b  + 3096576000C a b )c  - 722534400C a b c
+--R               + 
+--R                            6 9
+--R                 58060800C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                              10 5                 9 2               11  4
+--R                 7751073792A a  c  + (2642411520A a b  + 440401920C a  )c
+--R               + 
+--R                                8 4                10 2  3
+--R                 (- 660602880A a b  - 1321205760C a  b )c
+--R               + 
+--R                             7 6               9 4  2               8 6
+--R                 (55050240A a b  + 825753600C a b )c  - 192675840C a b c
+--R               + 
+--R                            7 8
+--R                 15482880C a b
+--R            *
+--R               x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                             3   8             2 3 7               5 6
+--R                   352321536a b c  + 616562688a b c  + 154140672a b c
+--R                 + 
+--R                           7 5
+--R                   5505024b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                           4 8              3 2 7              2 4 6
+--R                 704643072a c  + 4756340736a b c  + 2774532096a b c
+--R               + 
+--R                             6 5
+--R                 231211008a b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          4   7               3 3 6              2 5 5  5
+--R             (10569646080a b c  + 15854469120a b c  + 2774532096a b c )x
+--R           + 
+--R                         5 7               4 2 6               3 4 5  4
+--R             (7046430720a c  + 38755368960a b c  + 14533263360a b c )x
+--R           + 
+--R                          5   6               4 3 5  3
+--R             (42278584320a b c  + 38755368960a b c )x
+--R           + 
+--R                          6 6               5 2 5  2               6   5
+--R             (16911433728a c  + 54962159616a b c )x  + 39460012032a b c x
+--R           + 
+--R                         7 5
+--R             11274289152a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                            4 9             3 2 8             2 4 7
+--R                 - 88080384a c  - 616562688a b c  - 385351680a b c
+--R               + 
+--R                              6 6          8 5
+--R                 - 38535168a b c  - 344064b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                              4   8              3 3 7              2 5 6
+--R                 - 2818572288a b c  - 4932501504a b c  - 1233125376a b c
+--R               + 
+--R                              7 5
+--R                 - 44040192a b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                              5 8               4 2 7               3 4 6
+--R                 - 2818572288a c  - 19025362944a b c  - 11098128384a b c
+--R               + 
+--R                             2 6 5
+--R                 - 924844032a b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            5   7               4 3 6              3 5 5  5
+--R             (- 28185722880a b c  - 42278584320a b c  - 7398752256a b c )x
+--R           + 
+--R                            6 7               5 2 6               4 4 5  4
+--R             (- 14092861440a c  - 77510737920a b c  - 29066526720a b c )x
+--R           + 
+--R                            6   6               5 3 5  3
+--R             (- 67645734912a b c  - 62008590336a b c )x
+--R           + 
+--R                            7 6               6 2 5  2               7   5
+--R             (- 22548578304a c  - 73282879488a b c )x  - 45097156608a b c x
+--R           + 
+--R                           8 5
+--R             - 11274289152a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 137
+
+--S 138 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                 6   8                  5 3              7   7
+--R                   - 220200960A a b c  + (- 220200960A a b  + 27525120C a b)c
+--R                 + 
+--R                                4 5              6 3  6              5 5 5
+--R                   (151388160A a b  - 34406400C a b )c  - 80855040C a b c
+--R                 + 
+--R                                2 9              4 7  4
+--R                   (- 9461760A a b  + 42577920C a b )c
+--R                 + 
+--R                               11             3 9  3
+--R                   (860160A a b   + 1182720C a b )c
+--R                 + 
+--R                          13             2 11  2              13            15
+--R                 (53760A b   - 2768640C a b  )c  + 235200C a b  c + 15120C b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                                 7 8                   6 2              8  7
+--R                   - 440401920A a c  + (- 2642411520A a b  + 55050240C a )c
+--R                 + 
+--R                                5 4               7 2  6
+--R                   (412876800A a b  + 206438400C a b )c
+--R                 + 
+--R                                4 6               6 4  5
+--R                   (605552640A a b  - 794787840C a b )c
+--R                 + 
+--R                                  3 8              5 6  4               4 8 3
+--R                   (- 170311680A a b  + 40427520C a b )c  + 191600640C a b c
+--R                 + 
+--R                                12              3 10  2            2 12
+--R                   (2257920A a b   - 47900160C a b  )c  - 282240C a b  c
+--R                 + 
+--R                              14
+--R                   635040C a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                                  7   7
+--R                   - 6606028800A a b c
+--R                 + 
+--R                                   6 3               8   6
+--R                   (- 4954521600A a b  + 825753600C a b)c
+--R                 + 
+--R                                 5 5                7 3  5
+--R                   (4459069440A a b  - 1238630400C a b )c
+--R                 + 
+--R                                  4 7                6 5  4
+--R                   (- 454164480A a b  - 1950842880C a b )c
+--R                 + 
+--R                                  3 9                5 7  3
+--R                   (- 170311680A a b  + 1310883840C a b )c
+--R                 + 
+--R                               2 11               4 9  2              3 11
+--R                   (27095040A a b   - 106444800C a b )c  - 51287040C a b  c
+--R                 + 
+--R                             2 13
+--R                   7620480C a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                                  8 7                    7 2               9  6
+--R                   - 4404019200A a c  + (- 20919091200A a b  + 550502400C a )c
+--R                 + 
+--R                                 6 4                8 2  5
+--R                   (8257536000A a b  + 1376256000C a b )c
+--R                 + 
+--R                                 5 6                7 4  4
+--R                   (2339635200A a b  - 6915686400C a b )c
+--R                 + 
+--R                                   4 8                6 6  3
+--R                   (- 1324646400A a b  + 2029977600C a b )c
+--R                 + 
+--R                                3 10               5 8  2               4 10
+--R                   (141926400A a b   + 823603200C a b )c  - 390297600C a b  c
+--R                 + 
+--R                              3 12
+--R                   39916800C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                   8   6
+--R                   - 26424115200A a b c
+--R                 + 
+--R                                   7 3                9   5
+--R                   (- 4404019200A a b  + 3303014400C a b)c
+--R                 + 
+--R                                  6 5                8 3  4
+--R                   (13212057600A a b  - 6881280000C a b )c
+--R                 + 
+--R                                   5 7                7 5  3
+--R                   (- 4128768000A a b  - 2890137600C a b )c
+--R                 + 
+--R                                4 9                6 7  2                5 9
+--R                   (378470400A a b  + 4231987200C a b )c  - 1208524800C a b c
+--R                 + 
+--R                               4 11
+--R                   106444800C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                   9 6
+--R                   - 10569646080A a c
+--R                 + 
+--R                                    8 2                10  5
+--R                   (- 26424115200A a b  + 1321205760C a  )c
+--R                 + 
+--R                                  7 4               9 2  4
+--R                   (23781703680A a b  + 330301440C a b )c
+--R                 + 
+--R                                   6 6                 8 4  3
+--R                   (- 6275727360A a b  - 10404495360C a b )c
+--R                 + 
+--R                                5 8                7 6  2                6 8
+--R                   (536739840A a b  + 7473070080C a b )c  - 1832140800C a b c
+--R                 + 
+--R                               5 10
+--R                   150958080C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                   9   5
+--R                   - 24662507520A a b c
+--R                 + 
+--R                                  8 3                10   4
+--R                   (18496880640A a b  + 3082813440C a  b)c
+--R                 + 
+--R                                   7 5                9 3  3
+--R                   (- 4624220160A a b  - 9248440320C a b )c
+--R                 + 
+--R                                6 7                8 5  2                7 7
+--R                   (385351680A a b  + 5780275200C a b )c  - 1348730880C a b c
+--R                 + 
+--R                               6 9
+--R                   108380160C a b
+--R              *
+--R                 x
+--R             + 
+--R                              10 5                 9 2               11  4
+--R               - 7046430720A a  c  + (5284823040A a b  + 880803840C a  )c
+--R             + 
+--R                               8 4                10 2  3
+--R               (- 1321205760A a b  - 2642411520C a  b )c
+--R             + 
+--R                            7 6                9 4  2               8 6
+--R               (110100480A a b  + 1651507200C a b )c  - 385351680C a b c
+--R             + 
+--R                          7 8
+--R               30965760C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                          7 9                6 2             8  8
+--R               55050240A a c  + (344064000A a b  - 6881280C a )c
+--R             + 
+--R                             5 4              7 2  7
+--R               (- 37847040A a b  - 27525120C a b )c
+--R             + 
+--R                             4 6               6 4  6              3 8 5
+--R               (- 85155840A a b  + 101498880C a b )c  + 21288960A a b c
+--R             + 
+--R                         2 10              4 8  4
+--R               (591360A a b   - 26611200C a b )c
+--R             + 
+--R                             12             3 10  3
+--R               (- 336000A a b   + 5913600C a b  )c
+--R             + 
+--R                         14            2 12  2             14          16
+--R               (- 3360A b   + 208320C a b  )c  - 94080C a b  c - 945C b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                            7   8                 6 3               8   7
+--R               1761607680A a b c  + (1761607680A a b  - 220200960C a b)c
+--R             + 
+--R                               5 5               7 3  6               6 5 5
+--R               (- 1211105280A a b  + 275251200C a b )c  + 646840320C a b c
+--R             + 
+--R                           3 9               5 7  4
+--R               (75694080A a b  - 340623360C a b )c
+--R             + 
+--R                            2 11             4 9  3
+--R               (- 6881280A a b   - 9461760C a b )c
+--R             + 
+--R                             13              3 11  2             2 13
+--R               (- 430080A a b   + 22149120C a b  )c  - 1881600C a b  c
+--R             + 
+--R                            15
+--R               - 120960C a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                            8 8                  7 2               9  7
+--R               1761607680A a c  + (10569646080A a b  - 220200960C a )c
+--R             + 
+--R                               6 4               8 2  6
+--R               (- 1651507200A a b  - 825753600C a b )c
+--R             + 
+--R                               5 6                7 4  5
+--R               (- 2422210560A a b  + 3179151360C a b )c
+--R             + 
+--R                            4 8               6 6  4               5 8 3
+--R               (681246720A a b  - 161710080C a b )c  - 766402560C a b c
+--R             + 
+--R                            2 12               4 10  2             3 12
+--R               (- 9031680A a b   + 191600640C a b  )c  + 1128960C a b  c
+--R             + 
+--R                           2 14
+--R               - 2540160C a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                             8   7                  7 3                9   6
+--R               17616076800A a b c  + (13212057600A a b  - 2202009600C a b)c
+--R             + 
+--R                                6 5                8 3  5
+--R               (- 11890851840A a b  + 3303014400C a b )c
+--R             + 
+--R                             5 7                7 5  4
+--R               (1211105280A a b  + 5202247680C a b )c
+--R             + 
+--R                            4 9                6 7  3
+--R               (454164480A a b  - 3495690240C a b )c
+--R             + 
+--R                             3 11               5 9  2               4 11
+--R               (- 72253440A a b   + 283852800C a b )c  + 136765440C a b  c
+--R             + 
+--R                            3 13
+--R               - 20321280C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                            9 7                  8 2                10  6
+--R               8808038400A a c  + (41838182400A a b  - 1101004800C a  )c
+--R             + 
+--R                                7 4                9 2  5
+--R               (- 16515072000A a b  - 2752512000C a b )c
+--R             + 
+--R                               6 6                 8 4  4
+--R               (- 4679270400A a b  + 13831372800C a b )c
+--R             + 
+--R                             5 8                7 6  3
+--R               (2649292800A a b  - 4059955200C a b )c
+--R             + 
+--R                              4 10                6 8  2               5 10
+--R               (- 283852800A a b   - 1647206400C a b )c  + 780595200C a b  c
+--R             + 
+--R                            4 12
+--R               - 79833600C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                             9   6                 8 3                10   5
+--R               42278584320A a b c  + (7046430720A a b  - 5284823040C a  b)c
+--R             + 
+--R                                7 5                 9 3  4
+--R               (- 21139292160A a b  + 11010048000C a b )c
+--R             + 
+--R                             6 7                8 5  3
+--R               (6606028800A a b  + 4624220160C a b )c
+--R             + 
+--R                              5 9                7 7  2                6 9
+--R               (- 605552640A a b  - 6771179520C a b )c  + 1933639680C a b c
+--R             + 
+--R                             5 11
+--R               - 170311680C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                             10 6                  9 2                11  5
+--R               14092861440A a  c  + (35232153600A a b  - 1761607680C a  )c
+--R             + 
+--R                                8 4               10 2  4
+--R               (- 31708938240A a b  - 440401920C a  b )c
+--R             + 
+--R                             7 6                 9 4  3
+--R               (8367636480A a b  + 13872660480C a b )c
+--R             + 
+--R                              6 8                8 6  2                7 8
+--R               (- 715653120A a b  - 9964093440C a b )c  + 2442854400C a b c
+--R             + 
+--R                             6 10
+--R               - 201277440C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                             10   5                    9 3                11   4
+--R               28185722880A a  b c  + (- 21139292160A a b  - 3523215360C a  b)c
+--R             + 
+--R                             8 5                 10 3  3
+--R               (5284823040A a b  + 10569646080C a  b )c
+--R             + 
+--R                              7 7                9 5  2                8 7
+--R               (- 440401920A a b  - 6606028800C a b )c  + 1541406720C a b c
+--R             + 
+--R                             7 9
+--R               - 123863040C a b
+--R          *
+--R             x
+--R         + 
+--R                        11 5                   10 2               12  4
+--R           7046430720A a  c  + (- 5284823040A a  b  - 880803840C a  )c
+--R         + 
+--R                         9 4                11 2  3
+--R           (1321205760A a b  + 2642411520C a  b )c
+--R         + 
+--R                          8 6                10 4  2               9 6
+--R           (- 110100480A a b  - 1651507200C a  b )c  + 385351680C a b c
+--R         + 
+--R                        8 8
+--R           - 30965760C a b
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                                 6   8                  5 3              7   7
+--R                   - 220200960A a b c  + (- 220200960A a b  + 27525120C a b)c
+--R                 + 
+--R                                4 5              6 3  6              5 5 5
+--R                   (151388160A a b  - 34406400C a b )c  - 80855040C a b c
+--R                 + 
+--R                                2 9              4 7  4
+--R                   (- 9461760A a b  + 42577920C a b )c
+--R                 + 
+--R                               11             3 9  3
+--R                   (860160A a b   + 1182720C a b )c
+--R                 + 
+--R                          13             2 11  2              13            15
+--R                 (53760A b   - 2768640C a b  )c  + 235200C a b  c + 15120C b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                                 7 8                   6 2              8  7
+--R                   - 440401920A a c  + (- 2642411520A a b  + 55050240C a )c
+--R                 + 
+--R                                5 4               7 2  6
+--R                   (412876800A a b  + 206438400C a b )c
+--R                 + 
+--R                                4 6               6 4  5
+--R                   (605552640A a b  - 794787840C a b )c
+--R                 + 
+--R                                  3 8              5 6  4               4 8 3
+--R                   (- 170311680A a b  + 40427520C a b )c  + 191600640C a b c
+--R                 + 
+--R                                12              3 10  2            2 12
+--R                   (2257920A a b   - 47900160C a b  )c  - 282240C a b  c
+--R                 + 
+--R                              14
+--R                   635040C a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                                  7   7
+--R                   - 6606028800A a b c
+--R                 + 
+--R                                   6 3               8   6
+--R                   (- 4954521600A a b  + 825753600C a b)c
+--R                 + 
+--R                                 5 5                7 3  5
+--R                   (4459069440A a b  - 1238630400C a b )c
+--R                 + 
+--R                                  4 7                6 5  4
+--R                   (- 454164480A a b  - 1950842880C a b )c
+--R                 + 
+--R                                  3 9                5 7  3
+--R                   (- 170311680A a b  + 1310883840C a b )c
+--R                 + 
+--R                               2 11               4 9  2              3 11
+--R                   (27095040A a b   - 106444800C a b )c  - 51287040C a b  c
+--R                 + 
+--R                             2 13
+--R                   7620480C a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                                  8 7                    7 2               9  6
+--R                   - 4404019200A a c  + (- 20919091200A a b  + 550502400C a )c
+--R                 + 
+--R                                 6 4                8 2  5
+--R                   (8257536000A a b  + 1376256000C a b )c
+--R                 + 
+--R                                 5 6                7 4  4
+--R                   (2339635200A a b  - 6915686400C a b )c
+--R                 + 
+--R                                   4 8                6 6  3
+--R                   (- 1324646400A a b  + 2029977600C a b )c
+--R                 + 
+--R                                3 10               5 8  2               4 10
+--R                   (141926400A a b   + 823603200C a b )c  - 390297600C a b  c
+--R                 + 
+--R                              3 12
+--R                   39916800C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                   8   6
+--R                   - 26424115200A a b c
+--R                 + 
+--R                                   7 3                9   5
+--R                   (- 4404019200A a b  + 3303014400C a b)c
+--R                 + 
+--R                                  6 5                8 3  4
+--R                   (13212057600A a b  - 6881280000C a b )c
+--R                 + 
+--R                                   5 7                7 5  3
+--R                   (- 4128768000A a b  - 2890137600C a b )c
+--R                 + 
+--R                                4 9                6 7  2                5 9
+--R                   (378470400A a b  + 4231987200C a b )c  - 1208524800C a b c
+--R                 + 
+--R                               4 11
+--R                   106444800C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                   9 6
+--R                   - 10569646080A a c
+--R                 + 
+--R                                    8 2                10  5
+--R                   (- 26424115200A a b  + 1321205760C a  )c
+--R                 + 
+--R                                  7 4               9 2  4
+--R                   (23781703680A a b  + 330301440C a b )c
+--R                 + 
+--R                                   6 6                 8 4  3
+--R                   (- 6275727360A a b  - 10404495360C a b )c
+--R                 + 
+--R                                5 8                7 6  2                6 8
+--R                   (536739840A a b  + 7473070080C a b )c  - 1832140800C a b c
+--R                 + 
+--R                               5 10
+--R                   150958080C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                   9   5
+--R                   - 24662507520A a b c
+--R                 + 
+--R                                  8 3                10   4
+--R                   (18496880640A a b  + 3082813440C a  b)c
+--R                 + 
+--R                                   7 5                9 3  3
+--R                   (- 4624220160A a b  - 9248440320C a b )c
+--R                 + 
+--R                                6 7                8 5  2                7 7
+--R                   (385351680A a b  + 5780275200C a b )c  - 1348730880C a b c
+--R                 + 
+--R                               6 9
+--R                   108380160C a b
+--R              *
+--R                 x
+--R             + 
+--R                              10 5                 9 2               11  4
+--R               - 7046430720A a  c  + (5284823040A a b  + 880803840C a  )c
+--R             + 
+--R                               8 4                10 2  3
+--R               (- 1321205760A a b  - 2642411520C a  b )c
+--R             + 
+--R                            7 6                9 4  2               8 6
+--R               (110100480A a b  + 1651507200C a b )c  - 385351680C a b c
+--R             + 
+--R                          7 8
+--R               30965760C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                          7 9                6 2             8  8
+--R               55050240A a c  + (344064000A a b  - 6881280C a )c
+--R             + 
+--R                             5 4              7 2  7
+--R               (- 37847040A a b  - 27525120C a b )c
+--R             + 
+--R                             4 6               6 4  6              3 8 5
+--R               (- 85155840A a b  + 101498880C a b )c  + 21288960A a b c
+--R             + 
+--R                         2 10              4 8  4
+--R               (591360A a b   - 26611200C a b )c
+--R             + 
+--R                             12             3 10  3
+--R               (- 336000A a b   + 5913600C a b  )c
+--R             + 
+--R                         14            2 12  2             14          16
+--R               (- 3360A b   + 208320C a b  )c  - 94080C a b  c - 945C b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                            7   8                 6 3               8   7
+--R               1761607680A a b c  + (1761607680A a b  - 220200960C a b)c
+--R             + 
+--R                               5 5               7 3  6               6 5 5
+--R               (- 1211105280A a b  + 275251200C a b )c  + 646840320C a b c
+--R             + 
+--R                           3 9               5 7  4
+--R               (75694080A a b  - 340623360C a b )c
+--R             + 
+--R                            2 11             4 9  3
+--R               (- 6881280A a b   - 9461760C a b )c
+--R             + 
+--R                             13              3 11  2             2 13
+--R               (- 430080A a b   + 22149120C a b  )c  - 1881600C a b  c
+--R             + 
+--R                            15
+--R               - 120960C a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                            8 8                  7 2               9  7
+--R               1761607680A a c  + (10569646080A a b  - 220200960C a )c
+--R             + 
+--R                               6 4               8 2  6
+--R               (- 1651507200A a b  - 825753600C a b )c
+--R             + 
+--R                               5 6                7 4  5
+--R               (- 2422210560A a b  + 3179151360C a b )c
+--R             + 
+--R                            4 8               6 6  4               5 8 3
+--R               (681246720A a b  - 161710080C a b )c  - 766402560C a b c
+--R             + 
+--R                            2 12               4 10  2             3 12
+--R               (- 9031680A a b   + 191600640C a b  )c  + 1128960C a b  c
+--R             + 
+--R                           2 14
+--R               - 2540160C a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                             8   7                  7 3                9   6
+--R               17616076800A a b c  + (13212057600A a b  - 2202009600C a b)c
+--R             + 
+--R                                6 5                8 3  5
+--R               (- 11890851840A a b  + 3303014400C a b )c
+--R             + 
+--R                             5 7                7 5  4
+--R               (1211105280A a b  + 5202247680C a b )c
+--R             + 
+--R                            4 9                6 7  3
+--R               (454164480A a b  - 3495690240C a b )c
+--R             + 
+--R                             3 11               5 9  2               4 11
+--R               (- 72253440A a b   + 283852800C a b )c  + 136765440C a b  c
+--R             + 
+--R                            3 13
+--R               - 20321280C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                            9 7                  8 2                10  6
+--R               8808038400A a c  + (41838182400A a b  - 1101004800C a  )c
+--R             + 
+--R                                7 4                9 2  5
+--R               (- 16515072000A a b  - 2752512000C a b )c
+--R             + 
+--R                               6 6                 8 4  4
+--R               (- 4679270400A a b  + 13831372800C a b )c
+--R             + 
+--R                             5 8                7 6  3
+--R               (2649292800A a b  - 4059955200C a b )c
+--R             + 
+--R                              4 10                6 8  2               5 10
+--R               (- 283852800A a b   - 1647206400C a b )c  + 780595200C a b  c
+--R             + 
+--R                            4 12
+--R               - 79833600C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                             9   6                 8 3                10   5
+--R               42278584320A a b c  + (7046430720A a b  - 5284823040C a  b)c
+--R             + 
+--R                                7 5                 9 3  4
+--R               (- 21139292160A a b  + 11010048000C a b )c
+--R             + 
+--R                             6 7                8 5  3
+--R               (6606028800A a b  + 4624220160C a b )c
+--R             + 
+--R                              5 9                7 7  2                6 9
+--R               (- 605552640A a b  - 6771179520C a b )c  + 1933639680C a b c
+--R             + 
+--R                             5 11
+--R               - 170311680C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                             10 6                  9 2                11  5
+--R               14092861440A a  c  + (35232153600A a b  - 1761607680C a  )c
+--R             + 
+--R                                8 4               10 2  4
+--R               (- 31708938240A a b  - 440401920C a  b )c
+--R             + 
+--R                             7 6                 9 4  3
+--R               (8367636480A a b  + 13872660480C a b )c
+--R             + 
+--R                              6 8                8 6  2                7 8
+--R               (- 715653120A a b  - 9964093440C a b )c  + 2442854400C a b c
+--R             + 
+--R                             6 10
+--R               - 201277440C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                             10   5                    9 3                11   4
+--R               28185722880A a  b c  + (- 21139292160A a b  - 3523215360C a  b)c
+--R             + 
+--R                             8 5                 10 3  3
+--R               (5284823040A a b  + 10569646080C a  b )c
+--R             + 
+--R                              7 7                9 5  2                8 7
+--R               (- 440401920A a b  - 6606028800C a b )c  + 1541406720C a b c
+--R             + 
+--R                             7 9
+--R               - 123863040C a b
+--R          *
+--R             x
+--R         + 
+--R                        11 5                   10 2               12  4
+--R           7046430720A a  c  + (- 5284823040A a  b  - 880803840C a  )c
+--R         + 
+--R                         9 4                11 2  3
+--R           (1321205760A a b  + 2642411520C a  b )c
+--R         + 
+--R                          8 6                10 4  2               9 6
+--R           (- 110100480A a b  - 1651507200C a  b )c  + 385351680C a b c
+--R         + 
+--R                        8 8
+--R           - 30965760C a b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                           6 2 7                5 4              7 2  6
+--R               242221056A a b c  + (350486528A a b  - 86900736C a b )c
+--R             + 
+--R                             4 6              6 4  5
+--R               (- 15597568A a b  - 74776576C a b )c
+--R             + 
+--R                             3 8              5 6  4
+--R               (- 16285696A a b  + 75751424C a b )c
+--R             + 
+--R                          2 10             4 8  3
+--R               (1863680A a b   - 3235840C a b )c
+--R             + 
+--R                         12             3 10  2            2 12              14
+--R             (107520A a b   - 4813312C a b  )c  + 510720C a b  c + 30240C a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                           7   7                 6 3               8   6
+--R               484442112A a b c  + (3123183616A a b  - 173801472C a b)c
+--R             + 
+--R                            5 5                7 3  5
+--R               (930349056A a b  - 1018560512C a b )c
+--R             + 
+--R                              4 7               6 5  4
+--R               (- 326172672A a b  + 316194816C a b )c
+--R             + 
+--R                          3 9               5 7  3
+--R               (6021120A a b  + 265273344C a b )c
+--R             + 
+--R                          2 11              4 9  2             3 11
+--R               (4515840A a b   - 92488704C a b )c  + 1128960C a b  c
+--R             + 
+--R                         2 13
+--R               1270080C a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                            7 2 6                 6 4                8 2  5
+--R               7266631680A a b c  + (8697937920A a b  - 2607022080C a b )c
+--R             + 
+--R                               5 6                7 4  4
+--R               (- 1189085184A a b  - 1591541760C a b )c
+--R             + 
+--R                              4 8                6 6  3
+--R               (- 268369920A a b  + 2149023744C a b )c
+--R             + 
+--R                           3 10               5 8  2              4 10
+--R               (54190080A a b   - 300883968C a b )c  - 82252800C a b  c
+--R             + 
+--R                          3 12
+--R               15240960C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                            8   6                  7 3                9   5
+--R               4844421120A a b c  + (25176309760A a b  - 1738014720C a b)c
+--R             + 
+--R                             6 5                8 3  4
+--R               (2055208960A a b  - 8013086720C a b )c
+--R             + 
+--R                               5 7                7 5  3
+--R               (- 2270822400A a b  + 4488232960C a b )c
+--R             + 
+--R                            4 9               6 7  2               5 9
+--R               (283852800A a b  + 861880320C a b )c  - 674150400C a b c
+--R             + 
+--R                          4 11
+--R               79833600C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                             8 2 5                  7 4                 9 2  4
+--R               29066526720A a b c  + (17836277760A a b  - 10428088320C a b )c
+--R             + 
+--R                               6 6               8 4  3
+--R               (- 7248281600A a b  - 283115520C a b )c
+--R             + 
+--R                            5 8                7 6  2                6 8
+--R               (756940800A a b  + 5922488320C a b )c  - 2133196800C a b c
+--R             + 
+--R                           5 10
+--R               212889600C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                             9   5                  8 3                10   4
+--R               11626610688A a b c  + (34263269376A a b  - 4171235328C a  b)c
+--R             + 
+--R                                7 5                9 3  3
+--R               (- 11120148480A a b  - 9846128640C a b )c
+--R             + 
+--R                             6 7                 8 5  2                7 7
+--R               (1073479680A a b  + 11026563072C a b )c  - 3261726720C a b c
+--R             + 
+--R                           6 9
+--R               301916160C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                             9 2 4                   8 4                10 2  3
+--R               27128758272A a b c  + (- 8220835840A a b  - 9732882432C a  b )c
+--R             + 
+--R                            7 6                9 4  2                8 6
+--R               (770703360A a b  + 8657567744C a b )c  - 2408448000C a b c
+--R             + 
+--R                           7 8
+--R               216760320C a b
+--R          *
+--R             x
+--R         + 
+--R                        10   4                   9 3                11   3
+--R           7751073792A a  b c  + (- 2348810240A a b  - 2780823552C a  b)c
+--R         + 
+--R                        8 5                10 3  2               9 5
+--R           (220200960A a b  + 2473590784C a  b )c  - 688128000C a b c
+--R         + 
+--R                      8 7
+--R           61931520C a b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R     + 
+--R                            6   8                  5 3              7   7
+--R               - 60555264A a b c  + (- 405536768A a b  + 21725184C a b)c
+--R             + 
+--R                              4 5               6 3  6
+--R               (- 138199040A a b  + 132751360C a b )c
+--R             + 
+--R                           3 7              5 5  5
+--R               (41746432A a b  - 34850816C a b )c
+--R             + 
+--R                         2 9              4 7  4
+--R               (265216A a b  - 37893632C a b )c
+--R             + 
+--R                             11              3 9  3
+--R               (- 680960A a b   + 11763328C a b )c
+--R             + 
+--R                         13            2 11  2              13           15
+--R               (- 6720A b   + 159712C a b  )c  - 190680C a b  c - 1890C b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                              6 2 7                   5 4               7 2  6
+--R               - 1937768448A a b c  + (- 2803892224A a b  + 695205888C a b )c
+--R             + 
+--R                            4 6               6 4  5
+--R               (124780544A a b  + 598212608C a b )c
+--R             + 
+--R                            3 8               5 6  4
+--R               (130285568A a b  - 606011392C a b )c
+--R             + 
+--R                             2 10              4 8  3
+--R               (- 14909440A a b   + 25886720C a b )c
+--R             + 
+--R                             12              3 10  2             2 12
+--R               (- 860160A a b   + 38506496C a b  )c  - 4085760C a b  c
+--R             + 
+--R                            14
+--R               - 241920C a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                              7   7                    6 3               8   6
+--R               - 1937768448A a b c  + (- 12492734464A a b  + 695205888C a b)c
+--R             + 
+--R                               5 5                7 3  5
+--R               (- 3721396224A a b  + 4074242048C a b )c
+--R             + 
+--R                             4 7                6 5  4
+--R               (1304690688A a b  - 1264779264C a b )c
+--R             + 
+--R                             3 9                5 7  3
+--R               (- 24084480A a b  - 1061093376C a b )c
+--R             + 
+--R                             2 11               4 9  2             3 11
+--R               (- 18063360A a b   + 369954816C a b )c  - 4515840C a b  c
+--R             + 
+--R                           2 13
+--R               - 5080320C a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                               7 2 6
+--R               - 19377684480A a b c
+--R             + 
+--R                                6 4                8 2  5
+--R               (- 23194501120A a b  + 6952058880C a b )c
+--R             + 
+--R                             5 6                7 4  4
+--R               (3170893824A a b  + 4244111360C a b )c
+--R             + 
+--R                            4 8                6 6  3
+--R               (715653120A a b  - 5730729984C a b )c
+--R             + 
+--R                              3 10               5 8  2               4 10
+--R               (- 144506880A a b   + 802357248C a b )c  + 219340800C a b  c
+--R             + 
+--R                            3 12
+--R               - 40642560C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                              8   6                    7 3                9   5
+--R               - 9688842240A a b c  + (- 50352619520A a b  + 3476029440C a b)c
+--R             + 
+--R                               6 5                 8 3  4
+--R               (- 4110417920A a b  + 16026173440C a b )c
+--R             + 
+--R                             5 7                7 5  3
+--R               (4541644800A a b  - 8976465920C a b )c
+--R             + 
+--R                              4 9                6 7  2                5 9
+--R               (- 567705600A a b  - 1723760640C a b )c  + 1348300800C a b c
+--R             + 
+--R                             4 11
+--R               - 159667200C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                               8 2 5
+--R               - 46506442752A a b c
+--R             + 
+--R                                7 4                 9 2  4
+--R               (- 28538044416A a b  + 16684941312C a b )c
+--R             + 
+--R                              6 6               8 4  3
+--R               (11597250560A a b  + 452984832C a b )c
+--R             + 
+--R                               5 8                7 6  2                6 8
+--R               (- 1211105280A a b  - 9475981312C a b )c  + 3413114880C a b c
+--R             + 
+--R                             5 10
+--R               - 340623360C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                               9   5
+--R               - 15502147584A a b c
+--R             + 
+--R                                8 3                10   4
+--R               (- 45684359168A a b  + 5561647104C a  b)c
+--R             + 
+--R                              7 5                 9 3  3
+--R               (14826864640A a b  + 13128171520C a b )c
+--R             + 
+--R                               6 7                 8 5  2                7 7
+--R               (- 1431306240A a b  - 14702084096C a b )c  + 4348968960C a b c
+--R             + 
+--R                             6 9
+--R               - 402554880C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                               9 2 4                 8 4                 10 2  3
+--R               - 31004295168A a b c  + (9395240960A a b  + 11123294208C a  b )c
+--R             + 
+--R                              7 6                9 4  2                8 6
+--R               (- 880803840A a b  - 9894363136C a b )c  + 2752512000C a b c
+--R             + 
+--R                             7 8
+--R               - 247726080C a b
+--R          *
+--R             x
+--R         + 
+--R                          10   4                 9 3                11   3
+--R           - 7751073792A a  b c  + (2348810240A a b  + 2780823552C a  b)c
+--R         + 
+--R                          8 5                10 3  2               9 5
+--R           (- 220200960A a b  - 2473590784C a  b )c  + 688128000C a b c
+--R         + 
+--R                        8 7
+--R           - 61931520C a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                           3   8              2 3 7               5 6
+--R                 704643072a b c  + 1233125376a b c  + 308281344a b c
+--R               + 
+--R                          7 5
+--R                 11010048b c
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                          4 8              3 2 7              2 4 6
+--R               1409286144a c  + 9512681472a b c  + 5549064192a b c
+--R             + 
+--R                           6 5
+--R               462422016a b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        4   7               3 3 6              2 5 5  5
+--R           (21139292160a b c  + 31708938240a b c  + 5549064192a b c )x
+--R         + 
+--R                        5 7               4 2 6               3 4 5  4
+--R           (14092861440a c  + 77510737920a b c  + 29066526720a b c )x
+--R         + 
+--R                        5   6               4 3 5  3
+--R           (84557168640a b c  + 77510737920a b c )x
+--R         + 
+--R                        6 6                5 2 5  2               6   5
+--R           (33822867456a c  + 109924319232a b c )x  + 78920024064a b c x
+--R         + 
+--R                       7 5
+--R           22548578304a c
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                           4 9              3 2 8             2 4 7
+--R               - 176160768a c  - 1233125376a b c  - 770703360a b c
+--R             + 
+--R                            6 6          8 5
+--R               - 77070336a b c  - 688128b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                            4   8              3 3 7              2 5 6
+--R               - 5637144576a b c  - 9865003008a b c  - 2466250752a b c
+--R             + 
+--R                            7 5
+--R               - 88080384a b c
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                            5 8               4 2 7               3 4 6
+--R               - 5637144576a c  - 38050725888a b c  - 22196256768a b c
+--R             + 
+--R                            2 6 5
+--R               - 1849688064a b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          5   7               4 3 6               3 5 5  5
+--R           (- 56371445760a b c  - 84557168640a b c  - 14797504512a b c )x
+--R         + 
+--R                          6 7                5 2 6               4 4 5  4
+--R           (- 28185722880a c  - 155021475840a b c  - 58133053440a b c )x
+--R         + 
+--R                           6   6                5 3 5  3
+--R           (- 135291469824a b c  - 124017180672a b c )x
+--R         + 
+--R                          7 6                6 2 5  2               7   5
+--R           (- 45097156608a c  - 146565758976a b c )x  - 90194313216a b c x
+--R         + 
+--R                         8 5
+--R           - 22548578304a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 138
+
+--S 139 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                 6   8                  5 3              7   7
+--R                   - 220200960A a b c  + (- 220200960A a b  + 27525120C a b)c
+--R                 + 
+--R                                4 5              6 3  6              5 5 5
+--R                   (151388160A a b  - 34406400C a b )c  - 80855040C a b c
+--R                 + 
+--R                                2 9              4 7  4
+--R                   (- 9461760A a b  + 42577920C a b )c
+--R                 + 
+--R                               11             3 9  3
+--R                   (860160A a b   + 1182720C a b )c
+--R                 + 
+--R                          13             2 11  2              13            15
+--R                 (53760A b   - 2768640C a b  )c  + 235200C a b  c + 15120C b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                                 7 8                   6 2              8  7
+--R                   - 440401920A a c  + (- 2642411520A a b  + 55050240C a )c
+--R                 + 
+--R                                5 4               7 2  6
+--R                   (412876800A a b  + 206438400C a b )c
+--R                 + 
+--R                                4 6               6 4  5
+--R                   (605552640A a b  - 794787840C a b )c
+--R                 + 
+--R                                  3 8              5 6  4               4 8 3
+--R                   (- 170311680A a b  + 40427520C a b )c  + 191600640C a b c
+--R                 + 
+--R                                12              3 10  2            2 12
+--R                   (2257920A a b   - 47900160C a b  )c  - 282240C a b  c
+--R                 + 
+--R                              14
+--R                   635040C a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                                  7   7
+--R                   - 6606028800A a b c
+--R                 + 
+--R                                   6 3               8   6
+--R                   (- 4954521600A a b  + 825753600C a b)c
+--R                 + 
+--R                                 5 5                7 3  5
+--R                   (4459069440A a b  - 1238630400C a b )c
+--R                 + 
+--R                                  4 7                6 5  4
+--R                   (- 454164480A a b  - 1950842880C a b )c
+--R                 + 
+--R                                  3 9                5 7  3
+--R                   (- 170311680A a b  + 1310883840C a b )c
+--R                 + 
+--R                               2 11               4 9  2              3 11
+--R                   (27095040A a b   - 106444800C a b )c  - 51287040C a b  c
+--R                 + 
+--R                             2 13
+--R                   7620480C a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                                  8 7                    7 2               9  6
+--R                   - 4404019200A a c  + (- 20919091200A a b  + 550502400C a )c
+--R                 + 
+--R                                 6 4                8 2  5
+--R                   (8257536000A a b  + 1376256000C a b )c
+--R                 + 
+--R                                 5 6                7 4  4
+--R                   (2339635200A a b  - 6915686400C a b )c
+--R                 + 
+--R                                   4 8                6 6  3
+--R                   (- 1324646400A a b  + 2029977600C a b )c
+--R                 + 
+--R                                3 10               5 8  2               4 10
+--R                   (141926400A a b   + 823603200C a b )c  - 390297600C a b  c
+--R                 + 
+--R                              3 12
+--R                   39916800C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                   8   6
+--R                   - 26424115200A a b c
+--R                 + 
+--R                                   7 3                9   5
+--R                   (- 4404019200A a b  + 3303014400C a b)c
+--R                 + 
+--R                                  6 5                8 3  4
+--R                   (13212057600A a b  - 6881280000C a b )c
+--R                 + 
+--R                                   5 7                7 5  3
+--R                   (- 4128768000A a b  - 2890137600C a b )c
+--R                 + 
+--R                                4 9                6 7  2                5 9
+--R                   (378470400A a b  + 4231987200C a b )c  - 1208524800C a b c
+--R                 + 
+--R                               4 11
+--R                   106444800C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                   9 6
+--R                   - 10569646080A a c
+--R                 + 
+--R                                    8 2                10  5
+--R                   (- 26424115200A a b  + 1321205760C a  )c
+--R                 + 
+--R                                  7 4               9 2  4
+--R                   (23781703680A a b  + 330301440C a b )c
+--R                 + 
+--R                                   6 6                 8 4  3
+--R                   (- 6275727360A a b  - 10404495360C a b )c
+--R                 + 
+--R                                5 8                7 6  2                6 8
+--R                   (536739840A a b  + 7473070080C a b )c  - 1832140800C a b c
+--R                 + 
+--R                               5 10
+--R                   150958080C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                   9   5
+--R                   - 24662507520A a b c
+--R                 + 
+--R                                  8 3                10   4
+--R                   (18496880640A a b  + 3082813440C a  b)c
+--R                 + 
+--R                                   7 5                9 3  3
+--R                   (- 4624220160A a b  - 9248440320C a b )c
+--R                 + 
+--R                                6 7                8 5  2                7 7
+--R                   (385351680A a b  + 5780275200C a b )c  - 1348730880C a b c
+--R                 + 
+--R                               6 9
+--R                   108380160C a b
+--R              *
+--R                 x
+--R             + 
+--R                              10 5                 9 2               11  4
+--R               - 7046430720A a  c  + (5284823040A a b  + 880803840C a  )c
+--R             + 
+--R                               8 4                10 2  3
+--R               (- 1321205760A a b  - 2642411520C a  b )c
+--R             + 
+--R                            7 6                9 4  2               8 6
+--R               (110100480A a b  + 1651507200C a b )c  - 385351680C a b c
+--R             + 
+--R                          7 8
+--R               30965760C a b
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + b x + a
+--R         + 
+--R                              7 9                6 2             8  8
+--R                   55050240A a c  + (344064000A a b  - 6881280C a )c
+--R                 + 
+--R                                 5 4              7 2  7
+--R                   (- 37847040A a b  - 27525120C a b )c
+--R                 + 
+--R                                 4 6               6 4  6              3 8 5
+--R                   (- 85155840A a b  + 101498880C a b )c  + 21288960A a b c
+--R                 + 
+--R                             2 10              4 8  4
+--R                   (591360A a b   - 26611200C a b )c
+--R                 + 
+--R                                 12             3 10  3
+--R                   (- 336000A a b   + 5913600C a b  )c
+--R                 + 
+--R                             14            2 12  2             14          16
+--R                   (- 3360A b   + 208320C a b  )c  - 94080C a b  c - 945C b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                7   8                 6 3               8   7
+--R                   1761607680A a b c  + (1761607680A a b  - 220200960C a b)c
+--R                 + 
+--R                                   5 5               7 3  6               6 5 5
+--R                   (- 1211105280A a b  + 275251200C a b )c  + 646840320C a b c
+--R                 + 
+--R                               3 9               5 7  4
+--R                   (75694080A a b  - 340623360C a b )c
+--R                 + 
+--R                                2 11             4 9  3
+--R                   (- 6881280A a b   - 9461760C a b )c
+--R                 + 
+--R                                 13              3 11  2             2 13
+--R                   (- 430080A a b   + 22149120C a b  )c  - 1881600C a b  c
+--R                 + 
+--R                                15
+--R                   - 120960C a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                                8 8                  7 2               9  7
+--R                   1761607680A a c  + (10569646080A a b  - 220200960C a )c
+--R                 + 
+--R                                   6 4               8 2  6
+--R                   (- 1651507200A a b  - 825753600C a b )c
+--R                 + 
+--R                                   5 6                7 4  5
+--R                   (- 2422210560A a b  + 3179151360C a b )c
+--R                 + 
+--R                                4 8               6 6  4               5 8 3
+--R                   (681246720A a b  - 161710080C a b )c  - 766402560C a b c
+--R                 + 
+--R                                2 12               4 10  2             3 12
+--R                   (- 9031680A a b   + 191600640C a b  )c  + 1128960C a b  c
+--R                 + 
+--R                               2 14
+--R                   - 2540160C a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                                 8   7                  7 3                9   6
+--R                   17616076800A a b c  + (13212057600A a b  - 2202009600C a b)c
+--R                 + 
+--R                                    6 5                8 3  5
+--R                   (- 11890851840A a b  + 3303014400C a b )c
+--R                 + 
+--R                                 5 7                7 5  4
+--R                   (1211105280A a b  + 5202247680C a b )c
+--R                 + 
+--R                                4 9                6 7  3
+--R                   (454164480A a b  - 3495690240C a b )c
+--R                 + 
+--R                                 3 11               5 9  2               4 11
+--R                   (- 72253440A a b   + 283852800C a b )c  + 136765440C a b  c
+--R                 + 
+--R                                3 13
+--R                   - 20321280C a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                                9 7                  8 2                10  6
+--R                   8808038400A a c  + (41838182400A a b  - 1101004800C a  )c
+--R                 + 
+--R                                    7 4                9 2  5
+--R                   (- 16515072000A a b  - 2752512000C a b )c
+--R                 + 
+--R                                   6 6                 8 4  4
+--R                   (- 4679270400A a b  + 13831372800C a b )c
+--R                 + 
+--R                                 5 8                7 6  3
+--R                   (2649292800A a b  - 4059955200C a b )c
+--R                 + 
+--R                                  4 10                6 8  2               5 10
+--R                   (- 283852800A a b   - 1647206400C a b )c  + 780595200C a b  c
+--R                 + 
+--R                                4 12
+--R                   - 79833600C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                 9   6                 8 3                10   5
+--R                   42278584320A a b c  + (7046430720A a b  - 5284823040C a  b)c
+--R                 + 
+--R                                    7 5                 9 3  4
+--R                   (- 21139292160A a b  + 11010048000C a b )c
+--R                 + 
+--R                                 6 7                8 5  3
+--R                   (6606028800A a b  + 4624220160C a b )c
+--R                 + 
+--R                                  5 9                7 7  2                6 9
+--R                   (- 605552640A a b  - 6771179520C a b )c  + 1933639680C a b c
+--R                 + 
+--R                                 5 11
+--R                   - 170311680C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                 10 6                  9 2                11  5
+--R                   14092861440A a  c  + (35232153600A a b  - 1761607680C a  )c
+--R                 + 
+--R                                    8 4               10 2  4
+--R                   (- 31708938240A a b  - 440401920C a  b )c
+--R                 + 
+--R                                 7 6                 9 4  3
+--R                   (8367636480A a b  + 13872660480C a b )c
+--R                 + 
+--R                                  6 8                8 6  2                7 8
+--R                   (- 715653120A a b  - 9964093440C a b )c  + 2442854400C a b c
+--R                 + 
+--R                                 6 10
+--R                   - 201277440C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                 10   5
+--R                   28185722880A a  b c
+--R                 + 
+--R                                    9 3                11   4
+--R                   (- 21139292160A a b  - 3523215360C a  b)c
+--R                 + 
+--R                                 8 5                 10 3  3
+--R                   (5284823040A a b  + 10569646080C a  b )c
+--R                 + 
+--R                                  7 7                9 5  2                8 7
+--R                   (- 440401920A a b  - 6606028800C a b )c  + 1541406720C a b c
+--R                 + 
+--R                                 7 9
+--R                   - 123863040C a b
+--R              *
+--R                 x
+--R             + 
+--R                            11 5                   10 2               12  4
+--R               7046430720A a  c  + (- 5284823040A a  b  - 880803840C a  )c
+--R             + 
+--R                             9 4                11 2  3
+--R               (1321205760A a b  + 2642411520C a  b )c
+--R             + 
+--R                              8 6                10 4  2               9 6
+--R               (- 110100480A a b  - 1651507200C a  b )c  + 385351680C a b c
+--R             + 
+--R                            8 8
+--R               - 30965760C a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                               6   8                5 3              7   7
+--R                   440401920A a b c  + (440401920A a b  - 55050240C a b)c
+--R                 + 
+--R                                  4 5              6 3  6               5 5 5
+--R                   (- 302776320A a b  + 68812800C a b )c  + 161710080C a b c
+--R                 + 
+--R                               2 9              4 7  4
+--R                   (18923520A a b  - 85155840C a b )c
+--R                 + 
+--R                                  11             3 9  3
+--R                   (- 1720320A a b   - 2365440C a b )c
+--R                 + 
+--R                               13             2 11  2              13
+--R                   (- 107520A b   + 5537280C a b  )c  - 470400C a b  c
+--R                 + 
+--R                             15
+--R                   - 30240C b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                               7 8                 6 2               8  7
+--R                   880803840A a c  + (5284823040A a b  - 110100480C a )c
+--R                 + 
+--R                                  5 4               7 2  6
+--R                   (- 825753600A a b  - 412876800C a b )c
+--R                 + 
+--R                                   4 6                6 4  5
+--R                   (- 1211105280A a b  + 1589575680C a b )c
+--R                 + 
+--R                                3 8              5 6  4               4 8 3
+--R                   (340623360A a b  - 80855040C a b )c  - 383201280C a b c
+--R                 + 
+--R                                  12              3 10  2            2 12
+--R                   (- 4515840A a b   + 95800320C a b  )c  + 564480C a b  c
+--R                 + 
+--R                                 14
+--R                   - 1270080C a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                                 7   7                 6 3                8   6
+--R                   13212057600A a b c  + (9909043200A a b  - 1651507200C a b)c
+--R                 + 
+--R                                   5 5                7 3  5
+--R                   (- 8918138880A a b  + 2477260800C a b )c
+--R                 + 
+--R                                4 7                6 5  4
+--R                   (908328960A a b  + 3901685760C a b )c
+--R                 + 
+--R                                3 9                5 7  3
+--R                   (340623360A a b  - 2621767680C a b )c
+--R                 + 
+--R                                 2 11               4 9  2               3 11
+--R                   (- 54190080A a b   + 212889600C a b )c  + 102574080C a b  c
+--R                 + 
+--R                                2 13
+--R                   - 15240960C a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                                8 7                  7 2                9  6
+--R                   8808038400A a c  + (41838182400A a b  - 1101004800C a )c
+--R                 + 
+--R                                    6 4                8 2  5
+--R                   (- 16515072000A a b  - 2752512000C a b )c
+--R                 + 
+--R                                   5 6                 7 4  4
+--R                   (- 4679270400A a b  + 13831372800C a b )c
+--R                 + 
+--R                                 4 8                6 6  3
+--R                   (2649292800A a b  - 4059955200C a b )c
+--R                 + 
+--R                                  3 10                5 8  2               4 10
+--R                   (- 283852800A a b   - 1647206400C a b )c  + 780595200C a b  c
+--R                 + 
+--R                                3 12
+--R                   - 79833600C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                 8   6                 7 3                9   5
+--R                   52848230400A a b c  + (8808038400A a b  - 6606028800C a b)c
+--R                 + 
+--R                                    6 5                 8 3  4
+--R                   (- 26424115200A a b  + 13762560000C a b )c
+--R                 + 
+--R                                 5 7                7 5  3
+--R                   (8257536000A a b  + 5780275200C a b )c
+--R                 + 
+--R                                  4 9                6 7  2                5 9
+--R                   (- 756940800A a b  - 8463974400C a b )c  + 2417049600C a b c
+--R                 + 
+--R                                 4 11
+--R                   - 212889600C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                 9 6                  8 2                10  5
+--R                   21139292160A a c  + (52848230400A a b  - 2642411520C a  )c
+--R                 + 
+--R                                    7 4               9 2  4
+--R                   (- 47563407360A a b  - 660602880C a b )c
+--R                 + 
+--R                                  6 6                 8 4  3
+--R                   (12551454720A a b  + 20808990720C a b )c
+--R                 + 
+--R                                   5 8                 7 6  2
+--R                   (- 1073479680A a b  - 14946140160C a b )c
+--R                 + 
+--R                                6 8                5 10
+--R                   3664281600C a b c - 301916160C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                 9   5
+--R                   49325015040A a b c
+--R                 + 
+--R                                    8 3                10   4
+--R                   (- 36993761280A a b  - 6165626880C a  b)c
+--R                 + 
+--R                                 7 5                 9 3  3
+--R                   (9248440320A a b  + 18496880640C a b )c
+--R                 + 
+--R                                  6 7                 8 5  2                7 7
+--R                   (- 770703360A a b  - 11560550400C a b )c  + 2697461760C a b c
+--R                 + 
+--R                                 6 9
+--R                   - 216760320C a b
+--R              *
+--R                 x
+--R             + 
+--R                             10 5                    9 2                11  4
+--R               14092861440A a  c  + (- 10569646080A a b  - 1761607680C a  )c
+--R             + 
+--R                             8 4                10 2  3
+--R               (2642411520A a b  + 5284823040C a  b )c
+--R             + 
+--R                              7 6                9 4  2               8 6
+--R               (- 220200960A a b  - 3303014400C a b )c  + 770703360C a b c
+--R             + 
+--R                            7 8
+--R               - 61931520C a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                                 7 9                  6 2              8  8
+--R                   - 110100480A a c  + (- 688128000A a b  + 13762560C a )c
+--R                 + 
+--R                               5 4              7 2  7
+--R                   (75694080A a b  + 55050240C a b )c
+--R                 + 
+--R                                4 6               6 4  6              3 8 5
+--R                   (170311680A a b  - 202997760C a b )c  - 42577920A a b c
+--R                 + 
+--R                                2 10              4 8  4
+--R                   (- 1182720A a b   + 53222400C a b )c
+--R                 + 
+--R                               12              3 10  3
+--R                   (672000A a b   - 11827200C a b  )c
+--R                 + 
+--R                           14            2 12  2              14           16
+--R                   (6720A b   - 416640C a b  )c  + 188160C a b  c + 1890C b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                  7   8
+--R                   - 3523215360A a b c
+--R                 + 
+--R                                   6 3               8   7
+--R                   (- 3523215360A a b  + 440401920C a b)c
+--R                 + 
+--R                                 5 5               7 3  6                6 5 5
+--R                   (2422210560A a b  - 550502400C a b )c  - 1293680640C a b c
+--R                 + 
+--R                                  3 9               5 7  4
+--R                   (- 151388160A a b  + 681246720C a b )c
+--R                 + 
+--R                               2 11              4 9  3
+--R                   (13762560A a b   + 18923520C a b )c
+--R                 + 
+--R                               13              3 11  2             2 13
+--R                   (860160A a b   - 44298240C a b  )c  + 3763200C a b  c
+--R                 + 
+--R                              15
+--R                   241920C a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                                  8 8                    7 2               9  7
+--R                   - 3523215360A a c  + (- 21139292160A a b  + 440401920C a )c
+--R                 + 
+--R                                 6 4                8 2  6
+--R                   (3303014400A a b  + 1651507200C a b )c
+--R                 + 
+--R                                 5 6                7 4  5
+--R                   (4844421120A a b  - 6358302720C a b )c
+--R                 + 
+--R                                   4 8               6 6  4                5 8 3
+--R                   (- 1362493440A a b  + 323420160C a b )c  + 1532805120C a b c
+--R                 + 
+--R                               2 12               4 10  2             3 12
+--R                   (18063360A a b   - 383201280C a b  )c  - 2257920C a b  c
+--R                 + 
+--R                             2 14
+--R                   5080320C a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                                   8   7
+--R                   - 35232153600A a b c
+--R                 + 
+--R                                    7 3                9   6
+--R                   (- 26424115200A a b  + 4404019200C a b)c
+--R                 + 
+--R                                  6 5                8 3  5
+--R                   (23781703680A a b  - 6606028800C a b )c
+--R                 + 
+--R                                   5 7                 7 5  4
+--R                   (- 2422210560A a b  - 10404495360C a b )c
+--R                 + 
+--R                                  4 9                6 7  3
+--R                   (- 908328960A a b  + 6991380480C a b )c
+--R                 + 
+--R                                3 11               5 9  2               4 11
+--R                   (144506880A a b   - 567705600C a b )c  - 273530880C a b  c
+--R                 + 
+--R                              3 13
+--R                   40642560C a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                                   9 7
+--R                   - 17616076800A a c
+--R                 + 
+--R                                    8 2                10  6
+--R                   (- 83676364800A a b  + 2202009600C a  )c
+--R                 + 
+--R                                  7 4                9 2  5
+--R                   (33030144000A a b  + 5505024000C a b )c
+--R                 + 
+--R                                 6 6                 8 4  4
+--R                   (9358540800A a b  - 27662745600C a b )c
+--R                 + 
+--R                                   5 8                7 6  3
+--R                   (- 5298585600A a b  + 8119910400C a b )c
+--R                 + 
+--R                                4 10                6 8  2                5 10
+--R                   (567705600A a b   + 3294412800C a b )c  - 1561190400C a b  c
+--R                 + 
+--R                               4 12
+--R                   159667200C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                   9   6
+--R                   - 84557168640A a b c
+--R                 + 
+--R                                    8 3                 10   5
+--R                   (- 14092861440A a b  + 10569646080C a  b)c
+--R                 + 
+--R                                  7 5                 9 3  4
+--R                   (42278584320A a b  - 22020096000C a b )c
+--R                 + 
+--R                                    6 7                8 5  3
+--R                   (- 13212057600A a b  - 9248440320C a b )c
+--R                 + 
+--R                                 5 9                 7 7  2                6 9
+--R                   (1211105280A a b  + 13542359040C a b )c  - 3867279360C a b c
+--R                 + 
+--R                               5 11
+--R                   340623360C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                   10 6
+--R                   - 28185722880A a  c
+--R                 + 
+--R                                    9 2                11  5
+--R                   (- 70464307200A a b  + 3523215360C a  )c
+--R                 + 
+--R                                  8 4               10 2  4
+--R                   (63417876480A a b  + 880803840C a  b )c
+--R                 + 
+--R                                    7 6                 9 4  3
+--R                   (- 16735272960A a b  - 27745320960C a b )c
+--R                 + 
+--R                                 6 8                 8 6  2                7 8
+--R                   (1431306240A a b  + 19928186880C a b )c  - 4885708800C a b c
+--R                 + 
+--R                               6 10
+--R                   402554880C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                   10   5
+--R                   - 56371445760A a  b c
+--R                 + 
+--R                                  9 3                11   4
+--R                   (42278584320A a b  + 7046430720C a  b)c
+--R                 + 
+--R                                    8 5                 10 3  3
+--R                   (- 10569646080A a b  - 21139292160C a  b )c
+--R                 + 
+--R                                7 7                 9 5  2                8 7
+--R                   (880803840A a b  + 13212057600C a b )c  - 3082813440C a b c
+--R                 + 
+--R                               7 9
+--R                   247726080C a b
+--R              *
+--R                 x
+--R             + 
+--R                               11 5                  10 2                12  4
+--R               - 14092861440A a  c  + (10569646080A a  b  + 1761607680C a  )c
+--R             + 
+--R                               9 4                11 2  3
+--R               (- 2642411520A a b  - 5284823040C a  b )c
+--R             + 
+--R                            8 6                10 4  2               9 6
+--R               (220200960A a b  + 3303014400C a  b )c  - 770703360C a b c
+--R             + 
+--R                          8 8
+--R               61931520C a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- c \|c x  + b x + a  - \|- c \|a
+--R         atan(------------------------------------)
+--R                               c x
+--R     + 
+--R                           6 2 7                5 4              7 2  6
+--R               242221056A a b c  + (350486528A a b  - 86900736C a b )c
+--R             + 
+--R                             4 6              6 4  5
+--R               (- 15597568A a b  - 74776576C a b )c
+--R             + 
+--R                             3 8              5 6  4
+--R               (- 16285696A a b  + 75751424C a b )c
+--R             + 
+--R                          2 10             4 8  3
+--R               (1863680A a b   - 3235840C a b )c
+--R             + 
+--R                         12             3 10  2            2 12              14
+--R             (107520A a b   - 4813312C a b  )c  + 510720C a b  c + 30240C a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                           7   7                 6 3               8   6
+--R               484442112A a b c  + (3123183616A a b  - 173801472C a b)c
+--R             + 
+--R                            5 5                7 3  5
+--R               (930349056A a b  - 1018560512C a b )c
+--R             + 
+--R                              4 7               6 5  4
+--R               (- 326172672A a b  + 316194816C a b )c
+--R             + 
+--R                          3 9               5 7  3
+--R               (6021120A a b  + 265273344C a b )c
+--R             + 
+--R                          2 11              4 9  2             3 11
+--R               (4515840A a b   - 92488704C a b )c  + 1128960C a b  c
+--R             + 
+--R                         2 13
+--R               1270080C a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                            7 2 6                 6 4                8 2  5
+--R               7266631680A a b c  + (8697937920A a b  - 2607022080C a b )c
+--R             + 
+--R                               5 6                7 4  4
+--R               (- 1189085184A a b  - 1591541760C a b )c
+--R             + 
+--R                              4 8                6 6  3
+--R               (- 268369920A a b  + 2149023744C a b )c
+--R             + 
+--R                           3 10               5 8  2              4 10
+--R               (54190080A a b   - 300883968C a b )c  - 82252800C a b  c
+--R             + 
+--R                          3 12
+--R               15240960C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                            8   6                  7 3                9   5
+--R               4844421120A a b c  + (25176309760A a b  - 1738014720C a b)c
+--R             + 
+--R                             6 5                8 3  4
+--R               (2055208960A a b  - 8013086720C a b )c
+--R             + 
+--R                               5 7                7 5  3
+--R               (- 2270822400A a b  + 4488232960C a b )c
+--R             + 
+--R                            4 9               6 7  2               5 9
+--R               (283852800A a b  + 861880320C a b )c  - 674150400C a b c
+--R             + 
+--R                          4 11
+--R               79833600C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                             8 2 5                  7 4                 9 2  4
+--R               29066526720A a b c  + (17836277760A a b  - 10428088320C a b )c
+--R             + 
+--R                               6 6               8 4  3
+--R               (- 7248281600A a b  - 283115520C a b )c
+--R             + 
+--R                            5 8                7 6  2                6 8
+--R               (756940800A a b  + 5922488320C a b )c  - 2133196800C a b c
+--R             + 
+--R                           5 10
+--R               212889600C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                             9   5                  8 3                10   4
+--R               11626610688A a b c  + (34263269376A a b  - 4171235328C a  b)c
+--R             + 
+--R                                7 5                9 3  3
+--R               (- 11120148480A a b  - 9846128640C a b )c
+--R             + 
+--R                             6 7                 8 5  2                7 7
+--R               (1073479680A a b  + 11026563072C a b )c  - 3261726720C a b c
+--R             + 
+--R                           6 9
+--R               301916160C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                             9 2 4                   8 4                10 2  3
+--R               27128758272A a b c  + (- 8220835840A a b  - 9732882432C a  b )c
+--R             + 
+--R                            7 6                9 4  2                8 6
+--R               (770703360A a b  + 8657567744C a b )c  - 2408448000C a b c
+--R             + 
+--R                           7 8
+--R               216760320C a b
+--R          *
+--R             x
+--R         + 
+--R                        10   4                   9 3                11   3
+--R           7751073792A a  b c  + (- 2348810240A a b  - 2780823552C a  b)c
+--R         + 
+--R                        8 5                10 3  2               9 5
+--R           (220200960A a b  + 2473590784C a  b )c  - 688128000C a b c
+--R         + 
+--R                      8 7
+--R           61931520C a b
+--R      *
+--R                    +--------------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b x + a
+--R     + 
+--R                            6   8                  5 3              7   7
+--R               - 60555264A a b c  + (- 405536768A a b  + 21725184C a b)c
+--R             + 
+--R                              4 5               6 3  6
+--R               (- 138199040A a b  + 132751360C a b )c
+--R             + 
+--R                           3 7              5 5  5
+--R               (41746432A a b  - 34850816C a b )c
+--R             + 
+--R                         2 9              4 7  4
+--R               (265216A a b  - 37893632C a b )c
+--R             + 
+--R                             11              3 9  3
+--R               (- 680960A a b   + 11763328C a b )c
+--R             + 
+--R                         13            2 11  2              13           15
+--R               (- 6720A b   + 159712C a b  )c  - 190680C a b  c - 1890C b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                              6 2 7                   5 4               7 2  6
+--R               - 1937768448A a b c  + (- 2803892224A a b  + 695205888C a b )c
+--R             + 
+--R                            4 6               6 4  5
+--R               (124780544A a b  + 598212608C a b )c
+--R             + 
+--R                            3 8               5 6  4
+--R               (130285568A a b  - 606011392C a b )c
+--R             + 
+--R                             2 10              4 8  3
+--R               (- 14909440A a b   + 25886720C a b )c
+--R             + 
+--R                             12              3 10  2             2 12
+--R               (- 860160A a b   + 38506496C a b  )c  - 4085760C a b  c
+--R             + 
+--R                            14
+--R               - 241920C a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                              7   7                    6 3               8   6
+--R               - 1937768448A a b c  + (- 12492734464A a b  + 695205888C a b)c
+--R             + 
+--R                               5 5                7 3  5
+--R               (- 3721396224A a b  + 4074242048C a b )c
+--R             + 
+--R                             4 7                6 5  4
+--R               (1304690688A a b  - 1264779264C a b )c
+--R             + 
+--R                             3 9                5 7  3
+--R               (- 24084480A a b  - 1061093376C a b )c
+--R             + 
+--R                             2 11               4 9  2             3 11
+--R               (- 18063360A a b   + 369954816C a b )c  - 4515840C a b  c
+--R             + 
+--R                           2 13
+--R               - 5080320C a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                               7 2 6
+--R               - 19377684480A a b c
+--R             + 
+--R                                6 4                8 2  5
+--R               (- 23194501120A a b  + 6952058880C a b )c
+--R             + 
+--R                             5 6                7 4  4
+--R               (3170893824A a b  + 4244111360C a b )c
+--R             + 
+--R                            4 8                6 6  3
+--R               (715653120A a b  - 5730729984C a b )c
+--R             + 
+--R                              3 10               5 8  2               4 10
+--R               (- 144506880A a b   + 802357248C a b )c  + 219340800C a b  c
+--R             + 
+--R                            3 12
+--R               - 40642560C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                              8   6                    7 3                9   5
+--R               - 9688842240A a b c  + (- 50352619520A a b  + 3476029440C a b)c
+--R             + 
+--R                               6 5                 8 3  4
+--R               (- 4110417920A a b  + 16026173440C a b )c
+--R             + 
+--R                             5 7                7 5  3
+--R               (4541644800A a b  - 8976465920C a b )c
+--R             + 
+--R                              4 9                6 7  2                5 9
+--R               (- 567705600A a b  - 1723760640C a b )c  + 1348300800C a b c
+--R             + 
+--R                             4 11
+--R               - 159667200C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                               8 2 5
+--R               - 46506442752A a b c
+--R             + 
+--R                                7 4                 9 2  4
+--R               (- 28538044416A a b  + 16684941312C a b )c
+--R             + 
+--R                              6 6               8 4  3
+--R               (11597250560A a b  + 452984832C a b )c
+--R             + 
+--R                               5 8                7 6  2                6 8
+--R               (- 1211105280A a b  - 9475981312C a b )c  + 3413114880C a b c
+--R             + 
+--R                             5 10
+--R               - 340623360C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                               9   5
+--R               - 15502147584A a b c
+--R             + 
+--R                                8 3                10   4
+--R               (- 45684359168A a b  + 5561647104C a  b)c
+--R             + 
+--R                              7 5                 9 3  3
+--R               (14826864640A a b  + 13128171520C a b )c
+--R             + 
+--R                               6 7                 8 5  2                7 7
+--R               (- 1431306240A a b  - 14702084096C a b )c  + 4348968960C a b c
+--R             + 
+--R                             6 9
+--R               - 402554880C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                               9 2 4                 8 4                 10 2  3
+--R               - 31004295168A a b c  + (9395240960A a b  + 11123294208C a  b )c
+--R             + 
+--R                              7 6                9 4  2                8 6
+--R               (- 880803840A a b  - 9894363136C a b )c  + 2752512000C a b c
+--R             + 
+--R                             7 8
+--R               - 247726080C a b
+--R          *
+--R             x
+--R         + 
+--R                          10   4                 9 3                11   3
+--R           - 7751073792A a  b c  + (2348810240A a b  + 2780823552C a  b)c
+--R         + 
+--R                          8 5                10 3  2               9 5
+--R           (- 220200960A a b  - 2473590784C a  b )c  + 688128000C a b c
+--R         + 
+--R                        8 7
+--R           - 61931520C a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                           3   8              2 3 7               5 6
+--R                 704643072a b c  + 1233125376a b c  + 308281344a b c
+--R               + 
+--R                          7 5
+--R                 11010048b c
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                          4 8              3 2 7              2 4 6
+--R               1409286144a c  + 9512681472a b c  + 5549064192a b c
+--R             + 
+--R                           6 5
+--R               462422016a b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        4   7               3 3 6              2 5 5  5
+--R           (21139292160a b c  + 31708938240a b c  + 5549064192a b c )x
+--R         + 
+--R                        5 7               4 2 6               3 4 5  4
+--R           (14092861440a c  + 77510737920a b c  + 29066526720a b c )x
+--R         + 
+--R                        5   6               4 3 5  3
+--R           (84557168640a b c  + 77510737920a b c )x
+--R         + 
+--R                        6 6                5 2 5  2               6   5
+--R           (33822867456a c  + 109924319232a b c )x  + 78920024064a b c x
+--R         + 
+--R                       7 5
+--R           22548578304a c
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                           4 9              3 2 8             2 4 7
+--R               - 176160768a c  - 1233125376a b c  - 770703360a b c
+--R             + 
+--R                            6 6          8 5
+--R               - 77070336a b c  - 688128b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                            4   8              3 3 7              2 5 6
+--R               - 5637144576a b c  - 9865003008a b c  - 2466250752a b c
+--R             + 
+--R                            7 5
+--R               - 88080384a b c
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                            5 8               4 2 7               3 4 6
+--R               - 5637144576a c  - 38050725888a b c  - 22196256768a b c
+--R             + 
+--R                            2 6 5
+--R               - 1849688064a b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          5   7               4 3 6               3 5 5  5
+--R           (- 56371445760a b c  - 84557168640a b c  - 14797504512a b c )x
+--R         + 
+--R                          6 7                5 2 6               4 4 5  4
+--R           (- 28185722880a c  - 155021475840a b c  - 58133053440a b c )x
+--R         + 
+--R                           6   6                5 3 5  3
+--R           (- 135291469824a b c  - 124017180672a b c )x
+--R         + 
+--R                          7 6                6 2 5  2               7   5
+--R           (- 45097156608a c  - 146565758976a b c )x  - 90194313216a b c x
+--R         + 
+--R                         8 5
+--R           - 22548578304a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 556
+t0:=(a+b*x+c*x^2)^(3/2)*(A+C*x^2)
+--R 
+--R
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R   (1)  (C c x  + C b x  + (A c + C a)x  + A b x + A a)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 556
+r0:=1/192*(24*A*c^2+7*b^2*C-4*a*c*C)*(b+2*c*x)*(a+b*x+c*x^2)^(3/2)/c^3-_
+   1/60*C*(7*b-10*c*x)*(a+b*x+c*x^2)^(5/2)/c^2+1/1024*(b^2-4*a*c)^2*_
+   (24*A*c^2+7*b^2*C-4*a*c*C)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/c^(9/2)-1/512*(b^2-4*a*c)*(24*A*c^2+7*b^2*C-_
+   4*a*c*C)*(b+2*c*x)*sqrt(a+b*x+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R                  2 4               2         3  3          4          2 2  2
+--R           5760A a c  + (- 2880A a b  - 960C a )c  + (360A b  + 2160C a b )c
+--R         + 
+--R                     4          6
+--R           - 900C a b c + 105C b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                  5 5            4 4           5            4        2 3  3
+--R           2560C c x  + 3328C b c x  + (3840A c  + 4480C a c  + 96C b c )x
+--R         + 
+--R                     4             3         3 2  2
+--R           (5760A b c  + 576C a b c  - 112C b c )x
+--R         + 
+--R                     4          2         2  3           2 2         4
+--R           (9600A a c  + (480A b  + 960C a )c  - 864C a b c  + 140C b c)x
+--R         + 
+--R                      3            3          2   2            3          5
+--R           4800A a b c  + (- 720A b  - 2592C a b)c  + 1520C a b c - 210C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R           4 +-+
+--R     15360c \|c
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               4   6             3 3            5   5
+--R                     1105920A a b c  + (368640A a b  - 184320C a b)c
+--R                   + 
+--R                                 2 5            4 3  4
+--R                     (- 322560A a b  + 261120C a b )c
+--R                   + 
+--R                                7            3 5  3           9           2 7  2
+--R                     (23040A a b  + 161280C a b )c  + (4320A b  - 97920C a b )c
+--R                   + 
+--R                              9           11
+--R                     6000C a b c + 1260C b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                               5 6              4 2            6  5
+--R                     2211840A a c  + (6635520A a b  - 368640C a )c
+--R                   + 
+--R                                  3 4            5 2  4
+--R                     (- 2119680A a b  - 460800C a b )c
+--R                   + 
+--R                                 2 6             4 4  3
+--R                     (- 322560A a b  + 2288640C a b )c
+--R                   + 
+--R                                 8            3 6  2            2 8
+--R                     (100800A a b  - 564480C a b )c  - 110880C a b c
+--R                   + 
+--R                               10
+--R                     29400C a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                                5   5              4 3             6   4
+--R                     17694720A a b c  + (1474560A a b  - 2949120C a b)c
+--R                   + 
+--R                                  3 5             5 3  3
+--R                     (- 4055040A a b  + 4915200C a b )c
+--R                   + 
+--R                               2 7             4 5  2             3 7
+--R                     (645120A a b  + 1105920C a b )c  - 1290240C a b c
+--R                   + 
+--R                              2 9
+--R                     188160C a b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                                6 5               5 2             7  4
+--R                     11796480A a c  + (20643840A a b  - 1966080C a )c
+--R                   + 
+--R                                  4 4 3              3 6             5 4  2
+--R                     - 12533760A a b c  + (1658880A a b  + 8110080C a b )c
+--R                   + 
+--R                                 4 6             3 8
+--R                     - 3932160C a b c + 483840C a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                                6   4                 5 3             7   3
+--R                     29491200A a b c  + (- 14745600A a b  - 4915200C a b)c
+--R                   + 
+--R                                4 5              6 3  2             5 5
+--R                     (1843200A a b  + 11059200C a b )c  - 4608000C a b c
+--R                   + 
+--R                              4 7
+--R                     537600C a b
+--R                *
+--R                   x
+--R               + 
+--R                            7 4                6 2             8  3
+--R                 11796480A a c  + (- 5898240A a b  - 1966080C a )c
+--R               + 
+--R                         5 4             7 2  2             6 4             5 6
+--R               (737280A a b  + 4423680C a b )c  - 1843200C a b c + 215040C a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                            5 7                4 2           6  6
+--R                 - 368640A a c  + (- 1198080A a b  + 61440C a )c
+--R               + 
+--R                           3 4           5 2  5            2 6            4 4  4
+--R                 (322560A a b  + 92160C a b )c  + (80640A a b  - 403200C a b )c
+--R               + 
+--R                              8           3 6  3            10           2 8  2
+--R                 (- 18720A a b  + 80640C a b )c  + (- 360A b   + 26640C a b )c
+--R               + 
+--R                            10          12
+--R                 - 5400C a b  c - 105C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                             5   6                4 3             6   5
+--R                 - 6635520A a b c  + (- 2211840A a b  + 1105920C a b)c
+--R               + 
+--R                            3 5             5 3  4
+--R                 (1935360A a b  - 1566720C a b )c
+--R               + 
+--R                             2 7            4 5  3
+--R                 (- 138240A a b  - 967680C a b )c
+--R               + 
+--R                              9            3 7  2           2 9             11
+--R                 (- 25920A a b  + 587520C a b )c  - 36000C a b c - 7560C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                             6 6                 5 2             7  5
+--R                 - 6635520A a c  + (- 19906560A a b  + 1105920C a )c
+--R               + 
+--R                            4 4             6 2  4
+--R                 (6359040A a b  + 1382400C a b )c
+--R               + 
+--R                           3 6             5 4  3
+--R                 (967680A a b  - 6865920C a b )c
+--R               + 
+--R                           2 8             4 6  2            3 8            2 10
+--R               (- 302400A a b  + 1693440C a b )c  + 332640C a b c - 88200C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                              6   5                5 3             7   4
+--R                 - 35389440A a b c  + (- 2949120A a b  + 5898240C a b)c
+--R               + 
+--R                            4 5             6 3  3
+--R                 (8110080A a b  - 9830400C a b )c
+--R               + 
+--R                              3 7             5 5  2             4 7
+--R                 (- 1290240A a b  - 2211840C a b )c  + 2580480C a b c
+--R               + 
+--R                            3 9
+--R                 - 376320C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                              7 5                 6 2             8  4
+--R                 - 17694720A a c  + (- 30965760A a b  + 2949120C a )c
+--R               + 
+--R                            5 4 3                4 6              6 4  2
+--R                 18800640A a b c  + (- 2488320A a b  - 12165120C a b )c
+--R               + 
+--R                           5 6             4 8
+--R                 5898240C a b c - 725760C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                              7   4               6 3             8   3
+--R                 - 35389440A a b c  + (17694720A a b  + 5898240C a b)c
+--R               + 
+--R                              5 5              7 3  2             6 5
+--R                 (- 2211840A a b  - 13271040C a b )c  + 5529600C a b c
+--R               + 
+--R                            5 7
+--R                 - 645120C a b
+--R            *
+--R               x
+--R           + 
+--R                          8 4              7 2             9  3
+--R             - 11796480A a c  + (5898240A a b  + 1966080C a )c
+--R           + 
+--R                         6 4             8 2  2             7 4             6 6
+--R             (- 737280A a b  - 4423680C a b )c  + 1843200C a b c - 215040C a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                         3 8            2 2 7              4 6          6 5  11
+--R             (- 163840C a c  - 614400C a b c  - 153600C a b c  - 2560C b c )x
+--R           + 
+--R                               3   7             2 3 6              5 5
+--R                   - 3162112C a b c  - 3256320C a b c  - 384000C a b c
+--R                 + 
+--R                            7 4
+--R                   - 3328C b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            3 8               2 2             4  7
+--R                 - 245760A a c  + (- 921600A a b  - 3235840C a )c
+--R               + 
+--R                               4              3 2  6
+--R                 (- 230400A a b  - 15237120C a b )c
+--R               + 
+--R                           6             2 4  5              6 4        8 3
+--R                 (- 3840A b  - 5637120C a b )c  - 249856C a b c  - 96C b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                             3   7                2 3              4   6
+--R                 - 4792320A a b c  + (- 5068800A a b  - 24760320C a b)c
+--R               + 
+--R                               5              3 3  5
+--R                 (- 622080A a b  - 27136000C a b )c
+--R               + 
+--R                           7             2 5  4           7 3         9 2
+--R                 (- 5760A b  - 3217920C a b )c  - 768C a b c  + 112C b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             4 7                 3 2              5  6
+--R                 - 5038080A a c  + (- 24453120A a b  - 13086720C a )c
+--R               + 
+--R                              2 4              4 2  5
+--R                 (- 9446400A a b  - 57154560C a b )c
+--R               + 
+--R                               6              3 4  4
+--R                 (- 453120A a b  - 16360960C a b )c
+--R               + 
+--R                          8          2 6  3           8 2         10
+--R                 (- 480A b  + 2688C a b )c  + 528C a b c  - 140C b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                              4   6                 3 3              5   5
+--R                 - 41594880A a b c  + (- 47861760A a b  - 55080960C a b)c
+--R               + 
+--R                              2 5              4 3  4
+--R                 (- 6105600A a b  - 41244160C a b )c
+--R               + 
+--R                           7           3 5  3          9           2 7  2
+--R                 (3840A a b  + 26880C a b )c  + (720A b  - 16320C a b )c
+--R               + 
+--R                          9          11
+--R                 1000C a b c + 210C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                              5 6                  4 2              6  5
+--R                 - 22855680A a c  + (- 105799680A a b  - 20111360C a )c
+--R               + 
+--R                               3 4              5 2  4
+--R                 (- 33792000A a b  - 55633920C a b )c
+--R               + 
+--R                             2 6             4 4  3
+--R                 (- 115200A a b  + 1090560C a b )c
+--R               + 
+--R                            8            3 6  2           2 8              10
+--R                 (43200A a b  - 296192C a b )c  - 40800C a b c + 12600C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                               5   5                 4 3              6   4
+--R                 - 103956480A a b c  + (- 89518080A a b  - 40017920C a b)c
+--R               + 
+--R                              3 5             5 3  3
+--R                 (- 2472960A a b  + 3440640C a b )c
+--R               + 
+--R                           2 7            4 5  2            3 7             2 9
+--R                 (403200A a b  + 537600C a b )c  - 788480C a b c + 117600C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                              6 5                  5 2              7  4
+--R                 - 37355520A a c  + (- 117964800A a b  - 12124160C a )c
+--R               + 
+--R                              4 4            6 2  3
+--R                 (- 9707520A a b  + 245760C a b )c
+--R               + 
+--R                          3 6             5 4  2             4 6             3 8
+--R               (1290240A a b  + 6205440C a b )c  - 3046400C a b c + 376320C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                              6   4                 5 3             7   3
+--R                 - 75694080A a b c  + (- 13271040A a b  - 4423680C a b)c
+--R               + 
+--R                          4 5             6 3  2             5 5             4 7
+--R               (1658880A a b  + 9953280C a b )c  - 4147200C a b c + 483840C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                              7 4                6 2             8  3
+--R                 - 19660800A a c  + (- 5898240A a b  - 1966080C a )c
+--R               + 
+--R                         5 4             7 2  2             6 4             5 6
+--R               (737280A a b  + 4423680C a b )c  - 1843200C a b c + 215040C a b
+--R            *
+--R               x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                       2   8              3 7           5 6  12
+--R             (491520C a b c  + 409600C a b c  + 30720C b c )x
+--R           + 
+--R                       3 8             2 2 7               4 6           6 5  11
+--R             (983040C a c  + 4571136C a b c  + 1658880C a b c  + 70656C b c )x
+--R           + 
+--R                          2   8               3              3   7
+--R                 737280A a b c  + (614400A a b  + 11476992C a b)c
+--R               + 
+--R                          5              2 3  6               5 5           7 4
+--R                 (46080A b  + 14284800C a b )c  + 2280960C a b c  + 41088C b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           3 8              2 2             4  7
+--R                 1474560A a c  + (7004160A a b  + 7946240C a )c
+--R               + 
+--R                              4              3 2  6
+--R                 (2611200A a b  + 42270720C a b )c
+--R               + 
+--R                           6              2 4  5               6 4         8 3
+--R                 (115200A b  + 18462720C a b )c  + 1056768C a b c  - 192C b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                            3   7               2 3              4   6
+--R                 18063360A a b c  + (23132160A a b  + 51056640C a b)c
+--R               + 
+--R                              5              3 3  5
+--R                 (3847680A a b  + 62361600C a b )c
+--R               + 
+--R                          7             2 5  4            7 3         9 2
+--R                 (74880A b  + 8501760C a b )c  - 2304C a b c  + 336C b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            4 7               3 2              5  6
+--R                 13025280A a c  + (71516160A a b  + 21749760C a )c
+--R               + 
+--R                             2 4               4 2  5
+--R                 (32532480A a b  + 102389760C a b )c
+--R               + 
+--R                              6              3 4  4
+--R                 (1950720A a b  + 31964160C a b )c
+--R               + 
+--R                           8           2 6  3            8 2         10
+--R                 (- 2880A b  + 16128C a b )c  + 3168C a b c  - 840C b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                            4   6                3 3              5   5
+--R                 89886720A a b c  + (115937280A a b  + 81930240C a b)c
+--R               + 
+--R                             2 5              4 3  4
+--R                 (17210880A a b  + 64094720C a b )c
+--R               + 
+--R                              7            3 5  3
+--R                 (- 80640A a b  - 341760C a b )c
+--R               + 
+--R                           9            2 7  2             9           11
+--R                 (- 7920A b  + 254016C a b )c  - 22200C a b c - 2310C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            5 6                4 2              6  5
+--R                 39075840A a c  + (196116480A a b  + 25927680C a )c
+--R               + 
+--R                             3 4              5 2  4
+--R                 (70502400A a b  + 73820160C a b )c
+--R               + 
+--R                           2 6             4 4  3
+--R                 (368640A a b  - 4254720C a b )c
+--R               + 
+--R                             8             3 6  2            2 8              10
+--R               (- 158400A a b  + 1212672C a b )c  + 133920C a b c - 46200C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                             5   5                4 3              6   4
+--R                 155566080A a b c  + (145428480A a b  + 47800320C a b)c
+--R               + 
+--R                            3 5             5 3  3
+--R                 (5391360A a b  - 7864320C a b )c
+--R               + 
+--R                             2 7             4 5  2             3 7
+--R                 (- 887040A a b  - 1059840C a b )c  + 1720320C a b c
+--R               + 
+--R                            2 9
+--R                 - 258720C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            6 5                5 2              7  4
+--R                 47185920A a c  + (156303360A a b  + 13107200C a )c
+--R               + 
+--R                             4 4            6 2  3
+--R                 (15237120A a b  - 491520C a b )c
+--R               + 
+--R                              3 6             5 4  2             4 6
+--R                 (- 2027520A a b  - 9707520C a b )c  + 4782080C a b c
+--R               + 
+--R                            3 8
+--R                 - 591360C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                            6   4               5 3             7   3
+--R                 85524480A a b c  + (16220160A a b  + 5406720C a b)c
+--R               + 
+--R                              4 5              6 3  2             5 5
+--R                 (- 2027520A a b  - 12165120C a b )c  + 5068800C a b c
+--R               + 
+--R                            4 7
+--R                 - 591360C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                            7 4              6 2             8  3
+--R                 19660800A a c  + (5898240A a b  + 1966080C a )c
+--R               + 
+--R                             5 4             7 2  2             6 4
+--R                 (- 737280A a b  - 4423680C a b )c  + 1843200C a b c
+--R               + 
+--R                            5 6
+--R                 - 215040C a b
+--R            *
+--R               x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                      2   6             3 5          5 4  5
+--R             (2949120a b c  + 2457600a b c  + 184320b c )x
+--R           + 
+--R                      3 6            2 2 5             4 4  4
+--R             (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R           + 
+--R                       3   5            2 3 4  3
+--R             (47185920a b c  + 27525120a b c )x
+--R           + 
+--R                       4 5            3 2 4  2            4   4             5 4
+--R             (31457280a c  + 70778880a b c )x  + 78643200a b c x + 31457280a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                       3 7           2 2 6            4 5         6 4  6
+--R             (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R           + 
+--R                         3   6            2 3 5             5 4  5
+--R             (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R           + 
+--R                         4 6            3 2 5            2 4 4  4
+--R             (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R           + 
+--R                         4   5            3 3 4  3
+--R             (- 94371840a b c  - 55050240a b c )x
+--R           + 
+--R                       5 5             4 2 4  2            5   4             6 4
+--R           (- 47185920a c  - 106168320a b c )x  - 94371840a b c x - 31457280a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                               4   6             3 3            5   5
+--R                     1105920A a b c  + (368640A a b  - 184320C a b)c
+--R                   + 
+--R                                 2 5            4 3  4
+--R                     (- 322560A a b  + 261120C a b )c
+--R                   + 
+--R                                7            3 5  3           9           2 7  2
+--R                     (23040A a b  + 161280C a b )c  + (4320A b  - 97920C a b )c
+--R                   + 
+--R                              9           11
+--R                     6000C a b c + 1260C b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                               5 6              4 2            6  5
+--R                     2211840A a c  + (6635520A a b  - 368640C a )c
+--R                   + 
+--R                                  3 4            5 2  4
+--R                     (- 2119680A a b  - 460800C a b )c
+--R                   + 
+--R                                 2 6             4 4  3
+--R                     (- 322560A a b  + 2288640C a b )c
+--R                   + 
+--R                                 8            3 6  2            2 8
+--R                     (100800A a b  - 564480C a b )c  - 110880C a b c
+--R                   + 
+--R                               10
+--R                     29400C a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                                5   5              4 3             6   4
+--R                     17694720A a b c  + (1474560A a b  - 2949120C a b)c
+--R                   + 
+--R                                  3 5             5 3  3
+--R                     (- 4055040A a b  + 4915200C a b )c
+--R                   + 
+--R                               2 7             4 5  2             3 7
+--R                     (645120A a b  + 1105920C a b )c  - 1290240C a b c
+--R                   + 
+--R                              2 9
+--R                     188160C a b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                                6 5               5 2             7  4
+--R                     11796480A a c  + (20643840A a b  - 1966080C a )c
+--R                   + 
+--R                                  4 4 3              3 6             5 4  2
+--R                     - 12533760A a b c  + (1658880A a b  + 8110080C a b )c
+--R                   + 
+--R                                 4 6             3 8
+--R                     - 3932160C a b c + 483840C a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                                6   4                 5 3             7   3
+--R                     29491200A a b c  + (- 14745600A a b  - 4915200C a b)c
+--R                   + 
+--R                                4 5              6 3  2             5 5
+--R                     (1843200A a b  + 11059200C a b )c  - 4608000C a b c
+--R                   + 
+--R                              4 7
+--R                     537600C a b
+--R                *
+--R                   x
+--R               + 
+--R                            7 4                6 2             8  3
+--R                 11796480A a c  + (- 5898240A a b  - 1966080C a )c
+--R               + 
+--R                         5 4             7 2  2             6 4             5 6
+--R               (737280A a b  + 4423680C a b )c  - 1843200C a b c + 215040C a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                            5 7                4 2           6  6
+--R                 - 368640A a c  + (- 1198080A a b  + 61440C a )c
+--R               + 
+--R                           3 4           5 2  5            2 6            4 4  4
+--R                 (322560A a b  + 92160C a b )c  + (80640A a b  - 403200C a b )c
+--R               + 
+--R                              8           3 6  3            10           2 8  2
+--R                 (- 18720A a b  + 80640C a b )c  + (- 360A b   + 26640C a b )c
+--R               + 
+--R                            10          12
+--R                 - 5400C a b  c - 105C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                             5   6                4 3             6   5
+--R                 - 6635520A a b c  + (- 2211840A a b  + 1105920C a b)c
+--R               + 
+--R                            3 5             5 3  4
+--R                 (1935360A a b  - 1566720C a b )c
+--R               + 
+--R                             2 7            4 5  3
+--R                 (- 138240A a b  - 967680C a b )c
+--R               + 
+--R                              9            3 7  2           2 9             11
+--R                 (- 25920A a b  + 587520C a b )c  - 36000C a b c - 7560C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                             6 6                 5 2             7  5
+--R                 - 6635520A a c  + (- 19906560A a b  + 1105920C a )c
+--R               + 
+--R                            4 4             6 2  4
+--R                 (6359040A a b  + 1382400C a b )c
+--R               + 
+--R                           3 6             5 4  3
+--R                 (967680A a b  - 6865920C a b )c
+--R               + 
+--R                           2 8             4 6  2            3 8            2 10
+--R               (- 302400A a b  + 1693440C a b )c  + 332640C a b c - 88200C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                              6   5                5 3             7   4
+--R                 - 35389440A a b c  + (- 2949120A a b  + 5898240C a b)c
+--R               + 
+--R                            4 5             6 3  3
+--R                 (8110080A a b  - 9830400C a b )c
+--R               + 
+--R                              3 7             5 5  2             4 7
+--R                 (- 1290240A a b  - 2211840C a b )c  + 2580480C a b c
+--R               + 
+--R                            3 9
+--R                 - 376320C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                              7 5                 6 2             8  4
+--R                 - 17694720A a c  + (- 30965760A a b  + 2949120C a )c
+--R               + 
+--R                            5 4 3                4 6              6 4  2
+--R                 18800640A a b c  + (- 2488320A a b  - 12165120C a b )c
+--R               + 
+--R                           5 6             4 8
+--R                 5898240C a b c - 725760C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                              7   4               6 3             8   3
+--R                 - 35389440A a b c  + (17694720A a b  + 5898240C a b)c
+--R               + 
+--R                              5 5              7 3  2             6 5
+--R                 (- 2211840A a b  - 13271040C a b )c  + 5529600C a b c
+--R               + 
+--R                            5 7
+--R                 - 645120C a b
+--R            *
+--R               x
+--R           + 
+--R                          8 4              7 2             9  3
+--R             - 11796480A a c  + (5898240A a b  + 1966080C a )c
+--R           + 
+--R                         6 4             8 2  2             7 4             6 6
+--R             (- 737280A a b  - 4423680C a b )c  + 1843200C a b c - 215040C a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                        3 8            2 2 7             4 6          6 5  11
+--R             (- 81920C a c  - 307200C a b c  - 76800C a b c  - 1280C b c )x
+--R           + 
+--R                               3   7             2 3 6              5 5
+--R                   - 1581056C a b c  - 1628160C a b c  - 192000C a b c
+--R                 + 
+--R                            7 4
+--R                   - 1664C b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            3 8               2 2             4  7
+--R                 - 122880A a c  + (- 460800A a b  - 1617920C a )c
+--R               + 
+--R                               4             3 2  6
+--R                 (- 115200A a b  - 7618560C a b )c
+--R               + 
+--R                           6             2 4  5              6 4        8 3
+--R                 (- 1920A b  - 2818560C a b )c  - 124928C a b c  - 48C b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                             3   7                2 3              4   6
+--R                 - 2396160A a b c  + (- 2534400A a b  - 12380160C a b)c
+--R               + 
+--R                               5              3 3  5
+--R                 (- 311040A a b  - 13568000C a b )c
+--R               + 
+--R                           7             2 5  4           7 3        9 2
+--R                 (- 2880A b  - 1608960C a b )c  - 384C a b c  + 56C b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             4 7                 3 2             5  6
+--R                 - 2519040A a c  + (- 12226560A a b  - 6543360C a )c
+--R               + 
+--R                              2 4              4 2  5
+--R                 (- 4723200A a b  - 28577280C a b )c
+--R               + 
+--R                               6             3 4  4            8          2 6  3
+--R                 (- 226560A a b  - 8180480C a b )c  + (- 240A b  + 1344C a b )c
+--R               + 
+--R                         8 2        10
+--R                 264C a b c  - 70C b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                              4   6                 3 3              5   5
+--R                 - 20797440A a b c  + (- 23930880A a b  - 27540480C a b)c
+--R               + 
+--R                              2 5              4 3  4
+--R                 (- 3052800A a b  - 20622080C a b )c
+--R               + 
+--R                           7           3 5  3          9          2 7  2
+--R                 (1920A a b  + 13440C a b )c  + (360A b  - 8160C a b )c
+--R               + 
+--R                         9          11
+--R                 500C a b c + 105C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                              5 6                 4 2              6  5
+--R                 - 11427840A a c  + (- 52899840A a b  - 10055680C a )c
+--R               + 
+--R                               3 4              5 2  4
+--R                 (- 16896000A a b  - 27816960C a b )c
+--R               + 
+--R                            2 6            4 4  3
+--R                 (- 57600A a b  + 545280C a b )c
+--R               + 
+--R                            8            3 6  2           2 8             10
+--R                 (21600A a b  - 148096C a b )c  - 20400C a b c + 6300C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                              5   5                 4 3              6   4
+--R                 - 51978240A a b c  + (- 44759040A a b  - 20008960C a b)c
+--R               + 
+--R                              3 5             5 3  3
+--R                 (- 1236480A a b  + 1720320C a b )c
+--R               + 
+--R                           2 7            4 5  2            3 7            2 9
+--R                 (201600A a b  + 268800C a b )c  - 394240C a b c + 58800C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                              6 5                 5 2             7  4
+--R                 - 18677760A a c  + (- 58982400A a b  - 6062080C a )c
+--R               + 
+--R                              4 4            6 2  3
+--R                 (- 4853760A a b  + 122880C a b )c
+--R               + 
+--R                         3 6             5 4  2             4 6             3 8
+--R               (645120A a b  + 3102720C a b )c  - 1523200C a b c + 188160C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                              6   4                5 3             7   3
+--R                 - 37847040A a b c  + (- 6635520A a b  - 2211840C a b)c
+--R               + 
+--R                         4 5             6 3  2             5 5             4 7
+--R               (829440A a b  + 4976640C a b )c  - 2073600C a b c + 241920C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                             7 4                6 2            8  3
+--R                 - 9830400A a c  + (- 2949120A a b  - 983040C a )c
+--R               + 
+--R                         5 4             7 2  2            6 4             5 6
+--R               (368640A a b  + 2211840C a b )c  - 921600C a b c + 107520C a b
+--R            *
+--R               x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                       2   8              3 7           5 6  12
+--R             (245760C a b c  + 204800C a b c  + 15360C b c )x
+--R           + 
+--R                       3 8             2 2 7              4 6           6 5  11
+--R             (491520C a c  + 2285568C a b c  + 829440C a b c  + 35328C b c )x
+--R           + 
+--R                          2   8               3             3   7
+--R                 368640A a b c  + (307200A a b  + 5738496C a b)c
+--R               + 
+--R                          5             2 3  6               5 5           7 4
+--R                 (23040A b  + 7142400C a b )c  + 1140480C a b c  + 20544C b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          3 8              2 2             4  7
+--R                 737280A a c  + (3502080A a b  + 3973120C a )c
+--R               + 
+--R                              4              3 2  6
+--R                 (1305600A a b  + 21135360C a b )c
+--R               + 
+--R                          6             2 4  5              6 4        8 3
+--R                 (57600A b  + 9231360C a b )c  + 528384C a b c  - 96C b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                           3   7               2 3              4   6
+--R                 9031680A a b c  + (11566080A a b  + 25528320C a b)c
+--R               + 
+--R                              5              3 3  5
+--R                 (1923840A a b  + 31180800C a b )c
+--R               + 
+--R                          7             2 5  4            7 3         9 2
+--R                 (37440A b  + 4250880C a b )c  - 1152C a b c  + 168C b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                           4 7               3 2              5  6
+--R                 6512640A a c  + (35758080A a b  + 10874880C a )c
+--R               + 
+--R                             2 4              4 2  5
+--R                 (16266240A a b  + 51194880C a b )c
+--R               + 
+--R                             6              3 4  4             8          2 6  3
+--R                 (975360A a b  + 15982080C a b )c  + (- 1440A b  + 8064C a b )c
+--R               + 
+--R                          8 2         10
+--R                 1584C a b c  - 420C b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                            4   6               3 3              5   5
+--R                 44943360A a b c  + (57968640A a b  + 40965120C a b)c
+--R               + 
+--R                            2 5              4 3  4
+--R                 (8605440A a b  + 32047360C a b )c
+--R               + 
+--R                              7            3 5  3
+--R                 (- 40320A a b  - 170880C a b )c
+--R               + 
+--R                           9            2 7  2             9           11
+--R                 (- 3960A b  + 127008C a b )c  - 11100C a b c - 1155C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            5 6               4 2              6  5
+--R                 19537920A a c  + (98058240A a b  + 12963840C a )c
+--R               + 
+--R                             3 4              5 2  4
+--R                 (35251200A a b  + 36910080C a b )c
+--R               + 
+--R                           2 6             4 4  3
+--R                 (184320A a b  - 2127360C a b )c
+--R               + 
+--R                              8            3 6  2           2 8              10
+--R                 (- 79200A a b  + 606336C a b )c  + 66960C a b c - 23100C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                            5   5               4 3              6   4
+--R                 77783040A a b c  + (72714240A a b  + 23900160C a b)c
+--R               + 
+--R                            3 5             5 3  3
+--R                 (2695680A a b  - 3932160C a b )c
+--R               + 
+--R                           2 7            4 5  2            3 7             2 9
+--R               (- 443520A a b  - 529920C a b )c  + 860160C a b c - 129360C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            6 5               5 2             7  4
+--R                 23592960A a c  + (78151680A a b  + 6553600C a )c
+--R               + 
+--R                            4 4            6 2  3
+--R                 (7618560A a b  - 245760C a b )c
+--R               + 
+--R                              3 6             5 4  2             4 6
+--R                 (- 1013760A a b  - 4853760C a b )c  + 2391040C a b c
+--R               + 
+--R                            3 8
+--R                 - 295680C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                            6   4              5 3             7   3
+--R                 42762240A a b c  + (8110080A a b  + 2703360C a b)c
+--R               + 
+--R                              4 5             6 3  2             5 5
+--R                 (- 1013760A a b  - 6082560C a b )c  + 2534400C a b c
+--R               + 
+--R                            4 7
+--R                 - 295680C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           7 4              6 2            8  3
+--R                 9830400A a c  + (2949120A a b  + 983040C a )c
+--R               + 
+--R                           5 4             7 2  2            6 4             5 6
+--R               (- 368640A a b  - 2211840C a b )c  + 921600C a b c - 107520C a b
+--R            *
+--R               x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                      2   6             3 5         5 4  5
+--R             (1474560a b c  + 1228800a b c  + 92160b c )x
+--R           + 
+--R                      3 6            2 2 5             4 4  4
+--R             (2949120a c  + 10321920a b c  + 2150400a b c )x
+--R           + 
+--R                       3   5            2 3 4  3
+--R             (23592960a b c  + 13762560a b c )x
+--R           + 
+--R                       4 5            3 2 4  2            4   4             5 4
+--R             (15728640a c  + 35389440a b c )x  + 39321600a b c x + 15728640a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                       3 7           2 2 6            4 5        6 4  6
+--R             (- 491520a c  - 1843200a b c  - 460800a b c  - 7680b c )x
+--R           + 
+--R                        3   6           2 3 5            5 4  5
+--R             (- 8847360a b c  - 7372800a b c  - 552960a b c )x
+--R           + 
+--R                        4 6            3 2 5           2 4 4  4
+--R             (- 8847360a c  - 30965760a b c  - 6451200a b c )x
+--R           + 
+--R                         4   5            3 3 4  3
+--R             (- 47185920a b c  - 27525120a b c )x
+--R           + 
+--R                       5 5            4 2 4  2            5   4             6 4
+--R           (- 23592960a c  - 53084160a b c )x  - 47185920a b c x - 15728640a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 144
+
+--S 145 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             4   6             3 3            5   5
+--R                   1105920A a b c  + (368640A a b  - 184320C a b)c
+--R                 + 
+--R                               2 5            4 3  4
+--R                   (- 322560A a b  + 261120C a b )c
+--R                 + 
+--R                              7            3 5  3           9           2 7  2
+--R                   (23040A a b  + 161280C a b )c  + (4320A b  - 97920C a b )c
+--R                 + 
+--R                            9           11
+--R                   6000C a b c + 1260C b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             5 6              4 2            6  5
+--R                   2211840A a c  + (6635520A a b  - 368640C a )c
+--R                 + 
+--R                                3 4            5 2  4
+--R                   (- 2119680A a b  - 460800C a b )c
+--R                 + 
+--R                               2 6             4 4  3
+--R                   (- 322560A a b  + 2288640C a b )c
+--R                 + 
+--R                             8            3 6  2            2 8              10
+--R                 (100800A a b  - 564480C a b )c  - 110880C a b c + 29400C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              5   5              4 3             6   4
+--R                   17694720A a b c  + (1474560A a b  - 2949120C a b)c
+--R                 + 
+--R                                3 5             5 3  3
+--R                   (- 4055040A a b  + 4915200C a b )c
+--R                 + 
+--R                             2 7             4 5  2             3 7
+--R                   (645120A a b  + 1105920C a b )c  - 1290240C a b c
+--R                 + 
+--R                            2 9
+--R                   188160C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                              6 5               5 2             7  4
+--R                   11796480A a c  + (20643840A a b  - 1966080C a )c
+--R                 + 
+--R                                4 4 3              3 6             5 4  2
+--R                   - 12533760A a b c  + (1658880A a b  + 8110080C a b )c
+--R                 + 
+--R                               4 6             3 8
+--R                   - 3932160C a b c + 483840C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                              6   4                 5 3             7   3
+--R                   29491200A a b c  + (- 14745600A a b  - 4915200C a b)c
+--R                 + 
+--R                              4 5              6 3  2             5 5
+--R                   (1843200A a b  + 11059200C a b )c  - 4608000C a b c
+--R                 + 
+--R                            4 7
+--R                   537600C a b
+--R              *
+--R                 x
+--R             + 
+--R                          7 4                6 2             8  3
+--R               11796480A a c  + (- 5898240A a b  - 1966080C a )c
+--R             + 
+--R                         5 4             7 2  2             6 4             5 6
+--R               (737280A a b  + 4423680C a b )c  - 1843200C a b c + 215040C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                          5 7                4 2           6  6
+--R               - 368640A a c  + (- 1198080A a b  + 61440C a )c
+--R             + 
+--R                         3 4           5 2  5            2 6            4 4  4
+--R               (322560A a b  + 92160C a b )c  + (80640A a b  - 403200C a b )c
+--R             + 
+--R                            8           3 6  3            10           2 8  2
+--R               (- 18720A a b  + 80640C a b )c  + (- 360A b   + 26640C a b )c
+--R             + 
+--R                          10          12
+--R               - 5400C a b  c - 105C b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           5   6                4 3             6   5
+--R               - 6635520A a b c  + (- 2211840A a b  + 1105920C a b)c
+--R             + 
+--R                          3 5             5 3  4
+--R               (1935360A a b  - 1566720C a b )c
+--R             + 
+--R                           2 7            4 5  3
+--R               (- 138240A a b  - 967680C a b )c
+--R             + 
+--R                            9            3 7  2           2 9             11
+--R               (- 25920A a b  + 587520C a b )c  - 36000C a b c - 7560C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                           6 6                 5 2             7  5
+--R               - 6635520A a c  + (- 19906560A a b  + 1105920C a )c
+--R             + 
+--R                          4 4             6 2  4
+--R               (6359040A a b  + 1382400C a b )c
+--R             + 
+--R                         3 6             5 4  3
+--R               (967680A a b  - 6865920C a b )c
+--R             + 
+--R                         2 8             4 6  2            3 8            2 10
+--R             (- 302400A a b  + 1693440C a b )c  + 332640C a b c - 88200C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                            6   5                5 3             7   4
+--R               - 35389440A a b c  + (- 2949120A a b  + 5898240C a b)c
+--R             + 
+--R                          4 5             6 3  3
+--R               (8110080A a b  - 9830400C a b )c
+--R             + 
+--R                          3 7             5 5  2             4 7             3 9
+--R             (- 1290240A a b  - 2211840C a b )c  + 2580480C a b c - 376320C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                            7 5                 6 2             8  4
+--R               - 17694720A a c  + (- 30965760A a b  + 2949120C a )c
+--R             + 
+--R                          5 4 3                4 6              6 4  2
+--R               18800640A a b c  + (- 2488320A a b  - 12165120C a b )c
+--R             + 
+--R                         5 6             4 8
+--R               5898240C a b c - 725760C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                            7   4               6 3             8   3
+--R               - 35389440A a b c  + (17694720A a b  + 5898240C a b)c
+--R             + 
+--R                            5 5              7 3  2             6 5
+--R               (- 2211840A a b  - 13271040C a b )c  + 5529600C a b c
+--R             + 
+--R                          5 7
+--R               - 645120C a b
+--R          *
+--R             x
+--R         + 
+--R                        8 4              7 2             9  3
+--R           - 11796480A a c  + (5898240A a b  + 1966080C a )c
+--R         + 
+--R                       6 4             8 2  2             7 4             6 6
+--R           (- 737280A a b  - 4423680C a b )c  + 1843200C a b c - 215040C a b
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                               4   6               3 3            5   5
+--R                   - 1105920A a b c  + (- 368640A a b  + 184320C a b)c
+--R                 + 
+--R                             2 5            4 3  4
+--R                   (322560A a b  - 261120C a b )c
+--R                 + 
+--R                                7            3 5  3
+--R                   (- 23040A a b  - 161280C a b )c
+--R                 + 
+--R                             9           2 7  2            9           11
+--R                   (- 4320A b  + 97920C a b )c  - 6000C a b c - 1260C b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                               5 6                4 2            6  5
+--R                   - 2211840A a c  + (- 6635520A a b  + 368640C a )c
+--R                 + 
+--R                              3 4            5 2  4
+--R                   (2119680A a b  + 460800C a b )c
+--R                 + 
+--R                             2 6             4 4  3
+--R                   (322560A a b  - 2288640C a b )c
+--R                 + 
+--R                                 8            3 6  2            2 8
+--R                   (- 100800A a b  + 564480C a b )c  + 110880C a b c
+--R                 + 
+--R                               10
+--R                   - 29400C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                5   5                4 3             6   4
+--R                   - 17694720A a b c  + (- 1474560A a b  + 2949120C a b)c
+--R                 + 
+--R                              3 5             5 3  3
+--R                   (4055040A a b  - 4915200C a b )c
+--R                 + 
+--R                               2 7             4 5  2             3 7
+--R                   (- 645120A a b  - 1105920C a b )c  + 1290240C a b c
+--R                 + 
+--R                              2 9
+--R                   - 188160C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                6 5                 5 2             7  4
+--R                   - 11796480A a c  + (- 20643840A a b  + 1966080C a )c
+--R                 + 
+--R                              4 4 3                3 6             5 4  2
+--R                   12533760A a b c  + (- 1658880A a b  - 8110080C a b )c
+--R                 + 
+--R                             4 6             3 8
+--R                   3932160C a b c - 483840C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                6   4               5 3             7   3
+--R                   - 29491200A a b c  + (14745600A a b  + 4915200C a b)c
+--R                 + 
+--R                                4 5              6 3  2             5 5
+--R                   (- 1843200A a b  - 11059200C a b )c  + 4608000C a b c
+--R                 + 
+--R                              4 7
+--R                   - 537600C a b
+--R              *
+--R                 x
+--R             + 
+--R                            7 4              6 2             8  3
+--R               - 11796480A a c  + (5898240A a b  + 1966080C a )c
+--R             + 
+--R                         5 4             7 2  2             6 4             5 6
+--R             (- 737280A a b  - 4423680C a b )c  + 1843200C a b c - 215040C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                        5 7              4 2           6  6
+--R               368640A a c  + (1198080A a b  - 61440C a )c
+--R             + 
+--R                           3 4           5 2  5
+--R               (- 322560A a b  - 92160C a b )c
+--R             + 
+--R                          2 6            4 4  4              8           3 6  3
+--R               (- 80640A a b  + 403200C a b )c  + (18720A a b  - 80640C a b )c
+--R             + 
+--R                      10           2 8  2            10          12
+--R               (360A b   - 26640C a b )c  + 5400C a b  c + 105C b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         5   6              4 3             6   5
+--R               6635520A a b c  + (2211840A a b  - 1105920C a b)c
+--R             + 
+--R                            3 5             5 3  4
+--R               (- 1935360A a b  + 1566720C a b )c
+--R             + 
+--R                         2 7            4 5  3              9            3 7  2
+--R               (138240A a b  + 967680C a b )c  + (25920A a b  - 587520C a b )c
+--R             + 
+--R                       2 9             11
+--R               36000C a b c + 7560C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                         6 6               5 2             7  5
+--R               6635520A a c  + (19906560A a b  - 1105920C a )c
+--R             + 
+--R                            4 4             6 2  4
+--R               (- 6359040A a b  - 1382400C a b )c
+--R             + 
+--R                           3 6             5 4  3
+--R               (- 967680A a b  + 6865920C a b )c
+--R             + 
+--R                         2 8             4 6  2            3 8            2 10
+--R               (302400A a b  - 1693440C a b )c  - 332640C a b c + 88200C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          6   5              5 3             7   4
+--R               35389440A a b c  + (2949120A a b  - 5898240C a b)c
+--R             + 
+--R                            4 5             6 3  3
+--R               (- 8110080A a b  + 9830400C a b )c
+--R             + 
+--R                        3 7             5 5  2             4 7             3 9
+--R             (1290240A a b  + 2211840C a b )c  - 2580480C a b c + 376320C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                          7 5               6 2             8  4
+--R               17694720A a c  + (30965760A a b  - 2949120C a )c
+--R             + 
+--R                            5 4 3              4 6              6 4  2
+--R               - 18800640A a b c  + (2488320A a b  + 12165120C a b )c
+--R             + 
+--R                           5 6             4 8
+--R               - 5898240C a b c + 725760C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                          7   4                 6 3             8   3
+--R               35389440A a b c  + (- 17694720A a b  - 5898240C a b)c
+--R             + 
+--R                        5 5              7 3  2             6 5             5 7
+--R             (2211840A a b  + 13271040C a b )c  - 5529600C a b c + 645120C a b
+--R          *
+--R             x
+--R         + 
+--R                      8 4                7 2             9  3
+--R           11796480A a c  + (- 5898240A a b  - 1966080C a )c
+--R         + 
+--R                     6 4             8 2  2             7 4             6 6
+--R           (737280A a b  + 4423680C a b )c  - 1843200C a b c + 215040C a b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                        4 2 5             3 4            5 2  4
+--R               921600A a b c  + (629760A a b  - 497664C a b )c
+--R             + 
+--R                          2 6            4 4  3
+--R               (- 57600A a b  - 122880C a b )c
+--R             + 
+--R                           8            3 6  2           2 8             10
+--R               (- 8640A a b  + 171776C a b )c  - 15360C a b c - 2520C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                         5   5              4 3            6   4
+--R               1843200A a b c  + (6174720A a b  - 995328C a b)c
+--R             + 
+--R                         3 5             5 3  3
+--R               (376320A a b  - 2899968C a b )c
+--R             + 
+--R                           2 7             4 5  2            3 7            2 9
+--R               (- 201600A a b  + 1236480C a b )c  + 143360C a b c - 58800C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          5 2 4              4 4             6 2  3
+--R               14745600A a b c  + (6389760A a b  - 7962624C a b )c
+--R             + 
+--R                          3 6           5 4  2             4 6             3 8
+--R             (- 1290240A a b  + 24576C a b )c  + 2078720C a b c - 376320C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                         6   4               5 3             7   3
+--R               9830400A a b c  + (20643840A a b  - 5308416C a b)c
+--R             + 
+--R                          4 5             6 3  2             5 5             4 7
+--R             (- 3317760A a b  - 8830976C a b )c  + 6574080C a b c - 967680C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                          6 2 3                5 4              7 2  2
+--R               24576000A a b c  + (- 3686400A a b  - 13271040C a b )c
+--R             + 
+--R                         6 4              5 6
+--R               7782400C a b c - 1075200C a b
+--R          *
+--R             x
+--R         + 
+--R                     7   3                6 3             8   2             7 3
+--R           9830400A a b c  + (- 1474560A a b  - 5308416C a b)c  + 3112960C a b c
+--R         + 
+--R                      6 5
+--R           - 430080C a b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R     + 
+--R                          4   6                3 3            5   5
+--R               - 307200A a b c  + (- 1105920A a b  + 165888C a b)c
+--R             + 
+--R                           2 5            4 3  4
+--R               (- 115200A a b  + 524800C a b )c
+--R             + 
+--R                          7            3 5  3          9           2 7  2
+--R               (38400A a b  - 195840C a b )c  + (720A b  - 38208C a b )c
+--R             + 
+--R                         9          11
+--R               11080C a b c + 210C b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           4 2 5                3 4             5 2  4
+--R               - 5529600A a b c  + (- 3778560A a b  + 2985984C a b )c
+--R             + 
+--R                         2 6            4 4  3              8             3 6  2
+--R               (345600A a b  + 737280C a b )c  + (51840A a b  - 1030656C a b )c
+--R             + 
+--R                       2 8              10
+--R               92160C a b c + 15120C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                           5   5                 4 3             6   4
+--R               - 5529600A a b c  + (- 18524160A a b  + 2985984C a b)c
+--R             + 
+--R                            3 5             5 3  3
+--R               (- 1128960A a b  + 8699904C a b )c
+--R             + 
+--R                         2 7             4 5  2            3 7             2 9
+--R               (604800A a b  - 3709440C a b )c  - 430080C a b c + 176400C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                            5 2 4                 4 4              6 2  3
+--R               - 29491200A a b c  + (- 12779520A a b  + 15925248C a b )c
+--R             + 
+--R                          3 6           5 4  2             4 6             3 8
+--R               (2580480A a b  - 49152C a b )c  - 4157440C a b c + 752640C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                            6   4                 5 3             7   3
+--R               - 14745600A a b c  + (- 30965760A a b  + 7962624C a b)c
+--R             + 
+--R                        4 5              6 3  2             5 5              4 7
+--R             (4976640A a b  + 13246464C a b )c  - 9861120C a b c + 1451520C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                            6 2 3              5 4              7 2  2
+--R               - 29491200A a b c  + (4423680A a b  + 15925248C a b )c
+--R             + 
+--R                           6 4              5 6
+--R               - 9338880C a b c + 1290240C a b
+--R          *
+--R             x
+--R         + 
+--R                       7   3              6 3             8   2             7 3
+--R           - 9830400A a b c  + (1474560A a b  + 5308416C a b)c  - 3112960C a b c
+--R         + 
+--R                    6 5
+--R           430080C a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                    2   6             3 5          5 4  5
+--R           (2949120a b c  + 2457600a b c  + 184320b c )x
+--R         + 
+--R                    3 6            2 2 5             4 4  4
+--R           (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R         + 
+--R                     3   5            2 3 4  3
+--R           (47185920a b c  + 27525120a b c )x
+--R         + 
+--R                     4 5            3 2 4  2            4   4             5 4
+--R           (31457280a c  + 70778880a b c )x  + 78643200a b c x + 31457280a c
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                     3 7           2 2 6            4 5         6 4  6
+--R           (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R         + 
+--R                       3   6            2 3 5             5 4  5
+--R           (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R         + 
+--R                       4 6            3 2 5            2 4 4  4
+--R           (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R         + 
+--R                       4   5            3 3 4  3
+--R           (- 94371840a b c  - 55050240a b c )x
+--R         + 
+--R                     5 5             4 2 4  2            5   4             6 4
+--R         (- 47185920a c  - 106168320a b c )x  - 94371840a b c x - 31457280a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                               4   6               3 3            5   5
+--R                   - 1105920A a b c  + (- 368640A a b  + 184320C a b)c
+--R                 + 
+--R                             2 5            4 3  4
+--R                   (322560A a b  - 261120C a b )c
+--R                 + 
+--R                                7            3 5  3
+--R                   (- 23040A a b  - 161280C a b )c
+--R                 + 
+--R                             9           2 7  2            9           11
+--R                   (- 4320A b  + 97920C a b )c  - 6000C a b c - 1260C b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                               5 6                4 2            6  5
+--R                   - 2211840A a c  + (- 6635520A a b  + 368640C a )c
+--R                 + 
+--R                              3 4            5 2  4
+--R                   (2119680A a b  + 460800C a b )c
+--R                 + 
+--R                             2 6             4 4  3
+--R                   (322560A a b  - 2288640C a b )c
+--R                 + 
+--R                                 8            3 6  2            2 8
+--R                   (- 100800A a b  + 564480C a b )c  + 110880C a b c
+--R                 + 
+--R                               10
+--R                   - 29400C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                5   5                4 3             6   4
+--R                   - 17694720A a b c  + (- 1474560A a b  + 2949120C a b)c
+--R                 + 
+--R                              3 5             5 3  3
+--R                   (4055040A a b  - 4915200C a b )c
+--R                 + 
+--R                               2 7             4 5  2             3 7
+--R                   (- 645120A a b  - 1105920C a b )c  + 1290240C a b c
+--R                 + 
+--R                              2 9
+--R                   - 188160C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                6 5                 5 2             7  4
+--R                   - 11796480A a c  + (- 20643840A a b  + 1966080C a )c
+--R                 + 
+--R                              4 4 3                3 6             5 4  2
+--R                   12533760A a b c  + (- 1658880A a b  - 8110080C a b )c
+--R                 + 
+--R                             4 6             3 8
+--R                   3932160C a b c - 483840C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                6   4               5 3             7   3
+--R                   - 29491200A a b c  + (14745600A a b  + 4915200C a b)c
+--R                 + 
+--R                                4 5              6 3  2             5 5
+--R                   (- 1843200A a b  - 11059200C a b )c  + 4608000C a b c
+--R                 + 
+--R                              4 7
+--R                   - 537600C a b
+--R              *
+--R                 x
+--R             + 
+--R                            7 4              6 2             8  3
+--R               - 11796480A a c  + (5898240A a b  + 1966080C a )c
+--R             + 
+--R                         5 4             7 2  2             6 4             5 6
+--R             (- 737280A a b  - 4423680C a b )c  + 1843200C a b c - 215040C a b
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + b x + a
+--R         + 
+--R                            5 7              4 2           6  6
+--R                   368640A a c  + (1198080A a b  - 61440C a )c
+--R                 + 
+--R                               3 4           5 2  5
+--R                   (- 322560A a b  - 92160C a b )c
+--R                 + 
+--R                              2 6            4 4  4
+--R                   (- 80640A a b  + 403200C a b )c
+--R                 + 
+--R                              8           3 6  3          10           2 8  2
+--R                   (18720A a b  - 80640C a b )c  + (360A b   - 26640C a b )c
+--R                 + 
+--R                            10          12
+--R                   5400C a b  c + 105C b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             5   6              4 3             6   5
+--R                   6635520A a b c  + (2211840A a b  - 1105920C a b)c
+--R                 + 
+--R                                3 5             5 3  4
+--R                   (- 1935360A a b  + 1566720C a b )c
+--R                 + 
+--R                             2 7            4 5  3
+--R                   (138240A a b  + 967680C a b )c
+--R                 + 
+--R                              9            3 7  2           2 9             11
+--R                   (25920A a b  - 587520C a b )c  + 36000C a b c + 7560C a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             6 6               5 2             7  5
+--R                   6635520A a c  + (19906560A a b  - 1105920C a )c
+--R                 + 
+--R                                4 4             6 2  4
+--R                   (- 6359040A a b  - 1382400C a b )c
+--R                 + 
+--R                               3 6             5 4  3
+--R                   (- 967680A a b  + 6865920C a b )c
+--R                 + 
+--R                           2 8             4 6  2            3 8            2 10
+--R                 (302400A a b  - 1693440C a b )c  - 332640C a b c + 88200C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              6   5              5 3             7   4
+--R                   35389440A a b c  + (2949120A a b  - 5898240C a b)c
+--R                 + 
+--R                                4 5             6 3  3
+--R                   (- 8110080A a b  + 9830400C a b )c
+--R                 + 
+--R                              3 7             5 5  2             4 7
+--R                   (1290240A a b  + 2211840C a b )c  - 2580480C a b c
+--R                 + 
+--R                            3 9
+--R                   376320C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                              7 5               6 2             8  4
+--R                   17694720A a c  + (30965760A a b  - 2949120C a )c
+--R                 + 
+--R                                5 4 3              4 6              6 4  2
+--R                   - 18800640A a b c  + (2488320A a b  + 12165120C a b )c
+--R                 + 
+--R                               5 6             4 8
+--R                   - 5898240C a b c + 725760C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                              7   4                 6 3             8   3
+--R                   35389440A a b c  + (- 17694720A a b  - 5898240C a b)c
+--R                 + 
+--R                              5 5              7 3  2             6 5
+--R                   (2211840A a b  + 13271040C a b )c  - 5529600C a b c
+--R                 + 
+--R                            5 7
+--R                   645120C a b
+--R              *
+--R                 x
+--R             + 
+--R                          8 4                7 2             9  3
+--R               11796480A a c  + (- 5898240A a b  - 1966080C a )c
+--R             + 
+--R                         6 4             8 2  2             7 4             6 6
+--R               (737280A a b  + 4423680C a b )c  - 1843200C a b c + 215040C a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                             4   6             3 3            5   5
+--R                   2211840A a b c  + (737280A a b  - 368640C a b)c
+--R                 + 
+--R                               2 5            4 3  4
+--R                   (- 645120A a b  + 522240C a b )c
+--R                 + 
+--R                              7            3 5  3           9            2 7  2
+--R                   (46080A a b  + 322560C a b )c  + (8640A b  - 195840C a b )c
+--R                 + 
+--R                             9           11
+--R                   12000C a b c + 2520C b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             5 6               4 2            6  5
+--R                   4423680A a c  + (13271040A a b  - 737280C a )c
+--R                 + 
+--R                                3 4            5 2  4
+--R                   (- 4239360A a b  - 921600C a b )c
+--R                 + 
+--R                               2 6             4 4  3
+--R                   (- 645120A a b  + 4577280C a b )c
+--R                 + 
+--R                             8             3 6  2            2 8              10
+--R                 (201600A a b  - 1128960C a b )c  - 221760C a b c + 58800C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              5   5              4 3             6   4
+--R                   35389440A a b c  + (2949120A a b  - 5898240C a b)c
+--R                 + 
+--R                                3 5             5 3  3
+--R                   (- 8110080A a b  + 9830400C a b )c
+--R                 + 
+--R                              2 7             4 5  2             3 7
+--R                   (1290240A a b  + 2211840C a b )c  - 2580480C a b c
+--R                 + 
+--R                            2 9
+--R                   376320C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                              6 5               5 2             7  4
+--R                   23592960A a c  + (41287680A a b  - 3932160C a )c
+--R                 + 
+--R                                4 4 3              3 6              5 4  2
+--R                   - 25067520A a b c  + (3317760A a b  + 16220160C a b )c
+--R                 + 
+--R                               4 6             3 8
+--R                   - 7864320C a b c + 967680C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                              6   4                 5 3             7   3
+--R                   58982400A a b c  + (- 29491200A a b  - 9830400C a b)c
+--R                 + 
+--R                              4 5              6 3  2             5 5
+--R                   (3686400A a b  + 22118400C a b )c  - 9216000C a b c
+--R                 + 
+--R                             4 7
+--R                   1075200C a b
+--R              *
+--R                 x
+--R             + 
+--R                          7 4                 6 2             8  3
+--R               23592960A a c  + (- 11796480A a b  - 3932160C a )c
+--R             + 
+--R                        5 4             7 2  2             6 4             5 6
+--R             (1474560A a b  + 8847360C a b )c  - 3686400C a b c + 430080C a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                              5 7                4 2            6  6
+--R                   - 737280A a c  + (- 2396160A a b  + 122880C a )c
+--R                 + 
+--R                             3 4            5 2  5
+--R                   (645120A a b  + 184320C a b )c
+--R                 + 
+--R                             2 6            4 4  4
+--R                   (161280A a b  - 806400C a b )c
+--R                 + 
+--R                                8            3 6  3
+--R                   (- 37440A a b  + 161280C a b )c
+--R                 + 
+--R                            10           2 8  2             10          12
+--R                   (- 720A b   + 53280C a b )c  - 10800C a b  c - 210C b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                                5   6                4 3             6   5
+--R                   - 13271040A a b c  + (- 4423680A a b  + 2211840C a b)c
+--R                 + 
+--R                              3 5             5 3  4
+--R                   (3870720A a b  - 3133440C a b )c
+--R                 + 
+--R                               2 7             4 5  3
+--R                   (- 276480A a b  - 1935360C a b )c
+--R                 + 
+--R                              9             3 7  2           2 9              11
+--R                 (- 51840A a b  + 1175040C a b )c  - 72000C a b c - 15120C a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                                6 6                 5 2             7  5
+--R                   - 13271040A a c  + (- 39813120A a b  + 2211840C a )c
+--R                 + 
+--R                               4 4             6 2  4
+--R                   (12718080A a b  + 2764800C a b )c
+--R                 + 
+--R                              3 6              5 4  3
+--R                   (1935360A a b  - 13731840C a b )c
+--R                 + 
+--R                               2 8             4 6  2            3 8
+--R                   (- 604800A a b  + 3386880C a b )c  + 665280C a b c
+--R                 + 
+--R                              2 10
+--R                   - 176400C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                6   5                5 3              7   4
+--R                   - 70778880A a b c  + (- 5898240A a b  + 11796480C a b)c
+--R                 + 
+--R                               4 5              6 3  3
+--R                   (16220160A a b  - 19660800C a b )c
+--R                 + 
+--R                                3 7             5 5  2             4 7
+--R                   (- 2580480A a b  - 4423680C a b )c  + 5160960C a b c
+--R                 + 
+--R                              3 9
+--R                   - 752640C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                7 5                 6 2             8  4
+--R                   - 35389440A a c  + (- 61931520A a b  + 5898240C a )c
+--R                 + 
+--R                              5 4 3                4 6              6 4  2
+--R                   37601280A a b c  + (- 4976640A a b  - 24330240C a b )c
+--R                 + 
+--R                              5 6              4 8
+--R                   11796480C a b c - 1451520C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                7   4               6 3              8   3
+--R                   - 70778880A a b c  + (35389440A a b  + 11796480C a b)c
+--R                 + 
+--R                                5 5              7 3  2              6 5
+--R                   (- 4423680A a b  - 26542080C a b )c  + 11059200C a b c
+--R                 + 
+--R                               5 7
+--R                   - 1290240C a b
+--R              *
+--R                 x
+--R             + 
+--R                            8 4               7 2             9  3
+--R               - 23592960A a c  + (11796480A a b  + 3932160C a )c
+--R             + 
+--R                          6 4             8 2  2             7 4             6 6
+--R             (- 1474560A a b  - 8847360C a b )c  + 3686400C a b c - 430080C a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- c \|c x  + b x + a  - \|- c \|a
+--R         atan(------------------------------------)
+--R                               c x
+--R     + 
+--R                        4 2 5             3 4            5 2  4
+--R               921600A a b c  + (629760A a b  - 497664C a b )c
+--R             + 
+--R                          2 6            4 4  3
+--R               (- 57600A a b  - 122880C a b )c
+--R             + 
+--R                           8            3 6  2           2 8             10
+--R               (- 8640A a b  + 171776C a b )c  - 15360C a b c - 2520C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                         5   5              4 3            6   4
+--R               1843200A a b c  + (6174720A a b  - 995328C a b)c
+--R             + 
+--R                         3 5             5 3  3
+--R               (376320A a b  - 2899968C a b )c
+--R             + 
+--R                           2 7             4 5  2            3 7            2 9
+--R               (- 201600A a b  + 1236480C a b )c  + 143360C a b c - 58800C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          5 2 4              4 4             6 2  3
+--R               14745600A a b c  + (6389760A a b  - 7962624C a b )c
+--R             + 
+--R                          3 6           5 4  2             4 6             3 8
+--R             (- 1290240A a b  + 24576C a b )c  + 2078720C a b c - 376320C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                         6   4               5 3             7   3
+--R               9830400A a b c  + (20643840A a b  - 5308416C a b)c
+--R             + 
+--R                          4 5             6 3  2             5 5             4 7
+--R             (- 3317760A a b  - 8830976C a b )c  + 6574080C a b c - 967680C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                          6 2 3                5 4              7 2  2
+--R               24576000A a b c  + (- 3686400A a b  - 13271040C a b )c
+--R             + 
+--R                         6 4              5 6
+--R               7782400C a b c - 1075200C a b
+--R          *
+--R             x
+--R         + 
+--R                     7   3                6 3             8   2             7 3
+--R           9830400A a b c  + (- 1474560A a b  - 5308416C a b)c  + 3112960C a b c
+--R         + 
+--R                      6 5
+--R           - 430080C a b
+--R      *
+--R                    +--------------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b x + a
+--R     + 
+--R                          4   6                3 3            5   5
+--R               - 307200A a b c  + (- 1105920A a b  + 165888C a b)c
+--R             + 
+--R                           2 5            4 3  4
+--R               (- 115200A a b  + 524800C a b )c
+--R             + 
+--R                          7            3 5  3          9           2 7  2
+--R               (38400A a b  - 195840C a b )c  + (720A b  - 38208C a b )c
+--R             + 
+--R                         9          11
+--R               11080C a b c + 210C b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           4 2 5                3 4             5 2  4
+--R               - 5529600A a b c  + (- 3778560A a b  + 2985984C a b )c
+--R             + 
+--R                         2 6            4 4  3              8             3 6  2
+--R               (345600A a b  + 737280C a b )c  + (51840A a b  - 1030656C a b )c
+--R             + 
+--R                       2 8              10
+--R               92160C a b c + 15120C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                           5   5                 4 3             6   4
+--R               - 5529600A a b c  + (- 18524160A a b  + 2985984C a b)c
+--R             + 
+--R                            3 5             5 3  3
+--R               (- 1128960A a b  + 8699904C a b )c
+--R             + 
+--R                         2 7             4 5  2            3 7             2 9
+--R               (604800A a b  - 3709440C a b )c  - 430080C a b c + 176400C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                            5 2 4                 4 4              6 2  3
+--R               - 29491200A a b c  + (- 12779520A a b  + 15925248C a b )c
+--R             + 
+--R                          3 6           5 4  2             4 6             3 8
+--R               (2580480A a b  - 49152C a b )c  - 4157440C a b c + 752640C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                            6   4                 5 3             7   3
+--R               - 14745600A a b c  + (- 30965760A a b  + 7962624C a b)c
+--R             + 
+--R                        4 5              6 3  2             5 5              4 7
+--R             (4976640A a b  + 13246464C a b )c  - 9861120C a b c + 1451520C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                            6 2 3              5 4              7 2  2
+--R               - 29491200A a b c  + (4423680A a b  + 15925248C a b )c
+--R             + 
+--R                           6 4              5 6
+--R               - 9338880C a b c + 1290240C a b
+--R          *
+--R             x
+--R         + 
+--R                       7   3              6 3             8   2             7 3
+--R           - 9830400A a b c  + (1474560A a b  + 5308416C a b)c  - 3112960C a b c
+--R         + 
+--R                    6 5
+--R           430080C a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                    2   6             3 5          5 4  5
+--R           (2949120a b c  + 2457600a b c  + 184320b c )x
+--R         + 
+--R                    3 6            2 2 5             4 4  4
+--R           (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R         + 
+--R                     3   5            2 3 4  3
+--R           (47185920a b c  + 27525120a b c )x
+--R         + 
+--R                     4 5            3 2 4  2            4   4             5 4
+--R           (31457280a c  + 70778880a b c )x  + 78643200a b c x + 31457280a c
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                     3 7           2 2 6            4 5         6 4  6
+--R           (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R         + 
+--R                       3   6            2 3 5             5 4  5
+--R           (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R         + 
+--R                       4 6            3 2 5            2 4 4  4
+--R           (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R         + 
+--R                       4   5            3 3 4  3
+--R           (- 94371840a b c  - 55050240a b c )x
+--R         + 
+--R                     5 5             4 2 4  2            5   4             6 4
+--R         (- 47185920a c  - 106168320a b c )x  - 94371840a b c x - 31457280a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 148
+
+)clear all
+
+--S 149 of 556
+t0:=(a+b*x+c*x^2)^(1/2)*(A+C*x^2)
+--R 
+--R
+--R                   +--------------+
+--R            2      |   2
+--R   (1)  (C x  + A)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 556
+r0:=-1/24*C*(5*b-6*c*x)*(a+b*x+c*x^2)^(3/2)/c^2-1/128*(b^2-4*a*c)*_
+   (16*A*c^2+5*b^2*C-4*a*c*C)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/c^(7/2)+1/64*(16*A*c^2+5*b^2*C-4*a*c*C)*(b+2*c*x)*_
+   sqrt(a+b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                  3           2        2  2          2         4
+--R         (192A a c  + (- 48A b  - 48C a )c  + 72C a b c - 15C b )
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                3 3          2 2          3          2        2             2
+--R           96C c x  + 16C b c x  + (192A c  + 48C a c  - 20C b c)x + 96A b c
+--R         + 
+--R                               3
+--R           - 104C a b c + 30C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R         3 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 150
+
+--S 151 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            2   4          3   3            5          2 3  2
+--R                     6144A a b c  - 1536C a b c  + (- 384A b  + 1920C a b )c
+--R                   + 
+--R                            5          7
+--R                     96C a b c - 120C b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                             3 4            2 2          4  3
+--R                     12288A a c  + (12288A a b  - 3072C a )c
+--R                   + 
+--R                                 4         3 2  2          2 4             6
+--R                     (- 3840A a b  + 768C a b )c  + 4800C a b c - 1200C a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                             3   3             2 3          4   2           3 3
+--R                     36864A a b c  + (- 9216A a b  - 9216C a b)c  + 13824C a b c
+--R                   + 
+--R                              2 5
+--R                     - 2880C a b
+--R                *
+--R                   x
+--R               + 
+--R                         4 3             3 2          5  2          4 2
+--R                 24576A a c  + (- 6144A a b  - 6144C a )c  + 9216C a b c
+--R               + 
+--R                          3 4
+--R                 - 1920C a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                          3 5             2 2         4  4           4 3
+--R                 - 3072A a c  + (- 3840A a b  + 768C a )c  + 960A a b c
+--R               + 
+--R                       6          2 4  2           6         8
+--R                 (48A b  - 1440C a b )c  + 288C a b c + 15C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           3   4          4   3             5          3 3  2
+--R                 - 24576A a b c  + 6144C a b c  + (1536A a b  - 7680C a b )c
+--R               + 
+--R                         2 5            7
+--R                 - 384C a b c + 480C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                           4 4              3 2          5  3
+--R                 - 24576A a c  + (- 24576A a b  + 6144C a )c
+--R               + 
+--R                         2 4          4 2  2          3 4           2 6
+--R                 (7680A a b  - 1536C a b )c  - 9600C a b c + 2400C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           4   3            3 3           5   2           4 3
+--R                 - 49152A a b c  + (12288A a b  + 12288C a b)c  - 18432C a b c
+--R               + 
+--R                        3 5
+--R                 3840C a b
+--R            *
+--R               x
+--R           + 
+--R                     5 3           4 2          6  2          5 2           4 4
+--R           - 24576A a c  + (6144A a b  + 6144C a )c  - 9216C a b c + 1920C a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                       2 5            2 4        4 3  7
+--R             (- 1536C a c  - 2304C a b c  - 96C b c )x
+--R           + 
+--R                        2   4            3 3        5 2  6
+--R             (- 12544C a b c  - 3456C a b c  - 16C b c )x
+--R           + 
+--R                          2 5               2           3  4
+--R                 - 3072A a c  + (- 4608A a b  - 13056C a )c
+--R               + 
+--R                          4           2 2  3          4 2        6
+--R                 (- 192A b  - 18240C a b )c  - 80C a b c  + 20C b c
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                           2   4               3           3   3
+--R                 - 26112A a b c  + (- 8448A a b  - 31104C a b)c
+--R               + 
+--R                         5         2 3  2          5         7
+--R                 (- 96A b  + 480C a b )c  + 24C a b c - 30C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           3 4              2 2           4  3
+--R                 - 24576A a c  + (- 39936A a b  - 18432C a )c
+--R               + 
+--R                             4         3 2  2          2 4            6
+--R                 (- 2304A a b  + 768C a b )c  + 2816C a b c - 720C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                           3   3             2 3          4   2           3 3
+--R                 - 55296A a b c  + (- 7680A a b  - 7680C a b)c  + 11520C a b c
+--R               + 
+--R                          2 5
+--R                 - 2400C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           4 3             3 2          5  2          4 2
+--R                 - 24576A a c  + (- 6144A a b  - 6144C a )c  + 9216C a b c
+--R               + 
+--R                          3 4
+--R                 - 1920C a b
+--R            *
+--R               x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                         5         3 4  8
+--R             (3072C a b c  + 768C b c )x
+--R           + 
+--R                     2 5             2 4         4 3  7
+--R             (6144C a c  + 11264C a b c  + 896C b c )x
+--R           + 
+--R                            5           3           2   4            3 3
+--R                 6144A a b c  + (1536A b  + 30208C a b)c  + 9984C a b c
+--R               + 
+--R                        5 2
+--R                 - 32C b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                         2 5              2           3  4
+--R                 12288A a c  + (24576A a b  + 21504C a )c
+--R               + 
+--R                         4           2 2  3           4 2        6
+--R                 (2304A b  + 31488C a b )c  - 320C a b c  + 80C b c
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                         2   4              3           3   3
+--R                 59904A a b c  + (25344A a b  + 42624C a b)c
+--R               + 
+--R                        5          2 3  2           5          7
+--R                 (672A b  - 4896C a b )c  + 152C a b c + 210C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         3 4            2 2           4  3
+--R                 36864A a c  + (67584A a b  + 21504C a )c
+--R               + 
+--R                           4          3 2  2          2 4             6
+--R                 (5376A a b  - 2304C a b )c  - 6464C a b c + 1680C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         3   3            2 3           4   2           3 3
+--R                 67584A a b c  + (10752A a b  + 10752C a b)c  - 16128C a b c
+--R               + 
+--R                        2 5
+--R                 3360C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    4 3           3 2          5  2          4 2           3 4
+--R           (24576A a c  + (6144A a b  + 6144C a )c  - 9216C a b c + 1920C a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                        4        3 3  3          2 4           2 3  2
+--R             (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R           + 
+--R                   2   3          3 3
+--R             73728a b c x + 49152a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                     2 5          2 4       4 3  4
+--R             (- 6144a c  - 9216a b c  - 384b c )x
+--R           + 
+--R                      2   4           3 3  3            3 4         2 2 3  2
+--R             (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R           + 
+--R                     3   3          4 3
+--R             - 98304a b c x - 49152a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                            2   4          3   3            5          2 3  2
+--R                     6144A a b c  - 1536C a b c  + (- 384A b  + 1920C a b )c
+--R                   + 
+--R                            5          7
+--R                     96C a b c - 120C b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                             3 4            2 2          4  3
+--R                     12288A a c  + (12288A a b  - 3072C a )c
+--R                   + 
+--R                                 4         3 2  2          2 4             6
+--R                     (- 3840A a b  + 768C a b )c  + 4800C a b c - 1200C a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                             3   3             2 3          4   2           3 3
+--R                     36864A a b c  + (- 9216A a b  - 9216C a b)c  + 13824C a b c
+--R                   + 
+--R                              2 5
+--R                     - 2880C a b
+--R                *
+--R                   x
+--R               + 
+--R                         4 3             3 2          5  2          4 2
+--R                 24576A a c  + (- 6144A a b  - 6144C a )c  + 9216C a b c
+--R               + 
+--R                          3 4
+--R                 - 1920C a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                          3 5             2 2         4  4           4 3
+--R                 - 3072A a c  + (- 3840A a b  + 768C a )c  + 960A a b c
+--R               + 
+--R                       6          2 4  2           6         8
+--R                 (48A b  - 1440C a b )c  + 288C a b c + 15C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           3   4          4   3             5          3 3  2
+--R                 - 24576A a b c  + 6144C a b c  + (1536A a b  - 7680C a b )c
+--R               + 
+--R                         2 5            7
+--R                 - 384C a b c + 480C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                           4 4              3 2          5  3
+--R                 - 24576A a c  + (- 24576A a b  + 6144C a )c
+--R               + 
+--R                         2 4          4 2  2          3 4           2 6
+--R                 (7680A a b  - 1536C a b )c  - 9600C a b c + 2400C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           4   3            3 3           5   2           4 3
+--R                 - 49152A a b c  + (12288A a b  + 12288C a b)c  - 18432C a b c
+--R               + 
+--R                        3 5
+--R                 3840C a b
+--R            *
+--R               x
+--R           + 
+--R                     5 3           4 2          6  2          5 2           4 4
+--R           - 24576A a c  + (6144A a b  + 6144C a )c  - 9216C a b c + 1920C a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                      2 5            2 4        4 3  7
+--R             (- 768C a c  - 1152C a b c  - 48C b c )x
+--R           + 
+--R                       2   4            3 3       5 2  6
+--R             (- 6272C a b c  - 1728C a b c  - 8C b c )x
+--R           + 
+--R                          2 5               2          3  4
+--R                 - 1536A a c  + (- 2304A a b  - 6528C a )c
+--R               + 
+--R                         4          2 2  3          4 2        6
+--R                 (- 96A b  - 9120C a b )c  - 40C a b c  + 10C b c
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                           2   4               3           3   3
+--R                 - 13056A a b c  + (- 4224A a b  - 15552C a b)c
+--R               + 
+--R                         5         2 3  2          5         7
+--R                 (- 48A b  + 240C a b )c  + 12C a b c - 15C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           3 4              2 2          4  3
+--R                 - 12288A a c  + (- 19968A a b  - 9216C a )c
+--R               + 
+--R                             4         3 2  2          2 4            6
+--R                 (- 1152A a b  + 384C a b )c  + 1408C a b c - 360C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                           3   3             2 3          4   2          3 3
+--R                 - 27648A a b c  + (- 3840A a b  - 3840C a b)c  + 5760C a b c
+--R               + 
+--R                          2 5
+--R                 - 1200C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           4 3             3 2          5  2          4 2
+--R                 - 12288A a c  + (- 3072A a b  - 3072C a )c  + 4608C a b c
+--R               + 
+--R                         3 4
+--R                 - 960C a b
+--R            *
+--R               x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                         5         3 4  8
+--R             (1536C a b c  + 384C b c )x
+--R           + 
+--R                     2 5            2 4         4 3  7
+--R             (3072C a c  + 5632C a b c  + 448C b c )x
+--R           + 
+--R                              5          3           2   4            3 3
+--R                   3072A a b c  + (768A b  + 15104C a b)c  + 4992C a b c
+--R                 + 
+--R                          5 2
+--R                   - 16C b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                        2 5              2           3  4
+--R                 6144A a c  + (12288A a b  + 10752C a )c
+--R               + 
+--R                         4           2 2  3           4 2        6
+--R                 (1152A b  + 15744C a b )c  - 160C a b c  + 40C b c
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                         2   4              3           3   3
+--R                 29952A a b c  + (12672A a b  + 21312C a b)c
+--R               + 
+--R                        5          2 3  2          5          7
+--R                 (336A b  - 2448C a b )c  + 76C a b c + 105C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         3 4            2 2           4  3
+--R                 18432A a c  + (33792A a b  + 10752C a )c
+--R               + 
+--R                           4          3 2  2          2 4            6
+--R                 (2688A a b  - 1152C a b )c  - 3232C a b c + 840C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         3   3           2 3          4   2          3 3
+--R                 33792A a b c  + (5376A a b  + 5376C a b)c  - 8064C a b c
+--R               + 
+--R                        2 5
+--R                 1680C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    4 3           3 2          5  2          4 2          3 4
+--R           (12288A a c  + (3072A a b  + 3072C a )c  - 4608C a b c + 960C a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                       4        3 3  3          2 4           2 3  2
+--R             (6144a b c  + 1536b c )x  + (12288a c  + 15360a b c )x
+--R           + 
+--R                   2   3          3 3
+--R             36864a b c x + 24576a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                     2 5          2 4       4 3  4
+--R             (- 3072a c  - 4608a b c  - 192b c )x
+--R           + 
+--R                      2   4          3 3  3            3 4         2 2 3  2
+--R             (- 24576a b c  - 6144a b c )x  + (- 24576a c  - 30720a b c )x
+--R           + 
+--R                     3   3          4 3
+--R             - 49152a b c x - 24576a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 151
+
+--S 152 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          2   4          3   3            5          2 3  2
+--R                   6144A a b c  - 1536C a b c  + (- 384A b  + 1920C a b )c
+--R                 + 
+--R                          5          7
+--R                   96C a b c - 120C b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                           3 4            2 2          4  3
+--R                   12288A a c  + (12288A a b  - 3072C a )c
+--R                 + 
+--R                               4         3 2  2          2 4             6
+--R                   (- 3840A a b  + 768C a b )c  + 4800C a b c - 1200C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           3   3             2 3          4   2           3 3
+--R                   36864A a b c  + (- 9216A a b  - 9216C a b)c  + 13824C a b c
+--R                 + 
+--R                            2 5
+--R                   - 2880C a b
+--R              *
+--R                 x
+--R             + 
+--R                       4 3             3 2          5  2          4 2
+--R               24576A a c  + (- 6144A a b  - 6144C a )c  + 9216C a b c
+--R             + 
+--R                        3 4
+--R               - 1920C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                        3 5             2 2         4  4           4 3
+--R               - 3072A a c  + (- 3840A a b  + 768C a )c  + 960A a b c
+--R             + 
+--R                     6          2 4  2           6         8
+--R               (48A b  - 1440C a b )c  + 288C a b c + 15C b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                         3   4          4   3             5          3 3  2
+--R               - 24576A a b c  + 6144C a b c  + (1536A a b  - 7680C a b )c
+--R             + 
+--R                       2 5            7
+--R               - 384C a b c + 480C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                         4 4              3 2          5  3
+--R               - 24576A a c  + (- 24576A a b  + 6144C a )c
+--R             + 
+--R                       2 4          4 2  2          3 4           2 6
+--R               (7680A a b  - 1536C a b )c  - 9600C a b c + 2400C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                         4   3            3 3           5   2           4 3
+--R               - 49152A a b c  + (12288A a b  + 12288C a b)c  - 18432C a b c
+--R             + 
+--R                      3 5
+--R               3840C a b
+--R          *
+--R             x
+--R         + 
+--R                     5 3           4 2          6  2          5 2           4 4
+--R           - 24576A a c  + (6144A a b  + 6144C a )c  - 9216C a b c + 1920C a b
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                            2   4          3   3          5          2 3  2
+--R                   - 6144A a b c  + 1536C a b c  + (384A b  - 1920C a b )c
+--R                 + 
+--R                            5          7
+--R                   - 96C a b c + 120C b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                             3 4              2 2          4  3
+--R                   - 12288A a c  + (- 12288A a b  + 3072C a )c
+--R                 + 
+--R                             4         3 2  2          2 4             6
+--R                   (3840A a b  - 768C a b )c  - 4800C a b c + 1200C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                             3   3           2 3          4   2           3 3
+--R                   - 36864A a b c  + (9216A a b  + 9216C a b)c  - 13824C a b c
+--R                 + 
+--R                          2 5
+--R                   2880C a b
+--R              *
+--R                 x
+--R             + 
+--R                         4 3           3 2          5  2          4 2
+--R               - 24576A a c  + (6144A a b  + 6144C a )c  - 9216C a b c
+--R             + 
+--R                      3 4
+--R               1920C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                      3 5           2 2         4  4           4 3
+--R               3072A a c  + (3840A a b  - 768C a )c  - 960A a b c
+--R             + 
+--R                       6          2 4  2           6         8
+--R               (- 48A b  + 1440C a b )c  - 288C a b c - 15C b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       3   4          4   3               5          3 3  2
+--R               24576A a b c  - 6144C a b c  + (- 1536A a b  + 7680C a b )c
+--R             + 
+--R                     2 5            7
+--R               384C a b c - 480C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       4 4            3 2          5  3
+--R               24576A a c  + (24576A a b  - 6144C a )c
+--R             + 
+--R                         2 4          4 2  2          3 4           2 6
+--R               (- 7680A a b  + 1536C a b )c  + 9600C a b c - 2400C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       4   3              3 3           5   2           4 3
+--R               49152A a b c  + (- 12288A a b  - 12288C a b)c  + 18432C a b c
+--R             + 
+--R                        3 5
+--R               - 3840C a b
+--R          *
+--R             x
+--R         + 
+--R                   5 3             4 2          6  2          5 2           4 4
+--R           24576A a c  + (- 6144A a b  - 6144C a )c  + 9216C a b c - 1920C a b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                        2 2 3            4          3 2  2         2 4
+--R                 3072A a b c  + (768A a b  - 3328C a b )c  + 128C a b c
+--R               + 
+--R                         6
+--R                 240C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      3   3           2 3          4   2          3 3
+--R               6144A a b c  + (7680A a b  - 6656C a b)c  - 6400C a b c
+--R             + 
+--R                      2 5
+--R               2400C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 2 2           4 2           3 4             4   2
+--R           (18432A a b c  - 19968C a b c + 5760C a b )x + 12288A a b c
+--R         + 
+--R                     5             4 3
+--R           - 13312C a b c + 3840C a b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R     + 
+--R                        2   4               3          3   3
+--R               - 1536A a b c  + (- 2304A a b  + 1664C a b)c
+--R             + 
+--R                       5          2 3  2           5         7
+--R               (- 96A b  + 2016C a b )c  - 616C a b c - 30C b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                         2 2 3               4           3 2  2         2 4
+--R               - 12288A a b c  + (- 3072A a b  + 13312C a b )c  - 512C a b c
+--R             + 
+--R                         6
+--R               - 960C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                         3   3              2 3           4   2           3 3
+--R               - 12288A a b c  + (- 15360A a b  + 13312C a b)c  + 12800C a b c
+--R             + 
+--R                        2 5
+--R               - 4800C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3 2 2           4 2           3 4             4   2
+--R           (- 24576A a b c  + 26624C a b c - 7680C a b )x - 12288A a b c
+--R         + 
+--R                   5             4 3
+--R           13312C a b c - 3840C a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                      4        3 3  3          2 4           2 3  2
+--R           (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R         + 
+--R                 2   3          3 3
+--R           73728a b c x + 49152a c
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                   2 5          2 4       4 3  4
+--R           (- 6144a c  - 9216a b c  - 384b c )x
+--R         + 
+--R                    2   4           3 3  3            3 4         2 2 3  2
+--R           (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R         + 
+--R                   3   3          4 3
+--R           - 98304a b c x - 49152a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+--S 154 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                            2   4          3   3          5          2 3  2
+--R                   - 6144A a b c  + 1536C a b c  + (384A b  - 1920C a b )c
+--R                 + 
+--R                            5          7
+--R                   - 96C a b c + 120C b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                             3 4              2 2          4  3
+--R                   - 12288A a c  + (- 12288A a b  + 3072C a )c
+--R                 + 
+--R                             4         3 2  2          2 4             6
+--R                   (3840A a b  - 768C a b )c  - 4800C a b c + 1200C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                             3   3           2 3          4   2           3 3
+--R                   - 36864A a b c  + (9216A a b  + 9216C a b)c  - 13824C a b c
+--R                 + 
+--R                          2 5
+--R                   2880C a b
+--R              *
+--R                 x
+--R             + 
+--R                         4 3           3 2          5  2          4 2
+--R               - 24576A a c  + (6144A a b  + 6144C a )c  - 9216C a b c
+--R             + 
+--R                      3 4
+--R               1920C a b
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + b x + a
+--R         + 
+--R                          3 5           2 2         4  4           4 3
+--R                   3072A a c  + (3840A a b  - 768C a )c  - 960A a b c
+--R                 + 
+--R                           6          2 4  2           6         8
+--R                   (- 48A b  + 1440C a b )c  - 288C a b c - 15C b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           3   4          4   3               5          3 3  2
+--R                   24576A a b c  - 6144C a b c  + (- 1536A a b  + 7680C a b )c
+--R                 + 
+--R                         2 5            7
+--R                   384C a b c - 480C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                           4 4            3 2          5  3
+--R                   24576A a c  + (24576A a b  - 6144C a )c
+--R                 + 
+--R                             2 4          4 2  2          3 4           2 6
+--R                   (- 7680A a b  + 1536C a b )c  + 9600C a b c - 2400C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           4   3              3 3           5   2           4 3
+--R                   49152A a b c  + (- 12288A a b  - 12288C a b)c  + 18432C a b c
+--R                 + 
+--R                            3 5
+--R                   - 3840C a b
+--R              *
+--R                 x
+--R             + 
+--R                       5 3             4 2          6  2          5 2
+--R               24576A a c  + (- 6144A a b  - 6144C a )c  + 9216C a b c
+--R             + 
+--R                        4 4
+--R               - 1920C a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                           2   4          3   3            5          2 3  2
+--R                   12288A a b c  - 3072C a b c  + (- 768A b  + 3840C a b )c
+--R                 + 
+--R                           5          7
+--R                   192C a b c - 240C b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                           3 4            2 2          4  3
+--R                   24576A a c  + (24576A a b  - 6144C a )c
+--R                 + 
+--R                               4          3 2  2          2 4             6
+--R                   (- 7680A a b  + 1536C a b )c  + 9600C a b c - 2400C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           3   3              2 3           4   2           3 3
+--R                   73728A a b c  + (- 18432A a b  - 18432C a b)c  + 27648C a b c
+--R                 + 
+--R                            2 5
+--R                   - 5760C a b
+--R              *
+--R                 x
+--R             + 
+--R                       4 3              3 2           5  2           4 2
+--R               49152A a c  + (- 12288A a b  - 12288C a )c  + 18432C a b c
+--R             + 
+--R                        3 4
+--R               - 3840C a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                            3 5             2 2          4  4            4 3
+--R                   - 6144A a c  + (- 7680A a b  + 1536C a )c  + 1920A a b c
+--R                 + 
+--R                         6          2 4  2           6         8
+--R                   (96A b  - 2880C a b )c  + 576C a b c + 30C b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             3   4           4   3
+--R                   - 49152A a b c  + 12288C a b c
+--R                 + 
+--R                             5           3 3  2         2 5            7
+--R                   (3072A a b  - 15360C a b )c  - 768C a b c + 960C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                             4 4              3 2           5  3
+--R                   - 49152A a c  + (- 49152A a b  + 12288C a )c
+--R                 + 
+--R                            2 4          4 2  2           3 4           2 6
+--R                   (15360A a b  - 3072C a b )c  - 19200C a b c + 4800C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                             4   3            3 3           5   2           4 3
+--R                   - 98304A a b c  + (24576A a b  + 24576C a b)c  - 36864C a b c
+--R                 + 
+--R                          3 5
+--R                   7680C a b
+--R              *
+--R                 x
+--R             + 
+--R                         5 3            4 2           6  2           5 2
+--R               - 49152A a c  + (12288A a b  + 12288C a )c  - 18432C a b c
+--R             + 
+--R                      4 4
+--R               3840C a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- c \|c x  + b x + a  - \|- c \|a
+--R         atan(------------------------------------)
+--R                               c x
+--R     + 
+--R                        2 2 3            4          3 2  2         2 4
+--R                 3072A a b c  + (768A a b  - 3328C a b )c  + 128C a b c
+--R               + 
+--R                         6
+--R                 240C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      3   3           2 3          4   2          3 3
+--R               6144A a b c  + (7680A a b  - 6656C a b)c  - 6400C a b c
+--R             + 
+--R                      2 5
+--R               2400C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 2 2           4 2           3 4             4   2
+--R           (18432A a b c  - 19968C a b c + 5760C a b )x + 12288A a b c
+--R         + 
+--R                     5             4 3
+--R           - 13312C a b c + 3840C a b
+--R      *
+--R                    +--------------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b x + a
+--R     + 
+--R                        2   4               3          3   3
+--R               - 1536A a b c  + (- 2304A a b  + 1664C a b)c
+--R             + 
+--R                       5          2 3  2           5         7
+--R               (- 96A b  + 2016C a b )c  - 616C a b c - 30C b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                         2 2 3               4           3 2  2         2 4
+--R               - 12288A a b c  + (- 3072A a b  + 13312C a b )c  - 512C a b c
+--R             + 
+--R                         6
+--R               - 960C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                         3   3              2 3           4   2           3 3
+--R               - 12288A a b c  + (- 15360A a b  + 13312C a b)c  + 12800C a b c
+--R             + 
+--R                        2 5
+--R               - 4800C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3 2 2           4 2           3 4             4   2
+--R           (- 24576A a b c  + 26624C a b c - 7680C a b )x - 12288A a b c
+--R         + 
+--R                   5             4 3
+--R           13312C a b c - 3840C a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                      4        3 3  3          2 4           2 3  2
+--R           (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R         + 
+--R                 2   3          3 3
+--R           73728a b c x + 49152a c
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                   2 5          2 4       4 3  4
+--R           (- 6144a c  - 9216a b c  - 384b c )x
+--R         + 
+--R                    2   4           3 3  3            3 4         2 2 3  2
+--R           (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R         + 
+--R                   3   3          4 3
+--R           - 98304a b c x - 49152a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 155
+
+)clear all
+
+--S 156 of 556
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^(1/2)
+--R 
+--R
+--R                2
+--R             C x  + A
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 556
+r0:=1/8*(8*A*c^2+3*b^2*C-4*a*c*C)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/c^(5/2)-1/4*C*(3*b-2*c*x)*sqrt(a+b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R            2                2              2c x + b
+--R       (8A c  - 4C a c + 3C b )atanh(----------------------)
+--R                                           +--------------+
+--R                                       +-+ |   2
+--R                                     2\|c \|c x  + b x + a
+--R     + 
+--R                           +--------------+
+--R                       +-+ |   2
+--R       (4C c x - 6C b)\|c \|c x  + b x + a
+--R  /
+--R       2 +-+
+--R     8c \|c
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                           2        2             3          2 2        3
+--R                 (32A a b c  - 16C a b c + 12C a b )x + 64A a c  - 32C a c
+--R               + 
+--R                      2 2
+--R                 24C a b
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                           3          2        2  2         2        4  2
+--R                 (- 32A a c  + (- 8A b  + 16C a )c  - 8C a b c - 3C b )x
+--R               + 
+--R                             2        2             3          2 2        3
+--R                 (- 64A a b c  + 32C a b c - 24C a b )x - 64A a c  + 32C a c
+--R               + 
+--R                        2 2
+--R                 - 24C a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                       2       2   3                     3  2
+--R             (- 16C a c  - 4C b c)x  + (- 8C a b c + 6C b )x
+--R           + 
+--R                     2           2
+--R             (- 32C a c + 24C a b )x
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                      2 4         2 2         2   3         2             3  2
+--R             16C a b c x  + (32C a c  - 8C a b c)x  + (24C a b c - 18C a b )x
+--R           + 
+--R                   3         2 2
+--R             (32C a c - 24C a b )x
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                                  +--------------+
+--R                 2       2 2  +-+ |   2
+--R         (32a b c x + 64a c )\|c \|c x  + b x + a
+--R       + 
+--R                  3     2 2  2          2       2 2  +-+ +-+
+--R         ((- 32a c  - 8b c )x  - 64a b c x - 64a c )\|a \|c
+--R     ,
+--R
+--R                           2        2             3          2 2        3
+--R                 (32A a b c  - 16C a b c + 12C a b )x + 64A a c  - 32C a c
+--R               + 
+--R                      2 2
+--R                 24C a b
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                           3          2        2  2         2        4  2
+--R                 (- 32A a c  + (- 8A b  + 16C a )c  - 8C a b c - 3C b )x
+--R               + 
+--R                             2        2             3          2 2        3
+--R                 (- 64A a b c  + 32C a b c - 24C a b )x - 64A a c  + 32C a c
+--R               + 
+--R                        2 2
+--R                 - 24C a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                      2       2   3                     3  2
+--R             (- 8C a c  - 2C b c)x  + (- 4C a b c + 3C b )x
+--R           + 
+--R                     2           2
+--R             (- 16C a c + 12C a b )x
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                     2 4         2 2         2   3         2            3  2
+--R             8C a b c x  + (16C a c  - 4C a b c)x  + (12C a b c - 9C a b )x
+--R           + 
+--R                   3         2 2
+--R             (16C a c - 12C a b )x
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                                    +--------------+
+--R                 2       2 2  +---+ |   2
+--R         (16a b c x + 32a c )\|- c \|c x  + b x + a
+--R       + 
+--R                  3     2 2  2          2       2 2  +---+ +-+
+--R         ((- 16a c  - 4b c )x  - 32a b c x - 32a c )\|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 158
+
+--S 159 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         2        2             3          2 2        3
+--R               (32A a b c  - 16C a b c + 12C a b )x + 64A a c  - 32C a c
+--R             + 
+--R                    2 2
+--R               24C a b
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                         3          2        2  2         2        4  2
+--R               (- 32A a c  + (- 8A b  + 16C a )c  - 8C a b c - 3C b )x
+--R             + 
+--R                           2        2             3          2 2        3
+--R               (- 64A a b c  + 32C a b c - 24C a b )x - 64A a c  + 32C a c
+--R             + 
+--R                      2 2
+--R               - 24C a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                           2        2             3          2 2        3
+--R               (- 32A a b c  + 16C a b c - 12C a b )x - 64A a c  + 32C a c
+--R             + 
+--R                      2 2
+--R               - 24C a b
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       3        2        2  2         2        4  2
+--R               (32A a c  + (8A b  - 16C a )c  + 8C a b c + 3C b )x
+--R             + 
+--R                         2        2             3          2 2        3
+--R               (64A a b c  - 32C a b c + 24C a b )x + 64A a c  - 32C a c
+--R             + 
+--R                    2 2
+--R               24C a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                                       +--------------+
+--R                 2         2   +-+ +-+ |   2
+--R       (- 24C a b x - 48C a b)\|a \|c \|c x  + b x + a
+--R     + 
+--R              2            3  2        2 2         3   +-+
+--R       ((24C a b c + 6C a b )x  + 48C a b x + 48C a b)\|c
+--R  /
+--R                                +--------------+
+--R               2       2 2  +-+ |   2
+--R       (32a b c x + 64a c )\|c \|c x  + b x + a
+--R     + 
+--R                3     2 2  2          2       2 2  +-+ +-+
+--R       ((- 32a c  - 8b c )x  - 64a b c x - 64a c )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                           2        2             3          2 2        3
+--R               (- 32A a b c  + 16C a b c - 12C a b )x - 64A a c  + 32C a c
+--R             + 
+--R                      2 2
+--R               - 24C a b
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b x + a
+--R         + 
+--R                       3        2        2  2         2        4  2
+--R               (32A a c  + (8A b  - 16C a )c  + 8C a b c + 3C b )x
+--R             + 
+--R                         2        2             3          2 2        3
+--R               (64A a b c  - 32C a b c + 24C a b )x + 64A a c  - 32C a c
+--R             + 
+--R                    2 2
+--R               24C a b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                         2        2             3           2 2        3
+--R               (64A a b c  - 32C a b c + 24C a b )x + 128A a c  - 64C a c
+--R             + 
+--R                    2 2
+--R               48C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                         3           2        2  2          2        4  2
+--R               (- 64A a c  + (- 16A b  + 32C a )c  - 16C a b c - 6C b )x
+--R             + 
+--R                            2        2             3           2 2        3
+--R               (- 128A a b c  + 64C a b c - 48C a b )x - 128A a c  + 64C a c
+--R             + 
+--R                      2 2
+--R               - 48C a b
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- c \|c x  + b x + a  - \|- c \|a
+--R         atan(------------------------------------)
+--R                               c x
+--R     + 
+--R                                             +--------------+
+--R                 2         2   +---+ +-+ +-+ |   2
+--R       (- 24C a b x - 48C a b)\|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R              2            3  2        2 2         3   +---+ +-+
+--R       ((24C a b c + 6C a b )x  + 48C a b x + 48C a b)\|- c \|c
+--R  /
+--R                                      +--------------+
+--R               2       2 2  +---+ +-+ |   2
+--R       (32a b c x + 64a c )\|- c \|c \|c x  + b x + a
+--R     + 
+--R                3     2 2  2          2       2 2  +---+ +-+ +-+
+--R       ((- 32a c  - 8b c )x  - 64a b c x - 64a c )\|- c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 556
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^(3/2)
+--R 
+--R
+--R                        2
+--R                     C x  + A
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 556
+r0:=C*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/c^(3/2)-_
+   2*(b*(A*c+a*C)+(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                       +--------------+
+--R                    2  |   2                        2c x + b
+--R       (4C a c - C b )\|c x  + b x + a atanh(----------------------)
+--R                                                   +--------------+
+--R                                               +-+ |   2
+--R                                             2\|c \|c x  + b x + a
+--R     + 
+--R             2                2                      +-+
+--R       ((4A c  - 4C a c + 2C b )x + 2A b c + 2C a b)\|c
+--R  /
+--R                       +--------------+
+--R          2    2   +-+ |   2
+--R     (4a c  - b c)\|c \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               +--------------+
+--R                            2  |   2
+--R             (C a b x + 2C a )\|c x  + b x + a
+--R           + 
+--R                        2                  2  +-+
+--R             (- 2C a c x  - 2C a b x - 2C a )\|a
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                                  +--------------+
+--R                          +-+ +-+ |   2
+--R         (- 2A c + 2C a)x\|a \|c \|c x  + b x + a
+--R       + 
+--R                    2                 2    +-+
+--R         (- 2C a b x  + (2A a c - 2C a )x)\|c
+--R    /
+--R                              +--------------+
+--R                      2   +-+ |   2
+--R         (a b c x + 2a c)\|c \|c x  + b x + a
+--R       + 
+--R                2 2                2   +-+ +-+
+--R         (- 2a c x  - 2a b c x - 2a c)\|a \|c
+--R     ,
+--R
+--R                                +--------------+
+--R                             2  |   2
+--R             (2C a b x + 4C a )\|c x  + b x + a
+--R           + 
+--R                        2                  2  +-+
+--R             (- 4C a c x  - 4C a b x - 4C a )\|a
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                                    +--------------+
+--R                          +---+ +-+ |   2
+--R         (- 2A c + 2C a)x\|- c \|a \|c x  + b x + a
+--R       + 
+--R                    2                 2    +---+
+--R         (- 2C a b x  + (2A a c - 2C a )x)\|- c
+--R    /
+--R                                +--------------+
+--R                      2   +---+ |   2
+--R         (a b c x + 2a c)\|- c \|c x  + b x + a
+--R       + 
+--R                2 2                2   +---+ +-+
+--R         (- 2a c x  - 2a b c x - 2a c)\|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 165
+
+--S 166 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                  +--------------+
+--R                2          2  +-+ |   2                     2           3
+--R           (8C a c - 2C a b )\|a \|c x  + b x + a  + (- 4C a b c + C a b )x
+--R         + 
+--R                 3        2 2
+--R           - 8C a c + 2C a b
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                                    +--------------+
+--R                  2          2  +-+ |   2                   2           3
+--R           (- 8C a c + 2C a b )\|a \|c x  + b x + a  + (4C a b c - C a b )x
+--R         + 
+--R               3        2 2
+--R           8C a c - 2C a b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                               +--------------+
+--R                       2   +-+ |   2
+--R       (4A a b c + 4C a b)\|c \|c x  + b x + a
+--R     + 
+--R               2          2                    2   +-+ +-+
+--R       ((- 2A b c - 2C a b )x - 4A a b c - 4C a b)\|a \|c
+--R  /
+--R                                +--------------+
+--R          2 2       2   +-+ +-+ |   2
+--R       (8a c  - 2a b c)\|a \|c \|c x  + b x + a
+--R     + 
+--R             2   2      3        3 2     2 2   +-+
+--R       ((- 4a b c  + a b c)x - 8a c  + 2a b c)\|c
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                          +--------------+
+--R                  2          2  +---+ +-+ |   2
+--R           (- 8C a c + 2C a b )\|- c \|a \|c x  + b x + a
+--R         + 
+--R                 2           3         3        2 2  +---+
+--R           ((4C a b c - C a b )x + 8C a c - 2C a b )\|- c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                                       +--------------+
+--R                 2          2  +-+ +-+ |   2
+--R           (16C a c - 4C a b )\|a \|c \|c x  + b x + a
+--R         + 
+--R                   2            3          3        2 2  +-+
+--R           ((- 8C a b c + 2C a b )x - 16C a c + 4C a b )\|c
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- c \|c x  + b x + a  - \|- c \|a
+--R         atan(------------------------------------)
+--R                               c x
+--R     + 
+--R                                     +--------------+
+--R                       2   +---+ +-+ |   2
+--R       (4A a b c + 4C a b)\|- c \|c \|c x  + b x + a
+--R     + 
+--R               2          2                    2   +---+ +-+ +-+
+--R       ((- 2A b c - 2C a b )x - 4A a b c - 4C a b)\|- c \|a \|c
+--R  /
+--R                                      +--------------+
+--R          2 2       2   +---+ +-+ +-+ |   2
+--R       (8a c  - 2a b c)\|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R             2   2      3        3 2     2 2   +---+ +-+
+--R       ((- 4a b c  + a b c)x - 8a c  + 2a b c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 168
+
+--S 169 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 169
+
+)clear all
+
+--S 170 of 556
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^(5/2)
+--R 
+--R
+--R                                       2
+--R                                    C x  + A
+--R   (1)  ---------------------------------------------------------------
+--R                                                       +--------------+
+--R          2 4         3            2  2             2  |   2
+--R        (c x  + 2b c x  + (2a c + b )x  + 2a b x + a )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 556
+r0:=-2/3*(b*(A*c+a*C)+(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2)^(3/2))+2/3*(8*A*c^2+(b^2+4*a*c)*C)*(b+2*c*x)/_
+   (c*(b^2-4*a*c)^2*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R             3          2       2   3           2                   3  2
+--R       (32A c  + 16C a c  + 4C b c)x  + (48A b c  + 24C a b c + 6C b )x
+--R     + 
+--R               2        2           2                     3        2
+--R       (48A a c  + 12A b c + 24C a b )x + 24A a b c - 2A b  + 16C a b
+--R  /
+--R             2 3        2 2     4   2       2   2        3      5        3 2
+--R         (48a c  - 24a b c  + 3b c)x  + (48a b c  - 24a b c + 3b )x + 48a c
+--R       + 
+--R              2 2        4
+--R         - 24a b c + 3a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     2          2       2    5
+--R           (- 16A a c  + (- 2A b  - 8C a )c)x
+--R         + 
+--R                              3        2   4           2           2        3  3
+--R           (- 52A a b c - 2A b  - 20C a b)x  + (- 88A a c - 38A a b  - 32C a )x
+--R         + 
+--R                   2   2        3
+--R           - 120A a b x  - 96A a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   2             6           2         2        2           2  5
+--R           (12A b c  + 4C a b c)x  + (48A a c  + (24A b  + 24C a )c + 6C a b )x
+--R         + 
+--R                              3        2   4          2           2        3  3
+--R           (132A a b c + 12A b  + 36C a b)x  + (136A a c + 86A a b  + 32C a )x
+--R         + 
+--R                 2   2        3
+--R           168A a b x  + 96A a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R               2   2       3   5       3 2      2 2        4  4
+--R           (36a b c  + 3a b c)x  + (72a c  + 90a b c + 3a b )x
+--R         + 
+--R                3         2 3  3        4        3 2  2       4         5
+--R           (252a b c + 57a b )x  + (168a c + 198a b )x  + 240a b x + 96a
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R             3 3      2 2 2  6          3   2      2 3   5
+--R       (- 24a c  - 18a b c )x  + (- 144a b c  - 36a b c)x
+--R     + 
+--R              4 2       3 2       2 4  4          4          3 3  3
+--R       (- 144a c  - 252a b c - 18a b )x  + (- 432a b c - 132a b )x
+--R     + 
+--R              5        4 2  2       5         6
+--R       (- 216a c - 306a b )x  - 288a b x - 96a
+--R                                         Type: Union(Expression(Integer),...)
+--E 172
+
+--S 173 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  2   2            3         3           5        2 3  2
+--R           (192A a b c  + (128A a b  + 128C a b)c - 12A b  + 96C a b )x
+--R         + 
+--R                2 2           4         3 2           3           2 3         4
+--R         (768A a b c - 64A a b  + 512C a b )x + 768A a b c - 64A a b  + 512C a b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R                2 2 2         3 2        6        2 4  3
+--R       (- 288A a b c  - 192C a b c + 2A b  - 16C a b )x
+--R     + 
+--R                3   2            2 3         4             5         3 3  2
+--R       (- 576A a b c  + (- 384A a b  - 384C a b)c + 36A a b  - 288C a b )x
+--R     + 
+--R               3 2         2 4         4 2           4           3 3         5
+--R     (- 1152A a b c + 96A a b  - 768C a b )x - 768A a b c + 64A a b  - 512C a b
+--R  /
+--R                5 3      4 2 2       3 4       2 6  2
+--R           (384a c  + 96a b c  - 120a b c + 18a b )x
+--R         + 
+--R                 5   2       4 3       3 5          6 2       5 2       4 4
+--R           (1536a b c  - 768a b c + 96a b )x + 1536a c  - 768a b c + 96a b
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                  4   3       3 3 2      2 5        7  3
+--R           (- 576a b c  + 240a b c  - 12a b c - 3a b )x
+--R         + 
+--R                   5 3       4 2 2       3 4       2 6  2
+--R           (- 1152a c  - 288a b c  + 360a b c - 54a b )x
+--R         + 
+--R                   5   2        4 3        3 5          6 2       5 2       4 4
+--R           (- 2304a b c  + 1152a b c - 144a b )x - 1536a c  + 768a b c - 96a b
+--R      *
+--R          +-+
+--R         \|a
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 556
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^(7/2)
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + A
+--R  /
+--R          3 6       2 5        2     2   4              3  3      2        2  2
+--R         c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R       + 
+--R           2       3
+--R         3a b x + a
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 556
+r0:=-2/5*(b*(A*c+a*C)+(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2)^(5/2))+2/15*(16*A*c^2+3*b^2*C+4*a*c*C)*(b+2*c*x)/_
+   (c*(b^2-4*a*c)^2*(a+b*x+c*x^2)^(3/2))-16/15*(16*A*c^2+3*b^2*C+4*a*c*C)*_
+   (b+2*c*x)/((b^2-4*a*c)^3*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R              5           4        2 3  5
+--R       (512A c  + 128C a c  + 96C b c )x
+--R     + 
+--R                 4             3         3 2  4
+--R       (1280A b c  + 320C a b c  + 240C b c )x
+--R     + 
+--R                 4          2         2  3           2 2         4   3
+--R       (1280A a c  + (960A b  + 320C a )c  + 480C a b c  + 180C b c)x
+--R     + 
+--R                   3          3         2   2           3         5  2
+--R       (1920A a b c  + (160A b  + 480C a b)c  + 400C a b c + 30C b )x
+--R     + 
+--R              2 3           2 2           4         2 2            4
+--R       (960A a c  + 480A a b c  + (- 20A b  + 480C a b )c + 40C a b )x
+--R     + 
+--R             2   2             3         3          5        2 3
+--R       480A a b c  + (- 80A a b  + 192C a b)c + 6A b  + 16C a b
+--R  /
+--R              3 5       2 2 4         4 3      6 2  4
+--R         (960a c  - 720a b c  + 180a b c  - 15b c )x
+--R       + 
+--R               3   4        2 3 3         5 2      7   3
+--R         (1920a b c  - 1440a b c  + 360a b c  - 30b c)x
+--R       + 
+--R               4 4       3 2 3       2 4 2         6       8  2
+--R         (1920a c  - 480a b c  - 360a b c  + 150a b c - 15b )x
+--R       + 
+--R               4   3        3 3 2       2 5         7         5 3       4 2 2
+--R         (1920a b c  - 1440a b c  + 360a b c - 30a b )x + 960a c  - 720a b c
+--R       + 
+--R             3 4       2 6
+--R         180a b c - 15a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 556
+--a0:=integrate(t0,x)
+--E 177
+
+--S 178 of 556
+--m0:=a0-r0
+--E 178
+
+--S 179 of 556
+--d0:=D(m0,x)
+--E 179
+
+)clear all
+
+--S 180 of 556
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^(9/2)
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + A
+--R  /
+--R          4 8       3 7        3     2 2  6           2     3   5
+--R         c x  + 4b c x  + (4a c  + 6b c )x  + (12a b c  + 4b c)x
+--R       + 
+--R            2 2        2     4  4       2          3  3      3      2 2  2
+--R         (6a c  + 12a b c + b )x  + (12a b c + 4a b )x  + (4a c + 6a b )x
+--R       + 
+--R           3       4
+--R         4a b x + a
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 180
+
+--S 181 of 556
+r0:=-2/7*(b*(A*c+a*C)+(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2)^(7/2))+2/35*(24*A*c^2+5*b^2*C+4*a*c*C)*(b+2*c*x)/_
+   (c*(b^2-4*a*c)^2*(a+b*x+c*x^2)^(5/2))-32/105*(24*A*c^2+5*b^2*C+_
+   4*a*c*C)*(b+2*c*x)/((b^2-4*a*c)^3*(a+b*x+c*x^2)^(3/2))+_
+   256/105*c*(24*A*c^2+5*b^2*C+4*a*c*C)*(b+2*c*x)/((b^2-4*a*c)^4*_
+   sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                7            6          2 5  7
+--R       (12288A c  + 2048C a c  + 2560C b c )x
+--R     + 
+--R                  6              5          3 4  6
+--R       (43008A b c  + 7168C a b c  + 8960C b c )x
+--R     + 
+--R                  6            2          2  5             2 4           4 3  5
+--R       (43008A a c  + (53760A b  + 7168C a )c  + 17920C a b c  + 11200C b c )x
+--R     + 
+--R                        5            3           2   4             3 3
+--R           107520A a b c  + (26880A b  + 17920C a b)c  + 26880C a b c
+--R         + 
+--R                  5 2
+--R           5600C b c
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                   2 5              2          3  4           4           2 2  3
+--R           53760A a c  + (80640A a b  + 8960C a )c  + (3360A b  + 24640C a b )c
+--R         + 
+--R                     4 2         6
+--R           17360C a b c  + 700C b c
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                   2   4              3           3   3
+--R           80640A a b c  + (13440A a b  + 13440C a b)c
+--R         + 
+--R                    5           2 3  2            5         7
+--R           (- 336A b  + 19040C a b )c  + 2744C a b c - 70C b
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                   3 4           2 2 3               4           3 2  2
+--R           26880A a c  + 20160A a b c  + (- 1680A a b  + 13440C a b )c
+--R         + 
+--R                 6          2 4            6
+--R           (84A b  + 2240C a b )c - 56C a b
+--R      *
+--R         x
+--R     + 
+--R               3   3             2 3          4   2            5         3 3
+--R       13440A a b c  + (- 3360A a b  + 3840C a b)c  + (504A a b  + 640C a b )c
+--R     + 
+--R              7        2 5
+--R       - 30A b  - 16C a b
+--R  /
+--R                4 7         3 2 6         2 4 5          6 4       8 3  6
+--R         (26880a c  - 26880a b c  + 10080a b c  - 1680a b c  + 105b c )x
+--R       + 
+--R                4   6         3 3 5         2 5 4          7 3       9 2  5
+--R         (80640a b c  - 80640a b c  + 30240a b c  - 5040a b c  + 315b c )x
+--R       + 
+--R                5 6         3 4 4         2 6 3          8 2       10   4
+--R         (80640a c  - 50400a b c  + 25200a b c  - 4725a b c  + 315b  c)x
+--R       + 
+--R                 5   5          4 3 4         3 5 3          9        11  3
+--R         (161280a b c  - 134400a b c  + 33600a b c  - 1050a b c + 105b  )x
+--R       + 
+--R                6 5         4 4 3         3 6 2        2 8          10  2
+--R         (80640a c  - 50400a b c  + 25200a b c  - 4725a b c + 315a b  )x
+--R       + 
+--R                6   4         5 3 3         4 5 2        3 7        2 9
+--R         (80640a b c  - 80640a b c  + 30240a b c  - 5040a b c + 315a b )x
+--R       + 
+--R               7 4         6 2 3         5 4 2        4 6        3 8
+--R         26880a c  - 26880a b c  + 10080a b c  - 1680a b c + 105a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 556
+--a0:=integrate(t0,x)
+--E 182
+
+--S 183 of 556
+--m0:=a0-r0
+--E 183
+
+--S 184 of 556
+--d0:=D(m0,x)
+--E 184
+
+)clear all
+
+--S 185 of 556
+t0:=(a+c*x^2)^(5/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R          2 6      2 5       2           4           3                2  2
+--R       C c x  + B c x  + (A c  + 2C a c)x  + 2B a c x  + (2A a c + C a )x
+--R     + 
+--R          2       2
+--R       B a x + A a
+--R  *
+--R      +--------+
+--R      |   2
+--R     \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 556
+r0:=5/192*a*(8*A*c-a*C)*x*(a+c*x^2)^(3/2)/c+1/48*(8*A*c-a*C)*x*_
+   (a+c*x^2)^(5/2)/c+1/56*(8*B+7*C*x)*(a+c*x^2)^(7/2)/c+5/128*a^3*_
+   (8*A*c-a*C)*atanh(x*sqrt(c)/sqrt(a+c*x^2))/c^(3/2)+5/128*a^2*_
+   (8*A*c-a*C)*x*sqrt(a+c*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                      +-+
+--R              3          4          x\|c
+--R       (840A a c - 105C a )atanh(-----------)
+--R                                  +--------+
+--R                                  |   2
+--R                                 \|c x  + a
+--R     + 
+--R                 3 7         3 6          3           2  5            2 4
+--R           336C c x  + 384B c x  + (448A c  + 952C a c )x  + 1152B a c x
+--R         + 
+--R                     2         2   3          2   2           2          3
+--R           (1456A a c  + 826C a c)x  + 1152B a c x  + (1848A a c + 105C a )x
+--R         + 
+--R                 3
+--R           384B a
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + a
+--R  /
+--R           +-+
+--R     2688c\|c
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         3 4         4 3  6            4 3          5 2  4
+--R                 (6720A a c  - 840C a c )x  + (67200A a c  - 8400C a c )x
+--R               + 
+--R                           5 2           6   2            6            7
+--R                 (161280A a c  - 20160C a c)x  + 107520A a c - 13440C a
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|a \|c x  + a
+--R           + 
+--R                      3 5         4 4  8              4 4          5 3  6
+--R             (- 840A a c  + 105C a c )x  + (- 26880A a c  + 3360C a c )x
+--R           + 
+--R                         5 3           6 2  4               6 2           7   2
+--R             (- 134400A a c  + 16800C a c )x  + (- 215040A a c  + 26880C a c)x
+--R           + 
+--R                        7            8
+--R             - 107520A a c + 13440C a
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|a \|c  - c x)\|c x  + a  + (- c x  - a)\|c  + c x\|a
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|a \|c x  + a  - a
+--R       + 
+--R                     7 15         7 14            7             6  13
+--R             - 336C c x   - 384B c x   + (- 448A c  - 11704C a c )x
+--R           + 
+--R                         6 12                6           2 5  11
+--R             - 13440B a c x   + (- 15792A a c  - 85050C a c )x
+--R           + 
+--R                       2 5 10               2 5            3 4  9
+--R             - 99456B a c x   + (- 120120A a c  - 264873C a c )x
+--R           + 
+--R                        3 4 8               3 4            4 3  7
+--R             - 319872B a c x  + (- 406784A a c  - 422240C a c )x
+--R           + 
+--R                        4 3 6               4 3            5 2  5
+--R             - 537600B a c x  + (- 725760A a c  - 350112C a c )x
+--R           + 
+--R                        5 2 4               5 2            6   3
+--R             - 473088B a c x  + (- 659456A a c  - 132608C a c)x
+--R           + 
+--R                        6   2               6            7
+--R             - 172032B a c x  + (- 236544A a c - 13440C a )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + a
+--R       + 
+--R                    7 15          7 14           7             6  13
+--R             2688C c x   + 3072B c x   + (3584A c  + 37184C a c )x
+--R           + 
+--R                       6 12              6            2 5  11            2 5 10
+--R             43008B a c x   + (51072A a c  + 181776C a c )x   + 215040B a c x
+--R           + 
+--R                       2 5            3 4  9            3 4 8
+--R             (264768A a c  + 439992C a c )x  + 540288B a c x
+--R           + 
+--R                       3 4            4 3  7            4 3 6
+--R             (702016A a c  + 581560C a c )x  + 752640B a c x
+--R           + 
+--R                        4 3            5 2  5            5 2 4
+--R             (1025920A a c  + 414736C a c )x  + 559104B a c x
+--R           + 
+--R                       5 2            6   3            6   2
+--R             (777728A a c  + 139328C a c)x  + 172032B a c x
+--R           + 
+--R                       6            7
+--R             (236544A a c + 13440C a )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                  4 6            3 4          2 2 2          3   +-+ +-+
+--R           (21504c x  + 215040a c x  + 516096a c x  + 344064a c)\|a \|c
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + a
+--R       + 
+--R               5 8           4 6          2 3 4          3 2 2          4   +-+
+--R       (- 2688c x  - 86016a c x  - 430080a c x  - 688128a c x  - 344064a c)\|c
+--R     ,
+--R
+--R                          3 4          4 3  6             4 3           5 2  4
+--R                 (13440A a c  - 1680C a c )x  + (134400A a c  - 16800C a c )x
+--R               + 
+--R                           5 2           6   2            6            7
+--R                 (322560A a c  - 40320C a c)x  + 215040A a c - 26880C a
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|a \|c x  + a
+--R           + 
+--R                       3 5         4 4  8              4 4          5 3  6
+--R             (- 1680A a c  + 210C a c )x  + (- 53760A a c  + 6720C a c )x
+--R           + 
+--R                         5 3           6 2  4               6 2           7   2
+--R             (- 268800A a c  + 33600C a c )x  + (- 430080A a c  + 53760C a c)x
+--R           + 
+--R                        7            8
+--R             - 215040A a c + 26880C a
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + a  - \|- c \|a
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                     7 15         7 14            7             6  13
+--R             - 336C c x   - 384B c x   + (- 448A c  - 11704C a c )x
+--R           + 
+--R                         6 12                6           2 5  11
+--R             - 13440B a c x   + (- 15792A a c  - 85050C a c )x
+--R           + 
+--R                       2 5 10               2 5            3 4  9
+--R             - 99456B a c x   + (- 120120A a c  - 264873C a c )x
+--R           + 
+--R                        3 4 8               3 4            4 3  7
+--R             - 319872B a c x  + (- 406784A a c  - 422240C a c )x
+--R           + 
+--R                        4 3 6               4 3            5 2  5
+--R             - 537600B a c x  + (- 725760A a c  - 350112C a c )x
+--R           + 
+--R                        5 2 4               5 2            6   3
+--R             - 473088B a c x  + (- 659456A a c  - 132608C a c)x
+--R           + 
+--R                        6   2               6            7
+--R             - 172032B a c x  + (- 236544A a c - 13440C a )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + a
+--R       + 
+--R                    7 15          7 14           7             6  13
+--R             2688C c x   + 3072B c x   + (3584A c  + 37184C a c )x
+--R           + 
+--R                       6 12              6            2 5  11            2 5 10
+--R             43008B a c x   + (51072A a c  + 181776C a c )x   + 215040B a c x
+--R           + 
+--R                       2 5            3 4  9            3 4 8
+--R             (264768A a c  + 439992C a c )x  + 540288B a c x
+--R           + 
+--R                       3 4            4 3  7            4 3 6
+--R             (702016A a c  + 581560C a c )x  + 752640B a c x
+--R           + 
+--R                        4 3            5 2  5            5 2 4
+--R             (1025920A a c  + 414736C a c )x  + 559104B a c x
+--R           + 
+--R                       5 2            6   3            6   2
+--R             (777728A a c  + 139328C a c)x  + 172032B a c x
+--R           + 
+--R                       6            7
+--R             (236544A a c + 13440C a )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                  4 6            3 4          2 2 2          3   +---+ +-+
+--R           (21504c x  + 215040a c x  + 516096a c x  + 344064a c)\|- c \|a
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + a
+--R       + 
+--R                   5 8           4 6          2 3 4          3 2 2          4
+--R           (- 2688c x  - 86016a c x  - 430080a c x  - 688128a c x  - 344064a c)
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 187
+
+--S 188 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       3 4         4 3  6            4 3          5 2  4
+--R               (2240A a c  - 280C a c )x  + (22400A a c  - 2800C a c )x
+--R             + 
+--R                        5 2          6   2           6           7
+--R               (53760A a c  - 6720C a c)x  + 35840A a c - 4480C a
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|a \|c x  + a
+--R         + 
+--R                    3 5        4 4  8             4 4          5 3  6
+--R           (- 280A a c  + 35C a c )x  + (- 8960A a c  + 1120C a c )x
+--R         + 
+--R                      5 3          6 2  4              6 2          7   2
+--R           (- 44800A a c  + 5600C a c )x  + (- 71680A a c  + 8960C a c)x
+--R         + 
+--R                     7           8
+--R           - 35840A a c + 4480C a
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|a \|c  - c x)\|c x  + a  + (- c x  - a)\|c  + c x\|a
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|a \|c x  + a  - a
+--R     + 
+--R                         3 4         4 3  6              4 3          5 2  4
+--R               (- 2240A a c  + 280C a c )x  + (- 22400A a c  + 2800C a c )x
+--R             + 
+--R                          5 2          6   2           6           7
+--R               (- 53760A a c  + 6720C a c)x  - 35840A a c + 4480C a
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|a \|c x  + a
+--R         + 
+--R                  3 5        4 4  8           4 4          5 3  6
+--R           (280A a c  - 35C a c )x  + (8960A a c  - 1120C a c )x
+--R         + 
+--R                    5 3          6 2  4            6 2          7   2
+--R           (44800A a c  - 5600C a c )x  + (71680A a c  - 8960C a c)x
+--R         + 
+--R                   7           8
+--R           35840A a c - 4480C a
+--R      *
+--R                    +-+
+--R                  x\|c
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|c x  + a
+--R     + 
+--R                                                                      +--------+
+--R               4 3 6           5 2 4           6   2           7  +-+ |   2
+--R       (1024B a c x  + 10240B a c x  + 24576B a c x  + 16384B a )\|c \|c x  + a
+--R     + 
+--R                   3 4 8          4 3 6           5 2 4           6   2
+--R           - 128B a c x  - 4096B a c x  - 20480B a c x  - 32768B a c x
+--R         + 
+--R                     7
+--R           - 16384B a
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                                                                   +--------+
+--R             4 6           3 4          2 2 2          3   +-+ +-+ |   2
+--R       (7168c x  + 71680a c x  + 172032a c x  + 114688a c)\|a \|c \|c x  + a
+--R     + 
+--R              5 8           4 6          2 3 4          3 2 2          4   +-+
+--R       (- 896c x  - 28672a c x  - 143360a c x  - 229376a c x  - 114688a c)\|c
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         3 4         4 3  6              4 3          5 2  4
+--R               (- 2240A a c  + 280C a c )x  + (- 22400A a c  + 2800C a c )x
+--R             + 
+--R                          5 2          6   2           6           7
+--R               (- 53760A a c  + 6720C a c)x  - 35840A a c + 4480C a
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + a
+--R         + 
+--R                      3 5        4 4  8           4 4          5 3  6
+--R               (280A a c  - 35C a c )x  + (8960A a c  - 1120C a c )x
+--R             + 
+--R                        5 3          6 2  4            6 2          7   2
+--R               (44800A a c  - 5600C a c )x  + (71680A a c  - 8960C a c)x
+--R             + 
+--R                       7           8
+--R               35840A a c - 4480C a
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    +-+
+--R                  x\|c
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|c x  + a
+--R     + 
+--R                       3 4         4 3  6            4 3          5 2  4
+--R               (4480A a c  - 560C a c )x  + (44800A a c  - 5600C a c )x
+--R             + 
+--R                         5 2           6   2           6           7
+--R               (107520A a c  - 13440C a c)x  + 71680A a c - 8960C a
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + a
+--R         + 
+--R                        3 5        4 4  8              4 4          5 3  6
+--R               (- 560A a c  + 70C a c )x  + (- 17920A a c  + 2240C a c )x
+--R             + 
+--R                          5 3           6 2  4               6 2           7   2
+--R               (- 89600A a c  + 11200C a c )x  + (- 143360A a c  + 17920C a c)x
+--R             + 
+--R                         7           8
+--R               - 71680A a c + 8960C a
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + a  - \|- c \|a
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                 4 3 6           5 2 4           6   2           7  +---+ +-+
+--R         (1024B a c x  + 10240B a c x  + 24576B a c x  + 16384B a )\|- c \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + a
+--R     + 
+--R                   3 4 8          4 3 6           5 2 4           6   2
+--R           - 128B a c x  - 4096B a c x  - 20480B a c x  - 32768B a c x
+--R         + 
+--R                     7
+--R           - 16384B a
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R               4 6           3 4          2 2 2          3   +---+ +-+ +-+
+--R         (7168c x  + 71680a c x  + 172032a c x  + 114688a c)\|- c \|a \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + a
+--R     + 
+--R                5 8           4 6          2 3 4          3 2 2          4
+--R         (- 896c x  - 28672a c x  - 143360a c x  - 229376a c x  - 114688a c)
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 191
+
+)clear all
+
+--S 192 of 556
+t0:=(a+c*x^2)^(3/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R                                                        +--------+
+--R              4        3               2                |   2
+--R   (1)  (C c x  + B c x  + (A c + C a)x  + B a x + A a)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 556
+r0:=1/24*(6*A*c-a*C)*x*(a+c*x^2)^(3/2)/c+1/30*(6*B+5*C*x)*(a+c*x^2)^(5/2)/c+_
+   1/16*a^2*(6*A*c-a*C)*atanh(x*sqrt(c)/sqrt(a+c*x^2))/c^(3/2)+_
+   1/16*a*(6*A*c-a*C)*x*sqrt(a+c*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                    +-+
+--R             2         3          x\|c
+--R       (90A a c - 15C a )atanh(-----------)
+--R                                +--------+
+--R                                |   2
+--R                               \|c x  + a
+--R     + 
+--R                2 5        2 4         2            3            2
+--R           40C c x  + 48B c x  + (60A c  + 70C a c)x  + 96B a c x
+--R         + 
+--R                            2          2
+--R           (150A a c + 15C a )x + 48B a
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + a
+--R  /
+--R          +-+
+--R     240c\|c
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        2 3        3 2  4           3 2         4   2
+--R                 (540A a c  - 90C a c )x  + (2880A a c  - 480C a c)x
+--R               + 
+--R                        4          5
+--R                 2880A a c - 480C a
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|a \|c x  + a
+--R           + 
+--R                     2 4        3 3  6             3 3         4 2  4
+--R             (- 90A a c  + 15C a c )x  + (- 1620A a c  + 270C a c )x
+--R           + 
+--R                       4 2         5   2          5          6
+--R             (- 4320A a c  + 720C a c)x  - 2880A a c + 480C a
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|a \|c  - c x)\|c x  + a  + (- c x  - a)\|c  + c x\|a
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|a \|c x  + a  - a
+--R       + 
+--R                    5 11        5 10           5           4  9           4 8
+--R             - 40C c x   - 48B c x   + (- 60A c  - 790C a c )x  - 960B a c x
+--R           + 
+--R                         4          2 3  7          2 3 6
+--R             (- 1230A a c  - 3195C a c )x  - 4080B a c x
+--R           + 
+--R                       2 3          3 2  5          3 2 4
+--R             (- 5580A a c  - 4910C a c )x  - 6720B a c x
+--R           + 
+--R                       3 2          4   3          4   2
+--R             (- 9120A a c  - 2960C a c)x  - 3840B a c x
+--R           + 
+--R                       4          5
+--R             (- 4800A a c - 480C a )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + a
+--R       + 
+--R                   5 11         5 10          5            4  9            4 8
+--R             240C c x   + 288B c x   + (360A c  + 1940C a c )x  + 2400B a c x
+--R           + 
+--R                       4          2 3  7          2 3 6
+--R             (3180A a c  + 5310C a c )x  + 6960B a c x
+--R           + 
+--R                     2 3          3 2  5          3 2 4
+--R             (9540A a c  + 6330C a c )x  + 8640B a c x
+--R           + 
+--R                    3 2          4   3          4   2           4          5
+--R           (11520A a c  + 3200C a c)x  + 3840B a c x  + (4800A a c + 480C a )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                                                   +--------+
+--R               3 4          2 2        2   +-+ +-+ |   2
+--R         (1440c x  + 7680a c x  + 7680a c)\|a \|c \|c x  + a
+--R       + 
+--R                4 6          3 4         2 2 2        3   +-+
+--R         (- 240c x  - 4320a c x  - 11520a c x  - 7680a c)\|c
+--R     ,
+--R
+--R                         2 3         3 2  4           3 2         4   2
+--R                 (1080A a c  - 180C a c )x  + (5760A a c  - 960C a c)x
+--R               + 
+--R                        4          5
+--R                 5760A a c - 960C a
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|a \|c x  + a
+--R           + 
+--R                      2 4        3 3  6             3 3         4 2  4
+--R             (- 180A a c  + 30C a c )x  + (- 3240A a c  + 540C a c )x
+--R           + 
+--R                       4 2          5   2          5          6
+--R             (- 8640A a c  + 1440C a c)x  - 5760A a c + 960C a
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + a  - \|- c \|a
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                    5 11        5 10           5           4  9           4 8
+--R             - 40C c x   - 48B c x   + (- 60A c  - 790C a c )x  - 960B a c x
+--R           + 
+--R                         4          2 3  7          2 3 6
+--R             (- 1230A a c  - 3195C a c )x  - 4080B a c x
+--R           + 
+--R                       2 3          3 2  5          3 2 4
+--R             (- 5580A a c  - 4910C a c )x  - 6720B a c x
+--R           + 
+--R                       3 2          4   3          4   2
+--R             (- 9120A a c  - 2960C a c)x  - 3840B a c x
+--R           + 
+--R                       4          5
+--R             (- 4800A a c - 480C a )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + a
+--R       + 
+--R                   5 11         5 10          5            4  9            4 8
+--R             240C c x   + 288B c x   + (360A c  + 1940C a c )x  + 2400B a c x
+--R           + 
+--R                       4          2 3  7          2 3 6
+--R             (3180A a c  + 5310C a c )x  + 6960B a c x
+--R           + 
+--R                     2 3          3 2  5          3 2 4
+--R             (9540A a c  + 6330C a c )x  + 8640B a c x
+--R           + 
+--R                    3 2          4   3          4   2           4          5
+--R           (11520A a c  + 3200C a c)x  + 3840B a c x  + (4800A a c + 480C a )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                                     +--------+
+--R               3 4          2 2        2   +---+ +-+ |   2
+--R         (1440c x  + 7680a c x  + 7680a c)\|- c \|a \|c x  + a
+--R       + 
+--R                4 6          3 4         2 2 2        3   +---+
+--R         (- 240c x  - 4320a c x  - 11520a c x  - 7680a c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 194
+
+--S 195 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2 3        3 2  4          3 2         4   2         4
+--R               (180A a c  - 30C a c )x  + (960A a c  - 160C a c)x  + 960A a c
+--R             + 
+--R                       5
+--R               - 160C a
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|a \|c x  + a
+--R         + 
+--R                   2 4       3 3  6            3 3        4 2  4
+--R           (- 30A a c  + 5C a c )x  + (- 540A a c  + 90C a c )x
+--R         + 
+--R                     4 2         5   2         5          6
+--R           (- 1440A a c  + 240C a c)x  - 960A a c + 160C a
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|a \|c  - c x)\|c x  + a  + (- c x  - a)\|c  + c x\|a
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|a \|c x  + a  - a
+--R     + 
+--R                        2 3        3 2  4            3 2         4   2
+--R               (- 180A a c  + 30C a c )x  + (- 960A a c  + 160C a c)x
+--R             + 
+--R                       4          5
+--R               - 960A a c + 160C a
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|a \|c x  + a
+--R         + 
+--R                 2 4       3 3  6          3 3        4 2  4
+--R           (30A a c  - 5C a c )x  + (540A a c  - 90C a c )x
+--R         + 
+--R                   4 2         5   2         5          6
+--R           (1440A a c  - 240C a c)x  + 960A a c - 160C a
+--R      *
+--R                    +-+
+--R                  x\|c
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|c x  + a
+--R     + 
+--R                                                +--------+
+--R             3 2 4         4   2         5  +-+ |   2
+--R       (96B a c x  + 512B a c x  + 512B a )\|c \|c x  + a
+--R     + 
+--R               2 3 6         3 2 4         4   2         5  +-+ +-+
+--R       (- 16B a c x  - 288B a c x  - 768B a c x  - 512B a )\|a \|c
+--R  /
+--R                                                +--------+
+--R            3 4          2 2        2   +-+ +-+ |   2
+--R       (480c x  + 2560a c x  + 2560a c)\|a \|c \|c x  + a
+--R     + 
+--R             4 6          3 4        2 2 2        3   +-+
+--R       (- 80c x  - 1440a c x  - 3840a c x  - 2560a c)\|c
+--R                                                    Type: Expression(Integer)
+--E 195
+
+--S 196 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        2 3        3 2  4            3 2         4   2
+--R               (- 180A a c  + 30C a c )x  + (- 960A a c  + 160C a c)x
+--R             + 
+--R                       4          5
+--R               - 960A a c + 160C a
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + a
+--R         + 
+--R                     2 4       3 3  6          3 3        4 2  4
+--R               (30A a c  - 5C a c )x  + (540A a c  - 90C a c )x
+--R             + 
+--R                       4 2         5   2         5          6
+--R               (1440A a c  - 240C a c)x  + 960A a c - 160C a
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    +-+
+--R                  x\|c
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|c x  + a
+--R     + 
+--R                      2 3        3 2  4           3 2         4   2          4
+--R               (360A a c  - 60C a c )x  + (1920A a c  - 320C a c)x  + 1920A a c
+--R             + 
+--R                       5
+--R               - 320C a
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + a
+--R         + 
+--R                       2 4        3 3  6             3 3         4 2  4
+--R               (- 60A a c  + 10C a c )x  + (- 1080A a c  + 180C a c )x
+--R             + 
+--R                         4 2         5   2          5          6
+--R               (- 2880A a c  + 480C a c)x  - 1920A a c + 320C a
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + a  - \|- c \|a
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                                                      +--------+
+--R             3 2 4         4   2         5  +---+ +-+ |   2
+--R       (96B a c x  + 512B a c x  + 512B a )\|- c \|c \|c x  + a
+--R     + 
+--R               2 3 6         3 2 4         4   2         5  +---+ +-+ +-+
+--R       (- 16B a c x  - 288B a c x  - 768B a c x  - 512B a )\|- c \|a \|c
+--R  /
+--R                                                      +--------+
+--R            3 4          2 2        2   +---+ +-+ +-+ |   2
+--R       (480c x  + 2560a c x  + 2560a c)\|- c \|a \|c \|c x  + a
+--R     + 
+--R             4 6          3 4        2 2 2        3   +---+ +-+
+--R       (- 80c x  - 1440a c x  - 3840a c x  - 2560a c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 556
+t0:=(a+c*x^2)^(1/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R                         +--------+
+--R            2            |   2
+--R   (1)  (C x  + B x + A)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 556
+r0:=1/12*(4*B+3*C*x)*(a+c*x^2)^(3/2)/c+1/8*a*(4*A*c-a*C)*atanh(x*_
+   sqrt(c)/sqrt(a+c*x^2))/c^(3/2)+1/8*(4*A*c-a*C)*x*sqrt(a+c*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                   +-+
+--R                      2          x\|c
+--R       (12A a c - 3C a )atanh(-----------)
+--R                               +--------+
+--R                               |   2
+--R                              \|c x  + a
+--R     + 
+--R                                                        +--------+
+--R              3         2                           +-+ |   2
+--R       (6C c x  + 8B c x  + (12A c + 3C a)x + 8B a)\|c \|c x  + a
+--R  /
+--R         +-+
+--R     24c\|c
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                             +--------+
+--R                      2        2   2        2         3  +-+ |   2
+--R             ((48A a c  - 12C a c)x  + 96A a c - 24C a )\|a \|c x  + a
+--R           + 
+--R                       3       2 2  4           2 2        3   2        3
+--R             (- 12A a c  + 3C a c )x  + (- 96A a c  + 24C a c)x  - 96A a c
+--R           + 
+--R                  4
+--R             24C a
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|a \|c  - c x)\|c x  + a  + (- c x  - a)\|c  + c x\|a
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|a \|c x  + a  - a
+--R       + 
+--R                   3 7       3 6           3          2  5          2 4
+--R             - 6C c x  - 8B c x  + (- 12A c  - 51C a c )x  - 72B a c x
+--R           + 
+--R                       2        2   3        2   2           2         3
+--R             (- 96A a c  - 72C a c)x  - 96B a c x  + (- 96A a c - 24C a )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + a
+--R       + 
+--R                  3 7        3 6         3          2  5           2 4
+--R             24C c x  + 32B c x  + (48A c  + 84C a c )x  + 120B a c x
+--R           + 
+--R                      2        2   3        2   2         2         3
+--R             (144A a c  + 84C a c)x  + 96B a c x  + (96A a c + 24C a )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                                   +--------+
+--R             2 2           +-+ +-+ |   2
+--R         (96c x  + 192a c)\|a \|c \|c x  + a
+--R       + 
+--R               3 4         2 2       2   +-+
+--R         (- 24c x  - 192a c x  - 192a c)\|c
+--R     ,
+--R
+--R                                                              +--------+
+--R                      2        2   2         2         3  +-+ |   2
+--R             ((96A a c  - 24C a c)x  + 192A a c - 48C a )\|a \|c x  + a
+--R           + 
+--R                       3       2 2  4            2 2        3   2         3
+--R             (- 24A a c  + 6C a c )x  + (- 192A a c  + 48C a c)x  - 192A a c
+--R           + 
+--R                  4
+--R             48C a
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + a  - \|- c \|a
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                   3 7       3 6           3          2  5          2 4
+--R             - 6C c x  - 8B c x  + (- 12A c  - 51C a c )x  - 72B a c x
+--R           + 
+--R                       2        2   3        2   2           2         3
+--R             (- 96A a c  - 72C a c)x  - 96B a c x  + (- 96A a c - 24C a )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + a
+--R       + 
+--R                  3 7        3 6         3          2  5           2 4
+--R             24C c x  + 32B c x  + (48A c  + 84C a c )x  + 120B a c x
+--R           + 
+--R                      2        2   3        2   2         2         3
+--R             (144A a c  + 84C a c)x  + 96B a c x  + (96A a c + 24C a )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                     +--------+
+--R             2 2           +---+ +-+ |   2
+--R         (96c x  + 192a c)\|- c \|a \|c x  + a
+--R       + 
+--R               3 4         2 2       2   +---+
+--R         (- 24c x  - 192a c x  - 192a c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 201
+
+--S 202 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                           +--------+
+--R                    2        2   2        2         3  +-+ |   2
+--R           ((48A a c  - 12C a c)x  + 96A a c - 24C a )\|a \|c x  + a
+--R         + 
+--R                   3       2 2  4           2 2        3   2        3         4
+--R         (- 12A a c  + 3C a c )x  + (- 96A a c  + 24C a c)x  - 96A a c + 24C a
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|a \|c  - c x)\|c x  + a  + (- c x  - a)\|c  + c x\|a
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|a \|c x  + a  - a
+--R     + 
+--R                                                             +--------+
+--R                      2        2   2        2         3  +-+ |   2
+--R           ((- 48A a c  + 12C a c)x  - 96A a c + 24C a )\|a \|c x  + a
+--R         + 
+--R                   3       2 2  4         2 2        3   2        3         4
+--R           (12A a c  - 3C a c )x  + (96A a c  - 24C a c)x  + 96A a c - 24C a
+--R      *
+--R                    +-+
+--R                  x\|c
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|c x  + a
+--R     + 
+--R                                 +--------+
+--R             2   2        3  +-+ |   2
+--R       (32B a c x  + 64B a )\|c \|c x  + a
+--R     + 
+--R                2 4        2   2        3  +-+ +-+
+--R       (- 8B a c x  - 64B a c x  - 64B a )\|a \|c
+--R  /
+--R                               +--------+
+--R         2 2           +-+ +-+ |   2              3 4         2 2       2   +-+
+--R     (96c x  + 192a c)\|a \|c \|c x  + a  + (- 24c x  - 192a c x  - 192a c)\|c
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                   +--------+
+--R                      2        2   2        2         3  +---+ +-+ |   2
+--R           ((- 48A a c  + 12C a c)x  - 96A a c + 24C a )\|- c \|a \|c x  + a
+--R         + 
+--R                         3       2 2  4         2 2        3   2        3
+--R                 (12A a c  - 3C a c )x  + (96A a c  - 24C a c)x  + 96A a c
+--R               + 
+--R                        4
+--R                 - 24C a
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    +-+
+--R                  x\|c
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|c x  + a
+--R     + 
+--R                                                                +--------+
+--R                    2        2   2         2         3  +-+ +-+ |   2
+--R           ((96A a c  - 24C a c)x  + 192A a c - 48C a )\|a \|c \|c x  + a
+--R         + 
+--R                         3       2 2  4            2 2        3   2         3
+--R               (- 24A a c  + 6C a c )x  + (- 192A a c  + 48C a c)x  - 192A a c
+--R             + 
+--R                    4
+--R               48C a
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + a  - \|- c \|a
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                                       +--------+
+--R             2   2        3  +---+ +-+ |   2
+--R       (32B a c x  + 64B a )\|- c \|c \|c x  + a
+--R     + 
+--R                2 4        2   2        3  +---+ +-+ +-+
+--R       (- 8B a c x  - 64B a c x  - 64B a )\|- c \|a \|c
+--R  /
+--R                                       +--------+
+--R           2 2           +---+ +-+ +-+ |   2
+--R       (96c x  + 192a c)\|- c \|a \|c \|c x  + a
+--R     + 
+--R             3 4         2 2       2   +---+ +-+
+--R       (- 24c x  - 192a c x  - 192a c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 205
+
+)clear all
+
+--S 206 of 556
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^(1/2)
+--R 
+--R
+--R           2
+--R        C x  + B x + A
+--R   (1)  --------------
+--R           +--------+
+--R           |   2
+--R          \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 556
+r0:=1/2*(2*A*c-a*C)*atanh(x*sqrt(c)/sqrt(a+c*x^2))/c^(3/2)+_
+   1/2*(2*B+C*x)*sqrt(a+c*x^2)/c
+--R 
+--R
+--R                               +-+                      +--------+
+--R                             x\|c                   +-+ |   2
+--R        (2A c - C a)atanh(-----------) + (C x + 2B)\|c \|c x  + a
+--R                           +--------+
+--R                           |   2
+--R                          \|c x  + a
+--R   (2)  ----------------------------------------------------------
+--R                                     +-+
+--R                                  2c\|c
+--R                                                    Type: Expression(Integer)
+--E 207
+
+--S 208 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                              +--------+
+--R                          +-+ |   2               2          2                2
+--R           ((4A c - 2C a)\|a \|c x  + a  + (- 2A c  + C a c)x  - 4A a c + 2C a )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|a \|c  - c x)\|c x  + a  + (- c x  - a)\|c  + c x\|a
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|a \|c x  + a  - a
+--R       + 
+--R                                           +--------+
+--R                 3         2           +-+ |   2
+--R         (- C c x  - 2B c x  - 2C a x)\|c \|c x  + a
+--R       + 
+--R                3         2           +-+ +-+
+--R         (2C c x  + 2B c x  + 2C a x)\|a \|c
+--R    /
+--R                  +--------+
+--R          +-+ +-+ |   2             2 2         +-+
+--R       4c\|a \|c \|c x  + a  + (- 2c x  - 4a c)\|c
+--R     ,
+--R
+--R                                 +--------+
+--R                             +-+ |   2               2           2
+--R               (8A c - 4C a)\|a \|c x  + a  + (- 4A c  + 2C a c)x  - 8A a c
+--R             + 
+--R                   2
+--R               4C a
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + a  - \|- c \|a
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                                             +--------+
+--R                 3         2           +---+ |   2
+--R         (- C c x  - 2B c x  - 2C a x)\|- c \|c x  + a
+--R       + 
+--R                3         2           +---+ +-+
+--R         (2C c x  + 2B c x  + 2C a x)\|- c \|a
+--R    /
+--R                    +--------+
+--R          +---+ +-+ |   2             2 2         +---+
+--R       4c\|- c \|a \|c x  + a  + (- 2c x  - 4a c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 208
+
+--S 209 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            +--------+
+--R                        +-+ |   2               2          2                2
+--R         ((4A c - 2C a)\|a \|c x  + a  + (- 2A c  + C a c)x  - 4A a c + 2C a )
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|a \|c  - c x)\|c x  + a  + (- c x  - a)\|c  + c x\|a
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|a \|c x  + a  - a
+--R     + 
+--R                              +--------+
+--R                          +-+ |   2             2          2                2
+--R         ((- 4A c + 2C a)\|a \|c x  + a  + (2A c  - C a c)x  + 4A a c - 2C a )
+--R      *
+--R                    +-+
+--R                  x\|c
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|c x  + a
+--R     + 
+--R                +--------+
+--R            +-+ |   2                 2         +-+ +-+
+--R       4B a\|c \|c x  + a  + (- 2B c x  - 4B a)\|a \|c
+--R  /
+--R                +--------+
+--R        +-+ +-+ |   2             2 2         +-+
+--R     4c\|a \|c \|c x  + a  + (- 2c x  - 4a c)\|c
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+--S 211 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                     +--------+
+--R                           +---+ +-+ |   2
+--R           (- 4A c + 2C a)\|- c \|a \|c x  + a
+--R         + 
+--R                 2          2                2  +---+
+--R           ((2A c  - C a c)x  + 4A a c - 2C a )\|- c
+--R      *
+--R                    +-+
+--R                  x\|c
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|c x  + a
+--R     + 
+--R                                 +--------+
+--R                         +-+ +-+ |   2
+--R           (8A c - 4C a)\|a \|c \|c x  + a
+--R         + 
+--R                   2           2                2  +-+
+--R           ((- 4A c  + 2C a c)x  - 8A a c + 4C a )\|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + a  - \|- c \|a
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                      +--------+
+--R            +---+ +-+ |   2                 2         +---+ +-+ +-+
+--R       4B a\|- c \|c \|c x  + a  + (- 2B c x  - 4B a)\|- c \|a \|c
+--R  /
+--R                      +--------+
+--R        +---+ +-+ +-+ |   2             2 2         +---+ +-+
+--R     4c\|- c \|a \|c \|c x  + a  + (- 2c x  - 4a c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 212
+
+)clear all
+
+--S 213 of 556
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^(3/2)
+--R 
+--R
+--R               2
+--R            C x  + B x + A
+--R   (1)  ---------------------
+--R                   +--------+
+--R            2      |   2
+--R        (c x  + a)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 213
+
+--S 214 of 556
+r0:=C*atanh(x*sqrt(c)/sqrt(a+c*x^2))/c^(3/2)+(-a*B+(A*c-a*C)*x)/_
+   (a*c*sqrt(a+c*x^2))
+--R 
+--R
+--R            +--------+           +-+
+--R            |   2              x\|c                             +-+
+--R        C a\|c x  + a atanh(-----------) + ((A c - C a)x - B a)\|c
+--R                             +--------+
+--R                             |   2
+--R                            \|c x  + a
+--R   (2)  -----------------------------------------------------------
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                             a c\|c \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    +--------+
+--R                +-+ |   2               2      2
+--R           (C a\|a \|c x  + a  - C a c x  - C a )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|a \|c  - c x)\|c x  + a  + (- c x  - a)\|c  + c x\|a
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|a \|c x  + a  - a
+--R       + 
+--R                            +--------+
+--R                        +-+ |   2              2                 +-+ +-+
+--R         (- A c + C a)x\|c \|c x  + a  + (B c x  + (A c - C a)x)\|a \|c
+--R    /
+--R                   +--------+
+--R           +-+ +-+ |   2              2 2    2   +-+
+--R       a c\|a \|c \|c x  + a  + (- a c x  - a c)\|c
+--R     ,
+--R
+--R                     +--------+
+--R                 +-+ |   2                2       2
+--R           (2C a\|a \|c x  + a  - 2C a c x  - 2C a )
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + a  - \|- c \|a
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                              +--------+
+--R                        +---+ |   2              2                 +---+ +-+
+--R         (- A c + C a)x\|- c \|c x  + a  + (B c x  + (A c - C a)x)\|- c \|a
+--R    /
+--R                     +--------+
+--R           +---+ +-+ |   2              2 2    2   +---+
+--R       a c\|- c \|a \|c x  + a  + (- a c x  - a c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 215
+
+--S 216 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              +--------+
+--R              |   2            +-+
+--R         (C a\|c x  + a  - C a\|a )
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|a \|c  - c x)\|c x  + a  + (- c x  - a)\|c  + c x\|a
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|a \|c x  + a  - a
+--R     + 
+--R              +--------+                      +-+                 +--------+
+--R              |   2            +-+          x\|c          +-+ +-+ |   2
+--R       (- C a\|c x  + a  + C a\|a )atanh(-----------) - B\|a \|c \|c x  + a
+--R                                          +--------+
+--R                                          |   2
+--R                                         \|c x  + a
+--R     + 
+--R           +-+
+--R       B a\|c
+--R  /
+--R             +--------+
+--R         +-+ |   2            +-+ +-+
+--R     a c\|c \|c x  + a  - a c\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    +--------+                            +-+
+--R              +---+ |   2            +---+ +-+          x\|c
+--R       (- C a\|- c \|c x  + a  + C a\|- c \|a )atanh(-----------)
+--R                                                      +--------+
+--R                                                      |   2
+--R                                                     \|c x  + a
+--R     + 
+--R                                                       +--------+
+--R                 +--------+                      +---+ |   2         +---+ +-+
+--R             +-+ |   2             +-+ +-+      \|- c \|c x  + a  - \|- c \|a
+--R       (2C a\|c \|c x  + a  - 2C a\|a \|c )atan(------------------------------)
+--R                                                              c x
+--R     + 
+--R                         +--------+
+--R           +---+ +-+ +-+ |   2            +---+ +-+
+--R       - B\|- c \|a \|c \|c x  + a  + B a\|- c \|c
+--R  /
+--R                   +--------+
+--R         +---+ +-+ |   2            +---+ +-+ +-+
+--R     a c\|- c \|c \|c x  + a  - a c\|- c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 556
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^(5/2)
+--R 
+--R
+--R                    2
+--R                 C x  + B x + A
+--R   (1)  --------------------------------
+--R                              +--------+
+--R          2 4         2    2  |   2
+--R        (c x  + 2a c x  + a )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 556
+r0:=1/3*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2)^(3/2))+1/3*(2*A*c+a*C)*x/_
+   (a^2*c*sqrt(a+c*x^2))
+--R 
+--R
+--R             2          3                 2
+--R        (2A c  + C a c)x  + 3A a c x - B a
+--R   (2)  -----------------------------------
+--R                             +--------+
+--R               2 2 2     3   |   2
+--R            (3a c x  + 3a c)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2          5           4                    2  3       2 2
+--R           (- 2A c  - C a c)x  - 3B a c x  + (- 11A a c - 4C a )x  - 6B a x
+--R         + 
+--R                  2
+--R           - 12A a x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + a
+--R     + 
+--R              2 6        2           5           4                  2  3
+--R           B c x  + (6A c  + 3C a c)x  + 6B a c x  + (17A a c + 4C a )x
+--R         + 
+--R               2 2        2
+--R           6B a x  + 12A a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                       +--------+
+--R          2 2 4      3   2      4  +-+ |   2          2 3 6      3 2 4
+--R       (9a c x  + 21a c x  + 12a )\|a \|c x  + a  - 3a c x  - 18a c x
+--R     + 
+--R            4   2      5
+--R       - 27a c x  - 12a
+--R                                         Type: Union(Expression(Integer),...)
+--E 222
+
+--S 223 of 556
+m0:=a0-r0
+--R 
+--R
+--R                               +--------+
+--R                 2         +-+ |   2                2       2
+--R         (- B c x  - 4B a)\|a \|c x  + a  + 3B a c x  + 4B a
+--R   (4)  ------------------------------------------------------
+--R                          +--------+
+--R           2 2 2      3   |   2             2 2 2      3   +-+
+--R        (3a c x  + 12a c)\|c x  + a  + (- 9a c x  - 12a c)\|a
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 224
+
+)clear all
+
+--S 225 of 556
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^(7/2)
+--R 
+--R
+--R                         2
+--R                      C x  + B x + A
+--R   (1)  ------------------------------------------
+--R                                        +--------+
+--R          3 6       2 4     2   2    3  |   2
+--R        (c x  + 3a c x  + 3a c x  + a )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 225
+
+--S 226 of 556
+r0:=1/5*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2)^(5/2))+1/15*(4*A*c+a*C)*x/_
+   (a^2*c*(a+c*x^2)^(3/2))+2/15*(4*A*c+a*C)*x/(a^3*c*sqrt(a+c*x^2))
+--R 
+--R
+--R             3         2  5           2       2   3        2          3
+--R        (8A c  + 2C a c )x  + (20A a c  + 5C a c)x  + 15A a c x - 3B a
+--R   (2)  ---------------------------------------------------------------
+--R                                                  +--------+
+--R                        3 3 4      4 2 2      5   |   2
+--R                    (15a c x  + 30a c x  + 15a c)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  4         3  9          3 8              3        2 2  7
+--R           (- 8A c  - 2C a c )x  - 15B a c x  + (- 116A a c  - 29C a c )x
+--R         + 
+--R                  2 2 6            2 2        3   5         3   4
+--R           - 90B a c x  + (- 383A a c  - 92C a c)x  - 180B a c x
+--R         + 
+--R                    3         4  3         4 2         4
+--R           (- 500A a c - 80C a )x  - 120B a x  - 240A a x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + a
+--R     + 
+--R               4 10         4          3  9          3 8
+--R           3B c x   + (40A c  + 10C a c )x  + 45B a c x
+--R         + 
+--R                    3        2 2  7         2 2 6          2 2         3   5
+--R           (260A a c  + 65C a c )x  + 165B a c x  + (603A a c  + 132C a c)x
+--R         + 
+--R                 3   4          3         4  3         4 2         4
+--R           240B a c x  + (620A a c + 80C a )x  + 120B a x  + 240A a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                                  +--------+
+--R           3 4 8       4 3 6       5 2 4       6   2       7  +-+ |   2
+--R       (75a c x  + 450a c x  + 915a c x  + 780a c x  + 240a )\|a \|c x  + a
+--R     + 
+--R            3 5 10       4 4 8       5 3 6        6 2 4       7   2       8
+--R       - 15a c x   - 225a c x  - 825a c x  - 1275a c x  - 900a c x  - 240a
+--R                                         Type: Union(Expression(Integer),...)
+--E 227
+
+--S 228 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +--------+
+--R             2 4            2        2  +-+ |   2              2 4        2   2
+--R       (- B c x  - 12B a c x  - 16B a )\|a \|c x  + a  + 5B a c x  + 20B a c x
+--R     + 
+--R            3
+--R       16B a
+--R  /
+--R                                    +--------+
+--R          3 3 4      4 2 2      5   |   2
+--R       (5a c x  + 60a c x  + 80a c)\|c x  + a
+--R     + 
+--R             3 3 4       4 2 2      5   +-+
+--R       (- 25a c x  - 100a c x  - 80a c)\|a
+--R                                                    Type: Expression(Integer)
+--E 228
+
+--S 229 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 229
+
+)clear all
+
+--S 230 of 556
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^(9/2)
+--R 
+--R
+--R                              2
+--R                           C x  + B x + A
+--R   (1)  ----------------------------------------------------
+--R                                                  +--------+
+--R          4 8       3 6     2 2 4     3   2    4  |   2
+--R        (c x  + 4a c x  + 6a c x  + 4a c x  + a )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 556
+r0:=1/7*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2)^(7/2))+1/35*(6*A*c+a*C)*x/_
+   (a^2*c*(a+c*x^2)^(5/2))+4/105*(6*A*c+a*C)*x/(a^3*c*(a+c*x^2)^(3/2))+_
+   8/105*(6*A*c+a*C)*x/(a^4*c*sqrt(a+c*x^2))
+--R 
+--R
+--R   (2)
+--R             4         3  7            3        2 2  5          2 2        3   3
+--R       (48A c  + 8C a c )x  + (168A a c  + 28C a c )x  + (210A a c  + 35C a c)x
+--R     + 
+--R             3           4
+--R       105A a c x - 15B a
+--R  /
+--R                                                  +--------+
+--R          4 4 6       5 3 4       6 2 2       7   |   2
+--R     (105a c x  + 315a c x  + 315a c x  + 105a c)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   6         5  13           5 12
+--R           (- 48A c  - 8C a c )x   - 105B a c x
+--R         + 
+--R                       5         2 4  11          2 4 10
+--R           (- 1320A a c  - 220C a c )x   - 1155B a c x
+--R         + 
+--R                     2 4          3 3  9          3 3 8
+--R           (- 8082A a c  - 1347C a c )x  - 4515B a c x
+--R         + 
+--R                      3 3          4 2  7          4 2 6
+--R           (- 21657A a c  - 3592C a c )x  - 8610B a c x
+--R         + 
+--R                      4 2          5   5          5   4
+--R           (- 30072A a c  - 4592C a c)x  - 8400B a c x
+--R         + 
+--R                      5           6  3          6 2          6
+--R           (- 21840A a c - 2240C a )x  - 3360B a x  - 6720A a x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + a
+--R     + 
+--R                6 14          6          5  13           5 12
+--R           15B c x   + (336A c  + 56C a c )x   + 420B a c x
+--R         + 
+--R                     5         2 4  11          2 4 10
+--R           (3864A a c  + 644C a c )x   + 2730B a c x
+--R         + 
+--R                    2 4          3 3  9          3 3 8
+--R           (16254A a c  + 2709C a c )x  + 7980B a c x
+--R         + 
+--R                    3 3          4 2  7           4 2 6
+--R           (34383A a c  + 5608C a c )x  + 12390B a c x
+--R         + 
+--R                    4 2          5   5           5   4
+--R           (40152A a c  + 5712C a c)x  + 10080B a c x
+--R         + 
+--R                    5           6  3          6 2          6
+--R           (25200A a c + 2240C a )x  + 3360B a x  + 6720A a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R               4 6 12        5 5 10         6 4 8         7 3 6         8 2 4
+--R           735a c x   + 8085a c x   + 31605a c x  + 60375a c x  + 61320a c x
+--R         + 
+--R                 9   2        10
+--R           31920a c x  + 6720a
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|a \|c x  + a
+--R     + 
+--R             4 7 14        5 6 12         6 5 10         7 4 8         8 3 6
+--R       - 105a c x   - 2940a c x   - 19110a c x   - 55860a c x  - 87465a c x
+--R     + 
+--R               9 2 4         10   2        11
+--R       - 76440a c x  - 35280a  c x  - 6720a
+--R                                         Type: Union(Expression(Integer),...)
+--E 232
+
+--S 233 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                         +--------+
+--R             3 6          2 4        2   2        3  +-+ |   2              3 6
+--R       (- B c x  - 24B a c x  - 80B a c x  - 64B a )\|a \|c x  + a  + 7B a c x
+--R     + 
+--R            2 2 4         3   2        4
+--R       56B a c x  + 112B a c x  + 64B a
+--R  /
+--R                                                  +--------+
+--R          4 4 6       5 3 4       6 2 2       7   |   2
+--R       (7a c x  + 168a c x  + 560a c x  + 448a c)\|c x  + a
+--R     + 
+--R             4 4 6       5 3 4       6 2 2       7   +-+
+--R       (- 49a c x  - 392a c x  - 784a c x  - 448a c)\|a
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 556
+t0:=(a+b*x+c*x^2)^3*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R        3 8       3         2  7       3                 2       2   6
+--R     C c x  + (B c  + 3C b c )x  + (A c  + (3B b + 3C a)c  + 3C b c)x
+--R   + 
+--R                    2        2                 3  5
+--R     ((3A b + 3B a)c  + (3B b  + 6C a b)c + C b )x
+--R   + 
+--R            2        2                2        3         2  4
+--R     (3A a c  + (3A b  + 6B a b + 3C a )c + B b  + 3C a b )x
+--R   + 
+--R                    2        3         2       2   3
+--R     ((6A a b + 3B a )c + A b  + 3B a b  + 3C a b)x
+--R   + 
+--R          2          2       2       3  2        2       3        3
+--R     (3A a c + 3A a b  + 3B a b + C a )x  + (3A a b + B a )x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 235
+
+--S 236 of 556
+r0:=a^3*A*x+1/2*a^2*(3*A*b+a*B)*x^2+1/3*a*(3*A*(b^2+a*c)+a*(3*b*B+a*C))*x^3+_
+   1/4*(A*(b^3+6*a*b*c)+3*a*(b^2*B+a*B*c+a*b*C))*x^4+1/5*(b^3*B+6*a*b*B*c+_
+   3*b^2*(A*c+a*C)+3*a*c*(A*c+a*C))*x^5+1/6*(3*b^2*B*c+3*a*B*c^2+b^3*C+_
+   3*b*c*(A*c+2*a*C))*x^6+1/7*c*(3*b*B*c+3*b^2*C+c*(A*c+3*a*C))*x^7+_
+   1/8*c^2*(B*c+3*b*C)*x^8+1/9*c^3*C*x^9
+--R 
+--R
+--R   (2)
+--R     1    3 9    1    3   3      2  8    1    3    3       3      2   3    2   7
+--R     - C c x  + (- B c  + - C b c )x  + (- A c  + (- B b + - C a)c  + - C b c)x
+--R     9           8        8              7         7       7          7
+--R   + 
+--R       1       1      2    1    2             1    3  6
+--R     ((- A b + - B a)c  + (- B b  + C a b)c + - C b )x
+--R       2       2           2                  6
+--R   + 
+--R      3      2    3    2   6         3    2     1    3   3      2  5
+--R     (- A a c  + (- A b  + - B a b + - C a )c + - B b  + - C a b )x
+--R      5           5        5         5          5        5
+--R   + 
+--R       3         3    2     1    3   3      2   3    2   4
+--R     ((- A a b + - B a )c + - A b  + - B a b  + - C a b)x
+--R       2         4          4        4          4
+--R   + 
+--R         2         2      2    1    3  3    3    2    1    3  2      3
+--R     (A a c + A a b  + B a b + - C a )x  + (- A a b + - B a )x  + A a x
+--R                               3            2         2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 236
+
+--S 237 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    3 9    1    3   3      2  8    1    3    3       3      2   3    2   7
+--R     - C c x  + (- B c  + - C b c )x  + (- A c  + (- B b + - C a)c  + - C b c)x
+--R     9           8        8              7         7       7          7
+--R   + 
+--R       1       1      2    1    2             1    3  6
+--R     ((- A b + - B a)c  + (- B b  + C a b)c + - C b )x
+--R       2       2           2                  6
+--R   + 
+--R      3      2    3    2   6         3    2     1    3   3      2  5
+--R     (- A a c  + (- A b  + - B a b + - C a )c + - B b  + - C a b )x
+--R      5           5        5         5          5        5
+--R   + 
+--R       3         3    2     1    3   3      2   3    2   4
+--R     ((- A a b + - B a )c + - A b  + - B a b  + - C a b)x
+--R       2         4          4        4          4
+--R   + 
+--R         2         2      2    1    3  3    3    2    1    3  2      3
+--R     (A a c + A a b  + B a b + - C a )x  + (- A a b + - B a )x  + A a x
+--R                               3            2         2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 237
+
+--S 238 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 238
+
+--S 239 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 239
+
+)clear all
+
+--S 240 of 556
+t0:=(a+b*x+c*x^2)^2*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R        2 6       2           5       2                       2  4
+--R     C c x  + (B c  + 2C b c)x  + (A c  + (2B b + 2C a)c + C b )x
+--R   + 
+--R                          2           3                2               2  2
+--R     ((2A b + 2B a)c + B b  + 2C a b)x  + (2A a c + A b  + 2B a b + C a )x
+--R   + 
+--R                  2        2
+--R     (2A a b + B a )x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 240
+
+--S 241 of 556
+r0:=a^2*A*x+1/2*a*(2*A*b+a*B)*x^2+1/3*(A*(b^2+2*a*c)+a*(2*b*B+a*C))*x^3+_
+   1/4*(b^2*B+2*a*B*c+2*b*(A*c+a*C))*x^4+1/5*(2*b*B*c+b^2*C+c*_
+   (A*c+2*a*C))*x^5+1/6*c*(B*c+2*b*C)*x^6+1/7*c^2*C*x^7
+--R 
+--R
+--R   (2)
+--R     1    2 7    1    2   1        6    1    2    2       2         1    2  5
+--R     - C c x  + (- B c  + - C b c)x  + (- A c  + (- B b + - C a)c + - C b )x
+--R     7           6        3             5         5       5         5
+--R   + 
+--R       1       1         1    2   1        4
+--R     ((- A b + - B a)c + - B b  + - C a b)x
+--R       2       2         4        2
+--R   + 
+--R      2         1    2   2         1    2  3            1    2  2      2
+--R     (- A a c + - A b  + - B a b + - C a )x  + (A a b + - B a )x  + A a x
+--R      3         3        3         3                    2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 241
+
+--S 242 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    2 7    1    2   1        6    1    2    2       2         1    2  5
+--R     - C c x  + (- B c  + - C b c)x  + (- A c  + (- B b + - C a)c + - C b )x
+--R     7           6        3             5         5       5         5
+--R   + 
+--R       1       1         1    2   1        4
+--R     ((- A b + - B a)c + - B b  + - C a b)x
+--R       2       2         4        2
+--R   + 
+--R      2         1    2   2         1    2  3            1    2  2      2
+--R     (- A a c + - A b  + - B a b + - C a )x  + (A a b + - B a )x  + A a x
+--R      3         3        3         3                    2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 242
+
+--S 243 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 243
+
+--S 244 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 244
+
+)clear all
+
+--S 245 of 556
+t0:=(a+b*x+c*x^2)*(A+B*x+C*x^2)
+--R 
+--R
+--R             4               3                     2
+--R   (1)  C c x  + (B c + C b)x  + (A c + B b + C a)x  + (A b + B a)x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 245
+
+--S 246 of 556
+r0:=a*A*x+1/2*(A*b+a*B)*x^2+1/3*(b*B+A*c+a*C)*x^3+1/4*(B*c+b*C)*x^4+1/5*c*C*x^5
+--R 
+--R
+--R   (2)
+--R     1      5    1       1      4    1       1       1      3
+--R     - C c x  + (- B c + - C b)x  + (- A c + - B b + - C a)x
+--R     5           4       4           3       3       3
+--R   + 
+--R      1       1      2
+--R     (- A b + - B a)x  + A a x
+--R      2       2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 246
+
+--S 247 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1      5    1       1      4    1       1       1      3
+--R     - C c x  + (- B c + - C b)x  + (- A c + - B b + - C a)x
+--R     5           4       4           3       3       3
+--R   + 
+--R      1       1      2
+--R     (- A b + - B a)x  + A a x
+--R      2       2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 247
+
+--S 248 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 248
+
+--S 249 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 249
+
+)clear all
+
+--S 250 of 556
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)
+--R 
+--R
+--R           2
+--R        C x  + B x + A
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 250
+
+--S 251 of 556
+r0:=C*x/c+1/2*(B*c-b*C)*log(a+b*x+c*x^2)/c^2+(b*B*c-b^2*C-2*c*(A*c-a*C))*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R              2                        2          2c x + b
+--R       (- 4A c  + (2B b + 4C a)c - 2C b )atanh(--------------)
+--R                                                +-----------+
+--R                                                |          2
+--R                                               \|- 4a c + b
+--R     + 
+--R                                                 +-----------+
+--R                          2                      |          2
+--R       ((B c - C b)log(c x  + b x + a) + 2C c x)\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2                        2
+--R           (2A c  + (- B b - 2C a)c + C b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                                   +-----------+
+--R                            2                      |          2
+--R         ((B c - C b)log(c x  + b x + a) + 2C c x)\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         2 |          2
+--R       2c \|- 4a c + b
+--R     ,
+--R
+--R                                                           +---------+
+--R                                                           |        2
+--R              2                          2      (2c x + b)\|4a c - b
+--R         (4A c  + (- 2B b - 4C a)c + 2C b )atan(----------------------)
+--R                                                               2
+--R                                                       4a c - b
+--R       + 
+--R                                                   +---------+
+--R                            2                      |        2
+--R         ((B c - C b)log(c x  + b x + a) + 2C c x)\|4a c - b
+--R    /
+--R           +---------+
+--R         2 |        2
+--R       2c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 252
+
+--S 253 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2                        2
+--R         (2A c  + (- B b - 2C a)c + C b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R            2                          2          2c x + b
+--R       (4A c  + (- 2B b - 4C a)c + 2C b )atanh(--------------)
+--R                                                +-----------+
+--R                                                |          2
+--R                                               \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                        +---------+
+--R            2                        2  |        2          2c x + b
+--R       (2A c  + (- B b - 2C a)c + C b )\|4a c - b  atanh(--------------)
+--R                                                          +-----------+
+--R                                                          |          2
+--R                                                         \|- 4a c + b
+--R     + 
+--R                                                                   +---------+
+--R                                      +-----------+                |        2
+--R          2                        2  |          2      (2c x + b)\|4a c - b
+--R     (2A c  + (- B b - 2C a)c + C b )\|- 4a c + b  atan(----------------------)
+--R                                                                       2
+--R                                                               4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      2 |          2  |        2
+--R     c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 255
+
+--S 256 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 256
+
+)clear all
+
+--S 257 of 556
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^2
+--R 
+--R
+--R                          2
+--R                       C x  + B x + A
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 257
+
+--S 258 of 556
+r0:=(-A*b*c+2*a*B*c-a*b*C+(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2))-2*(b*B-2*A*c-2*a*C)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                  3                 2  2            2        2
+--R           (- 4A c  + (2B b - 4C a)c )x  + (- 4A b c  + (2B b  - 4C a b)c)x
+--R         + 
+--R                   2                 2
+--R           - 4A a c  + (2B a b - 4C a )c
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                                 +-----------+
+--R           2                        2                            |          2
+--R     ((2A c  + (- B b - 2C a)c + C b )x + (A b - 2B a)c + C a b)\|- 4a c + b
+--R  /
+--R                                                           +-----------+
+--R           3    2 2  2          2    3        2 2      2   |          2
+--R     ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 258
+
+--S 259 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3                  2  2          2         2
+--R             (2A c  + (- B b + 2C a)c )x  + (2A b c  + (- B b  + 2C a b)c)x
+--R           + 
+--R                   2                  2
+--R             2A a c  + (- B a b + 2C a )c
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                                                   +-----------+
+--R             2                        2                            |          2
+--R       ((2A c  + (- B b - 2C a)c + C b )x + (A b - 2B a)c + C a b)\|- 4a c + b
+--R    /
+--R                                                             +-----------+
+--R             3    2 2  2          2    3        2 2      2   |          2
+--R       ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|- 4a c + b
+--R     ,
+--R
+--R                  3                   2  2          2          2
+--R             (4A c  + (- 2B b + 4C a)c )x  + (4A b c  + (- 2B b  + 4C a b)c)x
+--R           + 
+--R                   2                   2
+--R             4A a c  + (- 2B a b + 4C a )c
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                                                                   +---------+
+--R             2                        2                            |        2
+--R       ((2A c  + (- B b - 2C a)c + C b )x + (A b - 2B a)c + C a b)\|4a c - b
+--R    /
+--R                                                             +---------+
+--R             3    2 2  2          2    3        2 2      2   |        2
+--R       ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 259
+
+--S 260 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (2A c - B b + 2C a)
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                                    2c x + b
+--R       (4A c - 2B b + 4C a)atanh(--------------)
+--R                                  +-----------+
+--R                                  |          2
+--R                                 \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R              2  |          2
+--R     (4a c - b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                            +---------+
+--R                            |        2          2c x + b
+--R       (4A c - 2B b + 4C a)\|4a c - b  atanh(--------------)
+--R                                              +-----------+
+--R                                              |          2
+--R                                             \|- 4a c + b
+--R     + 
+--R                                                         +---------+
+--R                            +-----------+                |        2
+--R                            |          2      (2c x + b)\|4a c - b
+--R       (4A c - 2B b + 4C a)\|- 4a c + b  atan(----------------------)
+--R                                                             2
+--R                                                     4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 263
+
+)clear all
+
+--S 264 of 556
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + B x + A
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 264
+
+--S 265 of 556
+r0:=1/2*(-A*b*c+2*a*B*c-a*b*C+(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/_
+   (c*(b^2-4*a*c)*(a+b*x+c*x^2)^2)-1/2*(3*b*B*c-b^2*C-2*c*(3*A*c+a*C))*_
+   (b+2*c*x)/(c*(b^2-4*a*c)^2*(a+b*x+c*x^2))+2*(3*b*B*c-b^2*C-_
+   2*c*(3*A*c+a*C))*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                   4                  3       2 2  4
+--R           (- 24A c  + (12B b - 8C a)c  - 4C b c )x
+--R         + 
+--R                     3         2            2       3   3
+--R           (- 48A b c  + (24B b  - 16C a b)c  - 8C b c)x
+--R         + 
+--R                        3           2                  2  2
+--R               - 48A a c  + (- 24A b  + 24B a b - 16C a )c
+--R             + 
+--R                     3          2         4
+--R               (12B b  - 16C a b )c - 4C b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       2           2        2            3          2 2
+--R           (- 48A a b c  + (24B a b  - 16C a b)c - 8C a b )x - 24A a c
+--R         + 
+--R                 2        3         2 2
+--R           (12B a b - 8C a )c - 4C a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 3                   2       2   3
+--R           (12A c  + (- 6B b + 4C a)c  + 2C b c)x
+--R         + 
+--R                   2          2                  3  2
+--R           (18A b c  + (- 9B b  + 6C a b)c + 3C b )x
+--R         + 
+--R                   2        2                 2         3          2
+--R           (20A a c  + (4A b  - 10B a b - 4C a )c - 2B b  + 10C a b )x
+--R         + 
+--R                          2        3        2       2
+--R           (10A a b - 8B a )c - A b  - B a b  + 6C a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   4                   3       2 2  4
+--R             (12A c  + (- 6B b + 4C a)c  + 2C b c )x
+--R           + 
+--R                     3           2           2       3   3
+--R             (24A b c  + (- 12B b  + 8C a b)c  + 4C b c)x
+--R           + 
+--R                        3         2                 2  2          3         2
+--R                 24A a c  + (12A b  - 12B a b + 8C a )c  + (- 6B b  + 8C a b )c
+--R               + 
+--R                     4
+--R                 2C b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2             2       2            3          2 2
+--R             (24A a b c  + (- 12B a b  + 8C a b)c + 4C a b )x + 12A a c
+--R           + 
+--R                    2        3         2 2
+--R             (- 6B a b + 4C a )c + 2C a b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                   3                   2       2   3
+--R             (12A c  + (- 6B b + 4C a)c  + 2C b c)x
+--R           + 
+--R                     2          2                  3  2
+--R             (18A b c  + (- 9B b  + 6C a b)c + 3C b )x
+--R           + 
+--R                     2        2                 2         3          2
+--R             (20A a c  + (4A b  - 10B a b - 4C a )c - 2B b  + 10C a b )x
+--R           + 
+--R                            2        3        2       2
+--R             (10A a b - 8B a )c - A b  - B a b  + 6C a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  4       2   3        3 2     5   3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R         + 
+--R               3 3        4      6  2       3   2      2 3        5        4 2
+--R           (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                3 2      2 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   4                    3       2 2  4
+--R             (24A c  + (- 12B b + 8C a)c  + 4C b c )x
+--R           + 
+--R                     3           2            2       3   3
+--R             (48A b c  + (- 24B b  + 16C a b)c  + 8C b c)x
+--R           + 
+--R                        3         2                  2  2
+--R                 48A a c  + (24A b  - 24B a b + 16C a )c
+--R               + 
+--R                         3          2         4
+--R                 (- 12B b  + 16C a b )c + 4C b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2             2        2            3          2 2
+--R             (48A a b c  + (- 24B a b  + 16C a b)c + 8C a b )x + 24A a c
+--R           + 
+--R                     2        3         2 2
+--R             (- 12B a b + 8C a )c + 4C a b
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                   3                   2       2   3
+--R             (12A c  + (- 6B b + 4C a)c  + 2C b c)x
+--R           + 
+--R                     2          2                  3  2
+--R             (18A b c  + (- 9B b  + 6C a b)c + 3C b )x
+--R           + 
+--R                     2        2                 2         3          2
+--R             (20A a c  + (4A b  - 10B a b - 4C a )c - 2B b  + 10C a b )x
+--R           + 
+--R                            2        3        2       2
+--R             (10A a b - 8B a )c - A b  - B a b  + 6C a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 4        2 3     4 2  4       2   3        3 2     5   3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R         + 
+--R               3 3        4      6  2       3   2      2 3        5        4 2
+--R           (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                3 2      2 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 266
+
+--S 267 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2                         2
+--R         (6A c  + (- 3B b + 2C a)c + C b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R             2                          2          2c x + b
+--R       (12A c  + (- 6B b + 4C a)c + 2C b )atanh(--------------)
+--R                                                 +-----------+
+--R                                                 |          2
+--R                                                \|- 4a c + b
+--R  /
+--R                            +-----------+
+--R         2 2       2     4  |          2
+--R     (16a c  - 8a b c + b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                           +---------+
+--R             2                          2  |        2          2c x + b
+--R       (12A c  + (- 6B b + 4C a)c + 2C b )\|4a c - b  atanh(--------------)
+--R                                                             +-----------+
+--R                                                             |          2
+--R                                                            \|- 4a c + b
+--R     + 
+--R                                             +-----------+
+--R               2                          2  |          2
+--R         (12A c  + (- 6B b + 4C a)c + 2C b )\|- 4a c + b
+--R      *
+--R                         +---------+
+--R                         |        2
+--R              (2c x + b)\|4a c - b
+--R         atan(----------------------)
+--R                             2
+--R                     4a c - b
+--R  /
+--R                            +-----------+ +---------+
+--R         2 2       2     4  |          2  |        2
+--R     (16a c  - 8a b c + b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 556
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^4
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + B x + A
+--R  /
+--R        4 8       3 7        3     2 2  6           2     3   5
+--R       c x  + 4b c x  + (4a c  + 6b c )x  + (12a b c  + 4b c)x
+--R     + 
+--R          2 2        2     4  4       2          3  3      3      2 2  2
+--R       (6a c  + 12a b c + b )x  + (12a b c + 4a b )x  + (4a c + 6a b )x
+--R     + 
+--R         3       4
+--R       4a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 271
+
+--S 272 of 556
+r0:=1/3*(-A*b*c+2*a*B*c-a*b*C+(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/_
+   (c*(b^2-4*a*c)*(a+b*x+c*x^2)^3)-1/6*(5*b*B*c-2*b^2*C-2*c*(5*A*c+a*C))*_
+   (b+2*c*x)/(c*(b^2-4*a*c)^2*(a+b*x+c*x^2)^2)+(5*b*B*c-2*b^2*C-_
+   2*c*(5*A*c+a*C))*(b+2*c*x)/((b^2-4*a*c)^3*(a+b*x+c*x^2))-_
+   4*c*(5*b*B*c-2*b^2*C-2*c*(5*A*c+a*C))*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(7/2)
+--R 
+--R
+--R   (2)
+--R                    6                    5        2 4  6
+--R           (- 240A c  + (120B b - 48C a)c  - 48C b c )x
+--R         + 
+--R                      5          2             4         3 3  5
+--R           (- 720A b c  + (360B b  - 144C a b)c  - 144C b c )x
+--R         + 
+--R                         5            2                    2  4
+--R               - 720A a c  + (- 720A b  + 360B a b - 144C a )c
+--R             + 
+--R                      3           2  3         4 2
+--R               (360B b  - 288C a b )c  - 144C b c
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                            4            3           2         2   3
+--R               - 1440A a b c  + (- 240A b  + 720B a b  - 288C a b)c
+--R             + 
+--R                      4           3  2        5
+--R               (120B b  - 336C a b )c  - 48C b c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       2 4              2         2          3  3
+--R               - 720A a c  + (- 720A a b  + 360B a b - 144C a )c
+--R             + 
+--R                        3         2 2  2           4
+--R               (360B a b  - 288C a b )c  - 144C a b c
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    2   3          2 2         3   2         2 3            3 3
+--R           (- 720A a b c  + (360B a b  - 144C a b)c  - 144C a b c)x - 240A a c
+--R         + 
+--R                  3         4  2        3 2
+--R           (120B a b - 48C a )c  - 48C a b c
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                  5                     4        2 3  5
+--R           (120A c  + (- 60B b + 24C a)c  + 24C b c )x
+--R         + 
+--R                    4            2            3        3 2  4
+--R           (300A b c  + (- 150B b  + 60C a b)c  + 60C b c )x
+--R         + 
+--R                       4          2                   2  3
+--R               320A a c  + (220A b  - 160B a b + 64C a )c
+--R             + 
+--R                        3           2  2        4
+--R               (- 110B b  + 108C a b )c  + 44C b c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                         3         3           2        2   2
+--R               480A a b c  + (30A b  - 240B a b  + 96C a b)c
+--R             + 
+--R                       4           3         5
+--R               (- 15B b  + 102C a b )c + 6C b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     2 3            2         2         3  2
+--R               264A a c  + (108A a b  - 132B a b - 24C a )c
+--R             + 
+--R                      4          3         2 2         5         4
+--R               (- 6A b  - 54B a b  + 132C a b )c + 3B b  + 6C a b
+--R          *
+--R             x
+--R         + 
+--R                  2         3  2             3        2 2        3          5
+--R           (132A a b - 64B a )c  + (- 26A a b  - 18B a b  + 52C a b)c + 2A b
+--R         + 
+--R                4       2 3
+--R           B a b  + 2C a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              3 6       2 2 5        4 4     6 3  6
+--R         (384a c  - 288a b c  + 72a b c  - 6b c )x
+--R       + 
+--R               3   5       2 3 4         5 3      7 2  5
+--R         (1152a b c  - 864a b c  + 216a b c  - 18b c )x
+--R       + 
+--R               4 5       3 2 4       2 4 3         6 2      8   4
+--R         (1152a c  + 288a b c  - 648a b c  + 198a b c  - 18b c)x
+--R       + 
+--R               4   4        3 3 3       2 5 2        7      9  3
+--R         (2304a b c  - 1344a b c  + 144a b c  + 36a b c - 6b )x
+--R       + 
+--R               5 4       4 2 3       3 4 2       2 6         8  2
+--R         (1152a c  + 288a b c  - 648a b c  + 198a b c - 18a b )x
+--R       + 
+--R               5   3       4 3 2       3 5       2 7         6 3       5 2 2
+--R         (1152a b c  - 864a b c  + 216a b c - 18a b )x + 384a c  - 288a b c
+--R       + 
+--R            4 4      3 6
+--R         72a b c - 6a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    6                     5        2 4  6
+--R             (120A c  + (- 60B b + 24C a)c  + 24C b c )x
+--R           + 
+--R                      5            2            4        3 3  5
+--R             (360A b c  + (- 180B b  + 72C a b)c  + 72C b c )x
+--R           + 
+--R                         5          2                   2  4
+--R                 360A a c  + (360A b  - 180B a b + 72C a )c
+--R               + 
+--R                          3           2  3        4 2
+--R                 (- 180B b  + 144C a b )c  + 72C b c
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           4          3           2         2   3
+--R                 720A a b c  + (120A b  - 360B a b  + 144C a b)c
+--R               + 
+--R                         4           3  2        5
+--R                 (- 60B b  + 168C a b )c  + 24C b c
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       2 4            2         2         3  3
+--R                 360A a c  + (360A a b  - 180B a b + 72C a )c
+--R               + 
+--R                            3         2 2  2          4
+--R                 (- 180B a b  + 144C a b )c  + 72C a b c
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    2   3            2 2        3   2        2 3            3 3
+--R             (360A a b c  + (- 180B a b  + 72C a b)c  + 72C a b c)x + 120A a c
+--R           + 
+--R                     3         4  2        3 2
+--R             (- 60B a b + 24C a )c  + 24C a b c
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                    5                     4        2 3  5
+--R             (120A c  + (- 60B b + 24C a)c  + 24C b c )x
+--R           + 
+--R                      4            2            3        3 2  4
+--R             (300A b c  + (- 150B b  + 60C a b)c  + 60C b c )x
+--R           + 
+--R                         4          2                   2  3
+--R                 320A a c  + (220A b  - 160B a b + 64C a )c
+--R               + 
+--R                          3           2  2        4
+--R                 (- 110B b  + 108C a b )c  + 44C b c
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                           3         3           2        2   2
+--R                 480A a b c  + (30A b  - 240B a b  + 96C a b)c
+--R               + 
+--R                         4           3         5
+--R                 (- 15B b  + 102C a b )c + 6C b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2 3            2         2         3  2
+--R                 264A a c  + (108A a b  - 132B a b - 24C a )c
+--R               + 
+--R                        4          3         2 2         5         4
+--R                 (- 6A b  - 54B a b  + 132C a b )c + 3B b  + 6C a b
+--R            *
+--R               x
+--R           + 
+--R                    2         3  2             3        2 2        3          5
+--R             (132A a b - 64B a )c  + (- 26A a b  - 18B a b  + 52C a b)c + 2A b
+--R           + 
+--R                  4       2 3
+--R             B a b  + 2C a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                3 6       2 2 5        4 4     6 3  6
+--R           (384a c  - 288a b c  + 72a b c  - 6b c )x
+--R         + 
+--R                 3   5       2 3 4         5 3      7 2  5
+--R           (1152a b c  - 864a b c  + 216a b c  - 18b c )x
+--R         + 
+--R                 4 5       3 2 4       2 4 3         6 2      8   4
+--R           (1152a c  + 288a b c  - 648a b c  + 198a b c  - 18b c)x
+--R         + 
+--R                 4   4        3 3 3       2 5 2        7      9  3
+--R           (2304a b c  - 1344a b c  + 144a b c  + 36a b c - 6b )x
+--R         + 
+--R                 5 4       4 2 3       3 4 2       2 6         8  2
+--R           (1152a c  + 288a b c  - 648a b c  + 198a b c - 18a b )x
+--R         + 
+--R                 5   3       4 3 2       3 5       2 7         6 3       5 2 2
+--R           (1152a b c  - 864a b c  + 216a b c - 18a b )x + 384a c  - 288a b c
+--R         + 
+--R              4 4      3 6
+--R           72a b c - 6a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    6                      5        2 4  6
+--R             (240A c  + (- 120B b + 48C a)c  + 48C b c )x
+--R           + 
+--R                      5            2             4         3 3  5
+--R             (720A b c  + (- 360B b  + 144C a b)c  + 144C b c )x
+--R           + 
+--R                         5          2                    2  4
+--R                 720A a c  + (720A b  - 360B a b + 144C a )c
+--R               + 
+--R                          3           2  3         4 2
+--R                 (- 360B b  + 288C a b )c  + 144C b c
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            4          3           2         2   3
+--R                 1440A a b c  + (240A b  - 720B a b  + 288C a b)c
+--R               + 
+--R                          4           3  2        5
+--R                 (- 120B b  + 336C a b )c  + 48C b c
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       2 4            2         2          3  3
+--R                 720A a c  + (720A a b  - 360B a b + 144C a )c
+--R               + 
+--R                            3         2 2  2           4
+--R                 (- 360B a b  + 288C a b )c  + 144C a b c
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    2   3            2 2         3   2         2 3
+--R             (720A a b c  + (- 360B a b  + 144C a b)c  + 144C a b c)x
+--R           + 
+--R                   3 3            3         4  2        3 2
+--R             240A a c  + (- 120B a b + 48C a )c  + 48C a b c
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                    5                     4        2 3  5
+--R             (120A c  + (- 60B b + 24C a)c  + 24C b c )x
+--R           + 
+--R                      4            2            3        3 2  4
+--R             (300A b c  + (- 150B b  + 60C a b)c  + 60C b c )x
+--R           + 
+--R                         4          2                   2  3
+--R                 320A a c  + (220A b  - 160B a b + 64C a )c
+--R               + 
+--R                          3           2  2        4
+--R                 (- 110B b  + 108C a b )c  + 44C b c
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                           3         3           2        2   2
+--R                 480A a b c  + (30A b  - 240B a b  + 96C a b)c
+--R               + 
+--R                         4           3         5
+--R                 (- 15B b  + 102C a b )c + 6C b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2 3            2         2         3  2
+--R                 264A a c  + (108A a b  - 132B a b - 24C a )c
+--R               + 
+--R                        4          3         2 2         5         4
+--R                 (- 6A b  - 54B a b  + 132C a b )c + 3B b  + 6C a b
+--R            *
+--R               x
+--R           + 
+--R                    2         3  2             3        2 2        3          5
+--R             (132A a b - 64B a )c  + (- 26A a b  - 18B a b  + 52C a b)c + 2A b
+--R           + 
+--R                  4       2 3
+--R             B a b  + 2C a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                3 6       2 2 5        4 4     6 3  6
+--R           (384a c  - 288a b c  + 72a b c  - 6b c )x
+--R         + 
+--R                 3   5       2 3 4         5 3      7 2  5
+--R           (1152a b c  - 864a b c  + 216a b c  - 18b c )x
+--R         + 
+--R                 4 5       3 2 4       2 4 3         6 2      8   4
+--R           (1152a c  + 288a b c  - 648a b c  + 198a b c  - 18b c)x
+--R         + 
+--R                 4   4        3 3 3       2 5 2        7      9  3
+--R           (2304a b c  - 1344a b c  + 144a b c  + 36a b c - 6b )x
+--R         + 
+--R                 5 4       4 2 3       3 4 2       2 6         8  2
+--R           (1152a c  + 288a b c  - 648a b c  + 198a b c - 18a b )x
+--R         + 
+--R                 5   3       4 3 2       3 5       2 7         6 3       5 2 2
+--R           (1152a b c  - 864a b c  + 216a b c - 18a b )x + 384a c  - 288a b c
+--R         + 
+--R              4 4      3 6
+--R           72a b c - 6a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 273
+
+--S 274 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               3                    2       2
+--R         (20A c  + (- 10B b + 4C a)c  + 4C b c)
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R             3                    2       2           2c x + b
+--R       (40A c  + (- 20B b + 8C a)c  + 8C b c)atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R  /
+--R                                        +-----------+
+--R         3 3      2 2 2        4     6  |          2
+--R     (64a c  - 48a b c  + 12a b c - b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                              +---------+
+--R             3                    2       2   |        2          2c x + b
+--R       (40A c  + (- 20B b + 8C a)c  + 8C b c)\|4a c - b  atanh(--------------)
+--R                                                                +-----------+
+--R                                                                |          2
+--R                                                               \|- 4a c + b
+--R     + 
+--R                                                +-----------+
+--R               3                    2       2   |          2
+--R         (40A c  + (- 20B b + 8C a)c  + 8C b c)\|- 4a c + b
+--R      *
+--R                         +---------+
+--R                         |        2
+--R              (2c x + b)\|4a c - b
+--R         atan(----------------------)
+--R                             2
+--R                     4a c - b
+--R  /
+--R                                        +-----------+ +---------+
+--R         3 3      2 2 2        4     6  |          2  |        2
+--R     (64a c  - 48a b c  + 12a b c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 277
+
+)clear all
+
+--S 278 of 556
+t0:=(-4+3*x+x^2)/(-8-2*x+x^2)
+--R 
+--R
+--R         2
+--R        x  + 3x - 4
+--R   (1)  -----------
+--R         2
+--R        x  - 2x - 8
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 278
+
+--S 279 of 556
+r0:=x+4*log(4-x)+log(2+x)
+--R 
+--R
+--R   (2)  log(x + 2) + 4log(- x + 4) + x
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  log(x + 2) + 4log(x - 4) + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 280
+
+--S 281 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  4log(x - 4) - 4log(- x + 4)
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 556
+t0:=(7+5*x+4*x^2)/(5+4*x+4*x^2)
+--R 
+--R
+--R          2
+--R        4x  + 5x + 7
+--R   (1)  ------------
+--R          2
+--R        4x  + 4x + 5
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 283
+
+--S 284 of 556
+r0:=x+3/8*atan(1/2+x)+1/8*log(5+4*x+4*x^2)
+--R 
+--R
+--R              2                   2x + 1
+--R        log(4x  + 4x + 5) + 3atan(------) + 8x
+--R                                     2
+--R   (2)  --------------------------------------
+--R                           8
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                   2x + 1
+--R        log(4x  + 4x + 5) + 3atan(------) + 8x
+--R                                     2
+--R   (3)  --------------------------------------
+--R                           8
+--R                                         Type: Union(Expression(Integer),...)
+--E 285
+
+--S 286 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 287
+
+)clear all
+
+--S 288 of 556
+t0:=(2-x+x^2)/(-5+2*x+x^2)
+--R 
+--R
+--R          2
+--R         x  - x + 2
+--R   (1)  -----------
+--R         2
+--R        x  + 2x - 5
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 288
+
+--S 289 of 556
+r0:=x-1/6*log(1+x-sqrt(6))*(9-5*sqrt(6))-1/6*log(1+x+sqrt(6))*(9+5*sqrt(6))
+--R 
+--R
+--R             +-+          +-+               +-+            +-+
+--R        (- 5\|6  - 9)log(\|6  + x + 1) + (5\|6  - 9)log(- \|6  + x + 1) + 6x
+--R   (2)  --------------------------------------------------------------------
+--R                                          6
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2           +-+              +-+
+--R     +-+    (x  + 2x + 7)\|3  + (- 6x - 6)\|2       +-+     2                +-+
+--R   5\|2 log(----------------------------------) - 3\|3 log(x  + 2x - 5) + 2x\|3
+--R                         2
+--R                        x  + 2x - 5
+--R   -----------------------------------------------------------------------------
+--R                                         +-+
+--R                                       2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 290
+
+--S 291 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+     +-+      +-+
+--R       (5\|3 \|6  + 9\|3 )log(\|6  + x + 1)
+--R     + 
+--R                   2           +-+              +-+
+--R          +-+    (x  + 2x + 7)\|3  + (- 6x - 6)\|2       +-+     2
+--R       15\|2 log(----------------------------------) - 9\|3 log(x  + 2x - 5)
+--R                              2
+--R                             x  + 2x - 5
+--R     + 
+--R            +-+ +-+     +-+        +-+
+--R       (- 5\|3 \|6  + 9\|3 )log(- \|6  + x + 1)
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 292
+
+)clear all
+
+--S 293 of 556
+t0:=(1+4*x+3*x^2)/(4+7*x+2*x^2)^2
+--R 
+--R
+--R                  2
+--R                3x  + 4x + 1
+--R   (1)  ----------------------------
+--R          4      3      2
+--R        4x  + 28x  + 65x  + 56x + 16
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 293
+
+--S 294 of 556
+r0:=1/2*(-2-3*x)/(4+7*x+2*x^2)
+--R 
+--R
+--R            3     1
+--R          - - x - -
+--R            4     2
+--R   (2)  ------------
+--R         2   7
+--R        x  + - x + 2
+--R             2
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 294
+
+--S 295 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R           - 3x - 2
+--R   (3)  -------------
+--R          2
+--R        4x  + 14x + 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 295
+
+--S 296 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 556
+t0:=(1+x+x^2)/(3+2*x+x^2)^2
+--R 
+--R
+--R                 2
+--R                x  + x + 1
+--R   (1)  -------------------------
+--R         4     3      2
+--R        x  + 4x  + 10x  + 12x + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 298
+
+--S 299 of 556
+r0:=1/4*(1-x)/(3+2*x+x^2)+3/4*atan((1+x)/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                   +-+
+--R           2               (x + 1)\|2               +-+
+--R        (3x  + 6x + 9)atan(-----------) + (- x + 1)\|2
+--R                                2
+--R   (2)  -----------------------------------------------
+--R                         2            +-+
+--R                      (4x  + 8x + 12)\|2
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   +-+
+--R           2               (x + 1)\|2               +-+
+--R        (3x  + 6x + 9)atan(-----------) + (- x + 1)\|2
+--R                                2
+--R   (3)  -----------------------------------------------
+--R                         2            +-+
+--R                      (4x  + 8x + 12)\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 300
+
+--S 301 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 302
+
+)clear all
+
+--S 303 of 556
+t0:=(-1+2*x+5*x^2)/(1+x+x^2)^4
+--R 
+--R
+--R                              2
+--R                            5x  + 2x - 1
+--R   (1)  ----------------------------------------------------
+--R         8     7      6      5      4      3      2
+--R        x  + 4x  + 10x  + 16x  + 19x  + 16x  + 10x  + 4x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 303
+
+--S 304 of 556
+r0:=-x/(1+x+x^2)^3
+--R 
+--R
+--R                           x
+--R   (2)  - -----------------------------------
+--R           6     5     4     3     2
+--R          x  + 3x  + 6x  + 7x  + 6x  + 3x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 304
+
+--S 305 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           x
+--R   (3)  - -----------------------------------
+--R           6     5     4     3     2
+--R          x  + 3x  + 6x  + 7x  + 6x  + 3x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 305
+
+--S 306 of 556
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 556
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 307
+
+)clear all
+
+--S 308 of 556
+t0:=(a+b*x+c*x^2)^(5/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R          2 6       2           5       2                       2  4
+--R       C c x  + (B c  + 2C b c)x  + (A c  + (2B b + 2C a)c + C b )x
+--R     + 
+--R                            2           3                2               2  2
+--R       ((2A b + 2B a)c + B b  + 2C a b)x  + (2A a c + A b  + 2B a b + C a )x
+--R     + 
+--R                    2        2
+--R       (2A a b + B a )x + A a
+--R  *
+--R      +--------------+
+--R      |   2
+--R     \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 556
+r0:=5/6144*(b^2-4*a*c)*(16*b*B*c-9*b^2*C-4*c*(8*A*c-a*C))*(b+2*c*x)*_
+   (a+b*x+c*x^2)^(3/2)/c^4-1/384*(16*b*B*c-32*A*c^2-9*b^2*C+4*a*c*C)*_
+   (b+2*c*x)*(a+b*x+c*x^2)^(5/2)/c^3+1/112*(16*B*c-9*b*C+14*c*C*x)*_
+   (a+b*x+c*x^2)^(7/2)/c^2+5/32768*(b^2-4*a*c)^3*(16*b*B*c-9*b^2*C-4*c*_
+   (8*A*c-a*C))*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/c^(11/2)-_
+   5/16384*(b^2-4*a*c)^2*(16*b*B*c-9*b^2*C-4*c*(8*A*c-a*C))*_
+   (b+2*c*x)*sqrt(a+b*x+c*x^2)/c^5
+--R 
+--R
+--R   (2)
+--R                    3 5               2 2            3            4  4
+--R           215040A a c  + (- 161280A a b  - 107520B a b - 26880C a )c
+--R         + 
+--R                      4           2 3           3 2  3
+--R           (40320A a b  + 80640B a b  + 80640C a b )c
+--R         + 
+--R                     6             5           2 4  2
+--R           (- 3360A b  - 20160B a b  - 50400C a b )c
+--R         + 
+--R                   7             6           8
+--R           (1680B b  + 11760C a b )c - 945C b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                   7 7            7              6  6
+--R           86016C c x  + (98304B c  + 202752C b c )x
+--R         + 
+--R                     7                           6            2 5  5
+--R           (114688A c  + (237568B b + 243712C a)c  + 124416C b c )x
+--R         + 
+--R                                       6             2                5
+--R               (286720A b + 294912B a)c  + (151552B b  + 314368C a b)c
+--R             + 
+--R                     3 4
+--R               768C b c
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          6             2                          2  5
+--R               372736A a c  + (193536A b  + 403456B a b + 211456C a )c
+--R             + 
+--R                       3            2  4         4 3
+--R               (1536B b  + 6912C a b )c  - 864C b c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                                       2  5
+--R               (559104A a b + 294912B a )c
+--R             + 
+--R                       3             2           2   4
+--R               (3584A b  + 15360B a b  + 22272C a b)c
+--R             + 
+--R                         4            3  3          5 2
+--R               (- 1792B b  - 9088C a b )c  + 1008C b c
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        2 5              2           2            3  4
+--R               473088A a c  + (43008A a b  + 58368B a b + 26880C a )c
+--R             + 
+--R                         4             3           2 2  3
+--R               (- 4480A b  - 21504B a b  - 38208C a b )c
+--R             + 
+--R                       5             4  2          6
+--R               (2240B b  + 12656C a b )c  - 1260C b c
+--R          *
+--R             x
+--R         + 
+--R                     2            3  4
+--R           (236544A a b + 98304B a )c
+--R         + 
+--R                        3            2 2           3   3
+--R           (- 71680A a b  - 118272B a b  - 84864C a b)c
+--R         + 
+--R                   5             4           2 3  2
+--R           (6720A b  + 35840B a b  + 75488C a b )c
+--R         + 
+--R                     6             5            7
+--R           (- 3360B b  - 21000C a b )c + 1890C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R            5 +-+
+--R     688128c \|c
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 556
+--a0:=integrate(t0,x)
+--E 310
+
+--S 311 of 556
+--m0:=a0-r0
+--E 311
+
+--S 312 of 556
+--d0:=D(m0,x)
+--E 312
+
+)clear all
+
+--S 313 of 556
+t0:=(a+b*x+c*x^2)^(3/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R           4               3                     2
+--R     (C c x  + (B c + C b)x  + (A c + B b + C a)x  + (A b + B a)x + A a)
+--R  *
+--R      +--------------+
+--R      |   2
+--R     \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 556
+r0:=-1/192*(12*b*B*c-24*A*c^2-7*b^2*C+4*a*c*C)*(b+2*c*x)*_
+   (a+b*x+c*x^2)^(3/2)/c^3+1/60*(12*B*c-7*b*C+10*c*C*x)*_
+   (a+b*x+c*x^2)^(5/2)/c^2-1/1024*(b^2-4*a*c)^2*(12*b*B*c-7*b^2*C-_
+   4*c*(6*A*c-a*C))*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   c^(9/2)+1/512*(b^2-4*a*c)*(12*b*B*c-7*b^2*C-4*c*(6*A*c-a*C))*_
+   (b+2*c*x)*sqrt(a+b*x+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R                  2 4               2          2          3  3
+--R           5760A a c  + (- 2880A a b  - 2880B a b - 960C a )c
+--R         + 
+--R                  4            3          2 2  2            5           4
+--R           (360A b  + 1440B a b  + 2160C a b )c  + (- 180B b  - 900C a b )c
+--R         + 
+--R                 6
+--R           105C b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                  5 5           5            4  4
+--R           2560C c x  + (3072B c  + 3328C b c )x
+--R         + 
+--R                   5                       4        2 3  3
+--R           (3840A c  + (4224B b + 4480C a)c  + 96C b c )x
+--R         + 
+--R                                4          2             3         3 2  2
+--R           ((5760A b + 6144B a)c  + (192B b  + 576C a b)c  - 112C b c )x
+--R         + 
+--R                        4          2                     2  3
+--R               9600A a c  + (480A b  + 1344B a b + 960C a )c
+--R             + 
+--R                        3           2  2         4
+--R               (- 240B b  - 864C a b )c  + 140C b c
+--R          *
+--R             x
+--R         + 
+--R                               2  3            3            2          2   2
+--R           (4800A a b + 3072B a )c  + (- 720A b  - 2400B a b  - 2592C a b)c
+--R         + 
+--R                  4            3           5
+--R           (360B b  + 1520C a b )c - 210C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R           4 +-+
+--R     15360c \|c
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               4   6
+--R                     1105920A a b c
+--R                   + 
+--R                               3 3            4 2            5   5
+--R                     (368640A a b  - 552960B a b  - 184320C a b)c
+--R                   + 
+--R                                 2 5            3 4            4 3  4
+--R                     (- 322560A a b  - 184320B a b  + 261120C a b )c
+--R                   + 
+--R                                7            2 6            3 5  3
+--R                     (23040A a b  + 161280B a b  + 161280C a b )c
+--R                   + 
+--R                             9             8           2 7  2
+--R                     (4320A b  - 11520B a b  - 97920C a b )c
+--R                   + 
+--R                               10            9            11
+--R                     (- 2160B b   + 6000C a b )c + 1260C b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                               5 6
+--R                     2211840A a c
+--R                   + 
+--R                                4 2             5             6  5
+--R                     (6635520A a b  - 1105920B a b - 368640C a )c
+--R                   + 
+--R                                  3 4             4 3            5 2  4
+--R                     (- 2119680A a b  - 3317760B a b  - 460800C a b )c
+--R                   + 
+--R                                 2 6             3 5             4 4  3
+--R                     (- 322560A a b  + 1059840B a b  + 2288640C a b )c
+--R                   + 
+--R                                 8            2 7            3 6  2
+--R                     (100800A a b  + 161280B a b  - 564480C a b )c
+--R                   + 
+--R                                  9            2 8               10
+--R                     (- 50400B a b  - 110880C a b )c + 29400C a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                                5   5
+--R                     17694720A a b c
+--R                   + 
+--R                                4 3             5 2             6   4
+--R                     (1474560A a b  - 8847360B a b  - 2949120C a b)c
+--R                   + 
+--R                                  3 5            4 4             5 3  3
+--R                     (- 4055040A a b  - 737280B a b  + 4915200C a b )c
+--R                   + 
+--R                               2 7             3 6             4 5  2
+--R                     (645120A a b  + 2027520B a b  + 1105920C a b )c
+--R                   + 
+--R                                 2 8             3 7              2 9
+--R                     (- 322560B a b  - 1290240C a b )c + 188160C a b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                                6 5
+--R                     11796480A a c
+--R                   + 
+--R                                 5 2             6              7  4
+--R                     (20643840A a b  - 5898240B a b - 1966080C a )c
+--R                   + 
+--R                                   4 4              5 3  3
+--R                     (- 12533760A a b  - 10321920B a b )c
+--R                   + 
+--R                                3 6             4 5             5 4  2
+--R                     (1658880A a b  + 6266880B a b  + 8110080C a b )c
+--R                   + 
+--R                                 3 7             4 6              3 8
+--R                     (- 829440B a b  - 3932160C a b )c + 483840C a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                                6   4
+--R                     29491200A a b c
+--R                   + 
+--R                                   5 3              6 2             7   3
+--R                     (- 14745600A a b  - 14745600B a b  - 4915200C a b)c
+--R                   + 
+--R                                4 5             5 4              6 3  2
+--R                     (1843200A a b  + 7372800B a b  + 11059200C a b )c
+--R                   + 
+--R                                 4 6             5 5              4 7
+--R                     (- 921600B a b  - 4608000C a b )c + 537600C a b
+--R                *
+--R                   x
+--R               + 
+--R                            7 4
+--R                 11796480A a c
+--R               + 
+--R                              6 2             7              8  3
+--R                 (- 5898240A a b  - 5898240B a b - 1966080C a )c
+--R               + 
+--R                           5 4             6 3             7 2  2
+--R                 (737280A a b  + 2949120B a b  + 4423680C a b )c
+--R               + 
+--R                             5 5             6 4              5 6
+--R                 (- 368640B a b  - 1843200C a b )c + 215040C a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                            5 7                4 2            5            6  6
+--R                 - 368640A a c  + (- 1198080A a b  + 184320B a b + 61440C a )c
+--R               + 
+--R                           3 4            4 3           5 2  5
+--R                 (322560A a b  + 599040B a b  + 92160C a b )c
+--R               + 
+--R                          2 6            3 5            4 4  4
+--R                 (80640A a b  - 161280B a b  - 403200C a b )c
+--R               + 
+--R                              8           2 7           3 6  3
+--R                 (- 18720A a b  - 40320B a b  + 80640C a b )c
+--R               + 
+--R                          10            9           2 8  2
+--R                 (- 360A b   + 9360B a b  + 26640C a b )c
+--R               + 
+--R                        11            10           12
+--R                 (180B b   - 5400C a b  )c - 105C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                             5   6
+--R                 - 6635520A a b c
+--R               + 
+--R                              4 3             5 2             6   5
+--R                 (- 2211840A a b  + 3317760B a b  + 1105920C a b)c
+--R               + 
+--R                            3 5             4 4             5 3  4
+--R                 (1935360A a b  + 1105920B a b  - 1566720C a b )c
+--R               + 
+--R                             2 7            3 6            4 5  3
+--R                 (- 138240A a b  - 967680B a b  - 967680C a b )c
+--R               + 
+--R                              9           2 8            3 7  2
+--R                 (- 25920A a b  + 69120B a b  + 587520C a b )c
+--R               + 
+--R                            10           2 9              11
+--R                 (12960B a b   - 36000C a b )c - 7560C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                             6 6
+--R                 - 6635520A a c
+--R               + 
+--R                               5 2             6              7  5
+--R                 (- 19906560A a b  + 3317760B a b + 1105920C a )c
+--R               + 
+--R                            4 4             5 3             6 2  4
+--R                 (6359040A a b  + 9953280B a b  + 1382400C a b )c
+--R               + 
+--R                           3 6             4 5             5 4  3
+--R                 (967680A a b  - 3179520B a b  - 6865920C a b )c
+--R               + 
+--R                             2 8            3 7             4 6  2
+--R                 (- 302400A a b  - 483840B a b  + 1693440C a b )c
+--R               + 
+--R                           2 9            3 8             2 10
+--R                 (151200B a b  + 332640C a b )c - 88200C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                              6   5
+--R                 - 35389440A a b c
+--R               + 
+--R                              5 3              6 2             7   4
+--R                 (- 2949120A a b  + 17694720B a b  + 5898240C a b)c
+--R               + 
+--R                            4 5             5 4             6 3  3
+--R                 (8110080A a b  + 1474560B a b  - 9830400C a b )c
+--R               + 
+--R                              3 7             4 6             5 5  2
+--R                 (- 1290240A a b  - 4055040B a b  - 2211840C a b )c
+--R               + 
+--R                           3 8             4 7              3 9
+--R                 (645120B a b  + 2580480C a b )c - 376320C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                              7 5
+--R                 - 17694720A a c
+--R               + 
+--R                               6 2             7              8  4
+--R                 (- 30965760A a b  + 8847360B a b + 2949120C a )c
+--R               + 
+--R                             5 4              6 3  3
+--R                 (18800640A a b  + 15482880B a b )c
+--R               + 
+--R                              4 6             5 5              6 4  2
+--R                 (- 2488320A a b  - 9400320B a b  - 12165120C a b )c
+--R               + 
+--R                            4 7             5 6              4 8
+--R                 (1244160B a b  + 5898240C a b )c - 725760C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                              7   4
+--R                 - 35389440A a b c
+--R               + 
+--R                             6 3              7 2             8   3
+--R                 (17694720A a b  + 17694720B a b  + 5898240C a b)c
+--R               + 
+--R                              5 5             6 4              7 3  2
+--R                 (- 2211840A a b  - 8847360B a b  - 13271040C a b )c
+--R               + 
+--R                            5 6             6 5              5 7
+--R                 (1105920B a b  + 5529600C a b )c - 645120C a b
+--R            *
+--R               x
+--R           + 
+--R                          8 4              7 2             8              9  3
+--R             - 11796480A a c  + (5898240A a b  + 5898240B a b + 1966080C a )c
+--R           + 
+--R                         6 4             7 3             8 2  2
+--R             (- 737280A a b  - 2949120B a b  - 4423680C a b )c
+--R           + 
+--R                       6 5             7 4              6 6
+--R             (368640B a b  + 1843200C a b )c - 215040C a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                         3 8            2 2 7              4 6          6 5  11
+--R             (- 163840C a c  - 614400C a b c  - 153600C a b c  - 2560C b c )x
+--R           + 
+--R                            3 8               2 2             3   7
+--R                 - 196608B a c  + (- 737280B a b  - 3162112C a b)c
+--R               + 
+--R                               4             2 3  6
+--R                 (- 184320B a b  - 3256320C a b )c
+--R               + 
+--R                           6              5  5          7 4
+--R                 (- 3072B b  - 384000C a b )c  - 3328C b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            3 8
+--R                 - 245760A a c
+--R               + 
+--R                             2 2             3              4  7
+--R                 (- 921600A a b  - 3809280B a b - 3235840C a )c
+--R               + 
+--R                               4             2 3              3 2  6
+--R                 (- 230400A a b  - 3962880B a b  - 15237120C a b )c
+--R               + 
+--R                           6              5             2 4  5
+--R                 (- 3840A b  - 474624B a b  - 5637120C a b )c
+--R               + 
+--R                           7              6  4        8 3
+--R                 (- 4224B b  - 249856C a b )c  - 96C b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                              3              4  7
+--R                 (- 4792320A a b - 3932160B a )c
+--R               + 
+--R                              2 3              3 2              4   6
+--R                 (- 5068800A a b  - 18739200B a b  - 24760320C a b)c
+--R               + 
+--R                               5             2 4              3 3  5
+--R                 (- 622080A a b  - 7050240B a b  - 27136000C a b )c
+--R               + 
+--R                           7              6             2 5  4
+--R                 (- 5760A b  - 321792B a b  - 3217920C a b )c
+--R               + 
+--R                          8           7  3         9 2
+--R                 (- 192B b  - 768C a b )c  + 112C b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             4 7
+--R                 - 5038080A a c
+--R               + 
+--R                               3 2              4               5  6
+--R                 (- 24453120A a b  - 30904320B a b - 13086720C a )c
+--R               + 
+--R                              2 4              3 3              4 2  5
+--R                 (- 9446400A a b  - 34467840B a b  - 57154560C a b )c
+--R               + 
+--R                               6             2 5              3 4  4
+--R                 (- 453120A a b  - 4197888B a b  - 16360960C a b )c
+--R               + 
+--R                          8           7          2 6  3
+--R                 (- 480A b  - 768B a b  + 2688C a b )c
+--R               + 
+--R                        9           8  2         10
+--R                 (240B b  + 528C a b )c  - 140C b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                               4               5  6
+--R                 (- 41594880A a b - 16711680B a )c
+--R               + 
+--R                               3 3              4 2              5   5
+--R                 (- 47861760A a b  - 74311680B a b  - 55080960C a b)c
+--R               + 
+--R                              2 5              3 4              4 3  4
+--R                 (- 6105600A a b  - 21719040B a b  - 41244160C a b )c
+--R               + 
+--R                           7           2 6           3 5  3
+--R                 (3840A a b  + 26880B a b  + 26880C a b )c
+--R               + 
+--R                        9            8           2 7  2
+--R                 (720A b  - 1920B a b  - 16320C a b )c
+--R               + 
+--R                          10            9           11
+--R                 (- 360B b   + 1000C a b )c + 210C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                              5 6
+--R                 - 22855680A a c
+--R               + 
+--R                                4 2              5               6  5
+--R                 (- 105799680A a b  - 74096640B a b - 20111360C a )c
+--R               + 
+--R                               3 4              4 3              5 2  4
+--R                 (- 33792000A a b  - 57692160B a b  - 55633920C a b )c
+--R               + 
+--R                             2 6            3 5             4 4  3
+--R                 (- 115200A a b  + 540672B a b  + 1090560C a b )c
+--R               + 
+--R                            8           2 7            3 6  2
+--R                 (43200A a b  + 57600B a b  - 296192C a b )c
+--R               + 
+--R                              9           2 8               10
+--R                 (- 21600B a b  - 40800C a b )c + 12600C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                                5               6  5
+--R                 (- 103956480A a b - 27525120B a )c
+--R               + 
+--R                               4 3              5 2              6   4
+--R                 (- 89518080A a b  - 83681280B a b  - 40017920C a b)c
+--R               + 
+--R                              3 5            4 4             5 3  3
+--R                 (- 2472960A a b  - 215040B a b  + 3440640C a b )c
+--R               + 
+--R                           2 7             3 6            4 5  2
+--R                 (403200A a b  + 1236480B a b  + 537600C a b )c
+--R               + 
+--R                             2 8            3 7              2 9
+--R                 (- 201600B a b  - 788480C a b )c + 117600C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                              6 5
+--R                 - 37355520A a c
+--R               + 
+--R                                5 2              6               7  4
+--R                 (- 117964800A a b  - 59965440B a b - 12124160C a )c
+--R               + 
+--R                              4 4             5 3            6 2  3
+--R                 (- 9707520A a b  - 7864320B a b  + 245760C a b )c
+--R               + 
+--R                            3 6             4 5             5 4  2
+--R                 (1290240A a b  + 4853760B a b  + 6205440C a b )c
+--R               + 
+--R                             3 7             4 6              3 8
+--R                 (- 645120B a b  - 3046400C a b )c + 376320C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                               6               7  4
+--R                 (- 75694080A a b - 15728640B a )c
+--R               + 
+--R                               5 3              6 2             7   3
+--R                 (- 13271040A a b  - 13271040B a b  - 4423680C a b)c
+--R               + 
+--R                            4 5             5 4             6 3  2
+--R                 (1658880A a b  + 6635520B a b  + 9953280C a b )c
+--R               + 
+--R                             4 6             5 5              4 7
+--R                 (- 829440B a b  - 4147200C a b )c + 483840C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                              7 4
+--R                 - 19660800A a c
+--R               + 
+--R                              6 2             7              8  3
+--R                 (- 5898240A a b  - 5898240B a b - 1966080C a )c
+--R               + 
+--R                           5 4             6 3             7 2  2
+--R                 (737280A a b  + 2949120B a b  + 4423680C a b )c
+--R               + 
+--R                             5 5             6 4              5 6
+--R                 (- 368640B a b  - 1843200C a b )c + 215040C a b
+--R            *
+--R               x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                       2   8              3 7           5 6  12
+--R             (491520C a b c  + 409600C a b c  + 30720C b c )x
+--R           + 
+--R                           2             3  8               3             2 2  7
+--R                 (589824B a b + 983040C a )c  + (491520B a b  + 4571136C a b )c
+--R               + 
+--R                          5               4  6           6 5
+--R                 (36864B b  + 1658880C a b )c  + 70656C b c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                           2              3  8
+--R                 (737280A a b + 1179648B a )c
+--R               + 
+--R                             3             2 2              3   7
+--R                 (614400A a b  + 5529600B a b  + 11476992C a b)c
+--R               + 
+--R                          5               4              2 3  6
+--R                 (46080A b  + 2027520B a b  + 14284800C a b )c
+--R               + 
+--R                          6               5  5           7 4
+--R                 (87552B b  + 2280960C a b )c  + 41088C b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           3 8              2 2              3              4  7
+--R                 1474560A a c  + (7004160A a b  + 14008320B a b + 7946240C a )c
+--R               + 
+--R                              4              2 3              3 2  6
+--R                 (2611200A a b  + 17633280B a b  + 42270720C a b )c
+--R               + 
+--R                           6               5              2 4  5
+--R                 (115200A b  + 2860032B a b  + 18462720C a b )c
+--R               + 
+--R                          7               6  4         8 3
+--R                 (52992B b  + 1056768C a b )c  - 192C b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                             3              4  7
+--R                 (18063360A a b + 9830400B a )c
+--R               + 
+--R                             2 3              3 2              4   6
+--R                 (23132160A a b  + 52899840B a b  + 51056640C a b)c
+--R               + 
+--R                              5              2 4              3 3  5
+--R                 (3847680A a b  + 23454720B a b  + 62361600C a b )c
+--R               + 
+--R                          7               6             2 5  4
+--R                 (74880A b  + 1369344B a b  + 8501760C a b )c
+--R               + 
+--R                          8            7  3         9 2
+--R                 (- 576B b  - 2304C a b )c  + 336C b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            4 7
+--R                 13025280A a c
+--R               + 
+--R                             3 2              4               5  6
+--R                 (71516160A a b  + 65249280B a b + 21749760C a )c
+--R               + 
+--R                             2 4              3 3               4 2  5
+--R                 (32532480A a b  + 80732160B a b  + 102389760C a b )c
+--R               + 
+--R                              6              2 5              3 4  4
+--R                 (1950720A a b  + 11123712B a b  + 31964160C a b )c
+--R               + 
+--R                           8            7           2 6  3
+--R                 (- 2880A b  - 4608B a b  + 16128C a b )c
+--R               + 
+--R                         9            8  2         10
+--R                 (1440B b  + 3168C a b )c  - 840C b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                             4               5  6
+--R                 (89886720A a b + 28508160B a )c
+--R               + 
+--R                              3 3               4 2              5   5
+--R                 (115937280A a b  + 137164800B a b  + 81930240C a b)c
+--R               + 
+--R                             2 5              3 4              4 3  4
+--R                 (17210880A a b  + 43223040B a b  + 64094720C a b )c
+--R               + 
+--R                              7            2 6            3 5  3
+--R                 (- 80640A a b  - 412416B a b  - 341760C a b )c
+--R               + 
+--R                           9             8            2 7  2
+--R                 (- 7920A b  + 40320B a b  + 254016C a b )c
+--R               + 
+--R                         10             9            11
+--R                 (3960B b   - 22200C a b )c - 2310C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            5 6
+--R                 39075840A a c
+--R               + 
+--R                              4 2               5               6  5
+--R                 (196116480A a b  + 113172480B a b + 25927680C a )c
+--R               + 
+--R                             3 4              4 3              5 2  4
+--R                 (70502400A a b  + 95109120B a b  + 73820160C a b )c
+--R               + 
+--R                           2 6             3 5             4 4  3
+--R                 (368640A a b  - 2184192B a b  - 4254720C a b )c
+--R               + 
+--R                               8            2 7             3 6  2
+--R                 (- 158400A a b  - 184320B a b  + 1212672C a b )c
+--R               + 
+--R                            9            2 8               10
+--R                 (79200B a b  + 133920C a b )c - 46200C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                              5               6  5
+--R                 (155566080A a b + 35389440B a )c
+--R               + 
+--R                              4 3               5 2              6   4
+--R                 (145428480A a b  + 116858880B a b  + 47800320C a b)c
+--R               + 
+--R                            3 5            4 4             5 3  3
+--R                 (5391360A a b  + 276480B a b  - 7864320C a b )c
+--R               + 
+--R                             2 7             3 6             4 5  2
+--R                 (- 887040A a b  - 2695680B a b  - 1059840C a b )c
+--R               + 
+--R                           2 8             3 7              2 9
+--R                 (443520B a b  + 1720320C a b )c - 258720C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            6 5
+--R                 47185920A a c
+--R               + 
+--R                              5 2              6               7  4
+--R                 (156303360A a b  + 70778880B a b + 13107200C a )c
+--R               + 
+--R                             4 4              5 3            6 2  3
+--R                 (15237120A a b  + 12288000B a b  - 491520C a b )c
+--R               + 
+--R                              3 6             4 5             5 4  2
+--R                 (- 2027520A a b  - 7618560B a b  - 9707520C a b )c
+--R               + 
+--R                            3 7             4 6              3 8
+--R                 (1013760B a b  + 4782080C a b )c - 591360C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                             6               7  4
+--R                 (85524480A a b + 15728640B a )c
+--R               + 
+--R                             5 3              6 2             7   3
+--R                 (16220160A a b  + 16220160B a b  + 5406720C a b)c
+--R               + 
+--R                              4 5             5 4              6 3  2
+--R                 (- 2027520A a b  - 8110080B a b  - 12165120C a b )c
+--R               + 
+--R                            4 6             5 5              4 7
+--R                 (1013760B a b  + 5068800C a b )c - 591360C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                            7 4              6 2             7              8  3
+--R                 19660800A a c  + (5898240A a b  + 5898240B a b + 1966080C a )c
+--R               + 
+--R                             5 4             6 3             7 2  2
+--R                 (- 737280A a b  - 2949120B a b  - 4423680C a b )c
+--R               + 
+--R                           5 5             6 4              5 6
+--R                 (368640B a b  + 1843200C a b )c - 215040C a b
+--R            *
+--R               x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                      2   6             3 5          5 4  5
+--R             (2949120a b c  + 2457600a b c  + 184320b c )x
+--R           + 
+--R                      3 6            2 2 5             4 4  4
+--R             (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R           + 
+--R                       3   5            2 3 4  3
+--R             (47185920a b c  + 27525120a b c )x
+--R           + 
+--R                       4 5            3 2 4  2            4   4             5 4
+--R             (31457280a c  + 70778880a b c )x  + 78643200a b c x + 31457280a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                       3 7           2 2 6            4 5         6 4  6
+--R             (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R           + 
+--R                         3   6            2 3 5             5 4  5
+--R             (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R           + 
+--R                         4 6            3 2 5            2 4 4  4
+--R             (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R           + 
+--R                         4   5            3 3 4  3
+--R             (- 94371840a b c  - 55050240a b c )x
+--R           + 
+--R                       5 5             4 2 4  2            5   4             6 4
+--R           (- 47185920a c  - 106168320a b c )x  - 94371840a b c x - 31457280a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                               4   6
+--R                     1105920A a b c
+--R                   + 
+--R                               3 3            4 2            5   5
+--R                     (368640A a b  - 552960B a b  - 184320C a b)c
+--R                   + 
+--R                                 2 5            3 4            4 3  4
+--R                     (- 322560A a b  - 184320B a b  + 261120C a b )c
+--R                   + 
+--R                                7            2 6            3 5  3
+--R                     (23040A a b  + 161280B a b  + 161280C a b )c
+--R                   + 
+--R                             9             8           2 7  2
+--R                     (4320A b  - 11520B a b  - 97920C a b )c
+--R                   + 
+--R                               10            9            11
+--R                     (- 2160B b   + 6000C a b )c + 1260C b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                               5 6
+--R                     2211840A a c
+--R                   + 
+--R                                4 2             5             6  5
+--R                     (6635520A a b  - 1105920B a b - 368640C a )c
+--R                   + 
+--R                                  3 4             4 3            5 2  4
+--R                     (- 2119680A a b  - 3317760B a b  - 460800C a b )c
+--R                   + 
+--R                                 2 6             3 5             4 4  3
+--R                     (- 322560A a b  + 1059840B a b  + 2288640C a b )c
+--R                   + 
+--R                                 8            2 7            3 6  2
+--R                     (100800A a b  + 161280B a b  - 564480C a b )c
+--R                   + 
+--R                                  9            2 8               10
+--R                     (- 50400B a b  - 110880C a b )c + 29400C a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                                5   5
+--R                     17694720A a b c
+--R                   + 
+--R                                4 3             5 2             6   4
+--R                     (1474560A a b  - 8847360B a b  - 2949120C a b)c
+--R                   + 
+--R                                  3 5            4 4             5 3  3
+--R                     (- 4055040A a b  - 737280B a b  + 4915200C a b )c
+--R                   + 
+--R                               2 7             3 6             4 5  2
+--R                     (645120A a b  + 2027520B a b  + 1105920C a b )c
+--R                   + 
+--R                                 2 8             3 7              2 9
+--R                     (- 322560B a b  - 1290240C a b )c + 188160C a b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                                6 5
+--R                     11796480A a c
+--R                   + 
+--R                                 5 2             6              7  4
+--R                     (20643840A a b  - 5898240B a b - 1966080C a )c
+--R                   + 
+--R                                   4 4              5 3  3
+--R                     (- 12533760A a b  - 10321920B a b )c
+--R                   + 
+--R                                3 6             4 5             5 4  2
+--R                     (1658880A a b  + 6266880B a b  + 8110080C a b )c
+--R                   + 
+--R                                 3 7             4 6              3 8
+--R                     (- 829440B a b  - 3932160C a b )c + 483840C a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                                6   4
+--R                     29491200A a b c
+--R                   + 
+--R                                   5 3              6 2             7   3
+--R                     (- 14745600A a b  - 14745600B a b  - 4915200C a b)c
+--R                   + 
+--R                                4 5             5 4              6 3  2
+--R                     (1843200A a b  + 7372800B a b  + 11059200C a b )c
+--R                   + 
+--R                                 4 6             5 5              4 7
+--R                     (- 921600B a b  - 4608000C a b )c + 537600C a b
+--R                *
+--R                   x
+--R               + 
+--R                            7 4
+--R                 11796480A a c
+--R               + 
+--R                              6 2             7              8  3
+--R                 (- 5898240A a b  - 5898240B a b - 1966080C a )c
+--R               + 
+--R                           5 4             6 3             7 2  2
+--R                 (737280A a b  + 2949120B a b  + 4423680C a b )c
+--R               + 
+--R                             5 5             6 4              5 6
+--R                 (- 368640B a b  - 1843200C a b )c + 215040C a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                            5 7                4 2            5            6  6
+--R                 - 368640A a c  + (- 1198080A a b  + 184320B a b + 61440C a )c
+--R               + 
+--R                           3 4            4 3           5 2  5
+--R                 (322560A a b  + 599040B a b  + 92160C a b )c
+--R               + 
+--R                          2 6            3 5            4 4  4
+--R                 (80640A a b  - 161280B a b  - 403200C a b )c
+--R               + 
+--R                              8           2 7           3 6  3
+--R                 (- 18720A a b  - 40320B a b  + 80640C a b )c
+--R               + 
+--R                          10            9           2 8  2
+--R                 (- 360A b   + 9360B a b  + 26640C a b )c
+--R               + 
+--R                        11            10           12
+--R                 (180B b   - 5400C a b  )c - 105C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                             5   6
+--R                 - 6635520A a b c
+--R               + 
+--R                              4 3             5 2             6   5
+--R                 (- 2211840A a b  + 3317760B a b  + 1105920C a b)c
+--R               + 
+--R                            3 5             4 4             5 3  4
+--R                 (1935360A a b  + 1105920B a b  - 1566720C a b )c
+--R               + 
+--R                             2 7            3 6            4 5  3
+--R                 (- 138240A a b  - 967680B a b  - 967680C a b )c
+--R               + 
+--R                              9           2 8            3 7  2
+--R                 (- 25920A a b  + 69120B a b  + 587520C a b )c
+--R               + 
+--R                            10           2 9              11
+--R                 (12960B a b   - 36000C a b )c - 7560C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                             6 6
+--R                 - 6635520A a c
+--R               + 
+--R                               5 2             6              7  5
+--R                 (- 19906560A a b  + 3317760B a b + 1105920C a )c
+--R               + 
+--R                            4 4             5 3             6 2  4
+--R                 (6359040A a b  + 9953280B a b  + 1382400C a b )c
+--R               + 
+--R                           3 6             4 5             5 4  3
+--R                 (967680A a b  - 3179520B a b  - 6865920C a b )c
+--R               + 
+--R                             2 8            3 7             4 6  2
+--R                 (- 302400A a b  - 483840B a b  + 1693440C a b )c
+--R               + 
+--R                           2 9            3 8             2 10
+--R                 (151200B a b  + 332640C a b )c - 88200C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                              6   5
+--R                 - 35389440A a b c
+--R               + 
+--R                              5 3              6 2             7   4
+--R                 (- 2949120A a b  + 17694720B a b  + 5898240C a b)c
+--R               + 
+--R                            4 5             5 4             6 3  3
+--R                 (8110080A a b  + 1474560B a b  - 9830400C a b )c
+--R               + 
+--R                              3 7             4 6             5 5  2
+--R                 (- 1290240A a b  - 4055040B a b  - 2211840C a b )c
+--R               + 
+--R                           3 8             4 7              3 9
+--R                 (645120B a b  + 2580480C a b )c - 376320C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                              7 5
+--R                 - 17694720A a c
+--R               + 
+--R                               6 2             7              8  4
+--R                 (- 30965760A a b  + 8847360B a b + 2949120C a )c
+--R               + 
+--R                             5 4              6 3  3
+--R                 (18800640A a b  + 15482880B a b )c
+--R               + 
+--R                              4 6             5 5              6 4  2
+--R                 (- 2488320A a b  - 9400320B a b  - 12165120C a b )c
+--R               + 
+--R                            4 7             5 6              4 8
+--R                 (1244160B a b  + 5898240C a b )c - 725760C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                              7   4
+--R                 - 35389440A a b c
+--R               + 
+--R                             6 3              7 2             8   3
+--R                 (17694720A a b  + 17694720B a b  + 5898240C a b)c
+--R               + 
+--R                              5 5             6 4              7 3  2
+--R                 (- 2211840A a b  - 8847360B a b  - 13271040C a b )c
+--R               + 
+--R                            5 6             6 5              5 7
+--R                 (1105920B a b  + 5529600C a b )c - 645120C a b
+--R            *
+--R               x
+--R           + 
+--R                          8 4              7 2             8              9  3
+--R             - 11796480A a c  + (5898240A a b  + 5898240B a b + 1966080C a )c
+--R           + 
+--R                         6 4             7 3             8 2  2
+--R             (- 737280A a b  - 2949120B a b  - 4423680C a b )c
+--R           + 
+--R                       6 5             7 4              6 6
+--R             (368640B a b  + 1843200C a b )c - 215040C a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                        3 8            2 2 7             4 6          6 5  11
+--R             (- 81920C a c  - 307200C a b c  - 76800C a b c  - 1280C b c )x
+--R           + 
+--R                           3 8               2 2             3   7
+--R                 - 98304B a c  + (- 368640B a b  - 1581056C a b)c
+--R               + 
+--R                              4             2 3  6
+--R                 (- 92160B a b  - 1628160C a b )c
+--R               + 
+--R                           6              5  5          7 4
+--R                 (- 1536B b  - 192000C a b )c  - 1664C b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            3 8
+--R                 - 122880A a c
+--R               + 
+--R                             2 2             3              4  7
+--R                 (- 460800A a b  - 1904640B a b - 1617920C a )c
+--R               + 
+--R                               4             2 3             3 2  6
+--R                 (- 115200A a b  - 1981440B a b  - 7618560C a b )c
+--R               + 
+--R                           6              5             2 4  5
+--R                 (- 1920A b  - 237312B a b  - 2818560C a b )c
+--R               + 
+--R                           7              6  4        8 3
+--R                 (- 2112B b  - 124928C a b )c  - 48C b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                              3              4  7
+--R                 (- 2396160A a b - 1966080B a )c
+--R               + 
+--R                              2 3             3 2              4   6
+--R                 (- 2534400A a b  - 9369600B a b  - 12380160C a b)c
+--R               + 
+--R                               5             2 4              3 3  5
+--R                 (- 311040A a b  - 3525120B a b  - 13568000C a b )c
+--R               + 
+--R                           7              6             2 5  4
+--R                 (- 2880A b  - 160896B a b  - 1608960C a b )c
+--R               + 
+--R                         8           7  3        9 2
+--R                 (- 96B b  - 384C a b )c  + 56C b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             4 7
+--R                 - 2519040A a c
+--R               + 
+--R                               3 2              4              5  6
+--R                 (- 12226560A a b  - 15452160B a b - 6543360C a )c
+--R               + 
+--R                              2 4              3 3              4 2  5
+--R                 (- 4723200A a b  - 17233920B a b  - 28577280C a b )c
+--R               + 
+--R                               6             2 5             3 4  4
+--R                 (- 226560A a b  - 2098944B a b  - 8180480C a b )c
+--R               + 
+--R                          8           7          2 6  3
+--R                 (- 240A b  - 384B a b  + 1344C a b )c
+--R               + 
+--R                        9           8  2        10
+--R                 (120B b  + 264C a b )c  - 70C b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                               4              5  6
+--R                 (- 20797440A a b - 8355840B a )c
+--R               + 
+--R                               3 3              4 2              5   5
+--R                 (- 23930880A a b  - 37155840B a b  - 27540480C a b)c
+--R               + 
+--R                              2 5              3 4              4 3  4
+--R                 (- 3052800A a b  - 10859520B a b  - 20622080C a b )c
+--R               + 
+--R                           7           2 6           3 5  3
+--R                 (1920A a b  + 13440B a b  + 13440C a b )c
+--R               + 
+--R                        9           8          2 7  2
+--R                 (360A b  - 960B a b  - 8160C a b )c
+--R               + 
+--R                          10           9           11
+--R                 (- 180B b   + 500C a b )c + 105C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                              5 6
+--R                 - 11427840A a c
+--R               + 
+--R                               4 2              5               6  5
+--R                 (- 52899840A a b  - 37048320B a b - 10055680C a )c
+--R               + 
+--R                               3 4              4 3              5 2  4
+--R                 (- 16896000A a b  - 28846080B a b  - 27816960C a b )c
+--R               + 
+--R                            2 6            3 5            4 4  3
+--R                 (- 57600A a b  + 270336B a b  + 545280C a b )c
+--R               + 
+--R                            8           2 7            3 6  2
+--R                 (21600A a b  + 28800B a b  - 148096C a b )c
+--R               + 
+--R                              9           2 8              10
+--R                 (- 10800B a b  - 20400C a b )c + 6300C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                               5               6  5
+--R                 (- 51978240A a b - 13762560B a )c
+--R               + 
+--R                               4 3              5 2              6   4
+--R                 (- 44759040A a b  - 41840640B a b  - 20008960C a b)c
+--R               + 
+--R                              3 5            4 4             5 3  3
+--R                 (- 1236480A a b  - 107520B a b  + 1720320C a b )c
+--R               + 
+--R                           2 7            3 6            4 5  2
+--R                 (201600A a b  + 618240B a b  + 268800C a b )c
+--R               + 
+--R                             2 8            3 7             2 9
+--R                 (- 100800B a b  - 394240C a b )c + 58800C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                              6 5
+--R                 - 18677760A a c
+--R               + 
+--R                               5 2              6              7  4
+--R                 (- 58982400A a b  - 29982720B a b - 6062080C a )c
+--R               + 
+--R                              4 4             5 3            6 2  3
+--R                 (- 4853760A a b  - 3932160B a b  + 122880C a b )c
+--R               + 
+--R                           3 6             4 5             5 4  2
+--R                 (645120A a b  + 2426880B a b  + 3102720C a b )c
+--R               + 
+--R                             3 7             4 6              3 8
+--R                 (- 322560B a b  - 1523200C a b )c + 188160C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                               6              7  4
+--R                 (- 37847040A a b - 7864320B a )c
+--R               + 
+--R                              5 3             6 2             7   3
+--R                 (- 6635520A a b  - 6635520B a b  - 2211840C a b)c
+--R               + 
+--R                           4 5             5 4             6 3  2
+--R                 (829440A a b  + 3317760B a b  + 4976640C a b )c
+--R               + 
+--R                             4 6             5 5              4 7
+--R                 (- 414720B a b  - 2073600C a b )c + 241920C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                             7 4
+--R                 - 9830400A a c
+--R               + 
+--R                              6 2             7             8  3
+--R                 (- 2949120A a b  - 2949120B a b - 983040C a )c
+--R               + 
+--R                           5 4             6 3             7 2  2
+--R                 (368640A a b  + 1474560B a b  + 2211840C a b )c
+--R               + 
+--R                             5 5            6 4              5 6
+--R                 (- 184320B a b  - 921600C a b )c + 107520C a b
+--R            *
+--R               x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                       2   8              3 7           5 6  12
+--R             (245760C a b c  + 204800C a b c  + 15360C b c )x
+--R           + 
+--R                           2             3  8               3             2 2  7
+--R                 (294912B a b + 491520C a )c  + (245760B a b  + 2285568C a b )c
+--R               + 
+--R                          5              4  6           6 5
+--R                 (18432B b  + 829440C a b )c  + 35328C b c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                           2             3  8
+--R                 (368640A a b + 589824B a )c
+--R               + 
+--R                             3             2 2             3   7
+--R                 (307200A a b  + 2764800B a b  + 5738496C a b)c
+--R               + 
+--R                          5               4             2 3  6
+--R                 (23040A b  + 1013760B a b  + 7142400C a b )c
+--R               + 
+--R                          6               5  5           7 4
+--R                 (43776B b  + 1140480C a b )c  + 20544C b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          3 8              2 2             3              4  7
+--R                 737280A a c  + (3502080A a b  + 7004160B a b + 3973120C a )c
+--R               + 
+--R                              4             2 3              3 2  6
+--R                 (1305600A a b  + 8816640B a b  + 21135360C a b )c
+--R               + 
+--R                          6               5             2 4  5
+--R                 (57600A b  + 1430016B a b  + 9231360C a b )c
+--R               + 
+--R                          7              6  4        8 3
+--R                 (26496B b  + 528384C a b )c  - 96C b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                            3              4  7
+--R                 (9031680A a b + 4915200B a )c
+--R               + 
+--R                             2 3              3 2              4   6
+--R                 (11566080A a b  + 26449920B a b  + 25528320C a b)c
+--R               + 
+--R                              5              2 4              3 3  5
+--R                 (1923840A a b  + 11727360B a b  + 31180800C a b )c
+--R               + 
+--R                          7              6             2 5  4
+--R                 (37440A b  + 684672B a b  + 4250880C a b )c
+--R               + 
+--R                          8            7  3         9 2
+--R                 (- 288B b  - 1152C a b )c  + 168C b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                           4 7
+--R                 6512640A a c
+--R               + 
+--R                             3 2              4               5  6
+--R                 (35758080A a b  + 32624640B a b + 10874880C a )c
+--R               + 
+--R                             2 4              3 3              4 2  5
+--R                 (16266240A a b  + 40366080B a b  + 51194880C a b )c
+--R               + 
+--R                             6             2 5              3 4  4
+--R                 (975360A a b  + 5561856B a b  + 15982080C a b )c
+--R               + 
+--R                           8            7          2 6  3
+--R                 (- 1440A b  - 2304B a b  + 8064C a b )c
+--R               + 
+--R                        9            8  2         10
+--R                 (720B b  + 1584C a b )c  - 420C b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                             4               5  6
+--R                 (44943360A a b + 14254080B a )c
+--R               + 
+--R                             3 3              4 2              5   5
+--R                 (57968640A a b  + 68582400B a b  + 40965120C a b)c
+--R               + 
+--R                            2 5              3 4              4 3  4
+--R                 (8605440A a b  + 21611520B a b  + 32047360C a b )c
+--R               + 
+--R                              7            2 6            3 5  3
+--R                 (- 40320A a b  - 206208B a b  - 170880C a b )c
+--R               + 
+--R                           9             8            2 7  2
+--R                 (- 3960A b  + 20160B a b  + 127008C a b )c
+--R               + 
+--R                         10             9            11
+--R                 (1980B b   - 11100C a b )c - 1155C b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            5 6
+--R                 19537920A a c
+--R               + 
+--R                             4 2              5               6  5
+--R                 (98058240A a b  + 56586240B a b + 12963840C a )c
+--R               + 
+--R                             3 4              4 3              5 2  4
+--R                 (35251200A a b  + 47554560B a b  + 36910080C a b )c
+--R               + 
+--R                           2 6             3 5             4 4  3
+--R                 (184320A a b  - 1092096B a b  - 2127360C a b )c
+--R               + 
+--R                              8           2 7            3 6  2
+--R                 (- 79200A a b  - 92160B a b  + 606336C a b )c
+--R               + 
+--R                            9           2 8               10
+--R                 (39600B a b  + 66960C a b )c - 23100C a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                             5               6  5
+--R                 (77783040A a b + 17694720B a )c
+--R               + 
+--R                             4 3              5 2              6   4
+--R                 (72714240A a b  + 58429440B a b  + 23900160C a b)c
+--R               + 
+--R                            3 5            4 4             5 3  3
+--R                 (2695680A a b  + 138240B a b  - 3932160C a b )c
+--R               + 
+--R                             2 7             3 6            4 5  2
+--R                 (- 443520A a b  - 1347840B a b  - 529920C a b )c
+--R               + 
+--R                           2 8            3 7              2 9
+--R                 (221760B a b  + 860160C a b )c - 129360C a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            6 5
+--R                 23592960A a c
+--R               + 
+--R                             5 2              6              7  4
+--R                 (78151680A a b  + 35389440B a b + 6553600C a )c
+--R               + 
+--R                            4 4             5 3            6 2  3
+--R                 (7618560A a b  + 6144000B a b  - 245760C a b )c
+--R               + 
+--R                              3 6             4 5             5 4  2
+--R                 (- 1013760A a b  - 3809280B a b  - 4853760C a b )c
+--R               + 
+--R                           3 7             4 6              3 8
+--R                 (506880B a b  + 2391040C a b )c - 295680C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                             6              7  4
+--R                 (42762240A a b + 7864320B a )c
+--R               + 
+--R                            5 3             6 2             7   3
+--R                 (8110080A a b  + 8110080B a b  + 2703360C a b)c
+--R               + 
+--R                              4 5             5 4             6 3  2
+--R                 (- 1013760A a b  - 4055040B a b  - 6082560C a b )c
+--R               + 
+--R                           4 6             5 5              4 7
+--R                 (506880B a b  + 2534400C a b )c - 295680C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           7 4              6 2             7             8  3
+--R                 9830400A a c  + (2949120A a b  + 2949120B a b + 983040C a )c
+--R               + 
+--R                             5 4             6 3             7 2  2
+--R                 (- 368640A a b  - 1474560B a b  - 2211840C a b )c
+--R               + 
+--R                           5 5            6 4              5 6
+--R                 (184320B a b  + 921600C a b )c - 107520C a b
+--R            *
+--R               x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                      2   6             3 5         5 4  5
+--R             (1474560a b c  + 1228800a b c  + 92160b c )x
+--R           + 
+--R                      3 6            2 2 5             4 4  4
+--R             (2949120a c  + 10321920a b c  + 2150400a b c )x
+--R           + 
+--R                       3   5            2 3 4  3
+--R             (23592960a b c  + 13762560a b c )x
+--R           + 
+--R                       4 5            3 2 4  2            4   4             5 4
+--R             (15728640a c  + 35389440a b c )x  + 39321600a b c x + 15728640a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                       3 7           2 2 6            4 5        6 4  6
+--R             (- 491520a c  - 1843200a b c  - 460800a b c  - 7680b c )x
+--R           + 
+--R                        3   6           2 3 5            5 4  5
+--R             (- 8847360a b c  - 7372800a b c  - 552960a b c )x
+--R           + 
+--R                        4 6            3 2 5           2 4 4  4
+--R             (- 8847360a c  - 30965760a b c  - 6451200a b c )x
+--R           + 
+--R                         4   5            3 3 4  3
+--R             (- 47185920a b c  - 27525120a b c )x
+--R           + 
+--R                       5 5            4 2 4  2            5   4             6 4
+--R           (- 23592960a c  - 53084160a b c )x  - 47185920a b c x - 15728640a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 315
+
+--S 316 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             4   6
+--R                   1105920A a b c
+--R                 + 
+--R                             3 3            4 2            5   5
+--R                   (368640A a b  - 552960B a b  - 184320C a b)c
+--R                 + 
+--R                               2 5            3 4            4 3  4
+--R                   (- 322560A a b  - 184320B a b  + 261120C a b )c
+--R                 + 
+--R                              7            2 6            3 5  3
+--R                   (23040A a b  + 161280B a b  + 161280C a b )c
+--R                 + 
+--R                           9             8           2 7  2
+--R                   (4320A b  - 11520B a b  - 97920C a b )c
+--R                 + 
+--R                             10            9            11
+--R                   (- 2160B b   + 6000C a b )c + 1260C b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             5 6              4 2             5             6  5
+--R                   2211840A a c  + (6635520A a b  - 1105920B a b - 368640C a )c
+--R                 + 
+--R                                3 4             4 3            5 2  4
+--R                   (- 2119680A a b  - 3317760B a b  - 460800C a b )c
+--R                 + 
+--R                               2 6             3 5             4 4  3
+--R                   (- 322560A a b  + 1059840B a b  + 2288640C a b )c
+--R                 + 
+--R                               8            2 7            3 6  2
+--R                   (100800A a b  + 161280B a b  - 564480C a b )c
+--R                 + 
+--R                                9            2 8               10
+--R                   (- 50400B a b  - 110880C a b )c + 29400C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              5   5
+--R                   17694720A a b c
+--R                 + 
+--R                              4 3             5 2             6   4
+--R                   (1474560A a b  - 8847360B a b  - 2949120C a b)c
+--R                 + 
+--R                                3 5            4 4             5 3  3
+--R                   (- 4055040A a b  - 737280B a b  + 4915200C a b )c
+--R                 + 
+--R                             2 7             3 6             4 5  2
+--R                   (645120A a b  + 2027520B a b  + 1105920C a b )c
+--R                 + 
+--R                               2 8             3 7              2 9
+--R                   (- 322560B a b  - 1290240C a b )c + 188160C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                              6 5
+--R                   11796480A a c
+--R                 + 
+--R                               5 2             6              7  4
+--R                   (20643840A a b  - 5898240B a b - 1966080C a )c
+--R                 + 
+--R                                 4 4              5 3  3
+--R                   (- 12533760A a b  - 10321920B a b )c
+--R                 + 
+--R                              3 6             4 5             5 4  2
+--R                   (1658880A a b  + 6266880B a b  + 8110080C a b )c
+--R                 + 
+--R                               3 7             4 6              3 8
+--R                   (- 829440B a b  - 3932160C a b )c + 483840C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                              6   4
+--R                   29491200A a b c
+--R                 + 
+--R                                 5 3              6 2             7   3
+--R                   (- 14745600A a b  - 14745600B a b  - 4915200C a b)c
+--R                 + 
+--R                              4 5             5 4              6 3  2
+--R                   (1843200A a b  + 7372800B a b  + 11059200C a b )c
+--R                 + 
+--R                               4 6             5 5              4 7
+--R                   (- 921600B a b  - 4608000C a b )c + 537600C a b
+--R              *
+--R                 x
+--R             + 
+--R                          7 4                6 2             7              8  3
+--R               11796480A a c  + (- 5898240A a b  - 5898240B a b - 1966080C a )c
+--R             + 
+--R                         5 4             6 3             7 2  2
+--R               (737280A a b  + 2949120B a b  + 4423680C a b )c
+--R             + 
+--R                           5 5             6 4              5 6
+--R               (- 368640B a b  - 1843200C a b )c + 215040C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                          5 7                4 2            5            6  6
+--R               - 368640A a c  + (- 1198080A a b  + 184320B a b + 61440C a )c
+--R             + 
+--R                         3 4            4 3           5 2  5
+--R               (322560A a b  + 599040B a b  + 92160C a b )c
+--R             + 
+--R                        2 6            3 5            4 4  4
+--R               (80640A a b  - 161280B a b  - 403200C a b )c
+--R             + 
+--R                            8           2 7           3 6  3
+--R               (- 18720A a b  - 40320B a b  + 80640C a b )c
+--R             + 
+--R                        10            9           2 8  2
+--R               (- 360A b   + 9360B a b  + 26640C a b )c
+--R             + 
+--R                      11            10           12
+--R               (180B b   - 5400C a b  )c - 105C b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           5   6
+--R               - 6635520A a b c
+--R             + 
+--R                            4 3             5 2             6   5
+--R               (- 2211840A a b  + 3317760B a b  + 1105920C a b)c
+--R             + 
+--R                          3 5             4 4             5 3  4
+--R               (1935360A a b  + 1105920B a b  - 1566720C a b )c
+--R             + 
+--R                           2 7            3 6            4 5  3
+--R               (- 138240A a b  - 967680B a b  - 967680C a b )c
+--R             + 
+--R                            9           2 8            3 7  2
+--R               (- 25920A a b  + 69120B a b  + 587520C a b )c
+--R             + 
+--R                          10           2 9              11
+--R               (12960B a b   - 36000C a b )c - 7560C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                           6 6
+--R               - 6635520A a c
+--R             + 
+--R                             5 2             6              7  5
+--R               (- 19906560A a b  + 3317760B a b + 1105920C a )c
+--R             + 
+--R                          4 4             5 3             6 2  4
+--R               (6359040A a b  + 9953280B a b  + 1382400C a b )c
+--R             + 
+--R                         3 6             4 5             5 4  3
+--R               (967680A a b  - 3179520B a b  - 6865920C a b )c
+--R             + 
+--R                           2 8            3 7             4 6  2
+--R               (- 302400A a b  - 483840B a b  + 1693440C a b )c
+--R             + 
+--R                         2 9            3 8             2 10
+--R               (151200B a b  + 332640C a b )c - 88200C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                            6   5
+--R               - 35389440A a b c
+--R             + 
+--R                            5 3              6 2             7   4
+--R               (- 2949120A a b  + 17694720B a b  + 5898240C a b)c
+--R             + 
+--R                          4 5             5 4             6 3  3
+--R               (8110080A a b  + 1474560B a b  - 9830400C a b )c
+--R             + 
+--R                            3 7             4 6             5 5  2
+--R               (- 1290240A a b  - 4055040B a b  - 2211840C a b )c
+--R             + 
+--R                         3 8             4 7              3 9
+--R               (645120B a b  + 2580480C a b )c - 376320C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                            7 5
+--R               - 17694720A a c
+--R             + 
+--R                             6 2             7              8  4
+--R               (- 30965760A a b  + 8847360B a b + 2949120C a )c
+--R             + 
+--R                           5 4              6 3  3
+--R               (18800640A a b  + 15482880B a b )c
+--R             + 
+--R                            4 6             5 5              6 4  2
+--R               (- 2488320A a b  - 9400320B a b  - 12165120C a b )c
+--R             + 
+--R                          4 7             5 6              4 8
+--R               (1244160B a b  + 5898240C a b )c - 725760C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                            7   4
+--R               - 35389440A a b c
+--R             + 
+--R                           6 3              7 2             8   3
+--R               (17694720A a b  + 17694720B a b  + 5898240C a b)c
+--R             + 
+--R                            5 5             6 4              7 3  2
+--R               (- 2211840A a b  - 8847360B a b  - 13271040C a b )c
+--R             + 
+--R                          5 6             6 5              5 7
+--R               (1105920B a b  + 5529600C a b )c - 645120C a b
+--R          *
+--R             x
+--R         + 
+--R                        8 4              7 2             8              9  3
+--R           - 11796480A a c  + (5898240A a b  + 5898240B a b + 1966080C a )c
+--R         + 
+--R                       6 4             7 3             8 2  2
+--R           (- 737280A a b  - 2949120B a b  - 4423680C a b )c
+--R         + 
+--R                     6 5             7 4              6 6
+--R           (368640B a b  + 1843200C a b )c - 215040C a b
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                               4   6
+--R                   - 1105920A a b c
+--R                 + 
+--R                               3 3            4 2            5   5
+--R                   (- 368640A a b  + 552960B a b  + 184320C a b)c
+--R                 + 
+--R                             2 5            3 4            4 3  4
+--R                   (322560A a b  + 184320B a b  - 261120C a b )c
+--R                 + 
+--R                                7            2 6            3 5  3
+--R                   (- 23040A a b  - 161280B a b  - 161280C a b )c
+--R                 + 
+--R                             9             8           2 7  2
+--R                   (- 4320A b  + 11520B a b  + 97920C a b )c
+--R                 + 
+--R                           10            9            11
+--R                   (2160B b   - 6000C a b )c - 1260C b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                               5 6
+--R                   - 2211840A a c
+--R                 + 
+--R                                4 2             5             6  5
+--R                   (- 6635520A a b  + 1105920B a b + 368640C a )c
+--R                 + 
+--R                              3 4             4 3            5 2  4
+--R                   (2119680A a b  + 3317760B a b  + 460800C a b )c
+--R                 + 
+--R                             2 6             3 5             4 4  3
+--R                   (322560A a b  - 1059840B a b  - 2288640C a b )c
+--R                 + 
+--R                                 8            2 7            3 6  2
+--R                   (- 100800A a b  - 161280B a b  + 564480C a b )c
+--R                 + 
+--R                              9            2 8               10
+--R                   (50400B a b  + 110880C a b )c - 29400C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                5   5
+--R                   - 17694720A a b c
+--R                 + 
+--R                                4 3             5 2             6   4
+--R                   (- 1474560A a b  + 8847360B a b  + 2949120C a b)c
+--R                 + 
+--R                              3 5            4 4             5 3  3
+--R                   (4055040A a b  + 737280B a b  - 4915200C a b )c
+--R                 + 
+--R                               2 7             3 6             4 5  2
+--R                   (- 645120A a b  - 2027520B a b  - 1105920C a b )c
+--R                 + 
+--R                             2 8             3 7              2 9
+--R                   (322560B a b  + 1290240C a b )c - 188160C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                6 5
+--R                   - 11796480A a c
+--R                 + 
+--R                                 5 2             6              7  4
+--R                   (- 20643840A a b  + 5898240B a b + 1966080C a )c
+--R                 + 
+--R                               4 4              5 3  3
+--R                   (12533760A a b  + 10321920B a b )c
+--R                 + 
+--R                                3 6             4 5             5 4  2
+--R                   (- 1658880A a b  - 6266880B a b  - 8110080C a b )c
+--R                 + 
+--R                             3 7             4 6              3 8
+--R                   (829440B a b  + 3932160C a b )c - 483840C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                6   4
+--R                   - 29491200A a b c
+--R                 + 
+--R                               5 3              6 2             7   3
+--R                   (14745600A a b  + 14745600B a b  + 4915200C a b)c
+--R                 + 
+--R                                4 5             5 4              6 3  2
+--R                   (- 1843200A a b  - 7372800B a b  - 11059200C a b )c
+--R                 + 
+--R                             4 6             5 5              4 7
+--R                   (921600B a b  + 4608000C a b )c - 537600C a b
+--R              *
+--R                 x
+--R             + 
+--R                            7 4              6 2             7              8  3
+--R               - 11796480A a c  + (5898240A a b  + 5898240B a b + 1966080C a )c
+--R             + 
+--R                           5 4             6 3             7 2  2
+--R               (- 737280A a b  - 2949120B a b  - 4423680C a b )c
+--R             + 
+--R                         5 5             6 4              5 6
+--R               (368640B a b  + 1843200C a b )c - 215040C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                        5 7              4 2            5            6  6
+--R               368640A a c  + (1198080A a b  - 184320B a b - 61440C a )c
+--R             + 
+--R                           3 4            4 3           5 2  5
+--R               (- 322560A a b  - 599040B a b  - 92160C a b )c
+--R             + 
+--R                          2 6            3 5            4 4  4
+--R               (- 80640A a b  + 161280B a b  + 403200C a b )c
+--R             + 
+--R                          8           2 7           3 6  3
+--R               (18720A a b  + 40320B a b  - 80640C a b )c
+--R             + 
+--R                      10            9           2 8  2
+--R               (360A b   - 9360B a b  - 26640C a b )c
+--R             + 
+--R                        11            10           12
+--R               (- 180B b   + 5400C a b  )c + 105C b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         5   6
+--R               6635520A a b c
+--R             + 
+--R                          4 3             5 2             6   5
+--R               (2211840A a b  - 3317760B a b  - 1105920C a b)c
+--R             + 
+--R                            3 5             4 4             5 3  4
+--R               (- 1935360A a b  - 1105920B a b  + 1566720C a b )c
+--R             + 
+--R                         2 7            3 6            4 5  3
+--R               (138240A a b  + 967680B a b  + 967680C a b )c
+--R             + 
+--R                          9           2 8            3 7  2
+--R               (25920A a b  - 69120B a b  - 587520C a b )c
+--R             + 
+--R                            10           2 9              11
+--R               (- 12960B a b   + 36000C a b )c + 7560C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                         6 6               5 2             6              7  5
+--R               6635520A a c  + (19906560A a b  - 3317760B a b - 1105920C a )c
+--R             + 
+--R                            4 4             5 3             6 2  4
+--R               (- 6359040A a b  - 9953280B a b  - 1382400C a b )c
+--R             + 
+--R                           3 6             4 5             5 4  3
+--R               (- 967680A a b  + 3179520B a b  + 6865920C a b )c
+--R             + 
+--R                         2 8            3 7             4 6  2
+--R               (302400A a b  + 483840B a b  - 1693440C a b )c
+--R             + 
+--R                           2 9            3 8             2 10
+--R               (- 151200B a b  - 332640C a b )c + 88200C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          6   5
+--R               35389440A a b c
+--R             + 
+--R                          5 3              6 2             7   4
+--R               (2949120A a b  - 17694720B a b  - 5898240C a b)c
+--R             + 
+--R                            4 5             5 4             6 3  3
+--R               (- 8110080A a b  - 1474560B a b  + 9830400C a b )c
+--R             + 
+--R                          3 7             4 6             5 5  2
+--R               (1290240A a b  + 4055040B a b  + 2211840C a b )c
+--R             + 
+--R                           3 8             4 7              3 9
+--R               (- 645120B a b  - 2580480C a b )c + 376320C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                          7 5               6 2             7              8  4
+--R               17694720A a c  + (30965760A a b  - 8847360B a b - 2949120C a )c
+--R             + 
+--R                             5 4              6 3  3
+--R               (- 18800640A a b  - 15482880B a b )c
+--R             + 
+--R                          4 6             5 5              6 4  2
+--R               (2488320A a b  + 9400320B a b  + 12165120C a b )c
+--R             + 
+--R                            4 7             5 6              4 8
+--R               (- 1244160B a b  - 5898240C a b )c + 725760C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                          7   4
+--R               35389440A a b c
+--R             + 
+--R                             6 3              7 2             8   3
+--R               (- 17694720A a b  - 17694720B a b  - 5898240C a b)c
+--R             + 
+--R                          5 5             6 4              7 3  2
+--R               (2211840A a b  + 8847360B a b  + 13271040C a b )c
+--R             + 
+--R                            5 6             6 5              5 7
+--R               (- 1105920B a b  - 5529600C a b )c + 645120C a b
+--R          *
+--R             x
+--R         + 
+--R                      8 4                7 2             8              9  3
+--R           11796480A a c  + (- 5898240A a b  - 5898240B a b - 1966080C a )c
+--R         + 
+--R                     6 4             7 3             8 2  2
+--R           (737280A a b  + 2949120B a b  + 4423680C a b )c
+--R         + 
+--R                       6 5             7 4              6 6
+--R           (- 368640B a b  - 1843200C a b )c + 215040C a b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                         4 2            5   5
+--R               (921600A a b  + 589824B a b)c
+--R             + 
+--R                         3 4           4 3            5 2  4
+--R               (629760A a b  + 30720B a b  - 497664C a b )c
+--R             + 
+--R                          2 6            3 5            4 4  3
+--R               (- 57600A a b  - 278016B a b  - 122880C a b )c
+--R             + 
+--R                           8           2 7            3 6  2
+--R               (- 8640A a b  + 28800B a b  + 171776C a b )c
+--R             + 
+--R                         9           2 8              10
+--R               (4320B a b  - 15360C a b )c - 2520C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                          5              6  5
+--R               (1843200A a b + 1179648B a )c
+--R             + 
+--R                          4 3             5 2            6   4
+--R               (6174720A a b  + 3207168B a b  - 995328C a b)c
+--R             + 
+--R                         3 5             4 4             5 3  3
+--R               (376320A a b  - 2227200B a b  - 2899968C a b )c
+--R             + 
+--R                           2 7            3 6             4 5  2
+--R               (- 201600A a b  - 188160B a b  + 1236480C a b )c
+--R             + 
+--R                         2 8            3 7             2 9
+--R               (100800B a b  + 143360C a b )c - 58800C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                           5 2             6   4
+--R               (14745600A a b  + 9437184B a b)c
+--R             + 
+--R                          4 4             5 3             6 2  3
+--R               (6389760A a b  - 1867776B a b  - 7962624C a b )c
+--R             + 
+--R                            3 6             4 5           5 4  2
+--R               (- 1290240A a b  - 3194880B a b  + 24576C a b )c
+--R             + 
+--R                         3 7             4 6              3 8
+--R               (645120B a b  + 2078720C a b )c - 376320C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                          6              7  4
+--R               (9830400A a b + 6291456B a )c
+--R             + 
+--R                           5 3             6 2             7   3
+--R               (20643840A a b  + 9240576B a b  - 5308416C a b)c
+--R             + 
+--R                            4 5              5 4             6 3  2
+--R               (- 3317760A a b  - 10321920B a b  - 8830976C a b )c
+--R             + 
+--R                          4 6             5 5              4 7
+--R               (1658880B a b  + 6574080C a b )c - 967680C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                           6 2              7   3
+--R               (24576000A a b  + 15728640B a b)c
+--R             + 
+--R                            5 4              6 3              7 2  2
+--R               (- 3686400A a b  - 12288000B a b  - 13271040C a b )c
+--R             + 
+--R                          5 5             6 4               5 6
+--R               (1843200B a b  + 7782400C a b )c - 1075200C a b
+--R          *
+--R             x
+--R         + 
+--R                      7              8  3
+--R           (9830400A a b + 6291456B a )c
+--R         + 
+--R                        6 3             7 2             8   2
+--R           (- 1474560A a b  - 4915200B a b  - 5308416C a b)c
+--R         + 
+--R                     6 4             7 3              6 5
+--R           (737280B a b  + 3112960C a b )c - 430080C a b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R     + 
+--R                           4             5  6
+--R               (- 307200A a b - 196608B a )c
+--R             + 
+--R                            3 3            4 2            5   5
+--R               (- 1105920A a b  - 583680B a b  + 165888C a b)c
+--R             + 
+--R                           2 5            3 4            4 3  4
+--R               (- 115200A a b  + 368640B a b  + 524800C a b )c
+--R             + 
+--R                          7           2 6            3 5  3
+--R               (38400A a b  + 54528B a b  - 195840C a b )c
+--R             + 
+--R                      9             8           2 7  2
+--R               (720A b  - 19200B a b  - 38208C a b )c
+--R             + 
+--R                        10             9           11
+--R               (- 360B b   + 11080C a b )c + 210C b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                            4 2             5   5
+--R               (- 5529600A a b  - 3538944B a b)c
+--R             + 
+--R                            3 4            4 3             5 2  4
+--R               (- 3778560A a b  - 184320B a b  + 2985984C a b )c
+--R             + 
+--R                         2 6             3 5            4 4  3
+--R               (345600A a b  + 1668096B a b  + 737280C a b )c
+--R             + 
+--R                          8            2 7             3 6  2
+--R               (51840A a b  - 172800B a b  - 1030656C a b )c
+--R             + 
+--R                            9           2 8               10
+--R               (- 25920B a b  + 92160C a b )c + 15120C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                            5              6  5
+--R               (- 5529600A a b - 3538944B a )c
+--R             + 
+--R                             4 3             5 2             6   4
+--R               (- 18524160A a b  - 9621504B a b  + 2985984C a b)c
+--R             + 
+--R                            3 5             4 4             5 3  3
+--R               (- 1128960A a b  + 6681600B a b  + 8699904C a b )c
+--R             + 
+--R                         2 7            3 6             4 5  2
+--R               (604800A a b  + 564480B a b  - 3709440C a b )c
+--R             + 
+--R                           2 8            3 7              2 9
+--R               (- 302400B a b  - 430080C a b )c + 176400C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                             5 2              6   4
+--R               (- 29491200A a b  - 18874368B a b)c
+--R             + 
+--R                             4 4             5 3              6 2  3
+--R               (- 12779520A a b  + 3735552B a b  + 15925248C a b )c
+--R             + 
+--R                          3 6             4 5           5 4  2
+--R               (2580480A a b  + 6389760B a b  - 49152C a b )c
+--R             + 
+--R                            3 7             4 6              3 8
+--R               (- 1290240B a b  - 4157440C a b )c + 752640C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                             6              7  4
+--R               (- 14745600A a b - 9437184B a )c
+--R             + 
+--R                             5 3              6 2             7   3
+--R               (- 30965760A a b  - 13860864B a b  + 7962624C a b)c
+--R             + 
+--R                          4 5              5 4              6 3  2
+--R               (4976640A a b  + 15482880B a b  + 13246464C a b )c
+--R             + 
+--R                            4 6             5 5               4 7
+--R               (- 2488320B a b  - 9861120C a b )c + 1451520C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                             6 2              7   3
+--R               (- 29491200A a b  - 18874368B a b)c
+--R             + 
+--R                          5 4              6 3              7 2  2
+--R               (4423680A a b  + 14745600B a b  + 15925248C a b )c
+--R             + 
+--R                            5 5             6 4               5 6
+--R               (- 2211840B a b  - 9338880C a b )c + 1290240C a b
+--R          *
+--R             x
+--R         + 
+--R                        7              8  3
+--R           (- 9830400A a b - 6291456B a )c
+--R         + 
+--R                      6 3             7 2             8   2
+--R           (1474560A a b  + 4915200B a b  + 5308416C a b)c
+--R         + 
+--R                       6 4             7 3              6 5
+--R           (- 737280B a b  - 3112960C a b )c + 430080C a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                    2   6             3 5          5 4  5
+--R           (2949120a b c  + 2457600a b c  + 184320b c )x
+--R         + 
+--R                    3 6            2 2 5             4 4  4
+--R           (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R         + 
+--R                     3   5            2 3 4  3
+--R           (47185920a b c  + 27525120a b c )x
+--R         + 
+--R                     4 5            3 2 4  2            4   4             5 4
+--R           (31457280a c  + 70778880a b c )x  + 78643200a b c x + 31457280a c
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                     3 7           2 2 6            4 5         6 4  6
+--R           (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R         + 
+--R                       3   6            2 3 5             5 4  5
+--R           (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R         + 
+--R                       4 6            3 2 5            2 4 4  4
+--R           (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R         + 
+--R                       4   5            3 3 4  3
+--R           (- 94371840a b c  - 55050240a b c )x
+--R         + 
+--R                     5 5             4 2 4  2            5   4             6 4
+--R         (- 47185920a c  - 106168320a b c )x  - 94371840a b c x - 31457280a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                               4   6
+--R                   - 1105920A a b c
+--R                 + 
+--R                               3 3            4 2            5   5
+--R                   (- 368640A a b  + 552960B a b  + 184320C a b)c
+--R                 + 
+--R                             2 5            3 4            4 3  4
+--R                   (322560A a b  + 184320B a b  - 261120C a b )c
+--R                 + 
+--R                                7            2 6            3 5  3
+--R                   (- 23040A a b  - 161280B a b  - 161280C a b )c
+--R                 + 
+--R                             9             8           2 7  2
+--R                   (- 4320A b  + 11520B a b  + 97920C a b )c
+--R                 + 
+--R                           10            9            11
+--R                   (2160B b   - 6000C a b )c - 1260C b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                               5 6
+--R                   - 2211840A a c
+--R                 + 
+--R                                4 2             5             6  5
+--R                   (- 6635520A a b  + 1105920B a b + 368640C a )c
+--R                 + 
+--R                              3 4             4 3            5 2  4
+--R                   (2119680A a b  + 3317760B a b  + 460800C a b )c
+--R                 + 
+--R                             2 6             3 5             4 4  3
+--R                   (322560A a b  - 1059840B a b  - 2288640C a b )c
+--R                 + 
+--R                                 8            2 7            3 6  2
+--R                   (- 100800A a b  - 161280B a b  + 564480C a b )c
+--R                 + 
+--R                              9            2 8               10
+--R                   (50400B a b  + 110880C a b )c - 29400C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                5   5
+--R                   - 17694720A a b c
+--R                 + 
+--R                                4 3             5 2             6   4
+--R                   (- 1474560A a b  + 8847360B a b  + 2949120C a b)c
+--R                 + 
+--R                              3 5            4 4             5 3  3
+--R                   (4055040A a b  + 737280B a b  - 4915200C a b )c
+--R                 + 
+--R                               2 7             3 6             4 5  2
+--R                   (- 645120A a b  - 2027520B a b  - 1105920C a b )c
+--R                 + 
+--R                             2 8             3 7              2 9
+--R                   (322560B a b  + 1290240C a b )c - 188160C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                6 5
+--R                   - 11796480A a c
+--R                 + 
+--R                                 5 2             6              7  4
+--R                   (- 20643840A a b  + 5898240B a b + 1966080C a )c
+--R                 + 
+--R                               4 4              5 3  3
+--R                   (12533760A a b  + 10321920B a b )c
+--R                 + 
+--R                                3 6             4 5             5 4  2
+--R                   (- 1658880A a b  - 6266880B a b  - 8110080C a b )c
+--R                 + 
+--R                             3 7             4 6              3 8
+--R                   (829440B a b  + 3932160C a b )c - 483840C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                6   4
+--R                   - 29491200A a b c
+--R                 + 
+--R                               5 3              6 2             7   3
+--R                   (14745600A a b  + 14745600B a b  + 4915200C a b)c
+--R                 + 
+--R                                4 5             5 4              6 3  2
+--R                   (- 1843200A a b  - 7372800B a b  - 11059200C a b )c
+--R                 + 
+--R                             4 6             5 5              4 7
+--R                   (921600B a b  + 4608000C a b )c - 537600C a b
+--R              *
+--R                 x
+--R             + 
+--R                            7 4              6 2             7              8  3
+--R               - 11796480A a c  + (5898240A a b  + 5898240B a b + 1966080C a )c
+--R             + 
+--R                           5 4             6 3             7 2  2
+--R               (- 737280A a b  - 2949120B a b  - 4423680C a b )c
+--R             + 
+--R                         5 5             6 4              5 6
+--R               (368640B a b  + 1843200C a b )c - 215040C a b
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + b x + a
+--R         + 
+--R                            5 7              4 2            5            6  6
+--R                   368640A a c  + (1198080A a b  - 184320B a b - 61440C a )c
+--R                 + 
+--R                               3 4            4 3           5 2  5
+--R                   (- 322560A a b  - 599040B a b  - 92160C a b )c
+--R                 + 
+--R                              2 6            3 5            4 4  4
+--R                   (- 80640A a b  + 161280B a b  + 403200C a b )c
+--R                 + 
+--R                              8           2 7           3 6  3
+--R                   (18720A a b  + 40320B a b  - 80640C a b )c
+--R                 + 
+--R                          10            9           2 8  2
+--R                   (360A b   - 9360B a b  - 26640C a b )c
+--R                 + 
+--R                            11            10           12
+--R                   (- 180B b   + 5400C a b  )c + 105C b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             5   6
+--R                   6635520A a b c
+--R                 + 
+--R                              4 3             5 2             6   5
+--R                   (2211840A a b  - 3317760B a b  - 1105920C a b)c
+--R                 + 
+--R                                3 5             4 4             5 3  4
+--R                   (- 1935360A a b  - 1105920B a b  + 1566720C a b )c
+--R                 + 
+--R                             2 7            3 6            4 5  3
+--R                   (138240A a b  + 967680B a b  + 967680C a b )c
+--R                 + 
+--R                              9           2 8            3 7  2
+--R                   (25920A a b  - 69120B a b  - 587520C a b )c
+--R                 + 
+--R                                10           2 9              11
+--R                   (- 12960B a b   + 36000C a b )c + 7560C a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             6 6
+--R                   6635520A a c
+--R                 + 
+--R                               5 2             6              7  5
+--R                   (19906560A a b  - 3317760B a b - 1105920C a )c
+--R                 + 
+--R                                4 4             5 3             6 2  4
+--R                   (- 6359040A a b  - 9953280B a b  - 1382400C a b )c
+--R                 + 
+--R                               3 6             4 5             5 4  3
+--R                   (- 967680A a b  + 3179520B a b  + 6865920C a b )c
+--R                 + 
+--R                             2 8            3 7             4 6  2
+--R                   (302400A a b  + 483840B a b  - 1693440C a b )c
+--R                 + 
+--R                               2 9            3 8             2 10
+--R                   (- 151200B a b  - 332640C a b )c + 88200C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              6   5
+--R                   35389440A a b c
+--R                 + 
+--R                              5 3              6 2             7   4
+--R                   (2949120A a b  - 17694720B a b  - 5898240C a b)c
+--R                 + 
+--R                                4 5             5 4             6 3  3
+--R                   (- 8110080A a b  - 1474560B a b  + 9830400C a b )c
+--R                 + 
+--R                              3 7             4 6             5 5  2
+--R                   (1290240A a b  + 4055040B a b  + 2211840C a b )c
+--R                 + 
+--R                               3 8             4 7              3 9
+--R                   (- 645120B a b  - 2580480C a b )c + 376320C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                              7 5
+--R                   17694720A a c
+--R                 + 
+--R                               6 2             7              8  4
+--R                   (30965760A a b  - 8847360B a b - 2949120C a )c
+--R                 + 
+--R                                 5 4              6 3  3
+--R                   (- 18800640A a b  - 15482880B a b )c
+--R                 + 
+--R                              4 6             5 5              6 4  2
+--R                   (2488320A a b  + 9400320B a b  + 12165120C a b )c
+--R                 + 
+--R                                4 7             5 6              4 8
+--R                   (- 1244160B a b  - 5898240C a b )c + 725760C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                              7   4
+--R                   35389440A a b c
+--R                 + 
+--R                                 6 3              7 2             8   3
+--R                   (- 17694720A a b  - 17694720B a b  - 5898240C a b)c
+--R                 + 
+--R                              5 5             6 4              7 3  2
+--R                   (2211840A a b  + 8847360B a b  + 13271040C a b )c
+--R                 + 
+--R                                5 6             6 5              5 7
+--R                   (- 1105920B a b  - 5529600C a b )c + 645120C a b
+--R              *
+--R                 x
+--R             + 
+--R                          8 4                7 2             8              9  3
+--R               11796480A a c  + (- 5898240A a b  - 5898240B a b - 1966080C a )c
+--R             + 
+--R                         6 4             7 3             8 2  2
+--R               (737280A a b  + 2949120B a b  + 4423680C a b )c
+--R             + 
+--R                           6 5             7 4              6 6
+--R               (- 368640B a b  - 1843200C a b )c + 215040C a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                             4   6
+--R                   2211840A a b c
+--R                 + 
+--R                             3 3             4 2            5   5
+--R                   (737280A a b  - 1105920B a b  - 368640C a b)c
+--R                 + 
+--R                               2 5            3 4            4 3  4
+--R                   (- 645120A a b  - 368640B a b  + 522240C a b )c
+--R                 + 
+--R                              7            2 6            3 5  3
+--R                   (46080A a b  + 322560B a b  + 322560C a b )c
+--R                 + 
+--R                           9             8            2 7  2
+--R                   (8640A b  - 23040B a b  - 195840C a b )c
+--R                 + 
+--R                             10             9            11
+--R                   (- 4320B b   + 12000C a b )c + 2520C b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             5 6
+--R                   4423680A a c
+--R                 + 
+--R                               4 2             5             6  5
+--R                   (13271040A a b  - 2211840B a b - 737280C a )c
+--R                 + 
+--R                                3 4             4 3            5 2  4
+--R                   (- 4239360A a b  - 6635520B a b  - 921600C a b )c
+--R                 + 
+--R                               2 6             3 5             4 4  3
+--R                   (- 645120A a b  + 2119680B a b  + 4577280C a b )c
+--R                 + 
+--R                               8            2 7             3 6  2
+--R                   (201600A a b  + 322560B a b  - 1128960C a b )c
+--R                 + 
+--R                                 9            2 8               10
+--R                   (- 100800B a b  - 221760C a b )c + 58800C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              5   5
+--R                   35389440A a b c
+--R                 + 
+--R                              4 3              5 2             6   4
+--R                   (2949120A a b  - 17694720B a b  - 5898240C a b)c
+--R                 + 
+--R                                3 5             4 4             5 3  3
+--R                   (- 8110080A a b  - 1474560B a b  + 9830400C a b )c
+--R                 + 
+--R                              2 7             3 6             4 5  2
+--R                   (1290240A a b  + 4055040B a b  + 2211840C a b )c
+--R                 + 
+--R                               2 8             3 7              2 9
+--R                   (- 645120B a b  - 2580480C a b )c + 376320C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                              6 5
+--R                   23592960A a c
+--R                 + 
+--R                               5 2              6              7  4
+--R                   (41287680A a b  - 11796480B a b - 3932160C a )c
+--R                 + 
+--R                                 4 4              5 3  3
+--R                   (- 25067520A a b  - 20643840B a b )c
+--R                 + 
+--R                              3 6              4 5              5 4  2
+--R                   (3317760A a b  + 12533760B a b  + 16220160C a b )c
+--R                 + 
+--R                                3 7             4 6              3 8
+--R                   (- 1658880B a b  - 7864320C a b )c + 967680C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                              6   4
+--R                   58982400A a b c
+--R                 + 
+--R                                 5 3              6 2             7   3
+--R                   (- 29491200A a b  - 29491200B a b  - 9830400C a b)c
+--R                 + 
+--R                              4 5              5 4              6 3  2
+--R                   (3686400A a b  + 14745600B a b  + 22118400C a b )c
+--R                 + 
+--R                                4 6             5 5               4 7
+--R                   (- 1843200B a b  - 9216000C a b )c + 1075200C a b
+--R              *
+--R                 x
+--R             + 
+--R                          7 4
+--R               23592960A a c
+--R             + 
+--R                             6 2              7              8  3
+--R               (- 11796480A a b  - 11796480B a b - 3932160C a )c
+--R             + 
+--R                          5 4             6 3             7 2  2
+--R               (1474560A a b  + 5898240B a b  + 8847360C a b )c
+--R             + 
+--R                           5 5             6 4              5 6
+--R               (- 737280B a b  - 3686400C a b )c + 430080C a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                              5 7
+--R                   - 737280A a c
+--R                 + 
+--R                                4 2            5             6  6
+--R                   (- 2396160A a b  + 368640B a b + 122880C a )c
+--R                 + 
+--R                             3 4             4 3            5 2  5
+--R                   (645120A a b  + 1198080B a b  + 184320C a b )c
+--R                 + 
+--R                             2 6            3 5            4 4  4
+--R                   (161280A a b  - 322560B a b  - 806400C a b )c
+--R                 + 
+--R                                8           2 7            3 6  3
+--R                   (- 37440A a b  - 80640B a b  + 161280C a b )c
+--R                 + 
+--R                            10             9           2 8  2
+--R                   (- 720A b   + 18720B a b  + 53280C a b )c
+--R                 + 
+--R                          11             10           12
+--R                   (360B b   - 10800C a b  )c - 210C b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                                5   6
+--R                   - 13271040A a b c
+--R                 + 
+--R                                4 3             5 2             6   5
+--R                   (- 4423680A a b  + 6635520B a b  + 2211840C a b)c
+--R                 + 
+--R                              3 5             4 4             5 3  4
+--R                   (3870720A a b  + 2211840B a b  - 3133440C a b )c
+--R                 + 
+--R                               2 7             3 6             4 5  3
+--R                   (- 276480A a b  - 1935360B a b  - 1935360C a b )c
+--R                 + 
+--R                                9            2 8             3 7  2
+--R                   (- 51840A a b  + 138240B a b  + 1175040C a b )c
+--R                 + 
+--R                              10           2 9               11
+--R                   (25920B a b   - 72000C a b )c - 15120C a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                                6 6
+--R                   - 13271040A a c
+--R                 + 
+--R                                 5 2             6              7  5
+--R                   (- 39813120A a b  + 6635520B a b + 2211840C a )c
+--R                 + 
+--R                               4 4              5 3             6 2  4
+--R                   (12718080A a b  + 19906560B a b  + 2764800C a b )c
+--R                 + 
+--R                              3 6             4 5              5 4  3
+--R                   (1935360A a b  - 6359040B a b  - 13731840C a b )c
+--R                 + 
+--R                               2 8            3 7             4 6  2
+--R                   (- 604800A a b  - 967680B a b  + 3386880C a b )c
+--R                 + 
+--R                             2 9            3 8              2 10
+--R                   (302400B a b  + 665280C a b )c - 176400C a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                6   5
+--R                   - 70778880A a b c
+--R                 + 
+--R                                5 3              6 2              7   4
+--R                   (- 5898240A a b  + 35389440B a b  + 11796480C a b)c
+--R                 + 
+--R                               4 5             5 4              6 3  3
+--R                   (16220160A a b  + 2949120B a b  - 19660800C a b )c
+--R                 + 
+--R                                3 7             4 6             5 5  2
+--R                   (- 2580480A a b  - 8110080B a b  - 4423680C a b )c
+--R                 + 
+--R                              3 8             4 7              3 9
+--R                   (1290240B a b  + 5160960C a b )c - 752640C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                                7 5
+--R                   - 35389440A a c
+--R                 + 
+--R                                 6 2              7              8  4
+--R                   (- 61931520A a b  + 17694720B a b + 5898240C a )c
+--R                 + 
+--R                               5 4              6 3  3
+--R                   (37601280A a b  + 30965760B a b )c
+--R                 + 
+--R                                4 6              5 5              6 4  2
+--R                   (- 4976640A a b  - 18800640B a b  - 24330240C a b )c
+--R                 + 
+--R                              4 7              5 6               4 8
+--R                   (2488320B a b  + 11796480C a b )c - 1451520C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                                7   4
+--R                   - 70778880A a b c
+--R                 + 
+--R                               6 3              7 2              8   3
+--R                   (35389440A a b  + 35389440B a b  + 11796480C a b)c
+--R                 + 
+--R                                5 5              6 4              7 3  2
+--R                   (- 4423680A a b  - 17694720B a b  - 26542080C a b )c
+--R                 + 
+--R                              5 6              6 5               5 7
+--R                   (2211840B a b  + 11059200C a b )c - 1290240C a b
+--R              *
+--R                 x
+--R             + 
+--R                            8 4
+--R               - 23592960A a c
+--R             + 
+--R                           7 2              8              9  3
+--R               (11796480A a b  + 11796480B a b + 3932160C a )c
+--R             + 
+--R                            6 4             7 3             8 2  2
+--R               (- 1474560A a b  - 5898240B a b  - 8847360C a b )c
+--R             + 
+--R                         6 5             7 4              6 6
+--R               (737280B a b  + 3686400C a b )c - 430080C a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- c \|c x  + b x + a  - \|- c \|a
+--R         atan(------------------------------------)
+--R                               c x
+--R     + 
+--R                         4 2            5   5
+--R               (921600A a b  + 589824B a b)c
+--R             + 
+--R                         3 4           4 3            5 2  4
+--R               (629760A a b  + 30720B a b  - 497664C a b )c
+--R             + 
+--R                          2 6            3 5            4 4  3
+--R               (- 57600A a b  - 278016B a b  - 122880C a b )c
+--R             + 
+--R                           8           2 7            3 6  2
+--R               (- 8640A a b  + 28800B a b  + 171776C a b )c
+--R             + 
+--R                         9           2 8              10
+--R               (4320B a b  - 15360C a b )c - 2520C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                          5              6  5
+--R               (1843200A a b + 1179648B a )c
+--R             + 
+--R                          4 3             5 2            6   4
+--R               (6174720A a b  + 3207168B a b  - 995328C a b)c
+--R             + 
+--R                         3 5             4 4             5 3  3
+--R               (376320A a b  - 2227200B a b  - 2899968C a b )c
+--R             + 
+--R                           2 7            3 6             4 5  2
+--R               (- 201600A a b  - 188160B a b  + 1236480C a b )c
+--R             + 
+--R                         2 8            3 7             2 9
+--R               (100800B a b  + 143360C a b )c - 58800C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                           5 2             6   4
+--R               (14745600A a b  + 9437184B a b)c
+--R             + 
+--R                          4 4             5 3             6 2  3
+--R               (6389760A a b  - 1867776B a b  - 7962624C a b )c
+--R             + 
+--R                            3 6             4 5           5 4  2
+--R               (- 1290240A a b  - 3194880B a b  + 24576C a b )c
+--R             + 
+--R                         3 7             4 6              3 8
+--R               (645120B a b  + 2078720C a b )c - 376320C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                          6              7  4
+--R               (9830400A a b + 6291456B a )c
+--R             + 
+--R                           5 3             6 2             7   3
+--R               (20643840A a b  + 9240576B a b  - 5308416C a b)c
+--R             + 
+--R                            4 5              5 4             6 3  2
+--R               (- 3317760A a b  - 10321920B a b  - 8830976C a b )c
+--R             + 
+--R                          4 6             5 5              4 7
+--R               (1658880B a b  + 6574080C a b )c - 967680C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                           6 2              7   3
+--R               (24576000A a b  + 15728640B a b)c
+--R             + 
+--R                            5 4              6 3              7 2  2
+--R               (- 3686400A a b  - 12288000B a b  - 13271040C a b )c
+--R             + 
+--R                          5 5             6 4               5 6
+--R               (1843200B a b  + 7782400C a b )c - 1075200C a b
+--R          *
+--R             x
+--R         + 
+--R                      7              8  3
+--R           (9830400A a b + 6291456B a )c
+--R         + 
+--R                        6 3             7 2             8   2
+--R           (- 1474560A a b  - 4915200B a b  - 5308416C a b)c
+--R         + 
+--R                     6 4             7 3              6 5
+--R           (737280B a b  + 3112960C a b )c - 430080C a b
+--R      *
+--R                    +--------------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b x + a
+--R     + 
+--R                           4             5  6
+--R               (- 307200A a b - 196608B a )c
+--R             + 
+--R                            3 3            4 2            5   5
+--R               (- 1105920A a b  - 583680B a b  + 165888C a b)c
+--R             + 
+--R                           2 5            3 4            4 3  4
+--R               (- 115200A a b  + 368640B a b  + 524800C a b )c
+--R             + 
+--R                          7           2 6            3 5  3
+--R               (38400A a b  + 54528B a b  - 195840C a b )c
+--R             + 
+--R                      9             8           2 7  2
+--R               (720A b  - 19200B a b  - 38208C a b )c
+--R             + 
+--R                        10             9           11
+--R               (- 360B b   + 11080C a b )c + 210C b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                            4 2             5   5
+--R               (- 5529600A a b  - 3538944B a b)c
+--R             + 
+--R                            3 4            4 3             5 2  4
+--R               (- 3778560A a b  - 184320B a b  + 2985984C a b )c
+--R             + 
+--R                         2 6             3 5            4 4  3
+--R               (345600A a b  + 1668096B a b  + 737280C a b )c
+--R             + 
+--R                          8            2 7             3 6  2
+--R               (51840A a b  - 172800B a b  - 1030656C a b )c
+--R             + 
+--R                            9           2 8               10
+--R               (- 25920B a b  + 92160C a b )c + 15120C a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                            5              6  5
+--R               (- 5529600A a b - 3538944B a )c
+--R             + 
+--R                             4 3             5 2             6   4
+--R               (- 18524160A a b  - 9621504B a b  + 2985984C a b)c
+--R             + 
+--R                            3 5             4 4             5 3  3
+--R               (- 1128960A a b  + 6681600B a b  + 8699904C a b )c
+--R             + 
+--R                         2 7            3 6             4 5  2
+--R               (604800A a b  + 564480B a b  - 3709440C a b )c
+--R             + 
+--R                           2 8            3 7              2 9
+--R               (- 302400B a b  - 430080C a b )c + 176400C a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                             5 2              6   4
+--R               (- 29491200A a b  - 18874368B a b)c
+--R             + 
+--R                             4 4             5 3              6 2  3
+--R               (- 12779520A a b  + 3735552B a b  + 15925248C a b )c
+--R             + 
+--R                          3 6             4 5           5 4  2
+--R               (2580480A a b  + 6389760B a b  - 49152C a b )c
+--R             + 
+--R                            3 7             4 6              3 8
+--R               (- 1290240B a b  - 4157440C a b )c + 752640C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                             6              7  4
+--R               (- 14745600A a b - 9437184B a )c
+--R             + 
+--R                             5 3              6 2             7   3
+--R               (- 30965760A a b  - 13860864B a b  + 7962624C a b)c
+--R             + 
+--R                          4 5              5 4              6 3  2
+--R               (4976640A a b  + 15482880B a b  + 13246464C a b )c
+--R             + 
+--R                            4 6             5 5               4 7
+--R               (- 2488320B a b  - 9861120C a b )c + 1451520C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                             6 2              7   3
+--R               (- 29491200A a b  - 18874368B a b)c
+--R             + 
+--R                          5 4              6 3              7 2  2
+--R               (4423680A a b  + 14745600B a b  + 15925248C a b )c
+--R             + 
+--R                            5 5             6 4               5 6
+--R               (- 2211840B a b  - 9338880C a b )c + 1290240C a b
+--R          *
+--R             x
+--R         + 
+--R                        7              8  3
+--R           (- 9830400A a b - 6291456B a )c
+--R         + 
+--R                      6 3             7 2             8   2
+--R           (1474560A a b  + 4915200B a b  + 5308416C a b)c
+--R         + 
+--R                       6 4             7 3              6 5
+--R           (- 737280B a b  - 3112960C a b )c + 430080C a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                    2   6             3 5          5 4  5
+--R           (2949120a b c  + 2457600a b c  + 184320b c )x
+--R         + 
+--R                    3 6            2 2 5             4 4  4
+--R           (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R         + 
+--R                     3   5            2 3 4  3
+--R           (47185920a b c  + 27525120a b c )x
+--R         + 
+--R                     4 5            3 2 4  2            4   4             5 4
+--R           (31457280a c  + 70778880a b c )x  + 78643200a b c x + 31457280a c
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                     3 7           2 2 6            4 5         6 4  6
+--R           (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R         + 
+--R                       3   6            2 3 5             5 4  5
+--R           (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R         + 
+--R                       4 6            3 2 5            2 4 4  4
+--R           (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R         + 
+--R                       4   5            3 3 4  3
+--R           (- 94371840a b c  - 55050240a b c )x
+--R         + 
+--R                     5 5             4 2 4  2            5   4             6 4
+--R         (- 47185920a c  - 106168320a b c )x  - 94371840a b c x - 31457280a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 318
+
+--S 319 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 319
+
+)clear all
+
+--S 320 of 556
+t0:=(a+b*x+c*x^2)^(1/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R                         +--------------+
+--R            2            |   2
+--R   (1)  (C x  + B x + A)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 556
+r0:=1/24*(8*B*c-5*b*C+6*c*C*x)*(a+b*x+c*x^2)^(3/2)/c^2+1/128*(b^2-4*a*c)*_
+   (8*b*B*c-5*b^2*C-4*c*(4*A*c-a*C))*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/c^(7/2)-1/64*(8*b*B*c-16*A*c^2-5*b^2*C+4*a*c*C)*_
+   (b+2*c*x)*sqrt(a+b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                   3           2                  2  2         3          2
+--R           192A a c  + (- 48A b  - 96B a b - 48C a )c  + (24B b  + 72C a b )c
+--R         + 
+--R                  4
+--R           - 15C b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                3 3          3          2  2
+--R           96C c x  + (128B c  + 16C b c )x
+--R         + 
+--R                  3                   2        2                       2
+--R           (192A c  + (32B b + 48C a)c  - 20C b c)x + (96A b + 128B a)c
+--R         + 
+--R                   2                     3
+--R           (- 48B b  - 104C a b)c + 30C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R         3 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            2   4             2 2          3   3
+--R                     6144A a b c  + (- 3072B a b  - 1536C a b)c
+--R                   + 
+--R                            5          2 3  2          6          5           7
+--R                   (- 384A b  + 1920C a b )c  + (192B b  + 96C a b )c - 120C b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                             3 4            2 2          3           4  3
+--R                     12288A a c  + (12288A a b  - 6144B a b - 3072C a )c
+--R                   + 
+--R                                 4          2 3         3 2  2
+--R                     (- 3840A a b  - 6144B a b  + 768C a b )c
+--R                   + 
+--R                               5          2 4              6
+--R                     (1920B a b  + 4800C a b )c - 1200C a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                             3   3             2 3           3 2          4   2
+--R                     36864A a b c  + (- 9216A a b  - 18432B a b  - 9216C a b)c
+--R                   + 
+--R                             2 4           3 3            2 5
+--R                     (4608B a b  + 13824C a b )c - 2880C a b
+--R                *
+--R                   x
+--R               + 
+--R                         4 3             3 2           4           5  2
+--R                 24576A a c  + (- 6144A a b  - 12288B a b - 6144C a )c
+--R               + 
+--R                         3 3          4 2            3 4
+--R                 (3072B a b  + 9216C a b )c - 1920C a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                          3 5             2 2          3          4  4
+--R                 - 3072A a c  + (- 3840A a b  + 1536B a b + 768C a )c
+--R               + 
+--R                          4          2 3  3
+--R                 (960A a b  + 1920B a b )c
+--R               + 
+--R                       6           5          2 4  2           7           6
+--R                 (48A b  - 480B a b  - 1440C a b )c  + (- 24B b  + 288C a b )c
+--R               + 
+--R                      8
+--R                 15C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           3   4            3 2          4   3
+--R                 - 24576A a b c  + (12288B a b  + 6144C a b)c
+--R               + 
+--R                           5          3 3  2              6         2 5
+--R                 (1536A a b  - 7680C a b )c  + (- 768B a b  - 384C a b )c
+--R               + 
+--R                         7
+--R                 480C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                           4 4              3 2           4           5  3
+--R                 - 24576A a c  + (- 24576A a b  + 12288B a b + 6144C a )c
+--R               + 
+--R                         2 4           3 3          4 2  2
+--R                 (7680A a b  + 12288B a b  - 1536C a b )c
+--R               + 
+--R                           2 5          3 4            2 6
+--R                 (- 3840B a b  - 9600C a b )c + 2400C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           4   3            3 3           4 2           5   2
+--R                 - 49152A a b c  + (12288A a b  + 24576B a b  + 12288C a b)c
+--R               + 
+--R                           3 4           4 3            3 5
+--R                 (- 6144B a b  - 18432C a b )c + 3840C a b
+--R            *
+--R               x
+--R           + 
+--R                       5 3           4 2           5           6  2
+--R             - 24576A a c  + (6144A a b  + 12288B a b + 6144C a )c
+--R           + 
+--R                       4 3          5 2            4 4
+--R             (- 3072B a b  - 9216C a b )c + 1920C a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                       2 5            2 4        4 3  7
+--R             (- 1536C a c  - 2304C a b c  - 96C b c )x
+--R           + 
+--R                          2 5               2           2   4
+--R                 - 2048B a c  + (- 3072B a b  - 12544C a b)c
+--R               + 
+--R                          4            3  3        5 2
+--R                 (- 128B b  - 3456C a b )c  - 16C b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          2 5               2           2            3  4
+--R                 - 3072A a c  + (- 4608A a b  - 16896B a b - 13056C a )c
+--R               + 
+--R                          4            3           2 2  3
+--R                 (- 192A b  - 4864B a b  - 18240C a b )c
+--R               + 
+--R                         5          4  2        6
+--R                 (- 32B b  - 80C a b )c  + 20C b c
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                            2            3  4
+--R                 (- 26112A a b - 18432B a )c
+--R               + 
+--R                             3           2 2           3   3
+--R                 (- 8448A a b  - 26880B a b  - 31104C a b)c
+--R               + 
+--R                         5         2 3  2         6          5          7
+--R                 (- 96A b  + 480C a b )c  + (48B b  + 24C a b )c - 30C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           3 4              2 2           3            4  3
+--R                 - 24576A a c  + (- 39936A a b  - 49152B a b - 18432C a )c
+--R               + 
+--R                             4          2 3         3 2  2
+--R                 (- 2304A a b  - 3584B a b  + 768C a b )c
+--R               + 
+--R                           5          2 4             6
+--R                 (1152B a b  + 2816C a b )c - 720C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                            3            4  3
+--R                 (- 55296A a b - 24576B a )c
+--R               + 
+--R                           2 3           3 2          4   2
+--R                 (- 7680A a b  - 15360B a b  - 7680C a b)c
+--R               + 
+--R                         2 4           3 3            2 5
+--R                 (3840B a b  + 11520C a b )c - 2400C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           4 3             3 2           4           5  2
+--R                 - 24576A a c  + (- 6144A a b  - 12288B a b - 6144C a )c
+--R               + 
+--R                         3 3          4 2            3 4
+--R                 (3072B a b  + 9216C a b )c - 1920C a b
+--R            *
+--R               x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                         5         3 4  8
+--R             (3072C a b c  + 768C b c )x
+--R           + 
+--R                                       2  5           3             2  4
+--R                   (4096B a b + 6144C a )c  + (1024B b  + 11264C a b )c
+--R                 + 
+--R                         4 3
+--R                   896C b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                                     2  5
+--R                 (6144A a b + 8192B a )c
+--R               + 
+--R                         3             2           2   4
+--R                 (1536A b  + 15360B a b  + 30208C a b)c
+--R               + 
+--R                         4            3  3        5 2
+--R                 (1280B b  + 9984C a b )c  - 32C b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                         2 5              2           2            3  4
+--R                 12288A a c  + (24576A a b  + 43008B a b + 21504C a )c
+--R               + 
+--R                         4             3           2 2  3
+--R                 (2304A b  + 14336B a b  + 31488C a b )c
+--R               + 
+--R                          5           4  2        6
+--R                 (- 128B b  - 320C a b )c  + 80C b c
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                          2            3  4
+--R                 (59904A a b + 30720B a )c
+--R               + 
+--R                            3           2 2           3   3
+--R                 (25344A a b  + 52992B a b  + 42624C a b)c
+--R               + 
+--R                        5           4          2 3  2            6           5
+--R                 (672A b  - 512B a b  - 4896C a b )c  + (- 336B b  + 152C a b )c
+--R               + 
+--R                       7
+--R                 210C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         3 4            2 2           3            4  3
+--R                 36864A a c  + (67584A a b  + 67584B a b + 21504C a )c
+--R               + 
+--R                           4          2 3          3 2  2
+--R                 (5376A a b  + 8192B a b  - 2304C a b )c
+--R               + 
+--R                             5          2 4              6
+--R                 (- 2688B a b  - 6464C a b )c + 1680C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          3            4  3
+--R                 (67584A a b + 24576B a )c
+--R               + 
+--R                          2 3           3 2           4   2
+--R                 (10752A a b  + 21504B a b  + 10752C a b)c
+--R               + 
+--R                           2 4           3 3            2 5
+--R                 (- 5376B a b  - 16128C a b )c + 3360C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         4 3           3 2           4           5  2
+--R                 24576A a c  + (6144A a b  + 12288B a b + 6144C a )c
+--R               + 
+--R                           3 3          4 2            3 4
+--R                 (- 3072B a b  - 9216C a b )c + 1920C a b
+--R            *
+--R               x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                        4        3 3  3          2 4           2 3  2
+--R             (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R           + 
+--R                   2   3          3 3
+--R             73728a b c x + 49152a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                     2 5          2 4       4 3  4
+--R             (- 6144a c  - 9216a b c  - 384b c )x
+--R           + 
+--R                      2   4           3 3  3            3 4         2 2 3  2
+--R             (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R           + 
+--R                     3   3          4 3
+--R             - 98304a b c x - 49152a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                            2   4             2 2          3   3
+--R                     6144A a b c  + (- 3072B a b  - 1536C a b)c
+--R                   + 
+--R                            5          2 3  2          6          5           7
+--R                   (- 384A b  + 1920C a b )c  + (192B b  + 96C a b )c - 120C b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                             3 4            2 2          3           4  3
+--R                     12288A a c  + (12288A a b  - 6144B a b - 3072C a )c
+--R                   + 
+--R                                 4          2 3         3 2  2
+--R                     (- 3840A a b  - 6144B a b  + 768C a b )c
+--R                   + 
+--R                               5          2 4              6
+--R                     (1920B a b  + 4800C a b )c - 1200C a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                             3   3             2 3           3 2          4   2
+--R                     36864A a b c  + (- 9216A a b  - 18432B a b  - 9216C a b)c
+--R                   + 
+--R                             2 4           3 3            2 5
+--R                     (4608B a b  + 13824C a b )c - 2880C a b
+--R                *
+--R                   x
+--R               + 
+--R                         4 3             3 2           4           5  2
+--R                 24576A a c  + (- 6144A a b  - 12288B a b - 6144C a )c
+--R               + 
+--R                         3 3          4 2            3 4
+--R                 (3072B a b  + 9216C a b )c - 1920C a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                          3 5             2 2          3          4  4
+--R                 - 3072A a c  + (- 3840A a b  + 1536B a b + 768C a )c
+--R               + 
+--R                          4          2 3  3
+--R                 (960A a b  + 1920B a b )c
+--R               + 
+--R                       6           5          2 4  2           7           6
+--R                 (48A b  - 480B a b  - 1440C a b )c  + (- 24B b  + 288C a b )c
+--R               + 
+--R                      8
+--R                 15C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           3   4            3 2          4   3
+--R                 - 24576A a b c  + (12288B a b  + 6144C a b)c
+--R               + 
+--R                           5          3 3  2              6         2 5
+--R                 (1536A a b  - 7680C a b )c  + (- 768B a b  - 384C a b )c
+--R               + 
+--R                         7
+--R                 480C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                           4 4              3 2           4           5  3
+--R                 - 24576A a c  + (- 24576A a b  + 12288B a b + 6144C a )c
+--R               + 
+--R                         2 4           3 3          4 2  2
+--R                 (7680A a b  + 12288B a b  - 1536C a b )c
+--R               + 
+--R                           2 5          3 4            2 6
+--R                 (- 3840B a b  - 9600C a b )c + 2400C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           4   3            3 3           4 2           5   2
+--R                 - 49152A a b c  + (12288A a b  + 24576B a b  + 12288C a b)c
+--R               + 
+--R                           3 4           4 3            3 5
+--R                 (- 6144B a b  - 18432C a b )c + 3840C a b
+--R            *
+--R               x
+--R           + 
+--R                       5 3           4 2           5           6  2
+--R             - 24576A a c  + (6144A a b  + 12288B a b + 6144C a )c
+--R           + 
+--R                       4 3          5 2            4 4
+--R             (- 3072B a b  - 9216C a b )c + 1920C a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                      2 5            2 4        4 3  7
+--R             (- 768C a c  - 1152C a b c  - 48C b c )x
+--R           + 
+--R                          2 5               2          2   4
+--R                 - 1024B a c  + (- 1536B a b  - 6272C a b)c
+--R               + 
+--R                         4            3  3       5 2
+--R                 (- 64B b  - 1728C a b )c  - 8C b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          2 5               2          2           3  4
+--R                 - 1536A a c  + (- 2304A a b  - 8448B a b - 6528C a )c
+--R               + 
+--R                         4            3          2 2  3
+--R                 (- 96A b  - 2432B a b  - 9120C a b )c
+--R               + 
+--R                         5          4  2        6
+--R                 (- 16B b  - 40C a b )c  + 10C b c
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                            2           3  4
+--R                 (- 13056A a b - 9216B a )c
+--R               + 
+--R                             3           2 2           3   3
+--R                 (- 4224A a b  - 13440B a b  - 15552C a b)c
+--R               + 
+--R                         5         2 3  2         6          5          7
+--R                 (- 48A b  + 240C a b )c  + (24B b  + 12C a b )c - 15C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           3 4              2 2           3           4  3
+--R                 - 12288A a c  + (- 19968A a b  - 24576B a b - 9216C a )c
+--R               + 
+--R                             4          2 3         3 2  2
+--R                 (- 1152A a b  - 1792B a b  + 384C a b )c
+--R               + 
+--R                          5          2 4             6
+--R                 (576B a b  + 1408C a b )c - 360C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                            3            4  3
+--R                 (- 27648A a b - 12288B a )c
+--R               + 
+--R                           2 3          3 2          4   2
+--R                 (- 3840A a b  - 7680B a b  - 3840C a b)c
+--R               + 
+--R                         2 4          3 3            2 5
+--R                 (1920B a b  + 5760C a b )c - 1200C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           4 3             3 2          4           5  2
+--R                 - 12288A a c  + (- 3072A a b  - 6144B a b - 3072C a )c
+--R               + 
+--R                         3 3          4 2           3 4
+--R                 (1536B a b  + 4608C a b )c - 960C a b
+--R            *
+--R               x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                         5         3 4  8
+--R             (1536C a b c  + 384C b c )x
+--R           + 
+--R                                  2  5          3            2  4         4 3  7
+--R             ((2048B a b + 3072C a )c  + (512B b  + 5632C a b )c  + 448C b c )x
+--R           + 
+--R                                     2  5
+--R                 (3072A a b + 4096B a )c
+--R               + 
+--R                        3            2           2   4
+--R                 (768A b  + 7680B a b  + 15104C a b)c
+--R               + 
+--R                        4            3  3        5 2
+--R                 (640B b  + 4992C a b )c  - 16C b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                        2 5              2           2            3  4
+--R                 6144A a c  + (12288A a b  + 21504B a b + 10752C a )c
+--R               + 
+--R                         4            3           2 2  3
+--R                 (1152A b  + 7168B a b  + 15744C a b )c
+--R               + 
+--R                         5           4  2        6
+--R                 (- 64B b  - 160C a b )c  + 40C b c
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                          2            3  4
+--R                 (29952A a b + 15360B a )c
+--R               + 
+--R                            3           2 2           3   3
+--R                 (12672A a b  + 26496B a b  + 21312C a b)c
+--R               + 
+--R                        5           4          2 3  2            6          5
+--R                 (336A b  - 256B a b  - 2448C a b )c  + (- 168B b  + 76C a b )c
+--R               + 
+--R                       7
+--R                 105C b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         3 4            2 2           3            4  3
+--R                 18432A a c  + (33792A a b  + 33792B a b + 10752C a )c
+--R               + 
+--R                           4          2 3          3 2  2
+--R                 (2688A a b  + 4096B a b  - 1152C a b )c
+--R               + 
+--R                             5          2 4             6
+--R                 (- 1344B a b  - 3232C a b )c + 840C a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          3            4  3
+--R                 (33792A a b + 12288B a )c
+--R               + 
+--R                         2 3           3 2          4   2
+--R                 (5376A a b  + 10752B a b  + 5376C a b)c
+--R               + 
+--R                           2 4          3 3            2 5
+--R                 (- 2688B a b  - 8064C a b )c + 1680C a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         4 3           3 2          4           5  2
+--R                 12288A a c  + (3072A a b  + 6144B a b + 3072C a )c
+--R               + 
+--R                           3 3          4 2           3 4
+--R                 (- 1536B a b  - 4608C a b )c + 960C a b
+--R            *
+--R               x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                       4        3 3  3          2 4           2 3  2
+--R             (6144a b c  + 1536b c )x  + (12288a c  + 15360a b c )x
+--R           + 
+--R                   2   3          3 3
+--R             36864a b c x + 24576a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                     2 5          2 4       4 3  4
+--R             (- 3072a c  - 4608a b c  - 192b c )x
+--R           + 
+--R                      2   4          3 3  3            3 4         2 2 3  2
+--R             (- 24576a b c  - 6144a b c )x  + (- 24576a c  - 30720a b c )x
+--R           + 
+--R                     3   3          4 3
+--R             - 49152a b c x - 24576a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 322
+
+--S 323 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          2   4             2 2          3   3
+--R                   6144A a b c  + (- 3072B a b  - 1536C a b)c
+--R                 + 
+--R                            5          2 3  2          6          5           7
+--R                   (- 384A b  + 1920C a b )c  + (192B b  + 96C a b )c - 120C b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                           3 4            2 2          3           4  3
+--R                   12288A a c  + (12288A a b  - 6144B a b - 3072C a )c
+--R                 + 
+--R                               4          2 3         3 2  2
+--R                   (- 3840A a b  - 6144B a b  + 768C a b )c
+--R                 + 
+--R                             5          2 4              6
+--R                   (1920B a b  + 4800C a b )c - 1200C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           3   3             2 3           3 2          4   2
+--R                   36864A a b c  + (- 9216A a b  - 18432B a b  - 9216C a b)c
+--R                 + 
+--R                           2 4           3 3            2 5
+--R                   (4608B a b  + 13824C a b )c - 2880C a b
+--R              *
+--R                 x
+--R             + 
+--R                       4 3             3 2           4           5  2
+--R               24576A a c  + (- 6144A a b  - 12288B a b - 6144C a )c
+--R             + 
+--R                       3 3          4 2            3 4
+--R               (3072B a b  + 9216C a b )c - 1920C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                        3 5             2 2          3          4  4
+--R               - 3072A a c  + (- 3840A a b  + 1536B a b + 768C a )c
+--R             + 
+--R                        4          2 3  3         6           5          2 4  2
+--R               (960A a b  + 1920B a b )c  + (48A b  - 480B a b  - 1440C a b )c
+--R             + 
+--R                       7           6          8
+--R               (- 24B b  + 288C a b )c + 15C b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                         3   4            3 2          4   3
+--R               - 24576A a b c  + (12288B a b  + 6144C a b)c
+--R             + 
+--R                         5          3 3  2              6         2 5
+--R               (1536A a b  - 7680C a b )c  + (- 768B a b  - 384C a b )c
+--R             + 
+--R                       7
+--R               480C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                         4 4              3 2           4           5  3
+--R               - 24576A a c  + (- 24576A a b  + 12288B a b + 6144C a )c
+--R             + 
+--R                       2 4           3 3          4 2  2
+--R               (7680A a b  + 12288B a b  - 1536C a b )c
+--R             + 
+--R                         2 5          3 4            2 6
+--R               (- 3840B a b  - 9600C a b )c + 2400C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                         4   3            3 3           4 2           5   2
+--R               - 49152A a b c  + (12288A a b  + 24576B a b  + 12288C a b)c
+--R             + 
+--R                         3 4           4 3            3 5
+--R               (- 6144B a b  - 18432C a b )c + 3840C a b
+--R          *
+--R             x
+--R         + 
+--R                     5 3           4 2           5           6  2
+--R           - 24576A a c  + (6144A a b  + 12288B a b + 6144C a )c
+--R         + 
+--R                     4 3          5 2            4 4
+--R           (- 3072B a b  - 9216C a b )c + 1920C a b
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                            2   4           2 2          3   3
+--R                   - 6144A a b c  + (3072B a b  + 1536C a b)c
+--R                 + 
+--R                          5          2 3  2            6          5           7
+--R                   (384A b  - 1920C a b )c  + (- 192B b  - 96C a b )c + 120C b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                             3 4              2 2          3           4  3
+--R                   - 12288A a c  + (- 12288A a b  + 6144B a b + 3072C a )c
+--R                 + 
+--R                             4          2 3         3 2  2
+--R                   (3840A a b  + 6144B a b  - 768C a b )c
+--R                 + 
+--R                               5          2 4              6
+--R                   (- 1920B a b  - 4800C a b )c + 1200C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                             3   3           2 3           3 2          4   2
+--R                   - 36864A a b c  + (9216A a b  + 18432B a b  + 9216C a b)c
+--R                 + 
+--R                             2 4           3 3            2 5
+--R                   (- 4608B a b  - 13824C a b )c + 2880C a b
+--R              *
+--R                 x
+--R             + 
+--R                         4 3           3 2           4           5  2
+--R               - 24576A a c  + (6144A a b  + 12288B a b + 6144C a )c
+--R             + 
+--R                         3 3          4 2            3 4
+--R               (- 3072B a b  - 9216C a b )c + 1920C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                      3 5           2 2          3          4  4
+--R               3072A a c  + (3840A a b  - 1536B a b - 768C a )c
+--R             + 
+--R                          4          2 3  3
+--R               (- 960A a b  - 1920B a b )c
+--R             + 
+--R                       6           5          2 4  2         7           6
+--R               (- 48A b  + 480B a b  + 1440C a b )c  + (24B b  - 288C a b )c
+--R             + 
+--R                      8
+--R               - 15C b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       3   4              3 2          4   3
+--R               24576A a b c  + (- 12288B a b  - 6144C a b)c
+--R             + 
+--R                           5          3 3  2            6         2 5
+--R               (- 1536A a b  + 7680C a b )c  + (768B a b  + 384C a b )c
+--R             + 
+--R                         7
+--R               - 480C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       4 4            3 2           4           5  3
+--R               24576A a c  + (24576A a b  - 12288B a b - 6144C a )c
+--R             + 
+--R                         2 4           3 3          4 2  2
+--R               (- 7680A a b  - 12288B a b  + 1536C a b )c
+--R             + 
+--R                       2 5          3 4            2 6
+--R               (3840B a b  + 9600C a b )c - 2400C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       4   3              3 3           4 2           5   2
+--R               49152A a b c  + (- 12288A a b  - 24576B a b  - 12288C a b)c
+--R             + 
+--R                       3 4           4 3            3 5
+--R               (6144B a b  + 18432C a b )c - 3840C a b
+--R          *
+--R             x
+--R         + 
+--R                   5 3             4 2           5           6  2
+--R           24576A a c  + (- 6144A a b  - 12288B a b - 6144C a )c
+--R         + 
+--R                   4 3          5 2            4 4
+--R           (3072B a b  + 9216C a b )c - 1920C a b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                       2 2          3   3
+--R               (3072A a b  + 4096B a b)c
+--R             + 
+--R                        4         2 3          3 2  2
+--R               (768A a b  - 512B a b  - 3328C a b )c
+--R             + 
+--R                          5         2 4             6
+--R               (- 384B a b  + 128C a b )c + 240C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       3           4  3
+--R               (6144A a b + 8192B a )c
+--R             + 
+--R                       2 3          3 2          4   2
+--R               (7680A a b  + 7168B a b  - 6656C a b)c
+--R             + 
+--R                         2 4          3 3            2 5
+--R               (- 3840B a b  - 6400C a b )c + 2400C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        3 2           4   2             3 3           4 2
+--R               (18432A a b  + 24576B a b)c  + (- 9216B a b  - 19968C a b )c
+--R             + 
+--R                      3 4
+--R               5760C a b
+--R          *
+--R             x
+--R         + 
+--R                  4            5  2             4 2           5             4 3
+--R         (12288A a b + 16384B a )c  + (- 6144B a b  - 13312C a b)c + 3840C a b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R     + 
+--R                         2           3  4
+--R               (- 1536A a b - 2048B a )c
+--R             + 
+--R                           3          2 2          3   3
+--R               (- 2304A a b  - 2304B a b  + 1664C a b)c
+--R             + 
+--R                       5            4          2 3  2         6           5
+--R               (- 96A b  + 1024B a b  + 2016C a b )c  + (48B b  - 616C a b )c
+--R             + 
+--R                      7
+--R               - 30C b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          2 2           3   3
+--R               (- 12288A a b  - 16384B a b)c
+--R             + 
+--R                           4          2 3           3 2  2
+--R               (- 3072A a b  + 2048B a b  + 13312C a b )c
+--R             + 
+--R                         5         2 4             6
+--R               (1536B a b  - 512C a b )c - 960C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                          3            4  3
+--R               (- 12288A a b - 16384B a )c
+--R             + 
+--R                          2 3           3 2           4   2
+--R               (- 15360A a b  - 14336B a b  + 13312C a b)c
+--R             + 
+--R                       2 4           3 3            2 5
+--R               (7680B a b  + 12800C a b )c - 4800C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                          3 2           4   2            3 3           4 2
+--R               (- 24576A a b  - 32768B a b)c  + (12288B a b  + 26624C a b )c
+--R             + 
+--R                        3 4
+--R               - 7680C a b
+--R          *
+--R             x
+--R         + 
+--R                    4            5  2           4 2           5             4 3
+--R         (- 12288A a b - 16384B a )c  + (6144B a b  + 13312C a b)c - 3840C a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                      4        3 3  3          2 4           2 3  2
+--R           (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R         + 
+--R                 2   3          3 3
+--R           73728a b c x + 49152a c
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                   2 5          2 4       4 3  4
+--R           (- 6144a c  - 9216a b c  - 384b c )x
+--R         + 
+--R                    2   4           3 3  3            3 4         2 2 3  2
+--R           (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R         + 
+--R                   3   3          4 3
+--R           - 98304a b c x - 49152a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                            2   4           2 2          3   3
+--R                   - 6144A a b c  + (3072B a b  + 1536C a b)c
+--R                 + 
+--R                          5          2 3  2            6          5           7
+--R                   (384A b  - 1920C a b )c  + (- 192B b  - 96C a b )c + 120C b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                             3 4              2 2          3           4  3
+--R                   - 12288A a c  + (- 12288A a b  + 6144B a b + 3072C a )c
+--R                 + 
+--R                             4          2 3         3 2  2
+--R                   (3840A a b  + 6144B a b  - 768C a b )c
+--R                 + 
+--R                               5          2 4              6
+--R                   (- 1920B a b  - 4800C a b )c + 1200C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                             3   3           2 3           3 2          4   2
+--R                   - 36864A a b c  + (9216A a b  + 18432B a b  + 9216C a b)c
+--R                 + 
+--R                             2 4           3 3            2 5
+--R                   (- 4608B a b  - 13824C a b )c + 2880C a b
+--R              *
+--R                 x
+--R             + 
+--R                         4 3           3 2           4           5  2
+--R               - 24576A a c  + (6144A a b  + 12288B a b + 6144C a )c
+--R             + 
+--R                         3 3          4 2            3 4
+--R               (- 3072B a b  - 9216C a b )c + 1920C a b
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + b x + a
+--R         + 
+--R                          3 5           2 2          3          4  4
+--R                   3072A a c  + (3840A a b  - 1536B a b - 768C a )c
+--R                 + 
+--R                              4          2 3  3
+--R                   (- 960A a b  - 1920B a b )c
+--R                 + 
+--R                           6           5          2 4  2         7           6
+--R                   (- 48A b  + 480B a b  + 1440C a b )c  + (24B b  - 288C a b )c
+--R                 + 
+--R                          8
+--R                   - 15C b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           3   4              3 2          4   3
+--R                   24576A a b c  + (- 12288B a b  - 6144C a b)c
+--R                 + 
+--R                               5          3 3  2            6         2 5
+--R                   (- 1536A a b  + 7680C a b )c  + (768B a b  + 384C a b )c
+--R                 + 
+--R                             7
+--R                   - 480C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                           4 4            3 2           4           5  3
+--R                   24576A a c  + (24576A a b  - 12288B a b - 6144C a )c
+--R                 + 
+--R                             2 4           3 3          4 2  2
+--R                   (- 7680A a b  - 12288B a b  + 1536C a b )c
+--R                 + 
+--R                           2 5          3 4            2 6
+--R                   (3840B a b  + 9600C a b )c - 2400C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           4   3              3 3           4 2           5   2
+--R                   49152A a b c  + (- 12288A a b  - 24576B a b  - 12288C a b)c
+--R                 + 
+--R                           3 4           4 3            3 5
+--R                   (6144B a b  + 18432C a b )c - 3840C a b
+--R              *
+--R                 x
+--R             + 
+--R                       5 3             4 2           5           6  2
+--R               24576A a c  + (- 6144A a b  - 12288B a b - 6144C a )c
+--R             + 
+--R                       4 3          5 2            4 4
+--R               (3072B a b  + 9216C a b )c - 1920C a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                           2   4             2 2          3   3
+--R                   12288A a b c  + (- 6144B a b  - 3072C a b)c
+--R                 + 
+--R                          5          2 3  2          6           5           7
+--R                 (- 768A b  + 3840C a b )c  + (384B b  + 192C a b )c - 240C b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                           3 4            2 2           3           4  3
+--R                   24576A a c  + (24576A a b  - 12288B a b - 6144C a )c
+--R                 + 
+--R                               4           2 3          3 2  2
+--R                   (- 7680A a b  - 12288B a b  + 1536C a b )c
+--R                 + 
+--R                             5          2 4              6
+--R                   (3840B a b  + 9600C a b )c - 2400C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           3   3              2 3           3 2           4   2
+--R                   73728A a b c  + (- 18432A a b  - 36864B a b  - 18432C a b)c
+--R                 + 
+--R                           2 4           3 3            2 5
+--R                   (9216B a b  + 27648C a b )c - 5760C a b
+--R              *
+--R                 x
+--R             + 
+--R                       4 3              3 2           4            5  2
+--R               49152A a c  + (- 12288A a b  - 24576B a b - 12288C a )c
+--R             + 
+--R                       3 3           4 2            3 4
+--R               (6144B a b  + 18432C a b )c - 3840C a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                            3 5             2 2          3           4  4
+--R                   - 6144A a c  + (- 7680A a b  + 3072B a b + 1536C a )c
+--R                 + 
+--R                             4          2 3  3
+--R                   (1920A a b  + 3840B a b )c
+--R                 + 
+--R                         6           5          2 4  2           7           6
+--R                   (96A b  - 960B a b  - 2880C a b )c  + (- 48B b  + 576C a b )c
+--R                 + 
+--R                        8
+--R                   30C b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             3   4            3 2           4   3
+--R                   - 49152A a b c  + (24576B a b  + 12288C a b)c
+--R                 + 
+--R                             5           3 3  2               6         2 5
+--R                   (3072A a b  - 15360C a b )c  + (- 1536B a b  - 768C a b )c
+--R                 + 
+--R                           7
+--R                   960C a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                             4 4              3 2           4            5  3
+--R                   - 49152A a c  + (- 49152A a b  + 24576B a b + 12288C a )c
+--R                 + 
+--R                            2 4           3 3          4 2  2
+--R                   (15360A a b  + 24576B a b  - 3072C a b )c
+--R                 + 
+--R                             2 5           3 4            2 6
+--R                   (- 7680B a b  - 19200C a b )c + 4800C a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                             4   3            3 3           4 2           5   2
+--R                   - 98304A a b c  + (24576A a b  + 49152B a b  + 24576C a b)c
+--R                 + 
+--R                              3 4           4 3            3 5
+--R                   (- 12288B a b  - 36864C a b )c + 7680C a b
+--R              *
+--R                 x
+--R             + 
+--R                         5 3            4 2           5            6  2
+--R               - 49152A a c  + (12288A a b  + 24576B a b + 12288C a )c
+--R             + 
+--R                         4 3           5 2            4 4
+--R               (- 6144B a b  - 18432C a b )c + 3840C a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- c \|c x  + b x + a  - \|- c \|a
+--R         atan(------------------------------------)
+--R                               c x
+--R     + 
+--R                       2 2          3   3
+--R               (3072A a b  + 4096B a b)c
+--R             + 
+--R                        4         2 3          3 2  2
+--R               (768A a b  - 512B a b  - 3328C a b )c
+--R             + 
+--R                          5         2 4             6
+--R               (- 384B a b  + 128C a b )c + 240C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       3           4  3
+--R               (6144A a b + 8192B a )c
+--R             + 
+--R                       2 3          3 2          4   2
+--R               (7680A a b  + 7168B a b  - 6656C a b)c
+--R             + 
+--R                         2 4          3 3            2 5
+--R               (- 3840B a b  - 6400C a b )c + 2400C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        3 2           4   2             3 3           4 2
+--R               (18432A a b  + 24576B a b)c  + (- 9216B a b  - 19968C a b )c
+--R             + 
+--R                      3 4
+--R               5760C a b
+--R          *
+--R             x
+--R         + 
+--R                  4            5  2             4 2           5             4 3
+--R         (12288A a b + 16384B a )c  + (- 6144B a b  - 13312C a b)c + 3840C a b
+--R      *
+--R                    +--------------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b x + a
+--R     + 
+--R                         2           3  4
+--R               (- 1536A a b - 2048B a )c
+--R             + 
+--R                           3          2 2          3   3
+--R               (- 2304A a b  - 2304B a b  + 1664C a b)c
+--R             + 
+--R                       5            4          2 3  2         6           5
+--R               (- 96A b  + 1024B a b  + 2016C a b )c  + (48B b  - 616C a b )c
+--R             + 
+--R                      7
+--R               - 30C b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          2 2           3   3
+--R               (- 12288A a b  - 16384B a b)c
+--R             + 
+--R                           4          2 3           3 2  2
+--R               (- 3072A a b  + 2048B a b  + 13312C a b )c
+--R             + 
+--R                         5         2 4             6
+--R               (1536B a b  - 512C a b )c - 960C a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                          3            4  3
+--R               (- 12288A a b - 16384B a )c
+--R             + 
+--R                          2 3           3 2           4   2
+--R               (- 15360A a b  - 14336B a b  + 13312C a b)c
+--R             + 
+--R                       2 4           3 3            2 5
+--R               (7680B a b  + 12800C a b )c - 4800C a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                          3 2           4   2            3 3           4 2
+--R               (- 24576A a b  - 32768B a b)c  + (12288B a b  + 26624C a b )c
+--R             + 
+--R                        3 4
+--R               - 7680C a b
+--R          *
+--R             x
+--R         + 
+--R                    4            5  2           4 2           5             4 3
+--R         (- 12288A a b - 16384B a )c  + (6144B a b  + 13312C a b)c - 3840C a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                      4        3 3  3          2 4           2 3  2
+--R           (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R         + 
+--R                 2   3          3 3
+--R           73728a b c x + 49152a c
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                   2 5          2 4       4 3  4
+--R           (- 6144a c  - 9216a b c  - 384b c )x
+--R         + 
+--R                    2   4           3 3  3            3 4         2 2 3  2
+--R           (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R         + 
+--R                   3   3          4 3
+--R           - 98304a b c x - 49152a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 326
+
+)clear all
+
+--S 327 of 556
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^(1/2)
+--R 
+--R
+--R             2
+--R          C x  + B x + A
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 556
+r0:=-1/8*(4*b*B*c-8*A*c^2-3*b^2*C+4*a*c*C)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/c^(5/2)+1/4*(4*B*c-3*b*C+2*c*C*x)*_
+   sqrt(a+b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R            2                          2              2c x + b
+--R       (8A c  + (- 4B b - 4C a)c + 3C b )atanh(----------------------)
+--R                                                     +--------------+
+--R                                                 +-+ |   2
+--R                                               2\|c \|c x  + b x + a
+--R     + 
+--R                                  +--------------+
+--R                              +-+ |   2
+--R       (4C c x + 8B c - 6C b)\|c \|c x  + b x + a
+--R  /
+--R       2 +-+
+--R     8c \|c
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                           2             2        2             3          2 2
+--R                 (32A a b c  + (- 16B a b  - 16C a b)c + 12C a b )x + 64A a c
+--R               + 
+--R                         2         3          2 2
+--R                 (- 32B a b - 32C a )c + 24C a b
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                              3          2                  2  2
+--R                     - 32A a c  + (- 8A b  + 16B a b + 16C a )c
+--R                   + 
+--R                          3         2         4
+--R                     (4B b  - 8C a b )c - 3C b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                             2           2        2             3          2 2
+--R                 (- 64A a b c  + (32B a b  + 32C a b)c - 24C a b )x - 64A a c
+--R               + 
+--R                       2         3          2 2
+--R                 (32B a b + 32C a )c - 24C a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                       2       2   3
+--R             (- 16C a c  - 4C b c)x
+--R           + 
+--R                       2          2                  3  2
+--R             (- 32B a c  + (- 8B b  - 8C a b)c + 6C b )x
+--R           + 
+--R                                2            2
+--R             ((- 32B a b - 32C a )c + 24C a b )x
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                      2 4                    2  2         2   3
+--R             16C a b c x  + ((32B a b + 32C a )c  - 8C a b c)x
+--R           + 
+--R                   2 2           2        2             3  2
+--R             (32B a c  + (24B a b  + 24C a b)c - 18C a b )x
+--R           + 
+--R                    2         3          2 2
+--R             ((32B a b + 32C a )c - 24C a b )x
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                                  +--------------+
+--R                 2       2 2  +-+ |   2
+--R         (32a b c x + 64a c )\|c \|c x  + b x + a
+--R       + 
+--R                  3     2 2  2          2       2 2  +-+ +-+
+--R         ((- 32a c  - 8b c )x  - 64a b c x - 64a c )\|a \|c
+--R     ,
+--R
+--R                           2             2        2             3          2 2
+--R                 (32A a b c  + (- 16B a b  - 16C a b)c + 12C a b )x + 64A a c
+--R               + 
+--R                         2         3          2 2
+--R                 (- 32B a b - 32C a )c + 24C a b
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                              3          2                  2  2
+--R                     - 32A a c  + (- 8A b  + 16B a b + 16C a )c
+--R                   + 
+--R                          3         2         4
+--R                     (4B b  - 8C a b )c - 3C b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                             2           2        2             3          2 2
+--R                 (- 64A a b c  + (32B a b  + 32C a b)c - 24C a b )x - 64A a c
+--R               + 
+--R                       2         3          2 2
+--R                 (32B a b + 32C a )c - 24C a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                      2       2   3
+--R             (- 8C a c  - 2C b c)x
+--R           + 
+--R                       2          2                  3  2
+--R             (- 16B a c  + (- 4B b  - 4C a b)c + 3C b )x
+--R           + 
+--R                                2            2
+--R             ((- 16B a b - 16C a )c + 12C a b )x
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                     2 4                    2  2         2   3
+--R             8C a b c x  + ((16B a b + 16C a )c  - 4C a b c)x
+--R           + 
+--R                   2 2           2        2            3  2
+--R             (16B a c  + (12B a b  + 12C a b)c - 9C a b )x
+--R           + 
+--R                    2         3          2 2
+--R             ((16B a b + 16C a )c - 12C a b )x
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                                    +--------------+
+--R                 2       2 2  +---+ |   2
+--R         (16a b c x + 32a c )\|- c \|c x  + b x + a
+--R       + 
+--R                  3     2 2  2          2       2 2  +---+ +-+
+--R         ((- 16a c  - 4b c )x  - 32a b c x - 32a c )\|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 329
+
+--S 330 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         2             2        2             3          2 2
+--R               (32A a b c  + (- 16B a b  - 16C a b)c + 12C a b )x + 64A a c
+--R             + 
+--R                       2         3          2 2
+--R               (- 32B a b - 32C a )c + 24C a b
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                            3          2                  2  2
+--R                   - 32A a c  + (- 8A b  + 16B a b + 16C a )c
+--R                 + 
+--R                        3         2         4
+--R                   (4B b  - 8C a b )c - 3C b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           2           2        2             3          2 2
+--R               (- 64A a b c  + (32B a b  + 32C a b)c - 24C a b )x - 64A a c
+--R             + 
+--R                     2         3          2 2
+--R               (32B a b + 32C a )c - 24C a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                           2           2        2             3          2 2
+--R               (- 32A a b c  + (16B a b  + 16C a b)c - 12C a b )x - 64A a c
+--R             + 
+--R                     2         3          2 2
+--R               (32B a b + 32C a )c - 24C a b
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                          3        2                  2  2
+--R                   32A a c  + (8A b  - 16B a b - 16C a )c
+--R                 + 
+--R                          3         2         4
+--R                   (- 4B b  + 8C a b )c + 3C b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         2             2        2             3          2 2
+--R               (64A a b c  + (- 32B a b  - 32C a b)c + 24C a b )x + 64A a c
+--R             + 
+--R                       2         3          2 2
+--R               (- 32B a b - 32C a )c + 24C a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                                                             +--------------+
+--R                            2          2         2   +-+ +-+ |   2
+--R       ((32B a b c - 24C a b )x + 64B a c - 48C a b)\|a \|c \|c x  + b x + a
+--R     + 
+--R                   2 2            2        2            3  2
+--R           (- 32B a c  + (- 8B a b  + 24C a b)c + 6C a b )x
+--R         + 
+--R                   2           2 2          3         3
+--R           (- 64B a b c + 48C a b )x - 64B a c + 48C a b
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                +--------------+
+--R               2       2 2  +-+ |   2
+--R       (32a b c x + 64a c )\|c \|c x  + b x + a
+--R     + 
+--R                3     2 2  2          2       2 2  +-+ +-+
+--R       ((- 32a c  - 8b c )x  - 64a b c x - 64a c )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 330
+
+--S 331 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                           2           2        2             3          2 2
+--R               (- 32A a b c  + (16B a b  + 16C a b)c - 12C a b )x - 64A a c
+--R             + 
+--R                     2         3          2 2
+--R               (32B a b + 32C a )c - 24C a b
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b x + a
+--R         + 
+--R                          3        2                  2  2
+--R                   32A a c  + (8A b  - 16B a b - 16C a )c
+--R                 + 
+--R                          3         2         4
+--R                   (- 4B b  + 8C a b )c + 3C b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         2             2        2             3          2 2
+--R               (64A a b c  + (- 32B a b  - 32C a b)c + 24C a b )x + 64A a c
+--R             + 
+--R                       2         3          2 2
+--R               (- 32B a b - 32C a )c + 24C a b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                         2             2        2             3           2 2
+--R               (64A a b c  + (- 32B a b  - 32C a b)c + 24C a b )x + 128A a c
+--R             + 
+--R                       2         3          2 2
+--R               (- 64B a b - 64C a )c + 48C a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                            3           2                  2  2
+--R                   - 64A a c  + (- 16A b  + 32B a b + 32C a )c
+--R                 + 
+--R                        3          2         4
+--R                   (8B b  - 16C a b )c - 6C b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                            2           2        2             3           2 2
+--R               (- 128A a b c  + (64B a b  + 64C a b)c - 48C a b )x - 128A a c
+--R             + 
+--R                     2         3          2 2
+--R               (64B a b + 64C a )c - 48C a b
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- c \|c x  + b x + a  - \|- c \|a
+--R         atan(------------------------------------)
+--R                               c x
+--R     + 
+--R                              2          2         2   +---+ +-+ +-+
+--R         ((32B a b c - 24C a b )x + 64B a c - 48C a b)\|- c \|a \|c
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   2 2            2        2            3  2
+--R           (- 32B a c  + (- 8B a b  + 24C a b)c + 6C a b )x
+--R         + 
+--R                   2           2 2          3         3
+--R           (- 64B a b c + 48C a b )x - 64B a c + 48C a b
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                                      +--------------+
+--R               2       2 2  +---+ +-+ |   2
+--R       (32a b c x + 64a c )\|- c \|c \|c x  + b x + a
+--R     + 
+--R                3     2 2  2          2       2 2  +---+ +-+ +-+
+--R       ((- 32a c  - 8b c )x  - 64a b c x - 64a c )\|- c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 556
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^(3/2)
+--R 
+--R
+--R                     2
+--R                  C x  + B x + A
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 556
+r0:=C*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/c^(3/2)-_
+   2*(A*b*c-2*a*B*c+a*b*C-(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/(c*(b^2-4*a*c)*_
+   sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                       +--------------+
+--R                    2  |   2                        2c x + b
+--R       (4C a c - C b )\|c x  + b x + a atanh(----------------------)
+--R                                                   +--------------+
+--R                                               +-+ |   2
+--R                                             2\|c \|c x  + b x + a
+--R     + 
+--R             2                          2                              +-+
+--R       ((4A c  + (- 2B b - 4C a)c + 2C b )x + (2A b - 4B a)c + 2C a b)\|c
+--R  /
+--R                       +--------------+
+--R          2    2   +-+ |   2
+--R     (4a c  - b c)\|c \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               +--------------+
+--R                            2  |   2
+--R             (C a b x + 2C a )\|c x  + b x + a
+--R           + 
+--R                        2                  2  +-+
+--R             (- 2C a c x  - 2C a b x - 2C a )\|a
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                                  +--------------+
+--R                          +-+ +-+ |   2
+--R         (- 2A c + 2C a)x\|a \|c \|c x  + b x + a
+--R       + 
+--R                            2                 2    +-+
+--R         ((2B a c - 2C a b)x  + (2A a c - 2C a )x)\|c
+--R    /
+--R                              +--------------+
+--R                      2   +-+ |   2
+--R         (a b c x + 2a c)\|c \|c x  + b x + a
+--R       + 
+--R                2 2                2   +-+ +-+
+--R         (- 2a c x  - 2a b c x - 2a c)\|a \|c
+--R     ,
+--R
+--R                                +--------------+
+--R                             2  |   2
+--R             (2C a b x + 4C a )\|c x  + b x + a
+--R           + 
+--R                        2                  2  +-+
+--R             (- 4C a c x  - 4C a b x - 4C a )\|a
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                                    +--------------+
+--R                          +---+ +-+ |   2
+--R         (- 2A c + 2C a)x\|- c \|a \|c x  + b x + a
+--R       + 
+--R                            2                 2    +---+
+--R         ((2B a c - 2C a b)x  + (2A a c - 2C a )x)\|- c
+--R    /
+--R                                +--------------+
+--R                      2   +---+ |   2
+--R         (a b c x + 2a c)\|- c \|c x  + b x + a
+--R       + 
+--R                2 2                2   +---+ +-+
+--R         (- 2a c x  - 2a b c x - 2a c)\|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 336
+
+--S 337 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                  +--------------+
+--R                2          2  +-+ |   2                     2           3
+--R           (8C a c - 2C a b )\|a \|c x  + b x + a  + (- 4C a b c + C a b )x
+--R         + 
+--R                 3        2 2
+--R           - 8C a c + 2C a b
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                                    +--------------+
+--R                  2          2  +-+ |   2                   2           3
+--R           (- 8C a c + 2C a b )\|a \|c x  + b x + a  + (4C a b c - C a b )x
+--R         + 
+--R               3        2 2
+--R           8C a c - 2C a b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                                        +--------------+
+--R                      2         2   +-+ |   2
+--R       ((4A a b - 8B a )c + 4C a b)\|c \|c x  + b x + a
+--R     + 
+--R              2                    2                     2         2   +-+ +-+
+--R     (((- 2A b  + 4B a b)c - 2C a b )x + (- 4A a b + 8B a )c - 4C a b)\|a \|c
+--R  /
+--R                                +--------------+
+--R          2 2       2   +-+ +-+ |   2
+--R       (8a c  - 2a b c)\|a \|c \|c x  + b x + a
+--R     + 
+--R             2   2      3        3 2     2 2   +-+
+--R       ((- 4a b c  + a b c)x - 8a c  + 2a b c)\|c
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                          +--------------+
+--R                  2          2  +---+ +-+ |   2
+--R           (- 8C a c + 2C a b )\|- c \|a \|c x  + b x + a
+--R         + 
+--R                 2           3         3        2 2  +---+
+--R           ((4C a b c - C a b )x + 8C a c - 2C a b )\|- c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                                       +--------------+
+--R                 2          2  +-+ +-+ |   2
+--R           (16C a c - 4C a b )\|a \|c \|c x  + b x + a
+--R         + 
+--R                   2            3          3        2 2  +-+
+--R           ((- 8C a b c + 2C a b )x - 16C a c + 4C a b )\|c
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- c \|c x  + b x + a  - \|- c \|a
+--R         atan(------------------------------------)
+--R                               c x
+--R     + 
+--R                                              +--------------+
+--R                      2         2   +---+ +-+ |   2
+--R       ((4A a b - 8B a )c + 4C a b)\|- c \|c \|c x  + b x + a
+--R     + 
+--R                  2                    2                     2         2   +---+
+--R         (((- 2A b  + 4B a b)c - 2C a b )x + (- 4A a b + 8B a )c - 4C a b)\|- c
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                                      +--------------+
+--R          2 2       2   +---+ +-+ +-+ |   2
+--R       (8a c  - 2a b c)\|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R             2   2      3        3 2     2 2   +---+ +-+
+--R       ((- 4a b c  + a b c)x - 8a c  + 2a b c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 340
+
+)clear all
+
+--S 341 of 556
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^(5/2)
+--R 
+--R
+--R                                    2
+--R                                 C x  + B x + A
+--R   (1)  ---------------------------------------------------------------
+--R                                                       +--------------+
+--R          2 4         3            2  2             2  |   2
+--R        (c x  + 2b c x  + (2a c + b )x  + 2a b x + a )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 556
+r0:=-2/3*(A*b*c-2*a*B*c+a*b*C-(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/_
+   (c*(b^2-4*a*c)*(a+b*x+c*x^2)^(3/2))-2/3*(4*b*B*c-b^2*C-_
+   4*c*(2*A*c+a*C))*(b+2*c*x)/(c*(b^2-4*a*c)^2*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R             3                     2       2   3
+--R       (32A c  + (- 16B b + 16C a)c  + 4C b c)x
+--R     + 
+--R               2           2                   3  2
+--R       (48A b c  + (- 24B b  + 24C a b)c + 6C b )x
+--R     + 
+--R               2         2                   3          2
+--R       (48A a c  + (12A b  - 24B a b)c - 6B b  + 24C a b )x
+--R     + 
+--R                       2         3         2        2
+--R       (24A a b - 16B a )c - 2A b  - 4B a b  + 16C a b
+--R  /
+--R             2 3        2 2     4   2       2   2        3      5        3 2
+--R         (48a c  - 24a b c  + 3b c)x  + (48a b c  - 24a b c + 3b )x + 48a c
+--R       + 
+--R              2 2        4
+--R         - 24a b c + 3a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 556
+--a0:=integrate(t0,x)
+--E 343
+
+--S 344 of 556
+--m0:=a0-r0
+--E 344
+
+--S 345 of 556
+--d0:=D(m0,x)
+--E 345
+
+)clear all
+
+--S 346 of 556
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^(7/2)
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + B x + A
+--R  /
+--R          3 6       2 5        2     2   4              3  3      2        2  2
+--R         c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R       + 
+--R           2       3
+--R         3a b x + a
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 556
+r0:=-2/5*(A*b*c-2*a*B*c+a*b*C-(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/_
+   (c*(b^2-4*a*c)*(a+b*x+c*x^2)^(5/2))-2/15*(8*b*B*c-3*b^2*C-_
+   4*c*(4*A*c+a*C))*(b+2*c*x)/(c*(b^2-4*a*c)^2*(a+b*x+c*x^2)^(3/2))+_
+   16/15*(8*b*B*c-3*b^2*C-4*c*(4*A*c+a*C))*(b+2*c*x)/((b^2-4*a*c)^3*_
+   sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R              5                       4        2 3  5
+--R       (512A c  + (- 256B b + 128C a)c  + 96C b c )x
+--R     + 
+--R                 4            2             3         3 2  4
+--R       (1280A b c  + (- 640B b  + 320C a b)c  + 240C b c )x
+--R     + 
+--R                    4          2                    2  3
+--R           1280A a c  + (960A b  - 640B a b + 320C a )c
+--R         + 
+--R                    3           2  2         4
+--R           (- 480B b  + 480C a b )c  + 180C b c
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                      3          3           2         2   2
+--R           1920A a b c  + (160A b  - 960B a b  + 480C a b)c
+--R         + 
+--R                   4           3          5
+--R           (- 80B b  + 400C a b )c + 30C b
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 2 3            2         2   2
+--R           960A a c  + (480A a b  - 480B a b)c
+--R         + 
+--R                   4           3         2 2          5          4
+--R           (- 20A b  - 240B a b  + 480C a b )c + 10B b  + 40C a b
+--R      *
+--R         x
+--R     + 
+--R              2          3  2             3        2 2         3          5
+--R       (480A a b - 192B a )c  + (- 80A a b  - 96B a b  + 192C a b)c + 6A b
+--R     + 
+--R             4        2 3
+--R       4B a b  + 16C a b
+--R  /
+--R              3 5       2 2 4         4 3      6 2  4
+--R         (960a c  - 720a b c  + 180a b c  - 15b c )x
+--R       + 
+--R               3   4        2 3 3         5 2      7   3
+--R         (1920a b c  - 1440a b c  + 360a b c  - 30b c)x
+--R       + 
+--R               4 4       3 2 3       2 4 2         6       8  2
+--R         (1920a c  - 480a b c  - 360a b c  + 150a b c - 15b )x
+--R       + 
+--R               4   3        3 3 2       2 5         7         5 3       4 2 2
+--R         (1920a b c  - 1440a b c  + 360a b c - 30a b )x + 960a c  - 720a b c
+--R       + 
+--R             3 4       2 6
+--R         180a b c - 15a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 556
+--a0:=integrate(t0,x)
+--E 348
+
+--S 349 of 556
+--m0:=a0-r0
+--E 349
+
+--S 350 of 556
+--d0:=D(m0,x)
+--E 350
+
+)clear all
+
+--S 351 of 556
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^(9/2)
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + B x + A
+--R  /
+--R          4 8       3 7        3     2 2  6           2     3   5
+--R         c x  + 4b c x  + (4a c  + 6b c )x  + (12a b c  + 4b c)x
+--R       + 
+--R            2 2        2     4  4       2          3  3      3      2 2  2
+--R         (6a c  + 12a b c + b )x  + (12a b c + 4a b )x  + (4a c + 6a b )x
+--R       + 
+--R           3       4
+--R         4a b x + a
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 556
+r0:=-2/7*(A*b*c-2*a*B*c+a*b*C-(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/_
+   (c*(b^2-4*a*c)*(a+b*x+c*x^2)^(7/2))-2/35*(12*b*B*c-5*b^2*C-_
+   4*c*(6*A*c+a*C))*(b+2*c*x)/(c*(b^2-4*a*c)^2*(a+b*x+c*x^2)^(5/2))+_
+   32/105*(12*b*B*c-5*b^2*C-4*c*(6*A*c+a*C))*(b+2*c*x)/((b^2-4*a*c)^3*_
+   (a+b*x+c*x^2)^(3/2))-256/105*c*(12*b*B*c-5*b^2*C-4*c*(6*A*c+a*C))*_
+   (b+2*c*x)/((b^2-4*a*c)^4*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                7                         6          2 5  7
+--R       (12288A c  + (- 6144B b + 2048C a)c  + 2560C b c )x
+--R     + 
+--R                  6              2              5          3 4  6
+--R       (43008A b c  + (- 21504B b  + 7168C a b)c  + 8960C b c )x
+--R     + 
+--R                     6            2                       2  5
+--R           43008A a c  + (53760A b  - 21504B a b + 7168C a )c
+--R         + 
+--R                      3             2  4           4 3
+--R           (- 26880B b  + 17920C a b )c  + 11200C b c
+--R      *
+--R          5
+--R         x
+--R     + 
+--R                        5            3             2           2   4
+--R           107520A a b c  + (26880A b  - 53760B a b  + 17920C a b)c
+--R         + 
+--R                      4             3  3          5 2
+--R           (- 13440B b  + 26880C a b )c  + 5600C b c
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                   2 5              2           2           3  4
+--R           53760A a c  + (80640A a b  - 26880B a b + 8960C a )c
+--R         + 
+--R                   4             3           2 2  3
+--R           (3360A b  - 40320B a b  + 24640C a b )c
+--R         + 
+--R                     5             4  2         6
+--R           (- 1680B b  + 17360C a b )c  + 700C b c
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                   2   4              3           2 2           3   3
+--R           80640A a b c  + (13440A a b  - 40320B a b  + 13440C a b)c
+--R         + 
+--R                    5            4           2 3  2          6            5
+--R           (- 336A b  - 6720B a b  + 19040C a b )c  + (168B b  + 2744C a b )c
+--R         + 
+--R                  7
+--R           - 70C b
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                   3 4            2 2           3   3
+--R           26880A a c  + (20160A a b  - 13440B a b)c
+--R         + 
+--R                       4           2 3           3 2  2
+--R           (- 1680A a b  - 10080B a b  + 13440C a b )c
+--R         + 
+--R                 6           5          2 4          7          6
+--R           (84A b  + 840B a b  + 2240C a b )c - 42B b  - 56C a b
+--R      *
+--R         x
+--R     + 
+--R                3           4  3             2 3          3 2          4   2
+--R       (13440A a b - 3840B a )c  + (- 3360A a b  - 2880B a b  + 3840C a b)c
+--R     + 
+--R                5         2 4         3 3          7          6        2 5
+--R       (504A a b  + 240B a b  + 640C a b )c - 30A b  - 12B a b  - 16C a b
+--R  /
+--R                4 7         3 2 6         2 4 5          6 4       8 3  6
+--R         (26880a c  - 26880a b c  + 10080a b c  - 1680a b c  + 105b c )x
+--R       + 
+--R                4   6         3 3 5         2 5 4          7 3       9 2  5
+--R         (80640a b c  - 80640a b c  + 30240a b c  - 5040a b c  + 315b c )x
+--R       + 
+--R                5 6         3 4 4         2 6 3          8 2       10   4
+--R         (80640a c  - 50400a b c  + 25200a b c  - 4725a b c  + 315b  c)x
+--R       + 
+--R                 5   5          4 3 4         3 5 3          9        11  3
+--R         (161280a b c  - 134400a b c  + 33600a b c  - 1050a b c + 105b  )x
+--R       + 
+--R                6 5         4 4 3         3 6 2        2 8          10  2
+--R         (80640a c  - 50400a b c  + 25200a b c  - 4725a b c + 315a b  )x
+--R       + 
+--R                6   4         5 3 3         4 5 2        3 7        2 9
+--R         (80640a b c  - 80640a b c  + 30240a b c  - 5040a b c + 315a b )x
+--R       + 
+--R               7 4         6 2 3         5 4 2        4 6        3 8
+--R         26880a c  - 26880a b c  + 10080a b c  - 1680a b c + 105a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 556
+--a0:=integrate(t0,x)
+--E 353
+
+--S 354 of 556
+--m0:=a0-r0
+--E 354
+
+--S 355 of 556
+--d0:=D(m0,x)
+--E 355
+
+)clear all
+
+--S 356 of 556
+t0:=(A+B*x)*(a+b*x+c*x^2)/(d+f*x^2)
+--R 
+--R
+--R             3               2
+--R        B c x  + (A c + B b)x  + (A b + B a)x + A a
+--R   (1)  -------------------------------------------
+--R                             2
+--R                          f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 356
+
+--S 357 of 556
+r0:=(b*B+A*c)*x/f+1/2*B*c*x^2/f-1/2*(B*c*d-A*b*f-a*B*f)*log(d+f*x^2)/f^2-_
+   (b*B*d+A*c*d-a*A*f)*atan(x*sqrt(f)/sqrt(d))/(f^(3/2)*sqrt(d))
+--R 
+--R
+--R   (2)
+--R                                            +-+
+--R              2                           x\|f
+--R       (2A a f  + (- 2A c - 2B b)d f)atan(-----)
+--R                                            +-+
+--R                                           \|d
+--R     + 
+--R                                   2               2                     +-+ +-+
+--R     (((A b + B a)f - B c d)log(f x  + d) + B c f x  + (2A c + 2B b)f x)\|d \|f
+--R  /
+--R       2 +-+ +-+
+--R     2f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                            2      +-----+
+--R               2                        (f x  - d)\|- d f  + 2d f x
+--R         (A a f  + (- A c - B b)d f)log(---------------------------)
+--R                                                     2
+--R                                                  f x  + d
+--R       + 
+--R                                         2               2
+--R           (((A b + B a)f - B c d)log(f x  + d) + B c f x  + (2A c + 2B b)f x)
+--R        *
+--R            +-----+
+--R           \|- d f
+--R    /
+--R         2 +-----+
+--R       2f \|- d f
+--R     ,
+--R
+--R                                              +---+
+--R                2                           x\|d f
+--R         (2A a f  + (- 2A c - 2B b)d f)atan(-------)
+--R                                               d
+--R       + 
+--R                                     2               2                     +---+
+--R       (((A b + B a)f - B c d)log(f x  + d) + B c f x  + (2A c + 2B b)f x)\|d f
+--R    /
+--R         2 +---+
+--R       2f \|d f
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 358
+
+--S 359 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                               2      +-----+
+--R                                +-+ +-+    (f x  - d)\|- d f  + 2d f x
+--R       (A a f + (- A c - B b)d)\|d \|f log(---------------------------)
+--R                                                        2
+--R                                                     f x  + d
+--R     + 
+--R                                                 +-+
+--R                                   +-----+     x\|f
+--R       (- 2A a f + (2A c + 2B b)d)\|- d f atan(-----)
+--R                                                 +-+
+--R                                                \|d
+--R  /
+--R        +-----+ +-+ +-+
+--R     2f\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+--S 361 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                              +---+
+--R                                +-+ +-+     x\|d f
+--R       (A a f + (- A c - B b)d)\|d \|f atan(-------)
+--R                                               d
+--R     + 
+--R                                            +-+
+--R                                +---+     x\|f
+--R       (- A a f + (A c + B b)d)\|d f atan(-----)
+--R                                            +-+
+--R                                           \|d
+--R  /
+--R       +-+ +-+ +---+
+--R     f\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 362
+
+)clear all
+
+--S 363 of 556
+t0:=(A+B*x)*(a+b*x+c*x^2)^2/(d+f*x^2)
+--R 
+--R
+--R   (1)
+--R          2 5       2           4                        2  3
+--R       B c x  + (A c  + 2B b c)x  + ((2A b + 2B a)c + B b )x
+--R     + 
+--R                    2           2                2        2
+--R       (2A a c + A b  + 2B a b)x  + (2A a b + B a )x + A a
+--R  /
+--R        2
+--R     f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 363
+
+--S 364 of 556
+r0:=(A*b^2*f-A*c*(c*d-2*a*f)-b*B*(2*c*d-2*a*f))*x/f^2+1/2*(2*A*b*c*f-_
+   B*(c^2*d-b^2*f-2*a*c*f))*x^2/f^2+1/3*c*(2*b*B+A*c)*x^3/f+_
+   1/4*B*c^2*x^4/f-1/2*(2*A*b*f*(c*d-a*f)-B*(c^2*d^2-2*a*c*d*f-_
+   f*(b^2*d-a^2*f)))*log(d+f*x^2)/f^3-(A*b^2*d*f-2*b*B*d*(c*d-a*f)-_
+   A*(c*d-a*f)^2)*atan(x*sqrt(f)/sqrt(d))/(f^(5/2)*sqrt(d))
+--R 
+--R
+--R   (2)
+--R               2 3                     2              2         2            2
+--R         (12A a f  + (- 24A a c - 12A b  - 24B a b)d f  + (12A c  + 24B b c)d f)
+--R      *
+--R                +-+
+--R              x\|f
+--R         atan(-----)
+--R                +-+
+--R               \|d
+--R     + 
+--R                             2  2                             2           2 2
+--R             ((12A a b + 6B a )f  + ((- 12A b - 12B a)c - 6B b )d f + 6B c d )
+--R          *
+--R                    2
+--R             log(f x  + d)
+--R         + 
+--R               2 2 4        2           2 3
+--R           3B c f x  + (4A c  + 8B b c)f x
+--R         + 
+--R                                    2  2       2     2
+--R           (((12A b + 12B a)c + 6B b )f  - 6B c d f)x
+--R         + 
+--R                            2            2           2
+--R           ((24A a c + 12A b  + 24B a b)f  + (- 12A c  - 24B b c)d f)x
+--R      *
+--R          +-+ +-+
+--R         \|d \|f
+--R  /
+--R        3 +-+ +-+
+--R     12f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3                    2              2        2            2
+--R           (6A a f  + (- 12A a c - 6A b  - 12B a b)d f  + (6A c  + 12B b c)d f)
+--R        *
+--R                   2      +-----+
+--R               (f x  - d)\|- d f  + 2d f x
+--R           log(---------------------------)
+--R                            2
+--R                         f x  + d
+--R       + 
+--R                               2  2                             2           2 2
+--R               ((12A a b + 6B a )f  + ((- 12A b - 12B a)c - 6B b )d f + 6B c d )
+--R            *
+--R                      2
+--R               log(f x  + d)
+--R           + 
+--R                 2 2 4        2           2 3
+--R             3B c f x  + (4A c  + 8B b c)f x
+--R           + 
+--R                                      2  2       2     2
+--R             (((12A b + 12B a)c + 6B b )f  - 6B c d f)x
+--R           + 
+--R                              2            2           2
+--R             ((24A a c + 12A b  + 24B a b)f  + (- 12A c  - 24B b c)d f)x
+--R        *
+--R            +-----+
+--R           \|- d f
+--R    /
+--R          3 +-----+
+--R       12f \|- d f
+--R     ,
+--R
+--R                    2 3                     2              2
+--R               12A a f  + (- 24A a c - 12A b  - 24B a b)d f
+--R             + 
+--R                     2            2
+--R               (12A c  + 24B b c)d f
+--R        *
+--R                  +---+
+--R                x\|d f
+--R           atan(-------)
+--R                   d
+--R       + 
+--R                               2  2                             2           2 2
+--R               ((12A a b + 6B a )f  + ((- 12A b - 12B a)c - 6B b )d f + 6B c d )
+--R            *
+--R                      2
+--R               log(f x  + d)
+--R           + 
+--R                 2 2 4        2           2 3
+--R             3B c f x  + (4A c  + 8B b c)f x
+--R           + 
+--R                                      2  2       2     2
+--R             (((12A b + 12B a)c + 6B b )f  - 6B c d f)x
+--R           + 
+--R                              2            2           2
+--R             ((24A a c + 12A b  + 24B a b)f  + (- 12A c  - 24B b c)d f)x
+--R        *
+--R            +---+
+--R           \|d f
+--R    /
+--R          3 +---+
+--R       12f \|d f
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 365
+
+--S 366 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2 2                  2                    2           2  +-+ +-+
+--R         (A a f  + (- 2A a c - A b  - 2B a b)d f + (A c  + 2B b c)d )\|d \|f
+--R      *
+--R                 2      +-----+
+--R             (f x  - d)\|- d f  + 2d f x
+--R         log(---------------------------)
+--R                          2
+--R                       f x  + d
+--R     + 
+--R                2 2                 2                       2           2
+--R         (- 2A a f  + (4A a c + 2A b  + 4B a b)d f + (- 2A c  - 4B b c)d )
+--R      *
+--R                        +-+
+--R          +-----+     x\|f
+--R         \|- d f atan(-----)
+--R                        +-+
+--R                       \|d
+--R  /
+--R       2 +-----+ +-+ +-+
+--R     2f \|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             2 2                  2                    2           2  +-+ +-+
+--R         (A a f  + (- 2A a c - A b  - 2B a b)d f + (A c  + 2B b c)d )\|d \|f
+--R      *
+--R                +---+
+--R              x\|d f
+--R         atan(-------)
+--R                 d
+--R     + 
+--R               2 2                2                      2           2  +---+
+--R         (- A a f  + (2A a c + A b  + 2B a b)d f + (- A c  - 2B b c)d )\|d f
+--R      *
+--R                +-+
+--R              x\|f
+--R         atan(-----)
+--R                +-+
+--R               \|d
+--R  /
+--R      2 +-+ +-+ +---+
+--R     f \|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 556
+t0:=(A+B*x)*(a+b*x+c*x^2)^3/(d+f*x^2)
+--R 
+--R
+--R   (1)
+--R          3 7       3         2  6                  2       2   5
+--R       B c x  + (A c  + 3B b c )x  + ((3A b + 3B a)c  + 3B b c)x
+--R     + 
+--R              2        2                 3  4
+--R       (3A a c  + (3A b  + 6B a b)c + B b )x
+--R     + 
+--R                      2        3         2  3        2          2       2   2
+--R       ((6A a b + 3B a )c + A b  + 3B a b )x  + (3A a c + 3A a b  + 3B a b)x
+--R     + 
+--R            2       3        3
+--R       (3A a b + B a )x + A a
+--R  /
+--R        2
+--R     f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 370
+
+--S 371 of 556
+r0:=-(b^3*B*d*f+3*A*b^2*f*(c*d-a*f)-3*b*B*(c*d-a*f)^2-_
+   A*c*(c^2*d^2-3*a*c*d*f+3*a^2*f^2))*x/f^3-1/2*(A*b*f*(3*c^2*d-b^2*f-_
+   6*a*c*f)-B*(c^3*d^2-3*a*c^2*d*f+3*a*b^2*f^2-3*c*f*(b^2*d-a^2*f)))*_
+   x^2/f^3+1/3*(b^3*B*f+3*A*b^2*c*f-A*c^2*(c*d-3*a*f)-_
+   3*b*B*c*(c*d-2*a*f))*x^3/f^2+1/4*c*(3*A*b*c*f-B*(c^2*d-3*b^2*f-_
+   3*a*c*f))*x^4/f^2+1/5*c^2*(3*b*B+A*c)*x^5/f+1/6*B*c^3*x^6/f+_
+   1/2*(A*b*f*(3*c^2*d^2-6*a*c*d*f-f*(b^2*d-3*a^2*f))-B*(c*d-a*f)*_
+   (c^2*d^2-2*a*c*d*f-f*(3*b^2*d-a^2*f)))*log(d+f*x^2)/f^4+_
+   (b^3*B*d^2*f+3*A*b^2*d*f*(c*d-a*f)-3*b*B*d*(c*d-a*f)^2-_
+   A*(c*d-a*f)^3)*atan(x*sqrt(f)/sqrt(d))/(f^(7/2)*sqrt(d))
+--R 
+--R
+--R   (2)
+--R                3 4            2            2         2     3
+--R           60A a f  + (- 180A a c - 180A a b  - 180B a b)d f
+--R         + 
+--R                    2          2                     3  2 2
+--R           (180A a c  + (180A b  + 360B a b)c + 60B b )d f
+--R         + 
+--R                   3           2  3
+--R           (- 60A c  - 180B b c )d f
+--R      *
+--R                +-+
+--R              x\|f
+--R         atan(-----)
+--R                +-+
+--R               \|d
+--R     + 
+--R                     2         3  3
+--R               (90A a b + 30B a )f
+--R             + 
+--R                                   2          3          2    2
+--R               ((- 180A a b - 90B a )c - 30A b  - 90B a b )d f
+--R             + 
+--R                                2        2   2         3 3
+--R               ((90A b + 90B a)c  + 90B b c)d f - 30B c d
+--R          *
+--R                    2
+--R             log(f x  + d)
+--R         + 
+--R                3 3 6         3          2  3 5
+--R           10B c f x  + (12A c  + 36B b c )f x
+--R         + 
+--R                             2        2   3        3   2  4
+--R           (((45A b + 45B a)c  + 45B b c)f  - 15B c d f )x
+--R         + 
+--R                       2         2                     3  3
+--R               (60A a c  + (60A b  + 120B a b)c + 20B b )f
+--R             + 
+--R                       3          2    2
+--R               (- 20A c  - 60B b c )d f
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                                 2          3          2  3
+--R               ((180A a b + 90B a )c + 30A b  + 90B a b )f
+--R             + 
+--R                                  2        2     2        3 2
+--R               ((- 90A b - 90B a)c  - 90B b c)d f  + 30B c d f
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      2            2         2   3
+--R               (180A a c + 180A a b  + 180B a b)f
+--R             + 
+--R                          2            2                     3    2
+--R               (- 180A a c  + (- 180A b  - 360B a b)c - 60B b )d f
+--R             + 
+--R                     3           2  2
+--R               (60A c  + 180B b c )d f
+--R          *
+--R             x
+--R      *
+--R          +-+ +-+
+--R         \|d \|f
+--R  /
+--R        4 +-+ +-+
+--R     60f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3 4           2           2        2     3
+--R             30A a f  + (- 90A a c - 90A a b  - 90B a b)d f
+--R           + 
+--R                     2         2                     3  2 2
+--R             (90A a c  + (90A b  + 180B a b)c + 30B b )d f
+--R           + 
+--R                     3          2  3
+--R             (- 30A c  - 90B b c )d f
+--R        *
+--R                   2      +-----+
+--R               (f x  - d)\|- d f  + 2d f x
+--R           log(---------------------------)
+--R                            2
+--R                         f x  + d
+--R       + 
+--R                       2         3  3
+--R                 (90A a b + 30B a )f
+--R               + 
+--R                                     2          3          2    2
+--R                 ((- 180A a b - 90B a )c - 30A b  - 90B a b )d f
+--R               + 
+--R                                  2        2   2         3 3
+--R                 ((90A b + 90B a)c  + 90B b c)d f - 30B c d
+--R            *
+--R                      2
+--R               log(f x  + d)
+--R           + 
+--R                  3 3 6         3          2  3 5
+--R             10B c f x  + (12A c  + 36B b c )f x
+--R           + 
+--R                               2        2   3        3   2  4
+--R             (((45A b + 45B a)c  + 45B b c)f  - 15B c d f )x
+--R           + 
+--R                         2         2                     3  3
+--R                 (60A a c  + (60A b  + 120B a b)c + 20B b )f
+--R               + 
+--R                         3          2    2
+--R                 (- 20A c  - 60B b c )d f
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                                   2          3          2  3
+--R                 ((180A a b + 90B a )c + 30A b  + 90B a b )f
+--R               + 
+--R                                    2        2     2        3 2
+--R                 ((- 90A b - 90B a)c  - 90B b c)d f  + 30B c d f
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2            2         2   3
+--R                 (180A a c + 180A a b  + 180B a b)f
+--R               + 
+--R                            2            2                     3    2
+--R                 (- 180A a c  + (- 180A b  - 360B a b)c - 60B b )d f
+--R               + 
+--R                       3           2  2
+--R                 (60A c  + 180B b c )d f
+--R            *
+--R               x
+--R        *
+--R            +-----+
+--R           \|- d f
+--R    /
+--R          4 +-----+
+--R       60f \|- d f
+--R     ,
+--R
+--R                  3 4            2            2         2     3
+--R             60A a f  + (- 180A a c - 180A a b  - 180B a b)d f
+--R           + 
+--R                      2          2                     3  2 2
+--R             (180A a c  + (180A b  + 360B a b)c + 60B b )d f
+--R           + 
+--R                     3           2  3
+--R             (- 60A c  - 180B b c )d f
+--R        *
+--R                  +---+
+--R                x\|d f
+--R           atan(-------)
+--R                   d
+--R       + 
+--R                       2         3  3
+--R                 (90A a b + 30B a )f
+--R               + 
+--R                                     2          3          2    2
+--R                 ((- 180A a b - 90B a )c - 30A b  - 90B a b )d f
+--R               + 
+--R                                  2        2   2         3 3
+--R                 ((90A b + 90B a)c  + 90B b c)d f - 30B c d
+--R            *
+--R                      2
+--R               log(f x  + d)
+--R           + 
+--R                  3 3 6         3          2  3 5
+--R             10B c f x  + (12A c  + 36B b c )f x
+--R           + 
+--R                               2        2   3        3   2  4
+--R             (((45A b + 45B a)c  + 45B b c)f  - 15B c d f )x
+--R           + 
+--R                         2         2                     3  3
+--R                 (60A a c  + (60A b  + 120B a b)c + 20B b )f
+--R               + 
+--R                         3          2    2
+--R                 (- 20A c  - 60B b c )d f
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                                   2          3          2  3
+--R                 ((180A a b + 90B a )c + 30A b  + 90B a b )f
+--R               + 
+--R                                    2        2     2        3 2
+--R                 ((- 90A b - 90B a)c  - 90B b c)d f  + 30B c d f
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2            2         2   3
+--R                 (180A a c + 180A a b  + 180B a b)f
+--R               + 
+--R                            2            2                     3    2
+--R                 (- 180A a c  + (- 180A b  - 360B a b)c - 60B b )d f
+--R               + 
+--R                       3           2  2
+--R                 (60A c  + 180B b c )d f
+--R            *
+--R               x
+--R        *
+--R            +---+
+--R           \|d f
+--R    /
+--R          4 +---+
+--R       60f \|d f
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 372
+
+--S 373 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              3 3          2          2       2     2
+--R           A a f  + (- 3A a c - 3A a b  - 3B a b)d f
+--R         + 
+--R                  2        2                 3  2          3         2  3
+--R           (3A a c  + (3A b  + 6B a b)c + B b )d f + (- A c  - 3B b c )d
+--R      *
+--R                         2      +-----+
+--R          +-+ +-+    (f x  - d)\|- d f  + 2d f x
+--R         \|d \|f log(---------------------------)
+--R                                  2
+--R                               f x  + d
+--R     + 
+--R                 3 3        2          2       2     2
+--R           - 2A a f  + (6A a c + 6A a b  + 6B a b)d f
+--R         + 
+--R                    2          2                   3  2         3         2  3
+--R           (- 6A a c  + (- 6A b  - 12B a b)c - 2B b )d f + (2A c  + 6B b c )d
+--R      *
+--R                        +-+
+--R          +-----+     x\|f
+--R         \|- d f atan(-----)
+--R                        +-+
+--R                       \|d
+--R  /
+--R       3 +-----+ +-+ +-+
+--R     2f \|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              3 3          2          2       2     2
+--R           A a f  + (- 3A a c - 3A a b  - 3B a b)d f
+--R         + 
+--R                  2        2                 3  2          3         2  3
+--R           (3A a c  + (3A b  + 6B a b)c + B b )d f + (- A c  - 3B b c )d
+--R      *
+--R                        +---+
+--R          +-+ +-+     x\|d f
+--R         \|d \|f atan(-------)
+--R                         d
+--R     + 
+--R                3 3        2          2       2     2
+--R           - A a f  + (3A a c + 3A a b  + 3B a b)d f
+--R         + 
+--R                    2          2                 3  2        3         2  3
+--R           (- 3A a c  + (- 3A b  - 6B a b)c - B b )d f + (A c  + 3B b c )d
+--R      *
+--R                      +-+
+--R          +---+     x\|f
+--R         \|d f atan(-----)
+--R                      +-+
+--R                     \|d
+--R  /
+--R      3 +-+ +-+ +---+
+--R     f \|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 375
+
+--S 376 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 376
+
+)clear all
+
+--S 377 of 556
+t0:=(A+B*x)/((a+b*x+c*x^2)*(d+f*x^2))
+--R 
+--R
+--R                           B x + A
+--R   (1)  ---------------------------------------------
+--R             4        3               2
+--R        c f x  + b f x  + (a f + c d)x  + b d x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 377
+
+--S 378 of 556
+r0:=1/2*(B*c*d+A*b*f-a*B*f)*log(a+b*x+c*x^2)/(c^2*d^2-2*a*c*d*f+_
+   f*(b^2*d+a^2*f))-1/2*(B*c*d+A*b*f-a*B*f)*log(d+f*x^2)/(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))-(A*b^2*f+2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*_
+   sqrt(b^2-4*a*c))+(b*B*d-A*c*d+a*A*f)*atan(x*sqrt(f)/sqrt(d))*_
+   sqrt(f)/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(d))
+--R 
+--R
+--R   (2)
+--R                        2                     2             +-+
+--R         ((4A a c - 2A b  + 2B a b)f + (- 4A c  + 2B b c)d)\|d
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                   +-----------+           +-+
+--R                                   |          2  +-+     x\|f
+--R       (2A a f + (- 2A c + 2B b)d)\|- 4a c + b  \|f atan(-----)
+--R                                                           +-+
+--R                                                          \|d
+--R     + 
+--R                                          2
+--R           ((- A b + B a)f - B c d)log(f x  + d)
+--R         + 
+--R                                        2
+--R           ((A b - B a)f + B c d)log(c x  + b x + a)
+--R      *
+--R          +-----------+
+--R          |          2  +-+
+--R         \|- 4a c + b  \|d
+--R  /
+--R                                         +-----------+
+--R        2 2               2         2 2  |          2  +-+
+--R     (2a f  + (- 4a c + 2b )d f + 2c d )\|- 4a c + b  \|d
+--R                                                    Type: Expression(Integer)
+--E 378
+
+--S 379 of 556
+--a0:=integrate(t0,x)
+--E 379
+
+--S 380 of 556
+--m0:=a0-r0
+--E 380
+
+--S 381 of 556
+--d0:=D(m0,x)
+--E 381
+
+)clear all
+
+--S 382 of 556
+t0:=(A+B*x)/((a+b*x+c*x^2)^2*(d+f*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R        2   6           5             2      2   4                     3
+--R       c f x  + 2b c f x  + ((2a c + b )f + c d)x  + (2a b f + 2b c d)x
+--R     + 
+--R         2             2    2               2
+--R       (a f + (2a c + b )d)x  + 2a b d x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 382
+
+--S 383 of 556
+r0:=(-A*b*(c^2*d+b^2*f-3*a*c*f)+a*B*(2*c^2*d+b^2*f-2*a*c*f)-_
+   c*(A*b^2*f+2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*x)/((b^2-4*a*c)*_
+   (c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*(a+b*x+c*x^2))+2*c*(A*b^2*f+_
+   2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)^(3/2)*(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f)))-_
+   1/2*f*(2*A*b*f*(c*d-a*f)+B*(c^2*d^2-2*a*c*d*f-f*(b^2*d-a^2*f)))*_
+   log(a+b*x+c*x^2)/(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))^2+_
+   1/2*f*(2*A*b*f*(c*d-a*f)+B*(c^2*d^2-2*a*c*d*f-f*(b^2*d-a^2*f)))*_
+   log(d+f*x^2)/(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))^2-f*(b^3*B*d*f+_
+   2*a*A*b^2*f^2-2*A*c*(c*d-a*f)^2+b*B*(3*c^2*d^2-2*a*c*d*f-a^2*f^2))*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+_
+   a^2*f))^2*sqrt(b^2-4*a*c))-f^(3/2)*(A*b^2*d*f+2*b*B*d*(c*d-a*f)-_
+   A*(c*d-a*f)^2)*atan(x*sqrt(f)/sqrt(d))/((c^2*d^2-2*a*c*d*f+_
+   f*(b^2*d+a^2*f))^2*sqrt(d))
+--R 
+--R
+--R   (2)
+--R                     3 3           2 2        3   2          4       2 3    3
+--R               (24A a c  + (- 24A a b  + 12B a b)c  + (4A a b  - 2B a b )c)f
+--R             + 
+--R                          2 4           2        2   3          4         3  2
+--R                   - 56A a c  + (24A a b  + 12B a b)c  + (- 4A b  - 8B a b )c
+--R                 + 
+--R                       5
+--R                   2B b c
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                       5           2            4        3 3  2
+--R               (40A a c  + (- 16A b  - 28B a b)c  + 10B b c )d f
+--R             + 
+--R                      6         5  3
+--R               (- 8A c  + 4B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     3   2           2 3        3 2           5       2 4  3
+--R               (24A a b c  + (- 24A a b  + 12B a b )c + 4A a b  - 2B a b )f
+--R             + 
+--R                          2   3           3        2 2  2          5         4
+--R                   - 56A a b c  + (24A a b  + 12B a b )c  + (- 4A b  - 8B a b )c
+--R                 + 
+--R                       6
+--R                   2B b
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                         4           3          2  3        4 2  2
+--R               (40A a b c  + (- 16A b  - 28B a b )c  + 10B b c )d f
+--R             + 
+--R                        5       2 4  3
+--R               (- 8A b c  + 4B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 4 2           3 2        4          2 4       3 3  3
+--R           (24A a c  + (- 24A a b  + 12B a b)c + 4A a b  - 2B a b )f
+--R         + 
+--R                      3 3         2 2        3   2            4       2 3
+--R               - 56A a c  + (24A a b  + 12B a b)c  + (- 4A a b  - 8B a b )c
+--R             + 
+--R                     5
+--R               2B a b
+--R          *
+--R                2
+--R             d f
+--R         + 
+--R                 2 4             2        2   3          3 2  2
+--R           (40A a c  + (- 16A a b  - 28B a b)c  + 10B a b c )d f
+--R         + 
+--R                    5           4  3
+--R           (- 8A a c  + 4B a b c )d
+--R      *
+--R          +-+         2c x + b
+--R         \|d atanh(--------------)
+--R                    +-----------+
+--R                    |          2
+--R                   \|- 4a c + b
+--R     + 
+--R                    3 2       2 2   3
+--R               (8A a c  - 2A a b c)f
+--R             + 
+--R                       2 3            2        2   2        4         3      2
+--R               (- 16A a c  + (- 4A a b  + 16B a b)c  + (2A b  - 4B a b )c)d f
+--R             + 
+--R                      4          2            3       3 2  2
+--R               (8A a c  + (- 2A b  - 16B a b)c  + 4B b c )d f
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3          2 3  3
+--R               (8A a b c - 2A a b )f
+--R             + 
+--R                       2   2            3        2 2         5         4    2
+--R               (- 16A a b c  + (- 4A a b  + 16B a b )c + 2A b  - 4B a b )d f
+--R             + 
+--R                        3          3          2  2       4   2
+--R               (8A a b c  + (- 2A b  - 16B a b )c  + 4B b c)d f
+--R          *
+--R             x
+--R         + 
+--R                4        3 2  3
+--R           (8A a c - 2A a b )f
+--R         + 
+--R                   3 2          2 2        3            4       2 3    2
+--R           (- 16A a c  + (- 4A a b  + 16B a b)c + 2A a b  - 4B a b )d f
+--R         + 
+--R                2 3            2        2   2         3   2
+--R           (8A a c  + (- 2A a b  - 16B a b)c  + 4B a b c)d f
+--R      *
+--R          +-----------+           +-+
+--R          |          2  +-+     x\|f
+--R         \|- 4a c + b  \|f atan(-----)
+--R                                  +-+
+--R                                 \|d
+--R     + 
+--R                           2        3  2          3      2 2    3
+--R                   ((- 8A a b + 4B a )c  + (2A a b  - B a b )c)f
+--R                 + 
+--R                                  2  3          3         2  2      4     2
+--R                   ((8A a b - 8B a )c  + (- 2A b  - 2B a b )c  + B b c)d f
+--R                 + 
+--R                          4      2 3  2
+--R                   (4B a c  - B b c )d f
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           2 2       3            4      2 3  3
+--R                   ((- 8A a b  + 4B a b)c + 2A a b  - B a b )f
+--R                 + 
+--R                           2       2   2          4         3        5    2
+--R                   ((8A a b  - 8B a b)c  + (- 2A b  - 2B a b )c + B b )d f
+--R                 + 
+--R                            3      3 2  2
+--R                   (4B a b c  - B b c )d f
+--R              *
+--R                 x
+--R             + 
+--R                       3        4         2 3      3 2  3
+--R               ((- 8A a b + 4B a )c + 2A a b  - B a b )f
+--R             + 
+--R                     2        3  2            3       2 2          4    2
+--R               ((8A a b - 8B a )c  + (- 2A a b  - 2B a b )c + B a b )d f
+--R             + 
+--R                    2 3        2 2  2
+--R               (4B a c  - B a b c )d f
+--R          *
+--R                    2
+--R             log(f x  + d)
+--R         + 
+--R                         2        3  2            3      2 2    3
+--R                   ((8A a b - 4B a )c  + (- 2A a b  + B a b )c)f
+--R                 + 
+--R                                    2  3        3         2  2      4     2
+--R                   ((- 8A a b + 8B a )c  + (2A b  + 2B a b )c  - B b c)d f
+--R                 + 
+--R                            4      2 3  2
+--R                   (- 4B a c  + B b c )d f
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         2 2       3            4      2 3  3
+--R                   ((8A a b  - 4B a b)c - 2A a b  + B a b )f
+--R                 + 
+--R                             2       2   2        4         3        5    2
+--R                   ((- 8A a b  + 8B a b)c  + (2A b  + 2B a b )c - B b )d f
+--R                 + 
+--R                              3      3 2  2
+--R                   (- 4B a b c  + B b c )d f
+--R              *
+--R                 x
+--R             + 
+--R                     3        4         2 3      3 2  3
+--R               ((8A a b - 4B a )c - 2A a b  + B a b )f
+--R             + 
+--R                       2        3  2          3       2 2          4    2
+--R               ((- 8A a b + 8B a )c  + (2A a b  + 2B a b )c - B a b )d f
+--R             + 
+--R                      2 3        2 2  2
+--R               (- 4B a c  + B a b c )d f
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                      3 2        2 2       3     3
+--R               (- 4A a c  + (2A a b  - 2B a b)c)f
+--R             + 
+--R                     2 3            2       2   2        4         3      2
+--R               (12A a c  + (- 8A a b  + 2B a b)c  + (2A b  - 2B a b )c)d f
+--R             + 
+--R                         4        2           3       3 2  2
+--R               (- 12A a c  + (6A b  + 2B a b)c  - 2B b c )d f
+--R             + 
+--R                    5         4  3
+--R               (4A c  - 2B b c )d
+--R          *
+--R             x
+--R         + 
+--R                   3        4         2 3       3 2  3
+--R           ((- 6A a b + 4B a )c + 2A a b  - 2B a b )f
+--R         + 
+--R                    2         3  2             3       2 2         5         4
+--R             ((14A a b - 12B a )c  + (- 10A a b  + 8B a b )c + 2A b  - 2B a b )d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                            2  3        3         2  2  2                  4 3
+--R         ((- 10A a b + 12B a )c  + (4A b  - 6B a b )c )d f + (2A b - 4B a)c d
+--R      *
+--R          +-----------+
+--R          |          2  +-+
+--R         \|- 4a c + b  \|d
+--R  /
+--R                5 2     4 2   4         4 3      3 2 2     2 4     3
+--R             (8a c  - 2a b c)f  + (- 32a c  + 24a b c  - 4a b c)d f
+--R           + 
+--R                 3 4      2 2 3        4 2     6   2 2
+--R             (48a c  - 44a b c  + 16a b c  - 2b c)d f
+--R           + 
+--R                   2 5        2 4     4 3  3         6     2 5  4
+--R             (- 32a c  + 24a b c  - 4b c )d f + (8a c  - 2b c )d
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                5        4 3  4         4   2      3 3      2 5    3
+--R             (8a b c - 2a b )f  + (- 32a b c  + 24a b c - 4a b )d f
+--R           + 
+--R                 3   3      2 3 2        5      7  2 2
+--R             (48a b c  - 44a b c  + 16a b c - 2b )d f
+--R           + 
+--R                   2   4        3 3     5 2  3           5     3 4  4
+--R             (- 32a b c  + 24a b c  - 4b c )d f + (8a b c  - 2b c )d
+--R        *
+--R           x
+--R       + 
+--R            6      5 2  4         5 2      4 2      3 4    3
+--R         (8a c - 2a b )f  + (- 32a c  + 24a b c - 4a b )d f
+--R       + 
+--R             4 3      3 2 2      2 4        6  2 2
+--R         (48a c  - 44a b c  + 16a b c - 2a b )d f
+--R       + 
+--R               3 4      2 2 3       4 2  3       2 5       2 4  4
+--R         (- 32a c  + 24a b c  - 4a b c )d f + (8a c  - 2a b c )d
+--R    *
+--R        +-----------+
+--R        |          2  +-+
+--R       \|- 4a c + b  \|d
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 556
+--a0:=integrate(t0,x)
+--E 384
+
+--S 385 of 556
+--m0:=a0-r0
+--E 385
+
+--S 386 of 556
+--d0:=D(m0,x)
+--E 386
+
+)clear all
+
+--S 387 of 556
+t0:=(A+B*x)*(a+b*x+c*x^2)^(1/2)/(d+f*x^2)
+--R 
+--R
+--R                  +--------------+
+--R                  |   2
+--R        (B x + A)\|c x  + b x + a
+--R   (1)  --------------------------
+--R                    2
+--R                 f x  + d
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 556
+r0:=1/2*(b*B+2*A*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f*sqrt(c))+B*sqrt(a+b*x+c*x^2)/f-1/2*atan(1/2*(b*sqrt(-d)+2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))))*(B*c*d-A*b*f-a*B*f+(b*B*d+A*c*d-a*A*f)*_
+   sqrt(f)/sqrt(-d))/(f^(3/2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*(B*c*d-A*b*f-_
+   a*B*f+d*(b*B*d+A*c*d-a*A*f)*sqrt(f)/(-d)^(3/2))/(f^(3/2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                                   +-+ +-+                          +---+ +-+
+--R         ((A a f + (- A c - B b)d)\|c \|f  + ((A b + B a)f - B c d)\|- d \|c )
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                                   +-+ +-+                          +---+ +-+
+--R         ((- A a f + (A c + B b)d)\|c \|f  + ((A b + B a)f - B c d)\|- d \|c )
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                        +---+ +-+             2c x + b
+--R           (2A c + B b)\|- d \|f atanh(----------------------)
+--R                                             +--------------+
+--R                                         +-+ |   2
+--R                                       2\|c \|c x  + b x + a
+--R         + 
+--R                            +--------------+
+--R              +---+ +-+ +-+ |   2
+--R           2B\|- d \|c \|f \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                      +-------------------------+ +-----------------------+
+--R        +---+ +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2f\|- d \|c \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 556
+--a0:=integrate(t0,x)
+--E 389
+
+--S 390 of 556
+--m0:=a0-r0
+--E 390
+
+--S 391 of 556
+--d0:=D(m0,x)
+--E 391
+
+)clear all
+
+--S 392 of 556
+t0:=(A+B*x)/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                  B x + A
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 556
+r0:=1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*(B+A*sqrt(f)/_
+   sqrt(-d))/(sqrt(f)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*atan(1/2*_
+   (b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*(B+A*d*sqrt(f)/(-d)^(3/2))/_
+   (sqrt(f)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                           +-----------------------+
+--R            +-+     +---+  |  +---+ +-+
+--R         (A\|f  + B\|- d )\|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                             +-------------------------+
+--R              +-+     +---+  |    +---+ +-+
+--R         (- A\|f  + B\|- d )\|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R  /
+--R                 +-------------------------+ +-----------------------+
+--R       +---+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2\|- d \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 393
+
+--S 394 of 556
+--a0:=integrate(t0,x)
+--E 394
+
+--S 395 of 556
+--m0:=a0-r0
+--E 395
+
+--S 396 of 556
+--d0:=D(m0,x)
+--E 396
+
+)clear all
+
+--S 397 of 556
+t0:=(A+B*x)/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                     B x + A
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 556
+r0:=-2*(A*b*(c^2*d+b^2*f-3*a*c*f)-a*B*(2*c^2*d+b^2*f-2*a*c*f)+_
+   c*(A*b^2*f+2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*x)/((b^2-4*a*c)*(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))-1/2*atan(1/2*(b*_
+   sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(f)*(B*c*d+A*b*f-a*B*f+_
+   d*(b*B*d-A*c*d+a*A*f)*sqrt(f)/(-d)^(3/2))/((c^2*d^2-2*a*c*d*f+_
+   f*(b^2*d+a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+1/2*atan(1/2*(b*_
+   sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*sqrt(f)*(B*c*d+A*b*f-a*B*f+(b*B*d-_
+   A*c*d+a*A*f)*sqrt(f)/sqrt(-d))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                               2        3        2              2      2
+--R             (((- 4A a b + 4B a )c + A b  - B a b )f + (- 4B a c  + B b c)d)
+--R          *
+--R              +---+ +-+
+--R             \|- d \|f
+--R         + 
+--R                2         2  2            2       2                 3
+--R           (4A a c - A a b )f  + (- 4A a c  + (A b  + 4B a b)c - B b )d f
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                               2        3        2              2      2
+--R             (((- 4A a b + 4B a )c + A b  - B a b )f + (- 4B a c  + B b c)d)
+--R          *
+--R              +---+ +-+
+--R             \|- d \|f
+--R         + 
+--R                  2         2  2          2         2                 3
+--R           (- 4A a c + A a b )f  + (4A a c  + (- A b  - 4B a b)c + B b )d f
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                     2        2                     3         2
+--R           ((- 8A a c  + (4A b  - 4B a b)c)f + (8A c  - 4B b c )d)x
+--R         + 
+--R                             2         3         2                   2
+--R           ((- 12A a b + 8B a )c + 4A b  - 4B a b )f + (4A b - 8B a)c d
+--R      *
+--R                +-------------------------+ +-----------------------+
+--R          +---+ |    +---+ +-+              |  +---+ +-+
+--R         \|- d \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R           3      2 2  2         2 2        2      4            3     2 2  2
+--R       ((8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f + (8a c  - 2b c )d )
+--R    *
+--R              +--------------+ +-------------------------+
+--R        +---+ |   2            |    +---+ +-+
+--R       \|- d \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 556
+--a0:=integrate(t0,x)
+--E 399
+
+--S 400 of 556
+--m0:=a0-r0
+--E 400
+
+--S 401 of 556
+--d0:=D(m0,x)
+--E 401
+
+)clear all
+
+--S 402 of 556
+t0:=(A+B*x)/((a+b*x+c*x^2)^(5/2)*(d+f*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R          2   6           5             2      2   4                     3
+--R         c f x  + 2b c f x  + ((2a c + b )f + c d)x  + (2a b f + 2b c d)x
+--R       + 
+--R           2             2    2               2
+--R         (a f + (2a c + b )d)x  + 2a b d x + a d
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 402
+
+--S 403 of 556
+r0:=-2/3*(A*b*(c^2*d+b^2*f-3*a*c*f)-a*B*(2*c^2*d+b^2*f-2*a*c*f)+_
+   c*(A*b^2*f+2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*x)/((b^2-4*a*c)*_
+   (c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*(a+b*x+c*x^2)^(3/2))+8/3*c*_
+   (A*b^2*f+2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*(b+2*c*x)/((b^2-4*a*c)^2*_
+   (c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))-2*f*_
+   (b^4*B*d*f-A*b^3*f*(c*d-2*a*f)+2*a*B*c*(c*d-a*f)^2+b^2*B*(c^2*d^2-_
+   2*a*c*d*f-a^2*f^2)-A*b*c*(c^2*d^2-6*a*c*d*f+5*a^2*f^2)+c*(b^3*B*d*f+_
+   2*a*A*b^2*f^2-2*A*c*(c*d-a*f)^2+b*B*(3*c^2*d^2-2*a*c*d*f-a^2*f^2))*x)/_
+   ((b^2-4*a*c)*(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))^2*sqrt(a+b*x+c*x^2))-_
+   1/2*f^(3/2)*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+_
+   b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*_
+   (b*f*(b*B*d-A*c*d+a*A*f)-(c*d-a*f)*(B*c*d+A*b*f-a*B*f)+(A*b^2*d*f+_
+   2*b*B*d*(c*d-a*f)-A*(c*d-a*f)^2)*sqrt(f)/sqrt(-d))/((c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))^2*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*f^(3/2)*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-_
+   b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*_
+   (b*f*(b*B*d-A*c*d+a*A*f)-(c*d-a*f)*(B*c*d+A*b*f-a*B*f)-(A*b^2*d*f+_
+   2*b*B*d*(c*d-a*f)-A*(c*d-a*f)^2)*sqrt(f)/sqrt(-d))/((c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))^2*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                               3         4  3         2 3        3 2  2
+--R                       (- 96A a b + 48B a )c  + (48A a b  - 24B a b )c
+--R                     + 
+--R                                5       2 4
+--R                       (- 6A a b  + 3B a b )c
+--R                  *
+--R                      3
+--R                     f
+--R                 + 
+--R                             2         3  4          3 3        5          4  2
+--R                       (96A a b - 96B a )c  - 48A a b c  + (6A b  + 18B a b )c
+--R                     + 
+--R                             6
+--R                       - 3B b c
+--R                  *
+--R                        2
+--R                     d f
+--R                 + 
+--R                         2 5          2 4       4 3  2
+--R                   (48B a c  - 24B a b c  + 3B b c )d f
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                               3 2        4   2         2 4        3 3
+--R                       (- 96A a b  + 48B a b)c  + (48A a b  - 24B a b )c
+--R                     + 
+--R                               6       2 5
+--R                       - 6A a b  + 3B a b
+--R                  *
+--R                      3
+--R                     f
+--R                 + 
+--R                             2 2        3   3          4 2        6          5
+--R                       (96A a b  - 96B a b)c  - 48A a b c  + (6A b  + 18B a b )c
+--R                     + 
+--R                             7
+--R                       - 3B b
+--R                  *
+--R                        2
+--R                     d f
+--R                 + 
+--R                         2   4          3 3       5 2  2
+--R                   (48B a b c  - 24B a b c  + 3B b c )d f
+--R              *
+--R                 x
+--R             + 
+--R                           4         5  2         3 3        4 2         2 5
+--R                   (- 96A a b + 48B a )c  + (48A a b  - 24B a b )c - 6A a b
+--R                 + 
+--R                       3 4
+--R                   3B a b
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                         3         4  3        2 3 2          5        2 4
+--R                   (96A a b - 96B a )c  - 48A a b c  + (6A a b  + 18B a b )c
+--R                 + 
+--R                           6
+--R                   - 3B a b
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                     3 4        2 2 3         4 2  2
+--R               (48B a c  - 24B a b c  + 3B a b c )d f
+--R          *
+--R              +---+ +-+
+--R             \|- d \|f
+--R         + 
+--R                     4 3        3 2 2       2 4   4
+--R               (48A a c  - 24A a b c  + 3A a b c)f
+--R             + 
+--R                          3 4        3   3           4        2 3  2
+--R                   - 96A a c  + 96B a b c  + (18A a b  - 48B a b )c
+--R                 + 
+--R                          6         5
+--R                   (- 3A b  + 6B a b )c
+--R              *
+--R                    3
+--R                 d f
+--R             + 
+--R                        2 5             2        2   4        4          3  3
+--R                   48A a c  + (- 24A a b  - 96B a b)c  + (3A b  + 48B a b )c
+--R                 + 
+--R                         5 2
+--R                   - 6B b c
+--R              *
+--R                  2 2
+--R                 d f
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     4   2        3 3        2 5  4
+--R               (48A a b c  - 24A a b c + 3A a b )f
+--R             + 
+--R                          3   3        3 2 2           5        2 4         7
+--R                   - 96A a b c  + 96B a b c  + (18A a b  - 48B a b )c - 3A b
+--R                 + 
+--R                         6
+--R                   6B a b
+--R              *
+--R                    3
+--R                 d f
+--R             + 
+--R                        2   4             3        2 2  3        5          4  2
+--R                   48A a b c  + (- 24A a b  - 96B a b )c  + (3A b  + 48B a b )c
+--R                 + 
+--R                         6
+--R                   - 6B b c
+--R              *
+--R                  2 2
+--R                 d f
+--R          *
+--R             x
+--R         + 
+--R                 5 2        4 2        3 4  4
+--R           (48A a c  - 24A a b c + 3A a b )f
+--R         + 
+--R                      4 3        4   2         2 4        3 3           6
+--R               - 96A a c  + 96B a b c  + (18A a b  - 48B a b )c - 3A a b
+--R             + 
+--R                   2 5
+--R               6B a b
+--R          *
+--R                3
+--R             d f
+--R         + 
+--R                    3 4           2 2        3   3          4        2 3  2
+--R               48A a c  + (- 24A a b  - 96B a b)c  + (3A a b  + 48B a b )c
+--R             + 
+--R                       5
+--R               - 6B a b c
+--R          *
+--R              2 2
+--R             d f
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                               3         4  3         2 3        3 2  2
+--R                       (- 96A a b + 48B a )c  + (48A a b  - 24B a b )c
+--R                     + 
+--R                                5       2 4
+--R                       (- 6A a b  + 3B a b )c
+--R                  *
+--R                      3
+--R                     f
+--R                 + 
+--R                             2         3  4          3 3        5          4  2
+--R                       (96A a b - 96B a )c  - 48A a b c  + (6A b  + 18B a b )c
+--R                     + 
+--R                             6
+--R                       - 3B b c
+--R                  *
+--R                        2
+--R                     d f
+--R                 + 
+--R                         2 5          2 4       4 3  2
+--R                   (48B a c  - 24B a b c  + 3B b c )d f
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                               3 2        4   2         2 4        3 3
+--R                       (- 96A a b  + 48B a b)c  + (48A a b  - 24B a b )c
+--R                     + 
+--R                               6       2 5
+--R                       - 6A a b  + 3B a b
+--R                  *
+--R                      3
+--R                     f
+--R                 + 
+--R                             2 2        3   3          4 2        6          5
+--R                       (96A a b  - 96B a b)c  - 48A a b c  + (6A b  + 18B a b )c
+--R                     + 
+--R                             7
+--R                       - 3B b
+--R                  *
+--R                        2
+--R                     d f
+--R                 + 
+--R                         2   4          3 3       5 2  2
+--R                   (48B a b c  - 24B a b c  + 3B b c )d f
+--R              *
+--R                 x
+--R             + 
+--R                           4         5  2         3 3        4 2         2 5
+--R                   (- 96A a b + 48B a )c  + (48A a b  - 24B a b )c - 6A a b
+--R                 + 
+--R                       3 4
+--R                   3B a b
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                         3         4  3        2 3 2          5        2 4
+--R                   (96A a b - 96B a )c  - 48A a b c  + (6A a b  + 18B a b )c
+--R                 + 
+--R                           6
+--R                   - 3B a b
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                     3 4        2 2 3         4 2  2
+--R               (48B a c  - 24B a b c  + 3B a b c )d f
+--R          *
+--R              +---+ +-+
+--R             \|- d \|f
+--R         + 
+--R                       4 3        3 2 2       2 4   4
+--R               (- 48A a c  + 24A a b c  - 3A a b c)f
+--R             + 
+--R                        3 4        3   3             4        2 3  2
+--R                   96A a c  - 96B a b c  + (- 18A a b  + 48B a b )c
+--R                 + 
+--R                        6         5
+--R                   (3A b  - 6B a b )c
+--R              *
+--R                    3
+--R                 d f
+--R             + 
+--R                          2 5           2        2   4          4          3  3
+--R                   - 48A a c  + (24A a b  + 96B a b)c  + (- 3A b  - 48B a b )c
+--R                 + 
+--R                       5 2
+--R                   6B b c
+--R              *
+--R                  2 2
+--R                 d f
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       4   2        3 3        2 5  4
+--R               (- 48A a b c  + 24A a b c - 3A a b )f
+--R             + 
+--R                        3   3        3 2 2             5        2 4         7
+--R                   96A a b c  - 96B a b c  + (- 18A a b  + 48B a b )c + 3A b
+--R                 + 
+--R                           6
+--R                   - 6B a b
+--R              *
+--R                    3
+--R                 d f
+--R             + 
+--R                          2   4           3        2 2  3
+--R                   - 48A a b c  + (24A a b  + 96B a b )c
+--R                 + 
+--R                          5          4  2       6
+--R                   (- 3A b  - 48B a b )c  + 6B b c
+--R              *
+--R                  2 2
+--R                 d f
+--R          *
+--R             x
+--R         + 
+--R                   5 2        4 2        3 4  4
+--R           (- 48A a c  + 24A a b c - 3A a b )f
+--R         + 
+--R                    4 3        4   2           2 4        3 3           6
+--R               96A a c  - 96B a b c  + (- 18A a b  + 48B a b )c + 3A a b
+--R             + 
+--R                     2 5
+--R               - 6B a b
+--R          *
+--R                3
+--R             d f
+--R         + 
+--R                      3 4         2 2        3   3            4        2 3  2
+--R               - 48A a c  + (24A a b  + 96B a b)c  + (- 3A a b  - 48B a b )c
+--R             + 
+--R                     5
+--R               6B a b c
+--R          *
+--R              2 2
+--R             d f
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                           3 4          2 2        3   3
+--R                   - 160A a c  + (152A a b  - 80B a b)c
+--R                 + 
+--R                             4        2 3  2
+--R                   (- 24A a b  + 12B a b )c
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                         2 5              2        2   4         4          3  3
+--R                   384A a c  + (- 176A a b  - 64B a b)c  + (32A b  + 40B a b )c
+--R                 + 
+--R                          5 2
+--R                   - 12B b c
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                          6          2             5        3 4  2
+--R               (- 288A a c  + (120A b  + 176B a b)c  - 68B b c )d f
+--R             + 
+--R                     7          6  3
+--R               (64A c  - 32B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                            3         4  3          2 3         3 2  2
+--R                   (- 432A a b + 96B a )c  + (324A a b  - 168B a b )c
+--R                 + 
+--R                             5        2 4
+--R                   (- 48A a b  + 24B a b )c
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                          2          3  4              3        2 2  3
+--R                   (768A a b - 192B a )c  + (- 360A a b  - 96B a b )c
+--R                 + 
+--R                         5          4  2        6
+--R                   (60A b  + 96B a b )c  - 24B b c
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                                   2  5          3           2  4        4 3  2
+--R               ((- 432A a b + 96B a )c  + (180A b  + 216B a b )c  - 96B b c )d f
+--R             + 
+--R                       6        2 5  3
+--R               (96A b c  - 48B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                           4 3        3 2 2          2 4        3 3            6
+--R                   - 192A a c  - 96A a b c  + (144A a b  - 72B a b )c - 24A a b
+--R                 + 
+--R                        2 5
+--R                   12B a b
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                         3 4          2 2         3   3
+--R                   480A a c  + (120A a b  - 240B a b)c
+--R                 + 
+--R                              4        2 3  2         6          5          7
+--R                   (- 120A a b  - 12B a b )c  + (24A b  + 48B a b )c - 12B b
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                           2 5           2         2   4         4          3  3
+--R                   - 384A a c  + (48A a b  + 288B a b)c  + (48A b  - 48B a b )c
+--R                 + 
+--R                          5 2
+--R                   - 24B b c
+--R              *
+--R                  2
+--R                 d f
+--R             + 
+--R                       6         2            5        3 4  3
+--R               (96A a c  + (24A b  - 48B a b)c  - 12B b c )d
+--R          *
+--R             x
+--R         + 
+--R                        4          5  2          3 3         4 2          2 5
+--R               (- 320A a b + 128B a )c  + (200A a b  - 112B a b )c - 28A a b
+--R             + 
+--R                    3 4
+--R               16B a b
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                      3          4  3            2 3        3 2  2
+--R               (496A a b - 288B a )c  + (- 292A a b  + 56B a b )c
+--R             + 
+--R                       5        2 4         7         6
+--R               (64A a b  + 24B a b )c - 4A b  - 8B a b
+--R          *
+--R                2
+--R             d f
+--R         + 
+--R                        2          3  4            3        2 2  3
+--R               (- 224A a b + 192B a )c  + (112A a b  - 32B a b )c
+--R             + 
+--R                      5          4  2
+--R               (- 8A b  - 16B a b )c
+--R          *
+--R              2
+--R             d f
+--R         + 
+--R                            2  5          3         2  4  3
+--R           ((48A a b - 32B a )c  + (- 4A b  - 8B a b )c )d
+--R      *
+--R                +-------------------------+ +-----------------------+
+--R          +---+ |    +---+ +-+              |  +---+ +-+
+--R         \|- d \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                 6 3      5 2 2     4 4   4
+--R             (96a c  - 48a b c  + 6a b c)f
+--R           + 
+--R                    5 4       4 2 3       3 4 2      2 6     3
+--R             (- 384a c  + 384a b c  - 120a b c  + 12a b c)d f
+--R           + 
+--R                  4 5       3 2 4       2 4 3        6 2     8   2 2
+--R             (576a c  - 672a b c  + 324a b c  - 72a b c  + 6b c)d f
+--R           + 
+--R                    3 6       2 2 5         4 4      6 3  3
+--R             (- 384a c  + 384a b c  - 120a b c  + 12b c )d f
+--R           + 
+--R                 2 7        2 6     4 5  4
+--R             (96a c  - 48a b c  + 6b c )d
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                 6   2      5 3      4 5  4
+--R             (96a b c  - 48a b c + 6a b )f
+--R           + 
+--R                    5   3       4 3 2       3 5       2 7    3
+--R             (- 384a b c  + 384a b c  - 120a b c + 12a b )d f
+--R           + 
+--R                  4   4       3 3 3       2 5 2        7      9  2 2
+--R             (576a b c  - 672a b c  + 324a b c  - 72a b c + 6b )d f
+--R           + 
+--R                    3   5       2 3 4         5 3      7 2  3
+--R             (- 384a b c  + 384a b c  - 120a b c  + 12b c )d f
+--R           + 
+--R                 2   6        3 5     5 4  4
+--R             (96a b c  - 48a b c  + 6b c )d
+--R        *
+--R           x
+--R       + 
+--R             7 2      6 2      5 4  4
+--R         (96a c  - 48a b c + 6a b )f
+--R       + 
+--R                6 3       5 2 2       4 4       3 6    3
+--R         (- 384a c  + 384a b c  - 120a b c + 12a b )d f
+--R       + 
+--R              5 4       4 2 3       3 4 2      2 6        8  2 2
+--R         (576a c  - 672a b c  + 324a b c  - 72a b c + 6a b )d f
+--R       + 
+--R                4 5       3 2 4       2 4 3        6 2  3
+--R         (- 384a c  + 384a b c  - 120a b c  + 12a b c )d f
+--R       + 
+--R             3 6      2 2 5       4 4  4
+--R         (96a c  - 48a b c  + 6a b c )d
+--R    *
+--R              +--------------+ +-------------------------+
+--R        +---+ |   2            |    +---+ +-+
+--R       \|- d \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 556
+--a0:=integrate(t0,x)
+--E 404
+
+--S 405 of 556
+--m0:=a0-r0
+--E 405
+
+--S 406 of 556
+--d0:=D(m0,x)
+--E 406
+
+)clear all
+
+--S 407 of 556
+t0:=(A+B*x)*(a+b*x+c*x^2)/(d+e*x+f*x^2)
+--R 
+--R
+--R             3               2
+--R        B c x  + (A c + B b)x  + (A b + B a)x + A a
+--R   (1)  -------------------------------------------
+--R                          2
+--R                       f x  + e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 407
+
+--S 408 of 556
+r0:=-(B*c*e-b*B*f-A*c*f)*x/f^2+1/2*B*c*x^2/f-1/2*(A*f*(c*e-b*f)-_
+   B*(c*e^2-c*d*f-b*e*f+a*f^2))*log(d+e*x+f*x^2)/f^3-(A*f*(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2)+B*(f*(b*e^2-2*b*d*f-a*e*f)-c*(e^3-3*d*e*f)))*_
+   atanh((e+2*f*x)/sqrt(e^2-4*d*f))/(f^3*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R                   3                                     2
+--R           - 4A a f  + ((2A b + 2B a)e + (4A c + 4B b)d)f
+--R         + 
+--R                            2                      3
+--R           ((- 2A c - 2B b)e  - 6B c d e)f + 2B c e
+--R      *
+--R                  2f x + e
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4d f + e
+--R     + 
+--R                          2                                    2
+--R             ((A b + B a)f  + ((- A c - B b)e - B c d)f + B c e )
+--R          *
+--R                    2
+--R             log(f x  + e x + d)
+--R         + 
+--R                2 2                  2
+--R           B c f x  + ((2A c + 2B b)f  - 2B c e f)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4d f + e
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     2f \|- 4d f + e
+--R                                                    Type: Expression(Integer)
+--E 408
+
+--S 409 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   3                                       2
+--R             2A a f  + ((- A b - B a)e + (- 2A c - 2B b)d)f
+--R           + 
+--R                          2                     3
+--R             ((A c + B b)e  + 3B c d e)f - B c e
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2f x  + 2e f x - 2d f + e )\|- 4d f + e   + (8d f  - 2e f)x
+--R                + 
+--R                            3
+--R                  4d e f - e
+--R             /
+--R                   2
+--R                f x  + e x + d
+--R       + 
+--R                            2                                    2
+--R               ((A b + B a)f  + ((- A c - B b)e - B c d)f + B c e )
+--R            *
+--R                      2
+--R               log(f x  + e x + d)
+--R           + 
+--R                  2 2                  2
+--R             B c f x  + ((2A c + 2B b)f  - 2B c e f)x
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4d f + e
+--R    /
+--R           +-----------+
+--R         3 |          2
+--R       2f \|- 4d f + e
+--R     ,
+--R
+--R                   3                                         2
+--R             4A a f  + ((- 2A b - 2B a)e + (- 4A c - 4B b)d)f
+--R           + 
+--R                            2                      3
+--R             ((2A c + 2B b)e  + 6B c d e)f - 2B c e
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2f x + e)\|4d f - e
+--R           atan(----------------------)
+--R                               2
+--R                       4d f - e
+--R       + 
+--R                            2                                    2
+--R               ((A b + B a)f  + ((- A c - B b)e - B c d)f + B c e )
+--R            *
+--R                      2
+--R               log(f x  + e x + d)
+--R           + 
+--R                  2 2                  2
+--R             B c f x  + ((2A c + 2B b)f  - 2B c e f)x
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4d f - e
+--R    /
+--R           +---------+
+--R         3 |        2
+--R       2f \|4d f - e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 409
+
+--S 410 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 3                                       2
+--R           2A a f  + ((- A b - B a)e + (- 2A c - 2B b)d)f
+--R         + 
+--R                        2                     3
+--R           ((A c + B b)e  + 3B c d e)f - B c e
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2f x  + 2e f x - 2d f + e )\|- 4d f + e   + (8d f  - 2e f)x
+--R              + 
+--R                          3
+--R                4d e f - e
+--R           /
+--R                 2
+--R              f x  + e x + d
+--R     + 
+--R                 3                                         2
+--R           4A a f  + ((- 2A b - 2B a)e + (- 4A c - 4B b)d)f
+--R         + 
+--R                          2                      3
+--R           ((2A c + 2B b)e  + 6B c d e)f - 2B c e
+--R      *
+--R                  2f x + e
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4d f + e
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     2f \|- 4d f + e
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 3                                       2
+--R           2A a f  + ((- A b - B a)e + (- 2A c - 2B b)d)f
+--R         + 
+--R                        2                     3
+--R           ((A c + B b)e  + 3B c d e)f - B c e
+--R      *
+--R          +---------+
+--R          |        2          2f x + e
+--R         \|4d f - e  atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4d f + e
+--R     + 
+--R                 3                                       2
+--R           2A a f  + ((- A b - B a)e + (- 2A c - 2B b)d)f
+--R         + 
+--R                        2                     3
+--R           ((A c + B b)e  + 3B c d e)f - B c e
+--R      *
+--R                                       +---------+
+--R          +-----------+                |        2
+--R          |          2      (2f x + e)\|4d f - e
+--R         \|- 4d f + e  atan(----------------------)
+--R                                           2
+--R                                   4d f - e
+--R  /
+--R        +-----------+ +---------+
+--R      3 |          2  |        2
+--R     f \|- 4d f + e  \|4d f - e
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 413
+
+)clear all
+
+--S 414 of 556
+t0:=(A+B*x)*(a+b*x+c*x^2)^2/(d+e*x+f*x^2)
+--R 
+--R
+--R   (1)
+--R          2 5       2           4                        2  3
+--R       B c x  + (A c  + 2B b c)x  + ((2A b + 2B a)c + B b )x
+--R     + 
+--R                    2           2                2        2
+--R       (2A a c + A b  + 2B a b)x  + (2A a b + B a )x + A a
+--R  /
+--R        2
+--R     f x  + e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 414
+
+--S 415 of 556
+r0:=(B*(c*e-b*f)*(f*(b*e-2*a*f)-c*(e^2-2*d*f))+A*f*(b^2*f^2-_
+   2*c*f*(b*e-a*f)+c^2*(e^2-d*f)))*x/f^4-1/2*(A*c*f*(c*e-2*b*f)-_
+   B*(b^2*f^2-2*c*f*(b*e-a*f)+c^2*(e^2-d*f)))*x^2/f^3-1/3*c*(B*c*e-_
+   2*b*B*f-A*c*f)*x^3/f^2+1/4*B*c^2*x^4/f+1/2*(A*f*(c*e-b*f)*(f*_
+   (b*e-2*a*f)-c*(e^2-2*d*f))+B*(c^2*(e^4-3*d*e^2*f+d^2*f^2)-_
+   f^2*(2*a*b*e*f-a^2*f^2-b^2*(e^2-d*f))+2*c*f*(a*f*(e^2-d*f)-_
+   b*(e^3-2*d*e*f))))*log(d+e*x+f*x^2)/f^5-(A*f*(c^2*(e^4-4*d*e^2*f+_
+   2*d^2*f^2)-f^2*(2*a*b*e*f-2*a^2*f^2-b^2*(e^2-2*d*f))+2*c*f*(a*f*_
+   (e^2-2*d*f)-b*(e^3-3*d*e*f)))-B*(c^2*(e^5-5*d*e^3*f+5*d^2*e*f^2)+_
+   f^2*(a^2*e*f^2-2*a*b*f*(e^2-2*d*f)+b^2*(e^3-3*d*e*f))+2*c*f*(a*e*f*_
+   (e^2-3*d*f)-b*(e^4-4*d*e^2*f+2*d^2*f^2))))*atanh((e+2*f*x)/_
+   sqrt(e^2-4*d*f))/(f^5*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R                  2 5                    2                     2              4
+--R           - 24A a f  + ((24A a b + 12B a )e + (48A a c + 24A b  + 48B a b)d)f
+--R         + 
+--R                                 2            2
+--R               (- 24A a c - 12A b  - 24B a b)e
+--R             + 
+--R                                          2               2            2
+--R               ((- 72A b - 72B a)c - 36B b )d e + (- 24A c  - 48B b c)d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                                          2  3         2              2
+--R                 ((24A b + 24B a)c + 12B b )e  + (48A c  + 96B b c)d e
+--R               + 
+--R                      2 2
+--R                 60B c d e
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                    2            4        2   3          2 5
+--R           ((- 12A c  - 24B b c)e  - 60B c d e )f + 12B c e
+--R      *
+--R                  2f x + e
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4d f + e
+--R     + 
+--R                              2  4
+--R               (12A a b + 6B a )f
+--R             + 
+--R                                      2
+--R                     (- 12A a c - 6A b  - 12B a b)e
+--R                   + 
+--R                                               2
+--R                     ((- 12A b - 12B a)c - 6B b )d
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                                             2  2         2
+--R                     ((12A b + 12B a)c + 6B b )e  + (12A c  + 24B b c)d e
+--R                   + 
+--R                         2 2
+--R                     6B c d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                       2            3        2   2         2 4
+--R               ((- 6A c  - 12B b c)e  - 18B c d e )f + 6B c e
+--R          *
+--R                    2
+--R             log(f x  + e x + d)
+--R         + 
+--R               2 4 4         2           4       2   3  3
+--R           3B c f x  + ((4A c  + 8B b c)f  - 4B c e f )x
+--R         + 
+--R                                       2  4           2                   2   3
+--R               ((12A b + 12B a)c + 6B b )f  + ((- 6A c  - 12B b c)e - 6B c d)f
+--R             + 
+--R                   2 2 2
+--R               6B c e f
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                               2            4
+--R               (24A a c + 12A b  + 24B a b)f
+--R             + 
+--R                                           2             2              3
+--R               (((- 24A b - 24B a)c - 12B b )e + (- 12A c  - 24B b c)d)f
+--R             + 
+--R                      2            2        2     2        2 3
+--R               ((12A c  + 24B b c)e  + 24B c d e)f  - 12B c e f
+--R          *
+--R             x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4d f + e
+--R  /
+--R          +-----------+
+--R        5 |          2
+--R     12f \|- 4d f + e
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2 5
+--R             12A a f
+--R           + 
+--R                               2                       2              4
+--R             ((- 12A a b - 6B a )e + (- 24A a c - 12A b  - 24B a b)d)f
+--R           + 
+--R                                2            2                            2
+--R                 (12A a c + 6A b  + 12B a b)e  + ((36A b + 36B a)c + 18B b )d e
+--R               + 
+--R                       2            2
+--R                 (12A c  + 24B b c)d
+--R            *
+--R                3
+--R               f
+--R           + 
+--R                                           2  3           2              2
+--R                 ((- 12A b - 12B a)c - 6B b )e  + (- 24A c  - 48B b c)d e
+--R               + 
+--R                        2 2
+--R                 - 30B c d e
+--R            *
+--R                2
+--R               f
+--R           + 
+--R                   2            4        2   3         2 5
+--R             ((6A c  + 12B b c)e  + 30B c d e )f - 6B c e
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2f x  + 2e f x - 2d f + e )\|- 4d f + e   + (8d f  - 2e f)x
+--R                + 
+--R                            3
+--R                  4d e f - e
+--R             /
+--R                   2
+--R                f x  + e x + d
+--R       + 
+--R                                2  4
+--R                 (12A a b + 6B a )f
+--R               + 
+--R                                      2
+--R                     (- 12A a c - 6A b  - 12B a b)e
+--R                   + 
+--R                                               2
+--R                     ((- 12A b - 12B a)c - 6B b )d
+--R                *
+--R                    3
+--R                   f
+--R               + 
+--R                                             2  2         2
+--R                     ((12A b + 12B a)c + 6B b )e  + (12A c  + 24B b c)d e
+--R                   + 
+--R                         2 2
+--R                     6B c d
+--R                *
+--R                    2
+--R                   f
+--R               + 
+--R                         2            3        2   2         2 4
+--R                 ((- 6A c  - 12B b c)e  - 18B c d e )f + 6B c e
+--R            *
+--R                      2
+--R               log(f x  + e x + d)
+--R           + 
+--R                 2 4 4         2           4       2   3  3
+--R             3B c f x  + ((4A c  + 8B b c)f  - 4B c e f )x
+--R           + 
+--R                                         2  4
+--R                 ((12A b + 12B a)c + 6B b )f
+--R               + 
+--R                         2                   2   3       2 2 2
+--R                 ((- 6A c  - 12B b c)e - 6B c d)f  + 6B c e f
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                                 2            4
+--R                 (24A a c + 12A b  + 24B a b)f
+--R               + 
+--R                                             2             2              3
+--R                 (((- 24A b - 24B a)c - 12B b )e + (- 12A c  - 24B b c)d)f
+--R               + 
+--R                        2            2        2     2        2 3
+--R                 ((12A c  + 24B b c)e  + 24B c d e)f  - 12B c e f
+--R            *
+--R               x
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4d f + e
+--R    /
+--R            +-----------+
+--R          5 |          2
+--R       12f \|- 4d f + e
+--R     ,
+--R
+--R                  2 5
+--R             24A a f
+--R           + 
+--R                                2                       2              4
+--R             ((- 24A a b - 12B a )e + (- 48A a c - 24A b  - 48B a b)d)f
+--R           + 
+--R                                 2            2                            2
+--R                 (24A a c + 12A b  + 24B a b)e  + ((72A b + 72B a)c + 36B b )d e
+--R               + 
+--R                       2            2
+--R                 (24A c  + 48B b c)d
+--R            *
+--R                3
+--R               f
+--R           + 
+--R                                            2  3           2              2
+--R                 ((- 24A b - 24B a)c - 12B b )e  + (- 48A c  - 96B b c)d e
+--R               + 
+--R                        2 2
+--R                 - 60B c d e
+--R            *
+--R                2
+--R               f
+--R           + 
+--R                    2            4        2   3          2 5
+--R             ((12A c  + 24B b c)e  + 60B c d e )f - 12B c e
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2f x + e)\|4d f - e
+--R           atan(----------------------)
+--R                               2
+--R                       4d f - e
+--R       + 
+--R                                2  4
+--R                 (12A a b + 6B a )f
+--R               + 
+--R                                      2
+--R                     (- 12A a c - 6A b  - 12B a b)e
+--R                   + 
+--R                                               2
+--R                     ((- 12A b - 12B a)c - 6B b )d
+--R                *
+--R                    3
+--R                   f
+--R               + 
+--R                                             2  2         2
+--R                     ((12A b + 12B a)c + 6B b )e  + (12A c  + 24B b c)d e
+--R                   + 
+--R                         2 2
+--R                     6B c d
+--R                *
+--R                    2
+--R                   f
+--R               + 
+--R                         2            3        2   2         2 4
+--R                 ((- 6A c  - 12B b c)e  - 18B c d e )f + 6B c e
+--R            *
+--R                      2
+--R               log(f x  + e x + d)
+--R           + 
+--R                 2 4 4         2           4       2   3  3
+--R             3B c f x  + ((4A c  + 8B b c)f  - 4B c e f )x
+--R           + 
+--R                                         2  4
+--R                 ((12A b + 12B a)c + 6B b )f
+--R               + 
+--R                         2                   2   3       2 2 2
+--R                 ((- 6A c  - 12B b c)e - 6B c d)f  + 6B c e f
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                                 2            4
+--R                 (24A a c + 12A b  + 24B a b)f
+--R               + 
+--R                                             2             2              3
+--R                 (((- 24A b - 24B a)c - 12B b )e + (- 12A c  - 24B b c)d)f
+--R               + 
+--R                        2            2        2     2        2 3
+--R                 ((12A c  + 24B b c)e  + 24B c d e)f  - 12B c e f
+--R            *
+--R               x
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4d f - e
+--R    /
+--R            +---------+
+--R          5 |        2
+--R       12f \|4d f - e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 416
+
+--S 417 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               2 5                   2                     2             4
+--R           2A a f  + ((- 2A a b - B a )e + (- 4A a c - 2A b  - 4B a b)d)f
+--R         + 
+--R                            2           2                         2
+--R               (2A a c + A b  + 2B a b)e  + ((6A b + 6B a)c + 3B b )d e
+--R             + 
+--R                    2           2
+--R               (2A c  + 4B b c)d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                                   2  3          2             2       2 2   2
+--R           (((- 2A b - 2B a)c - B b )e  + (- 4A c  - 8B b c)d e  - 5B c d e)f
+--R         + 
+--R                2           4       2   3        2 5
+--R           ((A c  + 2B b c)e  + 5B c d e )f - B c e
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2f x  + 2e f x - 2d f + e )\|- 4d f + e   + (8d f  - 2e f)x
+--R              + 
+--R                          3
+--R                4d e f - e
+--R           /
+--R                 2
+--R              f x  + e x + d
+--R     + 
+--R               2 5                    2                     2             4
+--R           4A a f  + ((- 4A a b - 2B a )e + (- 8A a c - 4A b  - 8B a b)d)f
+--R         + 
+--R                             2           2                           2
+--R               (4A a c + 2A b  + 4B a b)e  + ((12A b + 12B a)c + 6B b )d e
+--R             + 
+--R                    2           2
+--R               (4A c  + 8B b c)d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                                         2  3          2              2
+--R                 ((- 4A b - 4B a)c - 2B b )e  + (- 8A c  - 16B b c)d e
+--R               + 
+--R                        2 2
+--R                 - 10B c d e
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                 2           4        2   3         2 5
+--R           ((2A c  + 4B b c)e  + 10B c d e )f - 2B c e
+--R      *
+--R                  2f x + e
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4d f + e
+--R  /
+--R         +-----------+
+--R       5 |          2
+--R     2f \|- 4d f + e
+--R                                                    Type: Expression(Integer)
+--E 417
+
+--S 418 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               2 5                   2                     2             4
+--R           2A a f  + ((- 2A a b - B a )e + (- 4A a c - 2A b  - 4B a b)d)f
+--R         + 
+--R                            2           2                         2
+--R               (2A a c + A b  + 2B a b)e  + ((6A b + 6B a)c + 3B b )d e
+--R             + 
+--R                    2           2
+--R               (2A c  + 4B b c)d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                                   2  3          2             2       2 2   2
+--R           (((- 2A b - 2B a)c - B b )e  + (- 4A c  - 8B b c)d e  - 5B c d e)f
+--R         + 
+--R                2           4       2   3        2 5
+--R           ((A c  + 2B b c)e  + 5B c d e )f - B c e
+--R      *
+--R          +---------+
+--R          |        2          2f x + e
+--R         \|4d f - e  atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4d f + e
+--R     + 
+--R               2 5                   2                     2             4
+--R           2A a f  + ((- 2A a b - B a )e + (- 4A a c - 2A b  - 4B a b)d)f
+--R         + 
+--R                            2           2                         2
+--R               (2A a c + A b  + 2B a b)e  + ((6A b + 6B a)c + 3B b )d e
+--R             + 
+--R                    2           2
+--R               (2A c  + 4B b c)d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                                   2  3          2             2       2 2   2
+--R           (((- 2A b - 2B a)c - B b )e  + (- 4A c  - 8B b c)d e  - 5B c d e)f
+--R         + 
+--R                2           4       2   3        2 5
+--R           ((A c  + 2B b c)e  + 5B c d e )f - B c e
+--R      *
+--R                                       +---------+
+--R          +-----------+                |        2
+--R          |          2      (2f x + e)\|4d f - e
+--R         \|- 4d f + e  atan(----------------------)
+--R                                           2
+--R                                   4d f - e
+--R  /
+--R        +-----------+ +---------+
+--R      5 |          2  |        2
+--R     f \|- 4d f + e  \|4d f - e
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 556
+t0:=(A+B*x)/((a+b*x+c*x^2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                     B x + A
+--R   (1)  -----------------------------------------------------------------
+--R             4               3                     2
+--R        c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 421
+
+--S 422 of 556
+r0:=1/2*(B*c*d-A*c*e+A*b*f-a*B*f)*log(a+b*x+c*x^2)/(c^2*d^2+_
+   f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))-1/2*(B*c*d-A*c*e+_
+   A*b*f-a*B*f)*log(d+e*x+f*x^2)/(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))-(A*b^2*f+2*c*(A*c*d+a*B*e-a*A*f)-_
+   b*(B*c*d+A*c*e+a*B*f))*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/((c^2*d^2+_
+   f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(b^2-4*a*c))+_
+   (B*(c*d*e-2*b*d*f+a*e*f)-A*(c*e^2-2*c*d*f-b*e*f+2*a*f^2))*_
+   atanh((e+2*f*x)/sqrt(e^2-4*d*f))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R                  2                                              2
+--R         (- 4A a f  + ((2A b + 2B a)e + (4A c - 4B b)d)f - 2A c e  + 2B c d e)
+--R      *
+--R          +-----------+
+--R          |          2          2f x + e
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4d f + e
+--R     + 
+--R                        2                                        2
+--R         ((4A a c - 2A b  + 2B a b)f + (2A b - 4B a)c e + (- 4A c  + 2B b c)d)
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4d f + e  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                                  2
+--R           ((- A b + B a)f + A c e - B c d)log(f x  + e x + d)
+--R         + 
+--R                                                2
+--R           ((A b - B a)f - A c e + B c d)log(c x  + b x + a)
+--R      *
+--R          +-----------+ +-----------+
+--R          |          2  |          2
+--R         \|- 4d f + e  \|- 4a c + b
+--R  /
+--R          2 2                           2             2                2 2
+--R       (2a f  + (- 2a b e + (- 4a c + 2b )d)f + 2a c e  - 2b c d e + 2c d )
+--R    *
+--R        +-----------+ +-----------+
+--R        |          2  |          2
+--R       \|- 4d f + e  \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 556
+--a0:=integrate(t0,x)
+--E 423
+
+--S 424 of 556
+--m0:=a0-r0
+--E 424
+
+--S 425 of 556
+--d0:=D(m0,x)
+--E 425
+
+)clear all
+
+--S 426 of 556
+t0:=(A+B*x)/((a+b*x+c*x^2)^2*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R        2   6              2   5             2               2   4
+--R       c f x  + (2b c f + c e)x  + ((2a c + b )f + 2b c e + c d)x
+--R     + 
+--R                          2             3     2                      2    2
+--R       (2a b f + (2a c + b )e + 2b c d)x  + (a f + 2a b e + (2a c + b )d)x
+--R     + 
+--R         2                2
+--R       (a e + 2a b d)x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 426
+
+--S 427 of 556
+r0:=(A*(b^2*c*e-2*a*c^2*e-b^3*f-b*c*(c*d-3*a*f))+a*B*(2*c^2*d+b^2*f-_
+   c*(b*e+2*a*f))-c*(A*b^2*f+2*c*(A*c*d+a*B*e-a*A*f)-b*(B*c*d+A*c*e+_
+   a*B*f))*x)/((b^2-4*a*c)*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))*(a+b*x+c*x^2))+2*c*(A*b^2*f+2*c*(A*c*d+a*B*e-a*A*f)-_
+   b*(B*c*d+A*c*e+a*B*f))*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)^(3/2)*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f))))+1/2*(A*(c*e-b*f)*(f*(b*e-2*a*f)-c*(e^2-2*d*f))-_
+   B*(2*c*d*f*(b*e-a*f)-f^2*(b^2*d-a^2*f)-c^2*d*(e^2-d*f)))*_
+   log(a+b*x+c*x^2)/(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))^2-1/2*(A*(c*e-b*f)*(f*(b*e-2*a*f)-c*(e^2-2*d*f))-_
+   B*(2*c*d*f*(b*e-a*f)-f^2*(b^2*d-a^2*f)-c^2*d*(e^2-d*f)))*_
+   log(d+e*x+f*x^2)/(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))^2+(B*(2*c^3*d^2*e-b*f^2*(b^2*d-a^2*f)-_
+   b*c^2*d*(e^2+3*d*f)+2*c*f*(b^2*d*e+a*b*d*f-a^2*e*f))+_
+   A*(b^2*f^2*(b*e-2*a*f)-2*c^3*d*(e^2-d*f)-2*c*f*(b^2*e^2-a*b*e*f-_
+   a^2*f^2)+c^2*(b*e^3+2*b*d*e*f-4*a*d*f^2)))*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))^2*sqrt(b^2-4*a*c))+(B*(c^2*d*e*(e^2-3*d*f)-_
+   2*c*d*f*(b*e^2-2*b*d*f-a*e*f)+f^2*(b^2*d*e-4*a*b*d*f+a^2*e*f))-_
+   A*(c^2*(e^4-4*d*e^2*f+2*d^2*f^2)-f^2*(2*a*b*e*f-2*a^2*f^2-_
+   b^2*(e^2-2*d*f))+2*c*f*(a*f*(e^2-2*d*f)-b*(e^3-3*d*e*f))))*_
+   atanh((e+2*f*x)/sqrt(e^2-4*d*f))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))^2*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R                       3 2       2 2   4
+--R               (- 16A a c  + 4A a b c)f
+--R             + 
+--R                          2        3  2            3       2 2
+--R                   ((16A a b + 8B a )c  + (- 4A a b  - 2B a b )c)e
+--R                 + 
+--R                         2 3          2        2   2          4         3
+--R                   (32A a c  + (8A a b  - 32B a b)c  + (- 4A b  + 8B a b )c)d
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                           2 3         2 2       4   2
+--R                   (- 16A a c  - 4A a b c  + 2A b c)e
+--R                 + 
+--R                                      2  3         3         2  2       4
+--R                   ((- 48A a b + 16B a )c  + (12A b  + 4B a b )c  - 2B b c)d e
+--R                 + 
+--R                             4        2            3       3 2  2
+--R                   (- 16A a c  + (4A b  + 32B a b)c  - 8B b c )d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                             3       3 2  3
+--R                   (16A a b c  - 4A b c )e
+--R                 + 
+--R                           4          2            3       3 2    2
+--R                   (32A a c  + (- 8A b  - 16B a b)c  + 4B b c )d e
+--R                 + 
+--R                             4       2 3  2
+--R                   (- 24B a c  + 6B b c )d e
+--R              *
+--R                 f
+--R             + 
+--R                        4       2 3  4          4       2 3    3
+--R               (- 8A a c  + 2A b c )e  + (8B a c  - 2B b c )d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       3          2 3  4
+--R               (- 16A a b c + 4A a b )f
+--R             + 
+--R                          2 2       3            4       2 3
+--R                   ((16A a b  + 8B a b)c - 4A a b  - 2B a b )e
+--R                 + 
+--R                         2   2          3        2 2         5         4
+--R                   (32A a b c  + (8A a b  - 32B a b )c - 4A b  + 8B a b )d
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                           2   2         3        5  2
+--R                   (- 16A a b c  - 4A a b c + 2A b )e
+--R                 + 
+--R                              2        2   2         4         3         5
+--R                   ((- 48A a b  + 16B a b)c  + (12A b  + 4B a b )c - 2B b )d e
+--R                 + 
+--R                               3        3          2  2       4   2
+--R                   (- 16A a b c  + (4A b  + 32B a b )c  - 8B b c)d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                           2 2       4   3
+--R                   (16A a b c  - 4A b c)e
+--R                 + 
+--R                             3          3          2  2       4     2
+--R                   (32A a b c  + (- 8A b  - 16B a b )c  + 4B b c)d e
+--R                 + 
+--R                               3       3 2  2
+--R                   (- 24B a b c  + 6B b c )d e
+--R              *
+--R                 f
+--R             + 
+--R                          3       3 2  4            3       3 2    3
+--R               (- 8A a b c  + 2A b c )e  + (8B a b c  - 2B b c )d e
+--R          *
+--R             x
+--R         + 
+--R                   4        3 2  4
+--R           (- 16A a c + 4A a b )f
+--R         + 
+--R                      3        4         2 3       3 2
+--R               ((16A a b + 8B a )c - 4A a b  - 2B a b )e
+--R             + 
+--R                     3 2        2 2        3            4       2 3
+--R               (32A a c  + (8A a b  - 32B a b)c - 4A a b  + 8B a b )d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                       3 2       2 2          4  2
+--R               (- 16A a c  - 4A a b c + 2A a b )e
+--R             + 
+--R                        2         3  2           3       2 2           4
+--R               ((- 48A a b + 16B a )c  + (12A a b  + 4B a b )c - 2B a b )d e
+--R             + 
+--R                       2 3          2        2   2         3   2
+--R               (- 16A a c  + (4A a b  + 32B a b)c  - 8B a b c)d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                     2   2         3   3
+--R               (16A a b c  - 4A a b c)e
+--R             + 
+--R                     2 3            2        2   2         3     2
+--R               (32A a c  + (- 8A a b  - 16B a b)c  + 4B a b c)d e
+--R             + 
+--R                       2 3         2 2  2
+--R               (- 24B a c  + 6B a b c )d e
+--R          *
+--R             f
+--R         + 
+--R                  2 3         2 2  4        2 3         2 2    3
+--R           (- 8A a c  + 2A a b c )e  + (8B a c  - 2B a b c )d e
+--R      *
+--R          +-----------+
+--R          |          2          2f x + e
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4d f + e
+--R     + 
+--R                     3 3           2 2        3   2          4       2 3    3
+--R               (24A a c  + (- 24A a b  + 12B a b)c  + (4A a b  - 2B a b )c)f
+--R             + 
+--R                          2         3  3         3 2       5
+--R                   ((12A a b - 24B a )c  + 8A a b c  - 2A b c)e
+--R                 + 
+--R                              2 4           2        2   3
+--R                       - 56A a c  + (24A a b  + 12B a b)c
+--R                     + 
+--R                              4         3  2       5
+--R                       (- 4A b  - 8B a b )c  + 2B b c
+--R                  *
+--R                     d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                        2 4             2        2   3       4 2  2
+--R                   (8A a c  + (- 24A a b  + 12B a b)c  + 4A b c )e
+--R                 + 
+--R                                   2  4       3 3       4 2
+--R                   ((8A a b + 16B a )c  + 4A b c  - 4B b c )d e
+--R                 + 
+--R                           5           2            4        3 3  2
+--R                   (40A a c  + (- 16A b  - 28B a b)c  + 10B b c )d
+--R              *
+--R                 f
+--R             + 
+--R                               2  4       3 3  3
+--R               ((12A a b - 8B a )c  - 2A b c )e
+--R             + 
+--R                         5           4       3 3    2
+--R               (- 24A a c  + 4B a b c  + 2B b c )d e
+--R             + 
+--R                               5       2 4  2           6         5  3
+--R               ((12A b + 8B a)c  - 8B b c )d e + (- 8A c  + 4B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     3   2           2 3        3 2           5       2 4  3
+--R               (24A a b c  + (- 24A a b  + 12B a b )c + 4A a b  - 2B a b )f
+--R             + 
+--R                          2 2        3   2         4        6
+--R                   ((12A a b  - 24B a b)c  + 8A a b c - 2A b )e
+--R                 + 
+--R                              2   3           3        2 2  2
+--R                       - 56A a b c  + (24A a b  + 12B a b )c
+--R                     + 
+--R                              5         4         6
+--R                       (- 4A b  - 8B a b )c + 2B b
+--R                  *
+--R                     d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                        2   3             3        2 2  2       5   2
+--R                   (8A a b c  + (- 24A a b  + 12B a b )c  + 4A b c)e
+--R                 + 
+--R                           2        2   3       4 2       5
+--R                   ((8A a b  + 16B a b)c  + 4A b c  - 4B b c)d e
+--R                 + 
+--R                             4           3          2  3        4 2  2
+--R                   (40A a b c  + (- 16A b  - 28B a b )c  + 10B b c )d
+--R              *
+--R                 f
+--R             + 
+--R                        2       2   3       4 2  3
+--R               ((12A a b  - 8B a b)c  - 2A b c )e
+--R             + 
+--R                           4         2 3       4 2    2
+--R               (- 24A a b c  + 4B a b c  + 2B b c )d e
+--R             + 
+--R                      2           4       3 3  2             5       2 4  3
+--R               ((12A b  + 8B a b)c  - 8B b c )d e + (- 8A b c  + 4B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 4 2           3 2        4          2 4       3 3  3
+--R           (24A a c  + (- 24A a b  + 12B a b)c + 4A a b  - 2B a b )f
+--R         + 
+--R                      3         4  2       2 3          5
+--R               ((12A a b - 24B a )c  + 8A a b c - 2A a b )e
+--R             + 
+--R                          3 3         2 2        3   2            4       2 3
+--R                   - 56A a c  + (24A a b  + 12B a b)c  + (- 4A a b  - 8B a b )c
+--R                 + 
+--R                         5
+--R                   2B a b
+--R              *
+--R                 d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                    3 3           2 2        3   2         4   2
+--R               (8A a c  + (- 24A a b  + 12B a b)c  + 4A a b c)e
+--R             + 
+--R                     2         3  3         3 2         4
+--R               ((8A a b + 16B a )c  + 4A a b c  - 4B a b c)d e
+--R             + 
+--R                     2 4             2        2   3          3 2  2
+--R               (40A a c  + (- 16A a b  - 28B a b)c  + 10B a b c )d
+--R          *
+--R             f
+--R         + 
+--R                  2        3  3         3 2  3
+--R           ((12A a b - 8B a )c  - 2A a b c )e
+--R         + 
+--R                   2 4       2   3         3 2    2
+--R           (- 24A a c  + 4B a b c  + 2B a b c )d e
+--R         + 
+--R                           2  4         2 3  2             5           4  3
+--R           ((12A a b + 8B a )c  - 8B a b c )d e + (- 8A a c  + 4B a b c )d
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4d f + e  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                           2        3  2          3      2 2    3
+--R                   ((- 8A a b + 4B a )c  + (2A a b  - B a b )c)f
+--R                 + 
+--R                            2 3         2 2      4
+--R                       (8A a c  + 2A a b c  - A b c)e
+--R                     + 
+--R                                      2  3          3         2  2      4
+--R                       ((8A a b - 8B a )c  + (- 2A b  - 2B a b )c  + B b c)d
+--R                  *
+--R                      2
+--R                     f
+--R                 + 
+--R                                  3       3 2  2
+--R                       (- 8A a b c  + 2A b c )e
+--R                     + 
+--R                                4        2           3       3 2
+--R                       (- 8A a c  + (2A b  + 8B a b)c  - 2B b c )d e
+--R                     + 
+--R                              4      2 3  2
+--R                       (4B a c  - B b c )d
+--R                  *
+--R                     f
+--R                 + 
+--R                          4      2 3  3            4      2 3    2
+--R                   (4A a c  - A b c )e  + (- 4B a c  + B b c )d e
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           2 2       3            4      2 3  3
+--R                   ((- 8A a b  + 4B a b)c + 2A a b  - B a b )f
+--R                 + 
+--R                            2   2         3       5
+--R                       (8A a b c  + 2A a b c - A b )e
+--R                     + 
+--R                               2       2   2          4         3        5
+--R                       ((8A a b  - 8B a b)c  + (- 2A b  - 2B a b )c + B b )d
+--R                  *
+--R                      2
+--R                     f
+--R                 + 
+--R                                2 2       4   2
+--R                       (- 8A a b c  + 2A b c)e
+--R                     + 
+--R                                  3        3         2  2       4
+--R                       (- 8A a b c  + (2A b  + 8B a b )c  - 2B b c)d e
+--R                     + 
+--R                                3      3 2  2
+--R                       (4B a b c  - B b c )d
+--R                  *
+--R                     f
+--R                 + 
+--R                            3      3 2  3              3      3 2    2
+--R                   (4A a b c  - A b c )e  + (- 4B a b c  + B b c )d e
+--R              *
+--R                 x
+--R             + 
+--R                       3        4         2 3      3 2  3
+--R               ((- 8A a b + 4B a )c + 2A a b  - B a b )f
+--R             + 
+--R                        3 2       2 2         4
+--R                   (8A a c  + 2A a b c - A a b )e
+--R                 + 
+--R                         2        3  2            3       2 2          4
+--R                   ((8A a b - 8B a )c  + (- 2A a b  - 2B a b )c + B a b )d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                          2   2         3   2
+--R                   (- 8A a b c  + 2A a b c)e
+--R                 + 
+--R                          2 3          2       2   2         3
+--R                   (- 8A a c  + (2A a b  + 8B a b)c  - 2B a b c)d e
+--R                 + 
+--R                        2 3        2 2  2
+--R                   (4B a c  - B a b c )d
+--R              *
+--R                 f
+--R             + 
+--R                    2 3        2 2  3          2 3        2 2    2
+--R               (4A a c  - A a b c )e  + (- 4B a c  + B a b c )d e
+--R          *
+--R                    2
+--R             log(f x  + e x + d)
+--R         + 
+--R                         2        3  2            3      2 2    3
+--R                   ((8A a b - 4B a )c  + (- 2A a b  + B a b )c)f
+--R                 + 
+--R                              2 3         2 2      4
+--R                       (- 8A a c  - 2A a b c  + A b c)e
+--R                     + 
+--R                                        2  3        3         2  2      4
+--R                       ((- 8A a b + 8B a )c  + (2A b  + 2B a b )c  - B b c)d
+--R                  *
+--R                      2
+--R                     f
+--R                 + 
+--R                                3       3 2  2
+--R                       (8A a b c  - 2A b c )e
+--R                     + 
+--R                              4          2           3       3 2
+--R                       (8A a c  + (- 2A b  - 8B a b)c  + 2B b c )d e
+--R                     + 
+--R                                4      2 3  2
+--R                       (- 4B a c  + B b c )d
+--R                  *
+--R                     f
+--R                 + 
+--R                            4      2 3  3          4      2 3    2
+--R                   (- 4A a c  + A b c )e  + (4B a c  - B b c )d e
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         2 2       3            4      2 3  3
+--R                   ((8A a b  - 4B a b)c - 2A a b  + B a b )f
+--R                 + 
+--R                              2   2         3       5
+--R                       (- 8A a b c  - 2A a b c + A b )e
+--R                     + 
+--R                                 2       2   2        4         3        5
+--R                       ((- 8A a b  + 8B a b)c  + (2A b  + 2B a b )c - B b )d
+--R                  *
+--R                      2
+--R                     f
+--R                 + 
+--R                              2 2       4   2
+--R                       (8A a b c  - 2A b c)e
+--R                     + 
+--R                                3          3         2  2       4
+--R                       (8A a b c  + (- 2A b  - 8B a b )c  + 2B b c)d e
+--R                     + 
+--R                                  3      3 2  2
+--R                       (- 4B a b c  + B b c )d
+--R                  *
+--R                     f
+--R                 + 
+--R                              3      3 2  3            3      3 2    2
+--R                   (- 4A a b c  + A b c )e  + (4B a b c  - B b c )d e
+--R              *
+--R                 x
+--R             + 
+--R                     3        4         2 3      3 2  3
+--R               ((8A a b - 4B a )c - 2A a b  + B a b )f
+--R             + 
+--R                          3 2       2 2         4
+--R                   (- 8A a c  - 2A a b c + A a b )e
+--R                 + 
+--R                           2        3  2          3       2 2          4
+--R                   ((- 8A a b + 8B a )c  + (2A a b  + 2B a b )c - B a b )d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                        2   2         3   2
+--R                   (8A a b c  - 2A a b c)e
+--R                 + 
+--R                        2 3            2       2   2         3
+--R                   (8A a c  + (- 2A a b  - 8B a b)c  + 2B a b c)d e
+--R                 + 
+--R                          2 3        2 2  2
+--R                   (- 4B a c  + B a b c )d
+--R              *
+--R                 f
+--R             + 
+--R                      2 3        2 2  3        2 3        2 2    2
+--R               (- 4A a c  + A a b c )e  + (4B a c  - B a b c )d e
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                      3 2        2 2       3     3
+--R               (- 4A a c  + (2A a b  - 2B a b)c)f
+--R             + 
+--R                         2        3  2            3       2 2
+--R                   ((2A a b + 4B a )c  + (- 2A a b  + 2B a b )c)e
+--R                 + 
+--R                         2 3            2       2   2        4         3
+--R                   (12A a c  + (- 8A a b  + 2B a b)c  + (2A b  - 2B a b )c)d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                          2 3          2       2   2  2
+--R                   (- 4A a c  + (4A a b  - 6B a b)c )e
+--R                 + 
+--R                                  2  3          3         2  2
+--R                   ((4A a b - 8B a )c  + (- 4A b  + 8B a b )c )d e
+--R                 + 
+--R                             4        2           3       3 2  2
+--R                   (- 12A a c  + (6A b  + 2B a b)c  - 2B b c )d
+--R              *
+--R                 f
+--R             + 
+--R                               2  3 3          4        2           3    2
+--R               (- 2A a b + 4B a )c e  + (4A a c  + (2A b  - 6B a b)c )d e
+--R             + 
+--R                                4       2 3  2         5         4  3
+--R               ((- 6A b + 4B a)c  + 2B b c )d e + (4A c  - 2B b c )d
+--R          *
+--R             x
+--R         + 
+--R                   3        4         2 3       3 2  3
+--R           ((- 6A a b + 4B a )c + 2A a b  - 2B a b )f
+--R         + 
+--R                    3 2        2 2       3            4       2 3
+--R               (4A a c  + (4A a b  - 2B a b)c - 2A a b  + 2B a b )e
+--R             + 
+--R                    2         3  2             3       2 2         5         4
+--R             ((14A a b - 12B a )c  + (- 10A a b  + 8B a b )c + 2A b  - 2B a b )d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                        2        3  2          3       2 2    2
+--R               ((- 10A a b + 4B a )c  + (4A a b  - 4B a b )c)e
+--R             + 
+--R                      2 3           2       2   2          4         3
+--R               (- 8A a c  + (12A a b  - 4B a b)c  + (- 4A b  + 4B a b )c)d e
+--R             + 
+--R                                  2  3        3         2  2  2
+--R               ((- 10A a b + 12B a )c  + (4A b  - 6B a b )c )d
+--R          *
+--R             f
+--R         + 
+--R                2 3            2       2   2  3
+--R           (4A a c  + (- 2A a b  + 2B a b)c )e
+--R         + 
+--R                            2  3        3         2  2    2
+--R           ((- 2A a b - 4B a )c  + (2A b  - 2B a b )c )d e
+--R         + 
+--R                  4          2           3  2                  4 3
+--R           (4A a c  + (- 4A b  + 6B a b)c )d e + (2A b - 4B a)c d
+--R      *
+--R          +-----------+ +-----------+
+--R          |          2  |          2
+--R         \|- 4d f + e  \|- 4a c + b
+--R  /
+--R                5 2     4 2   4
+--R             (8a c  - 2a b c)f
+--R           + 
+--R                    4   2     3 3            4 3      3 2 2     2 4     3
+--R             ((- 16a b c  + 4a b c)e + (- 32a c  + 24a b c  - 4a b c)d)f
+--R           + 
+--R                     4 3     3 2 2     2 4   2
+--R                 (16a c  + 4a b c  - 2a b c)e
+--R               + 
+--R                     3   3      2 3 2       5
+--R                 (16a b c  - 20a b c  + 4a b c)d e
+--R               + 
+--R                     3 4      2 2 3        4 2     6   2
+--R                 (48a c  - 44a b c  + 16a b c  - 2b c)d
+--R            *
+--R                2
+--R               f
+--R           + 
+--R                       3   3     2 3 2  3         3 4      2 2 3       4 2    2
+--R                 (- 16a b c  + 4a b c )e  + (- 32a c  + 40a b c  - 8a b c )d e
+--R               + 
+--R                     2   4        3 3     5 2  2
+--R                 (16a b c  - 20a b c  + 4b c )d e
+--R               + 
+--R                       2 5        2 4     4 3  3
+--R                 (- 32a c  + 24a b c  - 4b c )d
+--R            *
+--R               f
+--R           + 
+--R                3 4     2 2 3  4         2   4       3 3    3
+--R             (8a c  - 2a b c )e  + (- 16a b c  + 4a b c )d e
+--R           + 
+--R                 2 5       2 4     4 3  2 2             5     3 4  3
+--R             (16a c  + 4a b c  - 2b c )d e  + (- 16a b c  + 4b c )d e
+--R           + 
+--R                  6     2 5  4
+--R             (8a c  - 2b c )d
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                5        4 3  4
+--R             (8a b c - 2a b )f
+--R           + 
+--R                    4 2      3 4           4   2      3 3      2 5    3
+--R             ((- 16a b c + 4a b )e + (- 32a b c  + 24a b c - 4a b )d)f
+--R           + 
+--R                     4   2     3 3      2 5  2       3 2 2      2 4        6
+--R                 (16a b c  + 4a b c - 2a b )e  + (16a b c  - 20a b c + 4a b )d e
+--R               + 
+--R                     3   3      2 3 2        5      7  2
+--R                 (48a b c  - 44a b c  + 16a b c - 2b )d
+--R            *
+--R                2
+--R               f
+--R           + 
+--R                       3 2 2     2 4   3         3   3      2 3 2       5     2
+--R                 (- 16a b c  + 4a b c)e  + (- 32a b c  + 40a b c  - 8a b c)d e
+--R               + 
+--R                     2 2 3        4 2     6   2
+--R                 (16a b c  - 20a b c  + 4b c)d e
+--R               + 
+--R                       2   4        3 3     5 2  3
+--R                 (- 32a b c  + 24a b c  - 4b c )d
+--R            *
+--R               f
+--R           + 
+--R                3   3     2 3 2  4         2 2 3       4 2    3
+--R             (8a b c  - 2a b c )e  + (- 16a b c  + 4a b c )d e
+--R           + 
+--R                 2   4       3 3     5 2  2 2           2 4     4 3  3
+--R             (16a b c  + 4a b c  - 2b c )d e  + (- 16a b c  + 4b c )d e
+--R           + 
+--R                    5     3 4  4
+--R             (8a b c  - 2b c )d
+--R        *
+--R           x
+--R       + 
+--R            6      5 2  4
+--R         (8a c - 2a b )f
+--R       + 
+--R                5        4 3           5 2      4 2      3 4    3
+--R         ((- 16a b c + 4a b )e + (- 32a c  + 24a b c - 4a b )d)f
+--R       + 
+--R                 5 2     4 2      3 4  2       4   2      3 3      2 5
+--R             (16a c  + 4a b c - 2a b )e  + (16a b c  - 20a b c + 4a b )d e
+--R           + 
+--R                 4 3      3 2 2      2 4        6  2
+--R             (48a c  - 44a b c  + 16a b c - 2a b )d
+--R        *
+--R            2
+--R           f
+--R       + 
+--R                   4   2     3 3   3         4 3      3 2 2     2 4     2
+--R             (- 16a b c  + 4a b c)e  + (- 32a c  + 40a b c  - 8a b c)d e
+--R           + 
+--R               3   3      2 3 2       5   2          3 4      2 2 3       4 2  3
+--R           (16a b c  - 20a b c  + 4a b c)d e + (- 32a c  + 24a b c  - 4a b c )d
+--R        *
+--R           f
+--R       + 
+--R            4 3     3 2 2  4         3   3     2 3 2    3
+--R         (8a c  - 2a b c )e  + (- 16a b c  + 4a b c )d e
+--R       + 
+--R             3 4     2 2 3       4 2  2 2         2   4       3 3  3
+--R         (16a c  + 4a b c  - 2a b c )d e  + (- 16a b c  + 4a b c )d e
+--R       + 
+--R            2 5       2 4  4
+--R         (8a c  - 2a b c )d
+--R    *
+--R        +-----------+ +-----------+
+--R        |          2  |          2
+--R       \|- 4d f + e  \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 556
+--a0:=integrate(t0,x)
+--E 428
+
+--S 429 of 556
+--m0:=a0-r0
+--E 429
+
+--S 430 of 556
+--d0:=D(m0,x)
+--E 430
+
+)clear all
+
+--S 431 of 556
+t0:=(A+B*x)*(a+b*x+c*x^2)^(1/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R                  +--------------+
+--R                  |   2
+--R        (B x + A)\|c x  + b x + a
+--R   (1)  --------------------------
+--R                 2
+--R              f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 556
+r0:=-1/2*(2*B*c*e-b*B*f-2*A*c*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/(f^2*sqrt(c))+B*sqrt(a+b*x+c*x^2)/f+_
+   atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-_
+   b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*_
+   (2*f*(A*f*(c*d-a*f)-B*d*(c*e-b*f))-(A*f*(c*e-b*f)+B*(f*(b*e-a*f)-_
+   c*(e^2-d*f)))*(e-sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*_
+   (e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*f*(A*f*(c*d-a*f)-_
+   B*d*(c*e-b*f))-(A*f*(c*e-b*f)+B*(f*(b*e-a*f)-c*(e^2-d*f)))*_
+   (e+sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                            2                                        2
+--R             ((2A b + 2B a)f  + ((- 2A c - 2B b)e - 2B c d)f + 2B c e )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                   3                                     2
+--R           - 4A a f  + ((2A b + 2B a)e + (4A c + 4B b)d)f
+--R         + 
+--R                            2                      3
+--R           ((- 2A c - 2B b)e  - 6B c d e)f + 2B c e
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|c \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                              2                                      2
+--R             ((- 2A b - 2B a)f  + ((2A c + 2B b)e + 2B c d)f - 2B c e )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                   3                                     2
+--R           - 4A a f  + ((2A b + 2B a)e + (4A c + 4B b)d)f
+--R         + 
+--R                            2                      3
+--R           ((- 2A c - 2B b)e  - 6B c d e)f + 2B c e
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|c \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                          +-----------+
+--R                                      +-+ |          2
+--R             ((2A c + B b)f - 2B c e)\|2 \|- 4d f + e
+--R          *
+--R                          2c x + b
+--R             atanh(----------------------)
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|c \|c x  + b x + a
+--R         + 
+--R                    +-----------+     +--------------+
+--R                +-+ |          2  +-+ |   2
+--R           2B f\|2 \|- 4d f + e  \|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R               +-----------+
+--R         2 +-+ |          2  +-+
+--R       2f \|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 556
+--a0:=integrate(t0,x)
+--E 433
+
+--S 434 of 556
+--m0:=a0-r0
+--E 434
+
+--S 435 of 556
+--d0:=D(m0,x)
+--E 435
+
+)clear all
+
+--S 436 of 556
+t0:=(A+B*x)*(a+b*x+c*x^2)^(3/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R                                                      +--------------+
+--R              3               2                       |   2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x + A a)\|c x  + b x + a
+--R   (1)  --------------------------------------------------------------
+--R                                   2
+--R                                f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 556
+r0:=1/3*B*(a+b*x+c*x^2)^(3/2)/f+1/16*(b^2-4*a*c)*(2*B*c*e-b*B*f-2*A*c*f)*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f^2)+_
+   1/2*(A*f*(b^2*f^2-c*f*(3*b*e-2*a*f)+2*c^2*(e^2-d*f))-B*(b*f^2*_
+   (b*e-a*f)-c*f*(3*b*e^2-3*b*d*f-2*a*e*f)+2*c^2*(e^3-2*d*e*f)))*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f^4*sqrt(c))-_
+   (A*f*(c*e-b*f)-B*(c*e^2-c*d*f-b*e*f+a*f^2))*sqrt(a+b*x+c*x^2)/f^3-_
+   1/8*(2*B*c*e-b*B*f-2*A*c*f)*(b+2*c*x)*sqrt(a+b*x+c*x^2)/(c*f^2)+_
+   atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-_
+   sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*f*(B*d*(c*e-b*f)*_
+   (f*(b*e-2*a*f)-c*(e^2-2*d*f))-A*f*(2*c*d*f*(b*e-a*f)-f^2*(b^2*d-_
+   a^2*f)-c^2*d*(e^2-d*f)))+(f*(c*e-b*f)*(A*f*(c*d-a*f)-B*d*(c*e-b*f))+_
+   (f*(b*e-a*f)-c*(e^2-d*f))*(A*f*(c*e-b*f)+B*(f*(b*e-a*f)-c*(e^2-d*f))))*_
+   (e-sqrt(e^2-4*d*f)))/(f^4*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-atanh(1/2*(4*a*f-b*_
+   (e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(2*f*(B*d*(c*e-b*f)*(f*(b*e-2*a*f)-c*(e^2-2*d*f))-_
+   A*f*(2*c*d*f*(b*e-a*f)-f^2*(b^2*d-a^2*f)-c^2*d*(e^2-d*f)))+_
+   (f*(c*e-b*f)*(A*f*(c*d-a*f)-B*d*(c*e-b*f))+(f*(b*e-a*f)-c*(e^2-d*f))*_
+   (A*f*(c*e-b*f)+B*(f*(b*e-a*f)-c*(e^2-d*f))))*(e+sqrt(e^2-4*d*f)))/_
+   (f^4*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                               2    4
+--R               (96A a b + 48B a )c f
+--R             + 
+--R                             2           2
+--R                   (- 96A a c  + (- 48A b  - 96B a b)c)e
+--R                 + 
+--R                                      2        2
+--R                   ((- 96A b - 96B a)c  - 48B b c)d
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                                    2        2   2         3           2
+--R                   ((96A b + 96B a)c  + 48B b c)e  + (96A c  + 192B b c )d e
+--R                 + 
+--R                        3 2
+--R                   48B c d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                        3          2  3         3   2          3 4
+--R               ((- 48A c  - 96B b c )e  - 144B c d e )f + 48B c e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2   5
+--R           - 96A a c f
+--R         + 
+--R                            2                2         2                 4
+--R           ((96A a b + 48B a )c e + (192A a c  + (96A b  + 192B a b)c)d)f
+--R         + 
+--R                         2           2              2
+--R               (- 96A a c  + (- 48A b  - 96B a b)c)e
+--R             + 
+--R                                    2         2                3           2  2
+--R               ((- 288A b - 288B a)c  - 144B b c)d e + (- 96A c  - 192B b c )d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                                2        2   3          3           2    2
+--R               ((96A b + 96B a)c  + 48B b c)e  + (192A c  + 384B b c )d e
+--R             + 
+--R                     3 2
+--R               240B c d e
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                    3          2  4         3   3          3 5
+--R           ((- 48A c  - 96B b c )e  - 240B c d e )f + 48B c e
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|c \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                 2    4
+--R               (- 96A a b - 48B a )c f
+--R             + 
+--R                           2         2
+--R                   (96A a c  + (48A b  + 96B a b)c)e
+--R                 + 
+--R                                    2        2
+--R                   ((96A b + 96B a)c  + 48B b c)d
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                                      2        2   2           3           2
+--R                   ((- 96A b - 96B a)c  - 48B b c)e  + (- 96A c  - 192B b c )d e
+--R                 + 
+--R                          3 2
+--R                   - 48B c d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                      3          2  3         3   2          3 4
+--R               ((48A c  + 96B b c )e  + 144B c d e )f - 48B c e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2   5
+--R           - 96A a c f
+--R         + 
+--R                            2                2         2                 4
+--R           ((96A a b + 48B a )c e + (192A a c  + (96A b  + 192B a b)c)d)f
+--R         + 
+--R                         2           2              2
+--R               (- 96A a c  + (- 48A b  - 96B a b)c)e
+--R             + 
+--R                                    2         2                3           2  2
+--R               ((- 288A b - 288B a)c  - 144B b c)d e + (- 96A c  - 192B b c )d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                                2        2   3          3           2    2
+--R               ((96A b + 96B a)c  + 48B b c)e  + (192A c  + 384B b c )d e
+--R             + 
+--R                     3 2
+--R               240B c d e
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                    3          2  4         3   3          3 5
+--R           ((- 48A c  - 96B b c )e  - 240B c d e )f + 48B c e
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|c \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                       2         2                   3  3
+--R               (72A a c  + (18A b  + 36B a b)c - 3B b )f
+--R             + 
+--R                                   2        2              3          2    2
+--R               (((- 72A b - 72B a)c  - 18B b c)e + (- 48A c  - 72B b c )d)f
+--R             + 
+--R                      3          2  2        3             3 3
+--R               ((48A c  + 72B b c )e  + 96B c d e)f - 48B c e
+--R          *
+--R                  +-----------+
+--R              +-+ |          2              2c x + b
+--R             \|2 \|- 4d f + e  atanh(----------------------)
+--R                                           +--------------+
+--R                                       +-+ |   2
+--R                                     2\|c \|c x  + b x + a
+--R         + 
+--R                    2 3 2          2            3        2   2
+--R               16B c f x  + ((24A c  + 28B b c)f  - 24B c e f )x
+--R             + 
+--R                                       2  3
+--R               ((60A b + 64B a)c + 6B b )f
+--R             + 
+--R                        2                    2   2        2 2
+--R               ((- 48A c  - 60B b c)e - 48B c d)f  + 48B c e f
+--R          *
+--R                  +-----------+     +--------------+
+--R              +-+ |          2  +-+ |   2
+--R             \|2 \|- 4d f + e  \|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                  +-----------+
+--R            4 +-+ |          2  +-+
+--R       48c f \|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 556
+--a0:=integrate(t0,x)
+--E 438
+
+--S 439 of 556
+--m0:=a0-r0
+--E 439
+
+--S 440 of 556
+--d0:=D(m0,x)
+--E 440
+
+)clear all
+
+--S 441 of 556
+t0:=(A+B*x)/((a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                     B x + A
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 556
+r0:=-atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-_
+   b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*A*f-B*_
+   (e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))+atanh(1/2*(4*a*f-b*(e+_
+   sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(2*A*f-B*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R            +-----------+
+--R            |          2
+--R         (B\|- 4d f + e   - 2A f + B e)
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R              +-----------+
+--R              |          2
+--R         (- B\|- 4d f + e   - 2A f + B e)
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            +-----------+
+--R        +-+ |          2
+--R       \|2 \|- 4d f + e
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 556
+--a0:=integrate(t0,x)
+--E 443
+
+--S 444 of 556
+--m0:=a0-r0
+--E 444
+
+--S 445 of 556
+--d0:=D(m0,x)
+--E 445
+
+)clear all
+
+--S 446 of 556
+t0:=(A+B*x)/((a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R             4               3                     2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 556
+r0:=2*(A*(b^2*c*e-2*a*c^2*e-b^3*f-b*c*(c*d-3*a*f))+a*B*(2*c^2*d+b^2*f-_
+   c*(b*e+2*a*f))-c*(A*b^2*f+2*c*(A*c*d+a*B*e-a*A*f)-b*(B*c*d+A*c*e+_
+   a*B*f))*x)/((b^2-4*a*c)*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))*sqrt(a+b*x+c*x^2))-f*atanh(1/2*(4*a*f+2*x*(b*f-_
+   c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(-2*(B*(c*d*e-b*d*f)+A*(f*(b*e-a*f)-c*(e^2-d*f)))+_
+   (B*c*d-A*c*e+A*b*f-a*B*f)*(e-sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-_
+   a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))+_
+   f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+_
+   sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(-2*(B*(c*d*e-b*d*f)+_
+   A*(f*(b*e-a*f)-c*(e^2-d*f)))+(B*c*d-A*c*e+A*b*f-a*B*f)*(e+_
+   sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                2        3        2  2
+--R               ((- 4A a b + 4B a )c + A b  - B a b )f
+--R             + 
+--R                       2      2               2      2
+--R               ((4A a c  - A b c)e + (- 4B a c  + B b c)d)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2          2  3
+--R           (- 8A a c + 2A a b )f
+--R         + 
+--R                              2        3        2
+--R               ((4A a b + 4B a )c - A b  - B a b )e
+--R             + 
+--R                      2          2                  3
+--R               (8A a c  + (- 2A b  - 8B a b)c + 2B b )d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                     2      2   2          2      2
+--R           ((- 4A a c  + A b c)e  + (4B a c  - B b c)d e)f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                              2        3        2  2
+--R               ((4A a b - 4B a )c - A b  + B a b )f
+--R             + 
+--R                         2      2             2      2
+--R               ((- 4A a c  + A b c)e + (4B a c  - B b c)d)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2          2  3
+--R           (- 8A a c + 2A a b )f
+--R         + 
+--R                              2        3        2
+--R               ((4A a b + 4B a )c - A b  - B a b )e
+--R             + 
+--R                      2          2                  3
+--R               (8A a c  + (- 2A b  - 8B a b)c + 2B b )d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                     2      2   2          2      2
+--R           ((- 4A a c  + A b c)e  + (4B a c  - B b c)d e)f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                        2        2                                2
+--R               (- 4A a c  + (2A b  - 2B a b)c)f + (- 2A b + 4B a)c e
+--R             + 
+--R                    3         2
+--R               (4A c  - 2B b c )d
+--R          *
+--R             x
+--R         + 
+--R                            2         3         2
+--R           ((- 6A a b + 4B a )c + 2A b  - 2B a b )f
+--R         + 
+--R                  2          2                              2
+--R           (4A a c  + (- 2A b  + 2B a b)c)e + (2A b - 4B a)c d
+--R      *
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            3     2 2  2         2         3          2 2       2     4
+--R         (4a c - a b )f  + ((- 4a b c + a b )e + (- 8a c  + 6a b c - b )d)f
+--R       + 
+--R            2 2      2   2            2    3             3    2 2  2
+--R         (4a c  - a b c)e  + (- 4a b c  + b c)d e + (4a c  - b c )d
+--R    *
+--R            +-----------+ +--------------+
+--R        +-+ |          2  |   2
+--R       \|2 \|- 4d f + e  \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 556
+--a0:=integrate(t0,x)
+--E 448
+
+--S 449 of 556
+--m0:=a0-r0
+--E 449
+
+--S 450 of 556
+--d0:=D(m0,x)
+--E 450
+
+)clear all
+
+--S 451 of 556
+t0:=x^2*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)
+--R 
+--R
+--R           +------------------+ +--------+
+--R         2 | 2 2             2  |   2
+--R   (1)  x \|b x  + 2a b x + a  \|d x  + c
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 556
+r0:=-1/30*b*c*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(d^2*(a+b*x))+_
+   1/5*b*x^2*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(d*(a+b*x))-_
+   1/20*(2*b*c-5*a*d*x)*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   (d^2*(a+b*x))-1/8*a*c^2*atanh(x*sqrt(d)/sqrt(c+d*x^2))*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(d^(3/2)*(a+b*x))-1/8*a*c*x*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/(d*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                 +------------------+           +-+
+--R              2  | 2 2             2          x\|d
+--R       - 15a c d\|b x  + 2a b x + a  atanh(-----------)
+--R                                            +--------+
+--R                                            |   2
+--R                                           \|d x  + c
+--R     + 
+--R               2 4        2 3           2                    2  +-+
+--R         (24b d x  + 30a d x  + 8b c d x  + 15a c d x - 16b c )\|d
+--R      *
+--R          +------------------+ +--------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R            2          2  +-+
+--R     (120b d x + 120a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                      +--------+
+--R                   2 2 4         3   2         4  +-+ |   2             3 2 4
+--R             (15a c d x  + 180a c d x  + 240a c )\|c \|d x  + c  - 75a c d x
+--R           + 
+--R                     4   2         5
+--R             - 300a c d x  - 240a c
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|c \|d  + d x)\|d x  + c  + (- d x  - c)\|d  - d x\|c
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|c \|d x  + c  - c
+--R       + 
+--R                       3 8           3 7         2 2 6         2 2 5
+--R             - 120b c d x  - 150a c d x  - 520b c d x  - 675a c d x
+--R           + 
+--R                     3   4         3   3         4
+--R             - 480b c d x  - 780a c d x  - 240a c x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|d \|d x  + c
+--R       + 
+--R                  4 10        4 9           3 8           3 7         2 2 6
+--R             24b d x   + 30a d x  + 320b c d x  + 405a c d x  + 760b c d x
+--R           + 
+--R                    2 2 5         3   4         3   3         4
+--R             1035a c d x  + 480b c d x  + 900a c d x  + 240a c x
+--R        *
+--R            +-+ +-+
+--R           \|c \|d
+--R    /
+--R                                                  +--------+
+--R              3 4          2 2        2   +-+ +-+ |   2
+--R         (120d x  + 1440c d x  + 1920c d)\|c \|d \|d x  + c
+--R       + 
+--R                  3 4        2 2 2        3   +-+
+--R         (- 600c d x  - 2400c d x  - 1920c d)\|d
+--R     ,
+--R
+--R                                                        +--------+
+--R                     2 2 4         3   2         4  +-+ |   2              3 2 4
+--R             (- 30a c d x  - 360a c d x  - 480a c )\|c \|d x  + c  + 150a c d x
+--R           + 
+--R                   4   2         5
+--R             600a c d x  + 480a c
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- d \|d x  + c  - \|- d \|c
+--R           atan(------------------------------)
+--R                              d x
+--R       + 
+--R                       3 8           3 7         2 2 6         2 2 5
+--R             - 120b c d x  - 150a c d x  - 520b c d x  - 675a c d x
+--R           + 
+--R                     3   4         3   3         4
+--R             - 480b c d x  - 780a c d x  - 240a c x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- d \|d x  + c
+--R       + 
+--R                  4 10        4 9           3 8           3 7         2 2 6
+--R             24b d x   + 30a d x  + 320b c d x  + 405a c d x  + 760b c d x
+--R           + 
+--R                    2 2 5         3   4         3   3         4
+--R             1035a c d x  + 480b c d x  + 900a c d x  + 240a c x
+--R        *
+--R            +---+ +-+
+--R           \|- d \|c
+--R    /
+--R                                                    +--------+
+--R              3 4          2 2        2   +---+ +-+ |   2
+--R         (120d x  + 1440c d x  + 1920c d)\|- d \|c \|d x  + c
+--R       + 
+--R                  3 4        2 2 2        3   +---+
+--R         (- 600c d x  - 2400c d x  - 1920c d)\|- d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 453
+
+--S 454 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2 3 5      2 2 3 4           3 2 3       2 3 2 2
+--R               15a b c d x  + 15a c d x  + 180a b c d x  + 180a c d x
+--R             + 
+--R                       4          2 4
+--R               240a b c d x + 240a c d
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|d x  + c
+--R         + 
+--R                    3 3 5      2 3 3 4           4 2 3       2 4 2 2
+--R           - 75a b c d x  - 75a c d x  - 300a b c d x  - 300a c d x
+--R         + 
+--R                     5          2 5
+--R           - 240a b c d x - 240a c d
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|c \|d  + d x)\|d x  + c  + (- d x  - c)\|d  - d x\|c
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|c \|d x  + c  - c
+--R     + 
+--R                                                       +------------------+
+--R                   2 3 4         3 2 2         4   +-+ | 2 2             2
+--R             (15a c d x  + 180a c d x  + 240a c d)\|c \|b x  + 2a b x + a
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|d x  + c
+--R         + 
+--R                                                   +------------------+
+--R                   3 3 4         4 2 2         5   | 2 2             2
+--R           (- 75a c d x  - 300a c d x  - 240a c d)\|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                       4 8           4 7         2 3 6         2 3 5
+--R               120b c d x  + 150a c d x  + 520b c d x  + 675a c d x
+--R             + 
+--R                     3 2 4         3 2 3         4   2         4            5
+--R               464b c d x  + 780a c d x  - 192b c d x  + 240a c d x - 256b c
+--R          *
+--R                  +------------------+
+--R              +-+ | 2 2             2
+--R             \|d \|b x  + 2a b x + a
+--R         + 
+--R                     2   4 9             4 8          2   4       2 2 3  7
+--R               - 120b c d x  - 270a b c d x  + (- 150a c d  - 520b c d )x
+--R             + 
+--R                          2 3 6          2 2 3       2 3 2  5            3 2 4
+--R               - 1195a b c d x  + (- 675a c d  - 480b c d )x  - 1260a b c d x
+--R             + 
+--R                     2 3 2 3           4   2       2 4
+--R               - 780a c d x  - 240a b c d x  - 240a c d x
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                  5 10        5 9           4 8           4 7         2 3 6
+--R           - 24b d x   - 30a d x  - 320b c d x  - 405a c d x  - 760b c d x
+--R         + 
+--R                    2 3 5         3 2 4         3 2 3         4   2         4
+--R           - 1035a c d x  - 400b c d x  - 900a c d x  + 320b c d x  - 240a c d x
+--R         + 
+--R                 5
+--R           256b c
+--R      *
+--R                  +------------------+
+--R          +-+ +-+ | 2 2             2
+--R         \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R              2 5 11          5 10       2 5       2   4  9             4 8
+--R           24b d x   + 54a b d x   + (30a d  + 320b c d )x  + 725a b c d x
+--R         + 
+--R                2   4       2 2 3  7            2 3 6
+--R           (405a c d  + 760b c d )x  + 1795a b c d x
+--R         + 
+--R                 2 2 3       2 3 2  5            3 2 4       2 3 2 3
+--R           (1035a c d  + 480b c d )x  + 1380a b c d x  + 900a c d x
+--R         + 
+--R                   4   2       2 4
+--R           240a b c d x  + 240a c d x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R  /
+--R                 4 5         4 4            3 3            3 2          2 2
+--R           120b d x  + 120a d x  + 1440b c d x  + 1440a c d x  + 1920b c d x
+--R         + 
+--R                  2 2
+--R           1920a c d
+--R      *
+--R                  +--------+
+--R          +-+ +-+ |   2
+--R         \|c \|d \|d x  + c
+--R     + 
+--R                     4 5           4 4          2 3 3          2 3 2
+--R           - 600b c d x  - 600a c d x  - 2400b c d x  - 2400a c d x
+--R         + 
+--R                    3 2           3 2
+--R           - 1920b c d x - 1920a c d
+--R      *
+--R          +-+
+--R         \|d
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        7 17      7 16          6 15          6 14
+--R                   - b d x   - a d x   - 85b c d x   - 85a c d x
+--R                 + 
+--R                            2 5 13          2 5 12          3 4 11
+--R                   - 1204b c d x   - 1204a c d x   - 6496b c d x
+--R                 + 
+--R                            3 4 10           4 3 9           4 3 8
+--R                   - 6496a c d x   - 16896b c d x  - 16896a c d x
+--R                 + 
+--R                             5 2 7           5 2 6           6   5
+--R                   - 22784b c d x  - 22784a c d x  - 15360b c d x
+--R                 + 
+--R                             6   4          7 3          7 2
+--R                   - 15360a c d x  - 4096b c x  - 4096a c x
+--R              *
+--R                  +-+
+--R                 \|d
+--R             + 
+--R                          7 16        7 15           6 14           6 13
+--R                   - 13b d x   - 13a d x   - 364b c d x   - 364a c d x
+--R                 + 
+--R                            2 5 12          2 5 11          3 4 10
+--R                   - 2912b c d x   - 2912a c d x   - 9984b c d x
+--R                 + 
+--R                            3 4 9           4 3 8           4 3 7
+--R                   - 9984a c d x  - 16640b c d x  - 16640a c d x
+--R                 + 
+--R                           5 2 6           5 2 5          6   4          6   3
+--R                 - 13312b c d x  - 13312a c d x  - 4096b c d x  - 4096a c d x
+--R              *
+--R                  +-+
+--R                 \|c
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R         + 
+--R                2 7 18         7 17     2 7      2   6  16             6 15
+--R               b d x   + 2a b d x   + (a d  + 85b c d )x   + 170a b c d x
+--R             + 
+--R                   2   6        2 2 5  14            2 5 13
+--R               (85a c d  + 1204b c d )x   + 2408a b c d x
+--R             + 
+--R                     2 2 5        2 3 4  12             3 4 11
+--R               (1204a c d  + 6496b c d )x   + 12992a b c d x
+--R             + 
+--R                     2 3 4         2 4 3  10             4 3 9
+--R               (6496a c d  + 16896b c d )x   + 33792a b c d x
+--R             + 
+--R                      2 4 3         2 5 2  8             5 2 7
+--R               (16896a c d  + 22784b c d )x  + 45568a b c d x
+--R             + 
+--R                      2 5 2         2 6   6             6   5
+--R               (22784a c d  + 15360b c d)x  + 30720a b c d x
+--R             + 
+--R                      2 6         2 7  4            7 3        2 7 2
+--R               (15360a c d + 4096b c )x  + 8192a b c x  + 4096a c x
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                  2 7 17          7 16       2 7       2   6  15
+--R               13b d x   + 26a b d x   + (13a d  + 364b c d )x
+--R             + 
+--R                         6 14        2   6        2 2 5  13            2 5 12
+--R               728a b c d x   + (364a c d  + 2912b c d )x   + 5824a b c d x
+--R             + 
+--R                     2 2 5        2 3 4  11             3 4 10
+--R               (2912a c d  + 9984b c d )x   + 19968a b c d x
+--R             + 
+--R                     2 3 4         2 4 3  9             4 3 8
+--R               (9984a c d  + 16640b c d )x  + 33280a b c d x
+--R             + 
+--R                      2 4 3         2 5 2  7             5 2 6
+--R               (16640a c d  + 13312b c d )x  + 26624a b c d x
+--R             + 
+--R                      2 5 2        2 6   5            6   4        2 6   3
+--R               (13312a c d  + 4096b c d)x  + 8192a b c d x  + 4096a c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                    7 17        7 16           6 15           6 14
+--R               13b d x   + 13a d x   + 377b c d x   + 377a c d x
+--R             + 
+--R                      2 5 13          2 5 12           3 4 11           3 4 10
+--R               3276b c d x   + 3276a c d x   + 12896b c d x   + 12896a c d x
+--R             + 
+--R                       4 3 9           4 3 8           5 2 7           5 2 6
+--R               26624b c d x  + 26624a c d x  + 29952b c d x  + 29952a c d x
+--R             + 
+--R                       6   5           6   4          7 3          7 2
+--R               17408b c d x  + 17408a c d x  + 4096b c x  + 4096a c x
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R              8 18      8 17          7 16          7 15          2 6 14
+--R           b d x   + a d x   + 85b c d x   + 85a c d x   + 1204b c d x
+--R         + 
+--R                  2 6 13          3 5 12          3 5 11           4 4 10
+--R           1204a c d x   + 6496b c d x   + 6496a c d x   + 16896b c d x
+--R         + 
+--R                   4 4 9           5 3 8           5 3 7           6 2 6
+--R           16896a c d x  + 22784b c d x  + 22784a c d x  + 15360b c d x
+--R         + 
+--R                   6 2 5          7   4          7   3
+--R           15360a c d x  + 4096b c d x  + 4096a c d x
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R                2 7 18          7 17         2 7       2   6  16
+--R           - 13b d x   - 26a b d x   + (- 13a d  - 377b c d )x
+--R         + 
+--R                       6 15          2   6        2 2 5  14            2 5 13
+--R           - 754a b c d x   + (- 377a c d  - 3276b c d )x   - 6552a b c d x
+--R         + 
+--R                   2 2 5         2 3 4  12             3 4 11
+--R           (- 3276a c d  - 12896b c d )x   - 25792a b c d x
+--R         + 
+--R                    2 3 4         2 4 3  10             4 3 9
+--R           (- 12896a c d  - 26624b c d )x   - 53248a b c d x
+--R         + 
+--R                    2 4 3         2 5 2  8             5 2 7
+--R           (- 26624a c d  - 29952b c d )x  - 59904a b c d x
+--R         + 
+--R                    2 5 2         2 6   6             6   5
+--R           (- 29952a c d  - 17408b c d)x  - 34816a b c d x
+--R         + 
+--R                    2 6         2 7  4            7 3        2 7 2
+--R           (- 17408a c d - 4096b c )x  - 8192a b c x  - 4096a c x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R     + 
+--R          2 8 19         8 18       2 8      2   7  17             7 16
+--R       - b d x   - 2a b d x   + (- a d  - 85b c d )x   - 170a b c d x
+--R     + 
+--R             2   7        2 2 6  15            2 6 14
+--R       (- 85a c d  - 1204b c d )x   - 2408a b c d x
+--R     + 
+--R               2 2 6        2 3 5  13             3 5 12
+--R       (- 1204a c d  - 6496b c d )x   - 12992a b c d x
+--R     + 
+--R               2 3 5         2 4 4  11             4 4 10
+--R       (- 6496a c d  - 16896b c d )x   - 33792a b c d x
+--R     + 
+--R                2 4 4         2 5 3  9             5 3 8
+--R       (- 16896a c d  - 22784b c d )x  - 45568a b c d x
+--R     + 
+--R                2 5 3         2 6 2  7             6 2 6
+--R       (- 22784a c d  - 15360b c d )x  - 30720a b c d x
+--R     + 
+--R                2 6 2        2 7   5            7   4        2 7   3
+--R       (- 15360a c d  - 4096b c d)x  - 8192a b c d x  - 4096a c d x
+--R  /
+--R                  6 12         5 10        2 4 8        3 3 6         4 2 4
+--R               13d x   + 364c d x   + 2912c d x  + 9984c d x  + 16640c d x
+--R             + 
+--R                     5   2        6
+--R               13312c d x  + 4096c
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R            7 13        6 11        2 5 9        3 4 7         4 3 5
+--R           d x   + 84c d x   + 1120c d x  + 5376c d x  + 11520c d x
+--R         + 
+--R                 5 2 3        6
+--R           11264c d x  + 4096c d x
+--R      *
+--R          +------------------+ +--------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + c
+--R     + 
+--R                  7 14        6 12        2 5 10        3 4 8         4 3 6
+--R               - d x   - 85c d x   - 1204c d x   - 6496c d x  - 16896c d x
+--R             + 
+--R                       5 2 4         6   2        7
+--R               - 22784c d x  - 15360c d x  - 4096c
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                    7 13         6 11        2 5 9        3 4 7         4 3 5
+--R               - 13d x   - 364c d x   - 2912c d x  - 9984c d x  - 16640c d x
+--R             + 
+--R                       5 2 3        6
+--R               - 13312c d x  - 4096c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                   2 3 4         3 2 2         4   +---+ +-+
+--R             (15a c d x  + 180a c d x  + 240a c d)\|- d \|c
+--R          *
+--R              +------------------+ +--------+
+--R              | 2 2             2  |   2
+--R             \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                                         +------------------+
+--R                   3 3 4         4 2 2         5   +---+ | 2 2             2
+--R           (- 75a c d x  - 300a c d x  - 240a c d)\|- d \|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                        2 3 5      2 2 3 4           3 2 3       2 3 2 2
+--R               - 30a b c d x  - 30a c d x  - 360a b c d x  - 360a c d x
+--R             + 
+--R                         4          2 4
+--R               - 480a b c d x - 480a c d
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|c \|d \|d x  + c
+--R         + 
+--R                       3 3 5       2 3 3 4           4 2 3       2 4 2 2
+--R               150a b c d x  + 150a c d x  + 600a b c d x  + 600a c d x
+--R             + 
+--R                       5          2 5
+--R               480a b c d x + 480a c d
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- d \|d x  + c  - \|- d \|c
+--R         atan(------------------------------)
+--R                            d x
+--R     + 
+--R                       4 8           4 7         2 3 6         2 3 5
+--R               120b c d x  + 150a c d x  + 520b c d x  + 675a c d x
+--R             + 
+--R                     3 2 4         3 2 3         4   2         4            5
+--R               464b c d x  + 780a c d x  - 192b c d x  + 240a c d x - 256b c
+--R          *
+--R                        +------------------+
+--R              +---+ +-+ | 2 2             2
+--R             \|- d \|d \|b x  + 2a b x + a
+--R         + 
+--R                     2   4 9             4 8          2   4       2 2 3  7
+--R               - 120b c d x  - 270a b c d x  + (- 150a c d  - 520b c d )x
+--R             + 
+--R                          2 3 6          2 2 3       2 3 2  5            3 2 4
+--R               - 1195a b c d x  + (- 675a c d  - 480b c d )x  - 1260a b c d x
+--R             + 
+--R                     2 3 2 3           4   2       2 4
+--R               - 780a c d x  - 240a b c d x  - 240a c d x
+--R          *
+--R              +---+ +-+
+--R             \|- d \|d
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                  5 10        5 9           4 8           4 7         2 3 6
+--R           - 24b d x   - 30a d x  - 320b c d x  - 405a c d x  - 760b c d x
+--R         + 
+--R                    2 3 5         3 2 4         3 2 3         4   2         4
+--R           - 1035a c d x  - 400b c d x  - 900a c d x  + 320b c d x  - 240a c d x
+--R         + 
+--R                 5
+--R           256b c
+--R      *
+--R                        +------------------+
+--R          +---+ +-+ +-+ | 2 2             2
+--R         \|- d \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R              2 5 11          5 10       2 5       2   4  9             4 8
+--R           24b d x   + 54a b d x   + (30a d  + 320b c d )x  + 725a b c d x
+--R         + 
+--R                2   4       2 2 3  7            2 3 6
+--R           (405a c d  + 760b c d )x  + 1795a b c d x
+--R         + 
+--R                 2 2 3       2 3 2  5            3 2 4       2 3 2 3
+--R           (1035a c d  + 480b c d )x  + 1380a b c d x  + 900a c d x
+--R         + 
+--R                   4   2       2 4
+--R           240a b c d x  + 240a c d x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- d \|c \|d
+--R  /
+--R                 4 5         4 4            3 3            3 2          2 2
+--R           120b d x  + 120a d x  + 1440b c d x  + 1440a c d x  + 1920b c d x
+--R         + 
+--R                  2 2
+--R           1920a c d
+--R      *
+--R                        +--------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- d \|c \|d \|d x  + c
+--R     + 
+--R                     4 5           4 4          2 3 3          2 3 2
+--R           - 600b c d x  - 600a c d x  - 2400b c d x  - 2400a c d x
+--R         + 
+--R                    3 2           3 2
+--R           - 1920b c d x - 1920a c d
+--R      *
+--R          +---+ +-+
+--R         \|- d \|d
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                           +------------------+
+--R             5        4        3        2  | 2 2             2     2   6
+--R       (b d x  + a d x  + b c x  + a c x )\|b x  + 2a b x + a   - b d x
+--R     + 
+--R                 5       2     2   4           3    2   2
+--R       - 2a b d x  + (- a d - b c)x  - 2a b c x  - a c x
+--R  /
+--R      +------------------+ +--------+
+--R      | 2 2             2  |   2
+--R     \|b x  + 2a b x + a  \|d x  + c
+--R                                                    Type: Expression(Integer)
+--E 457
+
+)clear all
+
+--S 458 of 556
+t0:=x*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)
+--R 
+--R
+--R          +------------------+ +--------+
+--R          | 2 2             2  |   2
+--R   (1)  x\|b x  + 2a b x + a  \|d x  + c
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 556
+r0:=1/4*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/d+1/12*a*(c+d*x^2)^(3/2)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(d*(a+b*x))-1/8*b*c^2*atanh(x*sqrt(d)/_
+   sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x+b^2*x^2)/(d^(3/2)*(a+b*x))-_
+   1/8*b*c*x*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/(d*(a+b*x))
+--R 
+--R
+--R   (2)
+--R               +------------------+           +-+
+--R             2 | 2 2             2          x\|d
+--R       - 3b c \|b x  + 2a b x + a  atanh(-----------)
+--R                                          +--------+
+--R                                          |   2
+--R                                         \|d x  + c
+--R     + 
+--R                                               +------------------+ +--------+
+--R              3         2                  +-+ | 2 2             2  |   2
+--R       (6b d x  + 8a d x  + 3b c x + 8a c)\|d \|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R                       +-+
+--R     (24b d x + 24a d)\|d
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                       +--------+
+--R                   2   2        3  +-+ |   2            2 2 4        3   2
+--R             (12b c d x  + 24b c )\|c \|d x  + c  - 3b c d x  - 24b c d x
+--R           + 
+--R                    4
+--R             - 24b c
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|c \|d  + d x)\|d x  + c  + (- d x  - c)\|d  - d x\|c
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|c \|d x  + c  - c
+--R       + 
+--R                   3 7       3 6          2 5          2 4        2   3
+--R             - 6b d x  - 8a d x  - 51b c d x  - 72a c d x  - 72b c d x
+--R           + 
+--R                    2   2        3
+--R             - 96a c d x  - 24b c x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|d \|d x  + c
+--R       + 
+--R                  3 7        3 6          2 5           2 4        2   3
+--R             24b d x  + 32a d x  + 84b c d x  + 120a c d x  + 84b c d x
+--R           + 
+--R                  2   2        3
+--R             96a c d x  + 24b c x
+--R        *
+--R            +-+ +-+
+--R           \|c \|d
+--R    /
+--R                                   +--------+
+--R             2 2           +-+ +-+ |   2
+--R         (96d x  + 192c d)\|c \|d \|d x  + c
+--R       + 
+--R               3 4         2 2       2   +-+
+--R         (- 24d x  - 192c d x  - 192c d)\|d
+--R     ,
+--R
+--R                                         +--------+
+--R                     2   2        3  +-+ |   2            2 2 4        3   2
+--R             (- 24b c d x  - 48b c )\|c \|d x  + c  + 6b c d x  + 48b c d x
+--R           + 
+--R                  4
+--R             48b c
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- d \|d x  + c  - \|- d \|c
+--R           atan(------------------------------)
+--R                              d x
+--R       + 
+--R                   3 7       3 6          2 5          2 4        2   3
+--R             - 6b d x  - 8a d x  - 51b c d x  - 72a c d x  - 72b c d x
+--R           + 
+--R                    2   2        3
+--R             - 96a c d x  - 24b c x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- d \|d x  + c
+--R       + 
+--R                  3 7        3 6          2 5           2 4        2   3
+--R             24b d x  + 32a d x  + 84b c d x  + 120a c d x  + 84b c d x
+--R           + 
+--R                  2   2        3
+--R             96a c d x  + 24b c x
+--R        *
+--R            +---+ +-+
+--R           \|- d \|c
+--R    /
+--R                                     +--------+
+--R             2 2           +---+ +-+ |   2
+--R         (96d x  + 192c d)\|- d \|c \|d x  + c
+--R       + 
+--R               3 4         2 2       2   +---+
+--R         (- 24d x  - 192c d x  - 192c d)\|- d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 460
+
+--S 461 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                                +--------+
+--R               2 2   3          2   2      2 3           3  +-+ |   2
+--R           (12b c d x  + 12a b c d x  + 24b c x + 24a b c )\|c \|d x  + c
+--R         + 
+--R               2 2 2 5         2 2 4      2 3   3          3   2      2 4
+--R           - 3b c d x  - 3a b c d x  - 24b c d x  - 24a b c d x  - 24b c x
+--R         + 
+--R                    4
+--R           - 24a b c
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|c \|d  + d x)\|d x  + c  + (- d x  - c)\|d  - d x\|c
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|c \|d x  + c  - c
+--R     + 
+--R                                     +------------------+ +--------+
+--R                 2   2        3  +-+ | 2 2             2  |   2
+--R           (12b c d x  + 24b c )\|c \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                               +------------------+
+--R                  2 2 4        3   2        4  | 2 2             2
+--R           (- 3b c d x  - 24b c d x  - 24b c )\|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                   3 7       3 6          2 5          2 4        2   3
+--R               6b d x  + 8a d x  + 51b c d x  + 72a c d x  + 72b c d x
+--R             + 
+--R                     2   2        3         3
+--R               128a c d x  + 24b c x + 64a c
+--R          *
+--R                  +------------------+
+--R              +-+ | 2 2             2
+--R             \|d \|b x  + 2a b x + a
+--R         + 
+--R                   2 3 8          3 7        2 3      2   2  6             2 5
+--R               - 6b d x  - 14a b d x  + (- 8a d  - 51b c d )x  - 123a b c d x
+--R             + 
+--R                     2   2      2 2   4           2   3         2 2       2 3  2
+--R               (- 72a c d  - 72b c d)x  - 168a b c d x  + (- 96a c d - 24b c )x
+--R             + 
+--R                        3
+--R               - 24a b c x
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                  3 7        3 6          2 5           2 4        2   3
+--R           - 24b d x  - 32a d x  - 84b c d x  - 128a c d x  - 84b c d x
+--R         + 
+--R                   2   2        3         3
+--R           - 160a c d x  - 24b c x - 64a c
+--R      *
+--R                  +------------------+
+--R          +-+ +-+ | 2 2             2
+--R         \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R              2 3 8          3 7       2 3      2   2  6             2 5
+--R           24b d x  + 56a b d x  + (32a d  + 84b c d )x  + 204a b c d x
+--R         + 
+--R                2   2      2 2   4           2   3       2 2       2 3  2
+--R           (120a c d  + 84b c d)x  + 180a b c d x  + (96a c d + 24b c )x
+--R         + 
+--R                  3
+--R           24a b c x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R  /
+--R                                                             +--------+
+--R             2 3        2 2                          +-+ +-+ |   2
+--R       (96b d x  + 96a d x  + 192b c d x + 192a c d)\|c \|d \|d x  + c
+--R     + 
+--R                  3 5        3 4           2 3           2 2         2
+--R           - 24b d x  - 24a d x  - 192b c d x  - 192a c d x  - 192b c d x
+--R         + 
+--R                   2
+--R           - 192a c d
+--R      *
+--R          +-+
+--R         \|d
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        6 14      6 13          5 12          5 11
+--R                   - b d x   - a d x   - 61b c d x   - 61a c d x
+--R                 + 
+--R                           2 4 10         2 4 9          3 3 8          3 3 7
+--R                   - 620b c d x   - 620a c d x  - 2352b c d x  - 2352a c d x
+--R                 + 
+--R                            4 2 6          4 2 5          5   4          5   3
+--R                   - 4096b c d x  - 4096a c d x  - 3328b c d x  - 3328a c d x
+--R                 + 
+--R                            6 2          6
+--R                   - 1024b c x  - 1024a c x
+--R              *
+--R                  +-+
+--R                 \|d
+--R             + 
+--R                          6 13        6 12           5 11           5 10
+--R                   - 11b d x   - 11a d x   - 220b c d x   - 220a c d x
+--R                 + 
+--R                            2 4 9          2 4 8          3 3 7          3 3 6
+--R                   - 1232b c d x  - 1232a c d x  - 2816b c d x  - 2816a c d x
+--R                 + 
+--R                            4 2 5          4 2 4          5   3          5   2
+--R                   - 2816b c d x  - 2816a c d x  - 1024b c d x  - 1024a c d x
+--R              *
+--R                  +-+
+--R                 \|c
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R         + 
+--R                2 6 15         6 14     2 6      2   5  13             5 12
+--R               b d x   + 2a b d x   + (a d  + 61b c d )x   + 122a b c d x
+--R             + 
+--R                   2   5       2 2 4  11            2 4 10
+--R               (61a c d  + 620b c d )x   + 1240a b c d x
+--R             + 
+--R                    2 2 4        2 3 3  9            3 3 8
+--R               (620a c d  + 2352b c d )x  + 4704a b c d x
+--R             + 
+--R                     2 3 3        2 4 2  7            4 2 6
+--R               (2352a c d  + 4096b c d )x  + 8192a b c d x
+--R             + 
+--R                     2 4 2        2 5   5            5   4
+--R               (4096a c d  + 3328b c d)x  + 6656a b c d x
+--R             + 
+--R                     2 5         2 6  3            6 2        2 6
+--R               (3328a c d + 1024b c )x  + 2048a b c x  + 1024a c x
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                  2 6 14          6 13       2 6       2   5  12
+--R               11b d x   + 22a b d x   + (11a d  + 220b c d )x
+--R             + 
+--R                         5 11        2   5        2 2 4  10            2 4 9
+--R               440a b c d x   + (220a c d  + 1232b c d )x   + 2464a b c d x
+--R             + 
+--R                     2 2 4        2 3 3  8            3 3 7
+--R               (1232a c d  + 2816b c d )x  + 5632a b c d x
+--R             + 
+--R                     2 3 3        2 4 2  6            4 2 5
+--R               (2816a c d  + 2816b c d )x  + 5632a b c d x
+--R             + 
+--R                     2 4 2        2 5   4            5   3        2 5   2
+--R               (2816a c d  + 1024b c d)x  + 2048a b c d x  + 1024a c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                    6 14        6 13           5 12           5 11
+--R               11b d x   + 11a d x   + 231b c d x   + 231a c d x
+--R             + 
+--R                      2 4 10          2 4 9          3 3 8          3 3 7
+--R               1452b c d x   + 1452a c d x  + 4048b c d x  + 4048a c d x
+--R             + 
+--R                      4 2 6          4 2 5          5   4          5   3
+--R               5632b c d x  + 5632a c d x  + 3840b c d x  + 3840a c d x
+--R             + 
+--R                      6 2          6
+--R               1024b c x  + 1024a c x
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R              7 15      7 14          6 13          6 12         2 5 11
+--R           b d x   + a d x   + 61b c d x   + 61a c d x   + 620b c d x
+--R         + 
+--R                 2 5 10          3 4 9          3 4 8          4 3 7
+--R           620a c d x   + 2352b c d x  + 2352a c d x  + 4096b c d x
+--R         + 
+--R                  4 3 6          5 2 5          5 2 4          6   3
+--R           4096a c d x  + 3328b c d x  + 3328a c d x  + 1024b c d x
+--R         + 
+--R                  6   2
+--R           1024a c d x
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R                2 6 15          6 14         2 6       2   5  13
+--R           - 11b d x   - 22a b d x   + (- 11a d  - 231b c d )x
+--R         + 
+--R                       5 12          2   5        2 2 4  11            2 4 10
+--R           - 462a b c d x   + (- 231a c d  - 1452b c d )x   - 2904a b c d x
+--R         + 
+--R                   2 2 4        2 3 3  9            3 3 8
+--R           (- 1452a c d  - 4048b c d )x  - 8096a b c d x
+--R         + 
+--R                   2 3 3        2 4 2  7             4 2 6
+--R           (- 4048a c d  - 5632b c d )x  - 11264a b c d x
+--R         + 
+--R                   2 4 2        2 5   5            5   4
+--R           (- 5632a c d  - 3840b c d)x  - 7680a b c d x
+--R         + 
+--R                   2 5         2 6  3            6 2        2 6
+--R           (- 3840a c d - 1024b c )x  - 2048a b c x  - 1024a c x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R     + 
+--R          2 7 16         7 15       2 7      2   6  14             6 13
+--R       - b d x   - 2a b d x   + (- a d  - 61b c d )x   - 122a b c d x
+--R     + 
+--R             2   6       2 2 5  12            2 5 11
+--R       (- 61a c d  - 620b c d )x   - 1240a b c d x
+--R     + 
+--R              2 2 5        2 3 4  10            3 4 9
+--R       (- 620a c d  - 2352b c d )x   - 4704a b c d x
+--R     + 
+--R               2 3 4        2 4 3  8            4 3 7
+--R       (- 2352a c d  - 4096b c d )x  - 8192a b c d x
+--R     + 
+--R               2 4 3        2 5 2  6            5 2 5
+--R       (- 4096a c d  - 3328b c d )x  - 6656a b c d x
+--R     + 
+--R               2 5 2        2 6   4            6   3        2 6   2
+--R       (- 3328a c d  - 1024b c d)x  - 2048a b c d x  - 1024a c d x
+--R  /
+--R                    5 10         4 8        2 3 6        3 2 4        4   2
+--R                 11d x   + 220c d x  + 1232c d x  + 2816c d x  + 2816c d x
+--R               + 
+--R                      5
+--R                 1024c
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R            6 11        5 9       2 4 7        3 3 5        4 2 3        5
+--R           d x   + 60c d x  + 560c d x  + 1792c d x  + 2304c d x  + 1024c d x
+--R      *
+--R          +------------------+ +--------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + c
+--R     + 
+--R                  6 12        5 10       2 4 8        3 3 6        4 2 4
+--R               - d x   - 61c d x   - 620c d x  - 2352c d x  - 4096c d x
+--R             + 
+--R                      5   2        6
+--R               - 3328c d x  - 1024c
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                    6 11         5 9        2 4 7        3 3 5        4 2 3
+--R               - 11d x   - 220c d x  - 1232c d x  - 2816c d x  - 2816c d x
+--R             + 
+--R                      5
+--R               - 1024c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                           +------------------+ +--------+
+--R                 2   2        3  +---+ +-+ | 2 2             2  |   2
+--R           (12b c d x  + 24b c )\|- d \|c \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                                     +------------------+
+--R                  2 2 4        3   2        4  +---+ | 2 2             2
+--R           (- 3b c d x  - 24b c d x  - 24b c )\|- d \|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                                                                      +--------+
+--R                 2 2   3          2   2      2 3           3  +-+ +-+ |   2
+--R           (- 24b c d x  - 24a b c d x  - 48b c x - 48a b c )\|c \|d \|d x  + c
+--R         + 
+--R                 2 2 2 5         2 2 4      2 3   3          3   2      2 4
+--R               6b c d x  + 6a b c d x  + 48b c d x  + 48a b c d x  + 48b c x
+--R             + 
+--R                      4
+--R               48a b c
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- d \|d x  + c  - \|- d \|c
+--R         atan(------------------------------)
+--R                            d x
+--R     + 
+--R                   3 7       3 6          2 5          2 4        2   3
+--R               6b d x  + 8a d x  + 51b c d x  + 72a c d x  + 72b c d x
+--R             + 
+--R                     2   2        3         3
+--R               128a c d x  + 24b c x + 64a c
+--R          *
+--R                        +------------------+
+--R              +---+ +-+ | 2 2             2
+--R             \|- d \|d \|b x  + 2a b x + a
+--R         + 
+--R                   2 3 8          3 7        2 3      2   2  6             2 5
+--R               - 6b d x  - 14a b d x  + (- 8a d  - 51b c d )x  - 123a b c d x
+--R             + 
+--R                     2   2      2 2   4           2   3         2 2       2 3  2
+--R               (- 72a c d  - 72b c d)x  - 168a b c d x  + (- 96a c d - 24b c )x
+--R             + 
+--R                        3
+--R               - 24a b c x
+--R          *
+--R              +---+ +-+
+--R             \|- d \|d
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                  3 7        3 6          2 5           2 4        2   3
+--R           - 24b d x  - 32a d x  - 84b c d x  - 128a c d x  - 84b c d x
+--R         + 
+--R                   2   2        3         3
+--R           - 160a c d x  - 24b c x - 64a c
+--R      *
+--R                        +------------------+
+--R          +---+ +-+ +-+ | 2 2             2
+--R         \|- d \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R              2 3 8          3 7       2 3      2   2  6             2 5
+--R           24b d x  + 56a b d x  + (32a d  + 84b c d )x  + 204a b c d x
+--R         + 
+--R                2   2      2 2   4           2   3       2 2       2 3  2
+--R           (120a c d  + 84b c d)x  + 180a b c d x  + (96a c d + 24b c )x
+--R         + 
+--R                  3
+--R           24a b c x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- d \|c \|d
+--R  /
+--R                                                                   +--------+
+--R             2 3        2 2                          +---+ +-+ +-+ |   2
+--R       (96b d x  + 96a d x  + 192b c d x + 192a c d)\|- d \|c \|d \|d x  + c
+--R     + 
+--R                  3 5        3 4           2 3           2 2         2
+--R           - 24b d x  - 24a d x  - 192b c d x  - 192a c d x  - 192b c d x
+--R         + 
+--R                   2
+--R           - 192a c d
+--R      *
+--R          +---+ +-+
+--R         \|- d \|d
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                          +------------------+
+--R             4        3        2          | 2 2             2     2   5
+--R       (b d x  + a d x  + b c x  + a c x)\|b x  + 2a b x + a   - b d x
+--R     + 
+--R                 4       2     2   3           2    2
+--R       - 2a b d x  + (- a d - b c)x  - 2a b c x  - a c x
+--R  /
+--R      +------------------+ +--------+
+--R      | 2 2             2  |   2
+--R     \|b x  + 2a b x + a  \|d x  + c
+--R                                                    Type: Expression(Integer)
+--E 464
+
+)clear all
+
+--S 465 of 556
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)
+--R 
+--R
+--R         +------------------+ +--------+
+--R         | 2 2             2  |   2
+--R   (1)  \|b x  + 2a b x + a  \|d x  + c
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 556
+r0:=1/3*b*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(d*(a+b*x))+_
+   1/2*a*c*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   ((a+b*x)*sqrt(d))+1/2*a*x*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/(a+b*x)
+--R 
+--R
+--R   (2)
+--R              +------------------+           +-+
+--R              | 2 2             2          x\|d
+--R       3a c d\|b x  + 2a b x + a  atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|d x  + c
+--R     + 
+--R                                     +------------------+ +--------+
+--R              2                  +-+ | 2 2             2  |   2
+--R       (2b d x  + 3a d x + 2b c)\|d \|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R                     +-+
+--R     (6b d x + 6a d)\|d
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                     +--------+
+--R                     2        2  +-+ |   2            2   2        3
+--R           ((3a c d x  + 12a c )\|c \|d x  + c  - 9a c d x  - 12a c )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|c \|d  - d x)\|d x  + c  + (- d x  - c)\|d  + d x\|c
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|c \|d x  + c  - c
+--R       + 
+--R                                                            +--------+
+--R                    4           3        2 2        2   +-+ |   2
+--R         (- 6b c d x  - 9a c d x  - 12b c x  - 12a c x)\|d \|d x  + c
+--R       + 
+--R                2 6       2 5            4            3        2 2        2
+--R           (2b d x  + 3a d x  + 12b c d x  + 15a c d x  + 12b c x  + 12a c x)
+--R        *
+--R            +-+ +-+
+--R           \|c \|d
+--R    /
+--R                             +--------+
+--R            2        +-+ +-+ |   2                  2      2  +-+
+--R       (6d x  + 24c)\|c \|d \|d x  + c  + (- 18c d x  - 24c )\|d
+--R     ,
+--R
+--R                                     +--------+
+--R                     2        2  +-+ |   2             2   2        3
+--R           ((6a c d x  + 24a c )\|c \|d x  + c  - 18a c d x  - 24a c )
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- d \|d x  + c  - \|- d \|c
+--R           atan(------------------------------)
+--R                              d x
+--R       + 
+--R                                                              +--------+
+--R                    4           3        2 2        2   +---+ |   2
+--R         (- 6b c d x  - 9a c d x  - 12b c x  - 12a c x)\|- d \|d x  + c
+--R       + 
+--R                2 6       2 5            4            3        2 2        2
+--R           (2b d x  + 3a d x  + 12b c d x  + 15a c d x  + 12b c x  + 12a c x)
+--R        *
+--R            +---+ +-+
+--R           \|- d \|c
+--R    /
+--R                               +--------+
+--R            2        +---+ +-+ |   2                  2      2  +---+
+--R       (6d x  + 24c)\|- d \|c \|d x  + c  + (- 18c d x  - 24c )\|- d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 467
+
+--S 468 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                                 +--------+
+--R                    2 3     2   2 2          2         2 2   +-+ |   2
+--R           (3a b c d x  + 3a c d x  + 12a b c d x + 12a c d)\|c \|d x  + c
+--R         + 
+--R                   2 2 3     2 2 2 2          3         2 3
+--R           - 9a b c d x  - 9a c d x  - 12a b c d x - 12a c d
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|c \|d  - d x)\|d x  + c  + (- d x  - c)\|d  + d x\|c
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|c \|d x  + c  - c
+--R     + 
+--R                                       +------------------+ +--------+
+--R                    2 2        2   +-+ | 2 2             2  |   2
+--R           (- 3a c d x  - 12a c d)\|c \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                 +------------------+
+--R                2 2 2        3   | 2 2             2
+--R           (9a c d x  + 12a c d)\|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                    2 4         2 3        2   2        2          3  +-+
+--R             (6b c d x  + 9a c d x  + 14b c d x  + 12a c d x + 8b c )\|d
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R         + 
+--R                   2   2 5            2 4        2   2      2 2   3
+--R               - 6b c d x  - 15a b c d x  + (- 9a c d  - 12b c d)x
+--R             + 
+--R                        2   2      2 2
+--R               - 24a b c d x  - 12a c d x
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                 3 6       3 5          2 4          2 3        2   2
+--R           - 2b d x  - 3a d x  - 12b c d x  - 15a c d x  - 18b c d x
+--R         + 
+--R                  2          3
+--R           - 12a c d x - 8b c
+--R      *
+--R                  +------------------+
+--R          +-+ +-+ | 2 2             2
+--R         \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R             2 3 7         3 6      2 3      2   2  5            2 4
+--R           2b d x  + 5a b d x  + (3a d  + 12b c d )x  + 27a b c d x
+--R         + 
+--R               2   2      2 2   3          2   2      2 2
+--R           (15a c d  + 12b c d)x  + 24a b c d x  + 12a c d x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R  /
+--R                                                         +--------+
+--R            2 3       2 2                        +-+ +-+ |   2
+--R       (6b d x  + 6a d x  + 24b c d x + 24a c d)\|c \|d \|d x  + c
+--R     + 
+--R                 2 3          2 2        2           2   +-+
+--R       (- 18b c d x  - 18a c d x  - 24b c d x - 24a c d)\|d
+--R                                                    Type: Expression(Integer)
+--E 468
+
+--S 469 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        5 11      5 10          4 9          4 8         2 3 7
+--R                   - b d x   - a d x   - 41b c d x  - 41a c d x  - 280b c d x
+--R                 + 
+--R                           2 3 6         3 2 5         3 2 4         4   3
+--R                   - 280a c d x  - 688b c d x  - 688a c d x  - 704b c d x
+--R                 + 
+--R                           4   2         5          5
+--R                   - 704a c d x  - 256b c x - 256a c
+--R              *
+--R                  +-+
+--R                 \|d
+--R             + 
+--R                       5 10       5 9           4 8           4 7         2 3 6
+--R                   9b d x   + 9a d x  + 120b c d x  + 120a c d x  + 432b c d x
+--R                 + 
+--R                         2 3 5         3 2 4         3 2 3         4   2
+--R                   432a c d x  + 576b c d x  + 576a c d x  + 256b c d x
+--R                 + 
+--R                         4
+--R                   256a c d x
+--R              *
+--R                  +-+
+--R                 \|c
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R         + 
+--R                2 5 12         5 11     2 5      2   4  10            4 9
+--R               b d x   + 2a b d x   + (a d  + 41b c d )x   + 82a b c d x
+--R             + 
+--R                   2   4       2 2 3  8           2 3 7
+--R               (41a c d  + 280b c d )x  + 560a b c d x
+--R             + 
+--R                    2 2 3       2 3 2  6            3 2 5
+--R               (280a c d  + 688b c d )x  + 1376a b c d x
+--R             + 
+--R                    2 3 2       2 4   4            4   3
+--R               (688a c d  + 704b c d)x  + 1408a b c d x
+--R             + 
+--R                    2 4        2 5  2           5        2 5
+--R               (704a c d + 256b c )x  + 512a b c x + 256a c
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                   2 5 11          5 10        2 5       2   4  9
+--R               - 9b d x   - 18a b d x   + (- 9a d  - 120b c d )x
+--R             + 
+--R                           4 8          2   4       2 2 3  7           2 3 6
+--R               - 240a b c d x  + (- 120a c d  - 432b c d )x  - 864a b c d x
+--R             + 
+--R                      2 2 3       2 3 2  5            3 2 4
+--R               (- 432a c d  - 576b c d )x  - 1152a b c d x
+--R             + 
+--R                      2 3 2       2 4   3           4   2       2 4
+--R               (- 576a c d  - 256b c d)x  - 512a b c d x  - 256a c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                   5 11       5 10           4 9           4 8         2 3 7
+--R               9b d x   + 9a d x   + 129b c d x  + 129a c d x  + 552b c d x
+--R             + 
+--R                     2 3 6          3 2 5          3 2 4         4   3
+--R               552a c d x  + 1008b c d x  + 1008a c d x  + 832b c d x
+--R             + 
+--R                     4   2         5          5
+--R               832a c d x  + 256b c x + 256a c
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R                6 12      6 11          5 10          5 9         2 4 8
+--R           - b d x   - a d x   - 41b c d x   - 41a c d x  - 280b c d x
+--R         + 
+--R                   2 4 7         3 3 6         3 3 5         4 2 4         4 2 3
+--R           - 280a c d x  - 688b c d x  - 688a c d x  - 704b c d x  - 704a c d x
+--R         + 
+--R                   5   2         5
+--R           - 256b c d x  - 256a c d x
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R               2 5 12          5 11        2 5       2   4  10             4 9
+--R           - 9b d x   - 18a b d x   + (- 9a d  - 129b c d )x   - 258a b c d x
+--R         + 
+--R                  2   4       2 2 3  8            2 3 7
+--R           (- 129a c d  - 552b c d )x  - 1104a b c d x
+--R         + 
+--R                  2 2 3        2 3 2  6            3 2 5
+--R           (- 552a c d  - 1008b c d )x  - 2016a b c d x
+--R         + 
+--R                   2 3 2       2 4   4            4   3
+--R           (- 1008a c d  - 832b c d)x  - 1664a b c d x
+--R         + 
+--R                  2 4        2 5  2           5        2 5
+--R           (- 832a c d - 256b c )x  - 512a b c x - 256a c
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R     + 
+--R        2 6 13         6 12     2 6      2   5  11            5 10
+--R       b d x   + 2a b d x   + (a d  + 41b c d )x   + 82a b c d x
+--R     + 
+--R           2   5       2 2 4  9           2 4 8        2 2 4       2 3 3  7
+--R       (41a c d  + 280b c d )x  + 560a b c d x  + (280a c d  + 688b c d )x
+--R     + 
+--R                3 3 6        2 3 3       2 4 2  5            4 2 4
+--R       1376a b c d x  + (688a c d  + 704b c d )x  + 1408a b c d x
+--R     + 
+--R            2 4 2       2 5   3           5   2       2 5
+--R       (704a c d  + 256b c d)x  + 512a b c d x  + 256a c d x
+--R  /
+--R              4 8         3 6       2 2 4       3   2       4  +-+ +-+    5 9
+--R           (9d x  + 120c d x  + 432c d x  + 576c d x  + 256c )\|c \|d  - d x
+--R         + 
+--R                  4 7       2 3 5       3 2 3       4
+--R           - 40c d x  - 240c d x  - 448c d x  - 256c d x
+--R      *
+--R          +------------------+ +--------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + c
+--R     + 
+--R               5 10        4 8       2 3 6       3 2 4       4   2       5  +-+
+--R           (- d x   - 41c d x  - 280c d x  - 688c d x  - 704c d x  - 256c )\|d
+--R         + 
+--R              5 9         4 7       2 3 5       3 2 3       4     +-+
+--R           (9d x  + 120c d x  + 432c d x  + 576c d x  + 256c d x)\|c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                             +------------------+ +--------+
+--R                    2 2        2   +---+ +-+ | 2 2             2  |   2
+--R           (- 3a c d x  - 12a c d)\|- d \|c \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                       +------------------+
+--R                2 2 2        3   +---+ | 2 2             2
+--R           (9a c d x  + 12a c d)\|- d \|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                                                                     +--------+
+--R                    2 3     2   2 2          2         2 2   +-+ +-+ |   2
+--R           (6a b c d x  + 6a c d x  + 24a b c d x + 24a c d)\|c \|d \|d x  + c
+--R         + 
+--R                     2 2 3      2 2 2 2          3         2 3   +-+
+--R           (- 18a b c d x  - 18a c d x  - 24a b c d x - 24a c d)\|d
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- d \|d x  + c  - \|- d \|c
+--R         atan(------------------------------)
+--R                            d x
+--R     + 
+--R                    2 4         2 3        2   2        2          3  +---+ +-+
+--R             (6b c d x  + 9a c d x  + 14b c d x  + 12a c d x + 8b c )\|- d \|d
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R         + 
+--R                   2   2 5            2 4        2   2      2 2   3
+--R               - 6b c d x  - 15a b c d x  + (- 9a c d  - 12b c d)x
+--R             + 
+--R                        2   2      2 2
+--R               - 24a b c d x  - 12a c d x
+--R          *
+--R              +---+ +-+
+--R             \|- d \|d
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                 3 6       3 5          2 4          2 3        2   2
+--R           - 2b d x  - 3a d x  - 12b c d x  - 15a c d x  - 18b c d x
+--R         + 
+--R                  2          3
+--R           - 12a c d x - 8b c
+--R      *
+--R                        +------------------+
+--R          +---+ +-+ +-+ | 2 2             2
+--R         \|- d \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R             2 3 7         3 6      2 3      2   2  5            2 4
+--R           2b d x  + 5a b d x  + (3a d  + 12b c d )x  + 27a b c d x
+--R         + 
+--R               2   2      2 2   3          2   2      2 2
+--R           (15a c d  + 12b c d)x  + 24a b c d x  + 12a c d x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- d \|c \|d
+--R  /
+--R                                                               +--------+
+--R            2 3       2 2                        +---+ +-+ +-+ |   2
+--R       (6b d x  + 6a d x  + 24b c d x + 24a c d)\|- d \|c \|d \|d x  + c
+--R     + 
+--R                 2 3          2 2        2           2   +---+ +-+
+--R       (- 18b c d x  - 18a c d x  - 24b c d x - 24a c d)\|- d \|d
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                       +------------------+
+--R             3        2                | 2 2             2     2   4           3
+--R       (b d x  + a d x  + b c x + a c)\|b x  + 2a b x + a   - b d x  - 2a b d x
+--R     + 
+--R           2     2   2               2
+--R       (- a d - b c)x  - 2a b c x - a c
+--R  /
+--R      +------------------+ +--------+
+--R      | 2 2             2  |   2
+--R     \|b x  + 2a b x + a  \|d x  + c
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 556
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/x
+--R 
+--R
+--R         +------------------+ +--------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + c
+--R   (1)  --------------------------------
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 556
+r0:=-a*atanh(sqrt(c+d*x^2)/sqrt(c))*sqrt(c)*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   (a+b*x)+1/2*b*c*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x+_
+   b^2*x^2)/((a+b*x)*sqrt(d))+1/2*(2*a+b*x)*sqrt(a^2+2*a*b*x+b^2*x^2)*_
+   sqrt(c+d*x^2)/(a+b*x)
+--R 
+--R
+--R   (2)
+--R                                               +--------+
+--R                    +------------------+       |   2
+--R            +-+ +-+ | 2 2             2       \|d x  + c
+--R       - 2a\|c \|d \|b x  + 2a b x + a  atanh(-----------)
+--R                                                   +-+
+--R                                                  \|c
+--R     + 
+--R           +------------------+           +-+
+--R           | 2 2             2          x\|d
+--R       b c\|b x  + 2a b x + a  atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|d x  + c
+--R     + 
+--R                      +------------------+ +--------+
+--R                  +-+ | 2 2             2  |   2
+--R       (b x + 2a)\|d \|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R                 +-+
+--R     (2b x + 2a)\|d
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     +--------+
+--R                 +-+ |   2                 2         +-+ +-+
+--R           (4a c\|d \|d x  + c  + (- 2a d x  - 4a c)\|c \|d )
+--R        *
+--R                +--------+
+--R                |   2         +-+
+--R               \|d x  + c  - \|c
+--R           log(------------------)
+--R                        x
+--R       + 
+--R                     +--------+
+--R                 +-+ |   2               2       2
+--R           (2b c\|c \|d x  + c  - b c d x  - 2b c )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|c \|d  - d x)\|d x  + c  + (- d x  - c)\|d  + d x\|c
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|c \|d x  + c  - c
+--R       + 
+--R                                           +--------+
+--R                 3         2           +-+ |   2
+--R         (- b d x  - 2a d x  - 2b c x)\|d \|d x  + c
+--R       + 
+--R                3         2           +-+ +-+
+--R         (2b d x  + 2a d x  + 2b c x)\|c \|d
+--R    /
+--R                 +--------+
+--R         +-+ +-+ |   2               2       +-+
+--R       4\|c \|d \|d x  + c  + (- 2d x  - 4c)\|d
+--R     ,
+--R
+--R                       +--------+
+--R                 +---+ |   2                 2         +---+ +-+
+--R           (4a c\|- d \|d x  + c  + (- 2a d x  - 4a c)\|- d \|c )
+--R        *
+--R                +--------+
+--R                |   2         +-+
+--R               \|d x  + c  - \|c
+--R           log(------------------)
+--R                        x
+--R       + 
+--R                     +--------+
+--R                 +-+ |   2                2       2
+--R           (4b c\|c \|d x  + c  - 2b c d x  - 4b c )
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- d \|d x  + c  - \|- d \|c
+--R           atan(------------------------------)
+--R                              d x
+--R       + 
+--R                                             +--------+
+--R                 3         2           +---+ |   2
+--R         (- b d x  - 2a d x  - 2b c x)\|- d \|d x  + c
+--R       + 
+--R                3         2           +---+ +-+
+--R         (2b d x  + 2a d x  + 2b c x)\|- d \|c
+--R    /
+--R                   +--------+
+--R         +---+ +-+ |   2               2       +---+
+--R       4\|- d \|c \|d x  + c  + (- 2d x  - 4c)\|- d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 474
+
+--S 475 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------+
+--R                         2   +-+ |   2
+--R           (4a b c x + 4a c)\|d \|d x  + c
+--R         + 
+--R                      3     2   2                2   +-+ +-+
+--R           (- 2a b d x  - 2a d x  - 4a b c x - 4a c)\|c \|d
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|d x  + c  - \|c
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                 +--------+
+--R              2              +-+ |   2         2     3            2     2 2
+--R           (2b c x + 2a b c)\|c \|d x  + c  - b c d x  - a b c d x  - 2b c x
+--R         + 
+--R                   2
+--R           - 2a b c
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|c \|d  - d x)\|d x  + c  + (- d x  - c)\|d  + d x\|c
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|c \|d x  + c  - c
+--R     + 
+--R                    +------------------+ +--------+
+--R                +-+ | 2 2             2  |   2
+--R           4a c\|d \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                      +------------------+
+--R                    2         +-+ +-+ | 2 2             2
+--R           (- 2a d x  - 4a c)\|c \|d \|b x  + 2a b x + a
+--R      *
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R         atanh(-----------)
+--R                    +-+
+--R                   \|c
+--R     + 
+--R                      +------------------+ +--------+
+--R                  +-+ | 2 2             2  |   2
+--R           - 2b c\|c \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                              +------------------+
+--R                   2       2  | 2 2             2
+--R           (b c d x  + 2b c )\|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                                                  +------------------+
+--R                 3         2                  +-+ | 2 2             2
+--R           (b d x  + 2a d x  + 2b c x + 4a c)\|d \|b x  + 2a b x + a
+--R         + 
+--R               2   4           3        2      2   2             +-+
+--R           (- b d x  - 3a b d x  + (- 2a d - 2b c)x  - 2a b c x)\|d
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                                                     +------------------+
+--R                3         2                  +-+ +-+ | 2 2             2
+--R       (- 2b d x  - 4a d x  - 2b c x - 4a c)\|c \|d \|b x  + 2a b x + a
+--R     + 
+--R          2   4           3      2      2   2             +-+ +-+
+--R       (2b d x  + 4a b d x  + (2a d + 2b c)x  + 2a b c x)\|c \|d
+--R  /
+--R                         +--------+
+--R                 +-+ +-+ |   2                 3         2                  +-+
+--R     (4b x + 4a)\|c \|d \|d x  + c  + (- 2b d x  - 2a d x  - 4b c x - 4a c)\|d
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         4 9       4 8          3 7          3 6         2 2 5
+--R                   - 8b d x  - 8a d x  - 88b c d x  - 88a c d x  - 272b c d x
+--R                 + 
+--R                         2 2 4         3   3         3   2         4          4
+--R                 - 272a c d x  - 320b c d x  - 320a c d x  - 128b c x - 128a c
+--R              *
+--R                  +-+ +-+
+--R                 \|c \|d
+--R             + 
+--R                  5 10      5 9          4 8          4 7         2 3 6
+--R               b d x   + a d x  + 32b c d x  + 32a c d x  + 160b c d x
+--R             + 
+--R                   2 3 5         3 2 4         3 2 3         4   2         4
+--R             160a c d x  + 256b c d x  + 256a c d x  + 128b c d x  + 128a c d x
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R         + 
+--R                 2 4 10          4 9      2 4      2   3  8             3 7
+--R               8b d x   + 16a b d x  + (8a d  + 88b c d )x  + 176a b c d x
+--R             + 
+--R                   2   3       2 2 2  6           2 2 5
+--R               (88a c d  + 272b c d )x  + 544a b c d x
+--R             + 
+--R                    2 2 2       2 3   4           3   3        2 3        2 4  2
+--R               (272a c d  + 320b c d)x  + 640a b c d x  + (320a c d + 128b c )x
+--R             + 
+--R                       4        2 4
+--R               256a b c x + 128a c
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R              2 5 11         5 10       2 5      2   4  9            4 8
+--R           - b d x   - 2a b d x   + (- a d  - 32b c d )x  - 64a b c d x
+--R         + 
+--R                 2   4       2 2 3  7           2 3 6
+--R           (- 32a c d  - 160b c d )x  - 320a b c d x
+--R         + 
+--R                  2 2 3       2 3 2  5           3 2 4
+--R           (- 160a c d  - 256b c d )x  - 512a b c d x
+--R         + 
+--R                  2 3 2       2 4   3           4   2       2 4
+--R           (- 256a c d  - 128b c d)x  - 256a b c d x  - 128a c d x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                  5 11      5 10          4 9          4 8         2 3 7
+--R               b d x   + a d x   + 33b c d x  + 33a c d x  + 192b c d x
+--R             + 
+--R                     2 3 6         3 2 5         3 2 4         4   3
+--R               192a c d x  + 416b c d x  + 416a c d x  + 384b c d x
+--R             + 
+--R                     4   2         5          5
+--R               384a c d x  + 128b c x + 128a c
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                     5 10       5 9          4 8          4 7         2 3 6
+--R               - 8b d x   - 8a d x  - 88b c d x  - 88a c d x  - 272b c d x
+--R             + 
+--R                       2 3 5         3 2 4         3 2 3         4   2
+--R               - 272a c d x  - 320b c d x  - 320a c d x  - 128b c d x
+--R             + 
+--R                       4
+--R               - 128a c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R              2 5 12         5 11       2 5      2   4  10            4 9
+--R           - b d x   - 2a b d x   + (- a d  - 33b c d )x   - 66a b c d x
+--R         + 
+--R                 2   4       2 2 3  8           2 3 7
+--R           (- 33a c d  - 192b c d )x  - 384a b c d x
+--R         + 
+--R                  2 2 3       2 3 2  6           3 2 5
+--R           (- 192a c d  - 416b c d )x  - 832a b c d x
+--R         + 
+--R                  2 3 2       2 4   4           4   3          2 4        2 5  2
+--R           (- 416a c d  - 384b c d)x  - 768a b c d x  + (- 384a c d - 128b c )x
+--R         + 
+--R                     5        2 5
+--R           - 256a b c x - 128a c
+--R      *
+--R          +-+
+--R         \|d
+--R     + 
+--R             2 5 11          5 10      2 5      2   4  9             4 8
+--R           8b d x   + 16a b d x   + (8a d  + 88b c d )x  + 176a b c d x
+--R         + 
+--R               2   4       2 2 3  7           2 3 6        2 2 3       2 3 2  5
+--R           (88a c d  + 272b c d )x  + 544a b c d x  + (272a c d  + 320b c d )x
+--R         + 
+--R                 3 2 4        2 3 2       2 4   3           4   2       2 4
+--R         640a b c d x  + (320a c d  + 128b c d)x  + 256a b c d x  + 128a c d x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R             4 9        3 7       2 2 5       3   3       4   +-+
+--R           (d x  + 32c d x  + 160c d x  + 256c d x  + 128c x)\|d
+--R         + 
+--R                4 8        3 6       2 2 4       3   2  +-+
+--R           (- 8d x  - 80c d x  - 192c d x  - 128c d x )\|c
+--R      *
+--R          +------------------+ +--------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + c
+--R     + 
+--R                4 9        3 7       2 2 5       3   3       4   +-+ +-+    5 10
+--R           (- 8d x  - 88c d x  - 272c d x  - 320c d x  - 128c x)\|c \|d  + d x
+--R         + 
+--R                4 8       2 3 6       3 2 4       4   2
+--R           32c d x  + 160c d x  + 256c d x  + 128c d x
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                       +--------+
+--R                         2   +---+ +-+ |   2
+--R           (4a b c x + 4a c)\|- d \|d \|d x  + c
+--R         + 
+--R                      3     2   2                2   +---+ +-+ +-+
+--R           (- 2a b d x  - 2a d x  - 4a b c x - 4a c)\|- d \|c \|d
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|d x  + c  - \|c
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                          +------------------+ +--------+
+--R                +---+ +-+ | 2 2             2  |   2
+--R           4a c\|- d \|d \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                            +------------------+
+--R                    2         +---+ +-+ +-+ | 2 2             2
+--R           (- 2a d x  - 4a c)\|- d \|c \|d \|b x  + 2a b x + a
+--R      *
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R         atanh(-----------)
+--R                    +-+
+--R                   \|c
+--R     + 
+--R                            +------------------+ +--------+
+--R                  +---+ +-+ | 2 2             2  |   2
+--R           - 2b c\|- d \|c \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                    +------------------+
+--R                   2       2  +---+ | 2 2             2
+--R           (b c d x  + 2b c )\|- d \|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                                     +--------+
+--R              2              +-+ +-+ |   2
+--R           (4b c x + 4a b c)\|c \|d \|d x  + c
+--R         + 
+--R                2     3             2     2 2          2  +-+
+--R           (- 2b c d x  - 2a b c d x  - 4b c x - 4a b c )\|d
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- d \|d x  + c  - \|- d \|c
+--R         atan(------------------------------)
+--R                            d x
+--R     + 
+--R                                                        +------------------+
+--R                 3         2                  +---+ +-+ | 2 2             2
+--R           (b d x  + 2a d x  + 2b c x + 4a c)\|- d \|d \|b x  + 2a b x + a
+--R         + 
+--R               2   4           3        2      2   2             +---+ +-+
+--R           (- b d x  - 3a b d x  + (- 2a d - 2b c)x  - 2a b c x)\|- d \|d
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                                                           +------------------+
+--R                3         2                  +---+ +-+ +-+ | 2 2             2
+--R       (- 2b d x  - 4a d x  - 2b c x - 4a c)\|- d \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R          2   4           3      2      2   2             +---+ +-+ +-+
+--R       (2b d x  + 4a b d x  + (2a d + 2b c)x  + 2a b c x)\|- d \|c \|d
+--R  /
+--R                                 +--------+
+--R                   +---+ +-+ +-+ |   2
+--R       (4b x + 4a)\|- d \|c \|d \|d x  + c
+--R     + 
+--R                3         2                  +---+ +-+
+--R       (- 2b d x  - 2a d x  - 4b c x - 4a c)\|- d \|d
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                    2 5       2 4            3            2        2         2
+--R             (- 5b d x  - 5a d x  - 20b c d x  - 20a c d x  - 16b c x - 16a c )
+--R          *
+--R                  +------------------+
+--R              +-+ | 2 2             2
+--R             \|c \|b x  + 2a b x + a
+--R         + 
+--R                 2 2 6          2 5      2 2      2     4              3
+--R               5b d x  + 10a b d x  + (5a d  + 20b c d)x  + 40a b c d x
+--R             + 
+--R                   2         2 2  2          2       2 2
+--R               (20a c d + 16b c )x  + 32a b c x + 16a c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R              3 7      3 6          2 5          2 4        2   3        2   2
+--R           b d x  + a d x  + 13b c d x  + 13a c d x  + 28b c d x  + 28a c d x
+--R         + 
+--R                3         3
+--R           16b c x + 16a c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R          2 3 8         3 7       2 3      2   2  6            2 5
+--R       - b d x  - 2a b d x  + (- a d  - 13b c d )x  - 26a b c d x
+--R     + 
+--R             2   2      2 2   4          2   3         2 2       2 3  2
+--R       (- 13a c d  - 28b c d)x  - 56a b c d x  + (- 28a c d - 16b c )x
+--R     + 
+--R                3       2 3
+--R       - 32a b c x - 16a c
+--R  /
+--R                                 +------------------+ +--------+
+--R         2 5          3      2   | 2 2             2  |   2
+--R       (d x  + 12c d x  + 16c x)\|b x  + 2a b x + a  \|d x  + c
+--R     + 
+--R                                        +------------------+
+--R            2 5          3      2   +-+ | 2 2             2
+--R       (- 5d x  - 20c d x  - 16c x)\|c \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 478
+
+)clear all
+
+--S 479 of 556
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/x^2
+--R 
+--R
+--R         +------------------+ +--------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + c
+--R   (1)  --------------------------------
+--R                        2
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 556
+r0:=-b*atanh(sqrt(c+d*x^2)/sqrt(c))*sqrt(c)*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   (a+b*x)+a*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(d)*sqrt(a^2+2*a*b*x+_
+   b^2*x^2)/(a+b*x)-(a-b*x)*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/(x*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                                            +--------+
+--R                 +------------------+       |   2
+--R             +-+ | 2 2             2       \|d x  + c
+--R       - b x\|c \|b x  + 2a b x + a  atanh(-----------)
+--R                                                +-+
+--R                                               \|c
+--R     + 
+--R               +------------------+           +-+
+--R           +-+ | 2 2             2          x\|d
+--R       a x\|d \|b x  + 2a b x + a  atanh(-----------)
+--R                                          +--------+
+--R                                          |   2
+--R                                         \|d x  + c
+--R     + 
+--R                 +------------------+ +--------+
+--R                 | 2 2             2  |   2
+--R       (b x - a)\|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R        2
+--R     b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 480
+
+--S 481 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                         +--------+
+--R                     +--------+                          |   2         +-+
+--R                 +-+ |   2               3       2      \|d x  + c  - \|c
+--R         (2b c x\|c \|d x  + c  - b c d x  - 2b c x)log(------------------)
+--R                                                                 x
+--R       + 
+--R                       +--------+
+--R                   +-+ |   2                3           +-+ +-+
+--R           (2a c x\|d \|d x  + c  + (- a d x  - 2a c x)\|c \|d )
+--R        *
+--R                                +--------+
+--R                    +-+    +-+  |   2          +-+ +-+      2
+--R               (- x\|d  + \|c )\|d x  + c  + x\|c \|d  - d x  - c
+--R           log(--------------------------------------------------)
+--R                                    +--------+
+--R                                +-+ |   2
+--R                               \|c \|d x  + c  - c
+--R       + 
+--R                                      +--------+
+--R               3        2         +-+ |   2               3           2       2
+--R       (- b d x  + a d x  + 2a c)\|c \|d x  + c  + b c d x  - 2a c d x  - 2a c
+--R    /
+--R            +--------+
+--R            |   2              3         +-+
+--R       2c x\|d x  + c  + (- d x  - 2c x)\|c
+--R     ,
+--R
+--R                                                         +--------+
+--R                     +--------+                          |   2         +-+
+--R                 +-+ |   2               3       2      \|d x  + c  - \|c
+--R         (2b c x\|c \|d x  + c  - b c d x  - 2b c x)log(------------------)
+--R                                                                 x
+--R       + 
+--R                         +--------+
+--R                   +---+ |   2                 3           +---+ +-+
+--R           (4a c x\|- d \|d x  + c  + (- 2a d x  - 4a c x)\|- d \|c )
+--R        *
+--R                 +--------+
+--R                 |   2         +-+
+--R                \|d x  + c  - \|c
+--R           atan(------------------)
+--R                        +---+
+--R                      x\|- d
+--R       + 
+--R                                      +--------+
+--R               3        2         +-+ |   2               3           2       2
+--R       (- b d x  + a d x  + 2a c)\|c \|d x  + c  + b c d x  - 2a c d x  - 2a c
+--R    /
+--R            +--------+
+--R            |   2              3         +-+
+--R       2c x\|d x  + c  + (- d x  - 2c x)\|c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 481
+
+--S 482 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                    +--------+
+--R              2   2             +-+ |   2         2     4            3     2 2 2
+--R           (2b c x  + 2a b c x)\|c \|d x  + c  - b c d x  - a b c d x  - 2b c x
+--R         + 
+--R                   2
+--R           - 2a b c x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|d x  + c  - \|c
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                    +--------+
+--R                    2     2     +-+ |   2
+--R           (2a b c x  + 2a c x)\|d \|d x  + c
+--R         + 
+--R                     4    2   3           2     2     +-+ +-+
+--R           (- a b d x  - a d x  - 2a b c x  - 2a c x)\|c \|d
+--R      *
+--R                              +--------+
+--R                  +-+    +-+  |   2          +-+ +-+      2
+--R             (- x\|d  + \|c )\|d x  + c  + x\|c \|d  - d x  - c
+--R         log(--------------------------------------------------)
+--R                                  +--------+
+--R                              +-+ |   2
+--R                             \|c \|d x  + c  - c
+--R     + 
+--R                      +------------------+ +--------+
+--R                  +-+ | 2 2             2  |   2
+--R           2b c x\|c \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                 +------------------+
+--R                     3       2   | 2 2             2
+--R           (- b c d x  - 2b c x)\|b x  + 2a b x + a
+--R      *
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R         atanh(-----------)
+--R                    +-+
+--R                   \|c
+--R     + 
+--R                        +------------------+ +--------+
+--R                    +-+ | 2 2             2  |   2
+--R           - 2a c x\|d \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                     +------------------+
+--R                 3           +-+ +-+ | 2 2             2
+--R           (a d x  + 2a c x)\|c \|d \|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                                                 +------------------+
+--R                 3        2                  +-+ | 2 2             2
+--R           (b d x  - a d x  + 2b c x - 2a c)\|c \|b x  + 2a b x + a
+--R         + 
+--R               2   4    2   2                2   +-+
+--R           (- b d x  + a d x  + 2a b c x + 2a c)\|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                                                  +------------------+
+--R                  3           2       2        2  | 2 2             2
+--R       (- 2b c d x  + 2a c d x  - 2b c x + 2a c )\|b x  + 2a b x + a
+--R     + 
+--R        2     4            3     2     2         2      2 2
+--R       b c d x  - a b c d x  - 2a c d x  - 2a b c x - 2a c
+--R  /
+--R                        +--------+
+--R            2           |   2                4        3         2           +-+
+--R     (2b c x  + 2a c x)\|d x  + c  + (- b d x  - a d x  - 2b c x  - 2a c x)\|c
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        4 10      4 9          3 8          3 7         2 2 6
+--R                   - b d x   - a d x  - 32b c d x  - 32a c d x  - 160b c d x
+--R                 + 
+--R                           2 2 5         3   4         3   3         4 2
+--R                   - 160a c d x  - 256b c d x  - 256a c d x  - 128b c x
+--R                 + 
+--R                           4
+--R                   - 128a c x
+--R              *
+--R                  +-+
+--R                 \|d
+--R             + 
+--R                       4 9       4 8          3 7          3 6         2 2 5
+--R                   8b d x  + 8a d x  + 88b c d x  + 88a c d x  + 272b c d x
+--R                 + 
+--R                         2 2 4         3   3         3   2         4          4
+--R                   272a c d x  + 320b c d x  + 320a c d x  + 128b c x + 128a c
+--R              *
+--R                  +-+
+--R                 \|c
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R         + 
+--R                2 4 11         4 10     2 4      2   3  9            3 8
+--R               b d x   + 2a b d x   + (a d  + 32b c d )x  + 64a b c d x
+--R             + 
+--R                   2   3       2 2 2  7           2 2 6
+--R               (32a c d  + 160b c d )x  + 320a b c d x
+--R             + 
+--R                    2 2 2       2 3   5           3   4        2 3        2 4  3
+--R               (160a c d  + 256b c d)x  + 512a b c d x  + (256a c d + 128b c )x
+--R             + 
+--R                       4 2       2 4
+--R               256a b c x  + 128a c x
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                   2 4 10          4 9        2 4      2   3  8             3 7
+--R               - 8b d x   - 16a b d x  + (- 8a d  - 88b c d )x  - 176a b c d x
+--R             + 
+--R                     2   3       2 2 2  6           2 2 5
+--R               (- 88a c d  - 272b c d )x  - 544a b c d x
+--R             + 
+--R                      2 2 2       2 3   4           3   3
+--R               (- 272a c d  - 320b c d)x  - 640a b c d x
+--R             + 
+--R                      2 3        2 4  2           4        2 4
+--R               (- 320a c d - 128b c )x  - 256a b c x - 128a c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                   4 10       4 9          3 8          3 7         2 2 6
+--R               8b d x   + 8a d x  + 88b c d x  + 88a c d x  + 272b c d x
+--R             + 
+--R                     2 2 5         3   4         3   3         4 2         4
+--R               272a c d x  + 320b c d x  + 320a c d x  + 128b c x  + 128a c x
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R                5 11      5 10          4 9          4 8         2 3 7
+--R           - b d x   - a d x   - 33b c d x  - 33a c d x  - 192b c d x
+--R         + 
+--R                   2 3 6         3 2 5         3 2 4         4   3         4   2
+--R           - 192a c d x  - 416b c d x  - 416a c d x  - 384b c d x  - 384a c d x
+--R         + 
+--R                   5          5
+--R           - 128b c x - 128a c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R               2 4 11          4 10        2 4      2   3  9             3 8
+--R           - 8b d x   - 16a b d x   + (- 8a d  - 88b c d )x  - 176a b c d x
+--R         + 
+--R                 2   3       2 2 2  7           2 2 6
+--R           (- 88a c d  - 272b c d )x  - 544a b c d x
+--R         + 
+--R                  2 2 2       2 3   5           3   4          2 3        2 4  3
+--R           (- 272a c d  - 320b c d)x  - 640a b c d x  + (- 320a c d - 128b c )x
+--R         + 
+--R                     4 2       2 4
+--R           - 256a b c x  - 128a c x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R     + 
+--R        2 5 12         5 11     2 5      2   4  10            4 9
+--R       b d x   + 2a b d x   + (a d  + 33b c d )x   + 66a b c d x
+--R     + 
+--R           2   4       2 2 3  8           2 3 7        2 2 3       2 3 2  6
+--R       (33a c d  + 192b c d )x  + 384a b c d x  + (192a c d  + 416b c d )x
+--R     + 
+--R               3 2 5        2 3 2       2 4   4           4   3
+--R       832a b c d x  + (416a c d  + 384b c d)x  + 768a b c d x
+--R     + 
+--R            2 4        2 5  2           5        2 5
+--R       (384a c d + 128b c )x  + 256a b c x + 128a c
+--R  /
+--R              3 9        2 7       2   5       3 3  +-+ +-+    4 10        3 8
+--R           (8d x  + 80c d x  + 192c d x  + 128c x )\|c \|d  - d x   - 32c d x
+--R         + 
+--R                 2 2 6       3   4       4 2
+--R           - 160c d x  - 256c d x  - 128c x
+--R      *
+--R          +------------------+ +--------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + c
+--R     + 
+--R               4 11        3 9       2 2 7       3   5       4 3  +-+
+--R           (- d x   - 32c d x  - 160c d x  - 256c d x  - 128c x )\|d
+--R         + 
+--R              4 10        3 8       2 2 6       3   4       4 2  +-+
+--R           (8d x   + 88c d x  + 272c d x  + 320c d x  + 128c x )\|c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                    +--------+
+--R              2   2             +-+ |   2         2     4            3     2 2 2
+--R           (2b c x  + 2a b c x)\|c \|d x  + c  - b c d x  - a b c d x  - 2b c x
+--R         + 
+--R                   2
+--R           - 2a b c x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|d x  + c  - \|c
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                      +------------------+ +--------+
+--R                  +-+ | 2 2             2  |   2
+--R           2b c x\|c \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                 +------------------+
+--R                     3       2   | 2 2             2
+--R           (- b c d x  - 2b c x)\|b x  + 2a b x + a
+--R      *
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R         atanh(-----------)
+--R                    +-+
+--R                   \|c
+--R     + 
+--R                        +------------------+ +--------+
+--R                    +-+ | 2 2             2  |   2
+--R           - 2a c x\|d \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                     +------------------+
+--R                 3           +-+ +-+ | 2 2             2
+--R           (a d x  + 2a c x)\|c \|d \|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                                      +--------+
+--R                    2     2     +---+ |   2
+--R           (4a b c x  + 4a c x)\|- d \|d x  + c
+--R         + 
+--R                      4     2   3           2     2     +---+ +-+
+--R           (- 2a b d x  - 2a d x  - 4a b c x  - 4a c x)\|- d \|c
+--R      *
+--R               +--------+
+--R               |   2         +-+
+--R              \|d x  + c  - \|c
+--R         atan(------------------)
+--R                      +---+
+--R                    x\|- d
+--R     + 
+--R                                                 +------------------+
+--R                 3        2                  +-+ | 2 2             2
+--R           (b d x  - a d x  + 2b c x - 2a c)\|c \|b x  + 2a b x + a
+--R         + 
+--R               2   4    2   2                2   +-+
+--R           (- b d x  + a d x  + 2a b c x + 2a c)\|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                                                  +------------------+
+--R                  3           2       2        2  | 2 2             2
+--R       (- 2b c d x  + 2a c d x  - 2b c x + 2a c )\|b x  + 2a b x + a
+--R     + 
+--R        2     4            3     2     2         2      2 2
+--R       b c d x  - a b c d x  - 2a c d x  - 2a b c x - 2a c
+--R  /
+--R                        +--------+
+--R            2           |   2                4        3         2           +-+
+--R     (2b c x  + 2a c x)\|d x  + c  + (- b d x  - a d x  - 2b c x  - 2a c x)\|c
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                    2 5       2 4            3            2        2         2
+--R             (- 5b d x  - 5a d x  - 20b c d x  - 20a c d x  - 16b c x - 16a c )
+--R          *
+--R                  +------------------+
+--R              +-+ | 2 2             2
+--R             \|c \|b x  + 2a b x + a
+--R         + 
+--R                 2 2 6          2 5      2 2      2     4              3
+--R               5b d x  + 10a b d x  + (5a d  + 20b c d)x  + 40a b c d x
+--R             + 
+--R                   2         2 2  2          2       2 2
+--R               (20a c d + 16b c )x  + 32a b c x + 16a c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R              3 7      3 6          2 5          2 4        2   3        2   2
+--R           b d x  + a d x  + 13b c d x  + 13a c d x  + 28b c d x  + 28a c d x
+--R         + 
+--R                3         3
+--R           16b c x + 16a c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R          2 3 8         3 7       2 3      2   2  6            2 5
+--R       - b d x  - 2a b d x  + (- a d  - 13b c d )x  - 26a b c d x
+--R     + 
+--R             2   2      2 2   4          2   3         2 2       2 3  2
+--R       (- 13a c d  - 28b c d)x  - 56a b c d x  + (- 28a c d - 16b c )x
+--R     + 
+--R                3       2 3
+--R       - 32a b c x - 16a c
+--R  /
+--R                                  +------------------+ +--------+
+--R         2 6          4      2 2  | 2 2             2  |   2
+--R       (d x  + 12c d x  + 16c x )\|b x  + 2a b x + a  \|d x  + c
+--R     + 
+--R                                         +------------------+
+--R            2 6          4      2 2  +-+ | 2 2             2
+--R       (- 5d x  - 20c d x  - 16c x )\|c \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 485
+
+)clear all
+
+--S 486 of 556
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/x^3
+--R 
+--R
+--R         +------------------+ +--------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + c
+--R   (1)  --------------------------------
+--R                        3
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 556
+r0:=-1/2*a*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(c*x^2*(a+b*x))-_
+   1/2*a*d*atanh(sqrt(c+d*x^2)/sqrt(c))*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   ((a+b*x)*sqrt(c))+b*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(d)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(a+b*x)-1/2*(2*b*c-a*d*x)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/(c*x*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                                           +--------+
+--R                +------------------+       |   2
+--R              2 | 2 2             2       \|d x  + c
+--R       - a d x \|b x  + 2a b x + a  atanh(-----------)
+--R                                               +-+
+--R                                              \|c
+--R     + 
+--R                     +------------------+           +-+
+--R           2 +-+ +-+ | 2 2             2          x\|d
+--R       2b x \|c \|d \|b x  + 2a b x + a  atanh(-----------)
+--R                                                +--------+
+--R                                                |   2
+--R                                               \|d x  + c
+--R     + 
+--R                        +------------------+ +--------+
+--R                    +-+ | 2 2             2  |   2
+--R       (- 2b x - a)\|c \|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R          3       2  +-+
+--R     (2b x  + 2a x )\|c
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      +--------+
+--R                    2 |   2              2 4           2  +-+
+--R           (2a c d x \|d x  + c  + (- a d x  - 2a c d x )\|c )
+--R        *
+--R                +--------+
+--R                |   2         +-+
+--R               \|d x  + c  - \|c
+--R           log(------------------)
+--R                        x
+--R       + 
+--R                            +--------+
+--R                  2 +-+ +-+ |   2                   4       2 2  +-+
+--R           (4b c x \|c \|d \|d x  + c  + (- 2b c d x  - 4b c x )\|d )
+--R        *
+--R                                +--------+
+--R                    +-+    +-+  |   2          +-+ +-+      2
+--R               (- x\|d  + \|c )\|d x  + c  + x\|c \|d  - d x  - c
+--R           log(--------------------------------------------------)
+--R                                    +--------+
+--R                                +-+ |   2
+--R                               \|c \|d x  + c  - c
+--R       + 
+--R                                                 +--------+
+--R                  3          2       2        2  |   2
+--R         (2b c d x  + a c d x  + 4b c x + 2a c )\|d x  + c
+--R       + 
+--R                    3           2       2        2  +-+
+--R         (- 4b c d x  - 2a c d x  - 4b c x - 2a c )\|c
+--R    /
+--R                 +--------+
+--R           2 +-+ |   2              4     2 2
+--R       4c x \|c \|d x  + c  - 2c d x  - 4c x
+--R     ,
+--R
+--R                      +--------+
+--R                    2 |   2              2 4           2  +-+
+--R           (2a c d x \|d x  + c  + (- a d x  - 2a c d x )\|c )
+--R        *
+--R                +--------+
+--R                |   2         +-+
+--R               \|d x  + c  - \|c
+--R           log(------------------)
+--R                        x
+--R       + 
+--R                              +--------+
+--R                  2 +---+ +-+ |   2                   4       2 2  +---+
+--R           (8b c x \|- d \|c \|d x  + c  + (- 4b c d x  - 8b c x )\|- d )
+--R        *
+--R                 +--------+
+--R                 |   2         +-+
+--R                \|d x  + c  - \|c
+--R           atan(------------------)
+--R                        +---+
+--R                      x\|- d
+--R       + 
+--R                                                 +--------+
+--R                  3          2       2        2  |   2
+--R         (2b c d x  + a c d x  + 4b c x + 2a c )\|d x  + c
+--R       + 
+--R                    3           2       2        2  +-+
+--R         (- 4b c d x  - 2a c d x  - 4b c x - 2a c )\|c
+--R    /
+--R                 +--------+
+--R           2 +-+ |   2              4     2 2
+--R       4c x \|c \|d x  + c  - 2c d x  - 4c x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 488
+
+--S 489 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                     +--------+
+--R                    3     2   2  +-+ |   2             2 5    2 2 4
+--R           (2a b d x  + 2a d x )\|c \|d x  + c  - a b d x  - a d x
+--R         + 
+--R                       3     2     2
+--R           - 2a b c d x  - 2a c d x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|d x  + c  - \|c
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                     +--------+
+--R              2   3           2  +-+ |   2
+--R           (4b c x  + 4a b c x )\|d \|d x  + c
+--R         + 
+--R                2   5           4     2   3           2  +-+ +-+
+--R           (- 2b d x  - 2a b d x  - 4b c x  - 4a b c x )\|c \|d
+--R      *
+--R                              +--------+
+--R                  +-+    +-+  |   2          +-+ +-+      2
+--R             (- x\|d  + \|c )\|d x  + c  + x\|c \|d  - d x  - c
+--R         log(--------------------------------------------------)
+--R                                  +--------+
+--R                              +-+ |   2
+--R                             \|c \|d x  + c  - c
+--R     + 
+--R                       +------------------+ +--------+
+--R                 2 +-+ | 2 2             2  |   2
+--R           2a d x \|c \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                  +------------------+
+--R                 2 4           2  | 2 2             2
+--R           (- a d x  - 2a c d x )\|b x  + 2a b x + a
+--R      *
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R         atanh(-----------)
+--R                    +-+
+--R                   \|c
+--R     + 
+--R                         +------------------+ +--------+
+--R                   2 +-+ | 2 2             2  |   2
+--R           - 4b c x \|d \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                       +------------------+
+--R                  4         2  +-+ +-+ | 2 2             2
+--R           (2b d x  + 4b c x )\|c \|d \|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                                                    +------------------+
+--R                    3        2                  +-+ | 2 2             2
+--R           (- 2b d x  - a d x  - 4b c x - 2a c)\|c \|b x  + 2a b x + a
+--R         + 
+--R              2   4           3     2      2   2                2   +-+
+--R           (2b d x  + 3a b d x  + (a d + 4b c)x  + 6a b c x + 2a c)\|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                                                +------------------+
+--R                3           2       2        2  | 2 2             2      2     4
+--R       (4b c d x  + 2a c d x  + 4b c x + 2a c )\|b x  + 2a b x + a   - 4b c d x
+--R     + 
+--R                   3        2        2 2  2         2      2 2
+--R       - 6a b c d x  + (- 2a c d - 4b c )x  - 6a b c x - 2a c
+--R  /
+--R                           +--------+
+--R              3         2  |   2
+--R       (4b c x  + 4a c x )\|d x  + c
+--R     + 
+--R                5         4         3         2  +-+
+--R       (- 2b d x  - 2a d x  - 4b c x  - 4a c x )\|c
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        4 10      4 9          3 8          3 7         2 2 6
+--R                   - b d x   - a d x  - 32b c d x  - 32a c d x  - 160b c d x
+--R                 + 
+--R                           2 2 5         3   4         3   3         4 2
+--R                   - 160a c d x  - 256b c d x  - 256a c d x  - 128b c x
+--R                 + 
+--R                           4
+--R                   - 128a c x
+--R              *
+--R                  +-+
+--R                 \|d
+--R             + 
+--R                       4 9       4 8          3 7          3 6         2 2 5
+--R                   8b d x  + 8a d x  + 88b c d x  + 88a c d x  + 272b c d x
+--R                 + 
+--R                         2 2 4         3   3         3   2         4          4
+--R                   272a c d x  + 320b c d x  + 320a c d x  + 128b c x + 128a c
+--R              *
+--R                  +-+
+--R                 \|c
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R         + 
+--R                2 4 11         4 10     2 4      2   3  9            3 8
+--R               b d x   + 2a b d x   + (a d  + 32b c d )x  + 64a b c d x
+--R             + 
+--R                   2   3       2 2 2  7           2 2 6
+--R               (32a c d  + 160b c d )x  + 320a b c d x
+--R             + 
+--R                    2 2 2       2 3   5           3   4        2 3        2 4  3
+--R               (160a c d  + 256b c d)x  + 512a b c d x  + (256a c d + 128b c )x
+--R             + 
+--R                       4 2       2 4
+--R               256a b c x  + 128a c x
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                   2 4 10          4 9        2 4      2   3  8             3 7
+--R               - 8b d x   - 16a b d x  + (- 8a d  - 88b c d )x  - 176a b c d x
+--R             + 
+--R                     2   3       2 2 2  6           2 2 5
+--R               (- 88a c d  - 272b c d )x  - 544a b c d x
+--R             + 
+--R                      2 2 2       2 3   4           3   3
+--R               (- 272a c d  - 320b c d)x  - 640a b c d x
+--R             + 
+--R                      2 3        2 4  2           4        2 4
+--R               (- 320a c d - 128b c )x  - 256a b c x - 128a c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                   4 10       4 9          3 8          3 7         2 2 6
+--R               8b d x   + 8a d x  + 88b c d x  + 88a c d x  + 272b c d x
+--R             + 
+--R                     2 2 5         3   4         3   3         4 2         4
+--R               272a c d x  + 320b c d x  + 320a c d x  + 128b c x  + 128a c x
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R                5 11      5 10          4 9          4 8         2 3 7
+--R           - b d x   - a d x   - 33b c d x  - 33a c d x  - 192b c d x
+--R         + 
+--R                   2 3 6         3 2 5         3 2 4         4   3         4   2
+--R           - 192a c d x  - 416b c d x  - 416a c d x  - 384b c d x  - 384a c d x
+--R         + 
+--R                   5          5
+--R           - 128b c x - 128a c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R               2 4 11          4 10        2 4      2   3  9             3 8
+--R           - 8b d x   - 16a b d x   + (- 8a d  - 88b c d )x  - 176a b c d x
+--R         + 
+--R                 2   3       2 2 2  7           2 2 6
+--R           (- 88a c d  - 272b c d )x  - 544a b c d x
+--R         + 
+--R                  2 2 2       2 3   5           3   4          2 3        2 4  3
+--R           (- 272a c d  - 320b c d)x  - 640a b c d x  + (- 320a c d - 128b c )x
+--R         + 
+--R                     4 2       2 4
+--R           - 256a b c x  - 128a c x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R     + 
+--R        2 5 12         5 11     2 5      2   4  10            4 9
+--R       b d x   + 2a b d x   + (a d  + 33b c d )x   + 66a b c d x
+--R     + 
+--R           2   4       2 2 3  8           2 3 7        2 2 3       2 3 2  6
+--R       (33a c d  + 192b c d )x  + 384a b c d x  + (192a c d  + 416b c d )x
+--R     + 
+--R               3 2 5        2 3 2       2 4   4           4   3
+--R       832a b c d x  + (416a c d  + 384b c d)x  + 768a b c d x
+--R     + 
+--R            2 4        2 5  2           5        2 5
+--R       (384a c d + 128b c )x  + 256a b c x + 128a c
+--R  /
+--R              3 10        2 8       2   6       3 4  +-+ +-+    4 11        3 9
+--R           (8d x   + 80c d x  + 192c d x  + 128c x )\|c \|d  - d x   - 32c d x
+--R         + 
+--R                 2 2 7       3   5       4 3
+--R           - 160c d x  - 256c d x  - 128c x
+--R      *
+--R          +------------------+ +--------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + c
+--R     + 
+--R               4 12        3 10       2 2 8       3   6       4 4  +-+
+--R           (- d x   - 32c d x   - 160c d x  - 256c d x  - 128c x )\|d
+--R         + 
+--R              4 11        3 9       2 2 7       3   5       4 3  +-+
+--R           (8d x   + 88c d x  + 272c d x  + 320c d x  + 128c x )\|c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                     +--------+
+--R                    3     2   2  +-+ |   2             2 5    2 2 4
+--R           (2a b d x  + 2a d x )\|c \|d x  + c  - a b d x  - a d x
+--R         + 
+--R                       3     2     2
+--R           - 2a b c d x  - 2a c d x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|d x  + c  - \|c
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                       +------------------+ +--------+
+--R                 2 +-+ | 2 2             2  |   2
+--R           2a d x \|c \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                  +------------------+
+--R                 2 4           2  | 2 2             2
+--R           (- a d x  - 2a c d x )\|b x  + 2a b x + a
+--R      *
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R         atanh(-----------)
+--R                    +-+
+--R                   \|c
+--R     + 
+--R                         +------------------+ +--------+
+--R                   2 +-+ | 2 2             2  |   2
+--R           - 4b c x \|d \|b x  + 2a b x + a  \|d x  + c
+--R         + 
+--R                                       +------------------+
+--R                  4         2  +-+ +-+ | 2 2             2
+--R           (2b d x  + 4b c x )\|c \|d \|b x  + 2a b x + a
+--R      *
+--R                    +-+
+--R                  x\|d
+--R         atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|d x  + c
+--R     + 
+--R                                       +--------+
+--R              2   3           2  +---+ |   2
+--R           (8b c x  + 8a b c x )\|- d \|d x  + c
+--R         + 
+--R                2   5           4     2   3           2  +---+ +-+
+--R           (- 4b d x  - 4a b d x  - 8b c x  - 8a b c x )\|- d \|c
+--R      *
+--R               +--------+
+--R               |   2         +-+
+--R              \|d x  + c  - \|c
+--R         atan(------------------)
+--R                      +---+
+--R                    x\|- d
+--R     + 
+--R                                                    +------------------+
+--R                    3        2                  +-+ | 2 2             2
+--R           (- 2b d x  - a d x  - 4b c x - 2a c)\|c \|b x  + 2a b x + a
+--R         + 
+--R              2   4           3     2      2   2                2   +-+
+--R           (2b d x  + 3a b d x  + (a d + 4b c)x  + 6a b c x + 2a c)\|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                                                +------------------+
+--R                3           2       2        2  | 2 2             2      2     4
+--R       (4b c d x  + 2a c d x  + 4b c x + 2a c )\|b x  + 2a b x + a   - 4b c d x
+--R     + 
+--R                   3        2        2 2  2         2      2 2
+--R       - 6a b c d x  + (- 2a c d - 4b c )x  - 6a b c x - 2a c
+--R  /
+--R                           +--------+
+--R              3         2  |   2
+--R       (4b c x  + 4a c x )\|d x  + c
+--R     + 
+--R                5         4         3         2  +-+
+--R       (- 2b d x  - 2a d x  - 4b c x  - 4a c x )\|c
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                    2 5       2 4            3            2        2         2
+--R             (- 5b d x  - 5a d x  - 20b c d x  - 20a c d x  - 16b c x - 16a c )
+--R          *
+--R                  +------------------+
+--R              +-+ | 2 2             2
+--R             \|c \|b x  + 2a b x + a
+--R         + 
+--R                 2 2 6          2 5      2 2      2     4              3
+--R               5b d x  + 10a b d x  + (5a d  + 20b c d)x  + 40a b c d x
+--R             + 
+--R                   2         2 2  2          2       2 2
+--R               (20a c d + 16b c )x  + 32a b c x + 16a c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R              3 7      3 6          2 5          2 4        2   3        2   2
+--R           b d x  + a d x  + 13b c d x  + 13a c d x  + 28b c d x  + 28a c d x
+--R         + 
+--R                3         3
+--R           16b c x + 16a c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R          2 3 8         3 7       2 3      2   2  6            2 5
+--R       - b d x  - 2a b d x  + (- a d  - 13b c d )x  - 26a b c d x
+--R     + 
+--R             2   2      2 2   4          2   3         2 2       2 3  2
+--R       (- 13a c d  - 28b c d)x  - 56a b c d x  + (- 28a c d - 16b c )x
+--R     + 
+--R                3       2 3
+--R       - 32a b c x - 16a c
+--R  /
+--R                                  +------------------+ +--------+
+--R         2 7          5      2 3  | 2 2             2  |   2
+--R       (d x  + 12c d x  + 16c x )\|b x  + 2a b x + a  \|d x  + c
+--R     + 
+--R                                         +------------------+
+--R            2 7          5      2 3  +-+ | 2 2             2
+--R       (- 5d x  - 20c d x  - 16c x )\|c \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 556
+t0:=x^2*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)
+--R 
+--R
+--R           +------------------+ +--------------+
+--R         2 | 2 2             2  |   2
+--R   (1)  x \|b x  + 2a b x + a  \|d x  + e x + c
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 556
+r0:=-1/240*(8*b*c*d+50*a*d*e-35*b*e^2)*(c+e*x+d*x^2)^(3/2)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(d^3*(a+b*x))+1/5*b*x^2*(c+e*x+d*x^2)^(3/2)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(d*(a+b*x))-1/40*(4*b*c-(10*a*d-7*b*e)*x)*_
+   (c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(d^2*(a+b*x))-_
+   1/256*(4*c*d-e^2)*(2*a*d*(4*c*d-5*e^2)-b*(12*c*d*e-7*e^3))*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(d^(9/2)*(a+b*x))-_
+   1/128*(2*a*d*(4*c*d-5*e^2)-b*(12*c*d*e-7*e^3))*(e+2*d*x)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/(d^4*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                 5           4             3           2 2         2 2
+--R           105b e  - 150a d e  - 600b c d e  + 720a c d e  + 720b c d e
+--R         + 
+--R                   2 3
+--R           - 480a c d
+--R      *
+--R          +------------------+
+--R          | 2 2             2              2d x + e
+--R         \|b x  + 2a b x + a  atanh(----------------------)
+--R                                          +--------------+
+--R                                      +-+ |   2
+--R                                    2\|d \|d x  + e x + c
+--R     + 
+--R                 4 4         3          4  3
+--R           768b d x  + (96b d e + 960a d )x
+--R         + 
+--R                    2 2         3            3  2
+--R           (- 112b d e  + 160a d e + 256b c d )x
+--R         + 
+--R                    3         2 2           2            3           4
+--R           (140b d e  - 200a d e  - 464b c d e + 480a c d )x - 210b e
+--R         + 
+--R                   3             2            2          2 2
+--R           300a d e  + 920b c d e  - 1040a c d e - 512b c d
+--R      *
+--R              +------------------+ +--------------+
+--R          +-+ | 2 2             2  |   2
+--R         \|d \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R             4           4  +-+
+--R     (3840b d x + 3840a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 556
+--a0:=integrate(t0,x)
+--E 495
+
+--S 496 of 556
+--m0:=a0-r0
+--E 496
+
+--S 497 of 556
+--d0:=D(m0,x)
+--E 497
+
+)clear all
+
+--S 498 of 556
+t0:=x*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)
+--R 
+--R
+--R          +------------------+ +--------------+
+--R          | 2 2             2  |   2
+--R   (1)  x\|b x  + 2a b x + a  \|d x  + e x + c
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 556
+r0:=1/4*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/d+_
+   1/24*(2*a*d-5*b*e)*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   (d^2*(a+b*x))-1/128*(4*c*d-e^2)*(4*b*c*d+8*a*d*e-5*b*e^2)*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x+_
+   b^2*x^2)/(d^(7/2)*(a+b*x))-1/64*(4*b*c*d+8*a*d*e-5*b*e^2)*(e+2*d*x)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/(d^3*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                 4          3            2          2         2 2
+--R         (- 15b e  + 24a d e  + 72b c d e  - 96a c d e - 48b c d )
+--R      *
+--R          +------------------+
+--R          | 2 2             2              2d x + e
+--R         \|b x  + 2a b x + a  atanh(----------------------)
+--R                                          +--------------+
+--R                                      +-+ |   2
+--R                                    2\|d \|d x  + e x + c
+--R     + 
+--R                3 3         2          3  2             2        2           2
+--R           96b d x  + (16b d e + 128a d )x  + (- 20b d e  + 32a d e + 48b c d )x
+--R         + 
+--R                3          2                        2
+--R           30b e  - 48a d e  - 104b c d e + 128a c d
+--R      *
+--R              +------------------+ +--------------+
+--R          +-+ | 2 2             2  |   2
+--R         \|d \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R            3          3  +-+
+--R     (384b d x + 384a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 556
+--a0:=integrate(t0,x)
+--E 500
+
+--S 501 of 556
+--m0:=a0-r0
+--E 501
+
+--S 502 of 556
+--d0:=D(m0,x)
+--E 502
+
+)clear all
+
+--S 503 of 556
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)
+--R 
+--R
+--R         +------------------+ +--------------+
+--R         | 2 2             2  |   2
+--R   (1)  \|b x  + 2a b x + a  \|d x  + e x + c
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 556
+r0:=1/3*b*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(d*(a+b*x))+_
+   1/16*(2*a*d-b*e)*(4*c*d-e^2)*atanh(1/2*(e+2*d*x)/(sqrt(d)*_
+   sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x+b^2*x^2)/(d^(5/2)*(a+b*x))+_
+   1/8*(2*a*d-b*e)*(e+2*d*x)*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/_
+   (d^2*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                                                  +------------------+
+--R              3         2                      2  | 2 2             2
+--R         (3b e  - 6a d e  - 12b c d e + 24a c d )\|b x  + 2a b x + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R               2 2                  2         2                      +-+
+--R         (16b d x  + (4b d e + 24a d )x - 6b e  + 12a d e + 16b c d)\|d
+--R      *
+--R          +------------------+ +--------------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R           2         2  +-+
+--R     (48b d x + 48a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 504
+
+--S 505 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          5          4            3          2 2        2 2
+--R                     18b e  - 36a d e  - 48b c d e  + 96a c d e  - 96b c d e
+--R                   + 
+--R                           2 3
+--R                     192a c d
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                         4             3         2   2         2 2           2 3
+--R                 (96b c e  - 192a c d e  - 384b c d e  + 768a c d e)x + 96b c e
+--R               + 
+--R                         2   2         3            3 2
+--R                 - 192a c d e  - 384b c d e + 768a c d
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|c \|d x  + e x + c
+--R           + 
+--R                       6         5            4          2 3         2 2 2
+--R                 - 3b e  + 6a d e  - 24b c d e  + 48a c d e  + 144b c d e
+--R               + 
+--R                         2 3
+--R                 - 288a c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          5             4         2   3         2 2 2
+--R                 - 54b c e  + 108a c d e  + 144b c d e  - 288a c d e
+--R               + 
+--R                       3 2          3 3
+--R                 288b c d e - 576a c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      2 4         2   3         3   2          3 2           3 3
+--R             (- 144b c e  + 288a c d e  + 576b c d e  - 1152a c d e)x - 96b c e
+--R           + 
+--R                   3   2         4            4 2
+--R             192a c d e  + 384b c d e - 768a c d
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|c \|d  - 2d x)\|d x  + e x + c  + (- 2d x  - e x - 2c)\|d
+--R                + 
+--R                       +-+
+--R                  2d x\|c
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|c \|d x  + e x + c  - e x - 2c
+--R       + 
+--R                     2 3           3   5
+--R             (- 16b d e  - 192b c d e)x
+--R           + 
+--R                      4        2 3           2 2           3          2 3  4
+--R             (- 4b d e  - 24a d e  - 336b c d e  - 288a c d e - 384b c d )x
+--R           + 
+--R                     5          4            3           2 2          2 2
+--R                 6b e  - 12a d e  - 16b c d e  - 576a c d e  - 1056b c d e
+--R               + 
+--R                         2 3
+--R                 - 576a c d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     4             3         2   2          2 2          3 2  2
+--R             (72b c e  - 144a c d e  - 288b c d e  - 1344a c d e - 768b c d )x
+--R           + 
+--R                   2 3         2   2         3            3 2
+--R             (96b c e  - 192a c d e  - 384b c d e - 768a c d )x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|d \|d x  + e x + c
+--R       + 
+--R                   3 2           4  6
+--R             (96b d e  + 128b c d )x
+--R           + 
+--R                    2 3         3 2           3            4  5
+--R             (120b d e  + 144a d e  + 672b c d e + 192a c d )x
+--R           + 
+--R                       4         2 3           2 2            3          2 3  4
+--R             (- 12b d e  + 216a d e  + 816b c d e  + 1056a c d e + 768b c d )x
+--R           + 
+--R                        5          4            3            2 2          2 2
+--R                 - 30b e  + 60a d e  + 64b c d e  + 1248a c d e  + 1632b c d e
+--R               + 
+--R                       2 3
+--R                 960a c d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                             4             3         2   2          2 2
+--R                   - 120b c e  + 240a c d e  + 480b c d e  + 1728a c d e
+--R                 + 
+--R                         3 2
+--R                   768b c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     2 3         2   2         3            3 2
+--R             (- 96b c e  + 192a c d e  + 384b c d e + 768a c d )x
+--R        *
+--R            +-+ +-+
+--R           \|c \|d
+--R    /
+--R                 2 2         3  2          2           2 2  +-+ +-+
+--R           ((288d e  + 384c d )x  + 1536c d e x + 1536c d )\|c \|d
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|d x  + e x + c
+--R       + 
+--R                   2 3         3   3            2 2        2 3  2        2 2
+--R             (- 48d e  - 576c d e)x  + (- 864c d e  - 1152c d )x  - 2304c d e x
+--R           + 
+--R                    3 2
+--R             - 1536c d
+--R        *
+--R            +-+
+--R           \|d
+--R     ,
+--R
+--R                          5          4            3          2 2        2 2
+--R                     18b e  - 36a d e  - 48b c d e  + 96a c d e  - 96b c d e
+--R                   + 
+--R                           2 3
+--R                     192a c d
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                         4             3         2   2         2 2           2 3
+--R                 (96b c e  - 192a c d e  - 384b c d e  + 768a c d e)x + 96b c e
+--R               + 
+--R                         2   2         3            3 2
+--R                 - 192a c d e  - 384b c d e + 768a c d
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|c \|d x  + e x + c
+--R           + 
+--R                       6         5            4          2 3         2 2 2
+--R                 - 3b e  + 6a d e  - 24b c d e  + 48a c d e  + 144b c d e
+--R               + 
+--R                         2 3
+--R                 - 288a c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          5             4         2   3         2 2 2
+--R                 - 54b c e  + 108a c d e  + 144b c d e  - 288a c d e
+--R               + 
+--R                       3 2          3 3
+--R                 288b c d e - 576a c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      2 4         2   3         3   2          3 2           3 3
+--R             (- 144b c e  + 288a c d e  + 576b c d e  - 1152a c d e)x - 96b c e
+--R           + 
+--R                   3   2         4            4 2
+--R             192a c d e  + 384b c d e - 768a c d
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- d \|d x  + e x + c  - \|- d \|c
+--R           atan(------------------------------------)
+--R                                 d x
+--R       + 
+--R                    2 3          3   5
+--R             (- 8b d e  - 96b c d e)x
+--R           + 
+--R                      4        2 3           2 2           3          2 3  4
+--R             (- 2b d e  - 12a d e  - 168b c d e  - 144a c d e - 192b c d )x
+--R           + 
+--R                     5         4           3           2 2         2 2
+--R                 3b e  - 6a d e  - 8b c d e  - 288a c d e  - 528b c d e
+--R               + 
+--R                         2 3
+--R                 - 288a c d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     4            3         2   2         2 2          3 2  2
+--R             (36b c e  - 72a c d e  - 144b c d e  - 672a c d e - 384b c d )x
+--R           + 
+--R                   2 3        2   2         3            3 2
+--R             (48b c e  - 96a c d e  - 192b c d e - 384a c d )x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- d \|d x  + e x + c
+--R       + 
+--R                   3 2          4  6
+--R             (48b d e  + 64b c d )x
+--R           + 
+--R                   2 3        3 2           3           4  5
+--R             (60b d e  + 72a d e  + 336b c d e + 96a c d )x
+--R           + 
+--R                      4         2 3           2 2           3          2 3  4
+--R             (- 6b d e  + 108a d e  + 408b c d e  + 528a c d e + 384b c d )x
+--R           + 
+--R                        5          4            3           2 2         2 2
+--R                 - 15b e  + 30a d e  + 32b c d e  + 624a c d e  + 816b c d e
+--R               + 
+--R                       2 3
+--R                 480a c d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4             3         2   2         2 2          3 2  2
+--R             (- 60b c e  + 120a c d e  + 240b c d e  + 864a c d e + 384b c d )x
+--R           + 
+--R                     2 3        2   2         3            3 2
+--R             (- 48b c e  + 96a c d e  + 192b c d e + 384a c d )x
+--R        *
+--R            +---+ +-+
+--R           \|- d \|c
+--R    /
+--R                 2 2         3  2         2          2 2  +---+ +-+
+--R           ((144d e  + 192c d )x  + 768c d e x + 768c d )\|- d \|c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|d x  + e x + c
+--R       + 
+--R                   2 3         3   3            2 2       2 3  2        2 2
+--R             (- 24d e  - 288c d e)x  + (- 432c d e  - 576c d )x  - 1152c d e x
+--R           + 
+--R                   3 2
+--R             - 768c d
+--R        *
+--R            +---+
+--R           \|- d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 505
+
+--S 506 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2 5            4      2     3            2 2      2 2 2
+--R                   18b e  - 36a b d e  - 48b c d e  + 96a b c d e  - 96b c d e
+--R                 + 
+--R                           2 3
+--R                   192a b c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                          5         2       2   4               3
+--R                   18a b e  + (- 36a d + 96b c)e  - 240a b c d e
+--R                 + 
+--R                       2   2       2 2   2           2 2        2 2 3
+--R                   (96a c d  - 384b c d)e  + 672a b c d e + 192a c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                            4          2         2 2  3           2   2
+--R                   96a b c e  + (- 192a c d + 96b c )e  - 576a b c d e
+--R                 + 
+--R                        2 2 2       2 3              3 2
+--R                   (768a c d  - 384b c d)e + 768a b c d
+--R              *
+--R                 x
+--R             + 
+--R                      2 3       2 2   2           3          2 3 2
+--R               96a b c e  - 192a c d e  - 384a b c d e + 768a c d
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|d x  + e x + c
+--R         + 
+--R                   2 6           5      2     4            2 3       2 2 2 2
+--R               - 3b e  + 6a b d e  - 24b c d e  + 48a b c d e  + 144b c d e
+--R             + 
+--R                         2 3
+--R               - 288a b c d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       6      2       2   5              4
+--R               - 3a b e  + (6a d - 54b c)e  + 84a b c d e
+--R             + 
+--R                   2   2       2 2   3           2 2 2
+--R               (48a c d  + 144b c d)e  - 144a b c d e
+--R             + 
+--R                      2 2 3       2 3 2             3 3
+--R               (- 288a c d  + 288b c d )e - 576a b c d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                          5        2          2 2  4           2   3
+--R               - 54a b c e  + (108a c d - 144b c )e  + 432a b c d e
+--R             + 
+--R                      2 2 2       2 3   2           3 2        2 3 3
+--R               (- 288a c d  + 576b c d)e  - 864a b c d e - 576a c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                         2 4        2 2       2 3  3           3   2
+--R               - 144a b c e  + (288a c d - 96b c )e  + 768a b c d e
+--R             + 
+--R                       2 3 2       2 4              4 2
+--R               (- 1152a c d  + 384b c d)e - 768a b c d
+--R          *
+--R             x
+--R         + 
+--R                    3 3       2 3   2           4          2 4 2
+--R           - 96a b c e  + 192a c d e  + 384a b c d e - 768a c d
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|c \|d  - 2d x)\|d x  + e x + c  + (- 2d x  - e x - 2c)\|d
+--R              + 
+--R                     +-+
+--R                2d x\|c
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|c \|d x  + e x + c  - e x - 2c
+--R     + 
+--R                          5          4            3          2 2        2 2
+--R                   - 18b e  + 36a d e  + 48b c d e  - 96a c d e  + 96b c d e
+--R                 + 
+--R                           2 3
+--R                   - 192a c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         4             3         2   2         2 2           2 3
+--R               (- 96b c e  + 192a c d e  + 384b c d e  - 768a c d e)x - 96b c e
+--R             + 
+--R                     2   2         3            3 2
+--R               192a c d e  + 384b c d e - 768a c d
+--R          *
+--R                  +------------------+ +--------------+
+--R              +-+ | 2 2             2  |   2
+--R             \|c \|b x  + 2a b x + a  \|d x  + e x + c
+--R         + 
+--R                       6         5            4          2 3         2 2 2
+--R                   3b e  - 6a d e  + 24b c d e  - 48a c d e  - 144b c d e
+--R                 + 
+--R                         2 3
+--R                   288a c d e
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                          5             4         2   3         2 2 2
+--R                   54b c e  - 108a c d e  - 144b c d e  + 288a c d e
+--R                 + 
+--R                           3 2          3 3
+--R                   - 288b c d e + 576a c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                      2 4         2   3         3   2          3 2           3 3
+--R               (144b c e  - 288a c d e  - 576b c d e  + 1152a c d e)x + 96b c e
+--R             + 
+--R                       3   2         4            4 2
+--R               - 192a c d e  - 384b c d e + 768a c d
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R                     2 3           3   5
+--R               (16b d e  + 192b c d e)x
+--R             + 
+--R                      4        2 3           2 2           3          2 3  4
+--R               (4b d e  + 24a d e  + 336b c d e  + 288a c d e + 384b c d )x
+--R             + 
+--R                         5          4            3           2 2          2 2
+--R                   - 6b e  + 12a d e  + 16b c d e  + 576a c d e  + 1056b c d e
+--R                 + 
+--R                         2 3
+--R                   576a c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                             4             3         2   2          2 2
+--R                   - 108b c e  + 216a c d e  + 336b c d e  + 1440a c d e
+--R                 + 
+--R                         3 2
+--R                   896b c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        2 3         2   2         3            3 2           3 2
+--R               (- 288b c e  + 576a c d e  + 896b c d e + 768a c d )x - 192b c e
+--R             + 
+--R                     3            4
+--R               384a c d e + 512b c d
+--R          *
+--R                  +------------------+
+--R              +-+ | 2 2             2
+--R             \|d \|b x  + 2a b x + a
+--R         + 
+--R                     2 2 3       2   3   6
+--R               (- 16b d e  - 192b c d e)x
+--R             + 
+--R                         2   4          2 3       2   2 2             3
+--R                     - 4b d e  - 40a b d e  - 336b c d e  - 480a b c d e
+--R                   + 
+--R                           2 2 3
+--R                     - 384b c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                     2 5            4         2 2      2     3             2 2
+--R                   6b e  - 16a b d e  + (- 24a d  - 16b c d)e  - 912a b c d e
+--R                 + 
+--R                          2   3        2 2 2             2 3
+--R                   (- 288a c d  - 1056b c d )e - 960a b c d
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         5         2       2   4               3
+--R                   6a b e  + (- 12a d + 72b c)e  - 160a b c d e
+--R                 + 
+--R                          2   2       2 2   2            2 2        2 2 3
+--R                   (- 576a c d  - 288b c d)e  - 2400a b c d e - 576a c d
+--R                 + 
+--R                         2 3 2
+--R                   - 768b c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                            4          2         2 2  3           2   2
+--R                   72a b c e  + (- 144a c d + 96b c )e  - 480a b c d e
+--R                 + 
+--R                           2 2 2       2 3               3 2
+--R                   (- 1344a c d  - 384b c d)e - 1536a b c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                       2 3       2 2   2           3          2 3 2
+--R               (96a b c e  - 192a c d e  - 384a b c d e - 768a c d )x
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|d x  + e x + c
+--R     + 
+--R                   3 2           4  6
+--R           (- 96b d e  - 128b c d )x
+--R         + 
+--R                    2 3         3 2           3            4  5
+--R           (- 120b d e  - 144a d e  - 672b c d e - 192a c d )x
+--R         + 
+--R                   4         2 3           2 2            3          2 3  4
+--R           (12b d e  - 216a d e  - 816b c d e  - 1056a c d e - 768b c d )x
+--R         + 
+--R                    5          4           3            2 2          2 2
+--R               36b e  - 72a d e  - 8b c d e  - 1392a c d e  - 1824b c d e
+--R             + 
+--R                       2 3
+--R               - 960a c d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    4             3         2   2          2 2           3 2  2
+--R           (228b c e  - 456a c d e  - 624b c d e  - 2016a c d e - 1152b c d )x
+--R         + 
+--R                  2 3         2   2          3            3 2           3 2
+--R           (384b c e  - 768a c d e  - 1152b c d e - 768a c d )x + 192b c e
+--R         + 
+--R                   3            4
+--R           - 384a c d e - 512b c d
+--R      *
+--R                  +------------------+
+--R          +-+ +-+ | 2 2             2
+--R         \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R               2 3 2       2   4  7
+--R           (96b d e  + 128b c d )x
+--R         + 
+--R                2 2 3           3 2       2   3              4  6
+--R           (120b d e  + 240a b d e  + 672b c d e + 320a b c d )x
+--R         + 
+--R                    2   4           2 3        2 3       2   2  2
+--R               - 12b d e  + 336a b d e  + (144a d  + 816b c d )e
+--R             + 
+--R                          3        2   4       2 2 3
+--R               1728a b c d e + 192a c d  + 768b c d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    2 5            4        2 2      2     3              2 2
+--R               - 30b e  + 48a b d e  + (216a d  + 64b c d)e  + 2064a b c d e
+--R             + 
+--R                     2   3        2 2 2              2 3
+--R               (1056a c d  + 1632b c d )e + 1728a b c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        5       2        2   4               3
+--R               - 30a b e  + (60a d - 120b c)e  + 304a b c d e
+--R             + 
+--R                   2   2       2 2   2            2 2        2 2 3       2 3 2
+--R             (1248a c d  + 480b c d)e  + 3360a b c d e + 960a c d  + 768b c d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                           4        2         2 2  3           2   2
+--R               - 120a b c e  + (240a c d - 96b c )e  + 672a b c d e
+--R             + 
+--R                     2 2 2       2 3               3 2
+--R               (1728a c d  + 384b c d)e + 1536a b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     2 3       2 2   2           3          2 3 2
+--R           (- 96a b c e  + 192a c d e  + 384a b c d e + 768a c d )x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R  /
+--R                  2 2           3  3          2 2            2            3  2
+--R           (288b d e  + 384b c d )x  + (288a d e  + 1536b c d e + 384a c d )x
+--R         + 
+--R                     2           2 2            2 2
+--R           (1536a c d e + 1536b c d )x + 1536a c d
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|c \|d \|d x  + e x + c
+--R     + 
+--R                   2 3           3   4
+--R           (- 48b d e  - 576b c d e)x
+--R         + 
+--R                   2 3           2 2           3           2 3  3
+--R           (- 48a d e  - 864b c d e  - 576a c d e - 1152b c d )x
+--R         + 
+--R                      2 2          2 2           2 3  2
+--R           (- 864a c d e  - 2304b c d e - 1152a c d )x
+--R         + 
+--R                     2 2           3 2            3 2
+--R           (- 2304a c d e - 1536b c d )x - 1536a c d
+--R      *
+--R          +-+
+--R         \|d
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                               8           2 6          2 3 4          3 4 2
+--R                       - 2b d e  - 224b c d e  - 2240b c d e  - 3584b c d e
+--R                     + 
+--R                               4 5
+--R                       - 512b c d
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                            9         8             7           2 6
+--R                       - b e  - 2a d e  - 400b c d e  - 224a c d e
+--R                     + 
+--R                                2 2 5          2 3 4           3 3 3
+--R                       - 9184b c d e  - 2240a c d e  - 34048b c d e
+--R                     + 
+--R                                3 4 2           4 4          4 5
+--R                       - 3584a c d e  - 18688b c d e - 512a c d
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                            9           8             7           2   6
+--R                       - a e  - 162b c e  - 400a c d e  - 11424b c d e
+--R                     + 
+--R                                2 2 5            3 2 4           3 3 3
+--R                       - 9184a c d e  - 100800b c d e  - 34048a c d e
+--R                     + 
+--R                                  4 3 2           4 4            5 4
+--R                       - 152064b c d e  - 18688a c d e - 20992b c d
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                 8          2 7           2   6            3   5
+--R                       - 162a c e  - 4320b c e  - 11424a c d e  - 115584b c d e
+--R                     + 
+--R                                  3 2 4            4 2 3            4 3 2
+--R                       - 100800a c d e  - 453120b c d e  - 152064a c d e
+--R                     + 
+--R                                  5 3            5 4
+--R                       - 256000b c d e - 20992a c d
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                2 7           3 6            3   5
+--R                       - 4320a c e  - 44352b c e  - 115584a c d e
+--R                     + 
+--R                                  4   4            4 2 3            5 2 2
+--R                       - 549120b c d e  - 453120a c d e  - 957440b c d e
+--R                     + 
+--R                                  5 3             6 3
+--R                       - 256000a c d e - 143360b c d
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                 3 6            4 5            4   4
+--R                       - 44352a c e  - 228096b c e  - 549120a c d e
+--R                     + 
+--R                                   5   3            5 2 2            6 2
+--R                       - 1374208b c d e  - 957440a c d e  - 946176b c d e
+--R                     + 
+--R                                  6 3
+--R                       - 143360a c d
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                  4 5            5 4             5   3
+--R                       - 228096a c e  - 658944b c e  - 1374208a c d e
+--R                     + 
+--R                                   6   2            6 2             7 2
+--R                       - 1863680b c d e  - 946176a c d e - 352256b c d
+--R                  *
+--R                      5
+--R                     x
+--R                 + 
+--R                                  5 4             6 3             6   2
+--R                       - 658944a c e  - 1118208b c e  - 1863680a c d e
+--R                     + 
+--R                                   7               7 2
+--R                       - 1294336b c d e - 352256a c d
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                   6 3             7 2             7
+--R                       - 1118208a c e  - 1105920b c e  - 1294336a c d e
+--R                     + 
+--R                                  8
+--R                       - 360448b c d
+--R                  *
+--R                      3
+--R                     x
+--R                 + 
+--R                                7 2            8             8   2
+--R                   (- 1105920a c e  - 589824b c e - 360448a c d)x
+--R                 + 
+--R                               8             9              9
+--R                   (- 589824a c e - 131072b c )x - 131072a c
+--R              *
+--R                  +-+
+--R                 \|d
+--R             + 
+--R                         2 7           3 5          2 4 3          3 5   11
+--R                   (32b d e  + 896b c d e  + 3584b c d e  + 2048b c d e)x
+--R                 + 
+--R                              8        2 7            2 6           3 5
+--R                       34b d e  + 32a d e  + 2464b c d e  + 896a c d e
+--R                     + 
+--R                               2 3 4          2 4 3           3 4 2
+--R                       21952b c d e  + 3584a c d e  + 33280b c d e
+--R                     + 
+--R                              3 5           4 5
+--R                       2048a c d e + 4608b c d
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                              8              7            2 6           2 2 5
+--R                       34a d e  + 1632b c d e  + 2464a c d e  + 40320b c d e
+--R                     + 
+--R                               2 3 4            3 3 3           3 4 2
+--R                       21952a c d e  + 152064b c d e  + 33280a c d e
+--R                     + 
+--R                               4 4           4 5
+--R                       83968b c d e + 4608a c d
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                  7           2   6           2 2 5
+--R                       1632a c d e  + 22848b c d e  + 40320a c d e
+--R                     + 
+--R                                3 2 4            3 3 3            4 3 2
+--R                       257280b c d e  + 152064a c d e  + 424960b c d e
+--R                     + 
+--R                               4 4            5 4
+--R                       83968a c d e + 61440b c d
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                               2   6            3   5            3 2 4
+--R                       22848a c d e  + 143616b c d e  + 257280a c d e
+--R                     + 
+--R                                4 2 3            4 3 2            5 3
+--R                       788480b c d e  + 424960a c d e  + 512000b c d e
+--R                     + 
+--R                               5 4
+--R                       61440a c d
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                3   5            4   4            4 2 3
+--R                       143616a c d e  + 478720b c d e  + 788480a c d e
+--R                     + 
+--R                                 5 2 2            5 3             6 3
+--R                       1241088b c d e  + 512000a c d e + 221184b c d
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                4   4            5   3             5 2 2
+--R                       478720a c d e  + 905216b c d e  + 1241088a c d e
+--R                     + 
+--R                                6 2             6 3
+--R                       966656b c d e + 221184a c d
+--R                  *
+--R                      5
+--R                     x
+--R                 + 
+--R                                5   3            6   2            6 2
+--R                       905216a c d e  + 974848b c d e  + 966656a c d e
+--R                     + 
+--R                                7 2
+--R                       294912b c d
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                             6   2            7               7 2  3
+--R                   (974848a c d e  + 557056b c d e + 294912a c d )x
+--R                 + 
+--R                             7               8   2            8
+--R                   (557056a c d e + 131072b c d)x  + 131072a c d x
+--R              *
+--R                  +-+
+--R                 \|c
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R         + 
+--R                       2   8       2   2 6        2 2 3 4        2 3 4 2
+--R                     2b d e  + 224b c d e  + 2240b c d e  + 3584b c d e
+--R                   + 
+--R                         2 4 5
+--R                     512b c d
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                    2 9           8       2     7             2 6        2 2 2 5
+--R                   b e  + 4a b d e  + 400b c d e  + 448a b c d e  + 9184b c d e
+--R                 + 
+--R                            2 3 4         2 3 3 3            3 4 2
+--R                   4480a b c d e  + 34048b c d e  + 7168a b c d e
+--R                 + 
+--R                         2 4 4             4 5
+--R                   18688b c d e + 1024a b c d
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                         9      2        2   8               7
+--R                   2a b e  + (2a d + 162b c)e  + 800a b c d e
+--R                 + 
+--R                        2   2         2 2   6             2 2 5
+--R                   (224a c d  + 11424b c d)e  + 18368a b c d e
+--R                 + 
+--R                         2 2 3          2 3 2  4             3 3 3
+--R                   (2240a c d  + 100800b c d )e  + 68096a b c d e
+--R                 + 
+--R                         2 3 4          2 4 3  2             4 4        2 4 5
+--R                   (3584a c d  + 152064b c d )e  + 37376a b c d e + 512a c d
+--R                 + 
+--R                         2 5 4
+--R                   20992b c d
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                    2 9             8        2           2 2  7
+--R                   a e  + 324a b c e  + (400a c d + 4320b c )e
+--R                 + 
+--R                             2   6         2 2 2          2 3   5
+--R                   22848a b c d e  + (9184a c d  + 115584b c d)e
+--R                 + 
+--R                              3 2 4          2 3 3          2 4 2  3
+--R                   201600a b c d e  + (34048a c d  + 453120b c d )e
+--R                 + 
+--R                              4 3 2          2 4 4          2 5 3
+--R                   304128a b c d e  + (18688a c d  + 256000b c d )e
+--R                 + 
+--R                             5 4
+--R                   41984a b c d
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                       2   8            2 7          2 2          2 3  6
+--R                   162a c e  + 8640a b c e  + (11424a c d + 44352b c )e
+--R                 + 
+--R                              3   5           2 3 2          2 4   4
+--R                   231168a b c d e  + (100800a c d  + 549120b c d)e
+--R                 + 
+--R                              4 2 3           2 4 3          2 5 2  2
+--R                   906240a b c d e  + (152064a c d  + 957440b c d )e
+--R                 + 
+--R                              5 3          2 5 4          2 6 3
+--R                   512000a b c d e + 20992a c d  + 143360b c d
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                        2 2 7             3 6           2 3           2 4  5
+--R                   4320a c e  + 88704a b c e  + (115584a c d + 228096b c )e
+--R                 + 
+--R                               4   4           2 4 2           2 5   3
+--R                   1098240a b c d e  + (453120a c d  + 1374208b c d)e
+--R                 + 
+--R                               5 2 2           2 5 3          2 6 2
+--R                   1914880a b c d e  + (256000a c d  + 946176b c d )e
+--R                 + 
+--R                              6 3
+--R                   286720a b c d
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                         2 3 6              4 5           2 4           2 5  4
+--R                   44352a c e  + 456192a b c e  + (549120a c d + 658944b c )e
+--R                 + 
+--R                               5   3           2 5 2           2 6   2
+--R                   2748416a b c d e  + (957440a c d  + 1863680b c d)e
+--R                 + 
+--R                               6 2           2 6 3          2 7 2
+--R                   1892352a b c d e + 143360a c d  + 352256b c d
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          2 4 5               5 4
+--R                   228096a c e  + 1317888a b c e
+--R                 + 
+--R                            2 5            2 6  3               6   2
+--R                   (1374208a c d + 1118208b c )e  + 3727360a b c d e
+--R                 + 
+--R                           2 6 2           2 7                 7 2
+--R                   (946176a c d  + 1294336b c d)e + 704512a b c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                          2 5 4               6 3
+--R                   658944a c e  + 2236416a b c e
+--R                 + 
+--R                            2 6            2 7  2               7
+--R                   (1863680a c d + 1105920b c )e  + 2588672a b c d e
+--R                 + 
+--R                          2 7 2          2 8
+--R                   352256a c d  + 360448b c d
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           2 6 3               7 2
+--R                   1118208a c e  + 2211840a b c e
+--R                 + 
+--R                            2 7           2 8                8
+--R                   (1294336a c d + 589824b c )e + 720896a b c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                        2 7 2               8           2 8           2 9  2
+--R               (1105920a c e  + 1179648a b c e + 360448a c d + 131072b c )x
+--R             + 
+--R                       2 8               9            2 9
+--R               (589824a c e + 262144a b c )x + 131072a c
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                     2 2 7       2   3 5        2 2 4 3        2 3 5   12
+--R               (- 32b d e  - 896b c d e  - 3584b c d e  - 2048b c d e)x
+--R             + 
+--R                        2   8          2 7        2   2 6              3 5
+--R                   - 34b d e  - 64a b d e  - 2464b c d e  - 1792a b c d e
+--R                 + 
+--R                           2 2 3 4            2 4 3         2 3 4 2
+--R                   - 21952b c d e  - 7168a b c d e  - 33280b c d e
+--R                 + 
+--R                              3 5         2 4 5
+--R                   - 4096a b c d e - 4608b c d
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                              8         2 2        2     7              2 6
+--R                   - 68a b d e  + (- 32a d  - 1632b c d)e  - 4928a b c d e
+--R                 + 
+--R                          2   3         2 2 2  5             2 3 4
+--R                   (- 896a c d  - 40320b c d )e  - 43904a b c d e
+--R                 + 
+--R                           2 2 4          2 3 3  3             3 4 2
+--R                   (- 3584a c d  - 152064b c d )e  - 66560a b c d e
+--R                 + 
+--R                           2 3 5         2 4 4              4 5
+--R                   (- 2048a c d  - 83968b c d )e - 9216a b c d
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                        2   8                7           2   2         2 2   6
+--R                   - 34a d e  - 3264a b c d e  + (- 2464a c d  - 22848b c d)e
+--R                 + 
+--R                               2 2 5            2 2 3          2 3 2  4
+--R                   - 80640a b c d e  + (- 21952a c d  - 257280b c d )e
+--R                 + 
+--R                                3 3 3            2 3 4          2 4 3  2
+--R                   - 304128a b c d e  + (- 33280a c d  - 424960b c d )e
+--R                 + 
+--R                                4 4         2 4 5         2 5 4
+--R                   - 167936a b c d e - 4608a c d  - 61440b c d
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                          2     7             2   6
+--R                   - 1632a c d e  - 45696a b c d e
+--R                 + 
+--R                            2 2 2          2 3   5              3 2 4
+--R                   (- 40320a c d  - 143616b c d)e  - 514560a b c d e
+--R                 + 
+--R                             2 3 3          2 4 2  3              4 3 2
+--R                   (- 152064a c d  - 788480b c d )e  - 849920a b c d e
+--R                 + 
+--R                            2 4 4          2 5 3                5 4
+--R                   (- 83968a c d  - 512000b c d )e - 122880a b c d
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           2 2   6              3   5
+--R                   - 22848a c d e  - 287232a b c d e
+--R                 + 
+--R                             2 3 2          2 4   4               4 2 3
+--R                   (- 257280a c d  - 478720b c d)e  - 1576960a b c d e
+--R                 + 
+--R                             2 4 3           2 5 2  2               5 3
+--R                   (- 424960a c d  - 1241088b c d )e  - 1024000a b c d e
+--R                 + 
+--R                           2 5 4          2 6 3
+--R                   - 61440a c d  - 221184b c d
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            2 3   5              4   4
+--R                   - 143616a c d e  - 957440a b c d e
+--R                 + 
+--R                             2 4 2          2 5   3               5 2 2
+--R                   (- 788480a c d  - 905216b c d)e  - 2482176a b c d e
+--R                 + 
+--R                             2 5 3          2 6 2                6 3
+--R                   (- 512000a c d  - 966656b c d )e - 442368a b c d
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            2 4   4               5   3
+--R                   - 478720a c d e  - 1810432a b c d e
+--R                 + 
+--R                              2 5 2          2 6   2               6 2
+--R                   (- 1241088a c d  - 974848b c d)e  - 1933312a b c d e
+--R                 + 
+--R                            2 6 3          2 7 2
+--R                   - 221184a c d  - 294912b c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                            2 5   3               6   2
+--R                   - 905216a c d e  - 1949696a b c d e
+--R                 + 
+--R                             2 6 2          2 7                 7 2
+--R                   (- 966656a c d  - 557056b c d)e - 589824a b c d
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            2 6   2               7             2 7 2
+--R                   - 974848a c d e  - 1114112a b c d e - 294912a c d
+--R                 + 
+--R                            2 8
+--R                   - 131072b c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                         2 7                 8   2          2 8
+--R               (- 557056a c d e - 262144a b c d)x  - 131072a c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|d x  + e x + c
+--R     + 
+--R                     2 7           3 5          2 4 3          3 5   12
+--R               (32b d e  + 896b c d e  + 3584b c d e  + 2048b c d e)x
+--R             + 
+--R                          8        2 7            2 6           3 5
+--R                   50b d e  + 32a d e  + 2912b c d e  + 896a c d e
+--R                 + 
+--R                           2 3 4          2 4 3           3 4 2          3 5
+--R                   23744b c d e  + 3584a c d e  + 34304b c d e  + 2048a c d e
+--R                 + 
+--R                          4 5
+--R                   4608b c d
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                        9          8              7            2 6
+--R                   18b e  + 50a d e  + 3008b c d e  + 2912a c d e
+--R                 + 
+--R                           2 2 5           2 3 4            3 3 3
+--R                   53312b c d e  + 23744a c d e  + 174080b c d e
+--R                 + 
+--R                           3 4 2           4 4           4 5
+--R                   34304a c d e  + 88576b c d e + 4608a c d
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                        9           8              7           2   6
+--R                   18a e  + 978b c e  + 3008a c d e  + 49056b c d e
+--R                 + 
+--R                           2 2 5            3 2 4            3 3 3
+--R                   53312a c d e  + 369600b c d e  + 174080a c d e
+--R                 + 
+--R                            4 3 2           4 4            5 4
+--R                   508416b c d e  + 88576a c d e + 66048b c d
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                           8           2 7           2   6            3   5
+--R                   978a c e  + 15744b c e  + 49056a c d e  + 344832b c d e
+--R                 + 
+--R                            3 2 4             4 2 3            4 3 2
+--R                   369600a c d e  + 1208320b c d e  + 508416a c d e
+--R                 + 
+--R                            5 3            5 4
+--R                   634880b c d e + 66048a c d
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           2 7            3 6            3   5             4   4
+--R                   15744a c e  + 116160b c e  + 344832a c d e  + 1253120b c d e
+--R                 + 
+--R                             4 2 3             5 2 2            5 3
+--R                   1208320a c d e  + 2003968b c d e  + 634880a c d e
+--R                 + 
+--R                            6 3
+--R                   282624b c d
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            3 6            4 5             4   4
+--R                   116160a c e  + 467456b c e  + 1253120a c d e
+--R                 + 
+--R                             5   3             5 2 2             6 2
+--R                   2539520b c d e  + 2003968a c d e  + 1630208b c d e
+--R                 + 
+--R                            6 3
+--R                   282624a c d
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            4 5             5 4             5   3
+--R                   467456a c e  + 1111552b c e  + 2539520a c d e
+--R                 + 
+--R                             6   2             6 2             7 2
+--R                   2895872b c d e  + 1630208a c d e + 516096b c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             5 4             6 3             6   2
+--R                   1111552a c e  + 1605632b c e  + 2895872a c d e
+--R                 + 
+--R                             7               7 2
+--R                   1736704b c d e + 516096a c d
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          6 3             7 2             7               8   3
+--R               (1605632a c e  + 1384448b c e  + 1736704a c d e + 425984b c d)x
+--R             + 
+--R                          7 2            8             8   2
+--R               (1384448a c e  + 655360b c e + 425984a c d)x
+--R             + 
+--R                         8             9              9
+--R               (655360a c e + 131072b c )x + 131072a c
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R                    2 8           3 6          2 4 4          3 5 2         4 6
+--R             (- 2b d e  - 224b c d e  - 2240b c d e  - 3584b c d e  - 512b c d )
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                       9       2 8           2 7           3 6           2 3 5
+--R               - 2b d e  - 2a d e  - 512b c d e  - 224a c d e  - 10304b c d e
+--R             + 
+--R                        2 4 4           3 4 3          3 5 2           4 5
+--R               - 2240a c d e  - 35840b c d e  - 3584a c d e  - 18944b c d e
+--R             + 
+--R                       4 6
+--R               - 512a c d
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                       9             8           2 7           2 2 6
+--R               - 2a d e  - 290b c d e  - 512a c d e  - 15008b c d e
+--R             + 
+--R                         2 3 5            3 3 4           3 4 3            4 4 2
+--R               - 10304a c d e  - 115136b c d e  - 35840a c d e  - 160256b c d e
+--R             + 
+--R                         4 5            5 5
+--R               - 18944a c d e - 20992b c d
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                           8          2   7           2 2 6            3 2 5
+--R               - 290a c d e  - 7008b c d e  - 15008a c d e  - 147840b c d e
+--R             + 
+--R                          3 3 4            4 3 3            4 4 2
+--R               - 115136a c d e  - 508416b c d e  - 160256a c d e
+--R             + 
+--R                          5 4            5 5
+--R               - 264192b c d e - 20992a c d
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                        2   7           3   6            3 2 5            4 2 4
+--R               - 7008a c d e  - 65856b c d e  - 147840a c d e  - 672000b c d e
+--R             + 
+--R                        4 3 3             5 3 2            5 4             6 4
+--R             - 508416a c d e  - 1039360b c d e  - 264192a c d e - 143360b c d
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         3   6            4   5            4 2 4
+--R               - 65856a c d e  - 312576b c d e  - 672000a c d e
+--R             + 
+--R                         5 2 3             5 3 2            6 3             6 4
+--R             - 1599488b c d e  - 1039360a c d e  - 987136b c d e - 143360a c d
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                          4   5            5   4             5 2 3
+--R               - 312576a c d e  - 839168b c d e  - 1599488a c d e
+--R             + 
+--R                           6 2 2            6 3             7 3
+--R               - 2060288b c d e  - 987136a c d e - 352256b c d
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          5   4             6   3             6 2 2
+--R               - 839168a c d e  - 1331200b c d e  - 2060288a c d e
+--R             + 
+--R                           7 2             7 3
+--R               - 1359872b c d e - 352256a c d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                             6   3             7   2             7 2
+--R                 - 1331200a c d e  - 1236992b c d e  - 1359872a c d e
+--R               + 
+--R                            8 2
+--R                 - 360448b c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        7   2            8               8 2  3
+--R           (- 1236992a c d e  - 622592b c d e - 360448a c d )x
+--R         + 
+--R                       8               9   2            9
+--R           (- 622592a c d e - 131072b c d)x  - 131072a c d x
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R                 2 2 7       2   3 5        2 2 4 3        2 3 5   13
+--R           (- 32b d e  - 896b c d e  - 3584b c d e  - 2048b c d e)x
+--R         + 
+--R                    2   8          2 7        2   2 6              3 5
+--R               - 50b d e  - 64a b d e  - 2912b c d e  - 1792a b c d e
+--R             + 
+--R                       2 2 3 4            2 4 3         2 3 4 2            3 5
+--R               - 23744b c d e  - 7168a b c d e  - 34304b c d e  - 4096a b c d e
+--R             + 
+--R                      2 4 5
+--R               - 4608b c d
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                    2 9             8         2 2        2     7
+--R               - 18b e  - 100a b d e  + (- 32a d  - 3008b c d)e
+--R             + 
+--R                            2 6          2   3         2 2 2  5
+--R               - 5824a b c d e  + (- 896a c d  - 53312b c d )e
+--R             + 
+--R                           2 3 4           2 2 4          2 3 3  3
+--R               - 47488a b c d e  + (- 3584a c d  - 174080b c d )e
+--R             + 
+--R                           3 4 2           2 3 5         2 4 4              4 5
+--R               - 68608a b c d e  + (- 2048a c d  - 88576b c d )e - 9216a b c d
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        9         2        2   8                7
+--R               - 36a b e  + (- 50a d - 978b c)e  - 6016a b c d e
+--R             + 
+--R                       2   2         2 2   6              2 2 5
+--R               (- 2912a c d  - 49056b c d)e  - 106624a b c d e
+--R             + 
+--R                        2 2 3          2 3 2  4              3 3 3
+--R               (- 23744a c d  - 369600b c d )e  - 348160a b c d e
+--R             + 
+--R                        2 3 4          2 4 3  2              4 4         2 4 5
+--R               (- 34304a c d  - 508416b c d )e  - 177152a b c d e - 4608a c d
+--R             + 
+--R                       2 5 4
+--R               - 66048b c d
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                    2 9              8           2            2 2  7
+--R               - 18a e  - 1956a b c e  + (- 3008a c d - 15744b c )e
+--R             + 
+--R                           2   6            2 2 2          2 3   5
+--R               - 98112a b c d e  + (- 53312a c d  - 344832b c d)e
+--R             + 
+--R                            3 2 4             2 3 3           2 4 2  3
+--R               - 739200a b c d e  + (- 174080a c d  - 1208320b c d )e
+--R             + 
+--R                             4 3 2            2 4 4          2 5 3
+--R               - 1016832a b c d e  + (- 88576a c d  - 634880b c d )e
+--R             + 
+--R                            5 4
+--R               - 132096a b c d
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                     2   8             2 7            2 2           2 3  6
+--R               - 978a c e  - 31488a b c e  + (- 49056a c d - 116160b c )e
+--R             + 
+--R                            3   5             2 3 2           2 4   4
+--R               - 689664a b c d e  + (- 369600a c d  - 1253120b c d)e
+--R             + 
+--R                             4 2 3             2 4 3           2 5 2  2
+--R               - 2416640a b c d e  + (- 508416a c d  - 2003968b c d )e
+--R             + 
+--R                             5 3          2 5 4          2 6 3
+--R               - 1269760a b c d e - 66048a c d  - 282624b c d
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                       2 2 7              3 6             2 3           2 4  5
+--R               - 15744a c e  - 232320a b c e  + (- 344832a c d - 467456b c )e
+--R             + 
+--R                             4   4              2 4 2           2 5   3
+--R               - 2506240a b c d e  + (- 1208320a c d  - 2539520b c d)e
+--R             + 
+--R                             5 2 2             2 5 3           2 6 2
+--R               - 4007936a b c d e  + (- 634880a c d  - 1630208b c d )e
+--R             + 
+--R                            6 3
+--R               - 565248a b c d
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                        2 3 6              4 5
+--R               - 116160a c e  - 934912a b c e
+--R             + 
+--R                          2 4            2 5  4               5   3
+--R               (- 1253120a c d - 1111552b c )e  - 5079040a b c d e
+--R             + 
+--R                          2 5 2           2 6   2               6 2
+--R               (- 2003968a c d  - 2895872b c d)e  - 3260416a b c d e
+--R             + 
+--R                        2 6 3          2 7 2
+--R               - 282624a c d  - 516096b c d
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        2 4 5               5 4
+--R               - 467456a c e  - 2223104a b c e
+--R             + 
+--R                          2 5            2 6  3               6   2
+--R               (- 2539520a c d - 1605632b c )e  - 5791744a b c d e
+--R             + 
+--R                          2 6 2           2 7                  7 2
+--R               (- 1630208a c d  - 1736704b c d)e - 1032192a b c d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                         2 5 4               6 3
+--R               - 1111552a c e  - 3211264a b c e
+--R             + 
+--R                          2 6            2 7  2               7
+--R               (- 2895872a c d - 1384448b c )e  - 3473408a b c d e
+--R             + 
+--R                        2 7 2          2 8
+--R               - 516096a c d  - 425984b c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                         2 6 3               7 2
+--R               - 1605632a c e  - 2768896a b c e
+--R             + 
+--R                          2 7           2 8                8
+--R               (- 1736704a c d - 655360b c )e - 851968a b c d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      2 7 2               8           2 8           2 9  2
+--R           (- 1384448a c e  - 1310720a b c e - 425984a c d - 131072b c )x
+--R         + 
+--R                     2 8               9            2 9
+--R           (- 655360a c e - 262144a b c )x - 131072a c
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R     + 
+--R          2 2 8       2   3 6        2 2 4 4        2 3 5 2       2 4 6  13
+--R       (2b d e  + 224b c d e  + 2240b c d e  + 3584b c d e  + 512b c d )x
+--R     + 
+--R             2   9         2 8       2   2 7             3 6         2 2 3 5
+--R           2b d e  + 4a b d e  + 512b c d e  + 448a b c d e  + 10304b c d e
+--R         + 
+--R                    2 4 4         2 3 4 3            3 5 2         2 4 5
+--R           4480a b c d e  + 35840b c d e  + 7168a b c d e  + 18944b c d e
+--R         + 
+--R                    4 6
+--R           1024a b c d
+--R      *
+--R          12
+--R         x
+--R     + 
+--R                   9      2 2       2     8              2 7
+--R           4a b d e  + (2a d  + 290b c d)e  + 1024a b c d e
+--R         + 
+--R                2   3         2 2 2  6             2 3 5
+--R           (224a c d  + 15008b c d )e  + 20608a b c d e
+--R         + 
+--R                 2 2 4          2 3 3  4             3 4 3
+--R           (2240a c d  + 115136b c d )e  + 71680a b c d e
+--R         + 
+--R                 2 3 5          2 4 4  2             4 5        2 4 6
+--R           (3584a c d  + 160256b c d )e  + 37888a b c d e + 512a c d
+--R         + 
+--R                 2 5 5
+--R           20992b c d
+--R      *
+--R          11
+--R         x
+--R     + 
+--R             2   9               8        2   2        2 2   7             2 2 6
+--R           2a d e  + 580a b c d e  + (512a c d  + 7008b c d)e  + 30016a b c d e
+--R         + 
+--R                  2 2 3          2 3 2  5              3 3 4
+--R           (10304a c d  + 147840b c d )e  + 230272a b c d e
+--R         + 
+--R                  2 3 4          2 4 3  3              4 4 2
+--R           (35840a c d  + 508416b c d )e  + 320512a b c d e
+--R         + 
+--R                  2 4 5          2 5 4               5 5
+--R           (18944a c d  + 264192b c d )e + 41984a b c d
+--R      *
+--R          10
+--R         x
+--R     + 
+--R               2     8             2   7          2 2 2         2 3   6
+--R           290a c d e  + 14016a b c d e  + (15008a c d  + 65856b c d)e
+--R         + 
+--R                      3 2 5           2 3 3          2 4 2  4
+--R           295680a b c d e  + (115136a c d  + 672000b c d )e
+--R         + 
+--R                       4 3 3           2 4 4           2 5 3  2
+--R           1016832a b c d e  + (160256a c d  + 1039360b c d )e
+--R         + 
+--R                      5 4          2 5 5          2 6 4
+--R           528384a b c d e + 20992a c d  + 143360b c d
+--R      *
+--R          9
+--R         x
+--R     + 
+--R                2 2   7              3   6           2 3 2          2 4   5
+--R           7008a c d e  + 131712a b c d e  + (147840a c d  + 312576b c d)e
+--R         + 
+--R                       4 2 4           2 4 3           2 5 2  3
+--R           1344000a b c d e  + (508416a c d  + 1599488b c d )e
+--R         + 
+--R                       5 3 2           2 5 4          2 6 3                6 4
+--R           2078720a b c d e  + (264192a c d  + 987136b c d )e + 286720a b c d
+--R      *
+--R          8
+--R         x
+--R     + 
+--R                 2 3   6              4   5           2 4 2          2 5   4
+--R           65856a c d e  + 625152a b c d e  + (672000a c d  + 839168b c d)e
+--R         + 
+--R                       5 2 3            2 5 3           2 6 2  2
+--R           3198976a b c d e  + (1039360a c d  + 2060288b c d )e
+--R         + 
+--R                       6 3           2 6 4          2 7 3
+--R           1974272a b c d e + 143360a c d  + 352256b c d
+--R      *
+--R          7
+--R         x
+--R     + 
+--R                  2 4   5               5   4            2 5 2           2 6   3
+--R           312576a c d e  + 1678336a b c d e  + (1599488a c d  + 1331200b c d)e
+--R         + 
+--R                       6 2 2           2 6 3           2 7 2                7 3
+--R           4120576a b c d e  + (987136a c d  + 1359872b c d )e + 704512a b c d
+--R      *
+--R          6
+--R         x
+--R     + 
+--R                  2 5   4               6   3            2 6 2           2 7   2
+--R           839168a c d e  + 2662400a b c d e  + (2060288a c d  + 1236992b c d)e
+--R         + 
+--R                       7 2           2 7 3          2 8 2
+--R           2719744a b c d e + 352256a c d  + 360448b c d
+--R      *
+--R          5
+--R         x
+--R     + 
+--R                   2 6   3               7   2            2 7 2          2 8
+--R           1331200a c d e  + 2473984a b c d e  + (1359872a c d  + 622592b c d)e
+--R         + 
+--R                      8 2
+--R           720896a b c d
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                2 7   2               8             2 8 2          2 9   3
+--R       (1236992a c d e  + 1245184a b c d e + 360448a c d  + 131072b c d)x
+--R     + 
+--R               2 8                 9   2          2 9
+--R       (622592a c d e + 262144a b c d)x  + 131072a c d x
+--R  /
+--R                     7         2 5        2 3 3        3 4   9
+--R               (32d e  + 896c d e  + 3584c d e  + 2048c d e)x
+--R             + 
+--R                   8            6         2 2 4         3 3 2        4 4  8
+--R               (18e  + 2016c d e  + 20160c d e  + 32256c d e  + 4608c d )x
+--R             + 
+--R                      7         2   5          3 2 3         4 3   7
+--R               (960c e  + 32256c d e  + 138240c d e  + 81920c d e)x
+--R             + 
+--R                      2 6          3   4          4 2 2         5 3  6
+--R               (14784c e  + 211200c d e  + 394240c d e  + 61440c d )x
+--R             + 
+--R                       3 5          4   3          5 2   5
+--R               (101376c e  + 675840c d e  + 491520c d e)x
+--R             + 
+--R                       4 4           5   2          6 2  4
+--R               (366080c e  + 1118208c d e  + 221184c d )x
+--R             + 
+--R                       5 3          6     3           6 2          7   2
+--R               (745472c e  + 917504c d e)x  + (860160c e  + 294912c d)x
+--R             + 
+--R                      7             8
+--R               524288c e x + 131072c
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R                  8         2 6        2 3 4        3 4 2       4 5  9
+--R           (- 2d e  - 224c d e  - 2240c d e  - 3584c d e  - 512c d )x
+--R         + 
+--R                      7        2 2 5         3 3 3         4 4   8
+--R           (- 288c d e  - 8064c d e  - 32256c d e  - 18432c d e)x
+--R         + 
+--R                   2   6         3 2 4          4 3 2         5 4  7
+--R           (- 6720c d e  - 80640c d e  - 138240c d e  - 20480c d )x
+--R         + 
+--R                    3   5          4 2 3          5 3   6
+--R           (- 59136c d e  - 337920c d e  - 225280c d e)x
+--R         + 
+--R                     4   4          5 2 2          6 3  5
+--R           (- 253440c d e  - 675840c d e  - 122880c d )x
+--R         + 
+--R                     5   3          6 2   4             6   2          7 2  3
+--R           (- 585728c d e  - 638976c d e)x  + (- 745472c d e  - 229376c d )x
+--R         + 
+--R                    7     2          8
+--R           - 491520c d e x  - 131072c d x
+--R      *
+--R          +------------------+ +--------------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + e x + c
+--R     + 
+--R                      8         2 6        2 3 4        3 4 2       4 5  10
+--R               (- 2d e  - 224c d e  - 2240c d e  - 3584c d e  - 512c d )x
+--R             + 
+--R                   9           7        2 2 5         3 3 3         4 4   9
+--R               (- e  - 400c d e  - 9184c d e  - 34048c d e  - 18688c d e)x
+--R             + 
+--R                           8         2   6          3 2 4          4 3 2
+--R                   - 162c e  - 11424c d e  - 100800c d e  - 152064c d e
+--R                 + 
+--R                           5 4
+--R                   - 20992c d
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                       2 7          3   5          4 2 3          5 3   7
+--R               (- 4320c e  - 115584c d e  - 453120c d e  - 256000c d e)x
+--R             + 
+--R                        3 6          4   4          5 2 2          6 3  6
+--R               (- 44352c e  - 549120c d e  - 957440c d e  - 143360c d )x
+--R             + 
+--R                         4 5           5   3          6 2   5
+--R               (- 228096c e  - 1374208c d e  - 946176c d e)x
+--R             + 
+--R                         5 4           6   2          7 2  4
+--R               (- 658944c e  - 1863680c d e  - 352256c d )x
+--R             + 
+--R                          6 3           7     3              7 2          8   2
+--R               (- 1118208c e  - 1294336c d e)x  + (- 1105920c e  - 360448c d)x
+--R             + 
+--R                        8             9
+--R               - 589824c e x - 131072c
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                   2 7         3 5        2 4 3        3 5   10
+--R               (32d e  + 896c d e  + 3584c d e  + 2048c d e)x
+--R             + 
+--R                     8          2 6         2 3 4         3 4 2        4 5  9
+--R               (34d e  + 2464c d e  + 21952c d e  + 33280c d e  + 4608c d )x
+--R             + 
+--R                         7         2 2 5          3 3 3         4 4   8
+--R               (1632c d e  + 40320c d e  + 152064c d e  + 83968c d e)x
+--R             + 
+--R                      2   6          3 2 4          4 3 2         5 4  7
+--R               (22848c d e  + 257280c d e  + 424960c d e  + 61440c d )x
+--R             + 
+--R                       3   5          4 2 3          5 3   6
+--R               (143616c d e  + 788480c d e  + 512000c d e)x
+--R             + 
+--R                       4   4           5 2 2          6 3  5
+--R               (478720c d e  + 1241088c d e  + 221184c d )x
+--R             + 
+--R                       5   3          6 2   4           6   2          7 2  3
+--R               (905216c d e  + 966656c d e)x  + (974848c d e  + 294912c d )x
+--R             + 
+--R                      7     2          8
+--R               557056c d e x  + 131072c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          5          4            3          2 2        2 2
+--R                   - 18b e  + 36a d e  + 48b c d e  - 96a c d e  + 96b c d e
+--R                 + 
+--R                           2 3
+--R                   - 192a c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         4             3         2   2         2 2           2 3
+--R               (- 96b c e  + 192a c d e  + 384b c d e  - 768a c d e)x - 96b c e
+--R             + 
+--R                     2   2         3            3 2
+--R               192a c d e  + 384b c d e - 768a c d
+--R          *
+--R                        +------------------+ +--------------+
+--R              +---+ +-+ | 2 2             2  |   2
+--R             \|- d \|c \|b x  + 2a b x + a  \|d x  + e x + c
+--R         + 
+--R                       6         5            4          2 3         2 2 2
+--R                   3b e  - 6a d e  + 24b c d e  - 48a c d e  - 144b c d e
+--R                 + 
+--R                         2 3
+--R                   288a c d e
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                          5             4         2   3         2 2 2
+--R                   54b c e  - 108a c d e  - 144b c d e  + 288a c d e
+--R                 + 
+--R                           3 2          3 3
+--R                   - 288b c d e + 576a c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                      2 4         2   3         3   2          3 2           3 3
+--R               (144b c e  - 288a c d e  - 576b c d e  + 1152a c d e)x + 96b c e
+--R             + 
+--R                       3   2         4            4 2
+--R               - 192a c d e  - 384b c d e + 768a c d
+--R          *
+--R                    +------------------+
+--R              +---+ | 2 2             2
+--R             \|- d \|b x  + 2a b x + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R                      2 5            4      2     3             2 2       2 2 2
+--R                   36b e  - 72a b d e  - 96b c d e  + 192a b c d e  - 192b c d e
+--R                 + 
+--R                           2 3
+--R                   384a b c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                          5         2        2   4               3
+--R                   36a b e  + (- 72a d + 192b c)e  - 480a b c d e
+--R                 + 
+--R                        2   2       2 2   2            2 2        2 2 3
+--R                   (192a c d  - 768b c d)e  + 1344a b c d e + 384a c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                             4          2          2 2  3            2   2
+--R                   192a b c e  + (- 384a c d + 192b c )e  - 1152a b c d e
+--R                 + 
+--R                         2 2 2       2 3               3 2
+--R                   (1536a c d  - 768b c d)e + 1536a b c d
+--R              *
+--R                 x
+--R             + 
+--R                       2 3       2 2   2           3           2 3 2
+--R               192a b c e  - 384a c d e  - 768a b c d e + 1536a c d
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|c \|d \|d x  + e x + c
+--R         + 
+--R                       2 6            5      2     4            2 3
+--R                   - 6b e  + 12a b d e  - 48b c d e  + 96a b c d e
+--R                 + 
+--R                       2 2 2 2           2 3
+--R                   288b c d e  - 576a b c d e
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           6       2        2   5               4
+--R                   - 6a b e  + (12a d - 108b c)e  + 168a b c d e
+--R                 + 
+--R                       2   2       2 2   3           2 2 2
+--R                   (96a c d  + 288b c d)e  - 288a b c d e
+--R                 + 
+--R                          2 2 3       2 3 2              3 3
+--R                   (- 576a c d  + 576b c d )e - 1152a b c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                               5        2          2 2  4           2   3
+--R                   - 108a b c e  + (216a c d - 288b c )e  + 864a b c d e
+--R                 + 
+--R                          2 2 2        2 3   2            3 2         2 3 3
+--R                   (- 576a c d  + 1152b c d)e  - 1728a b c d e - 1152a c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                             2 4        2 2        2 3  3            3   2
+--R                   - 288a b c e  + (576a c d - 192b c )e  + 1536a b c d e
+--R                 + 
+--R                           2 3 2       2 4               4 2
+--R                   (- 2304a c d  + 768b c d)e - 1536a b c d
+--R              *
+--R                 x
+--R             + 
+--R                         3 3       2 3   2           4           2 4 2
+--R               - 192a b c e  + 384a c d e  + 768a b c d e - 1536a c d
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- d \|d x  + e x + c  - \|- d \|c
+--R         atan(------------------------------------)
+--R                               d x
+--R     + 
+--R                     2 3           3   5
+--R               (16b d e  + 192b c d e)x
+--R             + 
+--R                      4        2 3           2 2           3          2 3  4
+--R               (4b d e  + 24a d e  + 336b c d e  + 288a c d e + 384b c d )x
+--R             + 
+--R                         5          4            3           2 2          2 2
+--R                   - 6b e  + 12a d e  + 16b c d e  + 576a c d e  + 1056b c d e
+--R                 + 
+--R                         2 3
+--R                   576a c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                             4             3         2   2          2 2
+--R                   - 108b c e  + 216a c d e  + 336b c d e  + 1440a c d e
+--R                 + 
+--R                         3 2
+--R                   896b c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        2 3         2   2         3            3 2           3 2
+--R               (- 288b c e  + 576a c d e  + 896b c d e + 768a c d )x - 192b c e
+--R             + 
+--R                     3            4
+--R               384a c d e + 512b c d
+--R          *
+--R                        +------------------+
+--R              +---+ +-+ | 2 2             2
+--R             \|- d \|d \|b x  + 2a b x + a
+--R         + 
+--R                     2 2 3       2   3   6
+--R               (- 16b d e  - 192b c d e)x
+--R             + 
+--R                         2   4          2 3       2   2 2             3
+--R                     - 4b d e  - 40a b d e  - 336b c d e  - 480a b c d e
+--R                   + 
+--R                           2 2 3
+--R                     - 384b c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                     2 5            4         2 2      2     3             2 2
+--R                   6b e  - 16a b d e  + (- 24a d  - 16b c d)e  - 912a b c d e
+--R                 + 
+--R                          2   3        2 2 2             2 3
+--R                   (- 288a c d  - 1056b c d )e - 960a b c d
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         5         2       2   4               3
+--R                   6a b e  + (- 12a d + 72b c)e  - 160a b c d e
+--R                 + 
+--R                          2   2       2 2   2            2 2        2 2 3
+--R                   (- 576a c d  - 288b c d)e  - 2400a b c d e - 576a c d
+--R                 + 
+--R                         2 3 2
+--R                   - 768b c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                            4          2         2 2  3           2   2
+--R                   72a b c e  + (- 144a c d + 96b c )e  - 480a b c d e
+--R                 + 
+--R                           2 2 2       2 3               3 2
+--R                   (- 1344a c d  - 384b c d)e - 1536a b c d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                       2 3       2 2   2           3          2 3 2
+--R               (96a b c e  - 192a c d e  - 384a b c d e - 768a c d )x
+--R          *
+--R              +---+ +-+
+--R             \|- d \|d
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|d x  + e x + c
+--R     + 
+--R                   3 2           4  6
+--R           (- 96b d e  - 128b c d )x
+--R         + 
+--R                    2 3         3 2           3            4  5
+--R           (- 120b d e  - 144a d e  - 672b c d e - 192a c d )x
+--R         + 
+--R                   4         2 3           2 2            3          2 3  4
+--R           (12b d e  - 216a d e  - 816b c d e  - 1056a c d e - 768b c d )x
+--R         + 
+--R                    5          4           3            2 2          2 2
+--R               36b e  - 72a d e  - 8b c d e  - 1392a c d e  - 1824b c d e
+--R             + 
+--R                       2 3
+--R               - 960a c d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    4             3         2   2          2 2           3 2  2
+--R           (228b c e  - 456a c d e  - 624b c d e  - 2016a c d e - 1152b c d )x
+--R         + 
+--R                  2 3         2   2          3            3 2           3 2
+--R           (384b c e  - 768a c d e  - 1152b c d e - 768a c d )x + 192b c e
+--R         + 
+--R                   3            4
+--R           - 384a c d e - 512b c d
+--R      *
+--R                        +------------------+
+--R          +---+ +-+ +-+ | 2 2             2
+--R         \|- d \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R               2 3 2       2   4  7
+--R           (96b d e  + 128b c d )x
+--R         + 
+--R                2 2 3           3 2       2   3              4  6
+--R           (120b d e  + 240a b d e  + 672b c d e + 320a b c d )x
+--R         + 
+--R                    2   4           2 3        2 3       2   2  2
+--R               - 12b d e  + 336a b d e  + (144a d  + 816b c d )e
+--R             + 
+--R                          3        2   4       2 2 3
+--R               1728a b c d e + 192a c d  + 768b c d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    2 5            4        2 2      2     3              2 2
+--R               - 30b e  + 48a b d e  + (216a d  + 64b c d)e  + 2064a b c d e
+--R             + 
+--R                     2   3        2 2 2              2 3
+--R               (1056a c d  + 1632b c d )e + 1728a b c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        5       2        2   4               3
+--R               - 30a b e  + (60a d - 120b c)e  + 304a b c d e
+--R             + 
+--R                   2   2       2 2   2            2 2        2 2 3       2 3 2
+--R             (1248a c d  + 480b c d)e  + 3360a b c d e + 960a c d  + 768b c d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                           4        2         2 2  3           2   2
+--R               - 120a b c e  + (240a c d - 96b c )e  + 672a b c d e
+--R             + 
+--R                     2 2 2       2 3               3 2
+--R               (1728a c d  + 384b c d)e + 1536a b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     2 3       2 2   2           3          2 3 2
+--R           (- 96a b c e  + 192a c d e  + 384a b c d e + 768a c d )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- d \|c \|d
+--R  /
+--R                  2 2           3  3          2 2            2            3  2
+--R           (288b d e  + 384b c d )x  + (288a d e  + 1536b c d e + 384a c d )x
+--R         + 
+--R                     2           2 2            2 2
+--R           (1536a c d e + 1536b c d )x + 1536a c d
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- d \|c \|d \|d x  + e x + c
+--R     + 
+--R                   2 3           3   4
+--R           (- 48b d e  - 576b c d e)x
+--R         + 
+--R                   2 3           2 2           3           2 3  3
+--R           (- 48a d e  - 864b c d e  - 576a c d e - 1152b c d )x
+--R         + 
+--R                      2 2          2 2           2 3  2
+--R           (- 864a c d e  - 2304b c d e - 1152a c d )x
+--R         + 
+--R                     2 2           3 2            3 2
+--R           (- 2304a c d e - 1536b c d )x - 1536a c d
+--R      *
+--R          +---+ +-+
+--R         \|- d \|d
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                                     +------------------+
+--R             3               2                       | 2 2             2
+--R       (b d x  + (b e + a d)x  + (a e + b c)x + a c)\|b x  + 2a b x + a
+--R     + 
+--R          2   4       2            3                2     2   2
+--R       - b d x  + (- b e - 2a b d)x  + (- 2a b e - a d - b c)x
+--R     + 
+--R           2                2
+--R       (- a e - 2a b c)x - a c
+--R  /
+--R      +------------------+ +--------------+
+--R      | 2 2             2  |   2
+--R     \|b x  + 2a b x + a  \|d x  + e x + c
+--R                                                    Type: Expression(Integer)
+--E 509
+
+)clear all
+
+--S 510 of 556
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/x
+--R 
+--R
+--R         +------------------+ +--------------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + e x + c
+--R   (1)  --------------------------------------
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 510
+
+--S 511 of 556
+r0:=1/8*(4*b*c*d+4*a*d*e-b*e^2)*atanh(1/2*(e+2*d*x)/(sqrt(d)*_
+   sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x+b^2*x^2)/(d^(3/2)*(a+b*x))-_
+   a*atanh(1/2*(2*c+e*x)/(sqrt(c)*sqrt(c+e*x+d*x^2)))*sqrt(c)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(a+b*x)+1/4*(4*a*d+b*e+2*b*d*x)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/(d*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                      +------------------+
+--R              +-+ +-+ | 2 2             2              e x + 2c
+--R       - 8a d\|c \|d \|b x  + 2a b x + a  atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|c \|d x  + e x + c
+--R     + 
+--R                                    +------------------+
+--R               2                    | 2 2             2
+--R         (- b e  + 4a d e + 4b c d)\|b x  + 2a b x + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R                                  +------------------+ +--------------+
+--R                              +-+ | 2 2             2  |   2
+--R       (4b d x + 2b e + 8a d)\|d \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R                     +-+
+--R     (8b d x + 8a d)\|d
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 556
+--a0:=integrate(t0,x)
+--E 512
+
+--S 513 of 556
+--m0:=a0-r0
+--E 513
+
+--S 514 of 556
+--d0:=D(m0,x)
+--E 514
+
+)clear all
+
+--S 515 of 556
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/x^2
+--R 
+--R
+--R         +------------------+ +--------------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + e x + c
+--R   (1)  --------------------------------------
+--R                           2
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 556
+r0:=-1/2*(2*b*c+a*e)*atanh(1/2*(2*c+e*x)/(sqrt(c)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/((a+b*x)*sqrt(c))+1/2*(2*a*d+b*e)*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x+_
+   b^2*x^2)/((a+b*x)*sqrt(d))-(a-b*x)*sqrt(a^2+2*a*b*x+b^2*x^2)*_
+   sqrt(c+e*x+d*x^2)/(x*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                           +------------------+
+--R                       +-+ | 2 2             2              e x + 2c
+--R       (- a e - 2b c)x\|d \|b x  + 2a b x + a  atanh(----------------------)
+--R                                                           +--------------+
+--R                                                       +-+ |   2
+--R                                                     2\|c \|d x  + e x + c
+--R     + 
+--R                         +------------------+
+--R                     +-+ | 2 2             2              2d x + e
+--R       (b e + 2a d)x\|c \|b x  + 2a b x + a  atanh(----------------------)
+--R                                                         +--------------+
+--R                                                     +-+ |   2
+--R                                                   2\|d \|d x  + e x + c
+--R     + 
+--R                           +------------------+ +--------------+
+--R                   +-+ +-+ | 2 2             2  |   2
+--R       (2b x - 2a)\|c \|d \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R          2         +-+ +-+
+--R     (2b x  + 2a x)\|c \|d
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 556
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     2            2                   2    +-+ +-+
+--R               ((8a e  + 16b c e)x  + (16a c e + 32b c )x)\|c \|d
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|d x  + e x + c
+--R           + 
+--R                        3         2                   2   3
+--R                 (- 2a e  - 4b c e  - 8a c d e - 16b c d)x
+--R               + 
+--R                           2        2   2           2         3
+--R                 (- 16a c e  - 32b c e)x  + (- 16a c e - 32b c )x
+--R            *
+--R                +-+
+--R               \|d
+--R        *
+--R                  +--------------+
+--R                  |   2                           +-+
+--R               2c\|d x  + e x + c  + (- e x - 2c)\|c
+--R           log(--------------------------------------)
+--R                                2c x
+--R       + 
+--R                                                              +--------------+
+--R                     2              2         2         2     |   2
+--R             ((8b c e  + 16a c d e)x  + (16b c e + 32a c d)x)\|d x  + e x + c
+--R           + 
+--R                        3         2                     2  3
+--R                 (- 2b e  - 4a d e  - 8b c d e - 16a c d )x
+--R               + 
+--R                           2              2           2         2
+--R                 (- 16b c e  - 32a c d e)x  + (- 16b c e - 32a c d)x
+--R            *
+--R                +-+
+--R               \|c
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|c \|d  - 2d x)\|d x  + e x + c  + (- 2d x  - e x - 2c)\|d
+--R                + 
+--R                       +-+
+--R                  2d x\|c
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|c \|d x  + e x + c  - e x - 2c
+--R       + 
+--R                      2            3                         2
+--R               (- 4b e  - 16b c d)x  + (- 16b c e + 16a c d)x  + 24a c e x
+--R             + 
+--R                    2
+--R               32a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|c \|d \|d x  + e x + c
+--R       + 
+--R                        4       3          2                    2   3
+--R             16b c d e x  + (a e  + 12b c e  - 12a c d e + 16b c d)x
+--R           + 
+--R                      2        2         2   2        2           3
+--R             (- 8a c e  + 16b c e - 32a c d)x  - 40a c e x - 32a c
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R                                +--------------+
+--R                 2      2   +-+ |   2
+--R         (16c e x  + 32c x)\|d \|d x  + e x + c
+--R       + 
+--R               2          3          2      2   +-+ +-+
+--R         ((- 4e  - 16c d)x  - 32c e x  - 32c x)\|c \|d
+--R     ,
+--R
+--R                     2            2                   2    +---+ +-+
+--R               ((8a e  + 16b c e)x  + (16a c e + 32b c )x)\|- d \|c
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|d x  + e x + c
+--R           + 
+--R                        3         2                   2   3
+--R                 (- 2a e  - 4b c e  - 8a c d e - 16b c d)x
+--R               + 
+--R                           2        2   2           2         3
+--R                 (- 16a c e  - 32b c e)x  + (- 16a c e - 32b c )x
+--R            *
+--R                +---+
+--R               \|- d
+--R        *
+--R                  +--------------+
+--R                  |   2                           +-+
+--R               2c\|d x  + e x + c  + (- e x - 2c)\|c
+--R           log(--------------------------------------)
+--R                                2c x
+--R       + 
+--R                                                               +--------------+
+--R                      2              2         2         2     |   2
+--R             ((16b c e  + 32a c d e)x  + (32b c e + 64a c d)x)\|d x  + e x + c
+--R           + 
+--R                        3         2                      2  3
+--R                 (- 4b e  - 8a d e  - 16b c d e - 32a c d )x
+--R               + 
+--R                           2              2           2         2
+--R                 (- 32b c e  - 64a c d e)x  + (- 32b c e - 64a c d)x
+--R            *
+--R                +-+
+--R               \|c
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- d \|d x  + e x + c  - \|- d \|c
+--R           atan(------------------------------------)
+--R                                 d x
+--R       + 
+--R                      2            3                         2
+--R               (- 4b e  - 16b c d)x  + (- 16b c e + 16a c d)x  + 24a c e x
+--R             + 
+--R                    2
+--R               32a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- d \|c \|d x  + e x + c
+--R       + 
+--R                        4       3          2                    2   3
+--R             16b c d e x  + (a e  + 12b c e  - 12a c d e + 16b c d)x
+--R           + 
+--R                      2        2         2   2        2           3
+--R             (- 8a c e  + 16b c e - 32a c d)x  - 40a c e x - 32a c
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R                                  +--------------+
+--R                 2      2   +---+ |   2
+--R         (16c e x  + 32c x)\|- d \|d x  + e x + c
+--R       + 
+--R               2          3          2      2   +---+ +-+
+--R         ((- 4e  - 16c d)x  - 32c e x  - 32c x)\|- d \|c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 517
+
+--S 518 of 556
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        2      2 2   3      2   2          2       2 3  2
+--R               (8a b c e  + 16b c e)x  + (8a c e  + 32a b c e + 32b c )x
+--R             + 
+--R                   2 2           3
+--R               (16a c e + 32a b c )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|d \|d x  + e x + c
+--R         + 
+--R                        3     2   2                   2 2   4
+--R               (- 2a b e  - 4b c e  - 8a b c d e - 16b c d)x
+--R             + 
+--R                    2 3            2        2         2 2            2   3
+--R               (- 2a e  - 20a b c e  + (- 8a c d - 32b c )e - 16a b c d)x
+--R             + 
+--R                     2   2          2       2 3  2         2 2           3
+--R               (- 16a c e  - 48a b c e - 32b c )x  + (- 16a c e - 32a b c )x
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R      *
+--R                +--------------+
+--R                |   2                           +-+
+--R             2c\|d x  + e x + c  + (- e x - 2c)\|c
+--R         log(--------------------------------------)
+--R                              2c x
+--R     + 
+--R                  2   2                3
+--R               (8b c e  + 16a b c d e)x
+--R             + 
+--R                        2       2         2 2            2   2
+--R               (8a b c e  + (16a c d + 16b c )e + 32a b c d)x
+--R             + 
+--R                       2       2 2
+--R               (16a b c e + 32a c d)x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|d x  + e x + c
+--R         + 
+--R                2   3             2     2 2             2 2  4
+--R           (- 2b c e  - 4a b c d e  - 8b c d e - 16a b c d )x
+--R         + 
+--R                      3        2         2 2  2          2         2 2 2  3
+--R           (- 2a b c e  + (- 4a c d - 16b c )e  - 40a b c d e - 16a c d )x
+--R         + 
+--R                     2 2         2 2       2 3            3   2
+--R           (- 16a b c e  + (- 32a c d - 16b c )e - 32a b c d)x
+--R         + 
+--R                     3       2 3
+--R           (- 16a b c e - 32a c d)x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|c \|d  - 2d x)\|d x  + e x + c  + (- 2d x  - e x - 2c)\|d
+--R              + 
+--R                     +-+
+--R                2d x\|c
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|c \|d x  + e x + c  - e x - 2c
+--R     + 
+--R                     2        2   2         2         3    +-+
+--R             ((8a c e  + 16b c e)x  + (16a c e + 32b c )x)\|d
+--R          *
+--R              +------------------+ +--------------+
+--R              | 2 2             2  |   2
+--R             \|b x  + 2a b x + a  \|d x  + e x + c
+--R         + 
+--R                      3         2                   2   3
+--R               (- 2a e  - 4b c e  - 8a c d e - 16b c d)x
+--R             + 
+--R                         2        2   2           2         3
+--R               (- 16a c e  - 32b c e)x  + (- 16a c e - 32b c )x
+--R          *
+--R                      +------------------+
+--R              +-+ +-+ | 2 2             2
+--R             \|c \|d \|b x  + 2a b x + a
+--R      *
+--R                      e x + 2c
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|d x  + e x + c
+--R     + 
+--R                       2              2           2         2     +-+
+--R             ((- 8b c e  - 16a c d e)x  + (- 16b c e - 32a c d)x)\|c
+--R          *
+--R              +------------------+ +--------------+
+--R              | 2 2             2  |   2
+--R             \|b x  + 2a b x + a  \|d x  + e x + c
+--R         + 
+--R                      3           2       2           2 2  3
+--R               (2b c e  + 4a c d e  + 8b c d e + 16a c d )x
+--R             + 
+--R                     2 2        2     2         3         3
+--R               (16b c e  + 32a c d e)x  + (16b c e + 32a c d)x
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R                      2        2   3            2        2         2   2
+--R               (4b c e  + 16b c d)x  + (- 4a c e  + 32b c e - 16a c d)x
+--R             + 
+--R                       2         3          3
+--R               (- 32a c e + 32b c )x - 32a c
+--R          *
+--R                  +------------------+
+--R              +-+ | 2 2             2
+--R             \|d \|b x  + 2a b x + a
+--R         + 
+--R                    2   2      2 2   4              2      2 2   3
+--R               (- 4b c e  - 16b c d)x  + (- 4a b c e  - 16b c e)x
+--R             + 
+--R                      2       2 2   2       2 2           3        2 3
+--R               (8a b c e + 16a c d)x  + (24a c e + 32a b c )x + 32a c
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|d x  + e x + c
+--R     + 
+--R                        4             2                    2   3
+--R           - 16b c d e x  + (- 16b c e  + 16a c d e - 32b c d)x
+--R         + 
+--R                   2        2         2   2         2         3          3
+--R           (16a c e  - 48b c e + 32a c d)x  + (48a c e - 32b c )x + 32a c
+--R      *
+--R                  +------------------+
+--R          +-+ +-+ | 2 2             2
+--R         \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R              2       5         3      2   2                   2 2   4
+--R           16b c d e x  + (a b e  + 12b c e  + 4a b c d e + 16b c d)x
+--R         + 
+--R             2 3           2         2         2 2            2   3
+--R           (a e  + 4a b c e  + (- 12a c d + 16b c )e - 16a b c d)x
+--R         + 
+--R              2   2          2       2 2   2         2 2           3        2 3
+--R         (- 8a c e  - 24a b c e - 32a c d)x  + (- 40a c e - 32a b c )x - 32a c
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R  /
+--R                                                             +--------------+
+--R                 3                   2  2        2   +-+ +-+ |   2
+--R       (16b c e x  + (16a c e + 32b c )x  + 32a c x)\|c \|d \|d x  + e x + c
+--R     + 
+--R                    2        2   4            2        2         2   3
+--R           (- 4b c e  - 16b c d)x  + (- 4a c e  - 32b c e - 16a c d)x
+--R         + 
+--R                   2         3  2        3
+--R           (- 32a c e - 32b c )x  - 32a c x
+--R      *
+--R          +-+
+--R         \|d
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 556
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                            7           2 5          2 3 3         3 4   10
+--R                   (- 2b d e  - 168b c d e  - 1120b c d e  - 896b c d e)x
+--R                 + 
+--R                            8         7             6           2 5
+--R                       - b e  - 2a d e  - 308b c d e  - 168a c d e
+--R                     + 
+--R                                2 2 4          2 3 3           3 3 2
+--R                       - 5040b c d e  - 1120a c d e  - 11200b c d e
+--R                     + 
+--R                               3 4           4 4
+--R                       - 896a c d e - 2048b c d
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                            8           7             6          2   5
+--R                       - a e  - 128b c e  - 308a c d e  - 6720b c d e
+--R                     + 
+--R                                2 2 4           3 2 3           3 3 2
+--R                       - 5040a c d e  - 39424b c d e  - 11200a c d e
+--R                     + 
+--R                                 4 3           4 4
+--R                       - 29696b c d e - 2048a c d
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                 7          2 6          2   5           3   4
+--R                       - 128a c e  - 2688b c e  - 6720a c d e  - 51072b c d e
+--R                     + 
+--R                                 3 2 3            4 2 2           4 3
+--R                       - 39424a c d e  - 119808b c d e  - 29696a c d e
+--R                     + 
+--R                                 5 3
+--R                       - 22528b c d
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                2 6           3 5           3   4
+--R                       - 2688a c e  - 21504b c e  - 51072a c d e
+--R                     + 
+--R                                  4   3            4 2 2            5 2
+--R                       - 176640b c d e  - 119808a c d e  - 153600b c d e
+--R                     + 
+--R                                 5 3
+--R                       - 22528a c d
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                 3 5           4 4            4   3
+--R                       - 21504a c e  - 84480b c e  - 176640a c d e
+--R                     + 
+--R                                  5   2            5 2            6 2
+--R                       - 304128b c d e  - 153600a c d e - 69632b c d
+--R                  *
+--R                      5
+--R                     x
+--R                 + 
+--R                                 4 4            5 3            5   2
+--R                       - 84480a c e  - 180224b c e  - 304128a c d e
+--R                     + 
+--R                                  6              6 2
+--R                       - 253952b c d e - 69632a c d
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                    5 3            6 2            6
+--R                         - 180224a c e  - 212992b c e  - 253952a c d e
+--R                       + 
+--R                                   7
+--R                         - 81920b c d
+--R                  *
+--R                      3
+--R                     x
+--R                 + 
+--R                               6 2            7            7   2
+--R                   (- 212992a c e  - 131072b c e - 81920a c d)x
+--R                 + 
+--R                               7            8             8
+--R                   (- 131072a c e - 32768b c )x - 32768a c
+--R              *
+--R                  +-+ +-+
+--R                 \|c \|d
+--R             + 
+--R                       2 6         2 3 4          3 4 2         4 5  10
+--R               (28b c d e  + 560b c d e  + 1344b c d e  + 256b c d )x
+--R             + 
+--R                            7          2 6          2 2 5         2 3 4
+--R                   30b c d e  + 28a c d e  + 1624b c d e  + 560a c d e
+--R                 + 
+--R                          3 3 3          3 4 2          4 4          4 5
+--R                   9632b c d e  + 1344a c d e  + 7296b c d e + 256a c d
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            7          2   6          2 2 5           3 2 4
+--R                   30a c d e  + 1120b c d e  + 1624a c d e  + 19712b c d e
+--R                 + 
+--R                          3 3 3           4 3 2          4 4           5 4
+--R                   9632a c d e  + 44544b c d e  + 7296a c d e + 8192b c d
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          2   6           3   5           3 2 4           4 2 3
+--R                   1120a c d e  + 12096b c d e  + 19712a c d e  + 90624b c d e
+--R                 + 
+--R                           4 3 2           5 3           5 4
+--R                   44544a c d e  + 74752b c d e + 8192a c d
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                           3   5           4   4           4 2 3
+--R                   12096a c d e  + 57600b c d e  + 90624a c d e
+--R                 + 
+--R                            5 2 2           5 3            6 3
+--R                   189440b c d e  + 74752a c d e + 40960b c d
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                           4   4            5   3            5 2 2
+--R                   57600a c d e  + 140800b c d e  + 189440a c d e
+--R                 + 
+--R                            6 2            6 3
+--R                   182272b c d e + 40960a c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                         5   3            6   2            6 2            7 2  4
+--R               (140800a c d e  + 184320b c d e  + 182272a c d e + 65536b c d )x
+--R             + 
+--R                         6   2            7              7 2  3
+--R               (184320a c d e  + 122880b c d e + 65536a c d )x
+--R             + 
+--R                         7              8   2           8
+--R               (122880a c d e + 32768b c d)x  + 32768a c d x
+--R          *
+--R              +------------------+
+--R              | 2 2             2
+--R             \|b x  + 2a b x + a
+--R         + 
+--R                  2   7       2   2 5        2 2 3 3       2 3 4   11
+--R               (2b d e  + 168b c d e  + 1120b c d e  + 896b c d e)x
+--R             + 
+--R                    2 8           7       2     6             2 5        2 2 2 4
+--R                   b e  + 4a b d e  + 308b c d e  + 336a b c d e  + 5040b c d e
+--R                 + 
+--R                            2 3 3         2 3 3 2            3 4         2 4 4
+--R                   2240a b c d e  + 11200b c d e  + 1792a b c d e + 2048b c d
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                         8      2        2   7               6
+--R                   2a b e  + (2a d + 128b c)e  + 616a b c d e
+--R                 + 
+--R                        2   2        2 2   5             2 2 4
+--R                   (168a c d  + 6720b c d)e  + 10080a b c d e
+--R                 + 
+--R                         2 2 3         2 3 2  3             3 3 2
+--R                   (1120a c d  + 39424b c d )e  + 22400a b c d e
+--R                 + 
+--R                        2 3 4         2 4 3              4 4
+--R                   (896a c d  + 29696b c d )e + 4096a b c d
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                    2 8             7        2           2 2  6
+--R                   a e  + 256a b c e  + (308a c d + 2688b c )e
+--R                 + 
+--R                             2   5         2 2 2         2 3   4
+--R                   13440a b c d e  + (5040a c d  + 51072b c d)e
+--R                 + 
+--R                             3 2 3          2 3 3          2 4 2  2
+--R                   78848a b c d e  + (11200a c d  + 119808b c d )e
+--R                 + 
+--R                             4 3         2 4 4         2 5 3
+--R                   59392a b c d e + 2048a c d  + 22528b c d
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                       2   7            2 6         2 2          2 3  5
+--R                   128a c e  + 5376a b c e  + (6720a c d + 21504b c )e
+--R                 + 
+--R                              3   4          2 3 2          2 4   3
+--R                   102144a b c d e  + (39424a c d  + 176640b c d)e
+--R                 + 
+--R                              4 2 2          2 4 3          2 5 2
+--R                   239616a b c d e  + (29696a c d  + 153600b c d )e
+--R                 + 
+--R                             5 3
+--R                   45056a b c d
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                        2 2 6             3 5          2 3          2 4  4
+--R                   2688a c e  + 43008a b c e  + (51072a c d + 84480b c )e
+--R                 + 
+--R                              4   3           2 4 2          2 5   2
+--R                   353280a b c d e  + (119808a c d  + 304128b c d)e
+--R                 + 
+--R                              5 2          2 5 3         2 6 2
+--R                   307200a b c d e + 22528a c d  + 69632b c d
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         2 3 5              4 4           2 4           2 5  3
+--R                   21504a c e  + 168960a b c e  + (176640a c d + 180224b c )e
+--R                 + 
+--R                              5   2           2 5 2          2 6
+--R                   608256a b c d e  + (153600a c d  + 253952b c d)e
+--R                 + 
+--R                              6 2
+--R                   139264a b c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                         2 4 4              5 3           2 5           2 6  2
+--R                   84480a c e  + 360448a b c e  + (304128a c d + 212992b c )e
+--R                 + 
+--R                              6            2 6 2         2 7
+--R                   507904a b c d e + 69632a c d  + 81920b c d
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          2 5 3              6 2           2 6           2 7
+--R                   180224a c e  + 425984a b c e  + (253952a c d + 131072b c )e
+--R                 + 
+--R                              7
+--R                   163840a b c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                       2 6 2              7          2 7          2 8  2
+--R               (212992a c e  + 262144a b c e + 81920a c d + 32768b c )x
+--R             + 
+--R                       2 7              8           2 8
+--R               (131072a c e + 65536a b c )x + 32768a c
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R                 2   2 6       2 2 3 4        2 3 4 2       2 4 5  11
+--R           (- 28b c d e  - 560b c d e  - 1344b c d e  - 256b c d )x
+--R         + 
+--R                    2     7            2 6        2 2 2 5            2 3 4
+--R               - 30b c d e  - 56a b c d e  - 1624b c d e  - 1120a b c d e
+--R             + 
+--R                      2 3 3 3            3 4 2        2 4 4            4 5
+--R               - 9632b c d e  - 2688a b c d e  - 7296b c d e - 512a b c d
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                            7         2   2        2 2   6            2 2 5
+--R               - 60a b c d e  + (- 28a c d  - 1120b c d)e  - 3248a b c d e
+--R             + 
+--R                      2 2 3         2 3 2  4             3 3 3
+--R               (- 560a c d  - 19712b c d )e  - 19264a b c d e
+--R             + 
+--R                       2 3 4         2 4 3  2             4 4        2 4 5
+--R               (- 1344a c d  - 44544b c d )e  - 14592a b c d e - 256a c d
+--R             + 
+--R                      2 5 4
+--R               - 8192b c d
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                    2     7            2   6           2 2 2         2 3   5
+--R               - 30a c d e  - 2240a b c d e  + (- 1624a c d  - 12096b c d)e
+--R             + 
+--R                           3 2 4           2 3 3         2 4 2  3
+--R               - 39424a b c d e  + (- 9632a c d  - 90624b c d )e
+--R             + 
+--R                         4 3 2           2 4 4         2 5 3               5 4
+--R             - 89088a b c d e  + (- 7296a c d  - 74752b c d )e - 16384a b c d
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      2 2   6             3   5            2 3 2         2 4   4
+--R               - 1120a c d e  - 24192a b c d e  + (- 19712a c d  - 57600b c d)e
+--R             + 
+--R                            4 2 3            2 4 3          2 5 2  2
+--R               - 181248a b c d e  + (- 44544a c d  - 189440b c d )e
+--R             + 
+--R                            5 3         2 5 4         2 6 3
+--R               - 149504a b c d e - 8192a c d  - 40960b c d
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                       2 3   5              4   4
+--R               - 12096a c d e  - 115200a b c d e
+--R             + 
+--R                        2 4 2          2 5   3              5 2 2
+--R               (- 90624a c d  - 140800b c d)e  - 378880a b c d e
+--R             + 
+--R                        2 5 3          2 6 2               6 3
+--R               (- 74752a c d  - 182272b c d )e - 81920a b c d
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                       2 4   4              5   3
+--R               - 57600a c d e  - 281600a b c d e
+--R             + 
+--R                         2 5 2          2 6   2              6 2          2 6 3
+--R               (- 189440a c d  - 184320b c d)e  - 364544a b c d e - 40960a c d
+--R             + 
+--R                       2 7 2
+--R               - 65536b c d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                        2 5   3              6   2
+--R               - 140800a c d e  - 368640a b c d e
+--R             + 
+--R                         2 6 2          2 7                 7 2
+--R               (- 182272a c d  - 122880b c d)e - 131072a b c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     2 6   2              7            2 7 2         2 8   3
+--R           (- 184320a c d e  - 245760a b c d e - 65536a c d  - 32768b c d)x
+--R         + 
+--R                     2 7                8   2         2 8
+--R           (- 122880a c d e - 65536a b c d)x  - 32768a c d x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|d x  + e x + c
+--R     + 
+--R                       2 6         2 3 4          3 4 2         4 5  11
+--R               (28b c d e  + 560b c d e  + 1344b c d e  + 256b c d )x
+--R             + 
+--R                            7          2 6          2 2 5         2 3 4
+--R                   44b c d e  + 28a c d e  + 1904b c d e  + 560a c d e
+--R                 + 
+--R                           3 3 3          3 4 2          4 4          4 5
+--R                   10304b c d e  + 1344a c d e  + 7424b c d e + 256a c d
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                          8            7          2   6          2 2 5
+--R                   16b c e  + 44a c d e  + 2044b c d e  + 1904a c d e
+--R                 + 
+--R                           3 2 4           3 3 3           4 3 2          4 4
+--R                   25648b c d e  + 10304a c d e  + 49984b c d e  + 7424a c d e
+--R                 + 
+--R                          5 4
+--R                   8448b c d
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                          8         2 7          2   6           3   5
+--R                   16a c e  + 688b c e  + 2044a c d e  + 25536b c d e
+--R                 + 
+--R                           3 2 4            4 2 3           4 3 2           5 3
+--R                   25648a c d e  + 127232b c d e  + 49984a c d e  + 87040b c d e
+--R                 + 
+--R                          5 4
+--R                   8448a c d
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                         2 7          3 6           3   5            4   4
+--R                   688a c e  + 8736b c e  + 25536a c d e  + 135168b c d e
+--R                 + 
+--R                            4 2 3            5 2 2           5 3            6 3
+--R                   127232a c d e  + 282112b c d e  + 87040a c d e + 49152b c d
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                          3 6           4 5            4   4            5   3
+--R                   8736a c e  + 50304b c e  + 135168a c d e  + 358400b c d e
+--R                 + 
+--R                            5 2 2            6 2            6 3
+--R                   282112a c d e  + 284672b c d e + 49152a c d
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                           4 5            5 4            5   3            6   2
+--R                   50304a c e  + 154880b c e  + 358400a c d e  + 500736b c d e
+--R                 + 
+--R                            6 2             7 2
+--R                   284672a c d e + 106496b c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                            5 4            6 3            6   2            7
+--R                   154880a c e  + 272384b c e  + 500736a c d e  + 352256b c d e
+--R                 + 
+--R                            7 2
+--R                   106496a c d
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         6 3            7 2            7              8   3
+--R               (272384a c e  + 274432b c e  + 352256a c d e + 98304b c d)x
+--R             + 
+--R                         7 2            8            8   2
+--R               (274432a c e  + 147456b c e + 98304a c d)x
+--R             + 
+--R                         8            9             9
+--R               (147456a c e + 32768b c )x + 32768a c
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                      2 7           3 5          2 4 3         3 5   11
+--R               (- 2b d e  - 168b c d e  - 1120b c d e  - 896b c d e)x
+--R             + 
+--R                           8       2 7           2 6           3 5
+--R                   - 2b d e  - 2a d e  - 392b c d e  - 168a c d e
+--R                 + 
+--R                            2 3 4          2 4 3           3 4 2         3 5
+--R                   - 5600b c d e  - 1120a c d e  - 11648b c d e  - 896a c d e
+--R                 + 
+--R                            4 5
+--R                   - 2048b c d
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                           8             7           2 6          2 2 5
+--R                   - 2a d e  - 226b c d e  - 392a c d e  - 8680b c d e
+--R                 + 
+--R                            2 3 4           3 3 3           3 4 2           4 4
+--R                   - 5600a c d e  - 44128b c d e  - 11648a c d e  - 30592b c d e
+--R                 + 
+--R                            4 5
+--R                   - 2048a c d
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                               7          2   6          2 2 5           3 2 4
+--R                   - 226a c d e  - 4256b c d e  - 8680a c d e  - 63616b c d e
+--R                 + 
+--R                           3 3 3            4 3 2           4 4            5 4
+--R                 - 44128a c d e  - 130560b c d e  - 30592a c d e - 22528b c d
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            2   6           3   5           3 2 4
+--R                   - 4256a c d e  - 30912b c d e  - 63616a c d e
+--R                 + 
+--R                            4 2 3            4 3 2            5 3            5 4
+--R                 - 208896b c d e  - 130560a c d e  - 160768b c d e - 22528a c d
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                             3   5            4   4            4 2 3
+--R                   - 30912a c d e  - 111360b c d e  - 208896a c d e
+--R                 + 
+--R                              5 2 2            5 3            6 3
+--R                   - 339968b c d e  - 160768a c d e - 69632b c d
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              4   4            5   3            5 2 2
+--R                   - 111360a c d e  - 219648b c d e  - 339968a c d e
+--R                 + 
+--R                              6 2            6 3
+--R                   - 268288b c d e - 69632a c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                                5   3            6   2            6 2
+--R                     - 219648a c d e  - 241664b c d e  - 268288a c d e
+--R                   + 
+--R                               7 2
+--R                     - 81920b c d
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           6   2            7              7 2  3
+--R               (- 241664a c d e  - 139264b c d e - 81920a c d )x
+--R             + 
+--R                           7              8   2           8
+--R               (- 139264a c d e - 32768b c d)x  - 32768a c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R                 2   2 6       2 2 3 4        2 3 4 2       2 4 5  12
+--R           (- 28b c d e  - 560b c d e  - 1344b c d e  - 256b c d )x
+--R         + 
+--R                    2     7            2 6        2 2 2 5            2 3 4
+--R               - 44b c d e  - 56a b c d e  - 1904b c d e  - 1120a b c d e
+--R             + 
+--R                       2 3 3 3            3 4 2        2 4 4            4 5
+--R               - 10304b c d e  - 2688a b c d e  - 7424b c d e - 512a b c d
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                    2   8              7         2   2        2 2   6
+--R               - 16b c e  - 88a b c d e  + (- 28a c d  - 2044b c d)e
+--R             + 
+--R                          2 2 5          2 2 3         2 3 2  4
+--R               - 3808a b c d e  + (- 560a c d  - 25648b c d )e
+--R             + 
+--R                           3 3 3           2 3 4         2 4 3  2
+--R               - 20608a b c d e  + (- 1344a c d  - 49984b c d )e
+--R             + 
+--R                           4 4        2 4 5        2 5 4
+--R               - 14848a b c d e - 256a c d  - 8448b c d
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          8         2          2 2  7            2   6
+--R               - 32a b c e  + (- 44a c d - 688b c )e  - 4088a b c d e
+--R             + 
+--R                       2 2 2         2 3   5             3 2 4
+--R               (- 1904a c d  - 25536b c d)e  - 51296a b c d e
+--R             + 
+--R                        2 3 3          2 4 2  3             4 3 2
+--R               (- 10304a c d  - 127232b c d )e  - 99968a b c d e
+--R             + 
+--R                       2 4 4         2 5 3               5 4
+--R               (- 7424a c d  - 87040b c d )e - 16896a b c d
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                    2   8            2 7           2 2         2 3  6
+--R               - 16a c e  - 1376a b c e  + (- 2044a c d - 8736b c )e
+--R             + 
+--R                           3   5            2 3 2          2 4   4
+--R               - 51072a b c d e  + (- 25648a c d  - 135168b c d)e
+--R             + 
+--R                            4 2 3            2 4 3          2 5 2  2
+--R               - 254464a b c d e  + (- 49984a c d  - 282112b c d )e
+--R             + 
+--R                            5 3         2 5 4         2 6 3
+--R               - 174080a b c d e - 8448a c d  - 49152b c d
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                     2 2 7             3 6            2 3          2 4  5
+--R               - 688a c e  - 17472a b c e  + (- 25536a c d - 50304b c )e
+--R             + 
+--R                            4   4             2 4 2          2 5   3
+--R               - 270336a b c d e  + (- 127232a c d  - 358400b c d)e
+--R             + 
+--R                            5 2 2            2 5 3          2 6 2
+--R               - 564224a b c d e  + (- 87040a c d  - 284672b c d )e
+--R             + 
+--R                           6 3
+--R               - 98304a b c d
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                      2 3 6              4 5             2 4           2 5  4
+--R               - 8736a c e  - 100608a b c e  + (- 135168a c d - 154880b c )e
+--R             + 
+--R                            5   3             2 5 2          2 6   2
+--R               - 716800a b c d e  + (- 282112a c d  - 500736b c d)e
+--R             + 
+--R                            6 2          2 6 3          2 7 2
+--R               - 569344a b c d e - 49152a c d  - 106496b c d
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                       2 4 5              5 4             2 5           2 6  3
+--R               - 50304a c e  - 309760a b c e  + (- 358400a c d - 272384b c )e
+--R             + 
+--R                             6   2             2 6 2          2 7
+--R               - 1001472a b c d e  + (- 284672a c d  - 352256b c d)e
+--R             + 
+--R                            7 2
+--R               - 212992a b c d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                        2 5 4              6 3             2 6           2 7  2
+--R               - 154880a c e  - 544768a b c e  + (- 500736a c d - 274432b c )e
+--R             + 
+--R                            7             2 7 2         2 8
+--R               - 704512a b c d e - 106496a c d  - 98304b c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        2 6 3              7 2             2 7           2 8
+--R               - 272384a c e  - 548864a b c e  + (- 352256a c d - 147456b c )e
+--R             + 
+--R                            8
+--R               - 196608a b c d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     2 7 2              8          2 8          2 9  2
+--R           (- 274432a c e  - 294912a b c e - 98304a c d - 32768b c )x
+--R         + 
+--R                     2 8              9           2 9
+--R           (- 147456a c e - 65536a b c )x - 32768a c
+--R      *
+--R          +-+
+--R         \|d
+--R     + 
+--R              2 2 7       2   3 5        2 2 4 3       2 3 5   12
+--R           (2b d e  + 168b c d e  + 1120b c d e  + 896b c d e)x
+--R         + 
+--R                 2   8         2 7       2   2 6             3 5        2 2 3 4
+--R               2b d e  + 4a b d e  + 392b c d e  + 336a b c d e  + 5600b c d e
+--R             + 
+--R                        2 4 3         2 3 4 2            3 5         2 4 5
+--R               2240a b c d e  + 11648b c d e  + 1792a b c d e + 2048b c d
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                       8      2 2       2     7             2 6
+--R               4a b d e  + (2a d  + 226b c d)e  + 784a b c d e
+--R             + 
+--R                    2   3        2 2 2  5             2 3 4
+--R               (168a c d  + 8680b c d )e  + 11200a b c d e
+--R             + 
+--R                     2 2 4         2 3 3  3             3 4 2
+--R               (1120a c d  + 44128b c d )e  + 23296a b c d e
+--R             + 
+--R                    2 3 5         2 4 4              4 5
+--R               (896a c d  + 30592b c d )e + 4096a b c d
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                 2   8               7        2   2        2 2   6
+--R               2a d e  + 452a b c d e  + (392a c d  + 4256b c d)e
+--R             + 
+--R                         2 2 5         2 2 3         2 3 2  4             3 3 3
+--R               17360a b c d e  + (5600a c d  + 63616b c d )e  + 88256a b c d e
+--R             + 
+--R                      2 3 4          2 4 3  2             4 4         2 4 5
+--R               (11648a c d  + 130560b c d )e  + 61184a b c d e + 2048a c d
+--R             + 
+--R                     2 5 4
+--R               22528b c d
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                   2     7            2   6         2 2 2         2 3   5
+--R               226a c d e  + 8512a b c d e  + (8680a c d  + 30912b c d)e
+--R             + 
+--R                          3 2 4          2 3 3          2 4 2  3
+--R               127232a b c d e  + (44128a c d  + 208896b c d )e
+--R             + 
+--R                          4 3 2          2 4 4          2 5 3               5 4
+--R               261120a b c d e  + (30592a c d  + 160768b c d )e + 45056a b c d
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    2 2   6             3   5          2 3 2          2 4   4
+--R               4256a c d e  + 61824a b c d e  + (63616a c d  + 111360b c d)e
+--R             + 
+--R                          4 2 3           2 4 3          2 5 2  2
+--R               417792a b c d e  + (130560a c d  + 339968b c d )e
+--R             + 
+--R                          5 3          2 5 4         2 6 3
+--R               321536a b c d e + 22528a c d  + 69632b c d
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                     2 3   5              4   4           2 4 2          2 5   3
+--R               30912a c d e  + 222720a b c d e  + (208896a c d  + 219648b c d)e
+--R             + 
+--R                        5 2 2           2 5 3          2 6 2                6 3
+--R             679936a b c d e  + (160768a c d  + 268288b c d )e + 139264a b c d
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      2 4   4              5   3
+--R               111360a c d e  + 439296a b c d e
+--R             + 
+--R                       2 5 2          2 6   2              6 2          2 6 3
+--R               (339968a c d  + 241664b c d)e  + 536576a b c d e + 69632a c d
+--R             + 
+--R                     2 7 2
+--R               81920b c d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                      2 5   3              6   2           2 6 2          2 7
+--R               219648a c d e  + 483328a b c d e  + (268288a c d  + 139264b c d)e
+--R             + 
+--R                          7 2
+--R               163840a b c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   2 6   2              7            2 7 2         2 8   3
+--R           (241664a c d e  + 278528a b c d e + 81920a c d  + 32768b c d)x
+--R         + 
+--R                   2 7                8   2         2 8
+--R           (139264a c d e + 65536a b c d)x  + 32768a c d x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                       6       2 2 4        3 3 2       4 4  10
+--R               (28c d e  + 560c d e  + 1344c d e  + 256c d )x
+--R             + 
+--R                     7        2   5        3 2 3        4 3   9
+--R               (16c e  + 1344c d e  + 8960c d e  + 7168c d e)x
+--R             + 
+--R                    2 6         3   4         4 2 2        5 3  8
+--R               (672c e  + 16128c d e  + 41472c d e  + 8192c d )x
+--R             + 
+--R                     3 5         4   3         5 2   7
+--R               (8064c e  + 76800c d e  + 71680c d e)x
+--R             + 
+--R                      4 4          5   2         6 2  6
+--R               (42240c e  + 168960c d e  + 40960c d )x
+--R             + 
+--R                       5 3          6     5           6 2         7   4
+--R               (112640c e  + 172032c d e)x  + (159744c e  + 65536c d)x
+--R             + 
+--R                      7   3         8 2
+--R               114688c e x  + 32768c x
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                      7         2 5        2 3 3       3 4   10
+--R               (- 2d e  - 168c d e  - 1120c d e  - 896c d e)x
+--R             + 
+--R                          6        2 2 4         3 3 2        4 4  9
+--R               (- 224c d e  - 4480c d e  - 10752c d e  - 2048c d )x
+--R             + 
+--R                       2   5         3 2 3         4 3   8
+--R               (- 4032c d e  - 32256c d e  - 27648c d e)x
+--R             + 
+--R                        3   4         4 2 2         5 3  7
+--R               (- 26880c d e  - 92160c d e  - 20480c d )x
+--R             + 
+--R                        4   3          5 2   6             5   2         6 2  5
+--R               (- 84480c d e  - 112640c d e)x  + (- 135168c d e  - 49152c d )x
+--R             + 
+--R                        6     4         7   3
+--R               - 106496c d e x  - 32768c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +------------------+ +--------------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + e x + c
+--R     + 
+--R                      7         2 5        2 3 3       3 4   11
+--R               (- 2d e  - 168c d e  - 1120c d e  - 896c d e)x
+--R             + 
+--R                   8           6        2 2 4         3 3 2        4 4  10
+--R               (- e  - 308c d e  - 5040c d e  - 11200c d e  - 2048c d )x
+--R             + 
+--R                        7        2   5         3 2 3         4 3   9
+--R               (- 128c e  - 6720c d e  - 39424c d e  - 29696c d e)x
+--R             + 
+--R                       2 6         3   4          4 2 2         5 3  8
+--R               (- 2688c e  - 51072c d e  - 119808c d e  - 22528c d )x
+--R             + 
+--R                        3 5          4   3          5 2   7
+--R               (- 21504c e  - 176640c d e  - 153600c d e)x
+--R             + 
+--R                        4 4          5   2         6 2  6
+--R               (- 84480c e  - 304128c d e  - 69632c d )x
+--R             + 
+--R                         5 3          6     5             6 2         7   4
+--R               (- 180224c e  - 253952c d e)x  + (- 212992c e  - 81920c d)x
+--R             + 
+--R                        7   3         8 2
+--R               - 131072c e x  - 32768c x
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R                 2 6       2 3 4        3 4 2       4 5  11
+--R           (28c d e  + 560c d e  + 1344c d e  + 256c d )x
+--R         + 
+--R                   7        2 2 5        3 3 3        4 4   10
+--R           (30c d e  + 1624c d e  + 9632c d e  + 7296c d e)x
+--R         + 
+--R                 2   6         3 2 4         4 3 2        5 4  9
+--R           (1120c d e  + 19712c d e  + 44544c d e  + 8192c d )x
+--R         + 
+--R                  3   5         4 2 3         5 3   8
+--R           (12096c d e  + 90624c d e  + 74752c d e)x
+--R         + 
+--R                  4   4          5 2 2         6 3  7
+--R           (57600c d e  + 189440c d e  + 40960c d )x
+--R         + 
+--R                   5   3          6 2   6           6   2         7 2  5
+--R           (140800c d e  + 182272c d e)x  + (184320c d e  + 65536c d )x
+--R         + 
+--R                  7     4         8   3
+--R           122880c d e x  + 32768c d x
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 556
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        2      2 2   3      2   2          2       2 3  2
+--R               (8a b c e  + 16b c e)x  + (8a c e  + 32a b c e + 32b c )x
+--R             + 
+--R                   2 2           3
+--R               (16a c e + 32a b c )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- d \|d \|d x  + e x + c
+--R         + 
+--R                        3     2   2                   2 2   4
+--R               (- 2a b e  - 4b c e  - 8a b c d e - 16b c d)x
+--R             + 
+--R                    2 3            2        2         2 2            2   3
+--R               (- 2a e  - 20a b c e  + (- 8a c d - 32b c )e - 16a b c d)x
+--R             + 
+--R                     2   2          2       2 3  2         2 2           3
+--R               (- 16a c e  - 48a b c e - 32b c )x  + (- 16a c e - 32a b c )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- d \|c \|d
+--R      *
+--R                +--------------+
+--R                |   2                           +-+
+--R             2c\|d x  + e x + c  + (- e x - 2c)\|c
+--R         log(--------------------------------------)
+--R                              2c x
+--R     + 
+--R                     2        2   2         2         3    +---+ +-+
+--R             ((8a c e  + 16b c e)x  + (16a c e + 32b c )x)\|- d \|d
+--R          *
+--R              +------------------+ +--------------+
+--R              | 2 2             2  |   2
+--R             \|b x  + 2a b x + a  \|d x  + e x + c
+--R         + 
+--R                      3         2                   2   3
+--R               (- 2a e  - 4b c e  - 8a c d e - 16b c d)x
+--R             + 
+--R                         2        2   2           2         3
+--R               (- 16a c e  - 32b c e)x  + (- 16a c e - 32b c )x
+--R          *
+--R                            +------------------+
+--R              +---+ +-+ +-+ | 2 2             2
+--R             \|- d \|c \|d \|b x  + 2a b x + a
+--R      *
+--R                      e x + 2c
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|d x  + e x + c
+--R     + 
+--R                       2              2           2         2     +---+ +-+
+--R             ((- 8b c e  - 16a c d e)x  + (- 16b c e - 32a c d)x)\|- d \|c
+--R          *
+--R              +------------------+ +--------------+
+--R              | 2 2             2  |   2
+--R             \|b x  + 2a b x + a  \|d x  + e x + c
+--R         + 
+--R                      3           2       2           2 2  3
+--R               (2b c e  + 4a c d e  + 8b c d e + 16a c d )x
+--R             + 
+--R                     2 2        2     2         3         3
+--R               (16b c e  + 32a c d e)x  + (16b c e + 32a c d)x
+--R          *
+--R                    +------------------+
+--R              +---+ | 2 2             2
+--R             \|- d \|b x  + 2a b x + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R                   2   2                3
+--R               (16b c e  + 32a b c d e)x
+--R             + 
+--R                         2       2         2 2            2   2
+--R               (16a b c e  + (32a c d + 32b c )e + 64a b c d)x
+--R             + 
+--R                       2       2 2
+--R               (32a b c e + 64a c d)x
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|c \|d \|d x  + e x + c
+--R         + 
+--R                    2   3             2      2 2             2 2  4
+--R               (- 4b c e  - 8a b c d e  - 16b c d e - 32a b c d )x
+--R             + 
+--R                          3        2         2 2  2          2         2 2 2  3
+--R               (- 4a b c e  + (- 8a c d - 32b c )e  - 80a b c d e - 32a c d )x
+--R             + 
+--R                         2 2         2 2       2 3            3   2
+--R               (- 32a b c e  + (- 64a c d - 32b c )e - 64a b c d)x
+--R             + 
+--R                         3       2 3
+--R               (- 32a b c e - 64a c d)x
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- d \|d x  + e x + c  - \|- d \|c
+--R         atan(------------------------------------)
+--R                               d x
+--R     + 
+--R                      2        2   3            2        2         2   2
+--R               (4b c e  + 16b c d)x  + (- 4a c e  + 32b c e - 16a c d)x
+--R             + 
+--R                       2         3          3
+--R               (- 32a c e + 32b c )x - 32a c
+--R          *
+--R                        +------------------+
+--R              +---+ +-+ | 2 2             2
+--R             \|- d \|d \|b x  + 2a b x + a
+--R         + 
+--R                    2   2      2 2   4              2      2 2   3
+--R               (- 4b c e  - 16b c d)x  + (- 4a b c e  - 16b c e)x
+--R             + 
+--R                      2       2 2   2       2 2           3        2 3
+--R               (8a b c e + 16a c d)x  + (24a c e + 32a b c )x + 32a c
+--R          *
+--R              +---+ +-+
+--R             \|- d \|d
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|d x  + e x + c
+--R     + 
+--R                        4             2                    2   3
+--R           - 16b c d e x  + (- 16b c e  + 16a c d e - 32b c d)x
+--R         + 
+--R                   2        2         2   2         2         3          3
+--R           (16a c e  - 48b c e + 32a c d)x  + (48a c e - 32b c )x + 32a c
+--R      *
+--R                        +------------------+
+--R          +---+ +-+ +-+ | 2 2             2
+--R         \|- d \|c \|d \|b x  + 2a b x + a
+--R     + 
+--R              2       5         3      2   2                   2 2   4
+--R           16b c d e x  + (a b e  + 12b c e  + 4a b c d e + 16b c d)x
+--R         + 
+--R             2 3           2         2         2 2            2   3
+--R           (a e  + 4a b c e  + (- 12a c d + 16b c )e - 16a b c d)x
+--R         + 
+--R              2   2          2       2 2   2         2 2           3        2 3
+--R         (- 8a c e  - 24a b c e - 32a c d)x  + (- 40a c e - 32a b c )x - 32a c
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- d \|c \|d
+--R  /
+--R                   3                   2  2        2   +---+ +-+ +-+
+--R         (16b c e x  + (16a c e + 32b c )x  + 32a c x)\|- d \|c \|d
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|d x  + e x + c
+--R     + 
+--R                    2        2   4            2        2         2   3
+--R           (- 4b c e  - 16b c d)x  + (- 4a c e  - 32b c e - 16a c d)x
+--R         + 
+--R                   2         3  2        3
+--R           (- 32a c e - 32b c )x  - 32a c x
+--R      *
+--R          +---+ +-+
+--R         \|- d \|d
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 556
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                     5            3        2 2   6
+--R               (- b e  - 40b c d e  - 80b c d e)x
+--R             + 
+--R                        5          4            3         2   2        2 2
+--R                   - a e  - 50b c e  - 40a c d e  - 400b c d e  - 80a c d e
+--R                 + 
+--R                           3 2
+--R                   - 160b c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                         4         2 3         2   2         3            3 2  4
+--R               (- 50a c e  - 400b c e  - 400a c d e  - 960b c d e - 160a c d )x
+--R             + 
+--R                        2 3          3 2         3            4   3
+--R               (- 400a c e  - 1120b c e  - 960a c d e - 640b c d)x
+--R             + 
+--R                         3 2          4          4   2
+--R               (- 1120a c e  - 1280b c e - 640a c d)x
+--R             + 
+--R                         4          5           5
+--R               (- 1280a c e - 512b c )x - 512a c
+--R          *
+--R                  +------------------+
+--R              +-+ | 2 2             2
+--R             \|c \|b x  + 2a b x + a
+--R         + 
+--R                 2 5      2     3      2 2 2   7
+--R               (b e  + 40b c d e  + 80b c d e)x
+--R             + 
+--R                         5      2   4              3       2 2   2
+--R                   2a b e  + 50b c e  + 80a b c d e  + 400b c d e
+--R                 + 
+--R                           2 2        2 3 2
+--R                   160a b c d e + 160b c d
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                    2 5             4       2          2 2  3           2   2
+--R                   a e  + 100a b c e  + (40a c d + 400b c )e  + 800a b c d e
+--R                 + 
+--R                       2 2 2       2 3              3 2
+--R                   (80a c d  + 960b c d)e + 320a b c d
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                      2   4           2 3        2 2         2 3  2
+--R                   50a c e  + 800a b c e  + (400a c d + 1120b c )e
+--R                 + 
+--R                            3          2 3 2       2 4
+--R                   1920a b c d e + 160a c d  + 640b c d
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         2 2 3            3 2        2 3         2 4
+--R                     400a c e  + 2240a b c e  + (960a c d + 1280b c )e
+--R                   + 
+--R                              4
+--R                     1280a b c d
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                     2 3 2            4        2 4        2 5  2
+--R               (1120a c e  + 2560a b c e + 640a c d + 512b c )x
+--R             + 
+--R                     2 4             5         2 5
+--R               (1280a c e + 1024a b c )x + 512a c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|d x  + e x + c
+--R     + 
+--R                     4        2 2 2        3 3  7
+--R           (10b c d e  + 80b c d e  + 32b c d )x
+--R         + 
+--R                      5            4         2   3        2 2 2         3 2
+--R               10b c e  + 10a c d e  + 240b c d e  + 80a c d e  + 416b c d e
+--R             + 
+--R                    3 3
+--R               32a c d
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      5         2 4         2   3          3   2         3 2
+--R               10a c e  + 170b c e  + 240a c d e  + 1136b c d e  + 416a c d e
+--R             + 
+--R                     4 2
+--R               416b c d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                  2 4         3 3          3   2          4            4 2  4
+--R           (170a c e  + 832b c e  + 1136a c d e  + 1792b c d e + 416a c d )x
+--R         + 
+--R                  3 3          4 2          4            5   3
+--R           (832a c e  + 1696b c e  + 1792a c d e + 896b c d)x
+--R         + 
+--R                   4 2          5          5   2           5          6
+--R           (1696a c e  + 1536b c e + 896a c d)x  + (1536a c e + 512b c )x
+--R         + 
+--R                 6
+--R           512a c
+--R      *
+--R          +------------------+
+--R          | 2 2             2
+--R         \|b x  + 2a b x + a
+--R     + 
+--R             2     4      2 2 2 2      2 3 3  8
+--R       (- 10b c d e  - 80b c d e  - 32b c d )x
+--R     + 
+--R                2   5              4       2 2   3           2 2 2       2 3 2
+--R           - 10b c e  - 20a b c d e  - 240b c d e  - 160a b c d e  - 416b c d e
+--R         + 
+--R                    3 3
+--R           - 64a b c d
+--R      *
+--R          7
+--R         x
+--R     + 
+--R                      5         2          2 2  4           2   3
+--R           - 20a b c e  + (- 10a c d - 170b c )e  - 480a b c d e
+--R         + 
+--R                 2 2 2        2 3   2           3 2       2 3 3       2 4 2
+--R           (- 80a c d  - 1136b c d)e  - 832a b c d e - 32a c d  - 416b c d
+--R      *
+--R          6
+--R         x
+--R     + 
+--R                2   5           2 4          2 2        2 3  3            3   2
+--R           - 10a c e  - 340a b c e  + (- 240a c d - 832b c )e  - 2272a b c d e
+--R         + 
+--R                  2 3 2        2 4              4 2
+--R           (- 416a c d  - 1792b c d)e - 832a b c d
+--R      *
+--R          5
+--R         x
+--R     + 
+--R                 2 2 4            3 3           2 3         2 4  2
+--R           - 170a c e  - 1664a b c e  + (- 1136a c d - 1696b c )e
+--R         + 
+--R                      4          2 4 2       2 5
+--R           - 3584a b c d e - 416a c d  - 896b c d
+--R      *
+--R          4
+--R         x
+--R     + 
+--R              2 3 3            4 2           2 4         2 5              5   3
+--R       (- 832a c e  - 3392a b c e  + (- 1792a c d - 1536b c )e - 1792a b c d)x
+--R     + 
+--R               2 4 2            5        2 5        2 6  2
+--R       (- 1696a c e  - 3072a b c e - 896a c d - 512b c )x
+--R     + 
+--R               2 5             6         2 6
+--R       (- 1536a c e - 1024a b c )x - 512a c
+--R  /
+--R                 4      2   2      3 2  6        2 3       3     5
+--R           (10c e  + 80c d e  + 32c d )x  + (160c e  + 384c d e)x
+--R         + 
+--R                3 2       4   4        4   3       5 2
+--R           (672c e  + 384c d)x  + 1024c e x  + 512c x
+--R      *
+--R          +------------------+ +--------------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + e x + c
+--R     + 
+--R               5          3      2 2   7           4       2   2       3 2  6
+--R           (- e  - 40c d e  - 80c d e)x  + (- 50c e  - 400c d e  - 160c d )x
+--R         + 
+--R                  2 3       3     5           3 2       4   4        4   3
+--R           (- 400c e  - 960c d e)x  + (- 1120c e  - 640c d)x  - 1280c e x
+--R         + 
+--R                 5 2
+--R           - 512c x
+--R      *
+--R              +------------------+
+--R          +-+ | 2 2             2
+--R         \|c \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 521
+
+)clear all
+
+--S 522 of 556
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/x^3
+--R 
+--R
+--R         +------------------+ +--------------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + e x + c
+--R   (1)  --------------------------------------
+--R                           3
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 556
+r0:=-1/2*a*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(c*x^2*(a+b*x))-_
+   1/8*(4*a*c*d+4*b*c*e-a*e^2)*atanh(1/2*(2*c+e*x)/(sqrt(c)*_
+   sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x+b^2*x^2)/(c^(3/2)*(a+b*x))+_
+   b*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(d)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(a+b*x)-1/4*(4*b*c-a*e-2*a*d*x)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/(c*x*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                                    +------------------+
+--R             2                    2 | 2 2             2
+--R         (a e  - 4b c e - 4a c d)x \|b x  + 2a b x + a
+--R      *
+--R                      e x + 2c
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|d x  + e x + c
+--R     + 
+--R                       +------------------+
+--R             2 +-+ +-+ | 2 2             2              2d x + e
+--R       8b c x \|c \|d \|b x  + 2a b x + a  atanh(----------------------)
+--R                                                       +--------------+
+--R                                                   +-+ |   2
+--R                                                 2\|d \|d x  + e x + c
+--R     + 
+--R                                     +------------------+ +--------------+
+--R                                 +-+ | 2 2             2  |   2
+--R       ((- 2a e - 8b c)x - 4a c)\|c \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R            3         2  +-+
+--R     (8b c x  + 8a c x )\|c
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 556
+--a0:=integrate(t0,x)
+--E 524
+
+--S 525 of 556
+--m0:=a0-r0
+--E 525
+
+--S 526 of 556
+--d0:=D(m0,x)
+--E 526
+
+)clear all
+
+--S 527 of 556
+t0:=x*sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          +--------------+ +-------------------+
+--R          |   2            | 2 4         2    2
+--R   (1)  x\|d x  + e x + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 556
+r0:=1/3*a*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))-_
+   1/240*b*(8*c*d-35*e^2)*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (d^3*(a+b*x^2))+1/5*b*x^2*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d*(a+b*x^2))-1/40*b*(4*c+7*e*x)*(c+e*x+d*x^2)^(3/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^2*(a+b*x^2))-1/16*a*e*(4*c*d-e^2)*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d^(5/2)*(a+b*x^2))+1/256*b*e*(12*c*d-7*e^2)*(4*c*d-e^2)*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d^(9/2)*(a+b*x^2))-1/8*a*e*(e+2*d*x)*sqrt(c+e*x+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^2*(a+b*x^2))+1/128*b*e*(12*c*d-7*e^2)*_
+   (e+2*d*x)*sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^4*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                5          2             3              3         2 2
+--R         (105b e  + (240a d  - 600b c d)e  + (- 960a c d  + 720b c d )e)
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2              2d x + e
+--R         \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                           +--------------+
+--R                                       +-+ |   2
+--R                                     2\|d \|d x  + e x + c
+--R     + 
+--R                 4 4        3   3            2 2          4           3  2
+--R           768b d x  + 96b d e x  + (- 112b d e  + 1280a d  + 256b c d )x
+--R         + 
+--R                    3          3           2             4
+--R           (140b d e  + (320a d  - 464b c d )e)x - 210b e
+--R         + 
+--R                    2             2            3         2 2
+--R           (- 480a d  + 920b c d)e  + 1280a c d  - 512b c d
+--R      *
+--R              +--------------+ +-------------------+
+--R          +-+ |   2            | 2 4         2    2
+--R         \|d \|d x  + e x + c \|b x  + 2a b x  + a
+--R  /
+--R             4 2          4  +-+
+--R     (3840b d x  + 3840a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 528
+
+--S 529 of 556
+--a0:=integrate(t0,x)
+--E 529
+
+--S 530 of 556
+--m0:=a0-r0
+--E 530
+
+--S 531 of 556
+--d0:=D(m0,x)
+--E 531
+
+)clear all
+
+--S 532 of 556
+t0:=sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         +--------------+ +-------------------+
+--R         |   2            | 2 4         2    2
+--R   (1)  \|d x  + e x + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 556
+r0:=-1/24*b*(5*e-6*d*x)*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (d^2*(a+b*x^2))-1/128*(4*c*d-e^2)*(4*b*c*d-16*a*d^2-5*b*e^2)*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d^(7/2)*(a+b*x^2))-1/64*(4*b*c*d-16*a*d^2-5*b*e^2)*(e+2*d*x)*_
+   sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^3*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                 4           2            2           3        2 2
+--R         (- 15b e  + (- 48a d  + 72b c d)e  + 192a c d  - 48b c d )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2              2d x + e
+--R         \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                           +--------------+
+--R                                       +-+ |   2
+--R                                     2\|d \|d x  + e x + c
+--R     + 
+--R                3 3        2   2             2         3          2          3
+--R           96b d x  + 16b d e x  + (- 20b d e  + 192a d  + 48b c d )x + 30b e
+--R         + 
+--R                 2
+--R           (96a d  - 104b c d)e
+--R      *
+--R              +--------------+ +-------------------+
+--R          +-+ |   2            | 2 4         2    2
+--R         \|d \|d x  + e x + c \|b x  + 2a b x  + a
+--R  /
+--R            3 2         3  +-+
+--R     (384b d x  + 384a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 556
+--a0:=integrate(t0,x)
+--E 534
+
+--S 535 of 556
+--m0:=a0-r0
+--E 535
+
+--S 536 of 556
+--d0:=D(m0,x)
+--E 536
+
+)clear all
+
+--S 537 of 556
+t0:=sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x
+--R 
+--R
+--R         +--------------+ +-------------------+
+--R         |   2            | 2 4         2    2
+--R        \|d x  + e x + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 556
+r0:=1/3*b*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))-_
+   1/16*b*e*(4*c*d-e^2)*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^(5/2)*(a+b*x^2))-a*atanh(1/2*(2*c+e*x)/_
+   (sqrt(c)*sqrt(c+e*x+d*x^2)))*sqrt(c)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)+1/2*a*e*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/((a+b*x^2)*sqrt(d))+a*sqrt(c+e*x+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)-1/8*b*e*(e+2*d*x)*_
+   sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                        +-------------------+
+--R              2 +-+ +-+ | 2 4         2    2              e x + 2c
+--R       - 48a d \|c \|d \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                                         +--------------+
+--R                                                     +-+ |   2
+--R                                                   2\|c \|d x  + e x + c
+--R     + 
+--R                                       +-------------------+
+--R              3         2              | 2 4         2    2
+--R         (3b e  + (24a d  - 12b c d)e)\|b x  + 2a b x  + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R                                                              +--------------+
+--R               2 2                  2        2            +-+ |   2
+--R         (16b d x  + 4b d e x - 6b e  + 48a d  + 16b c d)\|d \|d x  + e x + c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R  /
+--R           2 2        2  +-+
+--R     (48b d x  + 48a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 556
+--a0:=integrate(t0,x)
+--E 539
+
+--S 540 of 556
+--m0:=a0-r0
+--E 540
+
+--S 541 of 556
+--d0:=D(m0,x)
+--E 541
+
+)clear all
+
+--S 542 of 556
+t0:=sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^2
+--R 
+--R
+--R         +--------------+ +-------------------+
+--R         |   2            | 2 4         2    2
+--R        \|d x  + e x + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------
+--R                            2
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 556
+r0:=1/8*b*(4*c*d-e^2)*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^(3/2)*(a+b*x^2))-1/2*a*e*atanh(1/2*_
+   (2*c+e*x)/(sqrt(c)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   ((a+b*x^2)*sqrt(c))+a*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(d)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)-a*sqrt(c+e*x+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x*(a+b*x^2))+1/4*b*(e+2*d*x)*_
+   sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                      +-------------------+
+--R                  +-+ | 2 4         2    2              e x + 2c
+--R       - 4a d e x\|d \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                                       +--------------+
+--R                                                   +-+ |   2
+--R                                                 2\|c \|d x  + e x + c
+--R     + 
+--R                                        +-------------------+
+--R               2       2            +-+ | 2 4         2    2
+--R         (- b e  + 8a d  + 4b c d)x\|c \|b x  + 2a b x  + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R                                         +--------------+ +-------------------+
+--R              2                  +-+ +-+ |   2            | 2 4         2    2
+--R       (4b d x  + 2b e x - 8a d)\|c \|d \|d x  + e x + c \|b x  + 2a b x  + a
+--R  /
+--R            3           +-+ +-+
+--R     (8b d x  + 8a d x)\|c \|d
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 556
+--a0:=integrate(t0,x)
+--E 544
+
+--S 545 of 556
+--m0:=a0-r0
+--E 545
+
+--S 546 of 556
+--d0:=D(m0,x)
+--E 546
+
+)clear all
+
+--S 547 of 556
+t0:=sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3
+--R 
+--R
+--R         +--------------+ +-------------------+
+--R         |   2            | 2 4         2    2
+--R        \|d x  + e x + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------
+--R                            3
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 556
+r0:=-1/8*a*(4*c*d-e^2)*atanh(1/2*(2*c+e*x)/(sqrt(c)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c^(3/2)*(a+b*x^2))-b*atanh(1/2*(2*c+e*x)/_
+   (sqrt(c)*sqrt(c+e*x+d*x^2)))*sqrt(c)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)+1/2*b*e*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/((a+b*x^2)*sqrt(d))+b*sqrt(c+e*x+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)-1/4*a*(2*c+e*x)*sqrt(c+e*x+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*x^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                       +-------------------+
+--R             2                2  2 +-+ | 2 4         2    2
+--R         (a e  - 4a c d - 8b c )x \|d \|b x  + 2a b x  + a
+--R      *
+--R                      e x + 2c
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|d x  + e x + c
+--R     + 
+--R                     +-------------------+
+--R               2 +-+ | 2 4         2    2              2d x + e
+--R       4b c e x \|c \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|d \|d x  + e x + c
+--R     + 
+--R                                         +--------------+ +-------------------+
+--R              2                  +-+ +-+ |   2            | 2 4         2    2
+--R       (8b c x  - 2a e x - 4a c)\|c \|d \|d x  + e x + c \|b x  + 2a b x  + a
+--R  /
+--R            4         2  +-+ +-+
+--R     (8b c x  + 8a c x )\|c \|d
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 556
+--a0:=integrate(t0,x)
+--E 549
+
+--S 550 of 556
+--m0:=a0-r0
+--E 550
+
+--S 551 of 556
+--d0:=D(m0,x)
+--E 551
+
+)clear all
+
+--S 552 of 556
+t0:=sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^4
+--R 
+--R
+--R         +--------------+ +-------------------+
+--R         |   2            | 2 4         2    2
+--R        \|d x  + e x + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------
+--R                            4
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 556
+r0:=-1/3*a*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*x^3*_
+   (a+b*x^2))+1/16*a*e*(4*c*d-e^2)*atanh(1/2*(2*c+e*x)/(sqrt(c)*_
+   sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c^(5/2)*(a+b*x^2))-_
+   1/2*b*e*atanh(1/2*(2*c+e*x)/(sqrt(c)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/((a+b*x^2)*sqrt(c))+b*atanh(1/2*(e+2*d*x)/_
+   (sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(d)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)-b*sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x*(a+b*x^2))+_
+   1/8*a*e*(2*c+e*x)*sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (c^2*x^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                           +-------------------+
+--R                3                   2    3 | 2 4         2    2
+--R         (- 3a e  + (12a c d - 24b c )e)x \|b x  + 2a b x  + a
+--R      *
+--R                      e x + 2c
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|d x  + e x + c
+--R     + 
+--R                        +-------------------+
+--R            2 3 +-+ +-+ | 2 4         2    2              2d x + e
+--R       48b c x \|c \|d \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                                         +--------------+
+--R                                                     +-+ |   2
+--R                                                   2\|d \|d x  + e x + c
+--R     + 
+--R                                                                +--------------+
+--R               2                  2  2                   2  +-+ |   2
+--R         ((6a e  - 16a c d - 48b c )x  - 4a c e x - 16a c )\|c \|d x  + e x + c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R  /
+--R           2 5        2 3  +-+
+--R     (48b c x  + 48a c x )\|c
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 556
+--a0:=integrate(t0,x)
+--E 554
+
+--S 555 of 556
+--m0:=a0-r0
+--E 555
+
+--S 556 of 556
+--d0:=D(m0,x)
+--E 556
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich14a.input.pamphlet b/src/input/rich14a.input.pamphlet
new file mode 100644
index 0000000..0d0e30a
--- /dev/null
+++ b/src/input/rich14a.input.pamphlet
@@ -0,0 +1,21595 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich14a.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a+b x^2+c x^4)^p|
+There are:
+\begin{itemize}
+\item 255 integrals in this file.
+\item 255 supplied "optimal results".
+\item 307 matching answers.
+\item 0 cases where Axiom answer differs from Rubi
+\item 91 cases where Axiom supplied 2 results.
+\item 12 cases that Axiom failed to integrate.
+\item 31 that contain expressions Axiom does not recognize.
+\end{itemize}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich14a.output
+)spool rich14a.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1370
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          2 4         2    2  m
+--R   (1)  (b x  + 2a b x  + a )x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1370
+r0:=a^2*x^(1+m)/(1+m)+2*a*b*x^(3+m)/(3+m)+b^2*x^(5+m)/(5+m)
+--R 
+--R
+--R   (2)
+--R         2 2     2      2  m + 5          2                    m + 3
+--R       (b m  + 4b m + 3b )x      + (2a b m  + 12a b m + 10a b)x
+--R     + 
+--R         2 2     2       2  m + 1
+--R       (a m  + 8a m + 15a )x
+--R  /
+--R      3     2
+--R     m  + 9m  + 23m + 15
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 2     2      2  5          2                    3
+--R         (b m  + 4b m + 3b )x  + (2a b m  + 12a b m + 10a b)x
+--R       + 
+--R           2 2     2       2
+--R         (a m  + 8a m + 15a )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      3     2
+--R     m  + 9m  + 23m + 15
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2 2     2      2  5          2                    3
+--R           (b m  + 4b m + 3b )x  + (2a b m  + 12a b m + 10a b)x
+--R         + 
+--R             2 2     2       2
+--R           (a m  + 8a m + 15a )x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           2 2     2      2  m + 5            2                    m + 3
+--R       (- b m  - 4b m - 3b )x      + (- 2a b m  - 12a b m - 10a b)x
+--R     + 
+--R           2 2     2       2  m + 1
+--R       (- a m  - 8a m - 15a )x
+--R  /
+--R      3     2
+--R     m  + 9m  + 23m + 15
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 1370
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 1370
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         2 8         6    2 4
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 6
+
+--S 7 of 1370
+r0:=1/5*a^2*x^5+2/7*a*b*x^7+1/9*b^2*x^9
+--R 
+--R
+--R        1  2 9   2      7   1  2 5
+--R   (2)  - b x  + - a b x  + - a x
+--R        9        7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 7
+
+--S 8 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  2 9   2      7   1  2 5
+--R   (3)  - b x  + - a b x  + - a x
+--R        9        7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 8
+
+--S 9 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 9
+
+--S 10 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 10
+
+)clear all
+
+--S 11 of 1370
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         2 7         5    2 3
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 11
+
+--S 12 of 1370
+r0:=1/4*a^2*x^4+1/3*a*b*x^6+1/8*b^2*x^8
+--R 
+--R
+--R        1  2 8   1      6   1  2 4
+--R   (2)  - b x  + - a b x  + - a x
+--R        8        3          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 12
+
+--S 13 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  2 8   1      6   1  2 4
+--R   (3)  - b x  + - a b x  + - a x
+--R        8        3          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 13
+
+--S 14 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 14
+
+--S 15 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 15
+
+)clear all
+
+--S 16 of 1370
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         2 6         4    2 2
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 16
+
+--S 17 of 1370
+r0:=1/3*a^2*x^3+2/5*a*b*x^5+1/7*b^2*x^7
+--R 
+--R
+--R        1  2 7   2      5   1  2 3
+--R   (2)  - b x  + - a b x  + - a x
+--R        7        5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 17
+
+--S 18 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  2 7   2      5   1  2 3
+--R   (3)  - b x  + - a b x  + - a x
+--R        7        5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 18
+
+--S 19 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 19
+
+--S 20 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 20
+
+)clear all
+
+--S 21 of 1370
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         2 5         3    2
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 21
+
+--S 22 of 1370
+r0:=1/6*(a+b*x^2)^3/b
+--R 
+--R
+--R        1  3 6   1    2 4   1  2   2   1  3
+--R        - b x  + - a b x  + - a b x  + - a
+--R        6        2          2          6
+--R   (2)  -----------------------------------
+--R                         b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 22
+
+--S 23 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  2 6   1      4   1  2 2
+--R   (3)  - b x  + - a b x  + - a x
+--R        6        2          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 23
+
+--S 24 of 1370
+m0:=a0-r0
+--R 
+--R
+--R          1  3
+--R          - a
+--R          6
+--R   (4)  - ----
+--R            b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 24
+
+--S 25 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 25
+
+)clear all
+
+--S 26 of 1370
+t0:=a^2+2*a*b*x^2+b^2*x^4
+--R 
+--R
+--R         2 4         2    2
+--R   (1)  b x  + 2a b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 26
+
+--S 27 of 1370
+r0:=a^2*x+2/3*a*b*x^3+1/5*b^2*x^5
+--R 
+--R
+--R        1  2 5   2      3    2
+--R   (2)  - b x  + - a b x  + a x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 27
+
+--S 28 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  2 5   2      3    2
+--R   (3)  - b x  + - a b x  + a x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 28
+
+--S 29 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 29
+
+--S 30 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 30
+
+)clear all
+
+--S 31 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 31
+
+--S 32 of 1370
+r0:=a*b*x^2+1/4*b^2*x^4+a^2*log(x)
+--R 
+--R
+--R          2          2 4         2
+--R        4a log(x) + b x  + 4a b x
+--R   (2)  --------------------------
+--R                     4
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2          2 4         2
+--R        4a log(x) + b x  + 4a b x
+--R   (3)  --------------------------
+--R                     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 33
+
+--S 34 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 35
+
+)clear all
+
+--S 36 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^2
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 36
+
+--S 37 of 1370
+r0:=-a^2/x+2*a*b*x+1/3*b^2*x^3
+--R 
+--R
+--R         2 4         2     2
+--R        b x  + 6a b x  - 3a
+--R   (2)  --------------------
+--R                 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 37
+
+--S 38 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2 4         2     2
+--R        b x  + 6a b x  - 3a
+--R   (3)  --------------------
+--R                 3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 38
+
+--S 39 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 40
+
+)clear all
+
+--S 41 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^3
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 41
+
+--S 42 of 1370
+r0:=-1/2*a^2/x^2+1/2*b^2*x^2+2*a*b*log(x)
+--R 
+--R
+--R              2          2 4    2
+--R        4a b x log(x) + b x  - a
+--R   (2)  -------------------------
+--R                     2
+--R                   2x
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2          2 4    2
+--R        4a b x log(x) + b x  - a
+--R   (3)  -------------------------
+--R                     2
+--R                   2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 43
+
+--S 44 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^4
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  4
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 46
+
+--S 47 of 1370
+r0:=-1/3*a^2/x^3-2*a*b/x+b^2*x
+--R 
+--R
+--R         2 4         2   1  2
+--R        b x  - 2a b x  - - a
+--R                         3
+--R   (2)  ---------------------
+--R                   3
+--R                  x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 47
+
+--S 48 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 4         2    2
+--R        3b x  - 6a b x  - a
+--R   (3)  --------------------
+--R                   3
+--R                 3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^5
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  5
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 51
+
+--S 52 of 1370
+r0:=-1/4*a^2/x^4-a*b/x^2+b^2*log(x)
+--R 
+--R
+--R          2 4               2    2
+--R        4b x log(x) - 4a b x  - a
+--R   (2)  --------------------------
+--R                      4
+--R                    4x
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 4               2    2
+--R        4b x log(x) - 4a b x  - a
+--R   (3)  --------------------------
+--R                      4
+--R                    4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 53
+
+--S 54 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 55
+
+)clear all
+
+--S 56 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^6
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  6
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 56
+
+--S 57 of 1370
+r0:=-1/5*a^2/x^5-2/3*a*b/x^3-b^2/x
+--R 
+--R
+--R           2 4   2      2   1  2
+--R        - b x  - - a b x  - - a
+--R                 3          5
+--R   (2)  ------------------------
+--R                    5
+--R                   x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 57
+
+--S 58 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 4          2     2
+--R        - 15b x  - 10a b x  - 3a
+--R   (3)  -------------------------
+--R                      5
+--R                   15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 58
+
+--S 59 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^7
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  7
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 61
+
+--S 62 of 1370
+r0:=-1/6*(a+b*x^2)^3/(a*x^6)
+--R 
+--R
+--R          1  3 6   1    2 4   1  2   2   1  3
+--R        - - b x  - - a b x  - - a b x  - - a
+--R          6        2          2          6
+--R   (2)  -------------------------------------
+--R                            6
+--R                         a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 62
+
+--S 63 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 4         2    2
+--R        - 3b x  - 3a b x  - a
+--R   (3)  ----------------------
+--R                    6
+--R                  6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 63
+
+--S 64 of 1370
+m0:=a0-r0
+--R 
+--R
+--R         3
+--R        b
+--R   (4)  --
+--R        6a
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 65
+
+)clear all
+
+--S 66 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^8
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  8
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 66
+
+--S 67 of 1370
+r0:=-1/7*a^2/x^7-2/5*a*b/x^5-1/3*b^2/x^3
+--R 
+--R
+--R          1  2 4   2      2   1  2
+--R        - - b x  - - a b x  - - a
+--R          3        5          7
+--R   (2)  --------------------------
+--R                     7
+--R                    x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 67
+
+--S 68 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 4          2      2
+--R        - 35b x  - 42a b x  - 15a
+--R   (3)  --------------------------
+--R                       7
+--R                   105x
+--R                                         Type: Union(Expression(Integer),...)
+--E 68
+
+--S 69 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 70
+
+)clear all
+
+--S 71 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^9
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  9
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 71
+
+--S 72 of 1370
+r0:=-1/8*a^2/x^8-1/3*a*b/x^6-1/4*b^2/x^4
+--R 
+--R
+--R          1  2 4   1      2   1  2
+--R        - - b x  - - a b x  - - a
+--R          4        3          8
+--R   (2)  --------------------------
+--R                     8
+--R                    x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 72
+
+--S 73 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 4         2     2
+--R        - 6b x  - 8a b x  - 3a
+--R   (3)  -----------------------
+--R                     8
+--R                  24x
+--R                                         Type: Union(Expression(Integer),...)
+--E 73
+
+--S 74 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^10
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                 10
+--R                x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 76
+
+--S 77 of 1370
+r0:=-1/9*a^2/x^9-2/7*a*b/x^7-1/5*b^2/x^5
+--R 
+--R
+--R          1  2 4   2      2   1  2
+--R        - - b x  - - a b x  - - a
+--R          5        7          9
+--R   (2)  --------------------------
+--R                     9
+--R                    x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 77
+
+--S 78 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 4          2      2
+--R        - 63b x  - 90a b x  - 35a
+--R   (3)  --------------------------
+--R                       9
+--R                   315x
+--R                                         Type: Union(Expression(Integer),...)
+--E 78
+
+--S 79 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 80
+
+)clear all
+
+--S 81 of 1370
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R          4 8       3 6     2 2 4     3   2    4  m
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a )x
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 1370
+r0:=a^4*x^(1+m)/(1+m)+4*a^3*b*x^(3+m)/(3+m)+6*a^2*b^2*x^(5+m)/(5+m)+_
+    4*a*b^3*x^(7+m)/(7+m)+b^4*x^(9+m)/(9+m)
+--R 
+--R
+--R   (2)
+--R         4 4      4 3      4 2       4        4  m + 9
+--R       (b m  + 16b m  + 86b m  + 176b m + 105b )x
+--R     + 
+--R            3 4        3 3         3 2         3          3  m + 7
+--R       (4a b m  + 72a b m  + 416a b m  + 888a b m + 540a b )x
+--R     + 
+--R          2 2 4       2 2 3       2 2 2        2 2         2 2  m + 5
+--R       (6a b m  + 120a b m  + 780a b m  + 1800a b m + 1134a b )x
+--R     + 
+--R          3   4      3   3       3   2        3           3   m + 3
+--R       (4a b m  + 88a b m  + 656a b m  + 1832a b m + 1260a b)x
+--R     + 
+--R         4 4      4 3       4 2       4        4  m + 1
+--R       (a m  + 24a m  + 206a m  + 744a m + 945a )x
+--R  /
+--R      5      4       3       2
+--R     m  + 25m  + 230m  + 950m  + 1689m + 945
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4 4      4 3      4 2       4        4  9
+--R         (b m  + 16b m  + 86b m  + 176b m + 105b )x
+--R       + 
+--R              3 4        3 3         3 2         3          3  7
+--R         (4a b m  + 72a b m  + 416a b m  + 888a b m + 540a b )x
+--R       + 
+--R            2 2 4       2 2 3       2 2 2        2 2         2 2  5
+--R         (6a b m  + 120a b m  + 780a b m  + 1800a b m + 1134a b )x
+--R       + 
+--R            3   4      3   3       3   2        3           3   3
+--R         (4a b m  + 88a b m  + 656a b m  + 1832a b m + 1260a b)x
+--R       + 
+--R           4 4      4 3       4 2       4        4
+--R         (a m  + 24a m  + 206a m  + 744a m + 945a )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      5      4       3       2
+--R     m  + 25m  + 230m  + 950m  + 1689m + 945
+--R                                         Type: Union(Expression(Integer),...)
+--E 83
+
+--S 84 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4 4      4 3      4 2       4        4  9
+--R           (b m  + 16b m  + 86b m  + 176b m + 105b )x
+--R         + 
+--R                3 4        3 3         3 2         3          3  7
+--R           (4a b m  + 72a b m  + 416a b m  + 888a b m + 540a b )x
+--R         + 
+--R              2 2 4       2 2 3       2 2 2        2 2         2 2  5
+--R           (6a b m  + 120a b m  + 780a b m  + 1800a b m + 1134a b )x
+--R         + 
+--R              3   4      3   3       3   2        3           3   3
+--R           (4a b m  + 88a b m  + 656a b m  + 1832a b m + 1260a b)x
+--R         + 
+--R             4 4      4 3       4 2       4        4
+--R           (a m  + 24a m  + 206a m  + 744a m + 945a )x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           4 4      4 3      4 2       4        4  m + 9
+--R       (- b m  - 16b m  - 86b m  - 176b m - 105b )x
+--R     + 
+--R              3 4        3 3         3 2         3          3  m + 7
+--R       (- 4a b m  - 72a b m  - 416a b m  - 888a b m - 540a b )x
+--R     + 
+--R            2 2 4       2 2 3       2 2 2        2 2         2 2  m + 5
+--R       (- 6a b m  - 120a b m  - 780a b m  - 1800a b m - 1134a b )x
+--R     + 
+--R            3   4      3   3       3   2        3           3   m + 3
+--R       (- 4a b m  - 88a b m  - 656a b m  - 1832a b m - 1260a b)x
+--R     + 
+--R           4 4      4 3       4 2       4        4  m + 1
+--R       (- a m  - 24a m  - 206a m  - 744a m - 945a )x
+--R  /
+--R      5      4       3       2
+--R     m  + 25m  + 230m  + 950m  + 1689m + 945
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 1370
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 1370
+t0:=x^6*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 14       3 12     2 2 10     3   8    4 6
+--R   (1)  b x   + 4a b x   + 6a b x   + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 86
+
+--S 87 of 1370
+r0:=1/7*a^4*x^7+4/9*a^3*b*x^9+6/11*a^2*b^2*x^11+4/13*a*b^3*x^13+1/15*b^4*x^15
+--R 
+--R
+--R         1  4 15    4    3 13    6  2 2 11   4  3   9   1  4 7
+--R   (2)  -- b x   + -- a b x   + -- a b x   + - a b x  + - a x
+--R        15         13           11           9          7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 87
+
+--S 88 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  4 15    4    3 13    6  2 2 11   4  3   9   1  4 7
+--R   (3)  -- b x   + -- a b x   + -- a b x   + - a b x  + - a x
+--R        15         13           11           9          7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 88
+
+--S 89 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 89
+
+--S 90 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 90
+
+)clear all
+
+--S 91 of 1370
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 13       3 11     2 2 9     3   7    4 5
+--R   (1)  b x   + 4a b x   + 6a b x  + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 91
+
+--S 92 of 1370
+r0:=1/6*a^4*x^6+1/2*a^3*b*x^8+3/5*a^2*b^2*x^10+1/3*a*b^3*x^12+1/14*b^4*x^14
+--R 
+--R
+--R         1  4 14   1    3 12   3  2 2 10   1  3   8   1  4 6
+--R   (2)  -- b x   + - a b x   + - a b x   + - a b x  + - a x
+--R        14         3           5           2          6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 92
+
+--S 93 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  4 14   1    3 12   3  2 2 10   1  3   8   1  4 6
+--R   (3)  -- b x   + - a b x   + - a b x   + - a b x  + - a x
+--R        14         3           5           2          6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 93
+
+--S 94 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 94
+
+--S 95 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 95
+
+)clear all
+
+--S 96 of 1370
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 12       3 10     2 2 8     3   6    4 4
+--R   (1)  b x   + 4a b x   + 6a b x  + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 96
+
+--S 97 of 1370
+r0:=1/5*a^4*x^5+4/7*a^3*b*x^7+2/3*a^2*b^2*x^9+4/11*a*b^3*x^11+1/13*b^4*x^13
+--R 
+--R
+--R         1  4 13    4    3 11   2  2 2 9   4  3   7   1  4 5
+--R   (2)  -- b x   + -- a b x   + - a b x  + - a b x  + - a x
+--R        13         11           3          7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 97
+
+--S 98 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  4 13    4    3 11   2  2 2 9   4  3   7   1  4 5
+--R   (3)  -- b x   + -- a b x   + - a b x  + - a b x  + - a x
+--R        13         11           3          7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 98
+
+--S 99 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 99
+
+--S 100 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 100
+
+)clear all
+
+--S 101 of 1370
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 11       3 9     2 2 7     3   5    4 3
+--R   (1)  b x   + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 101
+
+--S 102 of 1370
+r0:=-1/10*a*(a+b*x^2)^5/b^2+1/12*(a+b*x^2)^6/b^2
+--R 
+--R
+--R         1  6 12   2    5 10   3  2 4 8   2  3 3 6   1  4 2 4    1  6
+--R        -- b x   + - a b x   + - a b x  + - a b x  + - a b x  - -- a
+--R        12         5           4          3          4          60
+--R   (2)  -------------------------------------------------------------
+--R                                       2
+--R                                      b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 102
+
+--S 103 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  4 12   2    3 10   3  2 2 8   2  3   6   1  4 4
+--R   (3)  -- b x   + - a b x   + - a b x  + - a b x  + - a x
+--R        12         5           4          3          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 103
+
+--S 104 of 1370
+m0:=a0-r0
+--R 
+--R
+--R         1  6
+--R        -- a
+--R        60
+--R   (4)  -----
+--R           2
+--R          b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 104
+
+--S 105 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 105
+
+)clear all
+
+--S 106 of 1370
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 10       3 8     2 2 6     3   4    4 2
+--R   (1)  b x   + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 106
+
+--S 107 of 1370
+r0:=1/3*a^4*x^3+4/5*a^3*b*x^5+6/7*a^2*b^2*x^7+4/9*a*b^3*x^9+1/11*b^4*x^11
+--R 
+--R
+--R         1  4 11   4    3 9   6  2 2 7   4  3   5   1  4 3
+--R   (2)  -- b x   + - a b x  + - a b x  + - a b x  + - a x
+--R        11         9          7          5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 107
+
+--S 108 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  4 11   4    3 9   6  2 2 7   4  3   5   1  4 3
+--R   (3)  -- b x   + - a b x  + - a b x  + - a b x  + - a x
+--R        11         9          7          5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 108
+
+--S 109 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 109
+
+--S 110 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 110
+
+)clear all
+
+--S 111 of 1370
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 9       3 7     2 2 5     3   3    4
+--R   (1)  b x  + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 111
+
+--S 112 of 1370
+r0:=1/10*(a+b*x^2)^5/b
+--R 
+--R
+--R         1  5 10   1    4 8    2 3 6    3 2 4   1  4   2    1  5
+--R        -- b x   + - a b x  + a b x  + a b x  + - a b x  + -- a
+--R        10         2                            2          10
+--R   (2)  --------------------------------------------------------
+--R                                    b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 112
+
+--S 113 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  4 10   1    3 8    2 2 6    3   4   1  4 2
+--R   (3)  -- b x   + - a b x  + a b x  + a b x  + - a x
+--R        10         2                            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 113
+
+--S 114 of 1370
+m0:=a0-r0
+--R 
+--R
+--R           1  5
+--R          -- a
+--R          10
+--R   (4)  - -----
+--R            b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 114
+
+--S 115 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 115
+
+)clear all
+
+--S 116 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R   (1)  b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 116
+
+--S 117 of 1370
+r0:=a^4*x+4/3*a^3*b*x^3+6/5*a^2*b^2*x^5+4/7*a*b^3*x^7+1/9*b^4*x^9
+--R 
+--R
+--R        1  4 9   4    3 7   6  2 2 5   4  3   3    4
+--R   (2)  - b x  + - a b x  + - a b x  + - a b x  + a x
+--R        9        7          5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 117
+
+--S 118 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  4 9   4    3 7   6  2 2 5   4  3   3    4
+--R   (3)  - b x  + - a b x  + - a b x  + - a b x  + a x
+--R        9        7          5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 118
+
+--S 119 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 119
+
+--S 120 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 120
+
+)clear all
+
+--S 121 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 121
+
+--S 122 of 1370
+r0:=2*a^3*b*x^2+3/2*a^2*b^2*x^4+2/3*a*b^3*x^6+1/8*b^4*x^8+a^4*log(x)
+--R 
+--R
+--R           4           4 8        3 6      2 2 4      3   2
+--R        24a log(x) + 3b x  + 16a b x  + 36a b x  + 48a b x
+--R   (2)  ---------------------------------------------------
+--R                                 24
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4           4 8        3 6      2 2 4      3   2
+--R        24a log(x) + 3b x  + 16a b x  + 36a b x  + 48a b x
+--R   (3)  ---------------------------------------------------
+--R                                 24
+--R                                         Type: Union(Expression(Integer),...)
+--E 123
+
+--S 124 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 125
+
+)clear all
+
+--S 126 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^2
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            2
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 126
+
+--S 127 of 1370
+r0:=-a^4/x+4*a^3*b*x+2*a^2*b^2*x^3+4/5*a*b^3*x^5+1/7*b^4*x^7
+--R 
+--R
+--R          4 8        3 6      2 2 4       3   2      4
+--R        5b x  + 28a b x  + 70a b x  + 140a b x  - 35a
+--R   (2)  ----------------------------------------------
+--R                              35x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 127
+
+--S 128 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4 8        3 6      2 2 4       3   2      4
+--R        5b x  + 28a b x  + 70a b x  + 140a b x  - 35a
+--R   (3)  ----------------------------------------------
+--R                              35x
+--R                                         Type: Union(Expression(Integer),...)
+--E 128
+
+--S 129 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 130
+
+)clear all
+
+--S 131 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^3
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            3
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 131
+
+--S 132 of 1370
+r0:=-1/2*a^4/x^2+3*a^2*b^2*x^2+a*b^3*x^4+1/6*b^4*x^6+4*a^3*b*log(x)
+--R 
+--R
+--R           3   2          4 8       3 6      2 2 4     4
+--R        24a b x log(x) + b x  + 6a b x  + 18a b x  - 3a
+--R   (2)  ------------------------------------------------
+--R                                 2
+--R                               6x
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3   2          4 8       3 6      2 2 4     4
+--R        24a b x log(x) + b x  + 6a b x  + 18a b x  - 3a
+--R   (3)  ------------------------------------------------
+--R                                 2
+--R                               6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 133
+
+--S 134 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^4
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            4
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 136
+
+--S 137 of 1370
+r0:=-1/3*a^4/x^3-4*a^3*b/x+6*a^2*b^2*x+4/3*a*b^3*x^3+1/5*b^4*x^5
+--R 
+--R
+--R        1  4 8   4    3 6     2 2 4     3   2   1  4
+--R        - b x  + - a b x  + 6a b x  - 4a b x  - - a
+--R        5        3                              3
+--R   (2)  --------------------------------------------
+--R                              3
+--R                             x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 137
+
+--S 138 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4 8        3 6      2 2 4      3   2     4
+--R        3b x  + 20a b x  + 90a b x  - 60a b x  - 5a
+--R   (3)  --------------------------------------------
+--R                               3
+--R                            15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 138
+
+--S 139 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 140
+
+)clear all
+
+--S 141 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^5
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            5
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 141
+
+--S 142 of 1370
+r0:=-1/4*a^4/x^4-2*a^3*b/x^2+2*a*b^3*x^2+1/4*b^4*x^4+6*a^2*b^2*log(x)
+--R 
+--R
+--R           2 2 4          4 8       3 6     3   2    4
+--R        24a b x log(x) + b x  + 8a b x  - 8a b x  - a
+--R   (2)  ----------------------------------------------
+--R                                4
+--R                              4x
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2 4          4 8       3 6     3   2    4
+--R        24a b x log(x) + b x  + 8a b x  - 8a b x  - a
+--R   (3)  ----------------------------------------------
+--R                                4
+--R                              4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 143
+
+--S 144 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 145
+
+)clear all
+
+--S 146 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^6
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            6
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 146
+
+--S 147 of 1370
+r0:=-1/5*a^4/x^5-4/3*a^3*b/x^3-6*a^2*b^2/x+4*a*b^3*x+1/3*b^4*x^3
+--R 
+--R
+--R        1  4 8       3 6     2 2 4   4  3   2   1  4
+--R        - b x  + 4a b x  - 6a b x  - - a b x  - - a
+--R        3                            3          5
+--R   (2)  --------------------------------------------
+--R                              5
+--R                             x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 147
+
+--S 148 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4 8        3 6      2 2 4      3   2     4
+--R        5b x  + 60a b x  - 90a b x  - 20a b x  - 3a
+--R   (3)  --------------------------------------------
+--R                               5
+--R                            15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 148
+
+--S 149 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^7
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            7
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 151
+
+--S 152 of 1370
+r0:=-1/6*a^4/x^6-a^3*b/x^4-3*a^2*b^2/x^2+1/2*b^4*x^2+4*a*b^3*log(x)
+--R 
+--R
+--R             3 6           4 8      2 2 4     3   2    4
+--R        24a b x log(x) + 3b x  - 18a b x  - 6a b x  - a
+--R   (2)  ------------------------------------------------
+--R                                 6
+--R                               6x
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 6           4 8      2 2 4     3   2    4
+--R        24a b x log(x) + 3b x  - 18a b x  - 6a b x  - a
+--R   (3)  ------------------------------------------------
+--R                                 6
+--R                               6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 153
+
+--S 154 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 155
+
+)clear all
+
+--S 156 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^8
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            8
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 156
+
+--S 157 of 1370
+r0:=-1/7*a^4/x^7-4/5*a^3*b/x^5-2*a^2*b^2/x^3-4*a*b^3/x+b^4*x
+--R 
+--R
+--R         4 8       3 6     2 2 4   4  3   2   1  4
+--R        b x  - 4a b x  - 2a b x  - - a b x  - - a
+--R                                   5          7
+--R   (2)  ------------------------------------------
+--R                             7
+--R                            x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 157
+
+--S 158 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4 8         3 6      2 2 4      3   2     4
+--R        35b x  - 140a b x  - 70a b x  - 28a b x  - 5a
+--R   (3)  ----------------------------------------------
+--R                                7
+--R                             35x
+--R                                         Type: Union(Expression(Integer),...)
+--E 158
+
+--S 159 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 160
+
+)clear all
+
+--S 161 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^9
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            9
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 161
+
+--S 162 of 1370
+r0:=-1/8*a^4/x^8-2/3*a^3*b/x^6-3/2*a^2*b^2/x^4-2*a*b^3/x^2+b^4*log(x)
+--R 
+--R
+--R           4 8              3 6      2 2 4      3   2     4
+--R        24b x log(x) - 48a b x  - 36a b x  - 16a b x  - 3a
+--R   (2)  ---------------------------------------------------
+--R                                   8
+--R                                24x
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4 8              3 6      2 2 4      3   2     4
+--R        24b x log(x) - 48a b x  - 36a b x  - 16a b x  - 3a
+--R   (3)  ---------------------------------------------------
+--R                                   8
+--R                                24x
+--R                                         Type: Union(Expression(Integer),...)
+--E 163
+
+--S 164 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^10
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           10
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 166
+
+--S 167 of 1370
+r0:=-1/9*a^4/x^9-4/7*a^3*b/x^7-6/5*a^2*b^2/x^5-4/3*a*b^3/x^3-b^4/x
+--R 
+--R
+--R           4 8   4    3 6   6  2 2 4   4  3   2   1  4
+--R        - b x  - - a b x  - - a b x  - - a b x  - - a
+--R                 3          5          7          9
+--R   (2)  ----------------------------------------------
+--R                               9
+--R                              x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 167
+
+--S 168 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4 8         3 6       2 2 4       3   2      4
+--R        - 315b x  - 420a b x  - 378a b x  - 180a b x  - 35a
+--R   (3)  ----------------------------------------------------
+--R                                    9
+--R                                315x
+--R                                         Type: Union(Expression(Integer),...)
+--E 168
+
+--S 169 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 170
+
+)clear all
+
+--S 171 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^11
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           11
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 171
+
+--S 172 of 1370
+r0:=-1/10*(a+b*x^2)^5/(a*x^10)
+--R 
+--R
+--R           1  5 10   1    4 8    2 3 6    3 2 4   1  4   2    1  5
+--R        - -- b x   - - a b x  - a b x  - a b x  - - a b x  - -- a
+--R          10         2                            2          10
+--R   (2)  ----------------------------------------------------------
+--R                                      10
+--R                                   a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 172
+
+--S 173 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4 8        3 6      2 2 4     3   2    4
+--R        - 5b x  - 10a b x  - 10a b x  - 5a b x  - a
+--R   (3)  --------------------------------------------
+--R                               10
+--R                            10x
+--R                                         Type: Union(Expression(Integer),...)
+--E 173
+
+--S 174 of 1370
+m0:=a0-r0
+--R 
+--R
+--R          5
+--R         b
+--R   (4)  ---
+--R        10a
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 175
+
+)clear all
+
+--S 176 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^12
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           12
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 176
+
+--S 177 of 1370
+r0:=-1/11*a^4/x^11-4/9*a^3*b/x^9-6/7*a^2*b^2/x^7-4/5*a*b^3/x^5-1/3*b^4/x^3
+--R 
+--R
+--R          1  4 8   4    3 6   6  2 2 4   4  3   2    1  4
+--R        - - b x  - - a b x  - - a b x  - - a b x  - -- a
+--R          3        5          7          9          11
+--R   (2)  -------------------------------------------------
+--R                                11
+--R                               x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 177
+
+--S 178 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4 8          3 6        2 2 4        3   2       4
+--R        - 1155b x  - 2772a b x  - 2970a b x  - 1540a b x  - 315a
+--R   (3)  ---------------------------------------------------------
+--R                                      11
+--R                                 3465x
+--R                                         Type: Union(Expression(Integer),...)
+--E 178
+
+--S 179 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^13
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           13
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 181
+
+--S 182 of 1370
+r0a:=-1/12*(a+b*x^2)^5/(a*x^12)+1/60*b*(a+b*x^2)^5/(a^2*x^10)
+--R 
+--R
+--R         1  6 12   1  2 4 8   2  3 3 6   3  4 2 4   2  5   2    1  6
+--R        -- b x   - - a b x  - - a b x  - - a b x  - - a b x  - -- a
+--R        60         4          3          4          5          12
+--R   (2)  ------------------------------------------------------------
+--R                                     2 12
+--R                                    a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 182
+
+--S 183 of 1370
+r0b:=-1/12*a^4/x^12-2/5*a^3*b/x^10-3/4*a^2*b^2/x^8-2/3*a*b^3/x^6-1/4*b^4/x^4
+--R 
+--R
+--R          1  4 8   2    3 6   3  2 2 4   2  3   2    1  4
+--R        - - b x  - - a b x  - - a b x  - - a b x  - -- a
+--R          4        3          4          5          12
+--R   (3)  -------------------------------------------------
+--R                                12
+--R                               x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 183
+
+--S 184 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4 8        3 6      2 2 4      3   2     4
+--R        - 15b x  - 40a b x  - 45a b x  - 24a b x  - 5a
+--R   (4)  -----------------------------------------------
+--R                                12
+--R                             60x
+--R                                         Type: Union(Expression(Integer),...)
+--E 184
+
+--S 185 of 1370
+m0a:=a0-r0a
+--R 
+--R
+--R            6
+--R           b
+--R   (5)  - ----
+--R             2
+--R          60a
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 1370
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 188
+
+)clear all
+
+--S 189 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^14
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           14
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 189
+
+--S 190 of 1370
+r0:=-1/13*a^4/x^13-4/11*a^3*b/x^11-2/3*a^2*b^2/x^9-4/7*a*b^3/x^7-1/5*b^4/x^5
+--R 
+--R
+--R          1  4 8   4    3 6   2  2 2 4    4  3   2    1  4
+--R        - - b x  - - a b x  - - a b x  - -- a b x  - -- a
+--R          5        7          3          11          13
+--R   (2)  --------------------------------------------------
+--R                                 13
+--R                                x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 190
+
+--S 191 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4 8          3 6         2 2 4        3   2        4
+--R        - 3003b x  - 8580a b x  - 10010a b x  - 5460a b x  - 1155a
+--R   (3)  -----------------------------------------------------------
+--R                                        13
+--R                                  15015x
+--R                                         Type: Union(Expression(Integer),...)
+--E 191
+
+--S 192 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 193
+
+)clear all
+
+--S 194 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^15
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           15
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 194
+
+--S 195 of 1370
+r0:=-1/14*a^4/x^14-1/3*a^3*b/x^12-3/5*a^2*b^2/x^10-1/2*a*b^3/x^8-1/6*b^4/x^6
+--R 
+--R
+--R          1  4 8   1    3 6   3  2 2 4   1  3   2    1  4
+--R        - - b x  - - a b x  - - a b x  - - a b x  - -- a
+--R          6        2          5          3          14
+--R   (2)  -------------------------------------------------
+--R                                14
+--R                               x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 195
+
+--S 196 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4 8         3 6       2 2 4      3   2      4
+--R        - 35b x  - 105a b x  - 126a b x  - 70a b x  - 15a
+--R   (3)  --------------------------------------------------
+--R                                  14
+--R                              210x
+--R                                         Type: Union(Expression(Integer),...)
+--E 196
+
+--S 197 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^16
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           16
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 199
+
+--S 200 of 1370
+r0:=-1/15*a^4/x^15-4/13*a^3*b/x^13-6/11*a^2*b^2/x^11-4/9*a*b^3/x^9-1/7*b^4/x^7
+--R 
+--R
+--R          1  4 8   4    3 6    6  2 2 4    4  3   2    1  4
+--R        - - b x  - - a b x  - -- a b x  - -- a b x  - -- a
+--R          7        9          11          13          15
+--R   (2)  ---------------------------------------------------
+--R                                 15
+--R                                x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 200
+
+--S 201 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4 8           3 6         2 2 4         3   2        4
+--R        - 6435b x  - 20020a b x  - 24570a b x  - 13860a b x  - 3003a
+--R   (3)  -------------------------------------------------------------
+--R                                         15
+--R                                   45045x
+--R                                         Type: Union(Expression(Integer),...)
+--E 201
+
+--S 202 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 203
+
+)clear all
+
+--S 204 of 1370
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6  m
+--R   (1)  (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a )x
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 1370
+r0:=a^6*x^(1+m)/(1+m)+6*a^5*b*x^(3+m)/(3+m)+15*a^4*b^2*x^(5+m)/(5+m)+_
+    20*a^3*b^3*x^(7+m)/(7+m)+15*a^2*b^4*x^(9+m)/(9+m)+6*a*b^5*_
+    x^(11+m)/(11+m)+b^6*x^(13+m)/(13+m)
+--R 
+--R
+--R   (2)
+--R           6 6      6 5       6 4        6 3         6 2         6          6
+--R         (b m  + 36b m  + 505b m  + 3480b m  + 12139b m  + 19524b m + 10395b )
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R               5 6         5 5          5 4           5 3           5 2
+--R           6a b m  + 228a b m  + 3330a b m  + 23640a b m  + 84234a b m
+--R         + 
+--R                    5            5
+--R           137412a b m + 73710a b
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R              2 4 6       2 4 5        2 4 4         2 4 3          2 4 2
+--R           15a b m  + 600a b m  + 9195a b m  + 67920a b m  + 249405a b m
+--R         + 
+--R                  2 4           2 4
+--R           415320a b m + 225225a b
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R              3 3 6       3 3 5         3 3 4          3 3 3          3 3 2
+--R           20a b m  + 840a b m  + 13580a b m  + 105840a b m  + 406700a b m
+--R         + 
+--R                  3 3           3 3
+--R           699720a b m + 386100a b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R              4 2 6       4 2 5         4 2 4         4 2 3          4 2 2
+--R           15a b m  + 660a b m  + 11295a b m  + 94200a b m  + 389685a b m
+--R         + 
+--R                  4 2           4 2
+--R           711540a b m + 405405a b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R             5   6       5   5        5   4         5   3          5   2
+--R           6a b m  + 276a b m  + 5010a b m  + 45240a b m  + 208554a b m
+--R         + 
+--R                  5             5
+--R           438324a b m + 270270a b
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R           6 6      6 5       6 4        6 3         6 2          6           6
+--R         (a m  + 48a m  + 925a m  + 9120a m  + 48259a m  + 129072a m + 135135a )
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R      7      6       5         4         3          2
+--R     m  + 49m  + 973m  + 10045m  + 57379m  + 177331m  + 264207m + 135135
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             6 6      6 5       6 4        6 3         6 2         6          6
+--R           (b m  + 36b m  + 505b m  + 3480b m  + 12139b m  + 19524b m + 10395b )
+--R        *
+--R            13
+--R           x
+--R       + 
+--R                 5 6         5 5          5 4           5 3           5 2
+--R             6a b m  + 228a b m  + 3330a b m  + 23640a b m  + 84234a b m
+--R           + 
+--R                      5            5
+--R             137412a b m + 73710a b
+--R        *
+--R            11
+--R           x
+--R       + 
+--R                2 4 6       2 4 5        2 4 4         2 4 3          2 4 2
+--R             15a b m  + 600a b m  + 9195a b m  + 67920a b m  + 249405a b m
+--R           + 
+--R                    2 4           2 4
+--R             415320a b m + 225225a b
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                3 3 6       3 3 5         3 3 4          3 3 3          3 3 2
+--R             20a b m  + 840a b m  + 13580a b m  + 105840a b m  + 406700a b m
+--R           + 
+--R                    3 3           3 3
+--R             699720a b m + 386100a b
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                4 2 6       4 2 5         4 2 4         4 2 3          4 2 2
+--R             15a b m  + 660a b m  + 11295a b m  + 94200a b m  + 389685a b m
+--R           + 
+--R                    4 2           4 2
+--R             711540a b m + 405405a b
+--R        *
+--R            5
+--R           x
+--R       + 
+--R               5   6       5   5        5   4         5   3          5   2
+--R             6a b m  + 276a b m  + 5010a b m  + 45240a b m  + 208554a b m
+--R           + 
+--R                    5             5
+--R             438324a b m + 270270a b
+--R        *
+--R            3
+--R           x
+--R       + 
+--R         6 6      6 5       6 4        6 3         6 2          6           6
+--R       (a m  + 48a m  + 925a m  + 9120a m  + 48259a m  + 129072a m + 135135a )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      7      6       5         4         3          2
+--R     m  + 49m  + 973m  + 10045m  + 57379m  + 177331m  + 264207m + 135135
+--R                                         Type: Union(Expression(Integer),...)
+--E 206
+
+--S 207 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  6 6      6 5       6 4        6 3         6 2         6
+--R                 b m  + 36b m  + 505b m  + 3480b m  + 12139b m  + 19524b m
+--R               + 
+--R                       6
+--R                 10395b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                   5 6         5 5          5 4           5 3           5 2
+--R               6a b m  + 228a b m  + 3330a b m  + 23640a b m  + 84234a b m
+--R             + 
+--R                        5            5
+--R               137412a b m + 73710a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                  2 4 6       2 4 5        2 4 4         2 4 3          2 4 2
+--R               15a b m  + 600a b m  + 9195a b m  + 67920a b m  + 249405a b m
+--R             + 
+--R                      2 4           2 4
+--R               415320a b m + 225225a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                  3 3 6       3 3 5         3 3 4          3 3 3          3 3 2
+--R               20a b m  + 840a b m  + 13580a b m  + 105840a b m  + 406700a b m
+--R             + 
+--R                      3 3           3 3
+--R               699720a b m + 386100a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                  4 2 6       4 2 5         4 2 4         4 2 3          4 2 2
+--R               15a b m  + 660a b m  + 11295a b m  + 94200a b m  + 389685a b m
+--R             + 
+--R                      4 2           4 2
+--R               711540a b m + 405405a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                 5   6       5   5        5   4         5   3          5   2
+--R               6a b m  + 276a b m  + 5010a b m  + 45240a b m  + 208554a b m
+--R             + 
+--R                      5             5
+--R               438324a b m + 270270a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                6 6      6 5       6 4        6 3         6 2          6
+--R               a m  + 48a m  + 925a m  + 9120a m  + 48259a m  + 129072a m
+--R             + 
+--R                      6
+--R               135135a
+--R          *
+--R             x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R             6 6      6 5       6 4        6 3         6 2         6          6
+--R         (- b m  - 36b m  - 505b m  - 3480b m  - 12139b m  - 19524b m - 10395b )
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                 5 6         5 5          5 4           5 3           5 2
+--R           - 6a b m  - 228a b m  - 3330a b m  - 23640a b m  - 84234a b m
+--R         + 
+--R                      5            5
+--R           - 137412a b m - 73710a b
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                2 4 6       2 4 5        2 4 4         2 4 3          2 4 2
+--R           - 15a b m  - 600a b m  - 9195a b m  - 67920a b m  - 249405a b m
+--R         + 
+--R                    2 4           2 4
+--R           - 415320a b m - 225225a b
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                3 3 6       3 3 5         3 3 4          3 3 3          3 3 2
+--R           - 20a b m  - 840a b m  - 13580a b m  - 105840a b m  - 406700a b m
+--R         + 
+--R                    3 3           3 3
+--R           - 699720a b m - 386100a b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R                4 2 6       4 2 5         4 2 4         4 2 3          4 2 2
+--R           - 15a b m  - 660a b m  - 11295a b m  - 94200a b m  - 389685a b m
+--R         + 
+--R                    4 2           4 2
+--R           - 711540a b m - 405405a b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R               5   6       5   5        5   4         5   3          5   2
+--R           - 6a b m  - 276a b m  - 5010a b m  - 45240a b m  - 208554a b m
+--R         + 
+--R                    5             5
+--R           - 438324a b m - 270270a b
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R                6 6      6 5       6 4        6 3         6 2          6
+--R             - a m  - 48a m  - 925a m  - 9120a m  - 48259a m  - 129072a m
+--R           + 
+--R                      6
+--R             - 135135a
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R      7      6       5         4         3          2
+--R     m  + 49m  + 973m  + 10045m  + 57379m  + 177331m  + 264207m + 135135
+--R                                                    Type: Expression(Integer)
+--E 207
+
+--S 208 of 1370
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 208
+
+)clear all
+
+--S 209 of 1370
+t0:=x^8*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 20       5 18      2 4 16      3 3 14      4 2 12     5   10    6 8
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x   + 6a b x   + a x
+--R                                                    Type: Polynomial(Integer)
+--E 209
+
+--S 210 of 1370
+r0:=1/9*a^6*x^9+6/11*a^5*b*x^11+15/13*a^4*b^2*x^13+4/3*a^3*b^3*x^15+_
+    15/17*a^2*b^4*x^17+6/19*a*b^5*x^19+1/21*b^6*x^21
+--R 
+--R
+--R   (2)
+--R      1  6 21    6    5 19   15  2 4 17   4  3 3 15   15  4 2 13    6  5   11
+--R     -- b x   + -- a b x   + -- a b x   + - a b x   + -- a b x   + -- a b x
+--R     21         19           17           3           13           11
+--R   + 
+--R     1  6 9
+--R     - a x
+--R     9
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 210
+
+--S 211 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  6 21    6    5 19   15  2 4 17   4  3 3 15   15  4 2 13    6  5   11
+--R     -- b x   + -- a b x   + -- a b x   + - a b x   + -- a b x   + -- a b x
+--R     21         19           17           3           13           11
+--R   + 
+--R     1  6 9
+--R     - a x
+--R     9
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 211
+
+--S 212 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 212
+
+--S 213 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 213
+
+)clear all
+
+--S 214 of 1370
+t0:=x^7*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 19       5 17      2 4 15      3 3 13      4 2 11     5   9    6 7
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x   + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 214
+
+--S 215 of 1370
+r0:=1/8*a^6*x^8+3/5*a^5*b*x^10+5/4*a^4*b^2*x^12+10/7*a^3*b^3*x^14+_
+    15/16*a^2*b^4*x^16+1/3*a*b^5*x^18+1/20*b^6*x^20
+--R 
+--R
+--R   (2)
+--R      1  6 20   1    5 18   15  2 4 16   10  3 3 14   5  4 2 12   3  5   10
+--R     -- b x   + - a b x   + -- a b x   + -- a b x   + - a b x   + - a b x
+--R     20         3           16            7           4           5
+--R   + 
+--R     1  6 8
+--R     - a x
+--R     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 215
+
+--S 216 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  6 20   1    5 18   15  2 4 16   10  3 3 14   5  4 2 12   3  5   10
+--R     -- b x   + - a b x   + -- a b x   + -- a b x   + - a b x   + - a b x
+--R     20         3           16            7           4           5
+--R   + 
+--R     1  6 8
+--R     - a x
+--R     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 216
+
+--S 217 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 217
+
+--S 218 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 218
+
+)clear all
+
+--S 219 of 1370
+t0:=x^6*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 18       5 16      2 4 14      3 3 12      4 2 10     5   8    6 6
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x   + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 219
+
+--S 220 of 1370
+r0:=1/7*a^6*x^7+2/3*a^5*b*x^9+15/11*a^4*b^2*x^11+20/13*a^3*b^3*x^13+_
+    a^2*b^4*x^15+6/17*a*b^5*x^17+1/19*b^6*x^19
+--R 
+--R
+--R   (2)
+--R    1  6 19    6    5 17    2 4 15   20  3 3 13   15  4 2 11   2  5   9   1  6 7
+--R   -- b x   + -- a b x   + a b x   + -- a b x   + -- a b x   + - a b x  + - a x
+--R   19         17                     13           11           3          7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 220
+
+--S 221 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R    1  6 19    6    5 17    2 4 15   20  3 3 13   15  4 2 11   2  5   9   1  6 7
+--R   -- b x   + -- a b x   + a b x   + -- a b x   + -- a b x   + - a b x  + - a x
+--R   19         17                     13           11           3          7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 221
+
+--S 222 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 222
+
+--S 223 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 223
+
+)clear all
+
+--S 224 of 1370
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 17       5 15      2 4 13      3 3 11      4 2 9     5   7    6 5
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x  + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 224
+
+--S 225 of 1370
+r0:=1/14*a^2*(a+b*x^2)^7/b^3-1/8*a*(a+b*x^2)^8/b^3+1/18*(a+b*x^2)^9/b^3
+--R 
+--R
+--R   (2)
+--R        1  9 18   3    8 16   15  2 7 14   5  3 6 12   3  4 5 10   3  5 4 8
+--R       -- b x   + - a b x   + -- a b x   + - a b x   + - a b x   + - a b x
+--R       18         8           14           3           2           4
+--R     + 
+--R       1  6 3 6    1   9
+--R       - a b x  + --- a
+--R       6          504
+--R  /
+--R      3
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 225
+
+--S 226 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R    1  6 18   3    5 16   15  2 4 14   5  3 3 12   3  4 2 10   3  5   8   1  6 6
+--R   -- b x   + - a b x   + -- a b x   + - a b x   + - a b x   + - a b x  + - a x
+--R   18         8           14           3           2           4          6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 226
+
+--S 227 of 1370
+m0:=a0-r0
+--R 
+--R
+--R           1   9
+--R          --- a
+--R          504
+--R   (4)  - ------
+--R             3
+--R            b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 227
+
+--S 228 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 228
+
+)clear all
+
+--S 229 of 1370
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 16       5 14      2 4 12      3 3 10      4 2 8     5   6    6 4
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x  + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 229
+
+--S 230 of 1370
+r0:=1/5*a^6*x^5+6/7*a^5*b*x^7+5/3*a^4*b^2*x^9+20/11*a^3*b^3*x^11+_
+    15/13*a^2*b^4*x^13+2/5*a*b^5*x^15+1/17*b^6*x^17
+--R 
+--R
+--R   (2)
+--R    1  6 17   2    5 15   15  2 4 13   20  3 3 11   5  4 2 9   6  5   7   1  6 5
+--R   -- b x   + - a b x   + -- a b x   + -- a b x   + - a b x  + - a b x  + - a x
+--R   17         5           13           11           3          7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 230
+
+--S 231 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R    1  6 17   2    5 15   15  2 4 13   20  3 3 11   5  4 2 9   6  5   7   1  6 5
+--R   -- b x   + - a b x   + -- a b x   + -- a b x   + - a b x  + - a b x  + - a x
+--R   17         5           13           11           3          7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 231
+
+--S 232 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 232
+
+--S 233 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 233
+
+)clear all
+
+--S 234 of 1370
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 15       5 13      2 4 11      3 3 9      4 2 7     5   5    6 3
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 234
+
+--S 235 of 1370
+r0:=-1/14*a*(a+b*x^2)^7/b^2+1/16*(a+b*x^2)^8/b^2
+--R 
+--R
+--R   (2)
+--R        1  8 16   3    7 14   5  2 6 12     3 5 10   15  4 4 8    5 3 6
+--R       -- b x   + - a b x   + - a b x   + 2a b x   + -- a b x  + a b x
+--R       16         7           4                       8
+--R     + 
+--R       1  6 2 4    1   8
+--R       - a b x  - --- a
+--R       4          112
+--R  /
+--R      2
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 235
+
+--S 236 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R    1  6 16   3    5 14   5  2 4 12     3 3 10   15  4 2 8    5   6   1  6 4
+--R   -- b x   + - a b x   + - a b x   + 2a b x   + -- a b x  + a b x  + - a x
+--R   16         7           4                       8                   4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 236
+
+--S 237 of 1370
+m0:=a0-r0
+--R 
+--R
+--R         1   8
+--R        --- a
+--R        112
+--R   (4)  ------
+--R           2
+--R          b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 237
+
+--S 238 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 238
+
+)clear all
+
+--S 239 of 1370
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 14       5 12      2 4 10      3 3 8      4 2 6     5   4    6 2
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 239
+
+--S 240 of 1370
+r0:=1/3*a^6*x^3+6/5*a^5*b*x^5+15/7*a^4*b^2*x^7+20/9*a^3*b^3*x^9+_
+    15/11*a^2*b^4*x^11+6/13*a*b^5*x^13+1/15*b^6*x^15
+--R 
+--R
+--R   (2)
+--R      1  6 15    6    5 13   15  2 4 11   20  3 3 9   15  4 2 7   6  5   5
+--R     -- b x   + -- a b x   + -- a b x   + -- a b x  + -- a b x  + - a b x
+--R     15         13           11            9           7          5
+--R   + 
+--R     1  6 3
+--R     - a x
+--R     3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 240
+
+--S 241 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  6 15    6    5 13   15  2 4 11   20  3 3 9   15  4 2 7   6  5   5
+--R     -- b x   + -- a b x   + -- a b x   + -- a b x  + -- a b x  + - a b x
+--R     15         13           11            9           7          5
+--R   + 
+--R     1  6 3
+--R     - a x
+--R     3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 241
+
+--S 242 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 242
+
+--S 243 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 243
+
+)clear all
+
+--S 244 of 1370
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 13       5 11      2 4 9      3 3 7      4 2 5     5   3    6
+--R   (1)  b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 244
+
+--S 245 of 1370
+r0:=1/14*(a+b*x^2)^7/b
+--R 
+--R
+--R   (2)
+--R        1  7 14   1    6 12   3  2 5 10   5  3 4 8   5  4 3 6   3  5 2 4
+--R       -- b x   + - a b x   + - a b x   + - a b x  + - a b x  + - a b x
+--R       14         2           2           2          2          2
+--R     + 
+--R       1  6   2    1  7
+--R       - a b x  + -- a
+--R       2          14
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 245
+
+--S 246 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R    1  6 14   1    5 12   3  2 4 10   5  3 3 8   5  4 2 6   3  5   4   1  6 2
+--R   -- b x   + - a b x   + - a b x   + - a b x  + - a b x  + - a b x  + - a x
+--R   14         2           2           2          2          2          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 246
+
+--S 247 of 1370
+m0:=a0-r0
+--R 
+--R
+--R           1  7
+--R          -- a
+--R          14
+--R   (4)  - -----
+--R            b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 247
+
+--S 248 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 248
+
+)clear all
+
+--S 249 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R   (1)  b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 249
+
+--S 250 of 1370
+r0:=a^6*x+2*a^5*b*x^3+3*a^4*b^2*x^5+20/7*a^3*b^3*x^7+5/3*a^2*b^4*x^9+_
+    6/11*a*b^5*x^11+1/13*b^6*x^13
+--R 
+--R
+--R         1  6 13    6    5 11   5  2 4 9   20  3 3 7     4 2 5     5   3    6
+--R   (2)  -- b x   + -- a b x   + - a b x  + -- a b x  + 3a b x  + 2a b x  + a x
+--R        13         11           3           7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 250
+
+--S 251 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  6 13    6    5 11   5  2 4 9   20  3 3 7     4 2 5     5   3    6
+--R   (3)  -- b x   + -- a b x   + - a b x  + -- a b x  + 3a b x  + 2a b x  + a x
+--R        13         11           3           7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 251
+
+--S 252 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 252
+
+--S 253 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 253
+
+)clear all
+
+--S 254 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 254
+
+--S 255 of 1370
+r0:=3*a^5*b*x^2+15/4*a^4*b^2*x^4+10/3*a^3*b^3*x^6+15/8*a^2*b^4*x^8+_
+    3/5*a*b^5*x^10+1/12*b^6*x^12+a^6*log(x)
+--R 
+--R
+--R   (2)
+--R           6            6 12        5 10       2 4 8       3 3 6       4 2 4
+--R       120a log(x) + 10b x   + 72a b x   + 225a b x  + 400a b x  + 450a b x
+--R     + 
+--R           5   2
+--R       360a b x
+--R  /
+--R     120
+--R                                                    Type: Expression(Integer)
+--E 255
+
+--S 256 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           6            6 12        5 10       2 4 8       3 3 6       4 2 4
+--R       120a log(x) + 10b x   + 72a b x   + 225a b x  + 400a b x  + 450a b x
+--R     + 
+--R           5   2
+--R       360a b x
+--R  /
+--R     120
+--R                                         Type: Union(Expression(Integer),...)
+--E 256
+
+--S 257 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^2
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        2
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 259
+
+--S 260 of 1370
+r0:=-a^6/x+6*a^5*b*x+5*a^4*b^2*x^3+4*a^3*b^3*x^5+15/7*a^2*b^4*x^7+_
+    2/3*a*b^5*x^9+1/11*b^6*x^11
+--R 
+--R
+--R   (2)
+--R          6 12         5 10       2 4 8       3 3 6        4 2 4        5   2
+--R       21b x   + 154a b x   + 495a b x  + 924a b x  + 1155a b x  + 1386a b x
+--R     + 
+--R             6
+--R       - 231a
+--R  /
+--R     231x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 260
+
+--S 261 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          6 12         5 10       2 4 8       3 3 6        4 2 4        5   2
+--R       21b x   + 154a b x   + 495a b x  + 924a b x  + 1155a b x  + 1386a b x
+--R     + 
+--R             6
+--R       - 231a
+--R  /
+--R     231x
+--R                                         Type: Union(Expression(Integer),...)
+--E 261
+
+--S 262 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 263
+
+)clear all
+
+--S 264 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^3
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        3
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 264
+
+--S 265 of 1370
+r0:=-1/2*a^6/x^2+15/2*a^4*b^2*x^2+5*a^3*b^3*x^4+5/2*a^2*b^4*x^6+_
+    3/4*a*b^5*x^8+1/10*b^6*x^10+6*a^5*b*log(x)
+--R 
+--R
+--R   (2)
+--R           5   2           6 12        5 10      2 4 8       3 3 6       4 2 4
+--R       120a b x log(x) + 2b x   + 15a b x   + 50a b x  + 100a b x  + 150a b x
+--R     + 
+--R            6
+--R       - 10a
+--R  /
+--R        2
+--R     20x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           5   2           6 12        5 10      2 4 8       3 3 6       4 2 4
+--R       120a b x log(x) + 2b x   + 15a b x   + 50a b x  + 100a b x  + 150a b x
+--R     + 
+--R            6
+--R       - 10a
+--R  /
+--R        2
+--R     20x
+--R                                         Type: Union(Expression(Integer),...)
+--E 266
+
+--S 267 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 268
+
+)clear all
+
+--S 269 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^4
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        4
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 269
+
+--S 270 of 1370
+r0:=-1/3*a^6/x^3-6*a^5*b/x+15*a^4*b^2*x+20/3*a^3*b^3*x^3+3*a^2*b^4*x^5+_
+    6/7*a*b^5*x^7+1/9*b^6*x^9
+--R 
+--R
+--R        1  6 12   6    5 10     2 4 8   20  3 3 6      4 2 4     5   2   1  6
+--R        - b x   + - a b x   + 3a b x  + -- a b x  + 15a b x  - 6a b x  - - a
+--R        9         7                      3                               3
+--R   (2)  ---------------------------------------------------------------------
+--R                                           3
+--R                                          x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 270
+
+--S 271 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     6 12        5 10       2 4 8       3 3 6       4 2 4       5   2      6
+--R   7b x   + 54a b x   + 189a b x  + 420a b x  + 945a b x  - 378a b x  - 21a
+--R   -------------------------------------------------------------------------
+--R                                         3
+--R                                      63x
+--R                                         Type: Union(Expression(Integer),...)
+--E 271
+
+--S 272 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^5
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        5
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 274
+
+--S 275 of 1370
+r0:=-1/4*a^6/x^4-3*a^5*b/x^2+10*a^3*b^3*x^2+15/4*a^2*b^4*x^4+a*b^5*x^6+_
+    1/8*b^6*x^8+15*a^4*b^2*log(x)
+--R 
+--R
+--R   (2)
+--R       4 2 4          6 12       5 10      2 4 8      3 3 6      5   2     6
+--R   120a b x log(x) + b x   + 8a b x   + 30a b x  + 80a b x  - 24a b x  - 2a
+--R   -------------------------------------------------------------------------
+--R                                        4
+--R                                      8x
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       4 2 4          6 12       5 10      2 4 8      3 3 6      5   2     6
+--R   120a b x log(x) + b x   + 8a b x   + 30a b x  + 80a b x  - 24a b x  - 2a
+--R   -------------------------------------------------------------------------
+--R                                        4
+--R                                      8x
+--R                                         Type: Union(Expression(Integer),...)
+--E 276
+
+--S 277 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 278
+
+)clear all
+
+--S 279 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^6
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        6
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 279
+
+--S 280 of 1370
+r0:=-1/5*a^6/x^5-2*a^5*b/x^3-15*a^4*b^2/x+20*a^3*b^3*x+5*a^2*b^4*x^3+_
+    6/5*a*b^5*x^5+1/7*b^6*x^7
+--R 
+--R
+--R        1  6 12   6    5 10     2 4 8      3 3 6      4 2 4     5   2   1  6
+--R        - b x   + - a b x   + 5a b x  + 20a b x  - 15a b x  - 2a b x  - - a
+--R        7         5                                                     5
+--R   (2)  --------------------------------------------------------------------
+--R                                          5
+--R                                         x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 280
+
+--S 281 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     6 12        5 10       2 4 8       3 3 6       4 2 4      5   2     6
+--R   5b x   + 42a b x   + 175a b x  + 700a b x  - 525a b x  - 70a b x  - 7a
+--R   -----------------------------------------------------------------------
+--R                                        5
+--R                                     35x
+--R                                         Type: Union(Expression(Integer),...)
+--E 281
+
+--S 282 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 283
+
+)clear all
+
+--S 284 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^7
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        7
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 284
+
+--S 285 of 1370
+r0:=-1/6*a^6/x^6-3/2*a^5*b/x^4-15/2*a^4*b^2/x^2+15/2*a^2*b^4*x^2+_
+    3/2*a*b^5*x^4+1/6*b^6*x^6+20*a^3*b^3*log(x)
+--R 
+--R
+--R   (2)
+--R       3 3 6          6 12       5 10      2 4 8      4 2 4     5   2    6
+--R   120a b x log(x) + b x   + 9a b x   + 45a b x  - 45a b x  - 9a b x  - a
+--R   -----------------------------------------------------------------------
+--R                                       6
+--R                                     6x
+--R                                                    Type: Expression(Integer)
+--E 285
+
+--S 286 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       3 3 6          6 12       5 10      2 4 8      4 2 4     5   2    6
+--R   120a b x log(x) + b x   + 9a b x   + 45a b x  - 45a b x  - 9a b x  - a
+--R   -----------------------------------------------------------------------
+--R                                       6
+--R                                     6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 286
+
+--S 287 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^8
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        8
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 289
+
+--S 290 of 1370
+r0:=-1/7*a^6/x^7-6/5*a^5*b/x^5-5*a^4*b^2/x^3-20*a^3*b^3/x+15*a^2*b^4*x+_
+    2*a*b^5*x^3+1/5*b^6*x^5
+--R 
+--R
+--R        1  6 12       5 10      2 4 8      3 3 6     4 2 4   6  5   2   1  6
+--R        - b x   + 2a b x   + 15a b x  - 20a b x  - 5a b x  - - a b x  - - a
+--R        5                                                    5          7
+--R   (2)  --------------------------------------------------------------------
+--R                                          7
+--R                                         x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 290
+
+--S 291 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     6 12        5 10       2 4 8       3 3 6       4 2 4      5   2     6
+--R   7b x   + 70a b x   + 525a b x  - 700a b x  - 175a b x  - 42a b x  - 5a
+--R   -----------------------------------------------------------------------
+--R                                        7
+--R                                     35x
+--R                                         Type: Union(Expression(Integer),...)
+--E 291
+
+--S 292 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 293
+
+)clear all
+
+--S 294 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^9
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        9
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 294
+
+--S 295 of 1370
+r0:=-1/8*a^6/x^8-a^5*b/x^6-15/4*a^4*b^2/x^4-10*a^3*b^3/x^2+3*a*b^5*x^2+_
+    1/4*b^6*x^4+15*a^2*b^4*log(x)
+--R 
+--R
+--R   (2)
+--R       2 4 8           6 12        5 10      3 3 6      4 2 4     5   2    6
+--R   120a b x log(x) + 2b x   + 24a b x   - 80a b x  - 30a b x  - 8a b x  - a
+--R   -------------------------------------------------------------------------
+--R                                        8
+--R                                      8x
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       2 4 8           6 12        5 10      3 3 6      4 2 4     5   2    6
+--R   120a b x log(x) + 2b x   + 24a b x   - 80a b x  - 30a b x  - 8a b x  - a
+--R   -------------------------------------------------------------------------
+--R                                        8
+--R                                      8x
+--R                                         Type: Union(Expression(Integer),...)
+--E 296
+
+--S 297 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+--S 298 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 298
+
+)clear all
+
+--S 299 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^10
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        10
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 299
+
+--S 300 of 1370
+r0:=-1/9*a^6/x^9-6/7*a^5*b/x^7-3*a^4*b^2/x^5-20/3*a^3*b^3/x^3-15*a^2*b^4/x+_
+    6*a*b^5*x+1/3*b^6*x^3
+--R 
+--R
+--R        1  6 12       5 10      2 4 8   20  3 3 6     4 2 4   6  5   2   1  6
+--R        - b x   + 6a b x   - 15a b x  - -- a b x  - 3a b x  - - a b x  - - a
+--R        3                                3                    7          9
+--R   (2)  ---------------------------------------------------------------------
+--R                                           9
+--R                                          x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 300
+
+--S 301 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      6 12         5 10       2 4 8       3 3 6       4 2 4      5   2     6
+--R   21b x   + 378a b x   - 945a b x  - 420a b x  - 189a b x  - 54a b x  - 7a
+--R   -------------------------------------------------------------------------
+--R                                         9
+--R                                      63x
+--R                                         Type: Union(Expression(Integer),...)
+--E 301
+
+--S 302 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^11
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        11
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 304
+
+--S 305 of 1370
+r0:=-1/10*a^6/x^10-3/4*a^5*b/x^8-5/2*a^4*b^2/x^6-5*a^3*b^3/x^4-_
+    15/2*a^2*b^4/x^2+1/2*b^6*x^2+6*a*b^5*log(x)
+--R 
+--R
+--R   (2)
+--R             5 10            6 12       2 4 8       3 3 6      4 2 4      5   2
+--R       120a b x  log(x) + 10b x   - 150a b x  - 100a b x  - 50a b x  - 15a b x
+--R     + 
+--R           6
+--R       - 2a
+--R  /
+--R        10
+--R     20x
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 10            6 12       2 4 8       3 3 6      4 2 4      5   2
+--R       120a b x  log(x) + 10b x   - 150a b x  - 100a b x  - 50a b x  - 15a b x
+--R     + 
+--R           6
+--R       - 2a
+--R  /
+--R        10
+--R     20x
+--R                                         Type: Union(Expression(Integer),...)
+--E 306
+
+--S 307 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 308
+
+)clear all
+
+--S 309 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^12
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        12
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 309
+
+--S 310 of 1370
+r0:=-1/11*a^6/x^11-2/3*a^5*b/x^9-15/7*a^4*b^2/x^7-4*a^3*b^3/x^5-_
+    5*a^2*b^4/x^3-6*a*b^5/x+b^6*x
+--R 
+--R
+--R         6 12       5 10     2 4 8     3 3 6   15  4 2 4   2  5   2    1  6
+--R        b x   - 6a b x   - 5a b x  - 4a b x  - -- a b x  - - a b x  - -- a
+--R                                                7          3          11
+--R   (2)  -------------------------------------------------------------------
+--R                                         11
+--R                                        x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 310
+
+--S 311 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           6 12          5 10        2 4 8       3 3 6       4 2 4       5   2
+--R       231b x   - 1386a b x   - 1155a b x  - 924a b x  - 495a b x  - 154a b x
+--R     + 
+--R            6
+--R       - 21a
+--R  /
+--R         11
+--R     231x
+--R                                         Type: Union(Expression(Integer),...)
+--E 311
+
+--S 312 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 313
+
+)clear all
+
+--S 314 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^13
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        13
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 314
+
+--S 315 of 1370
+r0:=-1/12*a^6/x^12-3/5*a^5*b/x^10-15/8*a^4*b^2/x^8-10/3*a^3*b^3/x^6-_
+    15/4*a^2*b^4/x^4-3*a*b^5/x^2+b^6*log(x)
+--R 
+--R
+--R   (2)
+--R           6 12               5 10       2 4 8       3 3 6       4 2 4
+--R       120b x  log(x) - 360a b x   - 450a b x  - 400a b x  - 225a b x
+--R     + 
+--R            5   2      6
+--R       - 72a b x  - 10a
+--R  /
+--R         12
+--R     120x
+--R                                                    Type: Expression(Integer)
+--E 315
+
+--S 316 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           6 12               5 10       2 4 8       3 3 6       4 2 4
+--R       120b x  log(x) - 360a b x   - 450a b x  - 400a b x  - 225a b x
+--R     + 
+--R            5   2      6
+--R       - 72a b x  - 10a
+--R  /
+--R         12
+--R     120x
+--R                                         Type: Union(Expression(Integer),...)
+--E 316
+
+--S 317 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^14
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        14
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 319
+
+--S 320 of 1370
+r0:=-1/13*a^6/x^13-6/11*a^5*b/x^11-5/3*a^4*b^2/x^9-20/7*a^3*b^3/x^7-_
+    3*a^2*b^4/x^5-2*a*b^5/x^3-b^6/x
+--R 
+--R
+--R   (2)
+--R      6 12       5 10     2 4 8   20  3 3 6   5  4 2 4    6  5   2    1  6
+--R   - b x   - 2a b x   - 3a b x  - -- a b x  - - a b x  - -- a b x  - -- a
+--R                                   7          3          11          13
+--R   -----------------------------------------------------------------------
+--R                                      13
+--R                                     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 320
+
+--S 321 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              6 12          5 10        2 4 8        3 3 6        4 2 4
+--R       - 3003b x   - 6006a b x   - 9009a b x  - 8580a b x  - 5005a b x
+--R     + 
+--R              5   2       6
+--R       - 1638a b x  - 231a
+--R  /
+--R          13
+--R     3003x
+--R                                         Type: Union(Expression(Integer),...)
+--E 321
+
+--S 322 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 323
+
+)clear all
+
+--S 324 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^15
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        15
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 324
+
+--S 325 of 1370
+r0:=-1/14*(a+b*x^2)^7/(a*x^14)
+--R 
+--R
+--R   (2)
+--R          1  7 14   1    6 12   3  2 5 10   5  3 4 8   5  4 3 6   3  5 2 4
+--R       - -- b x   - - a b x   - - a b x   - - a b x  - - a b x  - - a b x
+--R         14         2           2           2          2          2
+--R     + 
+--R         1  6   2    1  7
+--R       - - a b x  - -- a
+--R         2          14
+--R  /
+--R        14
+--R     a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 325
+
+--S 326 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            6 12        5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        - 7b x   - 21a b x   - 35a b x  - 35a b x  - 21a b x  - 7a b x  - a
+--R   (3)  --------------------------------------------------------------------
+--R                                           14
+--R                                        14x
+--R                                         Type: Union(Expression(Integer),...)
+--E 326
+
+--S 327 of 1370
+m0:=a0-r0
+--R 
+--R
+--R          7
+--R         b
+--R   (4)  ---
+--R        14a
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 328
+
+)clear all
+
+--S 329 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^16
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        16
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 329
+
+--S 330 of 1370
+r0:=-1/15*a^6/x^15-6/13*a^5*b/x^13-15/11*a^4*b^2/x^11-20/9*a^3*b^3/x^9-_
+    15/7*a^2*b^4/x^7-6/5*a*b^5/x^5-1/3*b^6/x^3
+--R 
+--R
+--R   (2)
+--R     1  6 12   6    5 10   15  2 4 8   20  3 3 6   15  4 2 4    6  5   2    1  6
+--R   - - b x   - - a b x   - -- a b x  - -- a b x  - -- a b x  - -- a b x  - -- a
+--R     3         5            7           9          11          13          15
+--R   -----------------------------------------------------------------------------
+--R                                         15
+--R                                        x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 330
+
+--S 331 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               6 12           5 10         2 4 8          3 3 6         4 2 4
+--R       - 15015b x   - 54054a b x   - 96525a b x  - 100100a b x  - 61425a b x
+--R     + 
+--R               5   2        6
+--R       - 20790a b x  - 3003a
+--R  /
+--R           15
+--R     45045x
+--R                                         Type: Union(Expression(Integer),...)
+--E 331
+
+--S 332 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^17
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        17
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 334
+
+--S 335 of 1370
+r0:=-1/16*(a+b*x^2)^7/(a*x^16)+1/112*b*(a+b*x^2)^7/(a^2*x^14)
+--R 
+--R
+--R   (2)
+--R        1   8 16   1  2 6 12    3 5 10   15  4 4 8     5 3 6   5  6 2 4
+--R       --- b x   - - a b x   - a b x   - -- a b x  - 2a b x  - - a b x
+--R       112         4                      8                    4
+--R     + 
+--R         3  7   2    1  8
+--R       - - a b x  - -- a
+--R         7          16
+--R  /
+--R      2 16
+--R     a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 335
+
+--S 336 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        6 12         5 10       2 4 8       3 3 6       4 2 4      5   2     6
+--R   - 28b x   - 112a b x   - 210a b x  - 224a b x  - 140a b x  - 48a b x  - 7a
+--R   ---------------------------------------------------------------------------
+--R                                          16
+--R                                      112x
+--R                                         Type: Union(Expression(Integer),...)
+--E 336
+
+--S 337 of 1370
+m0:=a0-r0
+--R 
+--R
+--R             8
+--R            b
+--R   (4)  - -----
+--R              2
+--R          112a
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 338
+
+)clear all
+
+--S 339 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^18
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        18
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 339
+
+--S 340 of 1370
+r0:=-1/17*a^6/x^17-2/5*a^5*b/x^15-15/13*a^4*b^2/x^13-20/11*a^3*b^3/x^11-_
+    5/3*a^2*b^4/x^9-6/7*a*b^5/x^7-1/5*b^6/x^5
+--R 
+--R
+--R   (2)
+--R     1  6 12   6    5 10   5  2 4 8   20  3 3 6   15  4 2 4   2  5   2    1  6
+--R   - - b x   - - a b x   - - a b x  - -- a b x  - -- a b x  - - a b x  - -- a
+--R     5         7           3          11          13          5          17
+--R   ---------------------------------------------------------------------------
+--R                                        17
+--R                                       x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 340
+
+--S 341 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               6 12            5 10          2 4 8          3 3 6          4 2 4
+--R       - 51051b x   - 218790a b x   - 425425a b x  - 464100a b x  - 294525a b x
+--R     + 
+--R                5   2         6
+--R       - 102102a b x  - 15015a
+--R  /
+--R            17
+--R     255255x
+--R                                         Type: Union(Expression(Integer),...)
+--E 341
+
+--S 342 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 343
+
+)clear all
+
+--S 344 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^19
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        19
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 344
+
+--S 345 of 1370
+r0:=-1/18*(a+b*x^2)^7/(a*x^18)+1/72*b*(a+b*x^2)^7/(a^2*x^16)-_
+    1/504*b^2*(a+b*x^2)^7/(a^3*x^14)
+--R 
+--R
+--R   (2)
+--R          1   9 18   1  3 6 12   3  4 5 10   3  5 4 8   5  6 3 6   15  7 2 4
+--R       - --- b x   - - a b x   - - a b x   - - a b x  - - a b x  - -- a b x
+--R         504         6           4           2          3          14
+--R     + 
+--R         3  8   2    1  9
+--R       - - a b x  - -- a
+--R         8          18
+--R  /
+--R      3 18
+--R     a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 345
+
+--S 346 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        6 12         5 10       2 4 8       3 3 6       4 2 4       5   2      6
+--R   - 84b x   - 378a b x   - 756a b x  - 840a b x  - 540a b x  - 189a b x  - 28a
+--R   -----------------------------------------------------------------------------
+--R                                           18
+--R                                       504x
+--R                                         Type: Union(Expression(Integer),...)
+--E 346
+
+--S 347 of 1370
+m0:=a0-r0
+--R 
+--R
+--R           9
+--R          b
+--R   (4)  -----
+--R            3
+--R        504a
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^20
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        20
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 349
+
+--S 350 of 1370
+r0:=-1/19*a^6/x^19-6/17*a^5*b/x^17-a^4*b^2/x^15-20/13*a^3*b^3/x^13-_
+    15/11*a^2*b^4/x^11-2/3*a*b^5/x^9-1/7*b^6/x^7
+--R 
+--R
+--R   (2)
+--R     1  6 12   2    5 10   15  2 4 8   20  3 3 6    4 2 4    6  5   2    1  6
+--R   - - b x   - - a b x   - -- a b x  - -- a b x  - a b x  - -- a b x  - -- a
+--R     7         3           11          13                   17          19
+--R   --------------------------------------------------------------------------
+--R                                        19
+--R                                       x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 350
+
+--S 351 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                6 12            5 10           2 4 8           3 3 6
+--R       - 138567b x   - 646646a b x   - 1322685a b x  - 1492260a b x
+--R     + 
+--R                4 2 4          5   2         6
+--R       - 969969a b x  - 342342a b x  - 51051a
+--R  /
+--R            19
+--R     969969x
+--R                                         Type: Union(Expression(Integer),...)
+--E 351
+
+--S 352 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 353
+
+)clear all
+
+--S 354 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^21
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        21
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 354
+
+--S 355 of 1370
+r0:=-1/20*a^6/x^20-1/3*a^5*b/x^18-15/16*a^4*b^2/x^16-10/7*a^3*b^3/x^14-_
+    5/4*a^2*b^4/x^12-3/5*a*b^5/x^10-1/8*b^6/x^8
+--R 
+--R
+--R   (2)
+--R     1  6 12   3    5 10   5  2 4 8   10  3 3 6   15  4 2 4   1  5   2    1  6
+--R   - - b x   - - a b x   - - a b x  - -- a b x  - -- a b x  - - a b x  - -- a
+--R     8         5           4           7          16          3          20
+--R   ---------------------------------------------------------------------------
+--R                                        20
+--R                                       x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 355
+
+--S 356 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             6 12          5 10        2 4 8        3 3 6        4 2 4
+--R       - 210b x   - 1008a b x   - 2100a b x  - 2400a b x  - 1575a b x
+--R     + 
+--R             5   2      6
+--R       - 560a b x  - 84a
+--R  /
+--R          20
+--R     1680x
+--R                                         Type: Union(Expression(Integer),...)
+--E 356
+
+--S 357 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 358
+
+)clear all
+
+--S 359 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^22
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        22
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 359
+
+--S 360 of 1370
+r0:=-1/21*a^6/x^21-6/19*a^5*b/x^19-15/17*a^4*b^2/x^17-4/3*a^3*b^3/x^15-_
+    15/13*a^2*b^4/x^13-6/11*a*b^5/x^11-1/9*b^6/x^9
+--R 
+--R
+--R   (2)
+--R     1  6 12    6    5 10   15  2 4 8   4  3 3 6   15  4 2 4    6  5   2    1  6
+--R   - - b x   - -- a b x   - -- a b x  - - a b x  - -- a b x  - -- a b x  - -- a
+--R     9         11           13          3          17          19          21
+--R   -----------------------------------------------------------------------------
+--R                                         21
+--R                                        x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 360
+
+--S 361 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                6 12             5 10           2 4 8           3 3 6
+--R       - 323323b x   - 1587222a b x   - 3357585a b x  - 3879876a b x
+--R     + 
+--R                 4 2 4          5   2          6
+--R       - 2567565a b x  - 918918a b x  - 138567a
+--R  /
+--R             21
+--R     2909907x
+--R                                         Type: Union(Expression(Integer),...)
+--E 361
+
+--S 362 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 1370
+t0:=x^m/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  m
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 1370
+--r0:=1/2*x^(1+m)/(a*(a+b*x^2))+1/2*(1-m)*x^(1+m)*_
+--  hypergeometric(1,1/2*(1+m),1/2*(3+m),-b*x^2/a)/(a^2*(1+m))
+--E 365
+
+--S 366 of 1370
+--a0:=integrate(t0,x)
+--E 366
+
+--S 367 of 1370
+--m0:=a0-r0
+--E 367
+
+--S 368 of 1370
+--d0:=normalize(D(m0,x))
+--E 368
+
+)clear all
+
+--S 369 of 1370
+t0:=x^11/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 11
+--R                x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 369
+
+--S 370 of 1370
+r0:=-2*a^3*x^2/b^5+3/4*a^2*x^4/b^4-1/3*a*x^6/b^3+1/8*x^8/b^2+_
+    1/2*a^5/(b^6*(a+b*x^2))+5/2*a^4*log(a+b*x^2)/b^6
+--R 
+--R
+--R   (2)
+--R           4   2      5        2          5 10       4 8      2 3 6      3 2 4
+--R       (60a b x  + 60a )log(b x  + a) + 3b x   - 5a b x  + 10a b x  - 30a b x
+--R     + 
+--R            4   2      5
+--R       - 48a b x  + 12a
+--R  /
+--R        7 2        6
+--R     24b x  + 24a b
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4   2      5        2          5 10       4 8      2 3 6      3 2 4
+--R       (60a b x  + 60a )log(b x  + a) + 3b x   - 5a b x  + 10a b x  - 30a b x
+--R     + 
+--R            4   2      5
+--R       - 48a b x  + 12a
+--R  /
+--R        7 2        6
+--R     24b x  + 24a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 371
+
+--S 372 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 372
+
+--S 373 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 373
+
+)clear all
+
+--S 374 of 1370
+t0:=x^9/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  9
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 374
+
+--S 375 of 1370
+r0:=3/2*a^2*x^2/b^4-1/2*a*x^4/b^3+1/6*x^6/b^2-1/2*a^4/(b^5*(a+b*x^2))-_
+    2*a^3*log(a+b*x^2)/b^5
+--R 
+--R
+--R   (2)
+--R         3   2      4        2         4 8       3 6     2 2 4     3   2     4
+--R   (- 12a b x  - 12a )log(b x  + a) + b x  - 2a b x  + 6a b x  + 9a b x  - 3a
+--R   ---------------------------------------------------------------------------
+--R                                    6 2       5
+--R                                  6b x  + 6a b
+--R                                                    Type: Expression(Integer)
+--E 375
+
+--S 376 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3   2      4        2         4 8       3 6     2 2 4     3   2     4
+--R   (- 12a b x  - 12a )log(b x  + a) + b x  - 2a b x  + 6a b x  + 9a b x  - 3a
+--R   ---------------------------------------------------------------------------
+--R                                    6 2       5
+--R                                  6b x  + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 376
+
+--S 377 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 1370
+t0:=x^7/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  7
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 379
+
+--S 380 of 1370
+r0:=-a*x^2/b^3+1/4*x^4/b^2+1/2*a^3/(b^4*(a+b*x^2))+3/2*a^2*log(a+b*x^2)/b^4
+--R 
+--R
+--R           2   2     3        2         3 6       2 4     2   2     3
+--R        (6a b x  + 6a )log(b x  + a) + b x  - 3a b x  - 4a b x  + 2a
+--R   (2)  -------------------------------------------------------------
+--R                                  5 2       4
+--R                                4b x  + 4a b
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2   2     3        2         3 6       2 4     2   2     3
+--R        (6a b x  + 6a )log(b x  + a) + b x  - 3a b x  - 4a b x  + 2a
+--R   (3)  -------------------------------------------------------------
+--R                                  5 2       4
+--R                                4b x  + 4a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 381
+
+--S 382 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 383
+
+)clear all
+
+--S 384 of 1370
+t0:=x^5/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  5
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 384
+
+--S 385 of 1370
+r0:=1/2*x^2/b^2-1/2*a^2/(b^3*(a+b*x^2))-a*log(a+b*x^2)/b^3
+--R 
+--R
+--R                 2     2        2         2 4        2    2
+--R        (- 2a b x  - 2a )log(b x  + a) + b x  + a b x  - a
+--R   (2)  ---------------------------------------------------
+--R                             4 2       3
+--R                           2b x  + 2a b
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 2     2        2         2 4        2    2
+--R        (- 2a b x  - 2a )log(b x  + a) + b x  + a b x  - a
+--R   (3)  ---------------------------------------------------
+--R                             4 2       3
+--R                           2b x  + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 386
+
+--S 387 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 388
+
+)clear all
+
+--S 389 of 1370
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 389
+
+--S 390 of 1370
+r0:=1/2*a/(b^2*(a+b*x^2))+1/2*log(a+b*x^2)/b^2
+--R 
+--R
+--R            2            2
+--R        (b x  + a)log(b x  + a) + a
+--R   (2)  ---------------------------
+--R                 3 2       2
+--R               2b x  + 2a b
+--R                                                    Type: Expression(Integer)
+--E 390
+
+--S 391 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2            2
+--R        (b x  + a)log(b x  + a) + a
+--R   (3)  ---------------------------
+--R                 3 2       2
+--R               2b x  + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 391
+
+--S 392 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 1370
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 394
+
+--S 395 of 1370
+r0:=(-1/2)/(b*(a+b*x^2))
+--R 
+--R
+--R               1
+--R               -
+--R               2
+--R   (2)  - ----------
+--R           2 2
+--R          b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 395
+
+--S 396 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                1
+--R   (3)  - ------------
+--R            2 2
+--R          2b x  + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 396
+
+--S 397 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 398
+
+)clear all
+
+--S 399 of 1370
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         2 5         3    2
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 399
+
+--S 400 of 1370
+r0:=1/2/(a*(a+b*x^2))+log(x)/a^2-1/2*log(a+b*x^2)/a^2
+--R 
+--R
+--R              2            2             2
+--R        (- b x  - a)log(b x  + a) + (2b x  + 2a)log(x) + a
+--R   (2)  --------------------------------------------------
+--R                             2   2     3
+--R                           2a b x  + 2a
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2            2             2
+--R        (- b x  - a)log(b x  + a) + (2b x  + 2a)log(x) + a
+--R   (3)  --------------------------------------------------
+--R                             2   2     3
+--R                           2a b x  + 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 401
+
+--S 402 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+--S 403 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 403
+
+)clear all
+
+--S 404 of 1370
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 7         5    2 3
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 404
+
+--S 405 of 1370
+r0:=(-1)/(a^2*x^2)+1/2/(a*x^2*(a+b*x^2))-2*b*log(x)/a^3+b*log(a+b*x^2)/a^3
+--R 
+--R
+--R   (2)
+--R      2 4         2        2             2 4         2                2    2
+--R   (2b x  + 2a b x )log(b x  + a) + (- 4b x  - 4a b x )log(x) - 2a b x  - a
+--R   -------------------------------------------------------------------------
+--R                                  3   4     4 2
+--R                                2a b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 405
+
+--S 406 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      2 4         2        2             2 4         2                2    2
+--R   (2b x  + 2a b x )log(b x  + a) + (- 4b x  - 4a b x )log(x) - 2a b x  - a
+--R   -------------------------------------------------------------------------
+--R                                  3   4     4 2
+--R                                2a b x  + 2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 406
+
+--S 407 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 1370
+t0:=1/(x^5*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 9         7    2 5
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 409
+
+--S 410 of 1370
+r0:=(-3/4)/(a^2*x^4)+3/2*b/(a^3*x^2)+1/2/(a*x^4*(a+b*x^2))+_
+    3*b^2*log(x)/a^4-3/2*b^2*log(a+b*x^2)/a^4
+--R 
+--R
+--R   (2)
+--R            3 6       2 4        2            3 6        2 4              2 4
+--R       (- 6b x  - 6a b x )log(b x  + a) + (12b x  + 12a b x )log(x) + 6a b x
+--R     + 
+--R         2   2    3
+--R       3a b x  - a
+--R  /
+--R       4   6     5 4
+--R     4a b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 6       2 4        2            3 6        2 4              2 4
+--R       (- 6b x  - 6a b x )log(b x  + a) + (12b x  + 12a b x )log(x) + 6a b x
+--R     + 
+--R         2   2    3
+--R       3a b x  - a
+--R  /
+--R       4   6     5 4
+--R     4a b x  + 4a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 411
+
+--S 412 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 413
+
+)clear all
+
+--S 414 of 1370
+t0:=x^10/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 10
+--R                x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 414
+
+--S 415 of 1370
+r0:=-9/2*a^3*x/b^5+3/2*a^2*x^3/b^4-9/10*a*x^5/b^3+9/14*x^7/b^2-_
+    1/2*x^9/(b*(a+b*x^2))+9/2*a^(7/2)*atan(x*sqrt(b)/sqrt(a))/b^(11/2)
+--R 
+--R
+--R   (2)
+--R                                     +-+
+--R            3   2       4  +-+     x\|b
+--R       (315a b x  + 315a )\|a atan(-----)
+--R                                     +-+
+--R                                    \|a
+--R     + 
+--R           4 9        3 7      2 2 5       3   3       4   +-+
+--R       (10b x  - 18a b x  + 42a b x  - 210a b x  - 315a x)\|b
+--R  /
+--R         6 2        5  +-+
+--R     (70b x  + 70a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                           +---+
+--R                                           |  a       2
+--R                             +---+    2b x |- -  + b x  - a
+--R              3   2       4  |  a         \|  b                   4 9        3 7
+--R         (315a b x  + 315a ) |- - log(---------------------) + 20b x  - 36a b x
+--R                            \|  b               2
+--R                                             b x  + a
+--R       + 
+--R            2 2 5       3   3       4
+--R         84a b x  - 420a b x  - 630a x
+--R    /
+--R           6 2         5
+--R       140b x  + 140a b
+--R     ,
+--R
+--R                                        +-+
+--R                                        |a
+--R                               +-+      |-
+--R                3   2       4  |a      \|b        4 9        3 7      2 2 5
+--R         (- 315a b x  - 315a ) |- atan(----) + 10b x  - 18a b x  + 42a b x
+--R                              \|b        x
+--R       + 
+--R               3   3       4
+--R         - 210a b x  - 315a x
+--R    /
+--R          6 2        5
+--R       70b x  + 70a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 416
+
+--S 417 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                              +---+
+--R                              |  a       2
+--R            +---+        2b x |- -  + b x  - a                   +-+
+--R          3 |  a  +-+        \|  b                   3 +-+     x\|b
+--R        9a  |- - \|b log(---------------------) - 18a \|a atan(-----)
+--R           \|  b                   2                             +-+
+--R                                b x  + a                        \|a
+--R   (4)  -------------------------------------------------------------
+--R                                     5 +-+
+--R                                   4b \|b
+--R                                                    Type: Expression(Integer)
+--E 417
+
+--S 418 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                +-+
+--R                                                |a
+--R                        +-+        +-+          |-
+--R            3 +-+     x\|b       3 |a  +-+     \|b
+--R        - 9a \|a atan(-----) - 9a  |- \|b atan(----)
+--R                        +-+       \|b            x
+--R                       \|a
+--R   (6)  --------------------------------------------
+--R                             5 +-+
+--R                           2b \|b
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 1370
+t0:=x^8/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  8
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 421
+
+--S 422 of 1370
+r0:=7/2*a^2*x/b^4-7/6*a*x^3/b^3+7/10*x^5/b^2-1/2*x^7/(b*(a+b*x^2))-_
+    7/2*a^(5/2)*atan(x*sqrt(b)/sqrt(a))/b^(9/2)
+--R 
+--R
+--R   (2)
+--R                                       +-+
+--R              2   2       3  +-+     x\|b
+--R       (- 105a b x  - 105a )\|a atan(-----)
+--R                                       +-+
+--R                                      \|a
+--R     + 
+--R          3 7        2 5      2   3       3   +-+
+--R       (6b x  - 14a b x  + 70a b x  + 105a x)\|b
+--R  /
+--R         5 2        4  +-+
+--R     (30b x  + 30a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                             +---+
+--R                                             |  a       2
+--R                             +---+    - 2b x |- -  + b x  - a
+--R              2   2       3  |  a           \|  b                   3 7
+--R         (105a b x  + 105a ) |- - log(-----------------------) + 12b x
+--R                            \|  b                2
+--R                                              b x  + a
+--R       + 
+--R                2 5       2   3       3
+--R         - 28a b x  + 140a b x  + 210a x
+--R    /
+--R          5 2        4
+--R       60b x  + 60a b
+--R     ,
+--R                                 +-+
+--R                                 |a
+--R                        +-+      |-
+--R         2   2       3  |a      \|b       3 7        2 5      2   3       3
+--R    (105a b x  + 105a ) |- atan(----) + 6b x  - 14a b x  + 70a b x  + 105a x
+--R                       \|b        x
+--R    ------------------------------------------------------------------------]
+--R                                    5 2        4
+--R                                 30b x  + 30a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 423
+
+--S 424 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                +---+
+--R                                |  a       2
+--R            +---+        - 2b x |- -  + b x  - a                   +-+
+--R          2 |  a  +-+          \|  b                   2 +-+     x\|b
+--R        7a  |- - \|b log(-----------------------) + 14a \|a atan(-----)
+--R           \|  b                    2                              +-+
+--R                                 b x  + a                         \|a
+--R   (4)  ---------------------------------------------------------------
+--R                                      4 +-+
+--R                                    4b \|b
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                              +-+
+--R                                              |a
+--R                      +-+        +-+          |-
+--R          2 +-+     x\|b       2 |a  +-+     \|b
+--R        7a \|a atan(-----) + 7a  |- \|b atan(----)
+--R                      +-+       \|b            x
+--R                     \|a
+--R   (6)  ------------------------------------------
+--R                            4 +-+
+--R                          2b \|b
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 427
+
+)clear all
+
+--S 428 of 1370
+t0:=x^6/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  6
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 428
+
+--S 429 of 1370
+r0:=-5/2*a*x/b^3+5/6*x^3/b^2-1/2*x^5/(b*(a+b*x^2))+5/2*a^(3/2)*_
+    atan(x*sqrt(b)/sqrt(a))/b^(7/2)
+--R 
+--R
+--R                                    +-+
+--R                2      2  +-+     x\|b        2 5          3      2   +-+
+--R        (15a b x  + 15a )\|a atan(-----) + (2b x  - 10a b x  - 15a x)\|b
+--R                                    +-+
+--R                                   \|a
+--R   (2)  -----------------------------------------------------------------
+--R                                  4 2       3  +-+
+--R                               (6b x  + 6a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 429
+
+--S 430 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                    +---+
+--R                                    |  a       2
+--R                      +---+    2b x |- -  + b x  - a
+--R            2      2  |  a         \|  b                  2 5          3      2
+--R    (15a b x  + 15a ) |- - log(---------------------) + 4b x  - 20a b x  - 30a x
+--R                     \|  b               2
+--R                                      b x  + a
+--R   [----------------------------------------------------------------------------
+--R                                      4 2        3
+--R                                   12b x  + 12a b
+--R     ,
+--R                                 +-+
+--R                                 |a
+--R                        +-+      |-
+--R              2      2  |a      \|b       2 5          3      2
+--R    (- 15a b x  - 15a ) |- atan(----) + 2b x  - 10a b x  - 15a x
+--R                       \|b        x
+--R    ------------------------------------------------------------]
+--R                              4 2       3
+--R                            6b x  + 6a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 430
+
+--S 431 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                             +---+
+--R                             |  a       2
+--R           +---+        2b x |- -  + b x  - a                  +-+
+--R           |  a  +-+        \|  b                    +-+     x\|b
+--R        5a |- - \|b log(---------------------) - 10a\|a atan(-----)
+--R          \|  b                   2                            +-+
+--R                               b x  + a                       \|a
+--R   (4)  -----------------------------------------------------------
+--R                                    3 +-+
+--R                                  4b \|b
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                              +-+
+--R                                              |a
+--R                       +-+       +-+          |-
+--R             +-+     x\|b        |a  +-+     \|b
+--R        - 5a\|a atan(-----) - 5a |- \|b atan(----)
+--R                       +-+      \|b            x
+--R                      \|a
+--R   (6)  ------------------------------------------
+--R                            3 +-+
+--R                          2b \|b
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 434
+
+)clear all
+
+--S 435 of 1370
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  4
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 435
+
+--S 436 of 1370
+r0:=3/2*x/b^2-1/2*x^3/(b*(a+b*x^2))-3/2*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/b^(5/2)
+--R 
+--R
+--R                                 +-+
+--R               2       +-+     x\|b          3         +-+
+--R        (- 3b x  - 3a)\|a atan(-----) + (2b x  + 3a x)\|b
+--R                                 +-+
+--R                                \|a
+--R   (2)  --------------------------------------------------
+--R                           3 2       2  +-+
+--R                        (2b x  + 2a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 +---+
+--R                                 |  a       2
+--R                 +---+    - 2b x |- -  + b x  - a
+--R         2       |  a           \|  b                    3
+--R    (3b x  + 3a) |- - log(-----------------------) + 4b x  + 6a x
+--R                \|  b                2
+--R                                  b x  + a
+--R   [-------------------------------------------------------------,
+--R                              3 2       2
+--R                            4b x  + 4a b
+--R                          +-+
+--R                          |a
+--R                 +-+      |-
+--R         2       |a      \|b         3
+--R    (3b x  + 3a) |- atan(----) + 2b x  + 3a x
+--R                \|b        x
+--R    -----------------------------------------]
+--R                    3 2       2
+--R                  2b x  + 2a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 437
+
+--S 438 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                               +---+
+--R                               |  a       2
+--R           +---+        - 2b x |- -  + b x  - a               +-+
+--R           |  a  +-+          \|  b                 +-+     x\|b
+--R        3  |- - \|b log(----------------------- + 6\|a atan(-----)
+--R          \|  b                    2                          +-+
+--R                                b x  + a                     \|a
+--R   (4)  ----------------------------------------------------------
+--R                                    2 +-+
+--R                                  4b \|b
+--R                                                    Type: Expression(Integer)
+--E 438
+
+--S 439 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                           +-+
+--R                                           |a
+--R                    +-+       +-+          |-
+--R          +-+     x\|b        |a  +-+     \|b
+--R        3\|a atan(-----) + 3  |- \|b atan(----)
+--R                    +-+      \|b            x
+--R                   \|a
+--R   (6)  --------------------------------------
+--R                          2 +-+
+--R                        2b \|b
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 1370
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  2
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 442
+
+--S 443 of 1370
+r0:=-1/2*x/(b*(a+b*x^2))+1/2*atan(x*sqrt(b)/sqrt(a))/(b^(3/2)*sqrt(a))
+--R 
+--R
+--R                         +-+
+--R            2          x\|b       +-+ +-+
+--R        (b x  + a)atan(-----) - x\|a \|b
+--R                         +-+
+--R                        \|a
+--R   (2)  ---------------------------------
+--R                 2 2         +-+ +-+
+--R              (2b x  + 2a b)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      2      +-----+
+--R        2         (b x  - a)\|- a b  + 2a b x       +-----+
+--R    (b x  + a)log(---------------------------) - 2x\|- a b
+--R                               2
+--R                            b x  + a
+--R   [-------------------------------------------------------,
+--R                        2 2         +-----+
+--R                     (4b x  + 4a b)\|- a b
+--R                     +---+
+--R        2          x\|a b       +---+
+--R    (b x  + a)atan(-------) - x\|a b
+--R                      a
+--R    ---------------------------------]
+--R              2 2         +---+
+--R           (2b x  + 2a b)\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 444
+
+--S 445 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                        2      +-----+                             +-+
+--R         +-+ +-+    (b x  - a)\|- a b  + 2a b x      +-----+     x\|b
+--R        \|a \|b log(---------------------------) - 2\|- a b atan(-----)
+--R                                 2                                 +-+
+--R                              b x  + a                            \|a
+--R   (4)  ---------------------------------------------------------------
+--R                                  +-----+ +-+ +-+
+--R                               4b\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                       +---+                 +-+
+--R         +-+ +-+     x\|a b      +---+     x\|b
+--R        \|a \|b atan(-------) - \|a b atan(-----)
+--R                        a                    +-+
+--R                                            \|a
+--R   (6)  -----------------------------------------
+--R                        +-+ +-+ +---+
+--R                     2b\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 448
+
+)clear all
+
+--S 449 of 1370
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 449
+
+--S 450 of 1370
+r0:=1/2*x/(a*(a+b*x^2))+1/2*atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*sqrt(b))
+--R 
+--R
+--R                         +-+
+--R            2          x\|b       +-+ +-+
+--R        (b x  + a)atan(-----) + x\|a \|b
+--R                         +-+
+--R                        \|a
+--R   (2)  ---------------------------------
+--R                    2     2  +-+ +-+
+--R             (2a b x  + 2a )\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 450
+
+--S 451 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      2      +-----+
+--R        2         (b x  - a)\|- a b  + 2a b x       +-----+
+--R    (b x  + a)log(---------------------------) + 2x\|- a b
+--R                               2
+--R                            b x  + a
+--R   [-------------------------------------------------------,
+--R                           2     2  +-----+
+--R                    (4a b x  + 4a )\|- a b
+--R                     +---+
+--R        2          x\|a b       +---+
+--R    (b x  + a)atan(-------) + x\|a b
+--R                      a
+--R    ---------------------------------]
+--R                 2     2  +---+
+--R          (2a b x  + 2a )\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 451
+
+--S 452 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                        2      +-----+                             +-+
+--R         +-+ +-+    (b x  - a)\|- a b  + 2a b x      +-----+     x\|b
+--R        \|a \|b log(---------------------------) - 2\|- a b atan(-----)
+--R                                 2                                 +-+
+--R                              b x  + a                            \|a
+--R   (4)  ---------------------------------------------------------------
+--R                                  +-----+ +-+ +-+
+--R                               4a\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+--S 454 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                       +---+                 +-+
+--R         +-+ +-+     x\|a b      +---+     x\|b
+--R        \|a \|b atan(-------) - \|a b atan(-----)
+--R                        a                    +-+
+--R                                            \|a
+--R   (6)  -----------------------------------------
+--R                        +-+ +-+ +---+
+--R                     2a\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 455
+
+)clear all
+
+--S 456 of 1370
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 6         4    2 2
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 456
+
+--S 457 of 1370
+r0:=(-3/2)/(a^2*x)+1/2/(a*x*(a+b*x^2))-3/2*atan(x*sqrt(b)/sqrt(a))*_
+    sqrt(b)/a^(5/2)
+--R 
+--R
+--R                                   +-+
+--R               3         +-+     x\|b            2       +-+
+--R        (- 3b x  - 3a x)\|b atan(-----) + (- 3b x  - 2a)\|a
+--R                                   +-+
+--R                                  \|a
+--R   (2)  ----------------------------------------------------
+--R                           2   3     3   +-+
+--R                        (2a b x  + 2a x)\|a
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                   +---+
+--R                                   |  b       2
+--R                   +---+    - 2a x |- -  + b x  - a
+--R         3         |  b           \|  a                    2
+--R    (3b x  + 3a x) |- - log(-----------------------) - 6b x  - 4a
+--R                  \|  a                2
+--R                                    b x  + a
+--R   [-------------------------------------------------------------,
+--R                              2   3     3
+--R                            4a b x  + 4a x
+--R                             +-+
+--R                             |b
+--R                   +-+     a |-
+--R         3         |b       \|a         2
+--R    (3b x  + 3a x) |- atan(-----) - 3b x  - 2a
+--R                  \|a       b x
+--R    ------------------------------------------]
+--R                    2   3     3
+--R                  2a b x  + 2a x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 458
+
+--S 459 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                               +---+
+--R                               |  b       2
+--R           +---+        - 2a x |- -  + b x  - a               +-+
+--R           |  b  +-+          \|  a                 +-+     x\|b
+--R        3  |- - \|a log(----------------------- + 6\|b atan(-----)
+--R          \|  a                    2                          +-+
+--R                                b x  + a                     \|a
+--R   (4)  ----------------------------------------------------------
+--R                                    2 +-+
+--R                                  4a \|a
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                           +-+
+--R                                           |b
+--R                    +-+          +-+     a |-
+--R          +-+     x\|b       +-+ |b       \|a
+--R        3\|b atan(-----) + 3\|a  |- atan(-----)
+--R                    +-+         \|a       b x
+--R                   \|a
+--R   (6)  ---------------------------------------
+--R                          2 +-+
+--R                        2a \|a
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 1370
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 8         6    2 4
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 463
+
+--S 464 of 1370
+r0:=(-5/6)/(a^2*x^3)+5/2*b/(a^3*x)+1/2/(a*x^3*(a+b*x^2))+_
+    5/2*b^(3/2)*atan(x*sqrt(b)/sqrt(a))/a^(7/2)
+--R 
+--R
+--R                                      +-+
+--R            2 5          3  +-+     x\|b         2 4          2     2  +-+
+--R        (15b x  + 15a b x )\|b atan(-----) + (15b x  + 10a b x  - 2a )\|a
+--R                                      +-+
+--R                                     \|a
+--R   (2)  ------------------------------------------------------------------
+--R                                  3   5     4 3  +-+
+--R                               (6a b x  + 6a x )\|a
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                           +---+
+--R                                           |  b       2
+--R                             +---+    2a x |- -  + b x  - a
+--R             2 5          3  |  b         \|  a                   2 4          2
+--R         (15b x  + 15a b x ) |- - log(---------------------) + 30b x  + 20a b x
+--R                            \|  a               2
+--R                                             b x  + a
+--R       + 
+--R             2
+--R         - 4a
+--R    /
+--R          3   5      4 3
+--R       12a b x  + 12a x
+--R     ,
+--R                                    +-+
+--R                                    |b
+--R                          +-+     a |-
+--R          2 5          3  |b       \|a        2 4          2     2
+--R    (- 15b x  - 15a b x ) |- atan(-----) + 15b x  + 10a b x  - 2a
+--R                         \|a       b x
+--R    --------------------------------------------------------------]
+--R                              3   5     4 3
+--R                            6a b x  + 6a x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 465
+
+--S 466 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                             +---+
+--R                             |  b       2
+--R           +---+        2a x |- -  + b x  - a                  +-+
+--R           |  b  +-+        \|  a                    +-+     x\|b
+--R        5b |- - \|a log(---------------------) - 10b\|b atan(-----)
+--R          \|  a                   2                            +-+
+--R                               b x  + a                       \|a
+--R   (4)  -----------------------------------------------------------
+--R                                    3 +-+
+--R                                  4a \|a
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                               +-+
+--R                                               |b
+--R                       +-+           +-+     a |-
+--R             +-+     x\|b        +-+ |b       \|a
+--R        - 5b\|b atan(-----) - 5b\|a  |- atan(-----)
+--R                       +-+          \|a       b x
+--R                      \|a
+--R   (6)  -------------------------------------------
+--R                            3 +-+
+--R                          2a \|a
+--R                                                    Type: Expression(Integer)
+--E 468
+
+--S 469 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 469
+
+)clear all
+
+--S 470 of 1370
+t0:=1/(x^6*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         2 10         8    2 6
+--R        b x   + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 470
+
+--S 471 of 1370
+r0:=(-7/10)/(a^2*x^5)+7/6*b/(a^3*x^3)-7/2*b^2/(a^4*x)+1/2/(a*x^5*(a+b*x^2))-_
+    7/2*b^(5/2)*atan(x*sqrt(b)/sqrt(a))/a^(9/2)
+--R 
+--R
+--R   (2)
+--R                                         +-+
+--R              3 7         2 5  +-+     x\|b
+--R       (- 105b x  - 105a b x )\|b atan(-----)
+--R                                         +-+
+--R                                        \|a
+--R     + 
+--R              3 6        2 4      2   2     3  +-+
+--R       (- 105b x  - 70a b x  + 14a b x  - 6a )\|a
+--R  /
+--R         4   7      5 5  +-+
+--R     (30a b x  + 30a x )\|a
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                               +---+
+--R                                               |  b       2
+--R                               +---+    - 2a x |- -  + b x  - a
+--R              3 7         2 5  |  b           \|  a                    3 6
+--R         (105b x  + 105a b x ) |- - log(-----------------------) - 210b x
+--R                              \|  a                2
+--R                                                b x  + a
+--R       + 
+--R                 2 4      2   2      3
+--R         - 140a b x  + 28a b x  - 12a
+--R    /
+--R          4   7      5 5
+--R       60a b x  + 60a x
+--R     ,
+--R                                    +-+
+--R                                    |b
+--R                          +-+     a |-
+--R         3 7         2 5  |b       \|a         3 6        2 4      2   2     3
+--R    (105b x  + 105a b x ) |- atan(-----) - 105b x  - 70a b x  + 14a b x  - 6a
+--R                         \|a       b x
+--R    --------------------------------------------------------------------------]
+--R                                    4   7      5 5
+--R                                 30a b x  + 30a x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 472
+
+--S 473 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                +---+
+--R                                |  b       2
+--R            +---+        - 2a x |- -  + b x  - a                   +-+
+--R          2 |  b  +-+          \|  a                   2 +-+     x\|b
+--R        7b  |- - \|a log(-----------------------) + 14b \|b atan(-----)
+--R           \|  a                    2                              +-+
+--R                                 b x  + a                         \|a
+--R   (4)  ---------------------------------------------------------------
+--R                                      4 +-+
+--R                                    4a \|a
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+--S 475 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                               +-+
+--R                                               |b
+--R                      +-+            +-+     a |-
+--R          2 +-+     x\|b       2 +-+ |b       \|a
+--R        7b \|b atan(-----) + 7b \|a  |- atan(-----)
+--R                      +-+           \|a       b x
+--R                     \|a
+--R   (6)  -------------------------------------------
+--R                            4 +-+
+--R                          2a \|a
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 476
+
+)clear all
+
+--S 477 of 1370
+t0:=x^m/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            m
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 1370
+--r0:=1/6*x^(1+m)/(a*(a+b*x^2)^3)+1/24*(5-m)*x^(1+m)/(a^2*(a+b*x^2)^2)+_
+--  1/48*(3-m)*(5-m)*x^(1+m)/(a^3*(a+b*x^2))+1/48*(1-m)*(3-m)*_
+--  (5-m)*x^(1+m)*hypergeometric(1,1/2*(1+m),1/2*(3+m),-b*x^2/a)/(a^4*(1+m))
+--E 478
+
+--S 479 of 1370
+--a0:=integrate(t0,x)
+--E 479
+
+--S 480 of 1370
+--m0:=a0-r0
+--E 480
+
+--S 481 of 1370
+--d0:=D(m0,x)
+--E 481
+
+)clear all
+
+--S 482 of 1370
+t0:=x^11/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           11
+--R                          x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 482
+
+--S 483 of 1370
+r0:=-2*a*x^2/b^5+1/4*x^4/b^4+1/6*a^5/(b^6*(a+b*x^2)^3)-_
+    5/4*a^4/(b^6*(a+b*x^2)^2)+5*a^3/(b^6*(a+b*x^2))+5*a^2*log(a+b*x^2)/b^6
+--R 
+--R
+--R   (2)
+--R           2 3 6       3 2 4       4   2      5        2          5 10
+--R       (60a b x  + 180a b x  + 180a b x  + 60a )log(b x  + a) + 3b x
+--R     + 
+--R              4 8      2 3 6     3 2 4      4   2      5
+--R       - 15a b x  - 63a b x  - 9a b x  + 81a b x  + 47a
+--R  /
+--R        9 6        8 4      2 7 2      3 6
+--R     12b x  + 36a b x  + 36a b x  + 12a b
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 3 6       3 2 4       4   2      5        2          5 10
+--R       (60a b x  + 180a b x  + 180a b x  + 60a )log(b x  + a) + 3b x
+--R     + 
+--R              4 8      2 3 6     3 2 4      4   2      5
+--R       - 15a b x  - 63a b x  - 9a b x  + 81a b x  + 47a
+--R  /
+--R        9 6        8 4      2 7 2      3 6
+--R     12b x  + 36a b x  + 36a b x  + 12a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 484
+
+--S 485 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 1370
+t0:=x^9/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            9
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 487
+
+--S 488 of 1370
+r0:=1/2*x^2/b^4-1/6*a^4/(b^5*(a+b*x^2)^3)+a^3/(b^5*(a+b*x^2)^2)-_
+    3*a^2/(b^5*(a+b*x^2))-2*a*log(a+b*x^2)/b^5
+--R 
+--R
+--R   (2)
+--R               3 6      2 2 4      3   2      4        2          4 8       3 6
+--R       (- 12a b x  - 36a b x  - 36a b x  - 12a )log(b x  + a) + 3b x  + 9a b x
+--R     + 
+--R           2 2 4      3   2      4
+--R       - 9a b x  - 27a b x  - 13a
+--R  /
+--R       8 6        7 4      2 6 2     3 5
+--R     6b x  + 18a b x  + 18a b x  + 6a b
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 6      2 2 4      3   2      4        2          4 8       3 6
+--R       (- 12a b x  - 36a b x  - 36a b x  - 12a )log(b x  + a) + 3b x  + 9a b x
+--R     + 
+--R           2 2 4      3   2      4
+--R       - 9a b x  - 27a b x  - 13a
+--R  /
+--R       8 6        7 4      2 6 2     3 5
+--R     6b x  + 18a b x  + 18a b x  + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 489
+
+--S 490 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 491
+
+)clear all
+
+--S 492 of 1370
+t0:=x^7/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            7
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 492
+
+--S 493 of 1370
+r0:=1/6*a^3/(b^4*(a+b*x^2)^3)-3/4*a^2/(b^4*(a+b*x^2)^2)+_
+    3/2*a/(b^4*(a+b*x^2))+1/2*log(a+b*x^2)/b^4
+--R 
+--R
+--R   (2)
+--R      3 6        2 4      2   2     3        2             2 4      2   2      3
+--R   (6b x  + 18a b x  + 18a b x  + 6a )log(b x  + a) + 18a b x  + 27a b x  + 11a
+--R   -----------------------------------------------------------------------------
+--R                          7 6        6 4      2 5 2      3 4
+--R                       12b x  + 36a b x  + 36a b x  + 12a b
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      3 6        2 4      2   2     3        2             2 4      2   2      3
+--R   (6b x  + 18a b x  + 18a b x  + 6a )log(b x  + a) + 18a b x  + 27a b x  + 11a
+--R   -----------------------------------------------------------------------------
+--R                          7 6        6 4      2 5 2      3 4
+--R                       12b x  + 36a b x  + 36a b x  + 12a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 494
+
+--S 495 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+--S 496 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 496
+
+)clear all
+
+--S 497 of 1370
+t0:=x^5/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            5
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 497
+
+--S 498 of 1370
+r0:=1/6*x^6/(a*(a+b*x^2)^3)
+--R 
+--R
+--R                      1  6
+--R                      - x
+--R                      6
+--R   (2)  -------------------------------
+--R           3 6     2 2 4     3   2    4
+--R        a b x  + 3a b x  + 3a b x  + a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 498
+
+--S 499 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   2 4         2    2
+--R               - 3b x  - 3a b x  - a
+--R   (3)  -----------------------------------
+--R          6 6        5 4      2 4 2     3 3
+--R        6b x  + 18a b x  + 18a b x  + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 499
+
+--S 500 of 1370
+m0:=a0-r0
+--R 
+--R
+--R            1
+--R   (4)  - -----
+--R              3
+--R          6a b
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 1370
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            3
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 502
+
+--S 503 of 1370
+r0:=1/6*a/(b^2*(a+b*x^2)^3)+(-1/4)/(b^2*(a+b*x^2)^2)
+--R 
+--R
+--R                  1    2    1
+--R                - - b x  - -- a
+--R                  4        12
+--R   (2)  -------------------------------
+--R         5 6       4 4     2 3 2    3 2
+--R        b x  + 3a b x  + 3a b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 503
+
+--S 504 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           2
+--R                     - 3b x  - a
+--R   (3)  -------------------------------------
+--R           5 6        4 4      2 3 2      3 2
+--R        12b x  + 36a b x  + 36a b x  + 12a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 504
+
+--S 505 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 506
+
+)clear all
+
+--S 507 of 1370
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 507
+
+--S 508 of 1370
+r0:=(-1/6)/(b*(a+b*x^2)^3)
+--R 
+--R
+--R                         1
+--R                         -
+--R                         6
+--R   (2)  - ------------------------------
+--R           4 6       3 4     2 2 2    3
+--R          b x  + 3a b x  + 3a b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 508
+
+--S 509 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           1
+--R   (3)  - ----------------------------------
+--R            4 6        3 4      2 2 2     3
+--R          6b x  + 18a b x  + 18a b x  + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 509
+
+--S 510 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+--S 511 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 511
+
+)clear all
+
+--S 512 of 1370
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                            1
+--R   (1)  ----------------------------------------
+--R         4 9       3 7     2 2 5     3   3    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 512
+
+--S 513 of 1370
+r0:=1/6/(a*(a+b*x^2)^3)+1/4/(a^2*(a+b*x^2)^2)+1/2/(a^3*(a+b*x^2))+_
+    log(x)/a^4-1/2*log(a+b*x^2)/a^4
+--R 
+--R
+--R   (2)
+--R            3 6        2 4      2   2     3        2
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )log(b x  + a)
+--R     + 
+--R           3 6        2 4      2   2      3              2 4      2   2      3
+--R       (12b x  + 36a b x  + 36a b x  + 12a )log(x) + 6a b x  + 15a b x  + 11a
+--R  /
+--R        4 3 6      5 2 4      6   2      7
+--R     12a b x  + 36a b x  + 36a b x  + 12a
+--R                                                    Type: Expression(Integer)
+--E 513
+
+--S 514 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 6        2 4      2   2     3        2
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )log(b x  + a)
+--R     + 
+--R           3 6        2 4      2   2      3              2 4      2   2      3
+--R       (12b x  + 36a b x  + 36a b x  + 12a )log(x) + 6a b x  + 15a b x  + 11a
+--R  /
+--R        4 3 6      5 2 4      6   2      7
+--R     12a b x  + 36a b x  + 36a b x  + 12a
+--R                                         Type: Union(Expression(Integer),...)
+--E 514
+
+--S 515 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 1370
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                             1
+--R   (1)  ------------------------------------------
+--R         4 11       3 9     2 2 7     3   5    4 3
+--R        b x   + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 517
+
+--S 518 of 1370
+r0:=(-2)/(a^4*x^2)+1/6/(a*x^2*(a+b*x^2)^3)+1/3/(a^2*x^2*(a+b*x^2)^2)+_
+    1/(a^3*x^2*(a+b*x^2))-4*b*log(x)/a^5+2*b*log(a+b*x^2)/a^5
+--R 
+--R
+--R   (2)
+--R           4 8        3 6      2 2 4      3   2        2
+--R       (12b x  + 36a b x  + 36a b x  + 12a b x )log(b x  + a)
+--R     + 
+--R             4 8        3 6      2 2 4      3   2               3 6      2 2 4
+--R       (- 24b x  - 72a b x  - 72a b x  - 24a b x )log(x) - 12a b x  - 30a b x
+--R     + 
+--R            3   2     4
+--R       - 22a b x  - 3a
+--R  /
+--R       5 3 8      6 2 6      7   4     8 2
+--R     6a b x  + 18a b x  + 18a b x  + 6a x
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4 8        3 6      2 2 4      3   2        2
+--R       (12b x  + 36a b x  + 36a b x  + 12a b x )log(b x  + a)
+--R     + 
+--R             4 8        3 6      2 2 4      3   2               3 6      2 2 4
+--R       (- 24b x  - 72a b x  - 72a b x  - 24a b x )log(x) - 12a b x  - 30a b x
+--R     + 
+--R            3   2     4
+--R       - 22a b x  - 3a
+--R  /
+--R       5 3 8      6 2 6      7   4     8 2
+--R     6a b x  + 18a b x  + 18a b x  + 6a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 519
+
+--S 520 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 521
+
+)clear all
+
+--S 522 of 1370
+t0:=1/(x^5*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R         4 13       3 11     2 2 9     3   7    4 5
+--R        b x   + 4a b x   + 6a b x  + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 522
+
+--S 523 of 1370
+r0:=(-5/2)/(a^4*x^4)+5*b/(a^5*x^2)+1/6/(a*x^4*(a+b*x^2)^3)+_
+    5/12/(a^2*x^4*(a+b*x^2)^2)+5/3/(a^3*x^4*(a+b*x^2))+10*b^2*log(x)/a^6-_
+    5*b^2*log(a+b*x^2)/a^6
+--R 
+--R
+--R   (2)
+--R             5 10         4 8       2 3 6      3 2 4        2
+--R       (- 60b x   - 180a b x  - 180a b x  - 60a b x )log(b x  + a)
+--R     + 
+--R            5 10         4 8       2 3 6       3 2 4               4 8
+--R       (120b x   + 360a b x  + 360a b x  + 120a b x )log(x) + 60a b x
+--R     + 
+--R           2 3 6       3 2 4      4   2     5
+--R       150a b x  + 110a b x  + 15a b x  - 3a
+--R  /
+--R        6 3 10      7 2 8      8   6      9 4
+--R     12a b x   + 36a b x  + 36a b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 10         4 8       2 3 6      3 2 4        2
+--R       (- 60b x   - 180a b x  - 180a b x  - 60a b x )log(b x  + a)
+--R     + 
+--R            5 10         4 8       2 3 6       3 2 4               4 8
+--R       (120b x   + 360a b x  + 360a b x  + 120a b x )log(x) + 60a b x
+--R     + 
+--R           2 3 6       3 2 4      4   2     5
+--R       150a b x  + 110a b x  + 15a b x  - 3a
+--R  /
+--R        6 3 10      7 2 8      8   6      9 4
+--R     12a b x   + 36a b x  + 36a b x  + 12a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 524
+
+--S 525 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 526
+
+)clear all
+
+--S 527 of 1370
+t0:=x^12/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           12
+--R                          x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 527
+
+--S 528 of 1370
+r0:=231/16*a^2*x/b^6-77/16*a*x^3/b^5+231/80*x^5/b^4-1/6*x^11/(b*(a+b*x^2)^3)-_
+    11/24*x^9/(b^2*(a+b*x^2)^2)-33/16*x^7/(b^3*(a+b*x^2))-_
+    231/16*a^(5/2)*atan(x*sqrt(b)/sqrt(a))/b^(13/2)
+--R 
+--R
+--R   (2)
+--R                                                                     +-+
+--R               2 3 6         3 2 4         4   2        5  +-+     x\|b
+--R       (- 3465a b x  - 10395a b x  - 10395a b x  - 3465a )\|a atan(-----)
+--R                                                                     +-+
+--R                                                                    \|a
+--R     + 
+--R         5 11         4 9        2 3 7        3 2 5        4   3        5   +-+
+--R     (48b x   - 176a b x  + 1584a b x  + 7623a b x  + 9240a b x  + 3465a x)\|b
+--R  /
+--R          9 6         8 4       2 7 2       3 6  +-+
+--R     (240b x  + 720a b x  + 720a b x  + 240a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 528
+
+--S 529 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                             +---+
+--R                 2 3 6         3 2 4         4   2        5  |  a
+--R           (3465a b x  + 10395a b x  + 10395a b x  + 3465a ) |- -
+--R                                                            \|  b
+--R        *
+--R                      +---+
+--R                      |  a       2
+--R               - 2b x |- -  + b x  - a
+--R                     \|  b
+--R           log(-----------------------)
+--R                          2
+--R                       b x  + a
+--R       + 
+--R            5 11         4 9        2 3 7         3 2 5         4   3        5
+--R         96b x   - 352a b x  + 3168a b x  + 15246a b x  + 18480a b x  + 6930a x
+--R    /
+--R           9 6          8 4        2 7 2       3 6
+--R       480b x  + 1440a b x  + 1440a b x  + 480a b
+--R     ,
+--R
+--R                                                                    +-+
+--R                                                                    |a
+--R                                                           +-+      |-
+--R               2 3 6         3 2 4         4   2        5  |a      \|b
+--R         (3465a b x  + 10395a b x  + 10395a b x  + 3465a ) |- atan(----)
+--R                                                          \|b        x
+--R       + 
+--R            5 11         4 9        2 3 7        3 2 5        4   3        5
+--R         48b x   - 176a b x  + 1584a b x  + 7623a b x  + 9240a b x  + 3465a x
+--R    /
+--R           9 6         8 4       2 7 2       3 6
+--R       240b x  + 720a b x  + 720a b x  + 240a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 529
+
+--S 530 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                  +---+
+--R                                  |  a       2
+--R              +---+        - 2b x |- -  + b x  - a                    +-+
+--R            2 |  a  +-+          \|  b                    2 +-+     x\|b
+--R        231a  |- - \|b log(-----------------------) + 462a \|a atan(-----)
+--R             \|  b                    2                               +-+
+--R                                   b x  + a                          \|a
+--R   (4)  ------------------------------------------------------------------
+--R                                        6 +-+
+--R                                     32b \|b
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                  +-+
+--R                                                  |a
+--R                        +-+          +-+          |-
+--R            2 +-+     x\|b         2 |a  +-+     \|b
+--R        231a \|a atan(-----) + 231a  |- \|b atan(----)
+--R                        +-+         \|b            x
+--R                       \|a
+--R   (6)  ----------------------------------------------
+--R                              6 +-+
+--R                           16b \|b
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 533
+
+)clear all
+
+--S 534 of 1370
+t0:=x^10/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           10
+--R                          x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 534
+
+--S 535 of 1370
+r0:=-105/16*a*x/b^5+35/16*x^3/b^4-1/6*x^9/(b*(a+b*x^2)^3)-_
+    3/8*x^7/(b^2*(a+b*x^2)^2)-21/16*x^5/(b^3*(a+b*x^2))+_
+    105/16*a^(3/2)*atan(x*sqrt(b)/sqrt(a))/b^(11/2)
+--R 
+--R
+--R   (2)
+--R                                                             +-+
+--R              3 6       2 2 4       3   2       4  +-+     x\|b
+--R       (315a b x  + 945a b x  + 945a b x  + 315a )\|a atan(-----)
+--R                                                             +-+
+--R                                                            \|a
+--R     + 
+--R           4 9         3 7       2 2 5       3   3       4   +-+
+--R       (16b x  - 144a b x  - 693a b x  - 840a b x  - 315a x)\|b
+--R  /
+--R         8 6         7 4       2 6 2      3 5  +-+
+--R     (48b x  + 144a b x  + 144a b x  + 48a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                       +---+
+--R                  3 6       2 2 4       3   2       4  |  a
+--R           (315a b x  + 945a b x  + 945a b x  + 315a ) |- -
+--R                                                      \|  b
+--R        *
+--R                    +---+
+--R                    |  a       2
+--R               2b x |- -  + b x  - a
+--R                   \|  b
+--R           log(---------------------)
+--R                         2
+--R                      b x  + a
+--R       + 
+--R            4 9         3 7        2 2 5        3   3       4
+--R         32b x  - 288a b x  - 1386a b x  - 1680a b x  - 630a x
+--R    /
+--R          8 6         7 4       2 6 2      3 5
+--R       96b x  + 288a b x  + 288a b x  + 96a b
+--R     ,
+--R
+--R                                                                +-+
+--R                                                                |a
+--R                                                       +-+      |-
+--R                  3 6       2 2 4       3   2       4  |a      \|b        4 9
+--R         (- 315a b x  - 945a b x  - 945a b x  - 315a ) |- atan(----) + 16b x
+--R                                                      \|b        x
+--R       + 
+--R                 3 7       2 2 5       3   3       4
+--R         - 144a b x  - 693a b x  - 840a b x  - 315a x
+--R    /
+--R          8 6         7 4       2 6 2      3 5
+--R       48b x  + 144a b x  + 144a b x  + 48a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 536
+
+--S 537 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                               +---+
+--R                               |  a       2
+--R             +---+        2b x |- -  + b x  - a                   +-+
+--R             |  a  +-+        \|  b                     +-+     x\|b
+--R        105a |- - \|b log(---------------------) - 210a\|a atan(-----)
+--R            \|  b                   2                             +-+
+--R                                 b x  + a                        \|a
+--R   (4)  --------------------------------------------------------------
+--R                                      5 +-+
+--R                                   32b \|b
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                  +-+
+--R                                                  |a
+--R                         +-+         +-+          |-
+--R               +-+     x\|b          |a  +-+     \|b
+--R        - 105a\|a atan(-----) - 105a |- \|b atan(----)
+--R                         +-+        \|b            x
+--R                        \|a
+--R   (6)  ----------------------------------------------
+--R                              5 +-+
+--R                           16b \|b
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 1370
+t0:=x^8/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            8
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 541
+
+--S 542 of 1370
+r0:=35/16*x/b^4-1/6*x^7/(b*(a+b*x^2)^3)-7/24*x^5/(b^2*(a+b*x^2)^2)-_
+    35/48*x^3/(b^3*(a+b*x^2))-35/16*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/b^(9/2)
+--R 
+--R
+--R   (2)
+--R                                                             +-+
+--R              3 6         2 4       2   2       3  +-+     x\|b
+--R       (- 105b x  - 315a b x  - 315a b x  - 105a )\|a atan(-----)
+--R                                                             +-+
+--R                                                            \|a
+--R     + 
+--R           3 7         2 5       2   3       3   +-+
+--R       (48b x  + 231a b x  + 280a b x  + 105a x)\|b
+--R  /
+--R         7 6         6 4       2 5 2      3 4  +-+
+--R     (48b x  + 144a b x  + 144a b x  + 48a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                     +---+
+--R                3 6         2 4       2   2       3  |  a
+--R           (105b x  + 315a b x  + 315a b x  + 105a ) |- -
+--R                                                    \|  b
+--R        *
+--R                      +---+
+--R                      |  a       2
+--R               - 2b x |- -  + b x  - a
+--R                     \|  b
+--R           log(-----------------------)
+--R                          2
+--R                       b x  + a
+--R       + 
+--R            3 7         2 5       2   3       3
+--R         96b x  + 462a b x  + 560a b x  + 210a x
+--R    /
+--R          7 6         6 4       2 5 2      3 4
+--R       96b x  + 288a b x  + 288a b x  + 96a b
+--R     ,
+--R
+--R                                                            +-+
+--R                                                            |a
+--R                                                   +-+      |-
+--R              3 6         2 4       2   2       3  |a      \|b        3 7
+--R         (105b x  + 315a b x  + 315a b x  + 105a ) |- atan(----) + 48b x
+--R                                                  \|b        x
+--R       + 
+--R               2 5       2   3       3
+--R         231a b x  + 280a b x  + 105a x
+--R    /
+--R          7 6         6 4       2 5 2      3 4
+--R       48b x  + 144a b x  + 144a b x  + 48a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 543
+
+--S 544 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                +---+
+--R                                |  a       2
+--R            +---+        - 2b x |- -  + b x  - a                +-+
+--R            |  a  +-+          \|  b                  +-+     x\|b
+--R        35  |- - \|b log(----------------------- + 70\|a atan(-----)
+--R           \|  b                    2                           +-+
+--R                                 b x  + a                      \|a
+--R   (4)  ------------------------------------------------------------
+--R                                     4 +-+
+--R                                  32b \|b
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                             +-+
+--R                                             |a
+--R                     +-+        +-+          |-
+--R           +-+     x\|b         |a  +-+     \|b
+--R        35\|a atan(-----) + 35  |- \|b atan(----)
+--R                     +-+       \|b            x
+--R                    \|a
+--R   (6)  ----------------------------------------
+--R                           4 +-+
+--R                        16b \|b
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 547
+
+)clear all
+
+--S 548 of 1370
+t0:=x^6/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            6
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 548
+
+--S 549 of 1370
+r0:=-1/6*x^5/(b*(a+b*x^2)^3)-5/24*x^3/(b^2*(a+b*x^2)^2)-_
+    5/16*x/(b^3*(a+b*x^2))+5/16*atan(x*sqrt(b)/sqrt(a))/(b^(7/2)*sqrt(a))
+--R 
+--R
+--R   (2)
+--R                                                   +-+
+--R           3 6        2 4      2   2      3      x\|b
+--R       (15b x  + 45a b x  + 45a b x  + 15a )atan(-----)
+--R                                                   +-+
+--R                                                  \|a
+--R     + 
+--R             2 5          3      2   +-+ +-+
+--R       (- 33b x  - 40a b x  - 15a x)\|a \|b
+--R  /
+--R         6 6         5 4       2 4 2      3 3  +-+ +-+
+--R     (48b x  + 144a b x  + 144a b x  + 48a b )\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                      2      +-----+
+--R             3 6        2 4      2   2      3     (b x  - a)\|- a b  + 2a b x
+--R         (15b x  + 45a b x  + 45a b x  + 15a )log(---------------------------)
+--R                                                               2
+--R                                                            b x  + a
+--R       + 
+--R               2 5          3      2   +-----+
+--R         (- 66b x  - 80a b x  - 30a x)\|- a b
+--R    /
+--R           6 6         5 4       2 4 2      3 3  +-----+
+--R       (96b x  + 288a b x  + 288a b x  + 96a b )\|- a b
+--R     ,
+--R
+--R                                                     +---+
+--R             3 6        2 4      2   2      3      x\|a b
+--R         (15b x  + 45a b x  + 45a b x  + 15a )atan(-------)
+--R                                                      a
+--R       + 
+--R               2 5          3      2   +---+
+--R         (- 33b x  - 40a b x  - 15a x)\|a b
+--R    /
+--R           6 6         5 4       2 4 2      3 3  +---+
+--R       (48b x  + 144a b x  + 144a b x  + 48a b )\|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 550
+
+--S 551 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                         2      +-----+                              +-+
+--R          +-+ +-+    (b x  - a)\|- a b  + 2a b x       +-----+     x\|b
+--R        5\|a \|b log(---------------------------) - 10\|- a b atan(-----)
+--R                                  2                                  +-+
+--R                               b x  + a                             \|a
+--R   (4)  -----------------------------------------------------------------
+--R                                  3 +-----+ +-+ +-+
+--R                               32b \|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+                  +-+
+--R          +-+ +-+     x\|a b       +---+     x\|b
+--R        5\|a \|b atan(-------) - 5\|a b atan(-----)
+--R                         a                     +-+
+--R                                              \|a
+--R   (6)  -------------------------------------------
+--R                        3 +-+ +-+ +---+
+--R                     16b \|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 554
+
+)clear all
+
+--S 555 of 1370
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            4
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 555
+
+--S 556 of 1370
+r0:=-1/6*x^3/(b*(a+b*x^2)^3)-1/8*x/(b^2*(a+b*x^2)^2)+_
+    1/16*x/(a*b^2*(a+b*x^2))+1/16*atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*b^(5/2))
+--R 
+--R
+--R   (2)
+--R                                               +-+
+--R          3 6       2 4     2   2     3      x\|b
+--R       (3b x  + 9a b x  + 9a b x  + 3a )atan(-----)
+--R                                               +-+
+--R                                              \|a
+--R     + 
+--R          2 5         3     2   +-+ +-+
+--R       (3b x  - 8a b x  - 3a x)\|a \|b
+--R  /
+--R           5 6       2 4 4       3 3 2      4 2  +-+ +-+
+--R     (48a b x  + 144a b x  + 144a b x  + 48a b )\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                  2      +-----+
+--R            3 6       2 4     2   2     3     (b x  - a)\|- a b  + 2a b x
+--R         (3b x  + 9a b x  + 9a b x  + 3a )log(---------------------------)
+--R                                                           2
+--R                                                        b x  + a
+--R       + 
+--R            2 5          3     2   +-----+
+--R         (6b x  - 16a b x  - 6a x)\|- a b
+--R    /
+--R             5 6       2 4 4       3 3 2      4 2  +-----+
+--R       (96a b x  + 288a b x  + 288a b x  + 96a b )\|- a b
+--R     ,
+--R
+--R                                                 +---+
+--R            3 6       2 4     2   2     3      x\|a b
+--R         (3b x  + 9a b x  + 9a b x  + 3a )atan(-------)
+--R                                                  a
+--R       + 
+--R            2 5         3     2   +---+
+--R         (3b x  - 8a b x  - 3a x)\|a b
+--R    /
+--R             5 6       2 4 4       3 3 2      4 2  +---+
+--R       (48a b x  + 144a b x  + 144a b x  + 48a b )\|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 557
+
+--S 558 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                        2      +-----+                             +-+
+--R         +-+ +-+    (b x  - a)\|- a b  + 2a b x      +-----+     x\|b
+--R        \|a \|b log(---------------------------) - 2\|- a b atan(-----)
+--R                                 2                                 +-+
+--R                              b x  + a                            \|a
+--R   (4)  ---------------------------------------------------------------
+--R                                  2 +-----+ +-+ +-+
+--R                             32a b \|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                       +---+                 +-+
+--R         +-+ +-+     x\|a b      +---+     x\|b
+--R        \|a \|b atan(-------) - \|a b atan(-----)
+--R                        a                    +-+
+--R                                            \|a
+--R   (6)  -----------------------------------------
+--R                        2 +-+ +-+ +---+
+--R                   16a b \|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 1370
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            2
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 562
+
+--S 563 of 1370
+r0:=-1/6*x/(b*(a+b*x^2)^3)+1/24*x/(a*b*(a+b*x^2)^2)+_
+    1/16*x/(a^2*b*(a+b*x^2))+1/16*atan(x*sqrt(b)/sqrt(a))/(a^(5/2)*b^(3/2))
+--R 
+--R
+--R   (2)
+--R                                               +-+
+--R          3 6       2 4     2   2     3      x\|b
+--R       (3b x  + 9a b x  + 9a b x  + 3a )atan(-----)
+--R                                               +-+
+--R                                              \|a
+--R     + 
+--R          2 5         3     2   +-+ +-+
+--R       (3b x  + 8a b x  - 3a x)\|a \|b
+--R  /
+--R         2 4 6       3 3 4       4 2 2      5   +-+ +-+
+--R     (48a b x  + 144a b x  + 144a b x  + 48a b)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                  2      +-----+
+--R            3 6       2 4     2   2     3     (b x  - a)\|- a b  + 2a b x
+--R         (3b x  + 9a b x  + 9a b x  + 3a )log(---------------------------)
+--R                                                           2
+--R                                                        b x  + a
+--R       + 
+--R            2 5          3     2   +-----+
+--R         (6b x  + 16a b x  - 6a x)\|- a b
+--R    /
+--R           2 4 6       3 3 4       4 2 2      5   +-----+
+--R       (96a b x  + 288a b x  + 288a b x  + 96a b)\|- a b
+--R     ,
+--R
+--R                                                 +---+
+--R            3 6       2 4     2   2     3      x\|a b
+--R         (3b x  + 9a b x  + 9a b x  + 3a )atan(-------)
+--R                                                  a
+--R       + 
+--R            2 5         3     2   +---+
+--R         (3b x  + 8a b x  - 3a x)\|a b
+--R    /
+--R           2 4 6       3 3 4       4 2 2      5   +---+
+--R       (48a b x  + 144a b x  + 144a b x  + 48a b)\|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 564
+
+--S 565 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                        2      +-----+                             +-+
+--R         +-+ +-+    (b x  - a)\|- a b  + 2a b x      +-----+     x\|b
+--R        \|a \|b log(---------------------------) - 2\|- a b atan(-----)
+--R                                 2                                 +-+
+--R                              b x  + a                            \|a
+--R   (4)  ---------------------------------------------------------------
+--R                                2  +-----+ +-+ +-+
+--R                             32a b\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                       +---+                 +-+
+--R         +-+ +-+     x\|a b      +---+     x\|b
+--R        \|a \|b atan(-------) - \|a b atan(-----)
+--R                        a                    +-+
+--R                                            \|a
+--R   (6)  -----------------------------------------
+--R                      2  +-+ +-+ +---+
+--R                   16a b\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 568
+
+)clear all
+
+--S 569 of 1370
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           1
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 569
+
+--S 570 of 1370
+r0:=1/6*x/(a*(a+b*x^2)^3)+5/24*x/(a^2*(a+b*x^2)^2)+_
+    5/16*x/(a^3*(a+b*x^2))+5/16*atan(x*sqrt(b)/sqrt(a))/(a^(7/2)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                                                   +-+
+--R           3 6        2 4      2   2      3      x\|b
+--R       (15b x  + 45a b x  + 45a b x  + 15a )atan(-----)
+--R                                                   +-+
+--R                                                  \|a
+--R     + 
+--R           2 5          3      2   +-+ +-+
+--R       (15b x  + 40a b x  + 33a x)\|a \|b
+--R  /
+--R         3 3 6       4 2 4       5   2      6  +-+ +-+
+--R     (48a b x  + 144a b x  + 144a b x  + 48a )\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                      2      +-----+
+--R             3 6        2 4      2   2      3     (b x  - a)\|- a b  + 2a b x
+--R         (15b x  + 45a b x  + 45a b x  + 15a )log(---------------------------)
+--R                                                               2
+--R                                                            b x  + a
+--R       + 
+--R             2 5          3      2   +-----+
+--R         (30b x  + 80a b x  + 66a x)\|- a b
+--R    /
+--R           3 3 6       4 2 4       5   2      6  +-----+
+--R       (96a b x  + 288a b x  + 288a b x  + 96a )\|- a b
+--R     ,
+--R
+--R                                                     +---+
+--R             3 6        2 4      2   2      3      x\|a b
+--R         (15b x  + 45a b x  + 45a b x  + 15a )atan(-------)
+--R                                                      a
+--R       + 
+--R             2 5          3      2   +---+
+--R         (15b x  + 40a b x  + 33a x)\|a b
+--R    /
+--R           3 3 6       4 2 4       5   2      6  +---+
+--R       (48a b x  + 144a b x  + 144a b x  + 48a )\|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 571
+
+--S 572 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                         2      +-----+                              +-+
+--R          +-+ +-+    (b x  - a)\|- a b  + 2a b x       +-----+     x\|b
+--R        5\|a \|b log(---------------------------) - 10\|- a b atan(-----)
+--R                                  2                                  +-+
+--R                               b x  + a                             \|a
+--R   (4)  -----------------------------------------------------------------
+--R                                  3 +-----+ +-+ +-+
+--R                               32a \|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+                  +-+
+--R          +-+ +-+     x\|a b       +---+     x\|b
+--R        5\|a \|b atan(-------) - 5\|a b atan(-----)
+--R                         a                     +-+
+--R                                              \|a
+--R   (6)  -------------------------------------------
+--R                        3 +-+ +-+ +---+
+--R                     16a \|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 575
+
+)clear all
+
+--S 576 of 1370
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                             1
+--R   (1)  ------------------------------------------
+--R         4 10       3 8     2 2 6     3   4    4 2
+--R        b x   + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 576
+
+--S 577 of 1370
+r0:=(-35/16)/(a^4*x)+1/6/(a*x*(a+b*x^2)^3)+7/24/(a^2*x*(a+b*x^2)^2)+_
+    35/48/(a^3*x*(a+b*x^2))-35/16*atan(x*sqrt(b)/sqrt(a))*sqrt(b)/a^(9/2)
+--R 
+--R
+--R   (2)
+--R                                                              +-+
+--R              3 7         2 5       2   3       3   +-+     x\|b
+--R       (- 105b x  - 315a b x  - 315a b x  - 105a x)\|b atan(-----)
+--R                                                              +-+
+--R                                                             \|a
+--R     + 
+--R              3 6         2 4       2   2      3  +-+
+--R       (- 105b x  - 280a b x  - 231a b x  - 48a )\|a
+--R  /
+--R         4 3 7       5 2 5       6   3      7   +-+
+--R     (48a b x  + 144a b x  + 144a b x  + 48a x)\|a
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                      +---+
+--R                3 7         2 5       2   3       3   |  b
+--R           (105b x  + 315a b x  + 315a b x  + 105a x) |- -
+--R                                                     \|  a
+--R        *
+--R                      +---+
+--R                      |  b       2
+--R               - 2a x |- -  + b x  - a
+--R                     \|  a
+--R           log(-----------------------)
+--R                          2
+--R                       b x  + a
+--R       + 
+--R               3 6         2 4       2   2      3
+--R         - 210b x  - 560a b x  - 462a b x  - 96a
+--R    /
+--R          4 3 7       5 2 5       6   3      7
+--R       96a b x  + 288a b x  + 288a b x  + 96a x
+--R     ,
+--R
+--R                                                              +-+
+--R                                                              |b
+--R                                                    +-+     a |-
+--R              3 7         2 5       2   3       3   |b       \|a         3 6
+--R         (105b x  + 315a b x  + 315a b x  + 105a x) |- atan(-----) - 105b x
+--R                                                   \|a       b x
+--R       + 
+--R                 2 4       2   2      3
+--R         - 280a b x  - 231a b x  - 48a
+--R    /
+--R          4 3 7       5 2 5       6   3      7
+--R       48a b x  + 144a b x  + 144a b x  + 48a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 578
+
+--S 579 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                +---+
+--R                                |  b       2
+--R            +---+        - 2a x |- -  + b x  - a                +-+
+--R            |  b  +-+          \|  a                  +-+     x\|b
+--R        35  |- - \|a log(----------------------- + 70\|b atan(-----)
+--R           \|  a                    2                           +-+
+--R                                 b x  + a                      \|a
+--R   (4)  ------------------------------------------------------------
+--R                                     4 +-+
+--R                                  32a \|a
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                             +-+
+--R                                             |b
+--R                     +-+           +-+     a |-
+--R           +-+     x\|b        +-+ |b       \|a
+--R        35\|b atan(-----) + 35\|a  |- atan(-----)
+--R                     +-+          \|a       b x
+--R                    \|a
+--R   (6)  -----------------------------------------
+--R                            4 +-+
+--R                         16a \|a
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 1370
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R         4 12       3 10     2 2 8     3   6    4 4
+--R        b x   + 4a b x   + 6a b x  + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 583
+
+--S 584 of 1370
+r0:=(-35/16)/(a^4*x^3)+105/16*b/(a^5*x)+1/6/(a*x^3*(a+b*x^2)^3)+_
+    3/8/(a^2*x^3*(a+b*x^2)^2)+21/16/(a^3*x^3*(a+b*x^2))+_
+    105/16*b^(3/2)*atan(x*sqrt(b)/sqrt(a))/a^(11/2)
+--R 
+--R
+--R   (2)
+--R                                                               +-+
+--R            4 9         3 7       2 2 5       3   3  +-+     x\|b
+--R       (315b x  + 945a b x  + 945a b x  + 315a b x )\|b atan(-----)
+--R                                                               +-+
+--R                                                              \|a
+--R     + 
+--R            4 8         3 6       2 2 4       3   2      4  +-+
+--R       (315b x  + 840a b x  + 693a b x  + 144a b x  - 16a )\|a
+--R  /
+--R         5 3 9       6 2 7       7   5      8 3  +-+
+--R     (48a b x  + 144a b x  + 144a b x  + 48a x )\|a
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                         +---+
+--R                4 9         3 7       2 2 5       3   3  |  b
+--R           (315b x  + 945a b x  + 945a b x  + 315a b x ) |- -
+--R                                                        \|  a
+--R        *
+--R                    +---+
+--R                    |  b       2
+--R               2a x |- -  + b x  - a
+--R                   \|  a
+--R           log(---------------------)
+--R                         2
+--R                      b x  + a
+--R       + 
+--R             4 8          3 6        2 2 4       3   2      4
+--R         630b x  + 1680a b x  + 1386a b x  + 288a b x  - 32a
+--R    /
+--R          5 3 9       6 2 7       7   5      8 3
+--R       96a b x  + 288a b x  + 288a b x  + 96a x
+--R     ,
+--R
+--R                                                                   +-+
+--R                                                                   |b
+--R                                                         +-+     a |-
+--R                4 9         3 7       2 2 5       3   3  |b       \|a
+--R         (- 315b x  - 945a b x  - 945a b x  - 315a b x ) |- atan(-----)
+--R                                                        \|a       b x
+--R       + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         315b x  + 840a b x  + 693a b x  + 144a b x  - 16a
+--R    /
+--R          5 3 9       6 2 7       7   5      8 3
+--R       48a b x  + 144a b x  + 144a b x  + 48a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 585
+
+--S 586 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                               +---+
+--R                               |  b       2
+--R             +---+        2a x |- -  + b x  - a                   +-+
+--R             |  b  +-+        \|  a                     +-+     x\|b
+--R        105b |- - \|a log(---------------------) - 210b\|b atan(-----)
+--R            \|  a                   2                             +-+
+--R                                 b x  + a                        \|a
+--R   (4)  --------------------------------------------------------------
+--R                                      5 +-+
+--R                                   32a \|a
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                   +-+
+--R                                                   |b
+--R                         +-+             +-+     a |-
+--R               +-+     x\|b          +-+ |b       \|a
+--R        - 105b\|b atan(-----) - 105b\|a  |- atan(-----)
+--R                         +-+            \|a       b x
+--R                        \|a
+--R   (6)  -----------------------------------------------
+--R                               5 +-+
+--R                            16a \|a
+--R                                                    Type: Expression(Integer)
+--E 588
+
+--S 589 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 589
+
+)clear all
+
+--S 590 of 1370
+t0:=1/(x^6*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R         4 14       3 12     2 2 10     3   8    4 6
+--R        b x   + 4a b x   + 6a b x   + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 590
+
+--S 591 of 1370
+r0:=(-231/80)/(a^4*x^5)+77/16*b/(a^5*x^3)-231/16*b^2/(a^6*x)+_
+    1/6/(a*x^5*(a+b*x^2)^3)+11/24/(a^2*x^5*(a+b*x^2)^2)+_
+    33/16/(a^3*x^5*(a+b*x^2))-231/16*b^(5/2)*atan(x*sqrt(b)/sqrt(a))/a^(13/2)
+--R 
+--R
+--R   (2)
+--R                                                                        +-+
+--R               5 11           4 9         2 3 7        3 2 5  +-+     x\|b
+--R       (- 3465b x   - 10395a b x  - 10395a b x  - 3465a b x )\|b atan(-----)
+--R                                                                        +-+
+--R                                                                       \|a
+--R     + 
+--R             5 10          4 8        2 3 6        3 2 4       4   2      5  +-+
+--R     (- 3465b x   - 9240a b x  - 7623a b x  - 1584a b x  + 176a b x  - 48a )\|a
+--R  /
+--R          6 3 11       7 2 9       8   7       9 5  +-+
+--R     (240a b x   + 720a b x  + 720a b x  + 240a x )\|a
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                                +---+
+--R                 5 11           4 9         2 3 7        3 2 5  |  b
+--R           (3465b x   + 10395a b x  + 10395a b x  + 3465a b x ) |- -
+--R                                                               \|  a
+--R        *
+--R                      +---+
+--R                      |  b       2
+--R               - 2a x |- -  + b x  - a
+--R                     \|  a
+--R           log(-----------------------)
+--R                          2
+--R                       b x  + a
+--R       + 
+--R              5 10           4 8         2 3 6        3 2 4       4   2      5
+--R       - 6930b x   - 18480a b x  - 15246a b x  - 3168a b x  + 352a b x  - 96a
+--R    /
+--R           6 3 11        7 2 9        8   7       9 5
+--R       480a b x   + 1440a b x  + 1440a b x  + 480a x
+--R     ,
+--R
+--R                                                                        +-+
+--R                                                                        |b
+--R                                                              +-+     a |-
+--R               5 11           4 9         2 3 7        3 2 5  |b       \|a
+--R         (3465b x   + 10395a b x  + 10395a b x  + 3465a b x ) |- atan(-----)
+--R                                                             \|a       b x
+--R       + 
+--R                5 10          4 8        2 3 6        3 2 4       4   2      5
+--R         - 3465b x   - 9240a b x  - 7623a b x  - 1584a b x  + 176a b x  - 48a
+--R    /
+--R           6 3 11       7 2 9       8   7       9 5
+--R       240a b x   + 720a b x  + 720a b x  + 240a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 592
+
+--S 593 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                  +---+
+--R                                  |  b       2
+--R              +---+        - 2a x |- -  + b x  - a                    +-+
+--R            2 |  b  +-+          \|  a                    2 +-+     x\|b
+--R        231b  |- - \|a log(-----------------------) + 462b \|b atan(-----)
+--R             \|  a                    2                               +-+
+--R                                   b x  + a                          \|a
+--R   (4)  ------------------------------------------------------------------
+--R                                        6 +-+
+--R                                     32a \|a
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                   +-+
+--R                                                   |b
+--R                        +-+              +-+     a |-
+--R            2 +-+     x\|b         2 +-+ |b       \|a
+--R        231b \|b atan(-----) + 231b \|a  |- atan(-----)
+--R                        +-+             \|a       b x
+--R                       \|a
+--R   (6)  -----------------------------------------------
+--R                               6 +-+
+--R                            16a \|a
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 596
+
+)clear all
+
+--S 597 of 1370
+t0:=x^m/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        m
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 1370
+--r0:=1/10*x^(1+m)/(a*(a+b*x^2)^5)+1/80*(9-m)*x^(1+m)/(a^2*(a+b*x^2)^4)+_
+--  1/480*(7-m)*(9-m)*x^(1+m)/(a^3*(a+b*x^2)^3)+1/1920*(5-m)*(7-m)*_
+--  (9-m)*x^(1+m)/(a^4*(a+b*x^2)^2)+1/3840*(3-m)*(5-m)*(7-m)*(9-m)*_
+--  x^(1+m)/(a^5*(a+b*x^2))+1/3840*(1-m)*(3-m)*(5-m)*(7-m)*(9-m)*_
+--  x^(1+m)*hypergeometric(1,1/2*(1+m),1/2*(3+m),-b*x^2/a)/(a^6*(1+m))
+--E 598
+
+--S 599 of 1370
+--a0:=integrate(t0,x)
+--E 599
+
+--S 600 of 1370
+--m0:=a0-r0
+--E 600
+
+--S 601 of 1370
+--d0:=D(m0,x)
+--E 601
+
+)clear all
+
+--S 602 of 1370
+t0:=x^15/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        15
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 602
+
+--S 603 of 1370
+r0:=-3*a*x^2/b^7+1/4*x^4/b^6+1/10*a^7/(b^8*(a+b*x^2)^5)-_
+    7/8*a^6/(b^8*(a+b*x^2)^4)+7/2*a^5/(b^8*(a+b*x^2)^3)-_
+    35/4*a^4/(b^8*(a+b*x^2)^2)+35/2*a^3/(b^8*(a+b*x^2))+_
+    21/2*a^2*log(a+b*x^2)/b^8
+--R 
+--R
+--R   (2)
+--R                 2 5 10        3 4 8        4 3 6        5 2 4        6   2
+--R             420a b x   + 2100a b x  + 4200a b x  + 4200a b x  + 2100a b x
+--R           + 
+--R                 7
+--R             420a
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R          7 14        6 12       2 5 10       3 4 8        4 3 6        5 2 4
+--R       10b x   - 70a b x   - 500a b x   - 400a b x  + 1300a b x  + 2700a b x
+--R     + 
+--R            6   2       7
+--R       1875a b x  + 459a
+--R  /
+--R        13 10         12 8       2 11 6       3 10 4       4 9 2      5 8
+--R     40b  x   + 200a b  x  + 400a b  x  + 400a b  x  + 200a b x  + 40a b
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2 5 10        3 4 8        4 3 6        5 2 4        6   2
+--R             420a b x   + 2100a b x  + 4200a b x  + 4200a b x  + 2100a b x
+--R           + 
+--R                 7
+--R             420a
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R          7 14        6 12       2 5 10       3 4 8        4 3 6        5 2 4
+--R       10b x   - 70a b x   - 500a b x   - 400a b x  + 1300a b x  + 2700a b x
+--R     + 
+--R            6   2       7
+--R       1875a b x  + 459a
+--R  /
+--R        13 10         12 8       2 11 6       3 10 4       4 9 2      5 8
+--R     40b  x   + 200a b  x  + 400a b  x  + 400a b  x  + 200a b x  + 40a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 604
+
+--S 605 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 606
+
+)clear all
+
+--S 607 of 1370
+t0:=x^13/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        13
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 607
+
+--S 608 of 1370
+r0:=1/2*x^2/b^6-1/10*a^6/(b^7*(a+b*x^2)^5)+3/4*a^5/(b^7*(a+b*x^2)^4)-_
+    5/2*a^4/(b^7*(a+b*x^2)^3)+5*a^3/(b^7*(a+b*x^2)^2)-_
+    15/2*a^2/(b^7*(a+b*x^2))-3*a*log(a+b*x^2)/b^7
+--R 
+--R
+--R   (2)
+--R                 5 10       2 4 8       3 3 6       4 2 4       5   2      6
+--R         (- 60a b x   - 300a b x  - 600a b x  - 600a b x  - 300a b x  - 60a )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R        6 12        5 10      2 4 8       3 3 6       4 2 4       5   2      6
+--R     10b x   + 50a b x   - 50a b x  - 400a b x  - 600a b x  - 375a b x  - 87a
+--R  /
+--R        12 10         11 8       2 10 6       3 9 4       4 8 2      5 7
+--R     20b  x   + 100a b  x  + 200a b  x  + 200a b x  + 100a b x  + 20a b
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 5 10       2 4 8       3 3 6       4 2 4       5   2      6
+--R         (- 60a b x   - 300a b x  - 600a b x  - 600a b x  - 300a b x  - 60a )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R        6 12        5 10      2 4 8       3 3 6       4 2 4       5   2      6
+--R     10b x   + 50a b x   - 50a b x  - 400a b x  - 600a b x  - 375a b x  - 87a
+--R  /
+--R        12 10         11 8       2 10 6       3 9 4       4 8 2      5 7
+--R     20b  x   + 100a b  x  + 200a b  x  + 200a b x  + 100a b x  + 20a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 609
+
+--S 610 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 611
+
+)clear all
+
+--S 612 of 1370
+t0:=x^11/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        11
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 612
+
+--S 613 of 1370
+r0:=1/10*a^5/(b^6*(a+b*x^2)^5)-5/8*a^4/(b^6*(a+b*x^2)^4)+_
+    5/3*a^3/(b^6*(a+b*x^2)^3)-5/2*a^2/(b^6*(a+b*x^2)^2)+_
+    5/2*a/(b^6*(a+b*x^2))+1/2*log(a+b*x^2)/b^6
+--R 
+--R
+--R   (2)
+--R             5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (60b x   + 300a b x  + 600a b x  + 600a b x  + 300a b x  + 60a )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R             4 8       2 3 6        3 2 4       4   2       5
+--R       300a b x  + 900a b x  + 1100a b x  + 625a b x  + 137a
+--R  /
+--R         11 10         10 8        2 9 6        3 8 4       4 7 2       5 6
+--R     120b  x   + 600a b  x  + 1200a b x  + 1200a b x  + 600a b x  + 120a b
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (60b x   + 300a b x  + 600a b x  + 600a b x  + 300a b x  + 60a )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R             4 8       2 3 6        3 2 4       4   2       5
+--R       300a b x  + 900a b x  + 1100a b x  + 625a b x  + 137a
+--R  /
+--R         11 10         10 8        2 9 6        3 8 4       4 7 2       5 6
+--R     120b  x   + 600a b  x  + 1200a b x  + 1200a b x  + 600a b x  + 120a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 614
+
+--S 615 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 616
+
+)clear all
+
+--S 617 of 1370
+t0:=x^9/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        9
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 617
+
+--S 618 of 1370
+r0:=1/10*x^10/(a*(a+b*x^2)^5)
+--R 
+--R
+--R                                 1  10
+--R                                -- x
+--R                                10
+--R   (2)  ------------------------------------------------------
+--R           5 10     2 4 8      3 3 6      4 2 4     5   2    6
+--R        a b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 618
+
+--S 619 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      4 8        3 6      2 2 4     3   2    4
+--R                  - 5b x  - 10a b x  - 10a b x  - 5a b x  - a
+--R   (3)  ---------------------------------------------------------------
+--R           10 10        9 8       2 8 6       3 7 4      4 6 2      5 5
+--R        10b  x   + 50a b x  + 100a b x  + 100a b x  + 50a b x  + 10a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 619
+
+--S 620 of 1370
+m0:=a0-r0
+--R 
+--R
+--R             1
+--R   (4)  - ------
+--R               5
+--R          10a b
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 621
+
+)clear all
+
+--S 622 of 1370
+t0:=x^7/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        7
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 622
+
+--S 623 of 1370
+r0:=1/10*x^8/(a*(a+b*x^2)^5)+1/40*x^8/(a^2*(a+b*x^2)^4)
+--R 
+--R
+--R                            1    10   1    8
+--R                           -- b x   + - a x
+--R                           40         8
+--R   (2)  ------------------------------------------------------
+--R         2 5 10     3 4 8      4 3 6      5 2 4     6   2    7
+--R        a b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 623
+
+--S 624 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            3 6        2 4     2   2    3
+--R                       - 10b x  - 10a b x  - 5a b x  - a
+--R   (3)  ----------------------------------------------------------------
+--R           9 10         8 8       2 7 6       3 6 4       4 5 2      5 4
+--R        40b x   + 200a b x  + 400a b x  + 400a b x  + 200a b x  + 40a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 624
+
+--S 625 of 1370
+m0:=a0-r0
+--R 
+--R
+--R             1
+--R   (4)  - ------
+--R             2 4
+--R          40a b
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 626
+
+)clear all
+
+--S 627 of 1370
+t0:=x^5/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        5
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 627
+
+--S 628 of 1370
+r0:=-1/10*a^2/(b^3*(a+b*x^2)^5)+1/4*a/(b^3*(a+b*x^2)^4)+_
+    (-1/6)/(b^3*(a+b*x^2)^3)
+--R 
+--R
+--R                       1  2 4    1      2    1  2
+--R                     - - b x  - -- a b x  - -- a
+--R                       6        12          60
+--R   (2)  ------------------------------------------------------
+--R         8 10       7 8      2 6 6      3 5 4     4 4 2    5 3
+--R        b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 628
+
+--S 629 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                  2 4         2    2
+--R                             - 10b x  - 5a b x  - a
+--R   (3)  ----------------------------------------------------------------
+--R           8 10         7 8       2 6 6       3 5 4       4 4 2      5 3
+--R        60b x   + 300a b x  + 600a b x  + 600a b x  + 300a b x  + 60a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 629
+
+--S 630 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 631
+
+)clear all
+
+--S 632 of 1370
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        3
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 632
+
+--S 633 of 1370
+r0:=1/10*a/(b^2*(a+b*x^2)^5)+(-1/8)/(b^2*(a+b*x^2)^4)
+--R 
+--R
+--R                              1    2    1
+--R                            - - b x  - -- a
+--R                              8        40
+--R   (2)  ------------------------------------------------------
+--R         7 10       6 8      2 5 6      3 4 4     4 3 2    5 2
+--R        b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 633
+
+--S 634 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                         2
+--R                                   - 5b x  - a
+--R   (3)  ----------------------------------------------------------------
+--R           7 10         6 8       2 5 6       3 4 4       4 3 2      5 2
+--R        40b x   + 200a b x  + 400a b x  + 400a b x  + 200a b x  + 40a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 634
+
+--S 635 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 636
+
+)clear all
+
+--S 637 of 1370
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 637
+
+--S 638 of 1370
+r0:=(-1/10)/(b*(a+b*x^2)^5)
+--R 
+--R
+--R                                     1
+--R                                    --
+--R                                    10
+--R   (2)  - -----------------------------------------------------
+--R           6 10       5 8      2 4 6      3 3 4     4 2 2    5
+--R          b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 638
+
+--S 639 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        1
+--R   (3)  - -------------------------------------------------------------
+--R             6 10        5 8       2 4 6       3 3 4      4 2 2      5
+--R          10b x   + 50a b x  + 100a b x  + 100a b x  + 50a b x  + 10a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 639
+
+--S 640 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 641
+
+)clear all
+
+--S 642 of 1370
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                        1
+--R   (1)  -----------------------------------------------------------------
+--R         6 13       5 11      2 4 9      3 3 7      4 2 5     5   3    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 642
+
+--S 643 of 1370
+r0:=1/10/(a*(a+b*x^2)^5)+1/8/(a^2*(a+b*x^2)^4)+1/6/(a^3*(a+b*x^2)^3)+_
+    1/4/(a^4*(a+b*x^2)^2)+1/2/(a^5*(a+b*x^2))+log(x)/a^6-1/2*log(a+b*x^2)/a^6
+--R 
+--R
+--R   (2)
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 60b x   - 300a b x  - 600a b x  - 600a b x  - 300a b x  - 60a )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R              5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (120b x   + 600a b x  + 1200a b x  + 1200a b x  + 600a b x  + 120a )
+--R      *
+--R         log(x)
+--R     + 
+--R            4 8       2 3 6       3 2 4       4   2       5
+--R       60a b x  + 270a b x  + 470a b x  + 385a b x  + 137a
+--R  /
+--R         6 5 10       7 4 8        8 3 6        9 2 4       10   2       11
+--R     120a b x   + 600a b x  + 1200a b x  + 1200a b x  + 600a  b x  + 120a
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 60b x   - 300a b x  - 600a b x  - 600a b x  - 300a b x  - 60a )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R              5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (120b x   + 600a b x  + 1200a b x  + 1200a b x  + 600a b x  + 120a )
+--R      *
+--R         log(x)
+--R     + 
+--R            4 8       2 3 6       3 2 4       4   2       5
+--R       60a b x  + 270a b x  + 470a b x  + 385a b x  + 137a
+--R  /
+--R         6 5 10       7 4 8        8 3 6        9 2 4       10   2       11
+--R     120a b x   + 600a b x  + 1200a b x  + 1200a b x  + 600a  b x  + 120a
+--R                                         Type: Union(Expression(Integer),...)
+--E 644
+
+--S 645 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 645
+
+--S 646 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 646
+
+)clear all
+
+--S 647 of 1370
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R         6 15       5 13      2 4 11      3 3 9      4 2 7     5   5    6 3
+--R        b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 647
+
+--S 648 of 1370
+r0:=(-3)/(a^6*x^2)+1/10/(a*x^2*(a+b*x^2)^5)+3/20/(a^2*x^2*(a+b*x^2)^4)+_
+    1/4/(a^3*x^2*(a+b*x^2)^3)+1/2/(a^4*x^2*(a+b*x^2)^2)+_
+    3/2/(a^5*x^2*(a+b*x^2))-6*b*log(x)/a^7+3*b*log(a+b*x^2)/a^7
+--R 
+--R
+--R   (2)
+--R             6 12         5 10       2 4 8       3 3 6       4 2 4      5   2
+--R         (60b x   + 300a b x   + 600a b x  + 600a b x  + 300a b x  + 60a b x )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R                 6 12         5 10        2 4 8        3 3 6       4 2 4
+--R           - 120b x   - 600a b x   - 1200a b x  - 1200a b x  - 600a b x
+--R         + 
+--R                 5   2
+--R           - 120a b x
+--R      *
+--R         log(x)
+--R     + 
+--R              5 10       2 4 8       3 3 6       4 2 4       5   2      6
+--R       - 60a b x   - 270a b x  - 470a b x  - 385a b x  - 137a b x  - 10a
+--R  /
+--R        7 5 12       8 4 10       9 3 8       10 2 6       11   4      12 2
+--R     20a b x   + 100a b x   + 200a b x  + 200a  b x  + 100a  b x  + 20a  x
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             6 12         5 10       2 4 8       3 3 6       4 2 4      5   2
+--R         (60b x   + 300a b x   + 600a b x  + 600a b x  + 300a b x  + 60a b x )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R                 6 12         5 10        2 4 8        3 3 6       4 2 4
+--R           - 120b x   - 600a b x   - 1200a b x  - 1200a b x  - 600a b x
+--R         + 
+--R                 5   2
+--R           - 120a b x
+--R      *
+--R         log(x)
+--R     + 
+--R              5 10       2 4 8       3 3 6       4 2 4       5   2      6
+--R       - 60a b x   - 270a b x  - 470a b x  - 385a b x  - 137a b x  - 10a
+--R  /
+--R        7 5 12       8 4 10       9 3 8       10 2 6       11   4      12 2
+--R     20a b x   + 100a b x   + 200a b x  + 200a  b x  + 100a  b x  + 20a  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 649
+
+--S 650 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 651
+
+)clear all
+
+--S 652 of 1370
+t0:=1/(x^5*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R         6 17       5 15      2 4 13      3 3 11      4 2 9     5   7    6 5
+--R        b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x  + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 652
+
+--S 653 of 1370
+r0:=(-21/4)/(a^6*x^4)+21/2*b/(a^7*x^2)+1/10/(a*x^4*(a+b*x^2)^5)+_
+    7/40/(a^2*x^4*(a+b*x^2)^4)+7/20/(a^3*x^4*(a+b*x^2)^3)+_
+    7/8/(a^4*x^4*(a+b*x^2)^2)+7/2/(a^5*x^4*(a+b*x^2))+_
+    21*b^2*log(x)/a^8-21/2*b^2*log(a+b*x^2)/a^8
+--R 
+--R
+--R   (2)
+--R                 7 14          6 12        2 5 10        3 4 8        4 3 6
+--R           - 420b x   - 2100a b x   - 4200a b x   - 4200a b x  - 2100a b x
+--R         + 
+--R                 5 2 4
+--R           - 420a b x
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R               7 14          6 12        2 5 10        3 4 8        4 3 6
+--R           840b x   + 4200a b x   + 8400a b x   + 8400a b x  + 4200a b x
+--R         + 
+--R               5 2 4
+--R           840a b x
+--R      *
+--R         log(x)
+--R     + 
+--R             6 12        2 5 10        3 4 8        4 3 6       5 2 4      6   2
+--R       420a b x   + 1890a b x   + 3290a b x  + 2695a b x  + 959a b x  + 70a b x
+--R     + 
+--R            7
+--R       - 10a
+--R  /
+--R        8 5 14       9 4 12       10 3 10       11 2 8       12   6      13 4
+--R     40a b x   + 200a b x   + 400a  b x   + 400a  b x  + 200a  b x  + 40a  x
+--R                                                    Type: Expression(Integer)
+--E 653
+
+--S 654 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 7 14          6 12        2 5 10        3 4 8        4 3 6
+--R           - 420b x   - 2100a b x   - 4200a b x   - 4200a b x  - 2100a b x
+--R         + 
+--R                 5 2 4
+--R           - 420a b x
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R               7 14          6 12        2 5 10        3 4 8        4 3 6
+--R           840b x   + 4200a b x   + 8400a b x   + 8400a b x  + 4200a b x
+--R         + 
+--R               5 2 4
+--R           840a b x
+--R      *
+--R         log(x)
+--R     + 
+--R             6 12        2 5 10        3 4 8        4 3 6       5 2 4      6   2
+--R       420a b x   + 1890a b x   + 3290a b x  + 2695a b x  + 959a b x  + 70a b x
+--R     + 
+--R            7
+--R       - 10a
+--R  /
+--R        8 5 14       9 4 12       10 3 10       11 2 8       12   6      13 4
+--R     40a b x   + 200a b x   + 400a  b x   + 400a  b x  + 200a  b x  + 40a  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 654
+
+--S 655 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 656
+
+)clear all
+
+--S 657 of 1370
+t0:=x^16/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        16
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 657
+
+--S 658 of 1370
+r0:=9009/256*a^2*x/b^8-3003/256*a*x^3/b^7+9009/1280*x^5/b^6-_
+    1/10*x^15/(b*(a+b*x^2)^5)-3/16*x^13/(b^2*(a+b*x^2)^4)-_
+    13/32*x^11/(b^3*(a+b*x^2)^3)-143/128*x^9/(b^4*(a+b*x^2)^2)-_
+    1287/256*x^7/(b^5*(a+b*x^2))-9009/256*a^(5/2)*atan(x*_
+    sqrt(b)/sqrt(a))/b^(17/2)
+--R 
+--R
+--R   (2)
+--R                   2 5 10          3 4 8          4 3 6          5 2 4
+--R           - 45045a b x   - 225225a b x  - 450450a b x  - 450450a b x
+--R         + 
+--R                    6   2         7
+--R           - 225225a b x  - 45045a
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|a atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R               7 15          6 13         2 5 11          3 4 9          4 3 7
+--R           256b x   - 1280a b x   + 16640a b x   + 137995a b x  + 338910a b x
+--R         + 
+--R                  5 2 5          6   3         7
+--R           384384a b x  + 210210a b x  + 45045a x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              13 10          12 8         2 11 6         3 10 4        4 9 2
+--R         1280b  x   + 6400a b  x  + 12800a b  x  + 12800a b  x  + 6400a b x
+--R       + 
+--R              5 8
+--R         1280a b
+--R    *
+--R        +-+
+--R       \|b
+--R                                                    Type: Expression(Integer)
+--E 658
+
+--S 659 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2 5 10          3 4 8          4 3 6          5 2 4
+--R             45045a b x   + 225225a b x  + 450450a b x  + 450450a b x
+--R           + 
+--R                    6   2         7
+--R             225225a b x  + 45045a
+--R        *
+--R                            +---+
+--R                            |  a       2
+--R            +---+    - 2b x |- -  + b x  - a
+--R            |  a           \|  b
+--R            |- - log(-----------------------)
+--R           \|  b                2
+--R                             b x  + a
+--R       + 
+--R             7 15          6 13         2 5 11          3 4 9          4 3 7
+--R         512b x   - 2560a b x   + 33280a b x   + 275990a b x  + 677820a b x
+--R       + 
+--R                5 2 5          6   3         7
+--R         768768a b x  + 420420a b x  + 90090a x
+--R    /
+--R              13 10           12 8         2 11 6         3 10 4         4 9 2
+--R         2560b  x   + 12800a b  x  + 25600a b  x  + 25600a b  x  + 12800a b x
+--R       + 
+--R              5 8
+--R         2560a b
+--R     ,
+--R
+--R                   2 5 10          3 4 8          4 3 6          5 2 4
+--R             45045a b x   + 225225a b x  + 450450a b x  + 450450a b x
+--R           + 
+--R                    6   2         7
+--R             225225a b x  + 45045a
+--R        *
+--R                     +-+
+--R                     |a
+--R            +-+      |-
+--R            |a      \|b
+--R            |- atan(----)
+--R           \|b        x
+--R       + 
+--R             7 15          6 13         2 5 11          3 4 9          4 3 7
+--R         256b x   - 1280a b x   + 16640a b x   + 137995a b x  + 338910a b x
+--R       + 
+--R                5 2 5          6   3         7
+--R         384384a b x  + 210210a b x  + 45045a x
+--R    /
+--R              13 10          12 8         2 11 6         3 10 4        4 9 2
+--R         1280b  x   + 6400a b  x  + 12800a b  x  + 12800a b  x  + 6400a b x
+--R       + 
+--R              5 8
+--R         1280a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 659
+
+--S 660 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                   +---+
+--R                                   |  a       2
+--R               +---+        - 2b x |- -  + b x  - a                      +-+
+--R             2 |  a  +-+          \|  b                      2 +-+     x\|b
+--R        9009a  |- - \|b log(-----------------------) + 18018a \|a atan(-----)
+--R              \|  b                    2                                 +-+
+--R                                    b x  + a                            \|a
+--R   (4)  ---------------------------------------------------------------------
+--R                                          8 +-+
+--R                                      512b \|b
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                    +-+
+--R                                                    |a
+--R                         +-+           +-+          |-
+--R             2 +-+     x\|b          2 |a  +-+     \|b
+--R        9009a \|a atan(-----) + 9009a  |- \|b atan(----)
+--R                         +-+          \|b            x
+--R                        \|a
+--R   (6)  ------------------------------------------------
+--R                                8 +-+
+--R                            256b \|b
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 663
+
+)clear all
+
+--S 664 of 1370
+t0:=x^14/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        14
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 664
+
+--S 665 of 1370
+r0:=-3003/256*a*x/b^7+1001/256*x^3/b^6-1/10*x^13/(b*(a+b*x^2)^5)-_
+    13/80*x^11/(b^2*(a+b*x^2)^4)-143/480*x^9/(b^3*(a+b*x^2)^3)-_
+    429/640*x^7/(b^4*(a+b*x^2)^2)-3003/1280*x^5/(b^5*(a+b*x^2))+_
+    3003/256*a^(3/2)*atan(x*sqrt(b)/sqrt(a))/b^(15/2)
+--R 
+--R
+--R   (2)
+--R                   5 10          2 4 8          3 3 6          4 2 4
+--R           45045a b x   + 225225a b x  + 450450a b x  + 450450a b x
+--R         + 
+--R                  5   2         6
+--R           225225a b x  + 45045a
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|a atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                6 13           5 11          2 4 9          3 3 7          4 2 5
+--R           1280b x   - 16640a b x   - 137995a b x  - 338910a b x  - 384384a b x
+--R         + 
+--R                    5   3         6
+--R           - 210210a b x  - 45045a x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              12 10           11 8         2 10 6         3 9 4         4 8 2
+--R         3840b  x   + 19200a b  x  + 38400a b  x  + 38400a b x  + 19200a b x
+--R       + 
+--R              5 7
+--R         3840a b
+--R    *
+--R        +-+
+--R       \|b
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     5 10          2 4 8          3 3 6          4 2 4
+--R             45045a b x   + 225225a b x  + 450450a b x  + 450450a b x
+--R           + 
+--R                    5   2         6
+--R             225225a b x  + 45045a
+--R        *
+--R                          +---+
+--R                          |  a       2
+--R            +---+    2b x |- -  + b x  - a
+--R            |  a         \|  b
+--R            |- - log(---------------------)
+--R           \|  b               2
+--R                            b x  + a
+--R       + 
+--R              6 13           5 11          2 4 9          3 3 7          4 2 5
+--R         2560b x   - 33280a b x   - 275990a b x  - 677820a b x  - 768768a b x
+--R       + 
+--R                  5   3         6
+--R         - 420420a b x  - 90090a x
+--R    /
+--R              12 10           11 8         2 10 6         3 9 4         4 8 2
+--R         7680b  x   + 38400a b  x  + 76800a b  x  + 76800a b x  + 38400a b x
+--R       + 
+--R              5 7
+--R         7680a b
+--R     ,
+--R
+--R                       5 10          2 4 8          3 3 6          4 2 4
+--R             - 45045a b x   - 225225a b x  - 450450a b x  - 450450a b x
+--R           + 
+--R                      5   2         6
+--R             - 225225a b x  - 45045a
+--R        *
+--R                     +-+
+--R                     |a
+--R            +-+      |-
+--R            |a      \|b
+--R            |- atan(----)
+--R           \|b        x
+--R       + 
+--R              6 13           5 11          2 4 9          3 3 7          4 2 5
+--R         1280b x   - 16640a b x   - 137995a b x  - 338910a b x  - 384384a b x
+--R       + 
+--R                  5   3         6
+--R         - 210210a b x  - 45045a x
+--R    /
+--R              12 10           11 8         2 10 6         3 9 4         4 8 2
+--R         3840b  x   + 19200a b  x  + 38400a b  x  + 38400a b x  + 19200a b x
+--R       + 
+--R              5 7
+--R         3840a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 666
+
+--S 667 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                +---+
+--R                                |  a       2
+--R              +---+        2b x |- -  + b x  - a                    +-+
+--R              |  a  +-+        \|  b                      +-+     x\|b
+--R        3003a |- - \|b log(---------------------) - 6006a\|a atan(-----)
+--R             \|  b                   2                              +-+
+--R                                  b x  + a                         \|a
+--R   (4)  ----------------------------------------------------------------
+--R                                        7 +-+
+--R                                    512b \|b
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 668
+
+--S 669 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                    +-+
+--R                                                    |a
+--R                          +-+          +-+          |-
+--R                +-+     x\|b           |a  +-+     \|b
+--R        - 3003a\|a atan(-----) - 3003a |- \|b atan(----)
+--R                          +-+         \|b            x
+--R                         \|a
+--R   (6)  ------------------------------------------------
+--R                                7 +-+
+--R                            256b \|b
+--R                                                    Type: Expression(Integer)
+--E 669
+
+--S 670 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 670
+
+)clear all
+
+--S 671 of 1370
+t0:=x^12/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        12
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 671
+
+--S 672 of 1370
+r0:=693/256*x/b^6-1/10*x^11/(b*(a+b*x^2)^5)-11/80*x^9/(b^2*(a+b*x^2)^4)-_
+    33/160*x^7/(b^3*(a+b*x^2)^3)-231/640*x^5/(b^4*(a+b*x^2)^2)-_
+    231/256*x^3/(b^5*(a+b*x^2))-693/256*atan(x*sqrt(b)/sqrt(a))*_
+    sqrt(a)/b^(13/2)
+--R 
+--R
+--R   (2)
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 3465b x   - 17325a b x  - 34650a b x  - 34650a b x  - 17325a b x
+--R         + 
+--R                  5
+--R           - 3465a
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|a atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                5 11           4 9         2 3 7         3 2 5         4   3
+--R           1280b x   + 10615a b x  + 26070a b x  + 29568a b x  + 16170a b x
+--R         + 
+--R                5
+--R           3465a x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              11 10          10 8         2 9 6         3 8 4        4 7 2
+--R         1280b  x   + 6400a b  x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              5 6
+--R         1280a b
+--R    *
+--R        +-+
+--R       \|b
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R             3465b x   + 17325a b x  + 34650a b x  + 34650a b x  + 17325a b x
+--R           + 
+--R                  5
+--R             3465a
+--R        *
+--R                            +---+
+--R                            |  a       2
+--R            +---+    - 2b x |- -  + b x  - a
+--R            |  a           \|  b
+--R            |- - log(-----------------------)
+--R           \|  b                2
+--R                             b x  + a
+--R       + 
+--R              5 11           4 9         2 3 7         3 2 5         4   3
+--R         2560b x   + 21230a b x  + 52140a b x  + 59136a b x  + 32340a b x
+--R       + 
+--R              5
+--R         6930a x
+--R    /
+--R              11 10           10 8         2 9 6         3 8 4         4 7 2
+--R         2560b  x   + 12800a b  x  + 25600a b x  + 25600a b x  + 12800a b x
+--R       + 
+--R              5 6
+--R         2560a b
+--R     ,
+--R
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R             3465b x   + 17325a b x  + 34650a b x  + 34650a b x  + 17325a b x
+--R           + 
+--R                  5
+--R             3465a
+--R        *
+--R                     +-+
+--R                     |a
+--R            +-+      |-
+--R            |a      \|b
+--R            |- atan(----)
+--R           \|b        x
+--R       + 
+--R              5 11           4 9         2 3 7         3 2 5         4   3
+--R         1280b x   + 10615a b x  + 26070a b x  + 29568a b x  + 16170a b x
+--R       + 
+--R              5
+--R         3465a x
+--R    /
+--R              11 10          10 8         2 9 6         3 8 4        4 7 2
+--R         1280b  x   + 6400a b  x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              5 6
+--R         1280a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 673
+
+--S 674 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                 +---+
+--R                                 |  a       2
+--R             +---+        - 2b x |- -  + b x  - a                  +-+
+--R             |  a  +-+          \|  b                    +-+     x\|b
+--R        693  |- - \|b log(----------------------- + 1386\|a atan(-----)
+--R            \|  b                    2                             +-+
+--R                                  b x  + a                        \|a
+--R   (4)  ---------------------------------------------------------------
+--R                                       6 +-+
+--R                                   512b \|b
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                               +-+
+--R                                               |a
+--R                      +-+         +-+          |-
+--R            +-+     x\|b          |a  +-+     \|b
+--R        693\|a atan(-----) + 693  |- \|b atan(----)
+--R                      +-+        \|b            x
+--R                     \|a
+--R   (6)  ------------------------------------------
+--R                             6 +-+
+--R                         256b \|b
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 677
+
+)clear all
+
+--S 678 of 1370
+t0:=x^10/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        10
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 678
+
+--S 679 of 1370
+r0:=-1/10*x^9/(b*(a+b*x^2)^5)-9/80*x^7/(b^2*(a+b*x^2)^4)-_
+    21/160*x^5/(b^3*(a+b*x^2)^3)-21/128*x^3/(b^4*(a+b*x^2)^2)-_
+    63/256*x/(b^5*(a+b*x^2))+63/256*atan(x*sqrt(b)/sqrt(a))/(b^(11/2)*sqrt(a))
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x  + 315a )
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R              4 9          3 7        2 2 5        3   3       4   +-+ +-+
+--R       (- 965b x  - 2370a b x  - 2688a b x  - 1470a b x  - 315a x)\|a \|b
+--R  /
+--R              10 10          9 8         2 8 6         3 7 4        4 6 2
+--R         1280b  x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              5 5
+--R         1280a b
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 679
+
+--S 680 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R               315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x
+--R             + 
+--R                   5
+--R               315a
+--R        *
+--R                   2      +-----+
+--R               (b x  - a)\|- a b  + 2a b x
+--R           log(---------------------------)
+--R                            2
+--R                         b x  + a
+--R       + 
+--R                 4 9          3 7        2 2 5        3   3       4   +-----+
+--R         (- 1930b x  - 4740a b x  - 5376a b x  - 2940a b x  - 630a x)\|- a b
+--R    /
+--R                10 10           9 8         2 8 6         3 7 4         4 6 2
+--R           2560b  x   + 12800a b x  + 25600a b x  + 25600a b x  + 12800a b x
+--R         + 
+--R                5 5
+--R           2560a b
+--R      *
+--R          +-----+
+--R         \|- a b
+--R     ,
+--R
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R               315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x
+--R             + 
+--R                   5
+--R               315a
+--R        *
+--R                  +---+
+--R                x\|a b
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                4 9          3 7        2 2 5        3   3       4   +---+
+--R         (- 965b x  - 2370a b x  - 2688a b x  - 1470a b x  - 315a x)\|a b
+--R    /
+--R                10 10          9 8         2 8 6         3 7 4        4 6 2
+--R           1280b  x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R         + 
+--R                5 5
+--R           1280a b
+--R      *
+--R          +---+
+--R         \|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 680
+
+--S 681 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                          2      +-----+                               +-+
+--R           +-+ +-+    (b x  - a)\|- a b  + 2a b x        +-----+     x\|b
+--R        63\|a \|b log(---------------------------) - 126\|- a b atan(-----)
+--R                                   2                                   +-+
+--R                                b x  + a                              \|a
+--R   (4)  -------------------------------------------------------------------
+--R                                   5 +-----+ +-+ +-+
+--R                               512b \|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                         +---+                   +-+
+--R           +-+ +-+     x\|a b        +---+     x\|b
+--R        63\|a \|b atan(-------) - 63\|a b atan(-----)
+--R                          a                      +-+
+--R                                                \|a
+--R   (6)  ---------------------------------------------
+--R                         5 +-+ +-+ +---+
+--R                     256b \|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 683
+
+--S 684 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 684
+
+)clear all
+
+--S 685 of 1370
+t0:=x^8/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        8
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 685
+
+--S 686 of 1370
+r0:=-1/10*x^7/(b*(a+b*x^2)^5)-7/80*x^5/(b^2*(a+b*x^2)^4)-_
+    7/96*x^3/(b^3*(a+b*x^2)^3)-7/128*x/(b^4*(a+b*x^2)^2)+_
+    7/256*x/(a*b^4*(a+b*x^2))+7/256*atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*b^(9/2))
+--R 
+--R
+--R   (2)
+--R              5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (105b x   + 525a b x  + 1050a b x  + 1050a b x  + 525a b x  + 105a )
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R            4 9         3 7       2 2 5       3   3       4   +-+ +-+
+--R       (105b x  - 790a b x  - 896a b x  - 490a b x  - 105a x)\|a \|b
+--R  /
+--R                9 10         2 8 8         3 7 6         4 6 4         5 5 2
+--R         3840a b x   + 19200a b x  + 38400a b x  + 38400a b x  + 19200a b x
+--R       + 
+--R              6 4
+--R         3840a b
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                5 10         4 8        2 3 6        3 2 4       4   2       5
+--R           (105b x   + 525a b x  + 1050a b x  + 1050a b x  + 525a b x  + 105a )
+--R        *
+--R                   2      +-----+
+--R               (b x  - a)\|- a b  + 2a b x
+--R           log(---------------------------)
+--R                            2
+--R                         b x  + a
+--R       + 
+--R              4 9          3 7        2 2 5       3   3       4   +-----+
+--R         (210b x  - 1580a b x  - 1792a b x  - 980a b x  - 210a x)\|- a b
+--R    /
+--R                  9 10         2 8 8         3 7 6         4 6 4         5 5 2
+--R           7680a b x   + 38400a b x  + 76800a b x  + 76800a b x  + 38400a b x
+--R         + 
+--R                6 4
+--R           7680a b
+--R      *
+--R          +-----+
+--R         \|- a b
+--R     ,
+--R
+--R                5 10         4 8        2 3 6        3 2 4       4   2       5
+--R           (105b x   + 525a b x  + 1050a b x  + 1050a b x  + 525a b x  + 105a )
+--R        *
+--R                  +---+
+--R                x\|a b
+--R           atan(-------)
+--R                   a
+--R       + 
+--R              4 9         3 7       2 2 5       3   3       4   +---+
+--R         (105b x  - 790a b x  - 896a b x  - 490a b x  - 105a x)\|a b
+--R    /
+--R                  9 10         2 8 8         3 7 6         4 6 4         5 5 2
+--R           3840a b x   + 19200a b x  + 38400a b x  + 38400a b x  + 19200a b x
+--R         + 
+--R                6 4
+--R           3840a b
+--R      *
+--R          +---+
+--R         \|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 687
+
+--S 688 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                         2      +-----+                              +-+
+--R          +-+ +-+    (b x  - a)\|- a b  + 2a b x       +-----+     x\|b
+--R        7\|a \|b log(---------------------------) - 14\|- a b atan(-----)
+--R                                  2                                  +-+
+--R                               b x  + a                             \|a
+--R   (4)  -----------------------------------------------------------------
+--R                                   4 +-----+ +-+ +-+
+--R                             512a b \|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 688
+
+--S 689 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+                  +-+
+--R          +-+ +-+     x\|a b       +---+     x\|b
+--R        7\|a \|b atan(-------) - 7\|a b atan(-----)
+--R                         a                     +-+
+--R                                              \|a
+--R   (6)  -------------------------------------------
+--R                         4 +-+ +-+ +---+
+--R                   256a b \|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 690
+
+--S 691 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 691
+
+)clear all
+
+--S 692 of 1370
+t0:=x^6/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        6
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 692
+
+--S 693 of 1370
+r0:=-1/10*x^5/(b*(a+b*x^2)^5)-1/16*x^3/(b^2*(a+b*x^2)^4)-_
+    1/32*x/(b^3*(a+b*x^2)^3)+1/128*x/(a*b^3*(a+b*x^2)^2)+_
+    3/256*x/(a^2*b^3*(a+b*x^2))+3/256*atan(x*sqrt(b)/sqrt(a))/(a^(5/2)*b^(7/2))
+--R 
+--R
+--R   (2)
+--R                                                                            +-+
+--R           5 10        4 8       2 3 6       3 2 4      4   2      5      x\|b
+--R       (15b x   + 75a b x  + 150a b x  + 150a b x  + 75a b x  + 15a )atan(-----)
+--R                                                                            +-+
+--R                                                                           \|a
+--R     + 
+--R           4 9        3 7       2 2 5      3   3      4   +-+ +-+
+--R       (15b x  + 70a b x  - 128a b x  - 70a b x  - 15a x)\|a \|b
+--R  /
+--R              2 8 10        3 7 8         4 6 6         5 5 4        6 4 2
+--R         1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              7 3
+--R         1280a b
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 693
+
+--S 694 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               5 10        4 8       2 3 6       3 2 4      4   2      5
+--R           (15b x   + 75a b x  + 150a b x  + 150a b x  + 75a b x  + 15a )
+--R        *
+--R                   2      +-----+
+--R               (b x  - a)\|- a b  + 2a b x
+--R           log(---------------------------)
+--R                            2
+--R                         b x  + a
+--R       + 
+--R             4 9         3 7       2 2 5       3   3      4   +-----+
+--R         (30b x  + 140a b x  - 256a b x  - 140a b x  - 30a x)\|- a b
+--R    /
+--R                2 8 10         3 7 8         4 6 6         5 5 4         6 4 2
+--R           2560a b x   + 12800a b x  + 25600a b x  + 25600a b x  + 12800a b x
+--R         + 
+--R                7 3
+--R           2560a b
+--R      *
+--R          +-----+
+--R         \|- a b
+--R     ,
+--R
+--R               5 10        4 8       2 3 6       3 2 4      4   2      5
+--R           (15b x   + 75a b x  + 150a b x  + 150a b x  + 75a b x  + 15a )
+--R        *
+--R                  +---+
+--R                x\|a b
+--R           atan(-------)
+--R                   a
+--R       + 
+--R             4 9        3 7       2 2 5      3   3      4   +---+
+--R         (15b x  + 70a b x  - 128a b x  - 70a b x  - 15a x)\|a b
+--R    /
+--R                2 8 10        3 7 8         4 6 6         5 5 4        6 4 2
+--R           1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R         + 
+--R                7 3
+--R           1280a b
+--R      *
+--R          +---+
+--R         \|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 694
+
+--S 695 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                         2      +-----+                             +-+
+--R          +-+ +-+    (b x  - a)\|- a b  + 2a b x      +-----+     x\|b
+--R        3\|a \|b log(---------------------------) - 6\|- a b atan(-----)
+--R                                  2                                 +-+
+--R                               b x  + a                            \|a
+--R   (4)  ----------------------------------------------------------------
+--R                                 2 3 +-----+ +-+ +-+
+--R                             512a b \|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+                  +-+
+--R          +-+ +-+     x\|a b       +---+     x\|b
+--R        3\|a \|b atan(-------) - 3\|a b atan(-----)
+--R                         a                     +-+
+--R                                              \|a
+--R   (6)  -------------------------------------------
+--R                       2 3 +-+ +-+ +---+
+--R                   256a b \|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 698
+
+)clear all
+
+--S 699 of 1370
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        4
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 699
+
+--S 700 of 1370
+r0:=-1/10*x^3/(b*(a+b*x^2)^5)-3/80*x/(b^2*(a+b*x^2)^4)+_
+    1/160*x/(a*b^2*(a+b*x^2)^3)+1/128*x/(a^2*b^2*(a+b*x^2)^2)+_
+    3/256*x/(a^3*b^2*(a+b*x^2))+3/256*atan(x*sqrt(b)/sqrt(a))/(a^(7/2)*b^(5/2))
+--R 
+--R
+--R   (2)
+--R                                                                            +-+
+--R           5 10        4 8       2 3 6       3 2 4      4   2      5      x\|b
+--R       (15b x   + 75a b x  + 150a b x  + 150a b x  + 75a b x  + 15a )atan(-----)
+--R                                                                            +-+
+--R                                                                           \|a
+--R     + 
+--R           4 9        3 7       2 2 5      3   3      4   +-+ +-+
+--R       (15b x  + 70a b x  + 128a b x  - 70a b x  - 15a x)\|a \|b
+--R  /
+--R              3 7 10        4 6 8         5 5 6         6 4 4        7 3 2
+--R         1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              8 2
+--R         1280a b
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 700
+
+--S 701 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               5 10        4 8       2 3 6       3 2 4      4   2      5
+--R           (15b x   + 75a b x  + 150a b x  + 150a b x  + 75a b x  + 15a )
+--R        *
+--R                   2      +-----+
+--R               (b x  - a)\|- a b  + 2a b x
+--R           log(---------------------------)
+--R                            2
+--R                         b x  + a
+--R       + 
+--R             4 9         3 7       2 2 5       3   3      4   +-----+
+--R         (30b x  + 140a b x  + 256a b x  - 140a b x  - 30a x)\|- a b
+--R    /
+--R                3 7 10         4 6 8         5 5 6         6 4 4         7 3 2
+--R           2560a b x   + 12800a b x  + 25600a b x  + 25600a b x  + 12800a b x
+--R         + 
+--R                8 2
+--R           2560a b
+--R      *
+--R          +-----+
+--R         \|- a b
+--R     ,
+--R
+--R               5 10        4 8       2 3 6       3 2 4      4   2      5
+--R           (15b x   + 75a b x  + 150a b x  + 150a b x  + 75a b x  + 15a )
+--R        *
+--R                  +---+
+--R                x\|a b
+--R           atan(-------)
+--R                   a
+--R       + 
+--R             4 9        3 7       2 2 5      3   3      4   +---+
+--R         (15b x  + 70a b x  + 128a b x  - 70a b x  - 15a x)\|a b
+--R    /
+--R                3 7 10        4 6 8         5 5 6         6 4 4        7 3 2
+--R           1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R         + 
+--R                8 2
+--R           1280a b
+--R      *
+--R          +---+
+--R         \|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 701
+
+--S 702 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                         2      +-----+                             +-+
+--R          +-+ +-+    (b x  - a)\|- a b  + 2a b x      +-----+     x\|b
+--R        3\|a \|b log(---------------------------) - 6\|- a b atan(-----)
+--R                                  2                                 +-+
+--R                               b x  + a                            \|a
+--R   (4)  ----------------------------------------------------------------
+--R                                 3 2 +-----+ +-+ +-+
+--R                             512a b \|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 703
+
+--S 704 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+                  +-+
+--R          +-+ +-+     x\|a b       +---+     x\|b
+--R        3\|a \|b atan(-------) - 3\|a b atan(-----)
+--R                         a                     +-+
+--R                                              \|a
+--R   (6)  -------------------------------------------
+--R                       3 2 +-+ +-+ +---+
+--R                   256a b \|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 705
+
+)clear all
+
+--S 706 of 1370
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        2
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 706
+
+--S 707 of 1370
+r0:=-1/10*x/(b*(a+b*x^2)^5)+1/80*x/(a*b*(a+b*x^2)^4)+_
+    7/480*x/(a^2*b*(a+b*x^2)^3)+7/384*x/(a^3*b*(a+b*x^2)^2)+_
+    7/256*x/(a^4*b*(a+b*x^2))+7/256*atan(x*sqrt(b)/sqrt(a))/(a^(9/2)*b^(3/2))
+--R 
+--R
+--R   (2)
+--R              5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (105b x   + 525a b x  + 1050a b x  + 1050a b x  + 525a b x  + 105a )
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R            4 9         3 7       2 2 5       3   3       4   +-+ +-+
+--R       (105b x  + 490a b x  + 896a b x  + 790a b x  - 105a x)\|a \|b
+--R  /
+--R              4 6 10         5 5 8         6 4 6         7 3 4         8 2 2
+--R         3840a b x   + 19200a b x  + 38400a b x  + 38400a b x  + 19200a b x
+--R       + 
+--R              9
+--R         3840a b
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                5 10         4 8        2 3 6        3 2 4       4   2       5
+--R           (105b x   + 525a b x  + 1050a b x  + 1050a b x  + 525a b x  + 105a )
+--R        *
+--R                   2      +-----+
+--R               (b x  - a)\|- a b  + 2a b x
+--R           log(---------------------------)
+--R                            2
+--R                         b x  + a
+--R       + 
+--R              4 9         3 7        2 2 5        3   3       4   +-----+
+--R         (210b x  + 980a b x  + 1792a b x  + 1580a b x  - 210a x)\|- a b
+--R    /
+--R                4 6 10         5 5 8         6 4 6         7 3 4         8 2 2
+--R           7680a b x   + 38400a b x  + 76800a b x  + 76800a b x  + 38400a b x
+--R         + 
+--R                9
+--R           7680a b
+--R      *
+--R          +-----+
+--R         \|- a b
+--R     ,
+--R
+--R                5 10         4 8        2 3 6        3 2 4       4   2       5
+--R           (105b x   + 525a b x  + 1050a b x  + 1050a b x  + 525a b x  + 105a )
+--R        *
+--R                  +---+
+--R                x\|a b
+--R           atan(-------)
+--R                   a
+--R       + 
+--R              4 9         3 7       2 2 5       3   3       4   +---+
+--R         (105b x  + 490a b x  + 896a b x  + 790a b x  - 105a x)\|a b
+--R    /
+--R                4 6 10         5 5 8         6 4 6         7 3 4         8 2 2
+--R           3840a b x   + 19200a b x  + 38400a b x  + 38400a b x  + 19200a b x
+--R         + 
+--R                9
+--R           3840a b
+--R      *
+--R          +---+
+--R         \|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 708
+
+--S 709 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                         2      +-----+                              +-+
+--R          +-+ +-+    (b x  - a)\|- a b  + 2a b x       +-----+     x\|b
+--R        7\|a \|b log(---------------------------) - 14\|- a b atan(-----)
+--R                                  2                                  +-+
+--R                               b x  + a                             \|a
+--R   (4)  -----------------------------------------------------------------
+--R                                  4  +-----+ +-+ +-+
+--R                              512a b\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+                  +-+
+--R          +-+ +-+     x\|a b       +---+     x\|b
+--R        7\|a \|b atan(-------) - 7\|a b atan(-----)
+--R                         a                     +-+
+--R                                              \|a
+--R   (6)  -------------------------------------------
+--R                        4  +-+ +-+ +---+
+--R                    256a b\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 712
+
+)clear all
+
+--S 713 of 1370
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        1
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 713
+
+--S 714 of 1370
+r0:=1/10*x/(a*(a+b*x^2)^5)+9/80*x/(a^2*(a+b*x^2)^4)+_
+    21/160*x/(a^3*(a+b*x^2)^3)+21/128*x/(a^4*(a+b*x^2)^2)+_
+    63/256*x/(a^5*(a+b*x^2))+63/256*atan(x*sqrt(b)/sqrt(a))/(a^(11/2)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x  + 315a )
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R            4 9          3 7        2 2 5        3   3       4   +-+ +-+
+--R       (315b x  + 1470a b x  + 2688a b x  + 2370a b x  + 965a x)\|a \|b
+--R  /
+--R              5 5 10        6 4 8         7 3 6         8 2 4        9   2
+--R         1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              10
+--R         1280a
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 714
+
+--S 715 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R               315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x
+--R             + 
+--R                   5
+--R               315a
+--R        *
+--R                   2      +-----+
+--R               (b x  - a)\|- a b  + 2a b x
+--R           log(---------------------------)
+--R                            2
+--R                         b x  + a
+--R       + 
+--R              4 9          3 7        2 2 5        3   3        4   +-----+
+--R         (630b x  + 2940a b x  + 5376a b x  + 4740a b x  + 1930a x)\|- a b
+--R    /
+--R                5 5 10         6 4 8         7 3 6         8 2 4         9   2
+--R           2560a b x   + 12800a b x  + 25600a b x  + 25600a b x  + 12800a b x
+--R         + 
+--R                10
+--R           2560a
+--R      *
+--R          +-----+
+--R         \|- a b
+--R     ,
+--R
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R               315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x
+--R             + 
+--R                   5
+--R               315a
+--R        *
+--R                  +---+
+--R                x\|a b
+--R           atan(-------)
+--R                   a
+--R       + 
+--R              4 9          3 7        2 2 5        3   3       4   +---+
+--R         (315b x  + 1470a b x  + 2688a b x  + 2370a b x  + 965a x)\|a b
+--R    /
+--R                5 5 10        6 4 8         7 3 6         8 2 4        9   2
+--R           1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R         + 
+--R                10
+--R           1280a
+--R      *
+--R          +---+
+--R         \|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 715
+
+--S 716 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                          2      +-----+                               +-+
+--R           +-+ +-+    (b x  - a)\|- a b  + 2a b x        +-----+     x\|b
+--R        63\|a \|b log(---------------------------) - 126\|- a b atan(-----)
+--R                                   2                                   +-+
+--R                                b x  + a                              \|a
+--R   (4)  -------------------------------------------------------------------
+--R                                   5 +-----+ +-+ +-+
+--R                               512a \|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 717
+
+--S 718 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                         +---+                   +-+
+--R           +-+ +-+     x\|a b        +---+     x\|b
+--R        63\|a \|b atan(-------) - 63\|a b atan(-----)
+--R                          a                      +-+
+--R                                                \|a
+--R   (6)  ---------------------------------------------
+--R                         5 +-+ +-+ +---+
+--R                     256a \|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 719
+
+)clear all
+
+--S 720 of 1370
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R         6 14       5 12      2 4 10      3 3 8      4 2 6     5   4    6 2
+--R        b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 720
+
+--S 721 of 1370
+r0:=(-693/256)/(a^6*x)+1/10/(a*x*(a+b*x^2)^5)+11/80/(a^2*x*(a+b*x^2)^4)+_
+    33/160/(a^3*x*(a+b*x^2)^3)+231/640/(a^4*x*(a+b*x^2)^2)+_
+    231/256/(a^5*x*(a+b*x^2))-693/256*atan(x*sqrt(b)/sqrt(a))*sqrt(b)/a^(13/2)
+--R 
+--R
+--R   (2)
+--R                  5 11           4 9         2 3 7         3 2 5         4   3
+--R           - 3465b x   - 17325a b x  - 34650a b x  - 34650a b x  - 17325a b x
+--R         + 
+--R                  5
+--R           - 3465a x
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 3465b x   - 16170a b x  - 29568a b x  - 26070a b x  - 10615a b x
+--R         + 
+--R                  5
+--R           - 1280a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R              6 5 11        7 4 9         8 3 7         9 2 5        10   3
+--R         1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a  b x
+--R       + 
+--R              11
+--R         1280a  x
+--R    *
+--R        +-+
+--R       \|a
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  5 11           4 9         2 3 7         3 2 5         4   3
+--R             3465b x   + 17325a b x  + 34650a b x  + 34650a b x  + 17325a b x
+--R           + 
+--R                  5
+--R             3465a x
+--R        *
+--R                            +---+
+--R                            |  b       2
+--R            +---+    - 2a x |- -  + b x  - a
+--R            |  b           \|  a
+--R            |- - log(-----------------------)
+--R           \|  a                2
+--R                             b x  + a
+--R       + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R         - 6930b x   - 32340a b x  - 59136a b x  - 52140a b x  - 21230a b x
+--R       + 
+--R                5
+--R         - 2560a
+--R    /
+--R              6 5 11         7 4 9         8 3 7         9 2 5         10   3
+--R         2560a b x   + 12800a b x  + 25600a b x  + 25600a b x  + 12800a  b x
+--R       + 
+--R              11
+--R         2560a  x
+--R     ,
+--R
+--R                  5 11           4 9         2 3 7         3 2 5         4   3
+--R             3465b x   + 17325a b x  + 34650a b x  + 34650a b x  + 17325a b x
+--R           + 
+--R                  5
+--R             3465a x
+--R        *
+--R                      +-+
+--R                      |b
+--R            +-+     a |-
+--R            |b       \|a
+--R            |- atan(-----)
+--R           \|a       b x
+--R       + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R         - 3465b x   - 16170a b x  - 29568a b x  - 26070a b x  - 10615a b x
+--R       + 
+--R                5
+--R         - 1280a
+--R    /
+--R              6 5 11        7 4 9         8 3 7         9 2 5        10   3
+--R         1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a  b x
+--R       + 
+--R              11
+--R         1280a  x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 722
+
+--S 723 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                 +---+
+--R                                 |  b       2
+--R             +---+        - 2a x |- -  + b x  - a                  +-+
+--R             |  b  +-+          \|  a                    +-+     x\|b
+--R        693  |- - \|a log(----------------------- + 1386\|b atan(-----)
+--R            \|  a                    2                             +-+
+--R                                  b x  + a                        \|a
+--R   (4)  ---------------------------------------------------------------
+--R                                       6 +-+
+--R                                   512a \|a
+--R                                                    Type: Expression(Integer)
+--E 723
+
+--S 724 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 724
+
+--S 725 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                               +-+
+--R                                               |b
+--R                      +-+            +-+     a |-
+--R            +-+     x\|b         +-+ |b       \|a
+--R        693\|b atan(-----) + 693\|a  |- atan(-----)
+--R                      +-+           \|a       b x
+--R                     \|a
+--R   (6)  -------------------------------------------
+--R                             6 +-+
+--R                         256a \|a
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 726
+
+)clear all
+
+--S 727 of 1370
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R         6 16       5 14      2 4 12      3 3 10      4 2 8     5   6    6 4
+--R        b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x  + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 727
+
+--S 728 of 1370
+r0:=(-1001/256)/(a^6*x^3)+3003/256*b/(a^7*x)+1/10/(a*x^3*(a+b*x^2)^5)+_
+    13/80/(a^2*x^3*(a+b*x^2)^4)+143/480/(a^3*x^3*(a+b*x^2)^3)+_
+    429/640/(a^4*x^3*(a+b*x^2)^2)+3003/1280/(a^5*x^3*(a+b*x^2))+_
+    3003/256*b^(3/2)*atan(x*sqrt(b)/sqrt(a))/a^(15/2)
+--R 
+--R
+--R   (2)
+--R                 6 13            5 11          2 4 9          3 3 7
+--R           45045b x   + 225225a b x   + 450450a b x  + 450450a b x
+--R         + 
+--R                  4 2 5         5   3
+--R           225225a b x  + 45045a b x
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                 6 12            5 10          2 4 8          3 3 6
+--R           45045b x   + 210210a b x   + 384384a b x  + 338910a b x
+--R         + 
+--R                  4 2 4         5   2        6
+--R           137995a b x  + 16640a b x  - 1280a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R              7 5 13         8 4 11         9 3 9         10 2 7         11   5
+--R         3840a b x   + 19200a b x   + 38400a b x  + 38400a  b x  + 19200a  b x
+--R       + 
+--R              12 3
+--R         3840a  x
+--R    *
+--R        +-+
+--R       \|a
+--R                                                    Type: Expression(Integer)
+--E 728
+
+--S 729 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   6 13            5 11          2 4 9          3 3 7
+--R             45045b x   + 225225a b x   + 450450a b x  + 450450a b x
+--R           + 
+--R                    4 2 5         5   3
+--R             225225a b x  + 45045a b x
+--R        *
+--R                          +---+
+--R                          |  b       2
+--R            +---+    2a x |- -  + b x  - a
+--R            |  b         \|  a
+--R            |- - log(---------------------)
+--R           \|  a               2
+--R                            b x  + a
+--R       + 
+--R               6 12            5 10          2 4 8          3 3 6          4 2 4
+--R         90090b x   + 420420a b x   + 768768a b x  + 677820a b x  + 275990a b x
+--R       + 
+--R               5   2        6
+--R         33280a b x  - 2560a
+--R    /
+--R              7 5 13         8 4 11         9 3 9         10 2 7         11   5
+--R         7680a b x   + 38400a b x   + 76800a b x  + 76800a  b x  + 38400a  b x
+--R       + 
+--R              12 3
+--R         7680a  x
+--R     ,
+--R
+--R                     6 13            5 11          2 4 9          3 3 7
+--R             - 45045b x   - 225225a b x   - 450450a b x  - 450450a b x
+--R           + 
+--R                      4 2 5         5   3
+--R             - 225225a b x  - 45045a b x
+--R        *
+--R                      +-+
+--R                      |b
+--R            +-+     a |-
+--R            |b       \|a
+--R            |- atan(-----)
+--R           \|a       b x
+--R       + 
+--R               6 12            5 10          2 4 8          3 3 6          4 2 4
+--R         45045b x   + 210210a b x   + 384384a b x  + 338910a b x  + 137995a b x
+--R       + 
+--R               5   2        6
+--R         16640a b x  - 1280a
+--R    /
+--R              7 5 13         8 4 11         9 3 9         10 2 7         11   5
+--R         3840a b x   + 19200a b x   + 38400a b x  + 38400a  b x  + 19200a  b x
+--R       + 
+--R              12 3
+--R         3840a  x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 729
+
+--S 730 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                +---+
+--R                                |  b       2
+--R              +---+        2a x |- -  + b x  - a                    +-+
+--R              |  b  +-+        \|  a                      +-+     x\|b
+--R        3003b |- - \|a log(---------------------) - 6006b\|b atan(-----)
+--R             \|  a                   2                              +-+
+--R                                  b x  + a                         \|a
+--R   (4)  ----------------------------------------------------------------
+--R                                        7 +-+
+--R                                    512a \|a
+--R                                                    Type: Expression(Integer)
+--E 730
+
+--S 731 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                     +-+
+--R                                                     |b
+--R                          +-+              +-+     a |-
+--R                +-+     x\|b           +-+ |b       \|a
+--R        - 3003b\|b atan(-----) - 3003b\|a  |- atan(-----)
+--R                          +-+             \|a       b x
+--R                         \|a
+--R   (6)  -------------------------------------------------
+--R                                7 +-+
+--R                            256a \|a
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 733
+
+)clear all
+
+--S 734 of 1370
+t0:=1/(x^6*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                          1
+--R   (1)  ---------------------------------------------------------------------
+--R         6 18       5 16      2 4 14      3 3 12      4 2 10     5   8    6 6
+--R        b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x   + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 734
+
+--S 735 of 1370
+r0:=(-9009/1280)/(a^6*x^5)+3003/256*b/(a^7*x^3)-9009/256*b^2/(a^8*x)+_
+    1/10/(a*x^5*(a+b*x^2)^5)+3/16/(a^2*x^5*(a+b*x^2)^4)+_
+    13/32/(a^3*x^5*(a+b*x^2)^3)+143/128/(a^4*x^5*(a+b*x^2)^2)+_
+    1287/256/(a^5*x^5*(a+b*x^2))-9009/256*b^(5/2)*atan(x*_
+    sqrt(b)/sqrt(a))/a^(17/2)
+--R 
+--R
+--R   (2)
+--R                   7 15            6 13          2 5 11          3 4 9
+--R           - 45045b x   - 225225a b x   - 450450a b x   - 450450a b x
+--R         + 
+--R                    4 3 7         5 2 5
+--R           - 225225a b x  - 45045a b x
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                   7 14            6 12          2 5 10          3 4 8
+--R           - 45045b x   - 210210a b x   - 384384a b x   - 338910a b x
+--R         + 
+--R                    4 3 6         5 2 4        6   2       7
+--R           - 137995a b x  - 16640a b x  + 1280a b x  - 256a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R              8 5 15        9 4 13         10 3 11         11 2 9        12   7
+--R         1280a b x   + 6400a b x   + 12800a  b x   + 12800a  b x  + 6400a  b x
+--R       + 
+--R              13 5
+--R         1280a  x
+--R    *
+--R        +-+
+--R       \|a
+--R                                                    Type: Expression(Integer)
+--E 735
+
+--S 736 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   7 15            6 13          2 5 11          3 4 9
+--R             45045b x   + 225225a b x   + 450450a b x   + 450450a b x
+--R           + 
+--R                    4 3 7         5 2 5
+--R             225225a b x  + 45045a b x
+--R        *
+--R                            +---+
+--R                            |  b       2
+--R            +---+    - 2a x |- -  + b x  - a
+--R            |  b           \|  a
+--R            |- - log(-----------------------)
+--R           \|  a                2
+--R                             b x  + a
+--R       + 
+--R                 7 14            6 12          2 5 10          3 4 8
+--R         - 90090b x   - 420420a b x   - 768768a b x   - 677820a b x
+--R       + 
+--R                  4 3 6         5 2 4        6   2       7
+--R         - 275990a b x  - 33280a b x  + 2560a b x  - 512a
+--R    /
+--R              8 5 15         9 4 13         10 3 11         11 2 9
+--R         2560a b x   + 12800a b x   + 25600a  b x   + 25600a  b x
+--R       + 
+--R               12   7        13 5
+--R         12800a  b x  + 2560a  x
+--R     ,
+--R
+--R                   7 15            6 13          2 5 11          3 4 9
+--R             45045b x   + 225225a b x   + 450450a b x   + 450450a b x
+--R           + 
+--R                    4 3 7         5 2 5
+--R             225225a b x  + 45045a b x
+--R        *
+--R                      +-+
+--R                      |b
+--R            +-+     a |-
+--R            |b       \|a
+--R            |- atan(-----)
+--R           \|a       b x
+--R       + 
+--R                 7 14            6 12          2 5 10          3 4 8
+--R         - 45045b x   - 210210a b x   - 384384a b x   - 338910a b x
+--R       + 
+--R                  4 3 6         5 2 4        6   2       7
+--R         - 137995a b x  - 16640a b x  + 1280a b x  - 256a
+--R    /
+--R              8 5 15        9 4 13         10 3 11         11 2 9        12   7
+--R         1280a b x   + 6400a b x   + 12800a  b x   + 12800a  b x  + 6400a  b x
+--R       + 
+--R              13 5
+--R         1280a  x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 736
+
+--S 737 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R                                   +---+
+--R                                   |  b       2
+--R               +---+        - 2a x |- -  + b x  - a                      +-+
+--R             2 |  b  +-+          \|  a                      2 +-+     x\|b
+--R        9009b  |- - \|a log(-----------------------) + 18018b \|b atan(-----)
+--R              \|  a                    2                                 +-+
+--R                                    b x  + a                            \|a
+--R   (4)  ---------------------------------------------------------------------
+--R                                          8 +-+
+--R                                      512a \|a
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 738
+
+--S 739 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                     +-+
+--R                                                     |b
+--R                         +-+               +-+     a |-
+--R             2 +-+     x\|b          2 +-+ |b       \|a
+--R        9009b \|b atan(-----) + 9009b \|a  |- atan(-----)
+--R                         +-+              \|a       b x
+--R                        \|a
+--R   (6)  -------------------------------------------------
+--R                                8 +-+
+--R                            256a \|a
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 740
+
+)clear all
+
+--S 741 of 1370
+t0:=1/(1+2*x^2+x^4)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 741
+
+--S 742 of 1370
+r0:=1/2*x/(1+x^2)+1/2*atan(x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atan(x) + x
+--R   (2)  -------------------
+--R                2
+--R              2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atan(x) + x
+--R   (3)  -------------------
+--R                2
+--R              2x  + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 743
+
+--S 744 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 745
+
+)clear all
+
+--S 746 of 1370
+t0:=x/(1+2*x^2+x^4)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 746
+
+--S 747 of 1370
+r0:=(-1/2)/(1+x^2)
+--R 
+--R
+--R             1
+--R             -
+--R             2
+--R   (2)  - ------
+--R           2
+--R          x  + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 747
+
+--S 748 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            2
+--R          2x  + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 748
+
+--S 749 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 750
+
+)clear all
+
+--S 751 of 1370
+t0:=x^2/(1+2*x^2+x^4)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 751
+
+--S 752 of 1370
+r0:=-1/2*x/(1+x^2)+1/2*atan(x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atan(x) - x
+--R   (2)  -------------------
+--R                2
+--R              2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atan(x) - x
+--R   (3)  -------------------
+--R                2
+--R              2x  + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 753
+
+--S 754 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 755
+
+)clear all
+
+--S 756 of 1370
+t0:=x^3/(1+2*x^2+x^4)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 756
+
+--S 757 of 1370
+r0:=1/2/(1+x^2)+1/2*log(1+x^2)
+--R 
+--R
+--R          2          2
+--R        (x  + 1)log(x  + 1) + 1
+--R   (2)  -----------------------
+--R                  2
+--R                2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2          2
+--R        (x  + 1)log(x  + 1) + 1
+--R   (3)  -----------------------
+--R                  2
+--R                2x  + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 758
+
+--S 759 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 760
+
+)clear all
+
+--S 761 of 1370
+t0:=x/(81-18*x^2+x^4)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R         4      2
+--R        x  - 18x  + 81
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 761
+
+--S 762 of 1370
+r0:=1/2/(9-x^2)
+--R 
+--R
+--R             1
+--R             -
+--R             2
+--R   (2)  - ------
+--R           2
+--R          x  - 9
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 762
+
+--S 763 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              1
+--R   (3)  - --------
+--R            2
+--R          2x  - 18
+--R                                         Type: Union(Expression(Integer),...)
+--E 763
+
+--S 764 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 765
+
+)clear all
+
+--S 766 of 1370
+t0:=x^3/(16-8*x^2+x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  -------------
+--R         4     2
+--R        x  - 8x  + 16
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 766
+
+--S 767 of 1370
+r0:=2/(4-x^2)+1/2*log(4-x^2)
+--R 
+--R
+--R          2            2
+--R        (x  - 4)log(- x  + 4) - 4
+--R   (2)  -------------------------
+--R                   2
+--R                 2x  - 8
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2          2
+--R        (x  - 4)log(x  - 4) - 4
+--R   (3)  -----------------------
+--R                  2
+--R                2x  - 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 768
+
+--S 769 of 1370
+m0:=a0-r0
+--R 
+--R
+--R             2               2
+--R        log(x  - 4) - log(- x  + 4)
+--R   (4)  ---------------------------
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 770
+
+)clear all
+
+--S 771 of 1370
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R           +-------------------+
+--R         m | 2 4         2    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 771
+
+--S 772 of 1370
+r0:=x^(1+m)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(3+m)+2*a*x^(1+m)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/((3+4*m+m^2)*(a+b*x^2))
+--R 
+--R
+--R                                       +-------------------+
+--R                   2             m + 1 | 2 4         2    2
+--R        ((b m + b)x  + a m + 3a)x     \|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------
+--R                   2              2      2
+--R               (b m  + 4b m + 3b)x  + a m  + 4a m + 3a
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   3                 m log(x)
+--R        ((b m + b)x  + (a m + 3a)x)%e
+--R   (3)  -------------------------------------
+--R                      2
+--R                     m  + 4m + 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 773
+
+--S 774 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          2     2  5                   3     2      2     m log(x)
+--R       ((b m + b )x  + (2a b m + 4a b)x  + (a m + 3a )x)%e
+--R     + 
+--R                                        +-------------------+
+--R                    2             m + 1 | 2 4         2    2
+--R       ((- b m - b)x  - a m - 3a)x     \|b x  + 2a b x  + a
+--R  /
+--R         2              2      2
+--R     (b m  + 4b m + 3b)x  + a m  + 4a m + 3a
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                 +-------------------+
+--R                   2             | 2 4         2    2   m log(x)
+--R       ((b m + 3b)x  + a m + 3a)\|b x  + 2a b x  + a  %e
+--R     + 
+--R            2 3           m + 1
+--R       (- 2b x  - 2a b x)x
+--R     + 
+--R            2     2  4                     2    2      2  m
+--R       ((- b m - b )x  + (- 2a b m - 4a b)x  - a m - 3a )x
+--R  /
+--R             +-------------------+
+--R             | 2 4         2    2
+--R     (m + 3)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 775
+
+)clear all
+
+--S 776 of 1370
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R           +-------------------+
+--R         5 | 2 4         2    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 1370
+r0:=1/8*x^6*sqrt(a^2+2*a*b*x^2+b^2*x^4)+1/24*a*x^6*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                        +-------------------+
+--R             8       6  | 2 4         2    2
+--R        (3b x  + 4a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          2
+--R                     24b x  + 24a
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            8       6
+--R        3b x  + 4a x
+--R   (3)  -------------
+--R              24
+--R                                         Type: Union(Expression(Integer),...)
+--E 778
+
+--S 779 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                          +-------------------+
+--R               8       6  | 2 4         2    2      2 10         8     2 6
+--R        (- 3b x  - 4a x )\|b x  + 2a b x  + a   + 3b x   + 7a b x  + 4a x
+--R   (4)  ------------------------------------------------------------------
+--R                                        2
+--R                                   24b x  + 24a
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                      +-------------------+
+--R            7      5  | 2 4         2    2     2 9         7    2 5
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  -----------------------------------------------------------
+--R                            +-------------------+
+--R                            | 2 4         2    2
+--R                           \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 780
+
+)clear all
+
+--S 781 of 1370
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R           +-------------------+
+--R         4 | 2 4         2    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 781
+
+--S 782 of 1370
+r0:=1/7*x^5*sqrt(a^2+2*a*b*x^2+b^2*x^4)+2/35*a*x^5*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                        +-------------------+
+--R             7       5  | 2 4         2    2
+--R        (5b x  + 7a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          2
+--R                     35b x  + 35a
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            7       5
+--R        5b x  + 7a x
+--R   (3)  -------------
+--R              35
+--R                                         Type: Union(Expression(Integer),...)
+--E 783
+
+--S 784 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                          +-------------------+
+--R               7       5  | 2 4         2    2      2 9          7     2 5
+--R        (- 5b x  - 7a x )\|b x  + 2a b x  + a   + 5b x  + 12a b x  + 7a x
+--R   (4)  ------------------------------------------------------------------
+--R                                        2
+--R                                   35b x  + 35a
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                      +-------------------+
+--R            6      4  | 2 4         2    2     2 8         6    2 4
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  -----------------------------------------------------------
+--R                            +-------------------+
+--R                            | 2 4         2    2
+--R                           \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 785
+
+)clear all
+
+--S 786 of 1370
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R           +-------------------+
+--R         3 | 2 4         2    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 1370
+r0:=1/6*x^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)+1/12*a*x^4*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                        +-------------------+
+--R             6       4  | 2 4         2    2
+--R        (2b x  + 3a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          2
+--R                     12b x  + 12a
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            6       4
+--R        2b x  + 3a x
+--R   (3)  -------------
+--R              12
+--R                                         Type: Union(Expression(Integer),...)
+--E 788
+
+--S 789 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                          +-------------------+
+--R               6       4  | 2 4         2    2      2 8         6     2 4
+--R        (- 2b x  - 3a x )\|b x  + 2a b x  + a   + 2b x  + 5a b x  + 3a x
+--R   (4)  -----------------------------------------------------------------
+--R                                        2
+--R                                   12b x  + 12a
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                      +-------------------+
+--R            5      3  | 2 4         2    2     2 7         5    2 3
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  -----------------------------------------------------------
+--R                            +-------------------+
+--R                            | 2 4         2    2
+--R                           \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 790
+
+)clear all
+
+--S 791 of 1370
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R           +-------------------+
+--R         2 | 2 4         2    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 1370
+r0:=1/5*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4)+2/15*a*x^3*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                        +-------------------+
+--R             5       3  | 2 4         2    2
+--R        (3b x  + 5a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          2
+--R                     15b x  + 15a
+--R                                                    Type: Expression(Integer)
+--E 792
+
+--S 793 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5       3
+--R        3b x  + 5a x
+--R   (3)  -------------
+--R              15
+--R                                         Type: Union(Expression(Integer),...)
+--E 793
+
+--S 794 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                          +-------------------+
+--R               5       3  | 2 4         2    2      2 7         5     2 3
+--R        (- 3b x  - 5a x )\|b x  + 2a b x  + a   + 3b x  + 8a b x  + 5a x
+--R   (4)  -----------------------------------------------------------------
+--R                                        2
+--R                                   15b x  + 15a
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                      +-------------------+
+--R            4      2  | 2 4         2    2     2 6         4    2 2
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  -----------------------------------------------------------
+--R                            +-------------------+
+--R                            | 2 4         2    2
+--R                           \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 795
+
+)clear all
+
+--S 796 of 1370
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 4         2    2
+--R   (1)  x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 1370
+r0:=1/4*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/b
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a
+--R   (2)  --------------------------------
+--R                       4b
+--R                                                    Type: Expression(Integer)
+--E 797
+
+--S 798 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4       2
+--R        b x  + 2a x
+--R   (3)  ------------
+--R              4
+--R                                         Type: Union(Expression(Integer),...)
+--E 798
+
+--S 799 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R              2      | 2 4         2    2     2 4         2
+--R        (- b x  - a)\|b x  + 2a b x  + a   + b x  + 2a b x
+--R   (4)  ---------------------------------------------------
+--R                                 4b
+--R                                                    Type: Expression(Integer)
+--E 799
+
+--S 800 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                     +-------------------+
+--R            3        | 2 4         2    2     2 5         3    2
+--R        (b x  + a x)\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  ---------------------------------------------------------
+--R                           +-------------------+
+--R                           | 2 4         2    2
+--R                          \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 800
+
+)clear all
+
+--S 801 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R   (1)  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 801
+
+--S 802 of 1370
+r0:=1/3*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+2/3*a*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                      +-------------------+
+--R            3         | 2 4         2    2
+--R        (b x  + 3a x)\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------
+--R                         2
+--R                     3b x  + 3a
+--R                                                    Type: Expression(Integer)
+--E 802
+
+--S 803 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3
+--R        b x  + 3a x
+--R   (3)  -----------
+--R             3
+--R                                         Type: Union(Expression(Integer),...)
+--E 803
+
+--S 804 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                        +-------------------+
+--R              3         | 2 4         2    2     2 5         3     2
+--R        (- b x  - 3a x)\|b x  + 2a b x  + a   + b x  + 4a b x  + 3a x
+--R   (4)  -------------------------------------------------------------
+--R                                      2
+--R                                  3b x  + 3a
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                         +-------------------+
+--R                         | 2 4         2    2
+--R                        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 805
+
+)clear all
+
+--S 806 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 1370
+r0:=1/2*sqrt(a^2+2*a*b*x^2+b^2*x^4)+a*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                               +-------------------+
+--R                        2      | 2 4         2    2
+--R        (2a log(x) + b x  + a)\|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------
+--R                             2
+--R                         2b x  + 2a
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       2
+--R        2a log(x) + b x
+--R   (3)  ----------------
+--R                2
+--R                                         Type: Union(Expression(Integer),...)
+--E 808
+
+--S 809 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +-------------------+
+--R                         2      | 2 4         2    2           2     2
+--R       (- 2a log(x) - b x  - a)\|b x  + 2a b x  + a   + (2a b x  + 2a )log(x)
+--R     + 
+--R        2 4        2
+--R       b x  + a b x
+--R  /
+--R         2
+--R     2b x  + 2a
+--R                                                    Type: Expression(Integer)
+--E 809
+
+--S 810 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                          | 2 4         2    2
+--R                        x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 810
+
+)clear all
+
+--S 811 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^2
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   2
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 1370
+r0:=sqrt(a^2+2*a*b*x^2+b^2*x^4)/x-2*a*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x*(a+b*x^2))
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2
+--R        (b x  - a)\|b x  + 2a b x  + a
+--R   (2)  --------------------------------
+--R                      3
+--R                   b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R        b x  - a
+--R   (3)  --------
+--R            x
+--R                                         Type: Union(Expression(Integer),...)
+--E 813
+
+--S 814 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R              2      | 2 4         2    2     2 4    2
+--R        (- b x  + a)\|b x  + 2a b x  + a   + b x  - a
+--R   (4)  ----------------------------------------------
+--R                             3
+--R                          b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        2 | 2 4         2    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 815
+
+)clear all
+
+--S 816 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^3
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   3
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 1370
+r0:=-1/2*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^2*(a+b*x^2))+_
+    b*log(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                          +-------------------+
+--R             2            | 2 4         2    2
+--R        (2b x log(x) - a)\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------
+--R                         4       2
+--R                     2b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2
+--R        2b x log(x) - a
+--R   (3)  ---------------
+--R                2
+--R              2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 818
+
+--S 819 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           +-------------------+
+--R              2            | 2 4         2    2       2 4         2
+--R       (- 2b x log(x) + a)\|b x  + 2a b x  + a   + (2b x  + 2a b x )log(x)
+--R     + 
+--R              2    2
+--R       - a b x  - a
+--R  /
+--R         4       2
+--R     2b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        3 | 2 4         2    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 820
+
+)clear all
+
+--S 821 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^4
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   4
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 1370
+r0:=-sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3+2/3*a*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^3*(a+b*x^2))
+--R 
+--R
+--R                      +-------------------+
+--R               2      | 2 4         2    2
+--R        (- 3b x  - a)\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------
+--R                       5       3
+--R                   3b x  + 3a x
+--R                                                    Type: Expression(Integer)
+--E 822
+
+--S 823 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R        - 3b x  - a
+--R   (3)  -----------
+--R              3
+--R            3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 823
+
+--S 824 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                    +-------------------+
+--R             2      | 2 4         2    2      2 4         2    2
+--R        (3b x  + a)\|b x  + 2a b x  + a   - 3b x  - 4a b x  - a
+--R   (4)  --------------------------------------------------------
+--R                                  5       3
+--R                              3b x  + 3a x
+--R                                                    Type: Expression(Integer)
+--E 824
+
+--S 825 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        4 | 2 4         2    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 825
+
+)clear all
+
+--S 826 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^5
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   5
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 1370
+r0:=-1/4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/(a*x^4)
+--R 
+--R
+--R                     +-------------------+
+--R              2      | 2 4         2    2
+--R        (- b x  - a)\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------
+--R                           4
+--R                       4a x
+--R                                                    Type: Expression(Integer)
+--E 827
+
+--S 828 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R        - 2b x  - a
+--R   (3)  -----------
+--R              4
+--R            4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 828
+
+--S 829 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2          2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - 2a b x  - a
+--R   (4)  -----------------------------------------------
+--R                                 4
+--R                             4a x
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        5 | 2 4         2    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 830
+
+)clear all
+
+--S 831 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^6
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   6
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 1370
+r0:=-1/3*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^5+_
+    2/15*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^5*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 5b x  - 3a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                        7        5
+--R                   15b x  + 15a x
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R        - 5b x  - 3a
+--R   (3)  ------------
+--R               5
+--R            15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 833
+
+--S 834 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R             2       | 2 4         2    2      2 4         2     2
+--R        (5b x  + 3a)\|b x  + 2a b x  + a   - 5b x  - 8a b x  - 3a
+--R   (4)  ----------------------------------------------------------
+--R                                   7        5
+--R                              15b x  + 15a x
+--R                                                    Type: Expression(Integer)
+--E 834
+
+--S 835 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        6 | 2 4         2    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 835
+
+)clear all
+
+--S 836 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^7
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   7
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 1370
+r0:=-1/4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^6+_
+    1/12*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^6*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 3b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                        8        6
+--R                   12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R        - 3b x  - 2a
+--R   (3)  ------------
+--R               6
+--R            12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 838
+
+--S 839 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R             2       | 2 4         2    2      2 4         2     2
+--R        (3b x  + 2a)\|b x  + 2a b x  + a   - 3b x  - 5a b x  - 2a
+--R   (4)  ----------------------------------------------------------
+--R                                   8        6
+--R                              12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 839
+
+--S 840 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        7 | 2 4         2    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 840
+
+)clear all
+
+--S 841 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^8
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   8
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 841
+
+--S 842 of 1370
+r0:=-1/5*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^7+_
+    2/35*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^7*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 7b x  - 5a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                        9        7
+--R                   35b x  + 35a x
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R        - 7b x  - 5a
+--R   (3)  ------------
+--R               7
+--R            35x
+--R                                         Type: Union(Expression(Integer),...)
+--E 843
+
+--S 844 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R             2       | 2 4         2    2      2 4          2     2
+--R        (7b x  + 5a)\|b x  + 2a b x  + a   - 7b x  - 12a b x  - 5a
+--R   (4)  -----------------------------------------------------------
+--R                                   9        7
+--R                              35b x  + 35a x
+--R                                                    Type: Expression(Integer)
+--E 844
+
+--S 845 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        8 | 2 4         2    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 845
+
+)clear all
+
+--S 846 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^9
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   9
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 846
+
+--S 847 of 1370
+r0:=-1/6*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^8+_
+    1/24*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^8*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 4b x  - 3a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       10        8
+--R                  24b x   + 24a x
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R        - 4b x  - 3a
+--R   (3)  ------------
+--R               8
+--R            24x
+--R                                         Type: Union(Expression(Integer),...)
+--E 848
+
+--S 849 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R             2       | 2 4         2    2      2 4         2     2
+--R        (4b x  + 3a)\|b x  + 2a b x  + a   - 4b x  - 7a b x  - 3a
+--R   (4)  ----------------------------------------------------------
+--R                                  10        8
+--R                             24b x   + 24a x
+--R                                                    Type: Expression(Integer)
+--E 849
+
+--S 850 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        9 | 2 4         2    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 850
+
+)clear all
+
+--S 851 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^10
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   10
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 1370
+r0:=-1/7*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^9+_
+    2/63*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^9*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 9b x  - 7a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       11        9
+--R                  63b x   + 63a x
+--R                                                    Type: Expression(Integer)
+--E 852
+
+--S 853 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R        - 9b x  - 7a
+--R   (3)  ------------
+--R               9
+--R            63x
+--R                                         Type: Union(Expression(Integer),...)
+--E 853
+
+--S 854 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R             2       | 2 4         2    2      2 4          2     2
+--R        (9b x  + 7a)\|b x  + 2a b x  + a   - 9b x  - 16a b x  - 7a
+--R   (4)  -----------------------------------------------------------
+--R                                   11        9
+--R                              63b x   + 63a x
+--R                                                    Type: Expression(Integer)
+--E 854
+
+--S 855 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                           +-------------------+
+--R                        10 | 2 4         2    2
+--R                       x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 855
+
+)clear all
+
+--S 856 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^11
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   11
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 856
+
+--S 857 of 1370
+r0:=-1/8*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^10+_
+    1/40*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^10*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 5b x  - 4a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       12        10
+--R                  40b x   + 40a x
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R        - 5b x  - 4a
+--R   (3)  ------------
+--R               10
+--R            40x
+--R                                         Type: Union(Expression(Integer),...)
+--E 858
+
+--S 859 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R             2       | 2 4         2    2      2 4         2     2
+--R        (5b x  + 4a)\|b x  + 2a b x  + a   - 5b x  - 9a b x  - 4a
+--R   (4)  ----------------------------------------------------------
+--R                                  12        10
+--R                             40b x   + 40a x
+--R                                                    Type: Expression(Integer)
+--E 859
+
+--S 860 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                           +-------------------+
+--R                        11 | 2 4         2    2
+--R                       x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 860
+
+)clear all
+
+--S 861 of 1370
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 4         2    2  m | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a )x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 861
+
+--S 862 of 1370
+r0:=x^(1+m)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(7+m)+24*a^2*x^(1+m)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/((3+m)*(5+m)*(7+m))+48*a^3*x^(1+m)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/((5+m)*(7+m)*(3+4*m+m^2)*(a+b*x^2))+_
+    6*a*x^(1+m)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/((5+m)*(7+m))
+--R 
+--R
+--R   (2)
+--R           3 3     3 2      3       3  6
+--R         (b m  + 9b m  + 23b m + 15b )x
+--R       + 
+--R              2 3        2 2        2         2  4
+--R         (3a b m  + 33a b m  + 93a b m + 63a b )x
+--R       + 
+--R            2   3      2   2       2          2   2    3 3      3 2      3
+--R         (3a b m  + 39a b m  + 141a b m + 105a b)x  + a m  + 15a m  + 71a m
+--R       + 
+--R             3
+--R         105a
+--R    *
+--R              +-------------------+
+--R        m + 1 | 2 4         2    2
+--R       x     \|b x  + 2a b x  + a
+--R  /
+--R           4        3        2                  2      4        3        2
+--R       (b m  + 16b m  + 86b m  + 176b m + 105b)x  + a m  + 16a m  + 86a m
+--R     + 
+--R       176a m + 105a
+--R                                                    Type: Expression(Integer)
+--E 862
+
+--S 863 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 3     3 2      3       3  7
+--R         (b m  + 9b m  + 23b m + 15b )x
+--R       + 
+--R              2 3        2 2        2         2  5
+--R         (3a b m  + 33a b m  + 93a b m + 63a b )x
+--R       + 
+--R            2   3      2   2       2          2   3
+--R         (3a b m  + 39a b m  + 141a b m + 105a b)x
+--R       + 
+--R           3 3      3 2      3        3
+--R         (a m  + 15a m  + 71a m + 105a )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      4      3      2
+--R     m  + 16m  + 86m  + 176m + 105
+--R                                         Type: Union(Expression(Integer),...)
+--E 863
+
+--S 864 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4 3     4 2      4       4  9
+--R           (b m  + 9b m  + 23b m + 15b )x
+--R         + 
+--R                3 3        3 2         3         3  7
+--R           (4a b m  + 42a b m  + 116a b m + 78a b )x
+--R         + 
+--R              2 2 3      2 2 2       2 2        2 2  5
+--R           (6a b m  + 72a b m  + 234a b m + 168a b )x
+--R         + 
+--R              3   3      3   2       3          3   3
+--R           (4a b m  + 54a b m  + 212a b m + 210a b)x
+--R         + 
+--R             4 3      4 2      4        4
+--R           (a m  + 15a m  + 71a m + 105a )x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R               3 3     3 2      3       3  6
+--R           (- b m  - 9b m  - 23b m - 15b )x
+--R         + 
+--R                  2 3        2 2        2         2  4
+--R           (- 3a b m  - 33a b m  - 93a b m - 63a b )x
+--R         + 
+--R                2   3      2   2       2          2   2    3 3      3 2      3
+--R           (- 3a b m  - 39a b m  - 141a b m - 105a b)x  - a m  - 15a m  - 71a m
+--R         + 
+--R                 3
+--R           - 105a
+--R      *
+--R                +-------------------+
+--R          m + 1 | 2 4         2    2
+--R         x     \|b x  + 2a b x  + a
+--R  /
+--R           4        3        2                  2      4        3        2
+--R       (b m  + 16b m  + 86b m  + 176b m + 105b)x  + a m  + 16a m  + 86a m
+--R     + 
+--R       176a m + 105a
+--R                                                    Type: Expression(Integer)
+--E 864
+
+--S 865 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R             3 3      3 2      3        3  6
+--R           (b m  + 15b m  + 71b m + 105b )x
+--R         + 
+--R                2 3        2 2         2          2  4
+--R           (3a b m  + 45a b m  + 213a b m + 315a b )x
+--R         + 
+--R              2   3      2   2       2          2   2    3 3      3 2      3
+--R           (3a b m  + 45a b m  + 213a b m + 315a b)x  + a m  + 15a m  + 71a m
+--R         + 
+--R               3
+--R           105a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2   m log(x)
+--R         \|b x  + 2a b x  + a  %e
+--R     + 
+--R                4 2      4       4  7           3 2         3          3  5
+--R           (- 6b m  - 48b m - 90b )x  + (- 18a b m  - 168a b m - 342a b )x
+--R         + 
+--R               2 2 2       2 2        2 2  3        3   2      3          3
+--R         (- 18a b m  - 192a b m - 462a b )x  + (- 6a b m  - 72a b m - 210a b)x
+--R      *
+--R          m + 1
+--R         x
+--R     + 
+--R               4 3     4 2      4       4  8
+--R           (- b m  - 9b m  - 23b m - 15b )x
+--R         + 
+--R                  3 3        3 2         3         3  6
+--R           (- 4a b m  - 42a b m  - 116a b m - 78a b )x
+--R         + 
+--R                2 2 3      2 2 2       2 2        2 2  4
+--R           (- 6a b m  - 72a b m  - 234a b m - 168a b )x
+--R         + 
+--R                3   3      3   2       3          3   2    4 3      4 2      4
+--R           (- 4a b m  - 54a b m  - 212a b m - 210a b)x  - a m  - 15a m  - 71a m
+--R         + 
+--R                 4
+--R           - 105a
+--R      *
+--R          m
+--R         x
+--R  /
+--R                             +-------------------+
+--R       3      2              | 2 4         2    2
+--R     (m  + 15m  + 71m + 105)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 865
+
+)clear all
+
+--S 866 of 1370
+t0:=x^9*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 13         11    2 9  | 2 4         2    2
+--R   (1)  (b x   + 2a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 1370
+r0:=1/16*x^10*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/112*a^2*x^10*sqrt(a^2+_
+    2*a*b*x^2+b^2*x^4)+1/560*a^3*x^10*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+    (a+b*x^2)+3/112*a*x^10*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                      +-------------------+
+--R            3 16         2 14       2   12      3 10  | 2 4         2    2
+--R        (35b x   + 120a b x   + 140a b x   + 56a x  )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------------------
+--R                                         2
+--R                                   560b x  + 560a
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 16         2 14       2   12      3 10
+--R        35b x   + 120a b x   + 140a b x   + 56a x
+--R   (3)  -------------------------------------------
+--R                            560
+--R                                         Type: Union(Expression(Integer),...)
+--E 868
+
+--S 869 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                       +-------------------+
+--R             3 16         2 14       2   12      3 10  | 2 4         2    2
+--R       (- 35b x   - 120a b x   - 140a b x   - 56a x  )\|b x  + 2a b x  + a
+--R     + 
+--R          4 18         3 16       2 2 14       3   12      4 10
+--R       35b x   + 155a b x   + 260a b x   + 196a b x   + 56a x
+--R  /
+--R           2
+--R     560b x  + 560a
+--R                                                    Type: Expression(Integer)
+--E 869
+
+--S 870 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                            +-------------------+
+--R         3 15       2 13     2   11    3 9  | 2 4         2    2     4 17
+--R       (b x   + 3a b x   + 3a b x   + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 15     2 2 13     3   11    4 9
+--R       - 4a b x   - 6a b x   - 4a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 870
+
+)clear all
+
+--S 871 of 1370
+t0:=x^8*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 12         10    2 8  | 2 4         2    2
+--R   (1)  (b x   + 2a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 871
+
+--S 872 of 1370
+r0:=1/15*x^9*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/715*a^2*x^9*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/6435*a^3*x^9*sqrt(a^2+2*a*b*x^2+_
+    b^2*x^4)/(a+b*x^2)+2/65*a*x^9*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                         +-------------------+
+--R             3 15          2 13        2   11       3 9  | 2 4         2    2
+--R        (429b x   + 1485a b x   + 1755a b x   + 715a x )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------------
+--R                                          2
+--R                                   6435b x  + 6435a
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 15          2 13        2   11       3 9
+--R        429b x   + 1485a b x   + 1755a b x   + 715a x
+--R   (3)  ----------------------------------------------
+--R                             6435
+--R                                         Type: Union(Expression(Integer),...)
+--E 873
+
+--S 874 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +-------------------+
+--R              3 15          2 13        2   11       3 9  | 2 4         2    2
+--R       (- 429b x   - 1485a b x   - 1755a b x   - 715a x )\|b x  + 2a b x  + a
+--R     + 
+--R           4 17          3 15        2 2 13        3   11       4 9
+--R       429b x   + 1914a b x   + 3240a b x   + 2470a b x   + 715a x
+--R  /
+--R            2
+--R     6435b x  + 6435a
+--R                                                    Type: Expression(Integer)
+--E 874
+
+--S 875 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                            +-------------------+
+--R         3 14       2 12     2   10    3 8  | 2 4         2    2     4 16
+--R       (b x   + 3a b x   + 3a b x   + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 14     2 2 12     3   10    4 8
+--R       - 4a b x   - 6a b x   - 4a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 875
+
+)clear all
+
+--S 876 of 1370
+t0:=x^7*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                 +-------------------+
+--R          2 11         9    2 7  | 2 4         2    2
+--R   (1)  (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 876
+
+--S 877 of 1370
+r0:=1/14*x^8*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/70*a^2*x^8*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+1/280*a^3*x^8*sqrt(a^2+2*a*b*x^2+_
+    b^2*x^4)/(a+b*x^2)+1/28*a*x^8*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                   +-------------------+
+--R            3 14        2 12      2   10      3 8  | 2 4         2    2
+--R        (20b x   + 70a b x   + 84a b x   + 35a x )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                       2
+--R                                 280b x  + 280a
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--S 878 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 14        2 12      2   10      3 8
+--R        20b x   + 70a b x   + 84a b x   + 35a x
+--R   (3)  ----------------------------------------
+--R                           280
+--R                                         Type: Union(Expression(Integer),...)
+--E 878
+
+--S 879 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +-------------------+
+--R             3 14        2 12      2   10      3 8  | 2 4         2    2
+--R       (- 20b x   - 70a b x   - 84a b x   - 35a x )\|b x  + 2a b x  + a
+--R     + 
+--R          4 16        3 14       2 2 12       3   10      4 8
+--R       20b x   + 90a b x   + 154a b x   + 119a b x   + 35a x
+--R  /
+--R           2
+--R     280b x  + 280a
+--R                                                    Type: Expression(Integer)
+--E 879
+
+--S 880 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                           +-------------------+
+--R         3 13       2 11     2   9    3 7  | 2 4         2    2     4 15
+--R       (b x   + 3a b x   + 3a b x  + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 13     2 2 11     3   9    4 7
+--R       - 4a b x   - 6a b x   - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 880
+
+)clear all
+
+--S 881 of 1370
+t0:=x^6*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                 +-------------------+
+--R          2 10         8    2 6  | 2 4         2    2
+--R   (1)  (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 881
+
+--S 882 of 1370
+r0:=1/13*x^7*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/429*a^2*x^7*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/3003*a^3*x^7*sqrt(a^2+2*a*b*x^2+_
+    b^2*x^4)/(a+b*x^2)+6/143*a*x^7*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                       +-------------------+
+--R             3 13         2 11        2   9       3 7  | 2 4         2    2
+--R        (231b x   + 819a b x   + 1001a b x  + 429a x )\|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------------------------------
+--R                                         2
+--R                                  3003b x  + 3003a
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 13         2 11        2   9       3 7
+--R        231b x   + 819a b x   + 1001a b x  + 429a x
+--R   (3)  --------------------------------------------
+--R                            3003
+--R                                         Type: Union(Expression(Integer),...)
+--E 883
+
+--S 884 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                        +-------------------+
+--R              3 13         2 11        2   9       3 7  | 2 4         2    2
+--R       (- 231b x   - 819a b x   - 1001a b x  - 429a x )\|b x  + 2a b x  + a
+--R     + 
+--R           4 15          3 13        2 2 11        3   9       4 7
+--R       231b x   + 1050a b x   + 1820a b x   + 1430a b x  + 429a x
+--R  /
+--R            2
+--R     3003b x  + 3003a
+--R                                                    Type: Expression(Integer)
+--E 884
+
+--S 885 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                           +-------------------+
+--R         3 12       2 10     2   8    3 6  | 2 4         2    2     4 14
+--R       (b x   + 3a b x   + 3a b x  + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 12     2 2 10     3   8    4 6
+--R       - 4a b x   - 6a b x   - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 885
+
+)clear all
+
+--S 886 of 1370
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 9         7    2 5  | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 886
+
+--S 887 of 1370
+r0:=1/24*a^2*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/b^3+_
+    1/12*x^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/b-_
+    1/30*a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^3
+--R 
+--R
+--R   (2)
+--R                                                          +-------------------+
+--R       5 10        4 8      2 3 6    3 2 4    4   2    5  | 2 4         2    2
+--R   (10b x   + 26a b x  + 19a b x  + a b x  - a b x  + a )\|b x  + 2a b x  + a
+--R   ----------------------------------------------------------------------------
+--R                                           3
+--R                                       120b
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 12        2 10      2   8      3 6
+--R        10b x   + 36a b x   + 45a b x  + 20a x
+--R   (3)  ---------------------------------------
+--R                          120
+--R                                         Type: Union(Expression(Integer),...)
+--E 888
+
+--S 889 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 10        4 8      2 3 6    3 2 4    4   2    5
+--R         (- 10b x   - 26a b x  - 19a b x  - a b x  + a b x  - a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12        5 10      2 4 8      3 3 6
+--R       10b x   + 36a b x   + 45a b x  + 20a b x
+--R  /
+--R         3
+--R     120b
+--R                                                    Type: Expression(Integer)
+--E 889
+
+--S 890 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                          +-------------------+
+--R         3 11       2 9     2   7    3 5  | 2 4         2    2     4 13
+--R       (b x   + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 11     2 2 9     3   7    4 5
+--R       - 4a b x   - 6a b x  - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 890
+
+)clear all
+
+--S 891 of 1370
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 8         6    2 4  | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 891
+
+--S 892 of 1370
+r0:=1/11*x^5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/231*a^2*x^5*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/1155*a^3*x^5*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+2/33*a*x^5*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                     +-------------------+
+--R             3 11         2 9       2   7       3 5  | 2 4         2    2
+--R        (105b x   + 385a b x  + 495a b x  + 231a x )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------------
+--R                                        2
+--R                                 1155b x  + 1155a
+--R                                                    Type: Expression(Integer)
+--E 892
+
+--S 893 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 11         2 9       2   7       3 5
+--R        105b x   + 385a b x  + 495a b x  + 231a x
+--R   (3)  ------------------------------------------
+--R                           1155
+--R                                         Type: Union(Expression(Integer),...)
+--E 893
+
+--S 894 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +-------------------+
+--R              3 11         2 9       2   7       3 5  | 2 4         2    2
+--R       (- 105b x   - 385a b x  - 495a b x  - 231a x )\|b x  + 2a b x  + a
+--R     + 
+--R           4 13         3 11       2 2 9       3   7       4 5
+--R       105b x   + 490a b x   + 880a b x  + 726a b x  + 231a x
+--R  /
+--R            2
+--R     1155b x  + 1155a
+--R                                                    Type: Expression(Integer)
+--E 894
+
+--S 895 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                          +-------------------+
+--R         3 10       2 8     2   6    3 4  | 2 4         2    2     4 12
+--R       (b x   + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 10     2 2 8     3   6    4 4
+--R       - 4a b x   - 6a b x  - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 895
+
+)clear all
+
+--S 896 of 1370
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 7         5    2 3  | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 896
+
+--S 897 of 1370
+r0:=-1/8*a*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/b^2+_
+    1/10*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^2
+--R 
+--R
+--R                                                   +-------------------+
+--R           4 8        3 6     2 2 4    3   2    4  | 2 4         2    2
+--R        (4b x  + 11a b x  + 9a b x  + a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                         2
+--R                                      40b
+--R                                                    Type: Expression(Integer)
+--E 897
+
+--S 898 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3 10        2 8      2   6      3 4
+--R        4b x   + 15a b x  + 20a b x  + 10a x
+--R   (3)  -------------------------------------
+--R                          40
+--R                                         Type: Union(Expression(Integer),...)
+--E 898
+
+--S 899 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +-------------------+
+--R            4 8        3 6     2 2 4    3   2    4  | 2 4         2    2
+--R       (- 4b x  - 11a b x  - 9a b x  - a b x  + a )\|b x  + 2a b x  + a
+--R     + 
+--R         5 10        4 8      2 3 6      3 2 4
+--R       4b x   + 15a b x  + 20a b x  + 10a b x
+--R  /
+--R        2
+--R     40b
+--R                                                    Type: Expression(Integer)
+--E 899
+
+--S 900 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                         +-------------------+
+--R         3 9       2 7     2   5    3 3  | 2 4         2    2     4 11       3 9
+--R       (b x  + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 7     3   5    4 3
+--R       - 6a b x  - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 900
+
+)clear all
+
+--S 901 of 1370
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 6         4    2 2  | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 1370
+r0:=1/9*x^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/105*a^2*x^3*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/315*a^3*x^3*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+2/21*a*x^3*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                   +-------------------+
+--R            3 9         2 7       2   5       3 3  | 2 4         2    2
+--R        (35b x  + 135a b x  + 189a b x  + 105a x )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                       2
+--R                                 315b x  + 315a
+--R                                                    Type: Expression(Integer)
+--E 902
+
+--S 903 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 9         2 7       2   5       3 3
+--R        35b x  + 135a b x  + 189a b x  + 105a x
+--R   (3)  ----------------------------------------
+--R                           315
+--R                                         Type: Union(Expression(Integer),...)
+--E 903
+
+--S 904 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +-------------------+
+--R             3 9         2 7       2   5       3 3  | 2 4         2    2
+--R       (- 35b x  - 135a b x  - 189a b x  - 105a x )\|b x  + 2a b x  + a
+--R     + 
+--R          4 11         3 9       2 2 7       3   5       4 3
+--R       35b x   + 170a b x  + 324a b x  + 294a b x  + 105a x
+--R  /
+--R           2
+--R     315b x  + 315a
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                         +-------------------+
+--R         3 8       2 6     2   4    3 2  | 2 4         2    2     4 10       3 8
+--R       (b x  + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   4    4 2
+--R       - 6a b x  - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 905
+
+)clear all
+
+--S 906 of 1370
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                               +-------------------+
+--R          2 5         3    2   | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 906
+
+--S 907 of 1370
+r0:=1/8*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/b
+--R 
+--R
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------
+--R                                  8b
+--R                                                    Type: Expression(Integer)
+--E 907
+
+--S 908 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3 8       2 6     2   4     3 2
+--R        b x  + 4a b x  + 6a b x  + 4a x
+--R   (3)  --------------------------------
+--R                        8
+--R                                         Type: Union(Expression(Integer),...)
+--E 908
+
+--S 909 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +-------------------+
+--R           3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (- b x  - 3a b x  - 3a b x  - a )\|b x  + 2a b x  + a   + b x  + 4a b x
+--R     + 
+--R         2 2 4     3   2
+--R       6a b x  + 4a b x
+--R  /
+--R     8b
+--R                                                    Type: Expression(Integer)
+--E 909
+
+--S 910 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                        +-------------------+
+--R         3 7       2 5     2   3    3   | 2 4         2    2     4 9       3 7
+--R       (b x  + 3a b x  + 3a b x  + a x)\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 5     3   3    4
+--R       - 6a b x  - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 910
+
+)clear all
+
+--S 911 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 911
+
+--S 912 of 1370
+r0:=1/7*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/35*a^2*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/35*a^3*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+6/35*a*x*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                              +-------------------+
+--R           3 7        2 5      2   3      3   | 2 4         2    2
+--R        (5b x  + 21a b x  + 35a b x  + 35a x)\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------
+--R                                     2
+--R                                35b x  + 35a
+--R                                                    Type: Expression(Integer)
+--E 912
+
+--S 913 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3 7        2 5      2   3      3
+--R        5b x  + 21a b x  + 35a b x  + 35a x
+--R   (3)  -----------------------------------
+--R                         35
+--R                                         Type: Union(Expression(Integer),...)
+--E 913
+
+--S 914 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +-------------------+
+--R            3 7        2 5      2   3      3   | 2 4         2    2      4 9
+--R       (- 5b x  - 21a b x  - 35a b x  - 35a x)\|b x  + 2a b x  + a   + 5b x
+--R     + 
+--R            3 7      2 2 5      3   3      4
+--R       26a b x  + 56a b x  + 70a b x  + 35a x
+--R  /
+--R          2
+--R     35b x  + 35a
+--R                                                    Type: Expression(Integer)
+--E 914
+
+--S 915 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 915
+
+)clear all
+
+--S 916 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 916
+
+--S 917 of 1370
+r0:=1/6*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/2*a^2*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+    1/4*a*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+a^3*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                                                         +-------------------+
+--R            3           3 6       2 4      2   2      3  | 2 4         2    2
+--R        (12a log(x) + 2b x  + 9a b x  + 18a b x  + 11a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------------
+--R                                          2
+--R                                     12b x  + 12a
+--R                                                    Type: Expression(Integer)
+--E 917
+
+--S 918 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3           3 6       2 4      2   2
+--R        12a log(x) + 2b x  + 9a b x  + 18a b x
+--R   (3)  ---------------------------------------
+--R                           12
+--R                                         Type: Union(Expression(Integer),...)
+--E 918
+
+--S 919 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +-------------------+
+--R             3           3 6       2 4      2   2      3  | 2 4         2    2
+--R       (- 12a log(x) - 2b x  - 9a b x  - 18a b x  - 11a )\|b x  + 2a b x  + a
+--R     + 
+--R           3   2      4            4 8        3 6      2 2 4      3   2
+--R       (12a b x  + 12a )log(x) + 2b x  + 11a b x  + 27a b x  + 18a b x
+--R  /
+--R          2
+--R     12b x  + 12a
+--R                                                    Type: Expression(Integer)
+--E 919
+
+--S 920 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R       +-------------------+
+--R       | 2 4         2    2
+--R     x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 920
+
+)clear all
+
+--S 921 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^2
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              2
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 921
+
+--S 922 of 1370
+r0:=1/5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x+8/5*a*b*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/5*a^2*b*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)-6/5*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x
+--R 
+--R
+--R                                          +-------------------+
+--R          3 6       2 4      2   2     3  | 2 4         2    2
+--R        (b x  + 5a b x  + 15a b x  - 5a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------
+--R                                  3
+--R                              5b x  + 5a x
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3 6       2 4      2   2     3
+--R        b x  + 5a b x  + 15a b x  - 5a
+--R   (3)  -------------------------------
+--R                       5x
+--R                                         Type: Union(Expression(Integer),...)
+--E 923
+
+--S 924 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +-------------------+
+--R           3 6       2 4      2   2     3  | 2 4         2    2     4 8
+--R       (- b x  - 5a b x  - 15a b x  + 5a )\|b x  + 2a b x  + a   + b x
+--R     + 
+--R           3 6      2 2 4      3   2     4
+--R       6a b x  + 20a b x  + 10a b x  - 5a
+--R  /
+--R         3
+--R     5b x  + 5a x
+--R                                                    Type: Expression(Integer)
+--E 924
+
+--S 925 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      2 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 925
+
+)clear all
+
+--S 926 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^3
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              3
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 926
+
+--S 927 of 1370
+r0:=1/4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^2-3/2*a^3*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^2*(a+b*x^2))+3/4*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^2+3*a^2*b*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R       2   2          3 6       2 4     2   2     3  | 2 4         2    2
+--R   (12a b x log(x) + b x  + 6a b x  + 9a b x  - 2a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    4       2
+--R                                4b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 927
+
+--S 928 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2   2          3 6       2 4     3
+--R        12a b x log(x) + b x  + 6a b x  - 2a
+--R   (3)  -------------------------------------
+--R                           2
+--R                         4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 928
+
+--S 929 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                           +-------------------+
+--R             2   2          3 6       2 4     2   2     3  | 2 4         2    2
+--R       (- 12a b x log(x) - b x  - 6a b x  - 9a b x  + 2a )\|b x  + 2a b x  + a
+--R     + 
+--R           2 2 4      3   2           4 8       3 6     2 2 4     3   2     4
+--R       (12a b x  + 12a b x )log(x) + b x  + 7a b x  + 6a b x  - 2a b x  - 2a
+--R  /
+--R         4       2
+--R     4b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 929
+
+--S 930 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      3 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 930
+
+)clear all
+
+--S 931 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^4
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              4
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 931
+
+--S 932 of 1370
+r0:=-7/3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^3+8/3*b^2*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/3*a*b^2*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+2*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3
+--R 
+--R
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 9a b x  - 9a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------
+--R                                5       3
+--R                            3b x  + 3a x
+--R                                                    Type: Expression(Integer)
+--E 932
+
+--S 933 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        b x  + 9a b x  - 9a b x  - a
+--R   (3)  -----------------------------
+--R                       3
+--R                     3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 933
+
+--S 934 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +-------------------+
+--R           3 6       2 4     2   2    3  | 2 4         2    2     4 8        3 6
+--R       (- b x  - 9a b x  + 9a b x  + a )\|b x  + 2a b x  + a   + b x  + 10a b x
+--R     + 
+--R            3   2    4
+--R       - 10a b x  - a
+--R  /
+--R         5       3
+--R     3b x  + 3a x
+--R                                                    Type: Expression(Integer)
+--E 934
+
+--S 935 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      4 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 935
+
+)clear all
+
+--S 936 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^5
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              5
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 936
+
+--S 937 of 1370
+r0:=-(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^4+3/2*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+3/4*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^4+3*a*b^2*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R         2 4           3 6       2 4     2   2    3  | 2 4         2    2
+--R   (12a b x log(x) + 2b x  - 3a b x  - 6a b x  - a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    6       4
+--R                                4b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 937
+
+--S 938 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 4           3 6     2   2    3
+--R        12a b x log(x) + 2b x  - 6a b x  - a
+--R   (3)  -------------------------------------
+--R                           4
+--R                         4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 938
+
+--S 939 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                           +-------------------+
+--R               2 4           3 6       2 4     2   2    3  | 2 4         2    2
+--R       (- 12a b x log(x) - 2b x  + 3a b x  + 6a b x  + a )\|b x  + 2a b x  + a
+--R     + 
+--R             3 6      2 2 4            4 8       3 6     2 2 4     3   2    4
+--R       (12a b x  + 12a b x )log(x) + 2b x  + 2a b x  - 6a b x  - 7a b x  - a
+--R  /
+--R         6       4
+--R     4b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 939
+
+--S 940 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      5 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 940
+
+)clear all
+
+--S 941 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^6
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              6
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 941
+
+--S 942 of 1370
+r0:=-3/5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^5+8/5*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x-16/5*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x*(a+b*x^2))+2/5*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^5
+--R 
+--R
+--R                                          +-------------------+
+--R           3 6        2 4     2   2    3  | 2 4         2    2
+--R        (5b x  - 15a b x  - 5a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------
+--R                                 7       5
+--R                             5b x  + 5a x
+--R                                                    Type: Expression(Integer)
+--E 942
+
+--S 943 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3 6        2 4     2   2    3
+--R        5b x  - 15a b x  - 5a b x  - a
+--R   (3)  -------------------------------
+--R                        5
+--R                      5x
+--R                                         Type: Union(Expression(Integer),...)
+--E 943
+
+--S 944 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +-------------------+
+--R            3 6        2 4     2   2    3  | 2 4         2    2      4 8
+--R       (- 5b x  + 15a b x  + 5a b x  + a )\|b x  + 2a b x  + a   + 5b x
+--R     + 
+--R              3 6      2 2 4     3   2    4
+--R       - 10a b x  - 20a b x  - 6a b x  - a
+--R  /
+--R         7       5
+--R     5b x  + 5a x
+--R                                                    Type: Expression(Integer)
+--E 944
+
+--S 945 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      6 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 945
+
+)clear all
+
+--S 946 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^7
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              7
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 946
+
+--S 947 of 1370
+r0:=-5/12*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^6-1/2*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^2*(a+b*x^2))+1/4*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^6+b^3*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R       3 6           3 6        2 4     2   2     3  | 2 4         2    2
+--R   (12b x log(x) - 5b x  - 18a b x  - 9a b x  - 2a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    8        6
+--R                               12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 947
+
+--S 948 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 6              2 4     2   2     3
+--R        12b x log(x) - 18a b x  - 9a b x  - 2a
+--R   (3)  ---------------------------------------
+--R                             6
+--R                          12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 948
+
+--S 949 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                           +-------------------+
+--R             3 6           3 6        2 4     2   2     3  | 2 4         2    2
+--R       (- 12b x log(x) + 5b x  + 18a b x  + 9a b x  + 2a )\|b x  + 2a b x  + a
+--R     + 
+--R           4 8        3 6               3 6      2 2 4      3   2     4
+--R       (12b x  + 12a b x )log(x) - 18a b x  - 27a b x  - 11a b x  - 2a
+--R  /
+--R          8        6
+--R     12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 949
+
+--S 950 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      7 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 950
+
+)clear all
+
+--S 951 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^8
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              8
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 951
+
+--S 952 of 1370
+r0:=-11/35*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^7-24/35*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3+16/35*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^3*(a+b*x^2))+6/35*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^7
+--R 
+--R
+--R                                               +-------------------+
+--R              3 6        2 4      2   2     3  | 2 4         2    2
+--R        (- 35b x  - 35a b x  - 21a b x  - 5a )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------
+--R                                    9        7
+--R                               35b x  + 35a x
+--R                                                    Type: Expression(Integer)
+--E 952
+
+--S 953 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 6        2 4      2   2     3
+--R        - 35b x  - 35a b x  - 21a b x  - 5a
+--R   (3)  ------------------------------------
+--R                           7
+--R                        35x
+--R                                         Type: Union(Expression(Integer),...)
+--E 953
+
+--S 954 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +-------------------+
+--R           3 6        2 4      2   2     3  | 2 4         2    2       4 8
+--R       (35b x  + 35a b x  + 21a b x  + 5a )\|b x  + 2a b x  + a   - 35b x
+--R     + 
+--R              3 6      2 2 4      3   2     4
+--R       - 70a b x  - 56a b x  - 26a b x  - 5a
+--R  /
+--R          9        7
+--R     35b x  + 35a x
+--R                                                    Type: Expression(Integer)
+--E 954
+
+--S 955 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      8 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 955
+
+)clear all
+
+--S 956 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^9
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              9
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 1370
+r0:=-1/8*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(a*x^8)
+--R 
+--R
+--R                                          +-------------------+
+--R            3 6       2 4     2   2    3  | 2 4         2    2
+--R        (- b x  - 3a b x  - 3a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------
+--R                                     8
+--R                                 8a x
+--R                                                    Type: Expression(Integer)
+--E 957
+
+--S 958 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 6       2 4     2   2    3
+--R        - 4b x  - 6a b x  - 4a b x  - a
+--R   (3)  --------------------------------
+--R                         8
+--R                       8x
+--R                                         Type: Union(Expression(Integer),...)
+--E 958
+
+--S 959 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2        3 6     2 2 4
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - 4a b x  - 6a b x
+--R     + 
+--R           3   2    4
+--R       - 4a b x  - a
+--R  /
+--R         8
+--R     8a x
+--R                                                    Type: Expression(Integer)
+--E 959
+
+--S 960 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      9 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 960
+
+)clear all
+
+--S 961 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^10
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             10
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 961
+
+--S 962 of 1370
+r0:=-13/63*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^9-8/63*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^5+16/315*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^5*(a+b*x^2))+2/21*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^9
+--R 
+--R
+--R                                                   +-------------------+
+--R               3 6         2 4       2   2      3  | 2 4         2    2
+--R        (- 105b x  - 189a b x  - 135a b x  - 35a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                     11         9
+--R                               315b x   + 315a x
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3 6         2 4       2   2      3
+--R        - 105b x  - 189a b x  - 135a b x  - 35a
+--R   (3)  ----------------------------------------
+--R                              9
+--R                          315x
+--R                                         Type: Union(Expression(Integer),...)
+--E 963
+
+--S 964 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                +-------------------+
+--R            3 6         2 4       2   2      3  | 2 4         2    2        4 8
+--R       (105b x  + 189a b x  + 135a b x  + 35a )\|b x  + 2a b x  + a   - 105b x
+--R     + 
+--R               3 6       2 2 4       3   2      4
+--R       - 294a b x  - 324a b x  - 170a b x  - 35a
+--R  /
+--R           11         9
+--R     315b x   + 315a x
+--R                                                    Type: Expression(Integer)
+--E 964
+
+--S 965 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      10 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 965
+
+)clear all
+
+--S 966 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^11
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             11
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 966
+
+--S 967 of 1370
+r0:=-1/8*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(a*x^10)+_
+    1/40*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a^2*x^10)
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 8      3 6     2 2 4      3   2     4  | 2 4         2    2
+--R        (b x  - a b x  - 9a b x  - 11a b x  - 4a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                        2 10
+--R                                     40a x
+--R                                                    Type: Expression(Integer)
+--E 967
+
+--S 968 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 6        2 4      2   2     3
+--R        - 10b x  - 20a b x  - 15a b x  - 4a
+--R   (3)  ------------------------------------
+--R                           10
+--R                        40x
+--R                                         Type: Union(Expression(Integer),...)
+--E 968
+
+--S 969 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +-------------------+
+--R           4 8      3 6     2 2 4      3   2     4  | 2 4         2    2
+--R       (- b x  + a b x  + 9a b x  + 11a b x  + 4a )\|b x  + 2a b x  + a
+--R     + 
+--R            2 3 6      3 2 4      4   2     5
+--R       - 10a b x  - 20a b x  - 15a b x  - 4a
+--R  /
+--R        2 10
+--R     40a x
+--R                                                    Type: Expression(Integer)
+--E 969
+
+--S 970 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      11 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 970
+
+)clear all
+
+--S 971 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^12
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             12
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 971
+
+--S 972 of 1370
+r0:=-5/33*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^11-8/165*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^7+16/1155*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^7*(a+b*x^2))+2/33*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^11
+--R 
+--R
+--R                                                    +-------------------+
+--R               3 6         2 4       2   2       3  | 2 4         2    2
+--R        (- 231b x  - 495a b x  - 385a b x  - 105a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------------
+--R                                     13          11
+--R                              1155b x   + 1155a x
+--R                                                    Type: Expression(Integer)
+--E 972
+
+--S 973 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3 6         2 4       2   2       3
+--R        - 231b x  - 495a b x  - 385a b x  - 105a
+--R   (3)  -----------------------------------------
+--R                              11
+--R                         1155x
+--R                                         Type: Union(Expression(Integer),...)
+--E 973
+
+--S 974 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +-------------------+
+--R            3 6         2 4       2   2       3  | 2 4         2    2        4 8
+--R       (231b x  + 495a b x  + 385a b x  + 105a )\|b x  + 2a b x  + a   - 231b x
+--R     + 
+--R               3 6       2 2 4       3   2       4
+--R       - 726a b x  - 880a b x  - 490a b x  - 105a
+--R  /
+--R            13          11
+--R     1155b x   + 1155a x
+--R                                                    Type: Expression(Integer)
+--E 974
+
+--S 975 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      12 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 975
+
+)clear all
+
+--S 976 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^13
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             13
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 976
+
+--S 977 of 1370
+r0:=-1/12*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(a*x^12)+_
+    1/24*b*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(a^2*x^10)-_
+    1/120*b*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a^3*x^10)
+--R 
+--R
+--R   (2)
+--R           5 10      4 8    2 3 6      3 2 4      4   2      5
+--R       (- b x   + a b x  - a b x  - 19a b x  - 26a b x  - 10a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         3 12
+--R     120a x
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 6        2 4      2   2      3
+--R        - 20b x  - 45a b x  - 36a b x  - 10a
+--R   (3)  -------------------------------------
+--R                            12
+--R                        120x
+--R                                         Type: Union(Expression(Integer),...)
+--E 978
+
+--S 979 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           5 10      4 8    2 3 6      3 2 4      4   2      5
+--R         (b x   - a b x  + a b x  + 19a b x  + 26a b x  + 10a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            3 3 6      4 2 4      5   2      6
+--R       - 20a b x  - 45a b x  - 36a b x  - 10a
+--R  /
+--R         3 12
+--R     120a x
+--R                                                    Type: Expression(Integer)
+--E 979
+
+--S 980 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      13 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 980
+
+)clear all
+
+--S 981 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^14
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             14
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 981
+
+--S 982 of 1370
+r0:=-17/143*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^13-24/1001*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^9+16/3003*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^9*(a+b*x^2))+6/143*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^13
+--R 
+--R
+--R                                                     +-------------------+
+--R               3 6          2 4       2   2       3  | 2 4         2    2
+--R        (- 429b x  - 1001a b x  - 819a b x  - 231a )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------------
+--R                                      15          13
+--R                               3003b x   + 3003a x
+--R                                                    Type: Expression(Integer)
+--E 982
+
+--S 983 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3 6          2 4       2   2       3
+--R        - 429b x  - 1001a b x  - 819a b x  - 231a
+--R   (3)  ------------------------------------------
+--R                               13
+--R                          3003x
+--R                                         Type: Union(Expression(Integer),...)
+--E 983
+
+--S 984 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                  +-------------------+
+--R            3 6          2 4       2   2       3  | 2 4         2    2
+--R       (429b x  + 1001a b x  + 819a b x  + 231a )\|b x  + 2a b x  + a
+--R     + 
+--R             4 8          3 6        2 2 4        3   2       4
+--R       - 429b x  - 1430a b x  - 1820a b x  - 1050a b x  - 231a
+--R  /
+--R            15          13
+--R     3003b x   + 3003a x
+--R                                                    Type: Expression(Integer)
+--E 984
+
+--S 985 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      14 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 985
+
+)clear all
+
+--S 986 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^15
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             15
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 986
+
+--S 987 of 1370
+r0:=-3/28*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^14-1/56*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^10+1/280*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^10*(a+b*x^2))+1/28*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^14
+--R 
+--R
+--R                                                +-------------------+
+--R              3 6        2 4      2   2      3  | 2 4         2    2
+--R        (- 35b x  - 84a b x  - 70a b x  - 20a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------------
+--R                                   16         14
+--R                             280b x   + 280a x
+--R                                                    Type: Expression(Integer)
+--E 987
+
+--S 988 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 6        2 4      2   2      3
+--R        - 35b x  - 84a b x  - 70a b x  - 20a
+--R   (3)  -------------------------------------
+--R                            14
+--R                        280x
+--R                                         Type: Union(Expression(Integer),...)
+--E 988
+
+--S 989 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +-------------------+
+--R           3 6        2 4      2   2      3  | 2 4         2    2       4 8
+--R       (35b x  + 84a b x  + 70a b x  + 20a )\|b x  + 2a b x  + a   - 35b x
+--R     + 
+--R               3 6       2 2 4      3   2      4
+--R       - 119a b x  - 154a b x  - 90a b x  - 20a
+--R  /
+--R           16         14
+--R     280b x   + 280a x
+--R                                                    Type: Expression(Integer)
+--E 989
+
+--S 990 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      15 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 990
+
+)clear all
+
+--S 991 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^16
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             16
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 991
+
+--S 992 of 1370
+r0:=-19/195*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^15-8/585*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^11+16/6435*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^11*(a+b*x^2))+2/65*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^15
+--R 
+--R
+--R                                                      +-------------------+
+--R               3 6          2 4        2   2       3  | 2 4         2    2
+--R        (- 715b x  - 1755a b x  - 1485a b x  - 429a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------------------
+--R                                      17          15
+--R                               6435b x   + 6435a x
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3 6          2 4        2   2       3
+--R        - 715b x  - 1755a b x  - 1485a b x  - 429a
+--R   (3)  -------------------------------------------
+--R                               15
+--R                          6435x
+--R                                         Type: Union(Expression(Integer),...)
+--E 993
+
+--S 994 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                   +-------------------+
+--R            3 6          2 4        2   2       3  | 2 4         2    2
+--R       (715b x  + 1755a b x  + 1485a b x  + 429a )\|b x  + 2a b x  + a
+--R     + 
+--R             4 8          3 6        2 2 4        3   2       4
+--R       - 715b x  - 2470a b x  - 3240a b x  - 1914a b x  - 429a
+--R  /
+--R            17          15
+--R     6435b x   + 6435a x
+--R                                                    Type: Expression(Integer)
+--E 994
+
+--S 995 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      16 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 995
+
+)clear all
+
+--S 996 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^17
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             17
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 996
+
+--S 997 of 1370
+r0:=-5/56*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^16-3/280*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^12+1/560*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^12*(a+b*x^2))+3/112*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^16
+--R 
+--R
+--R                                                  +-------------------+
+--R              3 6         2 4       2   2      3  | 2 4         2    2
+--R        (- 56b x  - 140a b x  - 120a b x  - 35a )\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------------------------------
+--R                                    18         16
+--R                              560b x   + 560a x
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 6         2 4       2   2      3
+--R        - 56b x  - 140a b x  - 120a b x  - 35a
+--R   (3)  ---------------------------------------
+--R                             16
+--R                         560x
+--R                                         Type: Union(Expression(Integer),...)
+--E 998
+
+--S 999 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +-------------------+
+--R           3 6         2 4       2   2      3  | 2 4         2    2       4 8
+--R       (56b x  + 140a b x  + 120a b x  + 35a )\|b x  + 2a b x  + a   - 56b x
+--R     + 
+--R               3 6       2 2 4       3   2      4
+--R       - 196a b x  - 260a b x  - 155a b x  - 35a
+--R  /
+--R           18         16
+--R     560b x   + 560a x
+--R                                                    Type: Expression(Integer)
+--E 999
+
+--S 1000 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      17 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+)clear all
+
+--S 1001 of 1370
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                    +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  m | 2 4         2    2
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a )x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1001
+
+--S 1002 of 1370
+r0:=80*a^2*x^(1+m)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/((7+m)*(9+m)*(11+m))+_
+    10*a*x^(1+m)*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(99+20*m+m^2)+_
+    x^(1+m)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(11+m)+1920*a^4*x^(1+m)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/((3+m)*(5+m)*(7+m)*(9+m)*(11+m))+_
+    3840*a^5*x^(1+m)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/((5+m)*(7+m)*_
+    (9+m)*(11+m)*(3+4*m+m^2)*(a+b*x^2))+480*a^3*x^(1+m)*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/((5+m)*(7+m)*(9+m)*(11+m))
+--R 
+--R
+--R   (2)
+--R           5 5      5 4       5 3       5 2        5        5  10
+--R         (b m  + 25b m  + 230b m  + 950b m  + 1689b m + 945b )x
+--R       + 
+--R                   4 5         4 4          4 3          4 2           4
+--R               5a b m  + 135a b m  + 1310a b m  + 5610a b m  + 10205a b m
+--R             + 
+--R                      4
+--R               5775a b
+--R        *
+--R            8
+--R           x
+--R       + 
+--R                2 3 5       2 3 4        2 3 3         2 3 2         2 3
+--R             10a b m  + 290a b m  + 3020a b m  + 13660a b m  + 25770a b m
+--R           + 
+--R                   2 3
+--R             14850a b
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                3 2 5       3 2 4        3 2 3         3 2 2         3 2
+--R             10a b m  + 310a b m  + 3500a b m  + 17300a b m  + 34890a b m
+--R           + 
+--R                   3 2
+--R             20790a b
+--R        *
+--R            4
+--R           x
+--R       + 
+--R               4   5       4   4        4   3         4   2         4
+--R             5a b m  + 165a b m  + 2030a b m  + 11310a b m  + 26765a b m
+--R           + 
+--R                   4
+--R             17325a b
+--R        *
+--R            2
+--R           x
+--R       + 
+--R          5 5      5 4       5 3        5 2        5          5
+--R         a m  + 35a m  + 470a m  + 3010a m  + 9129a m + 10395a
+--R    *
+--R              +-------------------+
+--R        m + 1 | 2 4         2    2
+--R       x     \|b x  + 2a b x  + a
+--R  /
+--R           6        5         4          3           2                      2
+--R       (b m  + 36b m  + 505b m  + 3480b m  + 12139b m  + 19524b m + 10395b)x
+--R     + 
+--R          6        5         4          3           2
+--R       a m  + 36a m  + 505a m  + 3480a m  + 12139a m  + 19524a m + 10395a
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+--S 1003 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           5 5      5 4       5 3       5 2        5        5  11
+--R         (b m  + 25b m  + 230b m  + 950b m  + 1689b m + 945b )x
+--R       + 
+--R                   4 5         4 4          4 3          4 2           4
+--R               5a b m  + 135a b m  + 1310a b m  + 5610a b m  + 10205a b m
+--R             + 
+--R                      4
+--R               5775a b
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                2 3 5       2 3 4        2 3 3         2 3 2         2 3
+--R             10a b m  + 290a b m  + 3020a b m  + 13660a b m  + 25770a b m
+--R           + 
+--R                   2 3
+--R             14850a b
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                3 2 5       3 2 4        3 2 3         3 2 2         3 2
+--R             10a b m  + 310a b m  + 3500a b m  + 17300a b m  + 34890a b m
+--R           + 
+--R                   3 2
+--R             20790a b
+--R        *
+--R            5
+--R           x
+--R       + 
+--R               4   5       4   4        4   3         4   2         4
+--R             5a b m  + 165a b m  + 2030a b m  + 11310a b m  + 26765a b m
+--R           + 
+--R                   4
+--R             17325a b
+--R        *
+--R            3
+--R           x
+--R       + 
+--R           5 5      5 4       5 3        5 2        5          5
+--R         (a m  + 35a m  + 470a m  + 3010a m  + 9129a m + 10395a )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      6      5       4        3         2
+--R     m  + 36m  + 505m  + 3480m  + 12139m  + 19524m + 10395
+--R                                         Type: Union(Expression(Integer),...)
+--E 1003
+
+--S 1004 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             6 5      6 4       6 3       6 2        6        6  13
+--R           (b m  + 25b m  + 230b m  + 950b m  + 1689b m + 945b )x
+--R         + 
+--R                   5 5         5 4          5 3          5 2           5
+--R               6a b m  + 160a b m  + 1540a b m  + 6560a b m  + 11894a b m
+--R             + 
+--R                      5
+--R               6720a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                  2 4 5       2 4 4        2 4 3         2 4 2         2 4
+--R               15a b m  + 425a b m  + 4330a b m  + 19270a b m  + 35975a b m
+--R             + 
+--R                     2 4
+--R               20625a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                  3 3 5       3 3 4        3 3 3         3 3 2         3 3
+--R               20a b m  + 600a b m  + 6520a b m  + 30960a b m  + 60660a b m
+--R             + 
+--R                     3 3
+--R               35640a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                  4 2 5       4 2 4        4 2 3         4 2 2         4 2
+--R               15a b m  + 475a b m  + 5530a b m  + 28610a b m  + 61655a b m
+--R             + 
+--R                     4 2
+--R               38115a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                 5   5       5   4        5   3         5   2         5
+--R               6a b m  + 200a b m  + 2500a b m  + 14320a b m  + 35894a b m
+--R             + 
+--R                     5
+--R               27720a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R             6 5      6 4       6 3        6 2        6          6
+--R           (a m  + 35a m  + 470a m  + 3010a m  + 9129a m + 10395a )x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R               5 5      5 4       5 3       5 2        5        5  10
+--R           (- b m  - 25b m  - 230b m  - 950b m  - 1689b m - 945b )x
+--R         + 
+--R                     4 5         4 4          4 3          4 2           4
+--R               - 5a b m  - 135a b m  - 1310a b m  - 5610a b m  - 10205a b m
+--R             + 
+--R                        4
+--R               - 5775a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    2 3 5       2 3 4        2 3 3         2 3 2         2 3
+--R               - 10a b m  - 290a b m  - 3020a b m  - 13660a b m  - 25770a b m
+--R             + 
+--R                       2 3
+--R               - 14850a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                    3 2 5       3 2 4        3 2 3         3 2 2         3 2
+--R               - 10a b m  - 310a b m  - 3500a b m  - 17300a b m  - 34890a b m
+--R             + 
+--R                       3 2
+--R               - 20790a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   4   5       4   4        4   3         4   2         4
+--R               - 5a b m  - 165a b m  - 2030a b m  - 11310a b m  - 26765a b m
+--R             + 
+--R                       4
+--R               - 17325a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R              5 5      5 4       5 3        5 2        5          5
+--R           - a m  - 35a m  - 470a m  - 3010a m  - 9129a m - 10395a
+--R      *
+--R                +-------------------+
+--R          m + 1 | 2 4         2    2
+--R         x     \|b x  + 2a b x  + a
+--R  /
+--R           6        5         4          3           2                      2
+--R       (b m  + 36b m  + 505b m  + 3480b m  + 12139b m  + 19524b m + 10395b)x
+--R     + 
+--R          6        5         4          3           2
+--R       a m  + 36a m  + 505a m  + 3480a m  + 12139a m  + 19524a m + 10395a
+--R                                                    Type: Expression(Integer)
+--E 1004
+
+--S 1005 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R             5 5      5 4       5 3        5 2        5          5  10
+--R           (b m  + 35b m  + 470b m  + 3010b m  + 9129b m + 10395b )x
+--R         + 
+--R                   4 5         4 4          4 3           4 2           4
+--R               5a b m  + 175a b m  + 2350a b m  + 15050a b m  + 45645a b m
+--R             + 
+--R                       4
+--R               51975a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                  2 3 5       2 3 4        2 3 3         2 3 2         2 3
+--R               10a b m  + 350a b m  + 4700a b m  + 30100a b m  + 91290a b m
+--R             + 
+--R                      2 3
+--R               103950a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                  3 2 5       3 2 4        3 2 3         3 2 2         3 2
+--R               10a b m  + 350a b m  + 4700a b m  + 30100a b m  + 91290a b m
+--R             + 
+--R                      3 2
+--R               103950a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                 4   5       4   4        4   3         4   2         4
+--R               5a b m  + 175a b m  + 2350a b m  + 15050a b m  + 45645a b m
+--R             + 
+--R                     4
+--R               51975a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R            5 5      5 4       5 3        5 2        5          5
+--R           a m  + 35a m  + 470a m  + 3010a m  + 9129a m + 10395a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2   m log(x)
+--R         \|b x  + 2a b x  + a  %e
+--R     + 
+--R                 6 4       6 3        6 2        6         6  11
+--R           (- 10b m  - 240b m  - 2060b m  - 7440b m - 9450b )x
+--R         + 
+--R                   5 4          5 3           5 2           5            5  9
+--R           (- 50a b m  - 1280a b m  - 11500a b m  - 42880a b m - 55650a b )x
+--R         + 
+--R                  2 4 4        2 4 3         2 4 2          2 4           2 4  7
+--R           (- 100a b m  - 2720a b m  - 25880a b m  - 100960a b m - 135300a b )x
+--R         + 
+--R                  3 3 4        3 3 3         3 3 2          3 3           3 3  5
+--R           (- 100a b m  - 2880a b m  - 29240a b m  - 121920a b m - 172260a b )x
+--R         + 
+--R                 4 2 4        4 2 3         4 2 2         4 2           4 2  3
+--R           (- 50a b m  - 1520a b m  - 16540a b m  - 75280a b m - 117810a b )x
+--R         + 
+--R                 5   4       5   3        5   2         5            5
+--R           (- 10a b m  - 320a b m  - 3740a b m  - 18880a b m - 34650a b)x
+--R      *
+--R          m + 1
+--R         x
+--R     + 
+--R               6 5      6 4       6 3       6 2        6        6  12
+--R           (- b m  - 25b m  - 230b m  - 950b m  - 1689b m - 945b )x
+--R         + 
+--R                     5 5         5 4          5 3          5 2           5
+--R               - 6a b m  - 160a b m  - 1540a b m  - 6560a b m  - 11894a b m
+--R             + 
+--R                        5
+--R               - 6720a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                    2 4 5       2 4 4        2 4 3         2 4 2         2 4
+--R               - 15a b m  - 425a b m  - 4330a b m  - 19270a b m  - 35975a b m
+--R             + 
+--R                       2 4
+--R               - 20625a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    3 3 5       3 3 4        3 3 3         3 3 2         3 3
+--R               - 20a b m  - 600a b m  - 6520a b m  - 30960a b m  - 60660a b m
+--R             + 
+--R                       3 3
+--R               - 35640a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                    4 2 5       4 2 4        4 2 3         4 2 2         4 2
+--R               - 15a b m  - 475a b m  - 5530a b m  - 28610a b m  - 61655a b m
+--R             + 
+--R                       4 2
+--R               - 38115a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   5   5       5   4        5   3         5   2         5
+--R               - 6a b m  - 200a b m  - 2500a b m  - 14320a b m  - 35894a b m
+--R             + 
+--R                       5
+--R               - 27720a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R              6 5      6 4       6 3        6 2        6          6
+--R           - a m  - 35a m  - 470a m  - 3010a m  - 9129a m - 10395a
+--R      *
+--R          m
+--R         x
+--R  /
+--R                                                  +-------------------+
+--R       5      4       3        2                  | 2 4         2    2
+--R     (m  + 35m  + 470m  + 3010m  + 9129m + 10395)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1005
+
+)clear all
+
+--S 1006 of 1370
+t0:=x^13*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 21       3 19     2 2 17     3   15    4 13  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1006
+
+--S 1007 of 1370
+r0:=1/132*a^2*x^14*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+5/264*a*x^14*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/24*x^14*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)+1/1584*a^4*x^14*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+    1/11088*a^5*x^14*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+    1/396*a^3*x^14*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R             5 24          4 22        2 3 20        3 2 18        4   16
+--R         462b x   + 2520a b x   + 5544a b x   + 6160a b x   + 3465a b x
+--R       + 
+--R             5 14
+--R         792a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             2
+--R     11088b x  + 11088a
+--R                                                    Type: Expression(Integer)
+--E 1007
+
+--S 1008 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       5 24          4 22        2 3 20        3 2 18        4   16       5 14
+--R   462b x   + 2520a b x   + 5544a b x   + 6160a b x   + 3465a b x   + 792a x
+--R   ---------------------------------------------------------------------------
+--R                                      11088
+--R                                         Type: Union(Expression(Integer),...)
+--E 1008
+
+--S 1009 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 24          4 22        2 3 20        3 2 18        4   16
+--R           - 462b x   - 2520a b x   - 5544a b x   - 6160a b x   - 3465a b x
+--R         + 
+--R                 5 14
+--R           - 792a x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R           6 26          5 24        2 4 22         3 3 20        4 2 18
+--R       462b x   + 2982a b x   + 8064a b x   + 11704a b x   + 9625a b x
+--R     + 
+--R            5   16       6 14
+--R       4257a b x   + 792a x
+--R  /
+--R             2
+--R     11088b x  + 11088a
+--R                                                    Type: Expression(Integer)
+--E 1009
+
+--S 1010 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 23       4 21      2 3 19      3 2 17     4   15    5 13
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x  )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 25       5 23      2 4 21      3 3 19      4 2 17     5   15    6 13
+--R     - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1010
+
+)clear all
+
+--S 1011 of 1370
+t0:=x^12*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 20       3 18     2 2 16     3   14    4 12  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1011
+
+--S 1012 of 1370
+r0:=80/9177*a^2*x^13*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/483*a*x^13*_
+    (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/23*x^13*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(5/2)+128/156009*a^4*x^13*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/2028117*a^5*x^13*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+160/52003*a^3*x^13*_
+    (a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R               5 23            4 21           2 3 19           3 2 17
+--R         88179b x   + 482885a b x   + 1067430a b x   + 1193010a b x
+--R       + 
+--R                4   15          5 13
+--R         676039a b x   + 156009a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R               2
+--R     2028117b x  + 2028117a
+--R                                                    Type: Expression(Integer)
+--E 1012
+
+--S 1013 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 23            4 21           2 3 19           3 2 17
+--R       88179b x   + 482885a b x   + 1067430a b x   + 1193010a b x
+--R     + 
+--R              4   15          5 13
+--R       676039a b x   + 156009a x
+--R  /
+--R     2028117
+--R                                         Type: Union(Expression(Integer),...)
+--E 1013
+
+--S 1014 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 23            4 21           2 3 19           3 2 17
+--R           - 88179b x   - 482885a b x   - 1067430a b x   - 1193010a b x
+--R         + 
+--R                    4   15          5 13
+--R           - 676039a b x   - 156009a x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 25            5 23           2 4 21           3 3 19
+--R       88179b x   + 571064a b x   + 1550315a b x   + 2260440a b x
+--R     + 
+--R               4 2 17          5   15          6 13
+--R       1869049a b x   + 832048a b x   + 156009a x
+--R  /
+--R               2
+--R     2028117b x  + 2028117a
+--R                                                    Type: Expression(Integer)
+--E 1014
+
+--S 1015 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 22       4 20      2 3 18      3 2 16     4   14    5 12
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x  )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 24       5 22      2 4 20      3 3 18      4 2 16     5   14    6 12
+--R     - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1015
+
+)clear all
+
+--S 1016 of 1370
+t0:=x^11*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 19       3 17     2 2 15     3   13    4 11  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1016
+
+--S 1017 of 1370
+r0:=1/99*a^2*x^12*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/44*a*x^12*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/22*x^12*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    1/924*a^4*x^12*sqrt(a^2+2*a*b*x^2+b^2*x^4)+1/5544*a^5*x^12*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+1/264*a^3*x^12*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R             5 22          4 20        2 3 18        3 2 16        4   14
+--R         252b x   + 1386a b x   + 3080a b x   + 3465a b x   + 1980a b x
+--R       + 
+--R             5 12
+--R         462a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            2
+--R     5544b x  + 5544a
+--R                                                    Type: Expression(Integer)
+--E 1017
+
+--S 1018 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       5 22          4 20        2 3 18        3 2 16        4   14       5 12
+--R   252b x   + 1386a b x   + 3080a b x   + 3465a b x   + 1980a b x   + 462a x
+--R   ---------------------------------------------------------------------------
+--R                                       5544
+--R                                         Type: Union(Expression(Integer),...)
+--E 1018
+
+--S 1019 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 22          4 20        2 3 18        3 2 16        4   14
+--R           - 252b x   - 1386a b x   - 3080a b x   - 3465a b x   - 1980a b x
+--R         + 
+--R                 5 12
+--R           - 462a x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R           6 24          5 22        2 4 20        3 3 18        4 2 16
+--R       252b x   + 1638a b x   + 4466a b x   + 6545a b x   + 5445a b x
+--R     + 
+--R            5   14       6 12
+--R       2442a b x   + 462a x
+--R  /
+--R            2
+--R     5544b x  + 5544a
+--R                                                    Type: Expression(Integer)
+--E 1019
+
+--S 1020 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 21       4 19      2 3 17      3 2 15     4   13    5 11
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x  )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 23       5 21      2 4 19      3 3 17      4 2 15     5   13    6 11
+--R     - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1020
+
+)clear all
+
+--S 1021 of 1370
+t0:=x^10*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 18       3 16     2 2 14     3   12    4 10  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1021
+
+--S 1022 of 1370
+r0:=80/6783*a^2*x^11*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/399*a*x^11*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/21*x^11*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/88179*a^4*x^11*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/969969*a^5*_
+    x^11*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/6783*a^3*_
+    x^11*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R               5 21            4 19          2 3 17          3 2 15
+--R         46189b x   + 255255a b x   + 570570a b x   + 646646a b x
+--R       + 
+--R                4   13         5 11
+--R         373065a b x   + 88179a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     969969b x  + 969969a
+--R                                                    Type: Expression(Integer)
+--E 1022
+
+--S 1023 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 21            4 19          2 3 17          3 2 15
+--R       46189b x   + 255255a b x   + 570570a b x   + 646646a b x
+--R     + 
+--R              4   13         5 11
+--R       373065a b x   + 88179a x
+--R  /
+--R     969969
+--R                                         Type: Union(Expression(Integer),...)
+--E 1023
+
+--S 1024 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 21            4 19          2 3 17          3 2 15
+--R           - 46189b x   - 255255a b x   - 570570a b x   - 646646a b x
+--R         + 
+--R                    4   13         5 11
+--R           - 373065a b x   - 88179a x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 23            5 21          2 4 19           3 3 17
+--R       46189b x   + 301444a b x   + 825825a b x   + 1217216a b x
+--R     + 
+--R               4 2 15          5   13         6 11
+--R       1019711a b x   + 461244a b x   + 88179a x
+--R  /
+--R              2
+--R     969969b x  + 969969a
+--R                                                    Type: Expression(Integer)
+--E 1024
+
+--S 1025 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 20       4 18      2 3 16      3 2 14     4   12    5 10
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x  )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 22       5 20      2 4 18      3 3 16      4 2 14     5   12    6 10
+--R     - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1025
+
+)clear all
+
+--S 1026 of 1370
+t0:=x^9*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                        +-------------------+
+--R          4 17       3 15     2 2 13     3   11    4 9  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1026
+
+--S 1027 of 1370
+r0:=1/360*a^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^5+1/120*a^2*x^4*_
+    (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^3-1/45*a*x^6*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^2+1/20*x^8*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b-1/420*a^3*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(7/2)/b^5
+--R 
+--R
+--R   (2)
+--R             9 18         8 16        2 7 14       3 6 12       4 5 10    5 4 8
+--R         126b x   + 574a b x   + 1001a b x   + 799a b x   + 251a b x   + a b x
+--R       + 
+--R            6 3 6    7 2 4    8   2    9
+--R         - a b x  + a b x  - a b x  + a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          5
+--R     2520b
+--R                                                    Type: Expression(Integer)
+--E 1027
+
+--S 1028 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       5 20         4 18        2 3 16        3 2 14        4   12       5 10
+--R   126b x   + 700a b x   + 1575a b x   + 1800a b x   + 1050a b x   + 252a x
+--R   --------------------------------------------------------------------------
+--R                                      2520
+--R                                         Type: Union(Expression(Integer),...)
+--E 1028
+
+--S 1029 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 9 18         8 16        2 7 14       3 6 12       4 5 10
+--R           - 126b x   - 574a b x   - 1001a b x   - 799a b x   - 251a b x
+--R         + 
+--R              5 4 8    6 3 6    7 2 4    8   2    9
+--R           - a b x  + a b x  - a b x  + a b x  - a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R           10 20         9 18        2 8 16        3 7 14        4 6 12
+--R       126b  x   + 700a b x   + 1575a b x   + 1800a b x   + 1050a b x
+--R     + 
+--R           5 5 10
+--R       252a b x
+--R  /
+--R          5
+--R     2520b
+--R                                                    Type: Expression(Integer)
+--E 1029
+
+--S 1030 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 19       4 17      2 3 15      3 2 13     4   11    5 9
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 21       5 19      2 4 17      3 3 15      4 2 13     5   11    6 9
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1030
+
+)clear all
+
+--S 1031 of 1370
+t0:=x^8*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                        +-------------------+
+--R          4 16       3 14     2 2 12     3   10    4 8  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1031
+
+--S 1032 of 1370
+r0:=16/969*a^2*x^9*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/323*a*x^9*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/19*x^9*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/46189*a^4*x^9*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/415701*a^5*x^9*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/4199*a^3*x^9*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R               5 19            4 17          2 3 15          3 2 13
+--R         21879b x   + 122265a b x   + 277134a b x   + 319770a b x
+--R       + 
+--R                4   11         5 9
+--R         188955a b x   + 46189a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     415701b x  + 415701a
+--R                                                    Type: Expression(Integer)
+--E 1032
+
+--S 1033 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 19            4 17          2 3 15          3 2 13
+--R       21879b x   + 122265a b x   + 277134a b x   + 319770a b x
+--R     + 
+--R              4   11         5 9
+--R       188955a b x   + 46189a x
+--R  /
+--R     415701
+--R                                         Type: Union(Expression(Integer),...)
+--E 1033
+
+--S 1034 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 19            4 17          2 3 15          3 2 13
+--R           - 21879b x   - 122265a b x   - 277134a b x   - 319770a b x
+--R         + 
+--R                    4   11         5 9
+--R           - 188955a b x   - 46189a x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 21            5 19          2 4 17          3 3 15
+--R       21879b x   + 144144a b x   + 399399a b x   + 596904a b x
+--R     + 
+--R              4 2 13          5   11         6 9
+--R       508725a b x   + 235144a b x   + 46189a x
+--R  /
+--R              2
+--R     415701b x  + 415701a
+--R                                                    Type: Expression(Integer)
+--E 1034
+
+--S 1035 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 18       4 16      2 3 14      3 2 12     4   10    5 8
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 20       5 18      2 4 16      3 3 14      4 2 12     5   10    6 8
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1035
+
+)clear all
+
+--S 1036 of 1370
+t0:=x^7*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 15       3 13     2 2 11     3   9    4 7  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1036
+
+--S 1037 of 1370
+r0:=-1/144*a^3*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^4-1/48*a*x^4*_
+    (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^2+1/18*x^6*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b+1/168*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/b^4
+--R 
+--R
+--R   (2)
+--R            8 16         7 14       2 6 12       3 5 10       4 4 8    5 3 6
+--R         56b x   + 259a b x   + 461a b x   + 379a b x   + 125a b x  + a b x
+--R       + 
+--R            6 2 4    7   2    8
+--R         - a b x  + a b x  - a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          4
+--R     1008b
+--R                                                    Type: Expression(Integer)
+--E 1037
+
+--S 1038 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 18         4 16       2 3 14       3 2 12       4   10       5 8
+--R        56b x   + 315a b x   + 720a b x   + 840a b x   + 504a b x   + 126a x
+--R   (3)  ---------------------------------------------------------------------
+--R                                         1008
+--R                                         Type: Union(Expression(Integer),...)
+--E 1038
+
+--S 1039 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                8 16         7 14       2 6 12       3 5 10       4 4 8    5 3 6
+--R           - 56b x   - 259a b x   - 461a b x   - 379a b x   - 125a b x  - a b x
+--R         + 
+--R            6 2 4    7   2    8
+--R           a b x  - a b x  + a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          9 18         8 16       2 7 14       3 6 12       4 5 10       5 4 8
+--R       56b x   + 315a b x   + 720a b x   + 840a b x   + 504a b x   + 126a b x
+--R  /
+--R          4
+--R     1008b
+--R                                                    Type: Expression(Integer)
+--E 1039
+
+--S 1040 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 17       4 15      2 3 13      3 2 11     4   9    5 7
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 19       5 17      2 4 15      3 3 13      4 2 11     5   9    6 7
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1040
+
+)clear all
+
+--S 1041 of 1370
+t0:=x^6*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 14       3 12     2 2 10     3   8    4 6  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1041
+
+--S 1042 of 1370
+r0:=16/663*a^2*x^7*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/51*a*x^7*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/17*x^7*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/21879*a^4*x^7*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/153153*a^5*x^7*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/2431*a^3*x^7*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R              5 17           4 15          2 3 13          3 2 11         4   9
+--R         9009b x   + 51051a b x   + 117810a b x   + 139230a b x   + 85085a b x
+--R       + 
+--R               5 7
+--R         21879a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     153153b x  + 153153a
+--R                                                    Type: Expression(Integer)
+--E 1042
+
+--S 1043 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            5 17           4 15          2 3 13          3 2 11         4   9
+--R       9009b x   + 51051a b x   + 117810a b x   + 139230a b x   + 85085a b x
+--R     + 
+--R             5 7
+--R       21879a x
+--R  /
+--R     153153
+--R                                         Type: Union(Expression(Integer),...)
+--E 1043
+
+--S 1044 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 17           4 15          2 3 13          3 2 11
+--R           - 9009b x   - 51051a b x   - 117810a b x   - 139230a b x
+--R         + 
+--R                   4   9         5 7
+--R           - 85085a b x  - 21879a x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            6 19           5 17          2 4 15          3 3 13          4 2 11
+--R       9009b x   + 60060a b x   + 168861a b x   + 257040a b x   + 224315a b x
+--R     + 
+--R              5   9         6 7
+--R       106964a b x  + 21879a x
+--R  /
+--R              2
+--R     153153b x  + 153153a
+--R                                                    Type: Expression(Integer)
+--E 1044
+
+--S 1045 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 16       4 14      2 3 12      3 2 10     4   8    5 6
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 16      2 4 14      3 3 12      4 2 10     5   8    6 6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1045
+
+)clear all
+
+--S 1046 of 1370
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                      +-------------------+
+--R          4 13       3 11     2 2 9     3   7    4 5  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1046
+
+--S 1047 of 1370
+r0:=1/48*a^2*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^3+1/16*x^4*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b-1/56*a*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/b^3
+--R 
+--R
+--R   (2)
+--R            7 14        6 12       2 5 10       3 4 8      4 3 6    5 2 4
+--R         21b x   + 99a b x   + 181a b x   + 155a b x  + 55a b x  + a b x
+--R       + 
+--R            6   2    7
+--R         - a b x  + a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         3
+--R     336b
+--R                                                    Type: Expression(Integer)
+--E 1047
+
+--S 1048 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 16         4 14       2 3 12       3 2 10       4   8      5 6
+--R        21b x   + 120a b x   + 280a b x   + 336a b x   + 210a b x  + 56a x
+--R   (3)  -------------------------------------------------------------------
+--R                                        336
+--R                                         Type: Union(Expression(Integer),...)
+--E 1048
+
+--S 1049 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                7 14        6 12       2 5 10       3 4 8      4 3 6    5 2 4
+--R           - 21b x   - 99a b x   - 181a b x   - 155a b x  - 55a b x  - a b x
+--R         + 
+--R            6   2    7
+--R           a b x  - a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          8 16         7 14       2 6 12       3 5 10       4 4 8      5 3 6
+--R       21b x   + 120a b x   + 280a b x   + 336a b x   + 210a b x  + 56a b x
+--R  /
+--R         3
+--R     336b
+--R                                                    Type: Expression(Integer)
+--E 1049
+
+--S 1050 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 15       4 13      2 3 11      3 2 9     4   7    5 5
+--R         (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 17       5 15      2 4 13      3 3 11      4 2 9     5   7    6 5
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x  - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1050
+
+)clear all
+
+--S 1051 of 1370
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                      +-------------------+
+--R          4 12       3 10     2 2 8     3   6    4 4  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1051
+
+--S 1052 of 1370
+r0:=16/429*a^2*x^5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/39*a*x^5*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/15*x^5*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/9009*a^4*x^5*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/45045*a^5*x^5*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/1287*a^3*x^5*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R              5 15           4 13         2 3 11         3 2 9         4   7
+--R         3003b x   + 17325a b x   + 40950a b x   + 50050a b x  + 32175a b x
+--R       + 
+--R              5 5
+--R         9009a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             2
+--R     45045b x  + 45045a
+--R                                                    Type: Expression(Integer)
+--E 1052
+
+--S 1053 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            5 15           4 13         2 3 11         3 2 9         4   7
+--R       3003b x   + 17325a b x   + 40950a b x   + 50050a b x  + 32175a b x
+--R     + 
+--R            5 5
+--R       9009a x
+--R  /
+--R     45045
+--R                                         Type: Union(Expression(Integer),...)
+--E 1053
+
+--S 1054 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 15           4 13         2 3 11         3 2 9         4   7
+--R           - 3003b x   - 17325a b x   - 40950a b x   - 50050a b x  - 32175a b x
+--R         + 
+--R                  5 5
+--R           - 9009a x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            6 17           5 15         2 4 13         3 3 11         4 2 9
+--R       3003b x   + 20328a b x   + 58275a b x   + 91000a b x   + 82225a b x
+--R     + 
+--R             5   7        6 5
+--R       41184a b x  + 9009a x
+--R  /
+--R             2
+--R     45045b x  + 45045a
+--R                                                    Type: Expression(Integer)
+--E 1054
+
+--S 1055 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 14       4 12      2 3 10      3 2 8     4   6    5 4
+--R         (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 16       5 14      2 4 12      3 3 10      4 2 8     5   6    6 4
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x  - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1055
+
+)clear all
+
+--S 1056 of 1370
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                     +-------------------+
+--R          4 11       3 9     2 2 7     3   5    4 3  | 2 4         2    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1056
+
+--S 1057 of 1370
+r0:=-1/12*a*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^2+_
+    1/14*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/b^2
+--R 
+--R
+--R   (2)
+--R          6 12        5 10      2 4 8      3 3 6      4 2 4    5   2    6
+--R       (6b x   + 29a b x   + 55a b x  + 50a b x  + 20a b x  + a b x  - a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R        2
+--R     84b
+--R                                                    Type: Expression(Integer)
+--E 1057
+
+--S 1058 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          5 14        4 12      2 3 10       3 2 8      4   6      5 4
+--R        6b x   + 35a b x   + 84a b x   + 105a b x  + 70a b x  + 21a x
+--R   (3)  --------------------------------------------------------------
+--R                                      84
+--R                                         Type: Union(Expression(Integer),...)
+--E 1058
+
+--S 1059 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              6 12        5 10      2 4 8      3 3 6      4 2 4    5   2    6
+--R         (- 6b x   - 29a b x   - 55a b x  - 50a b x  - 20a b x  - a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R         7 14        6 12      2 5 10       3 4 8      4 3 6      5 2 4
+--R       6b x   + 35a b x   + 84a b x   + 105a b x  + 70a b x  + 21a b x
+--R  /
+--R        2
+--R     84b
+--R                                                    Type: Expression(Integer)
+--E 1059
+
+--S 1060 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 13       4 11      2 3 9      3 2 7     4   5    5 3
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 15       5 13      2 4 11      3 3 9      4 2 7     5   5    6 3
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1060
+
+)clear all
+
+--S 1061 of 1370
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                     +-------------------+
+--R          4 10       3 8     2 2 6     3   4    4 2  | 2 4         2    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1061
+
+--S 1062 of 1370
+r0:=80/1287*a^2*x^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/143*a*x^3*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/13*x^3*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/3003*a^4*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/9009*a^5*x^3*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+160/3003*a^3*x^3*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R             5 13          4 11         2 3 9         3 2 7        4   5
+--R         693b x   + 4095a b x   + 10010a b x  + 12870a b x  + 9009a b x
+--R       + 
+--R              5 3
+--R         3003a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            2
+--R     9009b x  + 9009a
+--R                                                    Type: Expression(Integer)
+--E 1062
+
+--S 1063 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       5 13          4 11         2 3 9         3 2 7        4   5        5 3
+--R   693b x   + 4095a b x   + 10010a b x  + 12870a b x  + 9009a b x  + 3003a x
+--R   --------------------------------------------------------------------------
+--R                                      9009
+--R                                         Type: Union(Expression(Integer),...)
+--E 1063
+
+--S 1064 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 13          4 11         2 3 9         3 2 7        4   5
+--R           - 693b x   - 4095a b x   - 10010a b x  - 12870a b x  - 9009a b x
+--R         + 
+--R                  5 3
+--R           - 3003a x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R           6 15          5 13         2 4 11         3 3 9         4 2 7
+--R       693b x   + 4788a b x   + 14105a b x   + 22880a b x  + 21879a b x
+--R     + 
+--R             5   5        6 3
+--R       12012a b x  + 3003a x
+--R  /
+--R            2
+--R     9009b x  + 9009a
+--R                                                    Type: Expression(Integer)
+--E 1064
+
+--S 1065 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 12       4 10      2 3 8      3 2 6     4   4    5 2
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 14       5 12      2 4 10      3 3 8      4 2 6     5   4    6 2
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1065
+
+)clear all
+
+--S 1066 of 1370
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 9       3 7     2 2 5     3   3    4   | 2 4         2    2
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1066
+
+--S 1067 of 1370
+r0:=1/12*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b
+--R 
+--R
+--R   (2)
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R   ----------------------------------------------------------------------------
+--R                                        12b
+--R                                                    Type: Expression(Integer)
+--E 1067
+
+--S 1068 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R         5 12       4 10      2 3 8      3 2 6      4   4     5 2
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a x
+--R   (3)  ---------------------------------------------------------
+--R                                    12
+--R                                         Type: Union(Expression(Integer),...)
+--E 1068
+
+--S 1069 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (- b x   - 5a b x  - 10a b x  - 10a b x  - 5a b x  - a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 12       5 10      2 4 8      3 3 6      4 2 4     5   2
+--R       b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x
+--R  /
+--R     12b
+--R                                                    Type: Expression(Integer)
+--E 1069
+
+--S 1070 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 11       4 9      2 3 7      3 2 5     4   3    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a x)
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 13       5 11      2 4 9      3 3 7      4 2 5     5   3    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1070
+
+)clear all
+
+--S 1071 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1071
+
+--S 1072 of 1370
+r0:=80/693*a^2*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/99*a*x*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/11*x*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/693*a^4*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/693*a^5*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/231*a^3*x*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R           5 11         4 9       2 3 7        3 2 5        4   3       5
+--R       (63b x   + 385a b x  + 990a b x  + 1386a b x  + 1155a b x  + 693a x)
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           2
+--R     693b x  + 693a
+--R                                                    Type: Expression(Integer)
+--E 1072
+
+--S 1073 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 11         4 9       2 3 7        3 2 5        4   3       5
+--R        63b x   + 385a b x  + 990a b x  + 1386a b x  + 1155a b x  + 693a x
+--R   (3)  ------------------------------------------------------------------
+--R                                        693
+--R                                         Type: Union(Expression(Integer),...)
+--E 1073
+
+--S 1074 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 11         4 9       2 3 7        3 2 5        4   3       5
+--R         (- 63b x   - 385a b x  - 990a b x  - 1386a b x  - 1155a b x  - 693a x)
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 13         5 11        2 4 9        3 3 7        4 2 5        5   3
+--R       63b x   + 448a b x   + 1375a b x  + 2376a b x  + 2541a b x  + 1848a b x
+--R     + 
+--R           6
+--R       693a x
+--R  /
+--R           2
+--R     693b x  + 693a
+--R                                                    Type: Expression(Integer)
+--E 1074
+
+--S 1075 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R      +-------------------+
+--R      | 2 4         2    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1075
+
+)clear all
+
+--S 1076 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1076
+
+--S 1077 of 1370
+r0:=1/6*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/8*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/10*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    1/2*a^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)+1/4*a^3*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+a^5*log(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+    (a+b*x^2)
+--R 
+--R
+--R   (2)
+--R             5            5 10        4 8       2 3 6       3 2 4       4   2
+--R         120a log(x) + 12b x   + 75a b x  + 200a b x  + 300a b x  + 300a b x
+--R       + 
+--R             5
+--R         137a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           2
+--R     120b x  + 120a
+--R                                                    Type: Expression(Integer)
+--E 1077
+
+--S 1078 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5            5 10        4 8       2 3 6       3 2 4       4   2
+--R        120a log(x) + 12b x   + 75a b x  + 200a b x  + 300a b x  + 300a b x
+--R   (3)  --------------------------------------------------------------------
+--R                                         120
+--R                                         Type: Union(Expression(Integer),...)
+--E 1078
+
+--S 1079 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5            5 10        4 8       2 3 6       3 2 4
+--R           - 120a log(x) - 12b x   - 75a b x  - 200a b x  - 300a b x
+--R         + 
+--R                 4   2       5
+--R           - 300a b x  - 137a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            5   2       6             6 12        5 10       2 4 8       3 3 6
+--R       (120a b x  + 120a )log(x) + 12b x   + 87a b x   + 275a b x  + 500a b x
+--R     + 
+--R           4 2 4       5   2
+--R       600a b x  + 300a b x
+--R  /
+--R           2
+--R     120b x  + 120a
+--R                                                    Type: Expression(Integer)
+--E 1079
+
+--S 1080 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R       +-------------------+
+--R       | 2 4         2    2
+--R     x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1080
+
+)clear all
+
+--S 1081 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^2
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        2
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1081
+
+--S 1082 of 1370
+r0:=80/63*a*b*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)-10/9*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x+1/9*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x+_
+    128/63*a^3*b*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/63*a^4*b*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/21*a^2*b*x*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R          5 10        4 8       2 3 6       3 2 4       4   2      5
+--R       (7b x   + 45a b x  + 126a b x  + 210a b x  + 315a b x  - 63a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          3
+--R     63b x  + 63a x
+--R                                                    Type: Expression(Integer)
+--E 1082
+
+--S 1083 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          5 10        4 8       2 3 6       3 2 4       4   2      5
+--R        7b x   + 45a b x  + 126a b x  + 210a b x  + 315a b x  - 63a
+--R   (3)  ------------------------------------------------------------
+--R                                     63x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1083
+
+--S 1084 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10        4 8       2 3 6       3 2 4       4   2      5
+--R         (- 7b x   - 45a b x  - 126a b x  - 210a b x  - 315a b x  + 63a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R       6 12        5 10       2 4 8       3 3 6       4 2 4       5   2      6
+--R     7b x   + 52a b x   + 171a b x  + 336a b x  + 525a b x  + 252a b x  - 63a
+--R  /
+--R          3
+--R     63b x  + 63a x
+--R                                                    Type: Expression(Integer)
+--E 1084
+
+--S 1085 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      2 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1085
+
+)clear all
+
+--S 1086 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^3
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        3
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1086
+
+--S 1087 of 1370
+r0:=5/12*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^2+5/24*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^2+1/8*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^2-_
+    5/2*a^5*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^2*(a+b*x^2))+5/4*a^3*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^2+5*a^4*b*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R             4   2           5 10        4 8      2 3 6       3 2 4       4   2
+--R         120a b x log(x) + 3b x   + 20a b x  + 60a b x  + 120a b x  + 125a b x
+--R       + 
+--R              5
+--R         - 12a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          4        2
+--R     24b x  + 24a x
+--R                                                    Type: Expression(Integer)
+--E 1087
+
+--S 1088 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4   2           5 10        4 8      2 3 6       3 2 4      5
+--R        120a b x log(x) + 3b x   + 20a b x  + 60a b x  + 120a b x  - 12a
+--R   (3)  -----------------------------------------------------------------
+--R                                          2
+--R                                       24x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1088
+
+--S 1089 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 4   2           5 10        4 8      2 3 6       3 2 4
+--R           - 120a b x log(x) - 3b x   - 20a b x  - 60a b x  - 120a b x
+--R         + 
+--R                 4   2      5
+--R           - 125a b x  + 12a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 2 4       5   2            6 12        5 10      2 4 8       3 3 6
+--R       (120a b x  + 120a b x )log(x) + 3b x   + 23a b x   + 80a b x  + 180a b x
+--R     + 
+--R           4 2 4      5   2      6
+--R       120a b x  - 12a b x  - 12a
+--R  /
+--R          4        2
+--R     24b x  + 24a x
+--R                                                    Type: Expression(Integer)
+--E 1089
+
+--S 1090 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      3 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1090
+
+)clear all
+
+--S 1091 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^4
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        4
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1091
+
+--S 1092 of 1370
+r0:=80/21*b^2*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/3*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^3-11/3*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^3+_
+    128/21*a^2*b^2*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/21*a^3*b^2*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/7*a*b^2*x*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R          5 10        4 8      2 3 6       3 2 4       4   2     5
+--R       (3b x   + 21a b x  + 70a b x  + 210a b x  - 105a b x  - 7a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          5        3
+--R     21b x  + 21a x
+--R                                                    Type: Expression(Integer)
+--E 1092
+
+--S 1093 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          5 10        4 8      2 3 6       3 2 4       4   2     5
+--R        3b x   + 21a b x  + 70a b x  + 210a b x  - 105a b x  - 7a
+--R   (3)  ----------------------------------------------------------
+--R                                      3
+--R                                   21x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1093
+
+--S 1094 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10        4 8      2 3 6       3 2 4       4   2     5
+--R         (- 3b x   - 21a b x  - 70a b x  - 210a b x  + 105a b x  + 7a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R         6 12        5 10      2 4 8       3 3 6       4 2 4       5   2     6
+--R       3b x   + 24a b x   + 91a b x  + 280a b x  + 105a b x  - 112a b x  - 7a
+--R  /
+--R          5        3
+--R     21b x  + 21a x
+--R                                                    Type: Expression(Integer)
+--E 1094
+
+--S 1095 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      4 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1095
+
+)clear all
+
+--S 1096 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^5
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        5
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1096
+
+--S 1097 of 1370
+r0:=5/3*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+5/4*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^4-3/2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^4+_
+    5*a^2*b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4)+5/2*a*b^2*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+10*a^3*b^2*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R             3 2 4           5 10        4 8      2 3 6      3 2 4      4   2
+--R         120a b x log(x) + 2b x   + 15a b x  + 60a b x  + 20a b x  - 30a b x
+--R       + 
+--R             5
+--R         - 3a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          6        4
+--R     12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 1097
+
+--S 1098 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 2 4           5 10        4 8      2 3 6      4   2     5
+--R        120a b x log(x) + 2b x   + 15a b x  + 60a b x  - 30a b x  - 3a
+--R   (3)  ---------------------------------------------------------------
+--R                                         4
+--R                                      12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1098
+
+--S 1099 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3 2 4           5 10        4 8      2 3 6      3 2 4
+--R           - 120a b x log(x) - 2b x   - 15a b x  - 60a b x  - 20a b x
+--R         + 
+--R              4   2     5
+--R           30a b x  + 3a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            3 3 6       4 2 4            6 12        5 10      2 4 8      3 3 6
+--R       (120a b x  + 120a b x )log(x) + 2b x   + 17a b x   + 75a b x  + 60a b x
+--R     + 
+--R            4 2 4      5   2     6
+--R       - 30a b x  - 33a b x  - 3a
+--R  /
+--R          6        4
+--R     12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 1099
+
+--S 1100 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      5 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1100
+
+)clear all
+
+--S 1101 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^6
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        6
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1101
+
+--S 1102 of 1370
+r0:=16/15*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x+2/3*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^5-13/15*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/_
+    x^5+128/15*a*b^3*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/15*a^2*b^3*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)-32/5*a*b^2*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x
+--R 
+--R
+--R   (2)
+--R          5 10        4 8       2 3 6       3 2 4      4   2     5
+--R       (3b x   + 25a b x  + 150a b x  - 150a b x  - 25a b x  - 3a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          7        5
+--R     15b x  + 15a x
+--R                                                    Type: Expression(Integer)
+--E 1102
+
+--S 1103 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          5 10        4 8       2 3 6       3 2 4      4   2     5
+--R        3b x   + 25a b x  + 150a b x  - 150a b x  - 25a b x  - 3a
+--R   (3)  ----------------------------------------------------------
+--R                                      5
+--R                                   15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1103
+
+--S 1104 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10        4 8       2 3 6       3 2 4      4   2     5
+--R         (- 3b x   - 25a b x  - 150a b x  + 150a b x  + 25a b x  + 3a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R         6 12        5 10       2 4 8       4 2 4      5   2     6
+--R       3b x   + 28a b x   + 175a b x  - 175a b x  - 28a b x  - 3a
+--R  /
+--R          7        5
+--R     15b x  + 15a x
+--R                                                    Type: Expression(Integer)
+--E 1104
+
+--S 1105 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      6 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1105
+
+)clear all
+
+--S 1106 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^7
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        7
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1106
+
+--S 1107 of 1370
+r0:=5/6*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^2+5/12*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^6-7/12*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^6-5*a^3*b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+    (x^2*(a+b*x^2))+5/2*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^2+_
+    10*a^2*b^3*log(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R             2 3 6           5 10        4 8      2 3 6      3 2 4      4   2
+--R         120a b x log(x) + 3b x   + 30a b x  + 40a b x  - 60a b x  - 15a b x
+--R       + 
+--R             5
+--R         - 2a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          8        6
+--R     12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 1107
+
+--S 1108 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 3 6           5 10        4 8      3 2 4      4   2     5
+--R        120a b x log(x) + 3b x   + 30a b x  - 60a b x  - 15a b x  - 2a
+--R   (3)  ---------------------------------------------------------------
+--R                                         6
+--R                                      12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1108
+
+--S 1109 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 2 3 6           5 10        4 8      2 3 6      3 2 4
+--R           - 120a b x log(x) - 3b x   - 30a b x  - 40a b x  + 60a b x
+--R         + 
+--R              4   2     5
+--R           15a b x  + 2a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            2 4 8       3 3 6            6 12        5 10      2 4 8      3 3 6
+--R       (120a b x  + 120a b x )log(x) + 3b x   + 33a b x   + 30a b x  - 60a b x
+--R     + 
+--R            4 2 4      5   2     6
+--R       - 75a b x  - 17a b x  - 2a
+--R  /
+--R          8        6
+--R     12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 1109
+
+--S 1110 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      7 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1110
+
+)clear all
+
+--S 1111 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^8
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        8
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1111
+
+--S 1112 of 1370
+r0:=-16/3*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^3+2/7*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^7-3/7*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^7+128/21*b^4*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+    256/21*a*b^4*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+    32/7*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3
+--R 
+--R
+--R   (2)
+--R          5 10         4 8       2 3 6      3 2 4      4   2     5
+--R       (7b x   + 105a b x  - 210a b x  - 70a b x  - 21a b x  - 3a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          9        7
+--R     21b x  + 21a x
+--R                                                    Type: Expression(Integer)
+--E 1112
+
+--S 1113 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R          5 10         4 8       2 3 6      3 2 4      4   2     5
+--R        7b x   + 105a b x  - 210a b x  - 70a b x  - 21a b x  - 3a
+--R   (3)  ----------------------------------------------------------
+--R                                      7
+--R                                   21x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1113
+
+--S 1114 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10         4 8       2 3 6      3 2 4      4   2     5
+--R         (- 7b x   - 105a b x  + 210a b x  + 70a b x  + 21a b x  + 3a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R         6 12         5 10       2 4 8       3 3 6      4 2 4      5   2     6
+--R       7b x   + 112a b x   - 105a b x  - 280a b x  - 91a b x  - 24a b x  - 3a
+--R  /
+--R          9        7
+--R     21b x  + 21a x
+--R                                                    Type: Expression(Integer)
+--E 1114
+
+--S 1115 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      8 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1115
+
+)clear all
+
+--S 1116 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^9
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        9
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1116
+
+--S 1117 of 1370
+r0:=-5/3*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^4+5/24*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^8-1/3*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^8+5/2*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+    5/4*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^4+_
+    5*a*b^4*log(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R               4 8            5 10        4 8       2 3 6      3 2 4      4   2
+--R         120a b x log(x) + 12b x   - 65a b x  - 120a b x  - 60a b x  - 20a b x
+--R       + 
+--R             5
+--R         - 3a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          10        8
+--R     24b x   + 24a x
+--R                                                    Type: Expression(Integer)
+--E 1117
+
+--S 1118 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4 8            5 10       2 3 6      3 2 4      4   2     5
+--R        120a b x log(x) + 12b x   - 120a b x  - 60a b x  - 20a b x  - 3a
+--R   (3)  -----------------------------------------------------------------
+--R                                          8
+--R                                       24x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1118
+
+--S 1119 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   4 8            5 10        4 8       2 3 6      3 2 4
+--R           - 120a b x log(x) - 12b x   + 65a b x  + 120a b x  + 60a b x
+--R         + 
+--R              4   2     5
+--R           20a b x  + 3a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              5 10       2 4 8             6 12        5 10       2 4 8
+--R       (120a b x   + 120a b x )log(x) + 12b x   + 12a b x   - 120a b x
+--R     + 
+--R             3 3 6      4 2 4      5   2     6
+--R       - 180a b x  - 80a b x  - 23a b x  - 3a
+--R  /
+--R          10        8
+--R     24b x   + 24a x
+--R                                                    Type: Expression(Integer)
+--E 1119
+
+--S 1120 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      9 | 2 4         2    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1120
+
+)clear all
+
+--S 1121 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^10
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       10
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1121
+
+--S 1122 of 1370
+r0:=-16/21*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^5+10/63*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^9-17/63*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^9+128/63*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x-_
+    256/63*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x*(a+b*x^2))+_
+    32/63*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^5
+--R 
+--R
+--R   (2)
+--R           5 10         4 8       2 3 6       3 2 4      4   2     5
+--R       (63b x   - 315a b x  - 210a b x  - 126a b x  - 45a b x  - 7a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          11        9
+--R     63b x   + 63a x
+--R                                                    Type: Expression(Integer)
+--E 1122
+
+--S 1123 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 10         4 8       2 3 6       3 2 4      4   2     5
+--R        63b x   - 315a b x  - 210a b x  - 126a b x  - 45a b x  - 7a
+--R   (3)  ------------------------------------------------------------
+--R                                       9
+--R                                    63x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1123
+
+--S 1124 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 10         4 8       2 3 6       3 2 4      4   2     5
+--R         (- 63b x   + 315a b x  + 210a b x  + 126a b x  + 45a b x  + 7a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 12         5 10       2 4 8       3 3 6       4 2 4      5   2     6
+--R     63b x   - 252a b x   - 525a b x  - 336a b x  - 171a b x  - 52a b x  - 7a
+--R  /
+--R          11        9
+--R     63b x   + 63a x
+--R                                                    Type: Expression(Integer)
+--E 1124
+
+--S 1125 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      10 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1125
+
+)clear all
+
+--S 1126 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^11
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       11
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1126
+
+--S 1127 of 1370
+r0:=-5/12*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^6+1/8*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^10-9/40*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^10-1/2*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+    (x^2*(a+b*x^2))+1/4*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^6+_
+    b^5*log(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R             5 10            5 10         4 8       2 3 6       3 2 4      4   2
+--R         120b x  log(x) - 77b x   - 300a b x  - 300a b x  - 200a b x  - 75a b x
+--R       + 
+--R              5
+--R         - 12a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           12         10
+--R     120b x   + 120a x
+--R                                                    Type: Expression(Integer)
+--E 1127
+
+--S 1128 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5 10               4 8       2 3 6       3 2 4      4   2      5
+--R        120b x  log(x) - 300a b x  - 300a b x  - 200a b x  - 75a b x  - 12a
+--R   (3)  --------------------------------------------------------------------
+--R                                           10
+--R                                       120x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1128
+
+--S 1129 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 10            5 10         4 8       2 3 6       3 2 4
+--R           - 120b x  log(x) + 77b x   + 300a b x  + 300a b x  + 200a b x
+--R         + 
+--R              4   2      5
+--R           75a b x  + 12a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            6 12         5 10                5 10       2 4 8       3 3 6
+--R       (120b x   + 120a b x  )log(x) - 300a b x   - 600a b x  - 500a b x
+--R     + 
+--R             4 2 4      5   2      6
+--R       - 275a b x  - 87a b x  - 12a
+--R  /
+--R           12         10
+--R     120b x   + 120a x
+--R                                                    Type: Expression(Integer)
+--E 1129
+
+--S 1130 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      11 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1130
+
+)clear all
+
+--S 1131 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^12
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       12
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1131
+
+--S 1132 of 1370
+r0:=-16/63*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^7+10/99*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^11-19/99*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^11-128/231*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3+_
+    256/693*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^3*(a+b*x^2))+_
+    32/231*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^7
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6       3 2 4       4   2      5
+--R       (- 693b x   - 1155a b x  - 1386a b x  - 990a b x  - 385a b x  - 63a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           13         11
+--R     693b x   + 693a x
+--R                                                    Type: Expression(Integer)
+--E 1132
+
+--S 1133 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              5 10          4 8        2 3 6       3 2 4       4   2      5
+--R        - 693b x   - 1155a b x  - 1386a b x  - 990a b x  - 385a b x  - 63a
+--R   (3)  -------------------------------------------------------------------
+--R                                           11
+--R                                       693x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1133
+
+--S 1134 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10          4 8        2 3 6       3 2 4       4   2      5
+--R         (693b x   + 1155a b x  + 1386a b x  + 990a b x  + 385a b x  + 63a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 12          5 10        2 4 8        3 3 6        4 2 4
+--R       - 693b x   - 1848a b x   - 2541a b x  - 2376a b x  - 1375a b x
+--R     + 
+--R             5   2      6
+--R       - 448a b x  - 63a
+--R  /
+--R           13         11
+--R     693b x   + 693a x
+--R                                                    Type: Expression(Integer)
+--E 1134
+
+--S 1135 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      12 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1135
+
+)clear all
+
+--S 1136 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^13
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       13
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1136
+
+--S 1137 of 1370
+r0:=-1/12*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a*x^12)
+--R 
+--R
+--R   (2)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R       (- b x   - 5a b x  - 10a b x  - 10a b x  - 5a b x  - a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          12
+--R     12a x
+--R                                                    Type: Expression(Integer)
+--E 1137
+
+--S 1138 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5 10        4 8      2 3 6      3 2 4     4   2    5
+--R        - 6b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R   (3)  --------------------------------------------------------
+--R                                     12
+--R                                  12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1138
+
+--S 1139 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R          12
+--R     12a x
+--R                                                    Type: Expression(Integer)
+--E 1139
+
+--S 1140 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      13 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1140
+
+)clear all
+
+--S 1141 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^14
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       14
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1141
+
+--S 1142 of 1370
+r0:=-80/693*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^9+10/143*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^13-21/143*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^13-640/9009*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^5+_
+    256/9009*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^5*(a+b*x^2))+_
+    160/3003*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^9
+--R 
+--R
+--R   (2)
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 3003b x   - 9009a b x  - 12870a b x  - 10010a b x  - 4095a b x
+--R         + 
+--R                 5
+--R           - 693a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            15          13
+--R     9009b x   + 9009a x
+--R                                                    Type: Expression(Integer)
+--E 1142
+
+--S 1143 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          5 10          4 8         2 3 6         3 2 4        4   2       5
+--R   - 3003b x   - 9009a b x  - 12870a b x  - 10010a b x  - 4095a b x  - 693a
+--R   -------------------------------------------------------------------------
+--R                                         13
+--R                                    9009x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1143
+
+--S 1144 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R             3003b x   + 9009a b x  + 12870a b x  + 10010a b x  + 4095a b x
+--R           + 
+--R                 5
+--R             693a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              6 12           5 10         2 4 8         3 3 6         4 2 4
+--R       - 3003b x   - 12012a b x   - 21879a b x  - 22880a b x  - 14105a b x
+--R     + 
+--R              5   2       6
+--R       - 4788a b x  - 693a
+--R  /
+--R            15          13
+--R     9009b x   + 9009a x
+--R                                                    Type: Expression(Integer)
+--E 1144
+
+--S 1145 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      14 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1145
+
+)clear all
+
+--S 1146 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^15
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       15
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1146
+
+--S 1147 of 1370
+r0:=-1/12*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a*x^14)+_
+    1/84*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/(a^2*x^14)
+--R 
+--R
+--R   (2)
+--R         6 12      5 10      2 4 8      3 3 6      4 2 4      5   2     6
+--R       (b x   - a b x   - 20a b x  - 50a b x  - 55a b x  - 29a b x  - 6a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R        2 14
+--R     84a x
+--R                                                    Type: Expression(Integer)
+--E 1147
+
+--S 1148 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             5 10        4 8       2 3 6      3 2 4      4   2     5
+--R        - 21b x   - 70a b x  - 105a b x  - 84a b x  - 35a b x  - 6a
+--R   (3)  ------------------------------------------------------------
+--R                                       14
+--R                                    84x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1148
+
+--S 1149 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             6 12      5 10      2 4 8      3 3 6      4 2 4      5   2     6
+--R         (- b x   + a b x   + 20a b x  + 50a b x  + 55a b x  + 29a b x  + 6a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            2 5 10      3 4 8       4 3 6      5 2 4      6   2     7
+--R       - 21a b x   - 70a b x  - 105a b x  - 84a b x  - 35a b x  - 6a
+--R  /
+--R        2 14
+--R     84a x
+--R                                                    Type: Expression(Integer)
+--E 1149
+
+--S 1150 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      15 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1150
+
+)clear all
+
+--S 1151 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^16
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       16
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1151
+
+--S 1152 of 1370
+r0:=-80/1287*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^11+2/39*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^15-23/195*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^15-128/6435*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^7+_
+    256/45045*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^7*(a+b*x^2))+_
+    32/1287*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^11
+--R 
+--R
+--R   (2)
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R         - 9009b x   - 32175a b x  - 50050a b x  - 40950a b x  - 17325a b x
+--R       + 
+--R                5
+--R         - 3003a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             17           15
+--R     45045b x   + 45045a x
+--R                                                    Type: Expression(Integer)
+--E 1152
+
+--S 1153 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          5 10           4 8         2 3 6         3 2 4         4   2        5
+--R   - 9009b x   - 32175a b x  - 50050a b x  - 40950a b x  - 17325a b x  - 3003a
+--R   ----------------------------------------------------------------------------
+--R                                           15
+--R                                     45045x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1153
+
+--S 1154 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           9009b x   + 32175a b x  + 50050a b x  + 40950a b x  + 17325a b x
+--R         + 
+--R                5
+--R           3003a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              6 12           5 10         2 4 8         3 3 6         4 2 4
+--R       - 9009b x   - 41184a b x   - 82225a b x  - 91000a b x  - 58275a b x
+--R     + 
+--R               5   2        6
+--R       - 20328a b x  - 3003a
+--R  /
+--R             17           15
+--R     45045b x   + 45045a x
+--R                                                    Type: Expression(Integer)
+--E 1154
+
+--S 1155 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      16 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1155
+
+)clear all
+
+--S 1156 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^17
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       17
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1156
+
+--S 1157 of 1370
+r0:=-1/16*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a*x^16)+_
+    1/48*b*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a^2*x^14)-_
+    1/336*b*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/(a^3*x^14)
+--R 
+--R
+--R   (2)
+--R            7 14      6 12    2 5 10      3 4 8       4 3 6       5 2 4
+--R         - b x   + a b x   - a b x   - 55a b x  - 155a b x  - 181a b x
+--R       + 
+--R              6   2      7
+--R         - 99a b x  - 21a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         3 16
+--R     336a x
+--R                                                    Type: Expression(Integer)
+--E 1157
+
+--S 1158 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R             5 10         4 8       2 3 6       3 2 4       4   2      5
+--R        - 56b x   - 210a b x  - 336a b x  - 280a b x  - 120a b x  - 21a
+--R   (3)  ----------------------------------------------------------------
+--R                                         16
+--R                                     336x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1158
+
+--S 1159 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            7 14      6 12    2 5 10      3 4 8       4 3 6       5 2 4
+--R           b x   - a b x   + a b x   + 55a b x  + 155a b x  + 181a b x
+--R         + 
+--R              6   2      7
+--R           99a b x  + 21a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            3 5 10       4 4 8       5 3 6       6 2 4       7   2      8
+--R       - 56a b x   - 210a b x  - 336a b x  - 280a b x  - 120a b x  - 21a
+--R  /
+--R         3 16
+--R     336a x
+--R                                                    Type: Expression(Integer)
+--E 1159
+
+--S 1160 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      17 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1160
+
+)clear all
+
+--S 1161 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^18
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       18
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1161
+
+--S 1162 of 1370
+r0:=-16/429*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^13+2/51*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^17-5/51*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^17-128/17017*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^9+_
+    256/153153*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^9*(a+b*x^2))+_
+    32/2431*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^13
+--R 
+--R
+--R   (2)
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R         - 21879b x   - 85085a b x  - 139230a b x  - 117810a b x  - 51051a b x
+--R       + 
+--R                5
+--R         - 9009a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              19            17
+--R     153153b x   + 153153a x
+--R                                                    Type: Expression(Integer)
+--E 1162
+
+--S 1163 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               5 10           4 8          2 3 6          3 2 4         4   2
+--R       - 21879b x   - 85085a b x  - 139230a b x  - 117810a b x  - 51051a b x
+--R     + 
+--R              5
+--R       - 9009a
+--R  /
+--R            17
+--R     153153x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1163
+
+--S 1164 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           21879b x   + 85085a b x  + 139230a b x  + 117810a b x  + 51051a b x
+--R         + 
+--R                5
+--R           9009a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               6 12            5 10          2 4 8          3 3 6          4 2 4
+--R       - 21879b x   - 106964a b x   - 224315a b x  - 257040a b x  - 168861a b x
+--R     + 
+--R               5   2        6
+--R       - 60060a b x  - 9009a
+--R  /
+--R              19            17
+--R     153153b x   + 153153a x
+--R                                                    Type: Expression(Integer)
+--E 1164
+
+--S 1165 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      18 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1165
+
+)clear all
+
+--S 1166 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^19
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       19
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1166
+
+--S 1167 of 1370
+r0:=-1/18*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a*x^18)+_
+    1/48*b*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a^2*x^16)-_
+    1/144*b^2*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a^3*x^14)+_
+    1/1008*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/(a^4*x^14)
+--R 
+--R
+--R   (2)
+--R          8 16      7 14    2 6 12    3 5 10       4 4 8       5 3 6       6 2 4
+--R         b x   - a b x   + a b x   - a b x   - 125a b x  - 379a b x  - 461a b x
+--R       + 
+--R               7   2      8
+--R         - 259a b x  - 56a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          4 18
+--R     1008a x
+--R                                                    Type: Expression(Integer)
+--E 1167
+
+--S 1168 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              5 10         4 8       2 3 6       3 2 4       4   2      5
+--R        - 126b x   - 504a b x  - 840a b x  - 720a b x  - 315a b x  - 56a
+--R   (3)  -----------------------------------------------------------------
+--R                                          18
+--R                                     1008x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1168
+
+--S 1169 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              8 16      7 14    2 6 12    3 5 10       4 4 8       5 3 6
+--R           - b x   + a b x   - a b x   + a b x   + 125a b x  + 379a b x
+--R         + 
+--R               6 2 4       7   2      8
+--R           461a b x  + 259a b x  + 56a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             4 5 10       5 4 8       6 3 6       7 2 4       8   2      9
+--R       - 126a b x   - 504a b x  - 840a b x  - 720a b x  - 315a b x  - 56a
+--R  /
+--R          4 18
+--R     1008a x
+--R                                                    Type: Expression(Integer)
+--E 1169
+
+--S 1170 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      19 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1170
+
+)clear all
+
+--S 1171 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^20
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       20
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1171
+
+--S 1172 of 1370
+r0:=-16/663*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^15+10/323*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^19-27/323*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^19-128/37791*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^11+_
+    256/415701*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^11*(a+b*x^2))+_
+    32/4199*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^15
+--R 
+--R
+--R   (2)
+--R                 5 10            4 8          2 3 6          3 2 4
+--R         - 46189b x   - 188955a b x  - 319770a b x  - 277134a b x
+--R       + 
+--R                  4   2         5
+--R         - 122265a b x  - 21879a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              21            19
+--R     415701b x   + 415701a x
+--R                                                    Type: Expression(Integer)
+--E 1172
+
+--S 1173 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               5 10            4 8          2 3 6          3 2 4          4   2
+--R       - 46189b x   - 188955a b x  - 319770a b x  - 277134a b x  - 122265a b x
+--R     + 
+--R               5
+--R       - 21879a
+--R  /
+--R            19
+--R     415701x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1173
+
+--S 1174 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           46189b x   + 188955a b x  + 319770a b x  + 277134a b x
+--R         + 
+--R                  4   2         5
+--R           122265a b x  + 21879a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               6 12            5 10          2 4 8          3 3 6          4 2 4
+--R       - 46189b x   - 235144a b x   - 508725a b x  - 596904a b x  - 399399a b x
+--R     + 
+--R                5   2         6
+--R       - 144144a b x  - 21879a
+--R  /
+--R              21            19
+--R     415701b x   + 415701a x
+--R                                                    Type: Expression(Integer)
+--E 1174
+
+--S 1175 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      20 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1175
+
+)clear all
+
+--S 1176 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^21
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       21
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1176
+
+--S 1177 of 1370
+r0:=-5/252*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^16+1/36*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^20-7/90*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^20-1/420*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^12+_
+    1/2520*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^12*(a+b*x^2))+_
+    1/168*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^16
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4       4   2       5
+--R       (- 252b x   - 1050a b x  - 1800a b x  - 1575a b x  - 700a b x  - 126a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            22          20
+--R     2520b x   + 2520a x
+--R                                                    Type: Expression(Integer)
+--E 1177
+
+--S 1178 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              5 10          4 8        2 3 6        3 2 4       4   2       5
+--R        - 252b x   - 1050a b x  - 1800a b x  - 1575a b x  - 700a b x  - 126a
+--R   (3)  ---------------------------------------------------------------------
+--R                                            20
+--R                                       2520x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1178
+
+--S 1179 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10          4 8        2 3 6        3 2 4       4   2       5
+--R         (252b x   + 1050a b x  + 1800a b x  + 1575a b x  + 700a b x  + 126a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 12          5 10        2 4 8        3 3 6        4 2 4
+--R       - 252b x   - 1302a b x   - 2850a b x  - 3375a b x  - 2275a b x
+--R     + 
+--R             5   2       6
+--R       - 826a b x  - 126a
+--R  /
+--R            22          20
+--R     2520b x   + 2520a x
+--R                                                    Type: Expression(Integer)
+--E 1179
+
+--S 1180 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      21 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1180
+
+)clear all
+
+--S 1181 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^22
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       22
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1181
+
+--S 1182 of 1370
+r0:=-16/969*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^17+10/399*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^21-29/399*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^21-128/74613*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^13+_
+    256/969969*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^13*(a+b*x^2))+_
+    32/6783*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^17
+--R 
+--R
+--R   (2)
+--R                 5 10            4 8          2 3 6          3 2 4
+--R         - 88179b x   - 373065a b x  - 646646a b x  - 570570a b x
+--R       + 
+--R                  4   2         5
+--R         - 255255a b x  - 46189a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              23            21
+--R     969969b x   + 969969a x
+--R                                                    Type: Expression(Integer)
+--E 1182
+
+--S 1183 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               5 10            4 8          2 3 6          3 2 4          4   2
+--R       - 88179b x   - 373065a b x  - 646646a b x  - 570570a b x  - 255255a b x
+--R     + 
+--R               5
+--R       - 46189a
+--R  /
+--R            21
+--R     969969x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1183
+
+--S 1184 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           88179b x   + 373065a b x  + 646646a b x  + 570570a b x
+--R         + 
+--R                  4   2         5
+--R           255255a b x  + 46189a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               6 12            5 10           2 4 8           3 3 6
+--R       - 88179b x   - 461244a b x   - 1019711a b x  - 1217216a b x
+--R     + 
+--R                4 2 4          5   2         6
+--R       - 825825a b x  - 301444a b x  - 46189a
+--R  /
+--R              23            21
+--R     969969b x   + 969969a x
+--R                                                    Type: Expression(Integer)
+--E 1184
+
+--S 1185 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      22 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1185
+
+)clear all
+
+--S 1186 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^23
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       23
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1186
+
+--S 1187 of 1370
+r0:=-1/72*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^18+1/44*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^22-3/44*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^22-1/792*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^14+_
+    1/5544*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^14*(a+b*x^2))+_
+    1/264*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^18
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R       (- 462b x   - 1980a b x  - 3465a b x  - 3080a b x  - 1386a b x  - 252a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            24          22
+--R     5544b x   + 5544a x
+--R                                                    Type: Expression(Integer)
+--E 1187
+
+--S 1188 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R        - 462b x   - 1980a b x  - 3465a b x  - 3080a b x  - 1386a b x  - 252a
+--R   (3)  ----------------------------------------------------------------------
+--R                                             22
+--R                                        5544x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1188
+
+--S 1189 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (462b x   + 1980a b x  + 3465a b x  + 3080a b x  + 1386a b x  + 252a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 12          5 10        2 4 8        3 3 6        4 2 4
+--R       - 462b x   - 2442a b x   - 5445a b x  - 6545a b x  - 4466a b x
+--R     + 
+--R              5   2       6
+--R       - 1638a b x  - 252a
+--R  /
+--R            24          22
+--R     5544b x   + 5544a x
+--R                                                    Type: Expression(Integer)
+--E 1189
+
+--S 1190 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      23 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1190
+
+)clear all
+
+--S 1191 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^24
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       24
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1191
+
+--S 1192 of 1370
+r0:=-80/6783*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^19+10/483*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^23-31/483*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^23-640/676039*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^15+_
+    256/2028117*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^15*(a+b*x^2))+_
+    160/52003*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^19
+--R 
+--R
+--R   (2)
+--R                  5 10            4 8           2 3 6           3 2 4
+--R         - 156009b x   - 676039a b x  - 1193010a b x  - 1067430a b x
+--R       + 
+--R                  4   2         5
+--R         - 482885a b x  - 88179a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R               25             23
+--R     2028117b x   + 2028117a x
+--R                                                    Type: Expression(Integer)
+--E 1192
+
+--S 1193 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                5 10            4 8           2 3 6           3 2 4
+--R       - 156009b x   - 676039a b x  - 1193010a b x  - 1067430a b x
+--R     + 
+--R                4   2         5
+--R       - 482885a b x  - 88179a
+--R  /
+--R             23
+--R     2028117x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1193
+
+--S 1194 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 10            4 8           2 3 6           3 2 4
+--R           156009b x   + 676039a b x  + 1193010a b x  + 1067430a b x
+--R         + 
+--R                  4   2         5
+--R           482885a b x  + 88179a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                6 12            5 10           2 4 8           3 3 6
+--R       - 156009b x   - 832048a b x   - 1869049a b x  - 2260440a b x
+--R     + 
+--R                 4 2 4          5   2         6
+--R       - 1550315a b x  - 571064a b x  - 88179a
+--R  /
+--R               25             23
+--R     2028117b x   + 2028117a x
+--R                                                    Type: Expression(Integer)
+--E 1194
+
+--S 1195 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      24 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1195
+
+)clear all
+
+--S 1196 of 1370
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^25
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       25
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 1196
+
+--S 1197 of 1370
+r0:=-1/99*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^20+5/264*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^24-2/33*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^24-1/1386*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^16+_
+    1/11088*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^16*(a+b*x^2))+_
+    1/396*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^20
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R       (- 792b x   - 3465a b x  - 6160a b x  - 5544a b x  - 2520a b x  - 462a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             26           24
+--R     11088b x   + 11088a x
+--R                                                    Type: Expression(Integer)
+--E 1197
+
+--S 1198 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R        - 792b x   - 3465a b x  - 6160a b x  - 5544a b x  - 2520a b x  - 462a
+--R   (3)  ----------------------------------------------------------------------
+--R                                             24
+--R                                       11088x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1198
+
+--S 1199 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (792b x   + 3465a b x  + 6160a b x  + 5544a b x  + 2520a b x  + 462a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 12          5 10        2 4 8         3 3 6        4 2 4
+--R       - 792b x   - 4257a b x   - 9625a b x  - 11704a b x  - 8064a b x
+--R     + 
+--R              5   2       6
+--R       - 2982a b x  - 462a
+--R  /
+--R             26           24
+--R     11088b x   + 11088a x
+--R                                                    Type: Expression(Integer)
+--E 1199
+
+--S 1200 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      25 | 2 4         2    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1200
+
+)clear all
+
+--S 1201 of 1370
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R                   4
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1201
+
+--S 1202 of 1370
+r0:=-a*x*(a+b*x^2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/3*x^3*_
+    (a+b*x^2)/(b*sqrt(a^2+2*a*b*x^2+b^2*x^4))+a^(3/2)*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(b^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                  +-+
+--R               2     2  +-+     x\|b       2 5         3     2   +-+
+--R        (3a b x  + 3a )\|a atan(-----) + (b x  - 2a b x  - 3a x)\|b
+--R                                  +-+
+--R                                 \|a
+--R   (2)  ------------------------------------------------------------
+--R                                +-------------------+
+--R                          2 +-+ | 2 4         2    2
+--R                        3b \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1202
+
+--S 1203 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +---+
+--R                     |  a       2
+--R       +---+    2b x |- -  + b x  - a
+--R       |  a         \|  b                    3
+--R    3a |- - log(---------------------) + 2b x  - 6a x
+--R      \|  b               2
+--R                       b x  + a
+--R   [-------------------------------------------------,
+--R                             2
+--R                           6b
+--R                  +-+
+--R                  |a
+--R         +-+      |-
+--R         |a      \|b        3
+--R    - 3a |- atan(----) + b x  - 3a x
+--R        \|b        x
+--R    --------------------------------]
+--R                     2
+--R                   3b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1203
+
+--S 1204 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                  +---+
+--R                                                  |  a       2
+--R          +---+     +-------------------+    2b x |- -  + b x  - a
+--R          |  a  +-+ | 2 4         2    2         \|  b
+--R       3a |- - \|b \|b x  + 2a b x  + a  log(---------------------)
+--R         \|  b                                         2
+--R                                                    b x  + a
+--R     + 
+--R                                   +-+
+--R                2     2  +-+     x\|b
+--R       (- 6a b x  - 6a )\|a atan(-----)
+--R                                   +-+
+--R                                  \|a
+--R     + 
+--R                        +-------------------+
+--R          3         +-+ | 2 4         2    2         2 5         3     2   +-+
+--R     (2b x  - 6a x)\|b \|b x  + 2a b x  + a   + (- 2b x  + 4a b x  + 6a x)\|b
+--R  /
+--R             +-------------------+
+--R       2 +-+ | 2 4         2    2
+--R     6b \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1204
+
+--S 1205 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R           +-------------------+
+--R         4 | 2 4         2    2       6      4
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  --------------------------------------
+--R                      +-------------------+
+--R               2      | 2 4         2    2
+--R           (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1205
+
+--S 1206 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                   +-+
+--R                2     2  +-+     x\|b
+--R       (- 3a b x  - 3a )\|a atan(-----)
+--R                                   +-+
+--R                                  \|a
+--R     + 
+--R                                               +-+
+--R                                               |a
+--R            +-+     +-------------------+      |-
+--R            |a  +-+ | 2 4         2    2      \|b
+--R       - 3a |- \|b \|b x  + 2a b x  + a  atan(----)
+--R           \|b                                  x
+--R     + 
+--R                         +-------------------+
+--R           3         +-+ | 2 4         2    2        2 5         3     2   +-+
+--R       (b x  - 3a x)\|b \|b x  + 2a b x  + a   + (- b x  + 2a b x  + 3a x)\|b
+--R  /
+--R             +-------------------+
+--R       2 +-+ | 2 4         2    2
+--R     3b \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1206
+
+--S 1207 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R           +-------------------+
+--R         4 | 2 4         2    2       6      4
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (7)  --------------------------------------
+--R                      +-------------------+
+--R               2      | 2 4         2    2
+--R           (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1207
+
+)clear all
+
+--S 1208 of 1370
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R                   3
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1208
+
+--S 1209 of 1370
+r0:=-1/2*a*(a+b*x^2)*log(a+b*x^2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+    1/2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/b^2
+--R 
+--R
+--R                2    2        2         2 4         2    2
+--R        (- a b x  - a )log(b x  + a) + b x  + 2a b x  + a
+--R   (2)  --------------------------------------------------
+--R                         +-------------------+
+--R                       2 | 2 4         2    2
+--R                     2b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1209
+
+--S 1210 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   2           2
+--R        - a log(b x  + a) + b x
+--R   (3)  ------------------------
+--R                     2
+--R                   2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1210
+
+--S 1211 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  +-------------------+
+--R                   2           2  | 2 4         2    2
+--R       (- a log(b x  + a) + b x )\|b x  + 2a b x  + a
+--R     + 
+--R             2    2        2         2 4         2    2
+--R       (a b x  + a )log(b x  + a) - b x  - 2a b x  - a
+--R  /
+--R         +-------------------+
+--R       2 | 2 4         2    2
+--R     2b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1211
+
+--S 1212 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R           +-------------------+
+--R         3 | 2 4         2    2       5      3
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  --------------------------------------
+--R                      +-------------------+
+--R               2      | 2 4         2    2
+--R           (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1212
+
+)clear all
+
+--S 1213 of 1370
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R                   2
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1213
+
+--S 1214 of 1370
+r0:=x*(a+b*x^2)/(b*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+    (a+b*x^2)*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/(b^(3/2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                               +-+
+--R              2      +-+     x\|b         3        +-+
+--R        (- b x  - a)\|a atan(-----) + (b x  + a x)\|b
+--R                               +-+
+--R                              \|a
+--R   (2)  ----------------------------------------------
+--R                        +-------------------+
+--R                    +-+ | 2 4         2    2
+--R                  b\|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1214
+
+--S 1215 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          +---+
+--R                          |  a       2                     +-+
+--R          +---+    - 2b x |- -  + b x  - a                 |a
+--R          |  a           \|  b                    +-+      |-
+--R          |- - log(-----------------------) + 2x  |a      \|b
+--R         \|  b                2                   |- atan(----) + x
+--R                           b x  + a              \|b        x
+--R   (3)  [---------------------------------------,------------------]
+--R                            2b                            b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1215
+
+--S 1216 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                  +---+
+--R                                                  |  a       2
+--R        +---+     +-------------------+    - 2b x |- -  + b x  - a
+--R        |  a  +-+ | 2 4         2    2           \|  b
+--R        |- - \|b \|b x  + 2a b x  + a  log(-----------------------)
+--R       \|  b                                          2
+--R                                                   b x  + a
+--R     + 
+--R                              +-+           +-------------------+
+--R            2       +-+     x\|b        +-+ | 2 4         2    2
+--R       (2b x  + 2a)\|a atan(-----) + 2x\|b \|b x  + 2a b x  + a
+--R                              +-+
+--R                             \|a
+--R     + 
+--R              3         +-+
+--R       (- 2b x  - 2a x)\|b
+--R  /
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R     2b\|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1216
+
+--S 1217 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R           +-------------------+
+--R         2 | 2 4         2    2       4      2
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  --------------------------------------
+--R                      +-------------------+
+--R               2      | 2 4         2    2
+--R           (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1217
+
+--S 1218 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                       +-+
+--R                                                                       |a
+--R                            +-+     +-+     +-------------------+      |-
+--R           2      +-+     x\|b      |a  +-+ | 2 4         2    2      \|b
+--R       (b x  + a)\|a atan(-----) +  |- \|b \|b x  + 2a b x  + a  atan(----)
+--R                            +-+    \|b                                  x
+--R                           \|a
+--R     + 
+--R             +-------------------+
+--R         +-+ | 2 4         2    2          3        +-+
+--R       x\|b \|b x  + 2a b x  + a   + (- b x  - a x)\|b
+--R  /
+--R           +-------------------+
+--R       +-+ | 2 4         2    2
+--R     b\|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1218
+
+--S 1219 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R           +-------------------+
+--R         2 | 2 4         2    2       4      2
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (7)  --------------------------------------
+--R                      +-------------------+
+--R               2      | 2 4         2    2
+--R           (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1219
+
+)clear all
+
+--S 1220 of 1370
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R                   x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1220
+
+--S 1221 of 1370
+r0:=1/2*(a+b*x^2)*log(a+b*x^2)/(b*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R             2            2
+--R         (b x  + a)log(b x  + a)
+--R   (2)  ------------------------
+--R           +-------------------+
+--R           | 2 4         2    2
+--R        2b\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1221
+
+--S 1222 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R        log(b x  + a)
+--R   (3)  -------------
+--R              2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1222
+
+--S 1223 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                      +-------------------+
+--R               2      | 2 4         2    2          2            2
+--R        log(b x  + a)\|b x  + 2a b x  + a   + (- b x  - a)log(b x  + a)
+--R   (4)  ---------------------------------------------------------------
+--R                               +-------------------+
+--R                               | 2 4         2    2
+--R                            2b\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1223
+
+--S 1224 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 4         2    2       3
+--R        x\|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  ------------------------------------
+--R                     +-------------------+
+--R              2      | 2 4         2    2
+--R          (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1224
+
+)clear all
+
+--S 1225 of 1370
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1225
+
+--S 1226 of 1370
+r0:=(a+b*x^2)*atan(x*sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                              +-+
+--R                 2          x\|b
+--R             (b x  + a)atan(-----)
+--R                              +-+
+--R                             \|a
+--R   (2)  ------------------------------
+--R                 +-------------------+
+--R         +-+ +-+ | 2 4         2    2
+--R        \|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1226
+
+--S 1227 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 2      +-----+
+--R             (b x  - a)\|- a b  + 2a b x         +---+
+--R         log(---------------------------)      x\|a b
+--R                          2               atan(-------)
+--R                       b x  + a                   a
+--R   (3)  [--------------------------------,-------------]
+--R                       +-----+                 +---+
+--R                     2\|- a b                 \|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1227
+
+--S 1228 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                +-------------------+        2      +-----+
+--R        +-+ +-+ | 2 4         2    2     (b x  - a)\|- a b  + 2a b x
+--R       \|a \|b \|b x  + 2a b x  + a  log(---------------------------)
+--R                                                      2
+--R                                                   b x  + a
+--R     + 
+--R                                    +-+
+--R              2       +-----+     x\|b
+--R       (- 2b x  - 2a)\|- a b atan(-----)
+--R                                    +-+
+--R                                   \|a
+--R  /
+--R                       +-------------------+
+--R       +-----+ +-+ +-+ | 2 4         2    2
+--R     2\|- a b \|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1228
+
+--S 1229 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2       2
+--R        \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ---------------------------------
+--R                    +-------------------+
+--R             2      | 2 4         2    2
+--R         (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1229
+
+--S 1230 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            +-------------------+       +---+                             +-+
+--R    +-+ +-+ | 2 4         2    2      x\|a b           2      +---+     x\|b
+--R   \|a \|b \|b x  + 2a b x  + a  atan(-------) + (- b x  - a)\|a b atan(-----)
+--R                                         a                                +-+
+--R                                                                         \|a
+--R   ---------------------------------------------------------------------------
+--R                                      +-------------------+
+--R                        +-+ +-+ +---+ | 2 4         2    2
+--R                       \|a \|b \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1230
+
+--S 1231 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2       2
+--R        \|b x  + 2a b x  + a   - b x  - a
+--R   (7)  ---------------------------------
+--R                    +-------------------+
+--R             2      | 2 4         2    2
+--R         (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1231
+
+)clear all
+
+--S 1232 of 1370
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4)^(1/2))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R          +-------------------+
+--R          | 2 4         2    2
+--R        x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1232
+
+--S 1233 of 1370
+r0:=(a+b*x^2)*log(x)/(a*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+    1/2*(a+b*x^2)*log(a+b*x^2)/(a*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R              2            2             2
+--R        (- b x  - a)log(b x  + a) + (2b x  + 2a)log(x)
+--R   (2)  ----------------------------------------------
+--R                      +-------------------+
+--R                      | 2 4         2    2
+--R                   2a\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1233
+
+--S 1234 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 2
+--R        - log(b x  + a) + 2log(x)
+--R   (3)  -------------------------
+--R                    2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1234
+
+--S 1235 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   +-------------------+
+--R                 2                 | 2 4         2    2
+--R       (- log(b x  + a) + 2log(x))\|b x  + 2a b x  + a
+--R     + 
+--R           2            2               2
+--R       (b x  + a)log(b x  + a) + (- 2b x  - 2a)log(x)
+--R  /
+--R        +-------------------+
+--R        | 2 4         2    2
+--R     2a\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1235
+
+--S 1236 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 4         2    2       2
+--R         \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ----------------------------------
+--R                     +-------------------+
+--R            3        | 2 4         2    2
+--R        (b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1236
+
+)clear all
+
+--S 1237 of 1370
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4)^(1/2))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         2 | 2 4         2    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1237
+
+--S 1238 of 1370
+r0:=(-a-b*x^2)/(a*x*sqrt(a^2+2*a*b*x^2+b^2*x^4))-(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))*sqrt(b)/(a^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                 +-+
+--R              3        +-+     x\|b           2      +-+
+--R        (- b x  - a x)\|b atan(-----) + (- b x  - a)\|a
+--R                                 +-+
+--R                                \|a
+--R   (2)  ------------------------------------------------
+--R                          +-------------------+
+--R                      +-+ | 2 4         2    2
+--R                  a x\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1238
+
+--S 1239 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           +---+
+--R                           |  b       2                      +-+
+--R           +---+    - 2a x |- -  + b x  - a                  |b
+--R           |  b           \|  a                    +-+     a |-
+--R         x |- - log(-----------------------) - 2   |b       \|a
+--R          \|  a                2                 x |- atan(-----) - 1
+--R                            b x  + a              \|a       b x
+--R   (3)  [---------------------------------------,--------------------]
+--R                           2a x                           a x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1239
+
+--S 1240 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                   +---+
+--R                                                   |  b       2
+--R         +---+     +-------------------+    - 2a x |- -  + b x  - a
+--R         |  b  +-+ | 2 4         2    2           \|  a
+--R       x |- - \|a \|b x  + 2a b x  + a  log(-----------------------)
+--R        \|  a                                          2
+--R                                                    b x  + a
+--R     + 
+--R                                +-+          +-------------------+
+--R            3         +-+     x\|b       +-+ | 2 4         2    2
+--R       (2b x  + 2a x)\|b atan(-----) - 2\|a \|b x  + 2a b x  + a
+--R                                +-+
+--R                               \|a
+--R     + 
+--R            2       +-+
+--R       (2b x  + 2a)\|a
+--R  /
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R     2a x\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1240
+
+--S 1241 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 4         2    2       2
+--R         \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -----------------------------------
+--R                      +-------------------+
+--R            4      2  | 2 4         2    2
+--R        (b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1241
+
+--S 1242 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                           +-+
+--R                                                                           |b
+--R                              +-+          +-+ +-------------------+     a |-
+--R           3        +-+     x\|b       +-+ |b  | 2 4         2    2       \|a
+--R       (b x  + a x)\|b atan(-----) + x\|a  |- \|b x  + 2a b x  + a  atan(-----)
+--R                              +-+         \|a                             b x
+--R                             \|a
+--R     + 
+--R              +-------------------+
+--R          +-+ | 2 4         2    2        2      +-+
+--R       - \|a \|b x  + 2a b x  + a   + (b x  + a)\|a
+--R  /
+--R             +-------------------+
+--R         +-+ | 2 4         2    2
+--R     a x\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1242
+
+--S 1243 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 4         2    2       2
+--R         \|b x  + 2a b x  + a   - b x  - a
+--R   (7)  -----------------------------------
+--R                      +-------------------+
+--R            4      2  | 2 4         2    2
+--R        (b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1243
+
+)clear all
+
+--S 1244 of 1370
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4)^(1/2))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         3 | 2 4         2    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1244
+
+--S 1245 of 1370
+r0:=-b*(a+b*x^2)*log(x)/(a^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+    1/2*b*(a+b*x^2)*log(a+b*x^2)/(a^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+    1/2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a^2*x^2)
+--R 
+--R
+--R   (2)
+--R         2 4        2        2             2 4         2           2 4         2
+--R       (b x  + a b x )log(b x  + a) + (- 2b x  - 2a b x )log(x) - b x  - 2a b x
+--R     + 
+--R          2
+--R       - a
+--R  /
+--R           +-------------------+
+--R       2 2 | 2 4         2    2
+--R     2a x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1245
+
+--S 1246 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2       2            2
+--R        b x log(b x  + a) - 2b x log(x) - a
+--R   (3)  -----------------------------------
+--R                         2 2
+--R                       2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1246
+
+--S 1247 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +-------------------+
+--R           2       2            2            | 2 4         2    2
+--R       (b x log(b x  + a) - 2b x log(x) - a)\|b x  + 2a b x  + a
+--R     + 
+--R           2 4        2        2           2 4         2           2 4         2
+--R       (- b x  - a b x )log(b x  + a) + (2b x  + 2a b x )log(x) + b x  + 2a b x
+--R     + 
+--R        2
+--R       a
+--R  /
+--R           +-------------------+
+--R       2 2 | 2 4         2    2
+--R     2a x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1247
+
+--S 1248 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 4         2    2       2
+--R         \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -----------------------------------
+--R                      +-------------------+
+--R            5      3  | 2 4         2    2
+--R        (b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1248
+
+)clear all
+
+--S 1249 of 1370
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4)^(1/2))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         4 | 2 4         2    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1249
+
+--S 1250 of 1370
+r0:=1/3*(-a-b*x^2)/(a*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))+b*(a+b*x^2)/_
+    (a^2*x*sqrt(a^2+2*a*b*x^2+b^2*x^4))+b^(3/2)*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(a^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                    +-+
+--R           2 5         3  +-+     x\|b        2 4         2    2  +-+
+--R        (3b x  + 3a b x )\|b atan(-----) + (3b x  + 2a b x  - a )\|a
+--R                                    +-+
+--R                                   \|a
+--R   (2)  -------------------------------------------------------------
+--R                                 +-------------------+
+--R                         2 3 +-+ | 2 4         2    2
+--R                       3a x \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1250
+
+--S 1251 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        +---+
+--R                        |  b       2
+--R          +---+    2a x |- -  + b x  - a
+--R        3 |  b         \|  a                    2
+--R    3b x  |- - log(---------------------) + 6b x  - 2a
+--R         \|  a               2
+--R                          b x  + a
+--R   [--------------------------------------------------,
+--R                             2 3
+--R                           6a x
+--R                      +-+
+--R                      |b
+--R            +-+     a |-
+--R          3 |b       \|a         2
+--R    - 3b x  |- atan(-----) + 3b x  - a
+--R           \|a       b x
+--R    ----------------------------------]
+--R                     2 3
+--R                   3a x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1251
+
+--S 1252 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                     +---+
+--R                                                     |  b       2
+--R             +---+     +-------------------+    2a x |- -  + b x  - a
+--R           3 |  b  +-+ | 2 4         2    2         \|  a
+--R       3b x  |- - \|a \|b x  + 2a b x  + a  log(---------------------)
+--R            \|  a                                         2
+--R                                                       b x  + a
+--R     + 
+--R                                     +-+
+--R            2 5         3  +-+     x\|b
+--R       (- 6b x  - 6a b x )\|b atan(-----)
+--R                                     +-+
+--R                                    \|a
+--R     + 
+--R                        +-------------------+
+--R            2       +-+ | 2 4         2    2         2 4         2     2  +-+
+--R       (6b x  - 2a)\|a \|b x  + 2a b x  + a   + (- 6b x  - 4a b x  + 2a )\|a
+--R  /
+--R               +-------------------+
+--R       2 3 +-+ | 2 4         2    2
+--R     6a x \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1252
+
+--S 1253 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 4         2    2       2
+--R         \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -----------------------------------
+--R                      +-------------------+
+--R            6      4  | 2 4         2    2
+--R        (b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1253
+
+--S 1254 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                     +-+
+--R            2 5         3  +-+     x\|b
+--R       (- 3b x  - 3a b x )\|b atan(-----)
+--R                                     +-+
+--R                                    \|a
+--R     + 
+--R                                                   +-+
+--R                                                   |b
+--R                   +-+ +-------------------+     a |-
+--R             3 +-+ |b  | 2 4         2    2       \|a
+--R       - 3b x \|a  |- \|b x  + 2a b x  + a  atan(-----)
+--R                  \|a                             b x
+--R     + 
+--R                       +-------------------+
+--R            2      +-+ | 2 4         2    2         2 4         2    2  +-+
+--R       (3b x  - a)\|a \|b x  + 2a b x  + a   + (- 3b x  - 2a b x  + a )\|a
+--R  /
+--R               +-------------------+
+--R       2 3 +-+ | 2 4         2    2
+--R     3a x \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1254
+
+--S 1255 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 4         2    2       2
+--R         \|b x  + 2a b x  + a   - b x  - a
+--R   (7)  -----------------------------------
+--R                      +-------------------+
+--R            6      4  | 2 4         2    2
+--R        (b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1255
+
+)clear all
+
+--S 1256 of 1370
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                              4
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1256
+
+--S 1257 of 1370
+r0:=1/4*a*x*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+    5/8*x/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/8*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(b^(5/2)*sqrt(a)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                      +-+
+--R           2 4         2     2      x\|b            3         +-+ +-+
+--R        (3b x  + 6a b x  + 3a )atan(-----) + (- 5b x  - 3a x)\|a \|b
+--R                                      +-+
+--R                                     \|a
+--R   (2)  -------------------------------------------------------------
+--R                                        +-------------------+
+--R                   3 2       2  +-+ +-+ | 2 4         2    2
+--R                (8b x  + 8a b )\|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1257
+
+--S 1258 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                        2      +-----+
+--R            2 4         2     2     (b x  - a)\|- a b  + 2a b x
+--R         (3b x  + 6a b x  + 3a )log(---------------------------)
+--R                                                 2
+--R                                              b x  + a
+--R       + 
+--R                 3         +-----+
+--R         (- 10b x  - 6a x)\|- a b
+--R    /
+--R           4 4        3 2      2 2  +-----+
+--R       (16b x  + 32a b x  + 16a b )\|- a b
+--R     ,
+--R                                  +---+
+--R       2 4         2     2      x\|a b            3         +---+
+--R    (3b x  + 6a b x  + 3a )atan(-------) + (- 5b x  - 3a x)\|a b
+--R                                   a
+--R    -------------------------------------------------------------]
+--R                      4 4        3 2     2 2  +---+
+--R                   (8b x  + 16a b x  + 8a b )\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1258
+
+--S 1259 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                         +-------------------+
+--R            2 4         2     2  +-+ +-+ | 2 4         2    2
+--R         (3b x  + 6a b x  + 3a )\|a \|b \|b x  + 2a b x  + a
+--R      *
+--R                 2      +-----+
+--R             (b x  - a)\|- a b  + 2a b x
+--R         log(---------------------------)
+--R                          2
+--R                       b x  + a
+--R     + 
+--R                                                           +-+
+--R            3 6        2 4      2   2     3  +-----+     x\|b
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )\|- a b atan(-----)
+--R                                                           +-+
+--R                                                          \|a
+--R     + 
+--R                                         +-------------------+
+--R               3         +-----+ +-+ +-+ | 2 4         2    2
+--R       (- 10b x  - 6a x)\|- a b \|a \|b \|b x  + 2a b x  + a
+--R     + 
+--R           2 5          3     2   +-----+ +-+ +-+
+--R       (10b x  + 16a b x  + 6a x)\|- a b \|a \|b
+--R  /
+--R                                                  +-------------------+
+--R         4 4        3 2      2 2  +-----+ +-+ +-+ | 2 4         2    2
+--R     (16b x  + 32a b x  + 16a b )\|- a b \|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1259
+
+--S 1260 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R                   +-------------------+
+--R                 4 | 2 4         2    2       6      4
+--R                x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1260
+
+--S 1261 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                       +-------------------+       +---+
+--R          2 4         2     2  +-+ +-+ | 2 4         2    2      x\|a b
+--R       (3b x  + 6a b x  + 3a )\|a \|b \|b x  + 2a b x  + a  atan(-------)
+--R                                                                    a
+--R     + 
+--R                                                       +-+
+--R            3 6       2 4     2   2     3  +---+     x\|b
+--R       (- 3b x  - 9a b x  - 9a b x  - 3a )\|a b atan(-----)
+--R                                                       +-+
+--R                                                      \|a
+--R     + 
+--R                                      +-------------------+
+--R              3         +-+ +-+ +---+ | 2 4         2    2
+--R       (- 5b x  - 3a x)\|a \|b \|a b \|b x  + 2a b x  + a
+--R     + 
+--R          2 5         3     2   +-+ +-+ +---+
+--R       (5b x  + 8a b x  + 3a x)\|a \|b \|a b
+--R  /
+--R                                              +-------------------+
+--R        4 4        3 2     2 2  +-+ +-+ +---+ | 2 4         2    2
+--R     (8b x  + 16a b x  + 8a b )\|a \|b \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1261
+
+--S 1262 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R                   +-------------------+
+--R                 4 | 2 4         2    2       6      4
+--R                x \|b x  + 2a b x  + a   - b x  - a x
+--R   (7)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1262
+
+)clear all
+
+--S 1263 of 1370
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                              3
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1263
+
+--S 1264 of 1370
+r0:=1/4*x^4*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                           4
+--R                          x
+--R   (2)  -------------------------------------
+--R                        +-------------------+
+--R               2     2  | 2 4         2    2
+--R        (4a b x  + 4a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1264
+
+--S 1265 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    2
+--R              - 2b x  - a
+--R   (3)  -----------------------
+--R          4 4       3 2     2 2
+--R        4b x  + 8a b x  + 4a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1265
+
+--S 1266 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                         +-------------------+
+--R                 2    2  | 2 4         2    2     3 6      2 4
+--R        (- 2a b x  - a )\|b x  + 2a b x  + a   - b x  - a b x
+--R   (4)  ------------------------------------------------------
+--R                                       +-------------------+
+--R                4 4     2 3 2     3 2  | 2 4         2    2
+--R           (4a b x  + 8a b x  + 4a b )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1266
+
+--S 1267 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R                 3 | 2 4         2    2       5      3
+--R                x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1267
+
+)clear all
+
+--S 1268 of 1370
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                              2
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1268
+
+--S 1269 of 1370
+r0:=1/4*x^3*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+    1/8*x/(a*b*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/8*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*b^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                    +-+
+--R          2 4         2    2      x\|b         3        +-+ +-+
+--R        (b x  + 2a b x  + a )atan(-----) + (b x  - a x)\|a \|b
+--R                                    +-+
+--R                                   \|a
+--R   (2)  -------------------------------------------------------
+--R                                      +-------------------+
+--R                  2 2     2   +-+ +-+ | 2 4         2    2
+--R             (8a b x  + 8a b)\|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1269
+
+--S 1270 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                      2      +-----+
+--R           2 4         2    2     (b x  - a)\|- a b  + 2a b x
+--R         (b x  + 2a b x  + a )log(---------------------------)
+--R                                               2
+--R                                            b x  + a
+--R       + 
+--R              3         +-----+
+--R         (2b x  - 2a x)\|- a b
+--R    /
+--R             3 4      2 2 2      3   +-----+
+--R       (16a b x  + 32a b x  + 16a b)\|- a b
+--R     ,
+--R                                +---+
+--R      2 4         2    2      x\|a b         3        +---+
+--R    (b x  + 2a b x  + a )atan(-------) + (b x  - a x)\|a b
+--R                                 a
+--R    -------------------------------------------------------]
+--R                    3 4      2 2 2     3   +---+
+--R               (8a b x  + 16a b x  + 8a b)\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1270
+
+--S 1271 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                       +-------------------+
+--R           2 4         2    2  +-+ +-+ | 2 4         2    2
+--R         (b x  + 2a b x  + a )\|a \|b \|b x  + 2a b x  + a
+--R      *
+--R                 2      +-----+
+--R             (b x  - a)\|- a b  + 2a b x
+--R         log(---------------------------)
+--R                          2
+--R                       b x  + a
+--R     + 
+--R                                                         +-+
+--R            3 6       2 4     2   2     3  +-----+     x\|b
+--R       (- 2b x  - 6a b x  - 6a b x  - 2a )\|- a b atan(-----)
+--R                                                         +-+
+--R                                                        \|a
+--R     + 
+--R                                      +-------------------+
+--R            3         +-----+ +-+ +-+ | 2 4         2    2
+--R       (2b x  - 2a x)\|- a b \|a \|b \|b x  + 2a b x  + a
+--R     + 
+--R            2 5     2   +-----+ +-+ +-+
+--R       (- 2b x  + 2a x)\|- a b \|a \|b
+--R  /
+--R                                                   +-------------------+
+--R           3 4      2 2 2      3   +-----+ +-+ +-+ | 2 4         2    2
+--R     (16a b x  + 32a b x  + 16a b)\|- a b \|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1271
+
+--S 1272 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R                   +-------------------+
+--R                 2 | 2 4         2    2       4      2
+--R                x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1272
+
+--S 1273 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                     +-------------------+       +---+
+--R         2 4         2    2  +-+ +-+ | 2 4         2    2      x\|a b
+--R       (b x  + 2a b x  + a )\|a \|b \|b x  + 2a b x  + a  atan(-------)
+--R                                                                  a
+--R     + 
+--R                                                     +-+
+--R           3 6       2 4     2   2    3  +---+     x\|b
+--R       (- b x  - 3a b x  - 3a b x  - a )\|a b atan(-----)
+--R                                                     +-+
+--R                                                    \|a
+--R     + 
+--R                                  +-------------------+
+--R           3        +-+ +-+ +---+ | 2 4         2    2
+--R       (b x  - a x)\|a \|b \|a b \|b x  + 2a b x  + a
+--R     + 
+--R           2 5    2   +-+ +-+ +---+
+--R       (- b x  + a x)\|a \|b \|a b
+--R  /
+--R                                               +-------------------+
+--R          3 4      2 2 2     3   +-+ +-+ +---+ | 2 4         2    2
+--R     (8a b x  + 16a b x  + 8a b)\|a \|b \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1273
+
+--S 1274 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R                   +-------------------+
+--R                 2 | 2 4         2    2       4      2
+--R                x \|b x  + 2a b x  + a   - b x  - a x
+--R   (7)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1274
+
+)clear all
+
+--S 1275 of 1370
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1275
+
+--S 1276 of 1370
+r0:=1/4*(-a-b*x^2)/(b*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                            1
+--R   (2)  - ------------------------------------
+--R                         +-------------------+
+--R             2 2         | 2 4         2    2
+--R          (4b x  + 4a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1276
+
+--S 1277 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     1
+--R   (3)  - ----------------------
+--R            3 4       2 2     2
+--R          4b x  + 8a b x  + 4a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1277
+
+--S 1278 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                 +-------------------+
+--R                 | 2 4         2    2       2
+--R              - \|b x  + 2a b x  + a   + b x  + a
+--R   (4)  ----------------------------------------------
+--R                                 +-------------------+
+--R           3 4       2 2     2   | 2 4         2    2
+--R        (4b x  + 8a b x  + 4a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1278
+
+--S 1279 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                   +-------------------+
+--R                   | 2 4         2    2       3
+--R                 x\|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1279
+
+)clear all
+
+--S 1280 of 1370
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1280
+
+--S 1281 of 1370
+r0:=1/4*x*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+3/8*x/(a^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/8*(a+b*x^2)*atan(x*sqrt(b)/_
+    sqrt(a))/(a^(5/2)*sqrt(b)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                      +-+
+--R           2 4         2     2      x\|b          3         +-+ +-+
+--R        (3b x  + 6a b x  + 3a )atan(-----) + (3b x  + 5a x)\|a \|b
+--R                                      +-+
+--R                                     \|a
+--R   (2)  -----------------------------------------------------------
+--R                                       +-------------------+
+--R                  2   2     3  +-+ +-+ | 2 4         2    2
+--R               (8a b x  + 8a )\|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1281
+
+--S 1282 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                        2      +-----+
+--R            2 4         2     2     (b x  - a)\|- a b  + 2a b x
+--R         (3b x  + 6a b x  + 3a )log(---------------------------)
+--R                                                 2
+--R                                              b x  + a
+--R       + 
+--R              3          +-----+
+--R         (6b x  + 10a x)\|- a b
+--R    /
+--R           2 2 4      3   2      4  +-----+
+--R       (16a b x  + 32a b x  + 16a )\|- a b
+--R     ,
+--R                                  +---+
+--R       2 4         2     2      x\|a b          3         +---+
+--R    (3b x  + 6a b x  + 3a )atan(-------) + (3b x  + 5a x)\|a b
+--R                                   a
+--R    -----------------------------------------------------------]
+--R                     2 2 4      3   2     4  +---+
+--R                  (8a b x  + 16a b x  + 8a )\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1282
+
+--S 1283 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                         +-------------------+
+--R            2 4         2     2  +-+ +-+ | 2 4         2    2
+--R         (3b x  + 6a b x  + 3a )\|a \|b \|b x  + 2a b x  + a
+--R      *
+--R                 2      +-----+
+--R             (b x  - a)\|- a b  + 2a b x
+--R         log(---------------------------)
+--R                          2
+--R                       b x  + a
+--R     + 
+--R                                                           +-+
+--R            3 6        2 4      2   2     3  +-----+     x\|b
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )\|- a b atan(-----)
+--R                                                           +-+
+--R                                                          \|a
+--R     + 
+--R                                       +-------------------+
+--R            3          +-----+ +-+ +-+ | 2 4         2    2
+--R       (6b x  + 10a x)\|- a b \|a \|b \|b x  + 2a b x  + a
+--R     + 
+--R            2 5          3      2   +-----+ +-+ +-+
+--R       (- 6b x  - 16a b x  - 10a x)\|- a b \|a \|b
+--R  /
+--R                                                  +-------------------+
+--R         2 2 4      3   2      4  +-----+ +-+ +-+ | 2 4         2    2
+--R     (16a b x  + 32a b x  + 16a )\|- a b \|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1283
+
+--S 1284 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R                   +-------------------+
+--R                   | 2 4         2    2       2
+--R                  \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1284
+
+--S 1285 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                       +-------------------+       +---+
+--R          2 4         2     2  +-+ +-+ | 2 4         2    2      x\|a b
+--R       (3b x  + 6a b x  + 3a )\|a \|b \|b x  + 2a b x  + a  atan(-------)
+--R                                                                    a
+--R     + 
+--R                                                       +-+
+--R            3 6       2 4     2   2     3  +---+     x\|b
+--R       (- 3b x  - 9a b x  - 9a b x  - 3a )\|a b atan(-----)
+--R                                                       +-+
+--R                                                      \|a
+--R     + 
+--R                                    +-------------------+
+--R            3         +-+ +-+ +---+ | 2 4         2    2
+--R       (3b x  + 5a x)\|a \|b \|a b \|b x  + 2a b x  + a
+--R     + 
+--R            2 5         3     2   +-+ +-+ +---+
+--R       (- 3b x  - 8a b x  - 5a x)\|a \|b \|a b
+--R  /
+--R                                              +-------------------+
+--R        2 2 4      3   2     4  +-+ +-+ +---+ | 2 4         2    2
+--R     (8a b x  + 16a b x  + 8a )\|a \|b \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1285
+
+--S 1286 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R                   +-------------------+
+--R                   | 2 4         2    2       2
+--R                  \|b x  + 2a b x  + a   - b x  - a
+--R   (7)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1286
+
+)clear all
+
+--S 1287 of 1370
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R                               +-------------------+
+--R          2 5         3    2   | 2 4         2    2
+--R        (b x  + 2a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1287
+
+--S 1288 of 1370
+r0:=1/4*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1/2/(a^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))+(a+b*x^2)*log(x)/(a^3*sqrt(a^2+_
+    2*a*b*x^2+b^2*x^4))-1/2*(a+b*x^2)*log(a+b*x^2)/(a^3*sqrt(a^2+_
+    2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2 4         2     2        2           2 4         2     2
+--R       (- 2b x  - 4a b x  - 2a )log(b x  + a) + (4b x  + 8a b x  + 4a )log(x)
+--R     + 
+--R             2     2
+--R       2a b x  + 3a
+--R  /
+--R                     +-------------------+
+--R        3   2     4  | 2 4         2    2
+--R     (4a b x  + 4a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1288
+
+--S 1289 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2 4         2     2        2           2 4         2     2
+--R       (- 2b x  - 4a b x  - 2a )log(b x  + a) + (4b x  + 8a b x  + 4a )log(x)
+--R     + 
+--R             2     2
+--R       2a b x  + 3a
+--R  /
+--R       3 2 4     4   2     5
+--R     4a b x  + 8a b x  + 4a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1289
+
+--S 1290 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2 4         2     2        2
+--R           (- 2b x  - 4a b x  - 2a )log(b x  + a)
+--R         + 
+--R              2 4         2     2                2     2
+--R           (4b x  + 8a b x  + 4a )log(x) + 2a b x  + 3a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          3 6       2 4     2   2     3        2
+--R       (2b x  + 6a b x  + 6a b x  + 2a )log(b x  + a)
+--R     + 
+--R            3 6        2 4      2   2     3              2 4     2   2     3
+--R       (- 4b x  - 12a b x  - 12a b x  - 4a )log(x) - 2a b x  - 5a b x  - 3a
+--R  /
+--R                               +-------------------+
+--R        3 2 4     4   2     5  | 2 4         2    2
+--R     (4a b x  + 8a b x  + 4a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1290
+
+--S 1291 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                    +-------------------+
+--R                    | 2 4         2    2       2
+--R                   \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ------------------------------------------------------
+--R                                         +-------------------+
+--R          3 7       2 5     2   3    3   | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1291
+
+)clear all
+
+--S 1292 of 1370
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                +-------------------+
+--R          2 6         4    2 2  | 2 4         2    2
+--R        (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1292
+
+--S 1293 of 1370
+r0:=1/4*(a+b*x^2)/(a*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/8/(a^2*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))-15/8*(a+b*x^2)/(a^3*x*sqrt(a^2+_
+    2*a*b*x^2+b^2*x^4))-15/8*(a+b*x^2)*atan(x*sqrt(b)/sqrt(a))*_
+    sqrt(b)/(a^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                               +-+
+--R             2 5          3      2   +-+     x\|b
+--R       (- 15b x  - 30a b x  - 15a x)\|b atan(-----)
+--R                                               +-+
+--R                                              \|a
+--R     + 
+--R             2 4          2     2  +-+
+--R       (- 15b x  - 25a b x  - 8a )\|a
+--R  /
+--R                          +-------------------+
+--R        3   3     4   +-+ | 2 4         2    2
+--R     (8a b x  + 8a x)\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1293
+
+--S 1294 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                     +---+
+--R                                                     |  b       2
+--R                                     +---+    - 2a x |- -  + b x  - a
+--R             2 5          3      2   |  b           \|  a                   2 4
+--R         (15b x  + 30a b x  + 15a x) |- - log(-----------------------) - 30b x
+--R                                    \|  a                2
+--R                                                      b x  + a
+--R       + 
+--R                  2      2
+--R         - 50a b x  - 16a
+--R    /
+--R          3 2 5      4   3      5
+--R       16a b x  + 32a b x  + 16a x
+--R     ,
+--R                                          +-+
+--R                                          |b
+--R                                +-+     a |-
+--R        2 5          3      2   |b       \|a        2 4          2     2
+--R    (15b x  + 30a b x  + 15a x) |- atan(-----) - 15b x  - 25a b x  - 8a
+--R                               \|a       b x
+--R    --------------------------------------------------------------------]
+--R                            3 2 5      4   3     5
+--R                          8a b x  + 16a b x  + 8a x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1294
+
+--S 1295 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                     +---+     +-------------------+
+--R             2 5          3      2   |  b  +-+ | 2 4         2    2
+--R         (15b x  + 30a b x  + 15a x) |- - \|a \|b x  + 2a b x  + a
+--R                                    \|  a
+--R      *
+--R                    +---+
+--R                    |  b       2
+--R             - 2a x |- -  + b x  - a
+--R                   \|  a
+--R         log(-----------------------)
+--R                        2
+--R                     b x  + a
+--R     + 
+--R                                                        +-+
+--R           3 7        2 5      2   3      3   +-+     x\|b
+--R       (30b x  + 90a b x  + 90a b x  + 30a x)\|b atan(-----)
+--R                                                        +-+
+--R                                                       \|a
+--R     + 
+--R                                        +-------------------+
+--R             2 4          2      2  +-+ | 2 4         2    2
+--R       (- 30b x  - 50a b x  - 16a )\|a \|b x  + 2a b x  + a
+--R     + 
+--R           3 6        2 4      2   2      3  +-+
+--R       (30b x  + 80a b x  + 66a b x  + 16a )\|a
+--R  /
+--R                                       +-------------------+
+--R         3 2 5      4   3      5   +-+ | 2 4         2    2
+--R     (16a b x  + 32a b x  + 16a x)\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1295
+
+--S 1296 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R                    +-------------------+
+--R                    | 2 4         2    2       2
+--R                   \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -------------------------------------------------------
+--R                                          +-------------------+
+--R          3 8       2 6     2   4    3 2  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1296
+
+--S 1297 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                        +-+
+--R           3 7        2 5      2   3      3   +-+     x\|b
+--R       (15b x  + 45a b x  + 45a b x  + 15a x)\|b atan(-----)
+--R                                                        +-+
+--R                                                       \|a
+--R     + 
+--R                                                                       +-+
+--R                                                                       |b
+--R                                       +-+ +-------------------+     a |-
+--R           2 5          3      2   +-+ |b  | 2 4         2    2       \|a
+--R       (15b x  + 30a b x  + 15a x)\|a  |- \|b x  + 2a b x  + a  atan(-----)
+--R                                      \|a                             b x
+--R     + 
+--R                                       +-------------------+
+--R             2 4          2     2  +-+ | 2 4         2    2
+--R       (- 15b x  - 25a b x  - 8a )\|a \|b x  + 2a b x  + a
+--R     + 
+--R           3 6        2 4      2   2     3  +-+
+--R       (15b x  + 40a b x  + 33a b x  + 8a )\|a
+--R  /
+--R                                     +-------------------+
+--R        3 2 5      4   3     5   +-+ | 2 4         2    2
+--R     (8a b x  + 16a b x  + 8a x)\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1297
+
+--S 1298 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R                    +-------------------+
+--R                    | 2 4         2    2       2
+--R                   \|b x  + 2a b x  + a   - b x  - a
+--R   (7)  -------------------------------------------------------
+--R                                          +-------------------+
+--R          3 8       2 6     2   4    3 2  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1298
+
+)clear all
+
+--S 1299 of 1370
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                +-------------------+
+--R          2 7         5    2 3  | 2 4         2    2
+--R        (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1299
+
+--S 1300 of 1370
+r0:=1/4*(a+b*x^2)/(a*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    3/4/(a^2*x^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))-3*b*(a+b*x^2)*_
+    log(x)/(a^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/2*b*(a+b*x^2)*_
+    log(a+b*x^2)/(a^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+    3/2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a^4*x^2)
+--R 
+--R
+--R   (2)
+--R          3 6        2 4     2   2        2
+--R       (6b x  + 12a b x  + 6a b x )log(b x  + a)
+--R     + 
+--R           3 6        2 4      2   2            3 6        2 4      2   2     3
+--R     (- 12b x  - 24a b x  - 12a b x )log(x) - 6b x  - 18a b x  - 15a b x  - 2a
+--R  /
+--R                       +-------------------+
+--R        4   4     5 2  | 2 4         2    2
+--R     (4a b x  + 4a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1300
+
+--S 1301 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3 6        2 4     2   2        2
+--R       (6b x  + 12a b x  + 6a b x )log(b x  + a)
+--R     + 
+--R             3 6        2 4      2   2              2 4     2   2     3
+--R       (- 12b x  - 24a b x  - 12a b x )log(x) - 6a b x  - 9a b x  - 2a
+--R  /
+--R       4 2 6     5   4     6 2
+--R     4a b x  + 8a b x  + 4a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1301
+
+--S 1302 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3 6        2 4     2   2        2
+--R           (6b x  + 12a b x  + 6a b x )log(b x  + a)
+--R         + 
+--R                 3 6        2 4      2   2              2 4     2   2     3
+--R           (- 12b x  - 24a b x  - 12a b x )log(x) - 6a b x  - 9a b x  - 2a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 8        3 6      2 2 4     3   2        2
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a b x )log(b x  + a)
+--R     + 
+--R           4 8        3 6      2 2 4      3   2            4 8        3 6
+--R       (12b x  + 36a b x  + 36a b x  + 12a b x )log(x) + 6b x  + 24a b x
+--R     + 
+--R          2 2 4      3   2     4
+--R       33a b x  + 17a b x  + 2a
+--R  /
+--R                                 +-------------------+
+--R        4 2 6     5   4     6 2  | 2 4         2    2
+--R     (4a b x  + 8a b x  + 4a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1302
+
+--S 1303 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R                    +-------------------+
+--R                    | 2 4         2    2       2
+--R                   \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -------------------------------------------------------
+--R                                          +-------------------+
+--R          3 9       2 7     2   5    3 3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1303
+
+)clear all
+
+--S 1304 of 1370
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                +-------------------+
+--R          2 8         6    2 4  | 2 4         2    2
+--R        (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1304
+
+--S 1305 of 1370
+r0:=1/4*(a+b*x^2)/(a*x^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    7/8/(a^2*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))-35/24*(a+b*x^2)/_
+    (a^3*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))+35/8*b*(a+b*x^2)/_
+    (a^4*x*sqrt(a^2+2*a*b*x^2+b^2*x^4))+35/8*b^(3/2)*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(a^(9/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                                   +-+
+--R            3 7         2 5       2   3  +-+     x\|b
+--R       (105b x  + 210a b x  + 105a b x )\|b atan(-----)
+--R                                                   +-+
+--R                                                  \|a
+--R     + 
+--R            3 6         2 4      2   2     3  +-+
+--R       (105b x  + 175a b x  + 56a b x  - 8a )\|a
+--R  /
+--R                             +-------------------+
+--R         4   5      5 3  +-+ | 2 4         2    2
+--R     (24a b x  + 24a x )\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1305
+
+--S 1306 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                         +---+
+--R                                                         |  b       2
+--R                                           +---+    2a x |- -  + b x  - a
+--R              3 7         2 5       2   3  |  b         \|  a
+--R         (105b x  + 210a b x  + 105a b x ) |- - log(---------------------)
+--R                                          \|  a               2
+--R                                                           b x  + a
+--R       + 
+--R             3 6         2 4       2   2      3
+--R         210b x  + 350a b x  + 112a b x  - 16a
+--R    /
+--R          4 2 7      5   5      6 3
+--R       48a b x  + 96a b x  + 48a x
+--R     ,
+--R
+--R                                                       +-+
+--R                                                       |b
+--R                                             +-+     a |-
+--R                3 7         2 5       2   3  |b       \|a         3 6
+--R         (- 105b x  - 210a b x  - 105a b x ) |- atan(-----) + 105b x
+--R                                            \|a       b x
+--R       + 
+--R               2 4      2   2     3
+--R         175a b x  + 56a b x  - 8a
+--R    /
+--R          4 2 7      5   5      6 3
+--R       24a b x  + 48a b x  + 24a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1306
+
+--S 1307 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                           +---+     +-------------------+
+--R              3 7         2 5       2   3  |  b  +-+ | 2 4         2    2
+--R         (105b x  + 210a b x  + 105a b x ) |- - \|a \|b x  + 2a b x  + a
+--R                                          \|  a
+--R      *
+--R                  +---+
+--R                  |  b       2
+--R             2a x |- -  + b x  - a
+--R                 \|  a
+--R         log(---------------------)
+--R                       2
+--R                    b x  + a
+--R     + 
+--R                                                                 +-+
+--R              4 9         3 7       2 2 5       3   3  +-+     x\|b
+--R       (- 210b x  - 630a b x  - 630a b x  - 210a b x )\|b atan(-----)
+--R                                                                 +-+
+--R                                                                \|a
+--R     + 
+--R                                                    +-------------------+
+--R            3 6         2 4       2   2      3  +-+ | 2 4         2    2
+--R       (210b x  + 350a b x  + 112a b x  - 16a )\|a \|b x  + 2a b x  + a
+--R     + 
+--R              4 8         3 6       2 2 4      3   2      4  +-+
+--R       (- 210b x  - 560a b x  - 462a b x  - 96a b x  + 16a )\|a
+--R  /
+--R                                        +-------------------+
+--R         4 2 7      5   5      6 3  +-+ | 2 4         2    2
+--R     (48a b x  + 96a b x  + 48a x )\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1307
+
+--S 1308 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R                     +-------------------+
+--R                     | 2 4         2    2       2
+--R                    \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  --------------------------------------------------------
+--R                                           +-------------------+
+--R          3 10       2 8     2   6    3 4  | 2 4         2    2
+--R        (b x   + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1308
+
+--S 1309 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                 +-+
+--R              4 9         3 7       2 2 5       3   3  +-+     x\|b
+--R       (- 105b x  - 315a b x  - 315a b x  - 105a b x )\|b atan(-----)
+--R                                                                 +-+
+--R                                                                \|a
+--R     + 
+--R                                                 +-+ +-------------------+
+--R                3 7         2 5       2   3  +-+ |b  | 2 4         2    2
+--R         (- 105b x  - 210a b x  - 105a b x )\|a  |- \|b x  + 2a b x  + a
+--R                                                \|a
+--R      *
+--R                +-+
+--R                |b
+--R              a |-
+--R               \|a
+--R         atan(-----)
+--R               b x
+--R     + 
+--R                                                  +-------------------+
+--R            3 6         2 4      2   2     3  +-+ | 2 4         2    2
+--R       (105b x  + 175a b x  + 56a b x  - 8a )\|a \|b x  + 2a b x  + a
+--R     + 
+--R              4 8         3 6       2 2 4      3   2     4  +-+
+--R       (- 105b x  - 280a b x  - 231a b x  - 48a b x  + 8a )\|a
+--R  /
+--R                                        +-------------------+
+--R         4 2 7      5   5      6 3  +-+ | 2 4         2    2
+--R     (24a b x  + 48a b x  + 24a x )\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1309
+
+--S 1310 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R                     +-------------------+
+--R                     | 2 4         2    2       2
+--R                    \|b x  + 2a b x  + a   - b x  - a
+--R   (7)  --------------------------------------------------------
+--R                                           +-------------------+
+--R          3 10       2 8     2   6    3 4  | 2 4         2    2
+--R        (b x   + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1310
+
+)clear all
+
+--S 1311 of 1370
+t0:=x^6/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                        6
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1311
+
+--S 1312 of 1370
+r0:=1/8*a*x^3*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+    11/48*x^3/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/64*x^3*_
+    (a+b*x^2)/(a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+    5/128*x/(a*b^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))+5/128*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*b^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                                              +-+
+--R           4 8        3 6      2 2 4      3   2      4      x\|b
+--R       (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )atan(-----)
+--R                                                              +-+
+--R                                                             \|a
+--R     + 
+--R           3 7        2 5      2   3      3   +-+ +-+
+--R       (15b x  - 73a b x  - 55a b x  - 15a x)\|a \|b
+--R  /
+--R              6 6        2 5 4        3 4 2       4 3  +-+ +-+
+--R       (384a b x  + 1152a b x  + 1152a b x  + 384a b )\|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1312
+
+--S 1313 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               4 8        3 6      2 2 4      3   2      4
+--R           (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )
+--R        *
+--R                   2      +-----+
+--R               (b x  - a)\|- a b  + 2a b x
+--R           log(---------------------------)
+--R                            2
+--R                         b x  + a
+--R       + 
+--R             3 7         2 5       2   3      3   +-----+
+--R         (30b x  - 146a b x  - 110a b x  - 30a x)\|- a b
+--R    /
+--R              7 8        2 6 6        3 5 4        4 4 2       5 3  +-----+
+--R       (768a b x  + 3072a b x  + 4608a b x  + 3072a b x  + 768a b )\|- a b
+--R     ,
+--R
+--R                                                                +---+
+--R             4 8        3 6      2 2 4      3   2      4      x\|a b
+--R         (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )atan(-------)
+--R                                                                 a
+--R       + 
+--R             3 7        2 5      2   3      3   +---+
+--R         (15b x  - 73a b x  - 55a b x  - 15a x)\|a b
+--R    /
+--R              7 8        2 6 6        3 5 4        4 4 2       5 3  +---+
+--R       (384a b x  + 1536a b x  + 2304a b x  + 1536a b x  + 384a b )\|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1313
+
+--S 1314 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             4 8        3 6      2 2 4      3   2      4  +-+ +-+
+--R         (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )\|a \|b
+--R      *
+--R          +-------------------+        2      +-----+
+--R          | 2 4         2    2     (b x  - a)\|- a b  + 2a b x
+--R         \|b x  + 2a b x  + a  log(---------------------------)
+--R                                                2
+--R                                             b x  + a
+--R     + 
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 30b x   - 150a b x  - 300a b x  - 300a b x  - 150a b x  - 30a )
+--R      *
+--R                        +-+
+--R          +-----+     x\|b
+--R         \|- a b atan(-----)
+--R                        +-+
+--R                       \|a
+--R     + 
+--R             3 7         2 5       2   3      3   +-----+ +-+ +-+
+--R         (30b x  - 146a b x  - 110a b x  - 30a x)\|- a b \|a \|b
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             4 9         3 7       2 2 5       3   3      4   +-----+ +-+ +-+
+--R       (- 30b x  + 116a b x  + 256a b x  + 140a b x  + 30a x)\|- a b \|a \|b
+--R  /
+--R              7 8        2 6 6        3 5 4        4 4 2       5 3  +-----+ +-+
+--R       (768a b x  + 3072a b x  + 4608a b x  + 3072a b x  + 768a b )\|- a b \|a
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1314
+
+--S 1315 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         +-------------------+
+--R                       6 | 2 4         2    2       8      6
+--R                      x \|b x  + 2a b x  + a   - b x  - a x
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1315
+
+--S 1316 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             4 8        3 6      2 2 4      3   2      4  +-+ +-+
+--R         (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )\|a \|b
+--R      *
+--R          +-------------------+       +---+
+--R          | 2 4         2    2      x\|a b
+--R         \|b x  + 2a b x  + a  atan(-------)
+--R                                       a
+--R     + 
+--R               5 10        4 8       2 3 6       3 2 4      4   2      5  +---+
+--R         (- 15b x   - 75a b x  - 150a b x  - 150a b x  - 75a b x  - 15a )\|a b
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R             3 7        2 5      2   3      3   +-+ +-+ +---+
+--R         (15b x  - 73a b x  - 55a b x  - 15a x)\|a \|b \|a b
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             4 9        3 7       2 2 5      3   3      4   +-+ +-+ +---+
+--R       (- 15b x  + 58a b x  + 128a b x  + 70a b x  + 15a x)\|a \|b \|a b
+--R  /
+--R              7 8        2 6 6        3 5 4        4 4 2       5 3  +-+ +-+
+--R       (384a b x  + 1536a b x  + 2304a b x  + 1536a b x  + 384a b )\|a \|b
+--R    *
+--R              +-------------------+
+--R        +---+ | 2 4         2    2
+--R       \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1316
+
+--S 1317 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                         +-------------------+
+--R                       6 | 2 4         2    2       8      6
+--R                      x \|b x  + 2a b x  + a   - b x  - a x
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1317
+
+)clear all
+
+--S 1318 of 1370
+t0:=x^5/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                        5
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1318
+
+--S 1319 of 1370
+r0:=1/8*x^6*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    1/24*x^6/(a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                                    8       6
+--R                                 b x  + 4a x
+--R   (2)  -------------------------------------------------------------
+--R                                                +-------------------+
+--R            2 3 6      3 2 4      4   2      5  | 2 4         2    2
+--R        (24a b x  + 72a b x  + 72a b x  + 24a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1319
+
+--S 1320 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          2 4         2    2
+--R                      - 6b x  - 4a b x  - a
+--R   (3)  -------------------------------------------------
+--R           7 8        6 6       2 5 4      3 4 2      4 3
+--R        24b x  + 96a b x  + 144a b x  + 96a b x  + 24a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1320
+
+--S 1321 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              +-------------------+
+--R        2 2 4     3   2    4  | 2 4         2    2     5 10       4 8     2 3 6
+--R   (- 6a b x  - 4a b x  - a )\|b x  + 2a b x  + a   - b x   - 5a b x  - 4a b x
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R        2 7 8      3 6 6       4 5 4      5 4 2      6 3  | 2 4         2    2
+--R    (24a b x  + 96a b x  + 144a b x  + 96a b x  + 24a b )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1321
+
+--S 1322 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                         +-------------------+
+--R                       5 | 2 4         2    2       7      5
+--R                      x \|b x  + 2a b x  + a   - b x  - a x
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1322
+
+)clear all
+
+--S 1323 of 1370
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                        4
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1323
+
+--S 1324 of 1370
+r0:=1/8*a*x*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+    3/16*x/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1/64*x*(a+b*x^2)/_
+    (a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+3/128*x/(a^2*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/128*(a+b*x^2)*atan(x*_
+    sqrt(b)/sqrt(a))/(a^(5/2)*b^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                                            +-+
+--R          4 8        3 6      2 2 4      3   2     4      x\|b
+--R       (3b x  + 12a b x  + 18a b x  + 12a b x  + 3a )atan(-----)
+--R                                                            +-+
+--R                                                           \|a
+--R     + 
+--R          3 7        2 5      2   3     3   +-+ +-+
+--R       (3b x  + 11a b x  - 11a b x  - 3a x)\|a \|b
+--R  /
+--R                                                           +-------------------+
+--R          2 5 6       3 4 4       4 3 2       5 2  +-+ +-+ | 2 4         2    2
+--R     (128a b x  + 384a b x  + 384a b x  + 128a b )\|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1324
+
+--S 1325 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              4 8        3 6      2 2 4      3   2     4
+--R           (3b x  + 12a b x  + 18a b x  + 12a b x  + 3a )
+--R        *
+--R                   2      +-----+
+--R               (b x  - a)\|- a b  + 2a b x
+--R           log(---------------------------)
+--R                            2
+--R                         b x  + a
+--R       + 
+--R            3 7        2 5      2   3     3   +-----+
+--R         (6b x  + 22a b x  - 22a b x  - 6a x)\|- a b
+--R    /
+--R            2 6 8        3 5 6        4 4 4        5 3 2       6 2  +-----+
+--R       (256a b x  + 1024a b x  + 1536a b x  + 1024a b x  + 256a b )\|- a b
+--R     ,
+--R
+--R                                                              +---+
+--R            4 8        3 6      2 2 4      3   2     4      x\|a b
+--R         (3b x  + 12a b x  + 18a b x  + 12a b x  + 3a )atan(-------)
+--R                                                               a
+--R       + 
+--R            3 7        2 5      2   3     3   +---+
+--R         (3b x  + 11a b x  - 11a b x  - 3a x)\|a b
+--R    /
+--R            2 6 8       3 5 6       4 4 4       5 3 2       6 2  +---+
+--R       (128a b x  + 512a b x  + 768a b x  + 512a b x  + 128a b )\|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1325
+
+--S 1326 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            4 8        3 6      2 2 4      3   2     4  +-+ +-+
+--R         (3b x  + 12a b x  + 18a b x  + 12a b x  + 3a )\|a \|b
+--R      *
+--R          +-------------------+        2      +-----+
+--R          | 2 4         2    2     (b x  - a)\|- a b  + 2a b x
+--R         \|b x  + 2a b x  + a  log(---------------------------)
+--R                                                2
+--R                                             b x  + a
+--R     + 
+--R              5 10        4 8      2 3 6      3 2 4      4   2     5  +-----+
+--R         (- 6b x   - 30a b x  - 60a b x  - 60a b x  - 30a b x  - 6a )\|- a b
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R            3 7        2 5      2   3     3   +-----+ +-+ +-+
+--R         (6b x  + 22a b x  - 22a b x  - 6a x)\|- a b \|a \|b
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 9        3 7      3   3     4   +-----+ +-+ +-+
+--R       (- 6b x  - 28a b x  + 28a b x  + 6a x)\|- a b \|a \|b
+--R  /
+--R            2 6 8        3 5 6        4 4 4        5 3 2       6 2  +-----+ +-+
+--R       (256a b x  + 1024a b x  + 1536a b x  + 1024a b x  + 256a b )\|- a b \|a
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1326
+
+--S 1327 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         +-------------------+
+--R                       4 | 2 4         2    2       6      4
+--R                      x \|b x  + 2a b x  + a   - b x  - a x
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1327
+
+--S 1328 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            4 8        3 6      2 2 4      3   2     4  +-+ +-+
+--R         (3b x  + 12a b x  + 18a b x  + 12a b x  + 3a )\|a \|b
+--R      *
+--R          +-------------------+       +---+
+--R          | 2 4         2    2      x\|a b
+--R         \|b x  + 2a b x  + a  atan(-------)
+--R                                       a
+--R     + 
+--R              5 10        4 8      2 3 6      3 2 4      4   2     5  +---+
+--R         (- 3b x   - 15a b x  - 30a b x  - 30a b x  - 15a b x  - 3a )\|a b
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                                                          +-------------------+
+--R          3 7        2 5      2   3     3   +-+ +-+ +---+ | 2 4         2    2
+--R       (3b x  + 11a b x  - 11a b x  - 3a x)\|a \|b \|a b \|b x  + 2a b x  + a
+--R     + 
+--R            4 9        3 7      3   3     4   +-+ +-+ +---+
+--R       (- 3b x  - 14a b x  + 14a b x  + 3a x)\|a \|b \|a b
+--R  /
+--R            2 6 8       3 5 6       4 4 4       5 3 2       6 2  +-+ +-+ +---+
+--R       (128a b x  + 512a b x  + 768a b x  + 512a b x  + 128a b )\|a \|b \|a b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1328
+
+--S 1329 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                         +-------------------+
+--R                       4 | 2 4         2    2       6      4
+--R                      x \|b x  + 2a b x  + a   - b x  - a x
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1329
+
+)clear all
+
+--S 1330 of 1370
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                        3
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1330
+
+--S 1331 of 1370
+r0:=1/8*a*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    (-1/6)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                                       2
+--R                                 - 4b x  - a
+--R   (2)  -------------------------------------------------------------
+--R                                                +-------------------+
+--R            5 6        4 4      2 3 2      3 2  | 2 4         2    2
+--R        (24b x  + 72a b x  + 72a b x  + 24a b )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1331
+
+--S 1332 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                 2
+--R                           - 4b x  - a
+--R   (3)  -------------------------------------------------
+--R           6 8        5 6       2 4 4      3 3 2      4 2
+--R        24b x  + 96a b x  + 144a b x  + 96a b x  + 24a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1332
+
+--S 1333 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +-------------------+
+--R                  2      | 2 4         2    2      2 4         2    2
+--R           (- 4b x  - a)\|b x  + 2a b x  + a   + 4b x  + 5a b x  + a
+--R   -------------------------------------------------------------------------
+--R                                                       +-------------------+
+--R       6 8        5 6       2 4 4      3 3 2      4 2  | 2 4         2    2
+--R   (24b x  + 96a b x  + 144a b x  + 96a b x  + 24a b )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1333
+
+--S 1334 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                         +-------------------+
+--R                       3 | 2 4         2    2       5      3
+--R                      x \|b x  + 2a b x  + a   - b x  - a x
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1334
+
+)clear all
+
+--S 1335 of 1370
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                        2
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1335
+
+--S 1336 of 1370
+r0:=1/8*x^3*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+    5/48*x/(a*b*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    5/192*x*(a+b*x^2)/(a^2*b*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    5/128*x/(a^3*b*sqrt(a^2+2*a*b*x^2+b^2*x^4))+5/128*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(a^(7/2)*b^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                                              +-+
+--R           4 8        3 6      2 2 4      3   2      4      x\|b
+--R       (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )atan(-----)
+--R                                                              +-+
+--R                                                             \|a
+--R     + 
+--R           3 7        2 5      2   3      3   +-+ +-+
+--R       (15b x  + 55a b x  + 73a b x  - 15a x)\|a \|b
+--R  /
+--R            3 4 6        4 3 4        5 2 2       6   +-+ +-+
+--R       (384a b x  + 1152a b x  + 1152a b x  + 384a b)\|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1336
+
+--S 1337 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               4 8        3 6      2 2 4      3   2      4
+--R           (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )
+--R        *
+--R                   2      +-----+
+--R               (b x  - a)\|- a b  + 2a b x
+--R           log(---------------------------)
+--R                            2
+--R                         b x  + a
+--R       + 
+--R             3 7         2 5       2   3      3   +-----+
+--R         (30b x  + 110a b x  + 146a b x  - 30a x)\|- a b
+--R    /
+--R            3 5 8        4 4 6        5 3 4        6 2 2       7   +-----+
+--R       (768a b x  + 3072a b x  + 4608a b x  + 3072a b x  + 768a b)\|- a b
+--R     ,
+--R
+--R                                                                +---+
+--R             4 8        3 6      2 2 4      3   2      4      x\|a b
+--R         (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )atan(-------)
+--R                                                                 a
+--R       + 
+--R             3 7        2 5      2   3      3   +---+
+--R         (15b x  + 55a b x  + 73a b x  - 15a x)\|a b
+--R    /
+--R            3 5 8        4 4 6        5 3 4        6 2 2       7   +---+
+--R       (384a b x  + 1536a b x  + 2304a b x  + 1536a b x  + 384a b)\|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1337
+
+--S 1338 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             4 8        3 6      2 2 4      3   2      4  +-+ +-+
+--R         (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )\|a \|b
+--R      *
+--R          +-------------------+        2      +-----+
+--R          | 2 4         2    2     (b x  - a)\|- a b  + 2a b x
+--R         \|b x  + 2a b x  + a  log(---------------------------)
+--R                                                2
+--R                                             b x  + a
+--R     + 
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 30b x   - 150a b x  - 300a b x  - 300a b x  - 150a b x  - 30a )
+--R      *
+--R                        +-+
+--R          +-----+     x\|b
+--R         \|- a b atan(-----)
+--R                        +-+
+--R                       \|a
+--R     + 
+--R             3 7         2 5       2   3      3   +-----+ +-+ +-+
+--R         (30b x  + 110a b x  + 146a b x  - 30a x)\|- a b \|a \|b
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             4 9         3 7       2 2 5       3   3      4   +-----+ +-+ +-+
+--R       (- 30b x  - 140a b x  - 256a b x  - 116a b x  + 30a x)\|- a b \|a \|b
+--R  /
+--R            3 5 8        4 4 6        5 3 4        6 2 2       7   +-----+ +-+
+--R       (768a b x  + 3072a b x  + 4608a b x  + 3072a b x  + 768a b)\|- a b \|a
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1338
+
+--S 1339 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         +-------------------+
+--R                       2 | 2 4         2    2       4      2
+--R                      x \|b x  + 2a b x  + a   - b x  - a x
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1339
+
+--S 1340 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             4 8        3 6      2 2 4      3   2      4  +-+ +-+
+--R         (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )\|a \|b
+--R      *
+--R          +-------------------+       +---+
+--R          | 2 4         2    2      x\|a b
+--R         \|b x  + 2a b x  + a  atan(-------)
+--R                                       a
+--R     + 
+--R               5 10        4 8       2 3 6       3 2 4      4   2      5  +---+
+--R         (- 15b x   - 75a b x  - 150a b x  - 150a b x  - 75a b x  - 15a )\|a b
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R             3 7        2 5      2   3      3   +-+ +-+ +---+
+--R         (15b x  + 55a b x  + 73a b x  - 15a x)\|a \|b \|a b
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             4 9        3 7       2 2 5      3   3      4   +-+ +-+ +---+
+--R       (- 15b x  - 70a b x  - 128a b x  - 58a b x  + 15a x)\|a \|b \|a b
+--R  /
+--R            3 5 8        4 4 6        5 3 4        6 2 2       7   +-+ +-+ +---+
+--R       (384a b x  + 1536a b x  + 2304a b x  + 1536a b x  + 384a b)\|a \|b \|a b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1340
+
+--S 1341 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                         +-------------------+
+--R                       2 | 2 4         2    2       4      2
+--R                      x \|b x  + 2a b x  + a   - b x  - a x
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1341
+
+)clear all
+
+--S 1342 of 1370
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1342
+
+--S 1343 of 1370
+r0:=1/8*(-a-b*x^2)/(b*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                       1
+--R   (2)  - ----------------------------------------------------------
+--R                                               +-------------------+
+--R             4 6        3 4      2 2 2     3   | 2 4         2    2
+--R          (8b x  + 24a b x  + 24a b x  + 8a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1343
+
+--S 1344 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                1
+--R   (3)  - ---------------------------------------------
+--R            5 8        4 6      2 3 4      3 2 2     4
+--R          8b x  + 32a b x  + 48a b x  + 32a b x  + 8a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1344
+
+--S 1345 of 1370
+m0:=a0-r0
+--R 
+--R
+--R                            +-------------------+
+--R                            | 2 4         2    2       2
+--R                         - \|b x  + 2a b x  + a   + b x  + a
+--R   (4)  ---------------------------------------------------------------------
+--R                                                        +-------------------+
+--R           5 8        4 6      2 3 4      3 2 2     4   | 2 4         2    2
+--R        (8b x  + 32a b x  + 48a b x  + 32a b x  + 8a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1345
+
+--S 1346 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                         +-------------------+
+--R                         | 2 4         2    2       3
+--R                       x\|b x  + 2a b x  + a   - b x  - a x
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1346
+
+)clear all
+
+--S 1347 of 1370
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                       1
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1347
+
+--S 1348 of 1370
+r0:=1/8*x*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    7/48*x/(a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    35/192*x*(a+b*x^2)/(a^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    35/128*x/(a^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+    35/128*(a+b*x^2)*atan(x*sqrt(b)/sqrt(a))/(a^(9/2)*sqrt(b)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                                                   +-+
+--R            4 8         3 6       2 2 4       3   2       4      x\|b
+--R       (105b x  + 420a b x  + 630a b x  + 420a b x  + 105a )atan(-----)
+--R                                                                   +-+
+--R                                                                  \|a
+--R     + 
+--R            3 7         2 5       2   3       3   +-+ +-+
+--R       (105b x  + 385a b x  + 511a b x  + 279a x)\|a \|b
+--R  /
+--R                                                           +-------------------+
+--R          4 3 6        5 2 4        6   2       7  +-+ +-+ | 2 4         2    2
+--R     (384a b x  + 1152a b x  + 1152a b x  + 384a )\|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1348
+
+--S 1349 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                4 8         3 6       2 2 4       3   2       4
+--R           (105b x  + 420a b x  + 630a b x  + 420a b x  + 105a )
+--R        *
+--R                   2      +-----+
+--R               (b x  - a)\|- a b  + 2a b x
+--R           log(---------------------------)
+--R                            2
+--R                         b x  + a
+--R       + 
+--R              3 7         2 5        2   3       3   +-----+
+--R         (210b x  + 770a b x  + 1022a b x  + 558a x)\|- a b
+--R    /
+--R            4 4 8        5 3 6        6 2 4        7   2       8  +-----+
+--R       (768a b x  + 3072a b x  + 4608a b x  + 3072a b x  + 768a )\|- a b
+--R     ,
+--R
+--R                                                                     +---+
+--R              4 8         3 6       2 2 4       3   2       4      x\|a b
+--R         (105b x  + 420a b x  + 630a b x  + 420a b x  + 105a )atan(-------)
+--R                                                                      a
+--R       + 
+--R              3 7         2 5       2   3       3   +---+
+--R         (105b x  + 385a b x  + 511a b x  + 279a x)\|a b
+--R    /
+--R            4 4 8        5 3 6        6 2 4        7   2       8  +---+
+--R       (384a b x  + 1536a b x  + 2304a b x  + 1536a b x  + 384a )\|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1349
+
+--S 1350 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              4 8         3 6       2 2 4       3   2       4  +-+ +-+
+--R         (105b x  + 420a b x  + 630a b x  + 420a b x  + 105a )\|a \|b
+--R      *
+--R          +-------------------+        2      +-----+
+--R          | 2 4         2    2     (b x  - a)\|- a b  + 2a b x
+--R         \|b x  + 2a b x  + a  log(---------------------------)
+--R                                                2
+--R                                             b x  + a
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 210b x   - 1050a b x  - 2100a b x  - 2100a b x  - 1050a b x
+--R           + 
+--R                   5
+--R             - 210a
+--R      *
+--R                        +-+
+--R          +-----+     x\|b
+--R         \|- a b atan(-----)
+--R                        +-+
+--R                       \|a
+--R     + 
+--R              3 7         2 5        2   3       3   +-----+ +-+ +-+
+--R         (210b x  + 770a b x  + 1022a b x  + 558a x)\|- a b \|a \|b
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 9         3 7        2 2 5        3   3       4   +-----+ +-+ +-+
+--R     (- 210b x  - 980a b x  - 1792a b x  - 1580a b x  - 558a x)\|- a b \|a \|b
+--R  /
+--R            4 4 8        5 3 6        6 2 4        7   2       8  +-----+ +-+
+--R       (768a b x  + 3072a b x  + 4608a b x  + 3072a b x  + 768a )\|- a b \|a
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1350
+
+--S 1351 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          +-------------------+
+--R                          | 2 4         2    2       2
+--R                         \|b x  + 2a b x  + a   - b x  - a
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1351
+
+--S 1352 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              4 8         3 6       2 2 4       3   2       4  +-+ +-+
+--R         (105b x  + 420a b x  + 630a b x  + 420a b x  + 105a )\|a \|b
+--R      *
+--R          +-------------------+       +---+
+--R          | 2 4         2    2      x\|a b
+--R         \|b x  + 2a b x  + a  atan(-------)
+--R                                       a
+--R     + 
+--R                5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (- 105b x   - 525a b x  - 1050a b x  - 1050a b x  - 525a b x  - 105a )
+--R      *
+--R                      +-+
+--R          +---+     x\|b
+--R         \|a b atan(-----)
+--R                      +-+
+--R                     \|a
+--R     + 
+--R              3 7         2 5       2   3       3   +-+ +-+ +---+
+--R         (105b x  + 385a b x  + 511a b x  + 279a x)\|a \|b \|a b
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              4 9         3 7       2 2 5       3   3       4   +-+ +-+ +---+
+--R       (- 105b x  - 490a b x  - 896a b x  - 790a b x  - 279a x)\|a \|b \|a b
+--R  /
+--R            4 4 8        5 3 6        6 2 4        7   2       8  +-+ +-+ +---+
+--R       (384a b x  + 1536a b x  + 2304a b x  + 1536a b x  + 384a )\|a \|b \|a b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1352
+
+--S 1353 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                          +-------------------+
+--R                          | 2 4         2    2       2
+--R                         \|b x  + 2a b x  + a   - b x  - a
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1353
+
+)clear all
+
+--S 1354 of 1370
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                        1
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 9       3 7     2 2 5     3   3    4   | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1354
+
+--S 1355 of 1370
+r0:=1/8*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    1/6/(a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1/4*(a+b*x^2)/_
+    (a^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1/2/(a^4*sqrt(a^2+2*a*_
+    b*x^2+b^2*x^4))+(a+b*x^2)*log(x)/(a^5*sqrt(a^2+2*a*b*x^2+_
+    b^2*x^4))-1/2*(a+b*x^2)*log(a+b*x^2)/(a^5*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             4 8        3 6      2 2 4      3   2      4        2
+--R       (- 12b x  - 48a b x  - 72a b x  - 48a b x  - 12a )log(b x  + a)
+--R     + 
+--R           4 8        3 6       2 2 4      3   2      4               3 6
+--R       (24b x  + 96a b x  + 144a b x  + 96a b x  + 24a )log(x) + 12a b x
+--R     + 
+--R          2 2 4      3   2      4
+--R       42a b x  + 52a b x  + 25a
+--R  /
+--R                                             +-------------------+
+--R         5 3 6      6 2 4      7   2      8  | 2 4         2    2
+--R     (24a b x  + 72a b x  + 72a b x  + 24a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1355
+
+--S 1356 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             4 8        3 6      2 2 4      3   2      4        2
+--R       (- 12b x  - 48a b x  - 72a b x  - 48a b x  - 12a )log(b x  + a)
+--R     + 
+--R           4 8        3 6       2 2 4      3   2      4               3 6
+--R       (24b x  + 96a b x  + 144a b x  + 96a b x  + 24a )log(x) + 12a b x
+--R     + 
+--R          2 2 4      3   2      4
+--R       42a b x  + 52a b x  + 25a
+--R  /
+--R        5 4 8      6 3 6       7 2 4      8   2      9
+--R     24a b x  + 96a b x  + 144a b x  + 96a b x  + 24a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1356
+
+--S 1357 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 4 8        3 6      2 2 4      3   2      4        2
+--R           (- 12b x  - 48a b x  - 72a b x  - 48a b x  - 12a )log(b x  + a)
+--R         + 
+--R               4 8        3 6       2 2 4      3   2      4               3 6
+--R           (24b x  + 96a b x  + 144a b x  + 96a b x  + 24a )log(x) + 12a b x
+--R         + 
+--R              2 2 4      3   2      4
+--R           42a b x  + 52a b x  + 25a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             5 10        4 8       2 3 6       3 2 4      4   2      5
+--R         (12b x   + 60a b x  + 120a b x  + 120a b x  + 60a b x  + 12a )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R             5 10         4 8       2 3 6       3 2 4       4   2      5
+--R       (- 24b x   - 120a b x  - 240a b x  - 240a b x  - 120a b x  - 24a )log(x)
+--R     + 
+--R              4 8      2 3 6      3 2 4      4   2      5
+--R       - 12a b x  - 54a b x  - 94a b x  - 77a b x  - 25a
+--R  /
+--R                                                         +-------------------+
+--R         5 4 8      6 3 6       7 2 4      8   2      9  | 2 4         2    2
+--R     (24a b x  + 96a b x  + 144a b x  + 96a b x  + 24a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1357
+
+--S 1358 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                          +-------------------+
+--R                          | 2 4         2    2       2
+--R                         \|b x  + 2a b x  + a   - b x  - a
+--R   -----------------------------------------------------------------------------
+--R                                                           +-------------------+
+--R     5 11       4 9      2 3 7      3 2 5     4   3    5   | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1358
+
+)clear all
+
+--S 1359 of 1370
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  ------------------------------------------------------------------
+--R                                                     +-------------------+
+--R          4 10       3 8     2 2 6     3   4    4 2  | 2 4         2    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1359
+
+--S 1360 of 1370
+r0:=1/8*(a+b*x^2)/(a*x*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    3/16/(a^2*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+21/64*(a+b*x^2)/_
+    (a^3*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+105/128/(a^4*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))-315/128*(a+b*x^2)/(a^5*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))-315/128*(a+b*x^2)*atan(x*_
+    sqrt(b)/sqrt(a))*sqrt(b)/(a^(11/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                4 9          3 7        2 2 5        3   3       4   +-+
+--R         (- 315b x  - 1260a b x  - 1890a b x  - 1260a b x  - 315a x)\|b
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R              4 8          3 6        2 2 4       3   2       4  +-+
+--R       (- 315b x  - 1155a b x  - 1533a b x  - 837a b x  - 128a )\|a
+--R  /
+--R                                                      +-------------------+
+--R          5 3 7       6 2 5       7   3       8   +-+ | 2 4         2    2
+--R     (128a b x  + 384a b x  + 384a b x  + 128a x)\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1360
+
+--S 1361 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                                     +---+
+--R                4 9          3 7        2 2 5        3   3       4   |  b
+--R           (315b x  + 1260a b x  + 1890a b x  + 1260a b x  + 315a x) |- -
+--R                                                                    \|  a
+--R        *
+--R                      +---+
+--R                      |  b       2
+--R               - 2a x |- -  + b x  - a
+--R                     \|  a
+--R           log(-----------------------)
+--R                          2
+--R                       b x  + a
+--R       + 
+--R               4 8          3 6        2 2 4        3   2       4
+--R         - 630b x  - 2310a b x  - 3066a b x  - 1674a b x  - 256a
+--R    /
+--R           5 4 9        6 3 7        7 2 5        8   3       9
+--R       256a b x  + 1024a b x  + 1536a b x  + 1024a b x  + 256a x
+--R     ,
+--R
+--R                                                                     +-+
+--R                4 9          3 7        2 2 5        3   3       4   |b
+--R           (315b x  + 1260a b x  + 1890a b x  + 1260a b x  + 315a x) |-
+--R                                                                    \|a
+--R        *
+--R                  +-+
+--R                  |b
+--R                a |-
+--R                 \|a
+--R           atan(-----)
+--R                 b x
+--R       + 
+--R               4 8          3 6        2 2 4       3   2       4
+--R         - 315b x  - 1155a b x  - 1533a b x  - 837a b x  - 128a
+--R    /
+--R           5 4 9       6 3 7       7 2 5       8   3       9
+--R       128a b x  + 512a b x  + 768a b x  + 512a b x  + 128a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1361
+
+--S 1362 of 1370
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                                   +---+
+--R              4 9          3 7        2 2 5        3   3       4   |  b  +-+
+--R         (315b x  + 1260a b x  + 1890a b x  + 1260a b x  + 315a x) |- - \|a
+--R                                                                  \|  a
+--R      *
+--R                                          +---+
+--R                                          |  b       2
+--R          +-------------------+    - 2a x |- -  + b x  - a
+--R          | 2 4         2    2           \|  a
+--R         \|b x  + 2a b x  + a  log(-----------------------)
+--R                                              2
+--R                                           b x  + a
+--R     + 
+--R              5 11          4 9        2 3 7        3 2 5        4   3       5
+--R         (630b x   + 3150a b x  + 6300a b x  + 6300a b x  + 3150a b x  + 630a x)
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                4 8          3 6        2 2 4        3   2       4  +-+
+--R         (- 630b x  - 2310a b x  - 3066a b x  - 1674a b x  - 256a )\|a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          5 10          4 8        2 3 6        3 2 4        4   2       5  +-+
+--R     (630b x   + 2940a b x  + 5376a b x  + 4740a b x  + 1930a b x  + 256a )\|a
+--R  /
+--R            5 4 9        6 3 7        7 2 5        8   3       9   +-+
+--R       (256a b x  + 1024a b x  + 1536a b x  + 1024a b x  + 256a x)\|a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1362
+
+--S 1363 of 1370
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 4         2    2       2
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 12       4 10      2 3 8      3 2 6     4   4    5 2
+--R       (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a x )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1363
+
+--S 1364 of 1370
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              5 11          4 9        2 3 7        3 2 5        4   3       5
+--R         (315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x  + 315a x)
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                                                                       +-+
+--R              4 9          3 7        2 2 5        3   3       4   +-+ |b
+--R         (315b x  + 1260a b x  + 1890a b x  + 1260a b x  + 315a x)\|a  |-
+--R                                                                      \|a
+--R      *
+--R                                      +-+
+--R                                      |b
+--R          +-------------------+     a |-
+--R          | 2 4         2    2       \|a
+--R         \|b x  + 2a b x  + a  atan(-----)
+--R                                     b x
+--R     + 
+--R                4 8          3 6        2 2 4       3   2       4  +-+
+--R         (- 315b x  - 1155a b x  - 1533a b x  - 837a b x  - 128a )\|a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          5 10          4 8        2 3 6        3 2 4       4   2       5  +-+
+--R     (315b x   + 1470a b x  + 2688a b x  + 2370a b x  + 965a b x  + 128a )\|a
+--R  /
+--R            5 4 9       6 3 7       7 2 5       8   3       9   +-+
+--R       (128a b x  + 512a b x  + 768a b x  + 512a b x  + 128a x)\|a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1364
+
+--S 1365 of 1370
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R      +-------------------+
+--R      | 2 4         2    2       2
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 12       4 10      2 3 8      3 2 6     4   4    5 2
+--R       (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a x )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1365
+
+)clear all
+
+--S 1366 of 1370
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  ------------------------------------------------------------------
+--R                                                     +-------------------+
+--R          4 11       3 9     2 2 7     3   5    4 3  | 2 4         2    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1366
+
+--S 1367 of 1370
+r0:=1/8*(a+b*x^2)/(a*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    5/24/(a^2*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/12*(a+b*x^2)/_
+    (a^3*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/4/(a^4*x^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))-5*b*(a+b*x^2)*log(x)/(a^6*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))+5/2*b*(a+b*x^2)*log(a+b*x^2)/_
+    (a^6*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+    5/2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a^6*x^2)
+--R 
+--R
+--R   (2)
+--R           5 10         4 8       2 3 6       3 2 4      4   2        2
+--R       (60b x   + 240a b x  + 360a b x  + 240a b x  + 60a b x )log(b x  + a)
+--R     + 
+--R              5 10         4 8       2 3 6       3 2 4       4   2
+--R       (- 120b x   - 480a b x  - 720a b x  - 480a b x  - 120a b x )log(x)
+--R     + 
+--R            5 10         4 8       2 3 6       3 2 4       4   2      5
+--R       - 60b x   - 300a b x  - 570a b x  - 500a b x  - 185a b x  - 12a
+--R  /
+--R                                               +-------------------+
+--R         6 3 8      7 2 6      8   4      9 2  | 2 4         2    2
+--R     (24a b x  + 72a b x  + 72a b x  + 24a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1367
+
+--S 1368 of 1370
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           5 10         4 8       2 3 6       3 2 4      4   2        2
+--R       (60b x   + 240a b x  + 360a b x  + 240a b x  + 60a b x )log(b x  + a)
+--R     + 
+--R              5 10         4 8       2 3 6       3 2 4       4   2
+--R       (- 120b x   - 480a b x  - 720a b x  - 480a b x  - 120a b x )log(x)
+--R     + 
+--R              4 8       2 3 6       3 2 4       4   2      5
+--R       - 60a b x  - 210a b x  - 260a b x  - 125a b x  - 12a
+--R  /
+--R        6 4 10      7 3 8       8 2 6      9   4      10 2
+--R     24a b x   + 96a b x  + 144a b x  + 96a b x  + 24a  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1368
+
+--S 1369 of 1370
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 10         4 8       2 3 6       3 2 4      4   2        2
+--R           (60b x   + 240a b x  + 360a b x  + 240a b x  + 60a b x )log(b x  + a)
+--R         + 
+--R                  5 10         4 8       2 3 6       3 2 4       4   2
+--R           (- 120b x   - 480a b x  - 720a b x  - 480a b x  - 120a b x )log(x)
+--R         + 
+--R                  4 8       2 3 6       3 2 4       4   2      5
+--R           - 60a b x  - 210a b x  - 260a b x  - 125a b x  - 12a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               6 12         5 10       2 4 8       3 3 6       4 2 4      5   2
+--R         (- 60b x   - 300a b x   - 600a b x  - 600a b x  - 300a b x  - 60a b x )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R                 6 12         5 10        2 4 8        3 3 6       4 2 4
+--R             120b x   + 600a b x   + 1200a b x  + 1200a b x  + 600a b x
+--R           + 
+--R                 5   2
+--R             120a b x
+--R      *
+--R         log(x)
+--R     + 
+--R          6 12         5 10       2 4 8        3 3 6       4 2 4       5   2
+--R       60b x   + 360a b x   + 870a b x  + 1070a b x  + 685a b x  + 197a b x
+--R     + 
+--R          6
+--R       12a
+--R  /
+--R           6 4 10      7 3 8       8 2 6      9   4      10 2
+--R       (24a b x   + 96a b x  + 144a b x  + 96a b x  + 24a  x )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1369
+
+--S 1370 of 1370
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 4         2    2       2
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 13       4 11      2 3 9      3 2 7     4   5    5 3
+--R       (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a x )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1370
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich14b.input.pamphlet b/src/input/rich14b.input.pamphlet
new file mode 100644
index 0000000..892befc
--- /dev/null
+++ b/src/input/rich14b.input.pamphlet
@@ -0,0 +1,55497 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich14b.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a+b x^2+c x^4)^p|
+
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich14b.output
+)spool rich14b.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1353
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R                                                      +-------------------+
+--R          4 12       3 10     2 2 8     3   6    4 4  | 2 4         2    2
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1353
+r0:=1/8*(a+b*x^2)/(a*x^3*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+11/48/(a^2*x^3*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))+33/64*(a+b*x^2)/(a^3*x^3*(a^2+2*a*b*_
+   x^2+b^2*x^4)^(3/2))+231/128/(a^4*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   385/128*(a+b*x^2)/(a^5*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1155/128*b*_
+   (a+b*x^2)/(a^6*x*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1155/128*b^(3/2)*_
+   (a+b*x^2)*atan(x*sqrt(b)/sqrt(a))/(a^(13/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R               5 11           4 9         2 3 7         3 2 5        4   3  +-+
+--R         (3465b x   + 13860a b x  + 20790a b x  + 13860a b x  + 3465a b x )\|b
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                  5 10           4 8         2 3 6        3 2 4        4   2
+--R             3465b x   + 12705a b x  + 16863a b x  + 9207a b x  + 1408a b x
+--R           + 
+--R                   5
+--R             - 128a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                         +-------------------+
+--R          6 3 9        7 2 7        8   5       9 3  +-+ | 2 4         2    2
+--R     (384a b x  + 1152a b x  + 1152a b x  + 384a x )\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 5 11           4 9         2 3 7         3 2 5        4   3
+--R           (3465b x   + 13860a b x  + 20790a b x  + 13860a b x  + 3465a b x )
+--R        *
+--R                          +---+
+--R                          |  b       2
+--R            +---+    2a x |- -  + b x  - a
+--R            |  b         \|  a
+--R            |- - log(---------------------)
+--R           \|  a               2
+--R                            b x  + a
+--R       + 
+--R            5 10           4 8         2 3 6         3 2 4        4   2       5
+--R       6930b x   + 25410a b x  + 33726a b x  + 18414a b x  + 2816a b x  - 256a
+--R    /
+--R           6 4 11        7 3 9        8 2 7        9   5       10 3
+--R       768a b x   + 3072a b x  + 4608a b x  + 3072a b x  + 768a  x
+--R     ,
+--R
+--R                   5 11           4 9         2 3 7         3 2 5        4   3
+--R           (- 3465b x   - 13860a b x  - 20790a b x  - 13860a b x  - 3465a b x )
+--R        *
+--R                      +-+
+--R                      |b
+--R            +-+     a |-
+--R            |b       \|a
+--R            |- atan(-----)
+--R           \|a       b x
+--R       + 
+--R            5 10           4 8         2 3 6        3 2 4        4   2       5
+--R       3465b x   + 12705a b x  + 16863a b x  + 9207a b x  + 1408a b x  - 128a
+--R    /
+--R           6 4 11        7 3 9        8 2 7        9   5       10 3
+--R       384a b x   + 1536a b x  + 2304a b x  + 1536a b x  + 384a  x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 3
+
+--S 4 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               5 11           4 9         2 3 7         3 2 5        4   3
+--R         (3465b x   + 13860a b x  + 20790a b x  + 13860a b x  + 3465a b x )
+--R      *
+--R                                                  +---+
+--R                                                  |  b       2
+--R          +---+     +-------------------+    2a x |- -  + b x  - a
+--R          |  b  +-+ | 2 4         2    2         \|  a
+--R          |- - \|a \|b x  + 2a b x  + a  log(---------------------)
+--R         \|  a                                         2
+--R                                                    b x  + a
+--R     + 
+--R                  6 13           5 11         2 4 9         3 3 7         4 2 5
+--R           - 6930b x   - 34650a b x   - 69300a b x  - 69300a b x  - 34650a b x
+--R         + 
+--R                  5   3
+--R           - 6930a b x
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4        4   2
+--R           6930b x   + 25410a b x  + 33726a b x  + 18414a b x  + 2816a b x
+--R         + 
+--R                 5
+--R           - 256a
+--R      *
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R         \|a \|b x  + 2a b x  + a
+--R     + 
+--R                  6 12           5 10         2 4 8         3 3 6         4 2 4
+--R           - 6930b x   - 32340a b x   - 59136a b x  - 52140a b x  - 21230a b x
+--R         + 
+--R                  5   2       6
+--R           - 2560a b x  + 256a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R            6 4 11        7 3 9        8 2 7        9   5       10 3  +-+
+--R       (768a b x   + 3072a b x  + 4608a b x  + 3072a b x  + 768a  x )\|a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 4         2    2       2
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 14       4 12      2 3 10      3 2 8     4   6    5 4
+--R       (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                  6 13           5 11         2 4 9         3 3 7         4 2 5
+--R           - 3465b x   - 17325a b x   - 34650a b x  - 34650a b x  - 17325a b x
+--R         + 
+--R                  5   3
+--R           - 3465a b x
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                 5 11           4 9         2 3 7         3 2 5        4   3
+--R         (- 3465b x   - 13860a b x  - 20790a b x  - 13860a b x  - 3465a b x )
+--R      *
+--R                                              +-+
+--R                                              |b
+--R              +-+ +-------------------+     a |-
+--R          +-+ |b  | 2 4         2    2       \|a
+--R         \|a  |- \|b x  + 2a b x  + a  atan(-----)
+--R             \|a                             b x
+--R     + 
+--R                  5 10           4 8         2 3 6        3 2 4        4   2
+--R             3465b x   + 12705a b x  + 16863a b x  + 9207a b x  + 1408a b x
+--R           + 
+--R                   5
+--R             - 128a
+--R      *
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R         \|a \|b x  + 2a b x  + a
+--R     + 
+--R                  6 12           5 10         2 4 8         3 3 6         4 2 4
+--R           - 3465b x   - 16170a b x   - 29568a b x  - 26070a b x  - 10615a b x
+--R         + 
+--R                  5   2       6
+--R           - 1280a b x  + 128a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R            6 4 11        7 3 9        8 2 7        9   5       10 3  +-+
+--R       (384a b x   + 1536a b x  + 2304a b x  + 1536a b x  + 384a  x )\|a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)
+--R      +-------------------+
+--R      | 2 4         2    2       2
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 14       4 12      2 3 10      3 2 8     4   6    5 4
+--R       (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 7
+
+)clear all
+
+--S 8 of 1353
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^(7/2)
+--R 
+--R
+--R   (1)
+--R      3
+--R     x
+--R  /
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 1353
+r0:=1/12*a*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(7/2))+(-1/10)/_
+   (b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R   (2)
+--R           2
+--R     - 6b x  - a
+--R  /
+--R           7 10         6 8       2 5 6       3 4 4       4 3 2      5 2
+--R       (60b x   + 300a b x  + 600a b x  + 600a b x  + 300a b x  + 60a b )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2
+--R     - 6b x  - a
+--R  /
+--R          8 12         7 10       2 6 8        3 5 6       4 4 4       5 3 2
+--R       60b x   + 360a b x   + 900a b x  + 1200a b x  + 900a b x  + 360a b x
+--R     + 
+--R          6 2
+--R       60a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 10
+
+--S 11 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +-------------------+
+--R            2      | 2 4         2    2      2 4         2    2
+--R     (- 6b x  - a)\|b x  + 2a b x  + a   + 6b x  + 7a b x  + a
+--R  /
+--R            8 12         7 10       2 6 8        3 5 6       4 4 4       5 3 2
+--R         60b x   + 360a b x   + 900a b x  + 1200a b x  + 900a b x  + 360a b x
+--R       + 
+--R            6 2
+--R         60a b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R        +-------------------+
+--R      3 | 2 4         2    2       5      3
+--R     x \|b x  + 2a b x  + a   - b x  - a x
+--R  /
+--R          7 14       6 12      2 5 10      3 4 8      4 3 6      5 2 4     6   2
+--R         b x   + 7a b x   + 21a b x   + 35a b x  + 35a b x  + 21a b x  + 7a b x
+--R       + 
+--R          7
+--R         a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 1353
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          2 7         5    2 3  +-+
+--R   (1)  (b x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 1353
+r0:=2/9*a^2*x^(9/2)+4/13*a*b*x^(13/2)+2/17*b^2*x^(17/2)
+--R 
+--R
+--R             2 8           6       2 4  +-+
+--R        (234b x  + 612a b x  + 442a x )\|x
+--R   (2)  -----------------------------------
+--R                        1989
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 8           6       2 4  +-+
+--R        (234b x  + 612a b x  + 442a x )\|x
+--R   (3)  -----------------------------------
+--R                        1989
+--R                                         Type: Union(Expression(Integer),...)
+--E 15
+
+--S 16 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 17
+
+)clear all
+
+--S 18 of 1353
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          2 6         4    2 2  +-+
+--R   (1)  (b x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 18
+
+--S 19 of 1353
+r0:=2/7*a^2*x^(7/2)+4/11*a*b*x^(11/2)+2/15*b^2*x^(15/2)
+--R 
+--R
+--R             2 7           5       2 3  +-+
+--R        (154b x  + 420a b x  + 330a x )\|x
+--R   (2)  -----------------------------------
+--R                        1155
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 7           5       2 3  +-+
+--R        (154b x  + 420a b x  + 330a x )\|x
+--R   (3)  -----------------------------------
+--R                        1155
+--R                                         Type: Union(Expression(Integer),...)
+--E 20
+
+--S 21 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 22
+
+)clear all
+
+--S 23 of 1353
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          2 5         3    2   +-+
+--R   (1)  (b x  + 2a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 1353
+r0:=2/5*a^2*x^(5/2)+4/9*a*b*x^(9/2)+2/13*b^2*x^(13/2)
+--R 
+--R
+--R            2 6           4       2 2  +-+
+--R        (90b x  + 260a b x  + 234a x )\|x
+--R   (2)  ----------------------------------
+--R                        585
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 6           4       2 2  +-+
+--R        (90b x  + 260a b x  + 234a x )\|x
+--R   (3)  ----------------------------------
+--R                        585
+--R                                         Type: Union(Expression(Integer),...)
+--E 25
+
+--S 26 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)*sqrt(x)
+--R 
+--R
+--R          2 4         2    2  +-+
+--R   (1)  (b x  + 2a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 1353
+r0:=2/3*a^2*x^(3/2)+4/7*a*b*x^(7/2)+2/11*b^2*x^(11/2)
+--R 
+--R
+--R            2 5           3       2   +-+
+--R        (42b x  + 132a b x  + 154a x)\|x
+--R   (2)  ---------------------------------
+--R                       231
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 5           3       2   +-+
+--R        (42b x  + 132a b x  + 154a x)\|x
+--R   (3)  ---------------------------------
+--R                       231
+--R                                         Type: Union(Expression(Integer),...)
+--E 30
+
+--S 31 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 32
+
+)clear all
+
+--S 33 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/sqrt(x)
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                 +-+
+--R                \|x
+--R                                                    Type: Expression(Integer)
+--E 33
+
+--S 34 of 1353
+r0:=4/5*a*b*x^(5/2)+2/9*b^2*x^(9/2)+2*a^2*sqrt(x)
+--R 
+--R
+--R            2 4          2      2  +-+
+--R        (10b x  + 36a b x  + 90a )\|x
+--R   (2)  ------------------------------
+--R                      45
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 4          2      2  +-+
+--R        (10b x  + 36a b x  + 90a )\|x
+--R   (3)  ------------------------------
+--R                      45
+--R                                         Type: Union(Expression(Integer),...)
+--E 35
+
+--S 36 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 37
+
+)clear all
+
+--S 38 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^(3/2)
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                 +-+
+--R               x\|x
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 1353
+r0:=4/3*a*b*x^(3/2)+2/7*b^2*x^(7/2)-2*a^2/sqrt(x)
+--R 
+--R
+--R          2 4          2      2
+--R        6b x  + 28a b x  - 42a
+--R   (2)  -----------------------
+--R                    +-+
+--R                 21\|x
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 4          2      2
+--R        6b x  + 28a b x  - 42a
+--R   (3)  -----------------------
+--R                    +-+
+--R                 21\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 40
+
+--S 41 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^(5/2)
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                2 +-+
+--R               x \|x
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 1353
+r0:=-2/3*a^2/x^(3/2)+2/5*b^2*x^(5/2)+4*a*b*sqrt(x)
+--R 
+--R
+--R          2 4          2      2
+--R        6b x  + 60a b x  - 10a
+--R   (2)  -----------------------
+--R                    +-+
+--R                15x\|x
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 4          2      2
+--R        6b x  + 60a b x  - 10a
+--R   (3)  -----------------------
+--R                    +-+
+--R                15x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 45
+
+--S 46 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 47
+
+)clear all
+
+--S 48 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^(7/2)
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                3 +-+
+--R               x \|x
+--R                                                    Type: Expression(Integer)
+--E 48
+
+--S 49 of 1353
+r0:=-2/5*a^2/x^(5/2)+2/3*b^2*x^(3/2)-4*a*b/sqrt(x)
+--R 
+--R
+--R           2 4          2     2
+--R        10b x  - 60a b x  - 6a
+--R   (2)  -----------------------
+--R                   2 +-+
+--R                15x \|x
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 4          2     2
+--R        10b x  - 60a b x  - 6a
+--R   (3)  -----------------------
+--R                   2 +-+
+--R                15x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 50
+
+--S 51 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 52
+
+)clear all
+
+--S 53 of 1353
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R          4 11       3 9     2 2 7     3   5    4 3  +-+
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 1353
+r0:=2/9*a^4*x^(9/2)+8/13*a^3*b*x^(13/2)+12/17*a^2*b^2*x^(17/2)+_
+   8/21*a*b^3*x^(21/2)+2/25*b^4*x^(25/2)
+--R 
+--R
+--R   (2)
+--R          4 12            3 10          2 2 8          3   6         4 4  +-+
+--R   (27846b x   + 132600a b x   + 245700a b x  + 214200a b x  + 77350a x )\|x
+--R   --------------------------------------------------------------------------
+--R                                     348075
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          4 12            3 10          2 2 8          3   6         4 4  +-+
+--R   (27846b x   + 132600a b x   + 245700a b x  + 214200a b x  + 77350a x )\|x
+--R   --------------------------------------------------------------------------
+--R                                     348075
+--R                                         Type: Union(Expression(Integer),...)
+--E 55
+
+--S 56 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 1353
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R          4 10       3 8     2 2 6     3   4    4 2  +-+
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 1353
+r0:=2/7*a^4*x^(7/2)+8/11*a^3*b*x^(11/2)+4/5*a^2*b^2*x^(15/2)+_
+   8/19*a*b^3*x^(19/2)+2/23*b^4*x^(23/2)
+--R 
+--R
+--R   (2)
+--R          4 11           3 9          2 2 7          3   5         4 3  +-+
+--R   (14630b x   + 70840a b x  + 134596a b x  + 122360a b x  + 48070a x )\|x
+--R   ------------------------------------------------------------------------
+--R                                    168245
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          4 11           3 9          2 2 7          3   5         4 3  +-+
+--R   (14630b x   + 70840a b x  + 134596a b x  + 122360a b x  + 48070a x )\|x
+--R   ------------------------------------------------------------------------
+--R                                    168245
+--R                                         Type: Union(Expression(Integer),...)
+--E 60
+
+--S 61 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 62
+
+)clear all
+
+--S 63 of 1353
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R          4 9       3 7     2 2 5     3   3    4   +-+
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 63
+
+--S 64 of 1353
+r0:=2/5*a^4*x^(5/2)+8/9*a^3*b*x^(9/2)+12/13*a^2*b^2*x^(13/2)+_
+   8/17*a*b^3*x^(17/2)+2/21*b^4*x^(21/2)
+--R 
+--R
+--R              4 10           3 8         2 2 6         3   4         4 2  +-+
+--R        (6630b x   + 32760a b x  + 64260a b x  + 61880a b x  + 27846a x )\|x
+--R   (2)  ---------------------------------------------------------------------
+--R                                        69615
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4 10           3 8         2 2 6         3   4         4 2  +-+
+--R        (6630b x   + 32760a b x  + 64260a b x  + 61880a b x  + 27846a x )\|x
+--R   (3)  ---------------------------------------------------------------------
+--R                                        69615
+--R                                         Type: Union(Expression(Integer),...)
+--E 65
+
+--S 66 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 67
+
+)clear all
+
+--S 68 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2*sqrt(x)
+--R 
+--R
+--R          4 8       3 6     2 2 4     3   2    4  +-+
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 1353
+r0:=2/3*a^4*x^(3/2)+8/7*a^3*b*x^(7/2)+12/11*a^2*b^2*x^(11/2)+_
+   8/15*a*b^3*x^(15/2)+2/19*b^4*x^(19/2)
+--R 
+--R
+--R              4 9           3 7         2 2 5         3   3         4   +-+
+--R        (2310b x  + 11704a b x  + 23940a b x  + 25080a b x  + 14630a x)\|x
+--R   (2)  -------------------------------------------------------------------
+--R                                       21945
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4 9           3 7         2 2 5         3   3         4   +-+
+--R        (2310b x  + 11704a b x  + 23940a b x  + 25080a b x  + 14630a x)\|x
+--R   (3)  -------------------------------------------------------------------
+--R                                       21945
+--R                                         Type: Union(Expression(Integer),...)
+--E 70
+
+--S 71 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/sqrt(x)
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           +-+
+--R                          \|x
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 1353
+r0:=8/5*a^3*b*x^(5/2)+4/3*a^2*b^2*x^(9/2)+8/13*a*b^3*x^(13/2)+_
+   2/17*b^4*x^(17/2)+2*a^4*sqrt(x)
+--R 
+--R
+--R             4 8          3 6        2 2 4        3   2        4  +-+
+--R        (390b x  + 2040a b x  + 4420a b x  + 5304a b x  + 6630a )\|x
+--R   (2)  -------------------------------------------------------------
+--R                                     3315
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4 8          3 6        2 2 4        3   2        4  +-+
+--R        (390b x  + 2040a b x  + 4420a b x  + 5304a b x  + 6630a )\|x
+--R   (3)  -------------------------------------------------------------
+--R                                     3315
+--R                                         Type: Union(Expression(Integer),...)
+--E 75
+
+--S 76 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 77
+
+)clear all
+
+--S 78 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^(3/2)
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           +-+
+--R                         x\|x
+--R                                                    Type: Expression(Integer)
+--E 78
+
+--S 79 of 1353
+r0:=8/3*a^3*b*x^(3/2)+12/7*a^2*b^2*x^(7/2)+8/11*a*b^3*x^(11/2)+_
+   2/15*b^4*x^(15/2)-2*a^4/sqrt(x)
+--R 
+--R
+--R            4 8         3 6        2 2 4        3   2        4
+--R        154b x  + 840a b x  + 1980a b x  + 3080a b x  - 2310a
+--R   (2)  ------------------------------------------------------
+--R                                    +-+
+--R                               1155\|x
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4 8         3 6        2 2 4        3   2        4
+--R        154b x  + 840a b x  + 1980a b x  + 3080a b x  - 2310a
+--R   (3)  ------------------------------------------------------
+--R                                    +-+
+--R                               1155\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 80
+
+--S 81 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 82
+
+)clear all
+
+--S 83 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^(5/2)
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                          2 +-+
+--R                         x \|x
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 1353
+r0:=-2/3*a^4/x^(3/2)+12/5*a^2*b^2*x^(5/2)+8/9*a*b^3*x^(9/2)+_
+   2/13*b^4*x^(13/2)+8*a^3*b*sqrt(x)
+--R 
+--R
+--R           4 8         3 6        2 2 4        3   2       4
+--R        90b x  + 520a b x  + 1404a b x  + 4680a b x  - 390a
+--R   (2)  ----------------------------------------------------
+--R                                   +-+
+--R                              585x\|x
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4 8         3 6        2 2 4        3   2       4
+--R        90b x  + 520a b x  + 1404a b x  + 4680a b x  - 390a
+--R   (3)  ----------------------------------------------------
+--R                                   +-+
+--R                              585x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 85
+
+--S 86 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^(7/2)
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                          3 +-+
+--R                         x \|x
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 1353
+r0:=-2/5*a^4/x^(5/2)+4*a^2*b^2*x^(3/2)+8/7*a*b^3*x^(7/2)+_
+   2/11*b^4*x^(11/2)-8*a^3*b/sqrt(x)
+--R 
+--R
+--R           4 8         3 6        2 2 4        3   2       4
+--R        70b x  + 440a b x  + 1540a b x  - 3080a b x  - 154a
+--R   (2)  ----------------------------------------------------
+--R                                  2 +-+
+--R                              385x \|x
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4 8         3 6        2 2 4        3   2       4
+--R        70b x  + 440a b x  + 1540a b x  - 3080a b x  - 154a
+--R   (3)  ----------------------------------------------------
+--R                                  2 +-+
+--R                              385x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 90
+
+--S 91 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 92
+
+)clear all
+
+--S 93 of 1353
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R   (1)
+--R     6 15       5 13      2 4 11      3 3 9      4 2 7     5   5    6 3  +-+
+--R   (b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 93
+
+--S 94 of 1353
+r0:=2/9*a^6*x^(9/2)+12/13*a^5*b*x^(13/2)+30/17*a^4*b^2*x^(17/2)+40/21*a^3*_
+   b^3*x^(21/2)+6/5*a^2*b^4*x^(25/2)+12/29*a*b^5*x^(29/2)+2/33*b^6*x^(33/2)
+--R 
+--R
+--R   (2)
+--R                 6 16             5 14            2 4 12            3 3 10
+--R         1345890b x   + 9189180a b x   + 26648622a b x   + 42299400a b x
+--R       + 
+--R                  4 2 8            5   6           6 4
+--R         39189150a b x  + 20498940a b x  + 4934930a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     22207185
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 6 16             5 14            2 4 12            3 3 10
+--R         1345890b x   + 9189180a b x   + 26648622a b x   + 42299400a b x
+--R       + 
+--R                  4 2 8            5   6           6 4
+--R         39189150a b x  + 20498940a b x  + 4934930a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     22207185
+--R                                         Type: Union(Expression(Integer),...)
+--E 95
+
+--S 96 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 97
+
+)clear all
+
+--S 98 of 1353
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R   (1)
+--R     6 14       5 12      2 4 10      3 3 8      4 2 6     5   4    6 2  +-+
+--R   (b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 1353
+r0:=2/7*a^6*x^(7/2)+12/11*a^5*b*x^(11/2)+2*a^4*b^2*x^(15/2)+40/19*a^3*b^3*_
+   x^(19/2)+30/23*a^2*b^4*x^(23/2)+4/9*a*b^5*x^(27/2)+2/31*b^6*x^(31/2)
+--R 
+--R
+--R   (2)
+--R                6 15             5 13            2 4 11            3 3 9
+--R         605682b x   + 4172476a b x   + 12245310a b x   + 19764360a b x
+--R       + 
+--R                  4 2 7            5   5           6 3
+--R         18776142a b x  + 10241532a b x  + 2682306a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     9388071
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                6 15             5 13            2 4 11            3 3 9
+--R         605682b x   + 4172476a b x   + 12245310a b x   + 19764360a b x
+--R       + 
+--R                  4 2 7            5   5           6 3
+--R         18776142a b x  + 10241532a b x  + 2682306a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     9388071
+--R                                         Type: Union(Expression(Integer),...)
+--E 100
+
+--S 101 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 1353
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R   (1)
+--R     6 13       5 11      2 4 9      3 3 7      4 2 5     5   3    6   +-+
+--R   (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 1353
+r0:=2/5*a^6*x^(5/2)+4/3*a^5*b*x^(9/2)+30/13*a^4*b^2*x^(13/2)+40/17*a^3*b^3*_
+   x^(17/2)+10/7*a^2*b^4*x^(21/2)+12/25*a*b^5*x^(25/2)+2/29*b^6*x^(29/2)
+--R 
+--R
+--R   (2)
+--R                6 14             5 12           2 4 10           3 3 8
+--R         232050b x   + 1615068a b x   + 4806750a b x   + 7917000a b x
+--R       + 
+--R                 4 2 6           5   4           6 2
+--R         7764750a b x  + 4486300a b x  + 1345890a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     3364725
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                6 14             5 12           2 4 10           3 3 8
+--R         232050b x   + 1615068a b x   + 4806750a b x   + 7917000a b x
+--R       + 
+--R                 4 2 6           5   4           6 2
+--R         7764750a b x  + 4486300a b x  + 1345890a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     3364725
+--R                                         Type: Union(Expression(Integer),...)
+--E 105
+
+--S 106 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 107
+
+)clear all
+
+--S 108 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3*sqrt(x)
+--R 
+--R
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6  +-+
+--R   (1)  (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 108
+
+--S 109 of 1353
+r0:=2/3*a^6*x^(3/2)+12/7*a^5*b*x^(7/2)+30/11*a^4*b^2*x^(11/2)+8/3*a^3*b^3*_
+   x^(15/2)+30/19*a^2*b^4*x^(19/2)+12/23*a*b^5*x^(23/2)+2/27*b^6*x^(27/2)
+--R 
+--R
+--R   (2)
+--R               6 13            5 11           2 4 9           3 3 7
+--R         67298b x   + 474012a b x   + 1434510a b x  + 2422728a b x
+--R       + 
+--R                 4 2 5           5   3          6
+--R         2477790a b x  + 1557468a b x  + 605682a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     908523
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               6 13            5 11           2 4 9           3 3 7
+--R         67298b x   + 474012a b x   + 1434510a b x  + 2422728a b x
+--R       + 
+--R                 4 2 5           5   3          6
+--R         2477790a b x  + 1557468a b x  + 605682a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     908523
+--R                                         Type: Union(Expression(Integer),...)
+--E 110
+
+--S 111 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 112
+
+)clear all
+
+--S 113 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/sqrt(x)
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                       +-+
+--R                                      \|x
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 1353
+r0:=12/5*a^5*b*x^(5/2)+10/3*a^4*b^2*x^(9/2)+40/13*a^3*b^3*x^(13/2)+_
+   30/17*a^2*b^4*x^(17/2)+4/7*a*b^5*x^(21/2)+2/25*b^6*x^(25/2)+2*a^6*sqrt(x)
+--R 
+--R
+--R   (2)
+--R              6 12           5 10          2 4 8          3 3 6          4 2 4
+--R         9282b x   + 66300a b x   + 204750a b x  + 357000a b x  + 386750a b x
+--R       + 
+--R                5   2          6
+--R         278460a b x  + 232050a
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     116025
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              6 12           5 10          2 4 8          3 3 6          4 2 4
+--R         9282b x   + 66300a b x   + 204750a b x  + 357000a b x  + 386750a b x
+--R       + 
+--R                5   2          6
+--R         278460a b x  + 232050a
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     116025
+--R                                         Type: Union(Expression(Integer),...)
+--E 115
+
+--S 116 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^(3/2)
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        +-+
+--R                                      x\|x
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 1353
+r0:=4*a^5*b*x^(3/2)+30/7*a^4*b^2*x^(7/2)+40/11*a^3*b^3*x^(11/2)+2*a^2*b^4*_
+   x^(15/2)+12/19*a*b^5*x^(19/2)+2/23*b^6*x^(23/2)-2*a^6/sqrt(x)
+--R 
+--R
+--R   (2)
+--R            6 12           5 10         2 4 8          3 3 6          4 2 4
+--R       2926b x   + 21252a b x   + 67298a b x  + 122360a b x  + 144210a b x
+--R     + 
+--R              5   2         6
+--R       134596a b x  - 67298a
+--R  /
+--R           +-+
+--R     33649\|x
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            6 12           5 10         2 4 8          3 3 6          4 2 4
+--R       2926b x   + 21252a b x   + 67298a b x  + 122360a b x  + 144210a b x
+--R     + 
+--R              5   2         6
+--R       134596a b x  - 67298a
+--R  /
+--R           +-+
+--R     33649\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 120
+
+--S 121 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 122
+
+)clear all
+
+--S 123 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^(5/2)
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                      2 +-+
+--R                                     x \|x
+--R                                                    Type: Expression(Integer)
+--E 123
+
+--S 124 of 1353
+r0:=-2/3*a^6/x^(3/2)+6*a^4*b^2*x^(5/2)+40/9*a^3*b^3*x^(9/2)+30/13*a^2*b^4*_
+   x^(13/2)+12/17*a*b^5*x^(17/2)+2/21*b^6*x^(21/2)+12*a^5*b*sqrt(x)
+--R 
+--R
+--R   (2)
+--R            6 12          5 10         2 4 8         3 3 6         4 2 4
+--R       1326b x   + 9828a b x   + 32130a b x  + 61880a b x  + 83538a b x
+--R     + 
+--R              5   2        6
+--R       167076a b x  - 9282a
+--R  /
+--R            +-+
+--R     13923x\|x
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            6 12          5 10         2 4 8         3 3 6         4 2 4
+--R       1326b x   + 9828a b x   + 32130a b x  + 61880a b x  + 83538a b x
+--R     + 
+--R              5   2        6
+--R       167076a b x  - 9282a
+--R  /
+--R            +-+
+--R     13923x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 125
+
+--S 126 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 127
+
+)clear all
+
+--S 128 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^(7/2)
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                      3 +-+
+--R                                     x \|x
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 1353
+r0:=-2/5*a^6/x^(5/2)+10*a^4*b^2*x^(3/2)+40/7*a^3*b^3*x^(7/2)+30/11*a^2*b^4*_
+   x^(11/2)+4/5*a*b^5*x^(15/2)+2/19*b^6*x^(19/2)-12*a^5*b/sqrt(x)
+--R 
+--R
+--R   (2)
+--R           6 12          5 10         2 4 8         3 3 6         4 2 4
+--R       770b x   + 5852a b x   + 19950a b x  + 41800a b x  + 73150a b x
+--R     + 
+--R               5   2        6
+--R       - 87780a b x  - 2926a
+--R  /
+--R          2 +-+
+--R     7315x \|x
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           6 12          5 10         2 4 8         3 3 6         4 2 4
+--R       770b x   + 5852a b x   + 19950a b x  + 41800a b x  + 73150a b x
+--R     + 
+--R               5   2        6
+--R       - 87780a b x  - 2926a
+--R  /
+--R          2 +-+
+--R     7315x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 130
+
+--S 131 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 1353
+t0:=x^(11/2)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                5 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 1353
+r0:=9/10*x^(5/2)/b^2-1/2*x^(9/2)/(b*(a+b*x^2))-9/4*a^(5/4)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(13/4)*sqrt(2))+9/4*a^(5/4)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(13/4)*sqrt(2))-9/8*a^(5/4)*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*sqrt(2))+9/8*_
+   a^(5/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*_
+   sqrt(2))-9/2*a*sqrt(x)/b^3
+--R 
+--R
+--R   (2)
+--R               2      2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45a b x  + 45a )\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 2      2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45a b x  - 45a )\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2      2 4+-+     \|2 \|b \|x  + \|a
+--R       (90a b x  + 90a )\|a atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2      2 4+-+     \|2 \|b \|x  - \|a
+--R       (90a b x  + 90a )\|a atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R           2 4           2       2  +-+4+-+ +-+
+--R       (16b x  - 144a b x  - 180a )\|2 \|b \|x
+--R  /
+--R         4 2        3  +-+4+-+
+--R     (40b x  + 40a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          +---------+                  +---------+
+--R                          |        5                   |        5
+--R           4 2        3   |   6561a         +-+     3  |   6561a
+--R       (10b x  + 10a b )  |- ------- log(9a\|x  + 8b   |- -------)
+--R                         4|       13                  4|       13
+--R                         \|  4096b                    \|  4096b
+--R     + 
+--R                            +---------+                  +---------+
+--R                            |        5                   |        5
+--R             4 2        3   |   6561a         +-+     3  |   6561a
+--R       (- 10b x  - 10a b )  |- ------- log(9a\|x  - 8b   |- -------)
+--R                           4|       13                  4|       13
+--R                           \|  4096b                    \|  4096b
+--R     + 
+--R                                                 +---------+
+--R                                                 |        5
+--R                                              3  |   6561a
+--R                            +---------+     8b   |- -------
+--R                            |        5          4|       13
+--R             4 2        3   |   6561a           \|  4096b
+--R       (- 20b x  - 20a b )  |- ------- atan(---------------)
+--R                           4|       13              +-+
+--R                           \|  4096b             9a\|x
+--R     + 
+--R          2 4          2      2  +-+
+--R       (4b x  - 36a b x  - 45a )\|x
+--R  /
+--R        4 2        3
+--R     10b x  + 10a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 135
+
+--S 136 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 9a\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                +---------+                      +---------+
+--R                |        5                       |        5
+--R         3 +-+  |   6561a  4+-+       +-+     3  |   6561a
+--R       8b \|2   |- ------- \|b log(9a\|x  + 8b   |- -------)
+--R               4|       13                      4|       13
+--R               \|  4096b                        \|  4096b
+--R     + 
+--R                  +---------+                      +---------+
+--R                  |        5                       |        5
+--R           3 +-+  |   6561a  4+-+       +-+     3  |   6561a
+--R       - 8b \|2   |- ------- \|b log(9a\|x  - 8b   |- -------)
+--R                 4|       13                      4|       13
+--R                 \|  4096b                        \|  4096b
+--R     + 
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       9a\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      +-+4+-+ +-+   4+-+                 +-+4+-+ +-+   4+-+
+--R            4+-+     \|2 \|b \|x  + \|a        4+-+     \|2 \|b \|x  - \|a
+--R       - 18a\|a atan(-------------------) - 18a\|a atan(-------------------)
+--R                             4+-+                               4+-+
+--R                             \|a                                \|a
+--R     + 
+--R                                            +---------+
+--R                                            |        5
+--R                                         3  |   6561a
+--R                   +---------+         8b   |- -------
+--R                   |        5              4|       13
+--R            3 +-+  |   6561a  4+-+         \|  4096b
+--R       - 16b \|2   |- ------- \|b atan(---------------)
+--R                  4|       13                  +-+
+--R                  \|  4096b                 9a\|x
+--R  /
+--R       3 +-+4+-+
+--R     8b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 137
+
+)clear all
+
+--S 138 of 1353
+t0:=x^(9/2)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                4 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 138
+
+--S 139 of 1353
+r0:=7/6*x^(3/2)/b^2-1/2*x^(7/2)/(b*(a+b*x^2))+7/4*a^(3/4)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(11/4)*sqrt(2))-7/4*a^(3/4)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(11/4)*sqrt(2))-7/8*a^(3/4)*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*sqrt(2))+_
+   7/8*a^(3/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2       4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 21a)\|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               2       4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21b x  - 21a)\|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2       4+-+3     \|2 \|b \|x  + \|a
+--R       (- 42b x  - 42a)\|a  atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2       4+-+3     \|2 \|b \|x  - \|a
+--R       (- 42b x  - 42a)\|a  atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R             3          +-+4+-+3 +-+
+--R       (16b x  + 28a x)\|2 \|b  \|x
+--R  /
+--R         3 2        2  +-+4+-+3
+--R     (24b x  + 24a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          +---------+                       +---------+3
+--R                          |        3                        |        3
+--R            3 2       2   |   2401a          2 +-+       8  |   2401a
+--R       (- 6b x  - 6a b )  |- ------- log(343a \|x  + 512b   |- ------- )
+--R                         4|       11                       4|       11
+--R                         \|  4096b                         \|  4096b
+--R     + 
+--R                        +---------+                       +---------+3
+--R                        |        3                        |        3
+--R          3 2       2   |   2401a          2 +-+       8  |   2401a
+--R       (6b x  + 6a b )  |- ------- log(343a \|x  - 512b   |- ------- )
+--R                       4|       11                       4|       11
+--R                       \|  4096b                         \|  4096b
+--R     + 
+--R                                                   +---------+3
+--R                                                   |        3
+--R                                                8  |   2401a
+--R                            +---------+     512b   |- -------
+--R                            |        3            4|       11
+--R             3 2        2   |   2401a             \|  4096b
+--R       (- 12b x  - 12a b )  |- ------- atan(------------------)
+--R                           4|       11               2 +-+
+--R                           \|  4096b             343a \|x
+--R     + 
+--R            3         +-+
+--R       (4b x  + 7a x)\|x
+--R  /
+--R       3 2       2
+--R     6b x  + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 140
+
+--S 141 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 7\|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  +---------+                            +---------+3
+--R                  |        3                             |        3
+--R           2 +-+  |   2401a  4+-+3        2 +-+       8  |   2401a
+--R       - 8b \|2   |- ------- \|b  log(343a \|x  + 512b   |- ------- )
+--R                 4|       11                            4|       11
+--R                 \|  4096b                              \|  4096b
+--R     + 
+--R                +---------+                            +---------+3
+--R                |        3                             |        3
+--R         2 +-+  |   2401a  4+-+3        2 +-+       8  |   2401a
+--R       8b \|2   |- ------- \|b  log(343a \|x  - 512b   |- ------- )
+--R               4|       11                            4|       11
+--R               \|  4096b                              \|  4096b
+--R     + 
+--R        4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       7\|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    +-+4+-+ +-+   4+-+                 +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  + \|a       4+-+3     \|2 \|b \|x  - \|a
+--R       14\|a  atan(-------------------) + 14\|a  atan(-------------------)
+--R                           4+-+                               4+-+
+--R                           \|a                                \|a
+--R     + 
+--R                                               +---------+3
+--R                                               |        3
+--R                                            8  |   2401a
+--R                   +---------+          512b   |- -------
+--R                   |        3                 4|       11
+--R            2 +-+  |   2401a  4+-+3           \|  4096b
+--R       - 16b \|2   |- ------- \|b  atan(------------------)
+--R                  4|       11                    2 +-+
+--R                  \|  4096b                  343a \|x
+--R  /
+--R       2 +-+4+-+3
+--R     8b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 142
+
+)clear all
+
+--S 143 of 1353
+t0:=x^(7/2)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                3 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 1353
+r0:=-1/2*x^(5/2)/(b*(a+b*x^2))+5/4*a^(1/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(b^(9/4)*sqrt(2))-5/4*a^(1/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(b^(9/4)*sqrt(2))+5/8*a^(1/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*_
+   b^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*sqrt(2))-5/8*a^(1/4)*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*sqrt(2))+5/2*_
+   sqrt(x)/b^2
+--R 
+--R
+--R   (2)
+--R              2      4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 5a)\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R            2      4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 5a)\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R               2       4+-+     \|2 \|b \|x  + \|a
+--R       (- 10b x  - 10a)\|a atan(-------------------)
+--R                                        4+-+
+--R                                        \|a
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R             2       4+-+     \|2 \|b \|x  - \|a           2        +-+4+-+ +-+
+--R     (- 10b x  - 10a)\|a atan(-------------------) + (16b x  + 20a)\|2 \|b \|x
+--R                                      4+-+
+--R                                      \|a
+--R  /
+--R        3 2       2  +-+4+-+
+--R     (8b x  + 8a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          +--------+                 +--------+
+--R            3 2       2   |   625a        +-+     2  |   625a
+--R       (- 2b x  - 2a b )  |- ------ log(5\|x  + 8b   |- ------)
+--R                         4|       9                 4|       9
+--R                         \|  4096b                  \|  4096b
+--R     + 
+--R                        +--------+                 +--------+
+--R          3 2       2   |   625a        +-+     2  |   625a
+--R       (2b x  + 2a b )  |- ------ log(5\|x  - 8b   |- ------)
+--R                       4|       9                 4|       9
+--R                       \|  4096b                  \|  4096b
+--R     + 
+--R                                            +--------+
+--R                                         2  |   625a
+--R                                       8b   |- ------
+--R                        +--------+         4|       9
+--R          3 2       2   |   625a           \|  4096b         2       +-+
+--R       (4b x  + 4a b )  |- ------ atan(-------------- + (4b x  + 5a)\|x
+--R                       4|       9             +-+
+--R                       \|  4096b            5\|x
+--R  /
+--R       3 2       2
+--R     2b x  + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 145
+
+--S 146 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       5\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  +--------+                     +--------+
+--R           2 +-+  |   625a  4+-+      +-+     2  |   625a
+--R       - 8b \|2   |- ------ \|b log(5\|x  + 8b   |- ------)
+--R                 4|       9                     4|       9
+--R                 \|  4096b                      \|  4096b
+--R     + 
+--R                +--------+                     +--------+
+--R         2 +-+  |   625a  4+-+      +-+     2  |   625a
+--R       8b \|2   |- ------ \|b log(5\|x  - 8b   |- ------)
+--R               4|       9                     4|       9
+--R               \|  4096b                      \|  4096b
+--R     + 
+--R          4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 5\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   +-+4+-+ +-+   4+-+                +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  + \|a       4+-+     \|2 \|b \|x  - \|a
+--R       10\|a atan(-------------------) + 10\|a atan(-------------------)
+--R                          4+-+                              4+-+
+--R                          \|a                               \|a
+--R     + 
+--R                                         +--------+
+--R                                      2  |   625a
+--R                                    8b   |- ------
+--R                 +--------+             4|       9
+--R          2 +-+  |   625a  4+-+         \|  4096b
+--R       16b \|2   |- ------ \|b atan(--------------)
+--R                4|       9                 +-+
+--R                \|  4096b                5\|x
+--R  /
+--R       2 +-+4+-+
+--R     8b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 1353
+t0:=x^(5/2)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                2 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 1353
+r0:=-1/2*x^(3/2)/(b*(a+b*x^2))-3/4*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(1/4)*b^(7/4)*sqrt(2))+3/4*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(1/4)*b^(7/4)*sqrt(2))+3/8*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*b^(7/4)*sqrt(2))-_
+   3/8*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*_
+   b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              2           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 3a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R            2             +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 3a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (6b x  + 6a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a        +-+4+-+4+-+3 +-+
+--R       (6b x  + 6a)atan(-------------------) - 4x\|2 \|a \|b  \|x
+--R                                4+-+
+--R                                \|a
+--R  /
+--R        2 2         +-+4+-+4+-+3
+--R     (8b x  + 8a b)\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       +----------+                    +----------+3
+--R          2 2          |      1         +-+         5  |      1
+--R       (6b x  + 6a b)  |- -------- log(\|x  + 512a b   |- -------- )
+--R                      4|         7                    4|         7
+--R                      \|  4096a b                     \|  4096a b
+--R     + 
+--R                         +----------+                    +----------+3
+--R            2 2          |      1         +-+         5  |      1
+--R       (- 6b x  - 6a b)  |- -------- log(\|x  - 512a b   |- -------- )
+--R                        4|         7                    4|         7
+--R                        \|  4096a b                     \|  4096a b
+--R     + 
+--R                                                   +----------+3
+--R                                                5  |      1
+--R                                          512a b   |- --------
+--R                         +----------+             4|         7
+--R           2 2           |      1                 \|  4096a b       +-+
+--R       (12b x  + 12a b)  |- -------- atan(--------------------- - x\|x
+--R                        4|         7                +-+
+--R                        \|  4096a b                \|x
+--R  /
+--R       2 2
+--R     2b x  + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 150
+
+--S 151 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             +-+4+-+4+-+ +-+     +-+    +-+
+--R       3log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                +----------+                             +----------+3
+--R           +-+  |      1    4+-+4+-+3     +-+         5  |      1
+--R       24b\|2   |- -------- \|a \|b  log(\|x  + 512a b   |- -------- )
+--R               4|         7                             4|         7
+--R               \|  4096a b                              \|  4096a b
+--R     + 
+--R                  +----------+                             +----------+3
+--R             +-+  |      1    4+-+4+-+3     +-+         5  |      1
+--R       - 24b\|2   |- -------- \|a \|b  log(\|x  - 512a b   |- -------- )
+--R                 4|         7                             4|         7
+--R                 \|  4096a b                              \|  4096a b
+--R     + 
+--R                                                          +-+4+-+ +-+   4+-+
+--R                 +-+4+-+4+-+ +-+     +-+    +-+          \|2 \|b \|x  + \|a
+--R       - 3log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 6atan(-------------------)
+--R                                                                 4+-+
+--R                                                                 \|a
+--R     + 
+--R                +-+4+-+ +-+   4+-+
+--R               \|2 \|b \|x  - \|a
+--R       - 6atan(-------------------)
+--R                       4+-+
+--R                       \|a
+--R     + 
+--R                                                   +----------+3
+--R                                                5  |      1
+--R                                          512a b   |- --------
+--R                +----------+                      4|         7
+--R           +-+  |      1    4+-+4+-+3             \|  4096a b
+--R       48b\|2   |- -------- \|a \|b  atan(---------------------)
+--R               4|         7                         +-+
+--R               \|  4096a b                         \|x
+--R  /
+--R        +-+4+-+4+-+3
+--R     8b\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 152
+
+)clear all
+
+--S 153 of 1353
+t0:=x^(3/2)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 +-+
+--R               x\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 153
+
+--S 154 of 1353
+r0:=-1/4*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(5/4)*sqrt(2))+_
+   1/4*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(5/4)*sqrt(2))-_
+   1/8*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(3/4)*_
+   b^(5/4)*sqrt(2))+1/8*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(3/4)*b^(5/4)*sqrt(2))-1/2*sqrt(x)/(b*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R           2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a       +-+4+-+3 4+-+ +-+
+--R       (2b x  + 2a)atan(-------------------) - 4\|2 \|a   \|b \|x
+--R                                4+-+
+--R                                \|a
+--R  /
+--R        2 2         +-+4+-+3 4+-+
+--R     (8b x  + 8a b)\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       +----------+                 +----------+
+--R          2 2          |      1         +-+         |      1
+--R       (2b x  + 2a b)  |- -------- log(\|x  + 8a b  |- --------)
+--R                      4|       3 5                 4|       3 5
+--R                      \|  4096a b                  \|  4096a b
+--R     + 
+--R                         +----------+                 +----------+
+--R            2 2          |      1         +-+         |      1
+--R       (- 2b x  - 2a b)  |- -------- log(\|x  - 8a b  |- --------)
+--R                        4|       3 5                 4|       3 5
+--R                        \|  4096a b                  \|  4096a b
+--R     + 
+--R                                                +----------+
+--R                                                |      1
+--R                                          8a b  |- --------
+--R                         +----------+          4|       3 5
+--R            2 2          |      1              \|  4096a b     +-+
+--R       (- 4b x  - 4a b)  |- -------- atan(----------------- - \|x
+--R                        4|       3 5              +-+
+--R                        \|  4096a b              \|x
+--R  /
+--R       2 2
+--R     2b x  + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 155
+
+--S 156 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R       - log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               +----------+                           +----------+
+--R          +-+  |      1    4+-+3 4+-+     +-+         |      1
+--R       8b\|2   |- -------- \|a   \|b log(\|x  + 8a b  |- --------)
+--R              4|       3 5                           4|       3 5
+--R              \|  4096a b                            \|  4096a b
+--R     + 
+--R                 +----------+                           +----------+
+--R            +-+  |      1    4+-+3 4+-+     +-+         |      1
+--R       - 8b\|2   |- -------- \|a   \|b log(\|x  - 8a b  |- --------)
+--R                4|       3 5                           4|       3 5
+--R                \|  4096a b                            \|  4096a b
+--R     + 
+--R                                                       +-+4+-+ +-+   4+-+
+--R              +-+4+-+4+-+ +-+     +-+    +-+          \|2 \|b \|x  + \|a
+--R       log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 2atan(-------------------)
+--R                                                              4+-+
+--R                                                              \|a
+--R     + 
+--R                +-+4+-+ +-+   4+-+
+--R               \|2 \|b \|x  - \|a
+--R       - 2atan(-------------------)
+--R                       4+-+
+--R                       \|a
+--R     + 
+--R                                                   +----------+
+--R                                                   |      1
+--R                                             8a b  |- --------
+--R                  +----------+                    4|       3 5
+--R             +-+  |      1    4+-+3 4+-+          \|  4096a b
+--R       - 16b\|2   |- -------- \|a   \|b atan(-----------------)
+--R                 4|       3 5                        +-+
+--R                 \|  4096a b                        \|x
+--R  /
+--R        +-+4+-+3 4+-+
+--R     8b\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 157
+
+)clear all
+
+--S 158 of 1353
+t0:=sqrt(x)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 +-+
+--R                \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 1353
+r0:=1/2*x^(3/2)/(a*(a+b*x^2))-1/4*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(5/4)*b^(3/4)*sqrt(2))+1/4*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(5/4)*b^(3/4)*sqrt(2))+1/8*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(5/4)*b^(3/4)*sqrt(2))-1/8*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a        +-+4+-+4+-+3 +-+
+--R       (2b x  + 2a)atan(-------------------) + 4x\|2 \|a \|b  \|x
+--R                                4+-+
+--R                                \|a
+--R  /
+--R            2     2  +-+4+-+4+-+3
+--R     (8a b x  + 8a )\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        +----------+                    +----------+3
+--R              2     2   |      1         +-+       4 2  |      1
+--R       (2a b x  + 2a )  |- -------- log(\|x  + 512a b   |- -------- )
+--R                       4|       5 3                    4|       5 3
+--R                       \|  4096a b                     \|  4096a b
+--R     + 
+--R                          +----------+                    +----------+3
+--R                2     2   |      1         +-+       4 2  |      1
+--R       (- 2a b x  - 2a )  |- -------- log(\|x  - 512a b   |- -------- )
+--R                         4|       5 3                    4|       5 3
+--R                         \|  4096a b                     \|  4096a b
+--R     + 
+--R                                                  +----------+3
+--R                                             4 2  |      1
+--R                                         512a b   |- --------
+--R                        +----------+             4|       5 3
+--R              2     2   |      1                 \|  4096a b       +-+
+--R       (4a b x  + 4a )  |- -------- atan(--------------------- + x\|x
+--R                       4|       5 3                +-+
+--R                       \|  4096a b                \|x
+--R  /
+--R           2     2
+--R     2a b x  + 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 160
+
+--S 161 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +-+4+-+4+-+ +-+     +-+    +-+
+--R       log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               +----------+                             +----------+3
+--R          +-+  |      1    4+-+4+-+3     +-+       4 2  |      1
+--R       8a\|2   |- -------- \|a \|b  log(\|x  + 512a b   |- -------- )
+--R              4|       5 3                             4|       5 3
+--R              \|  4096a b                              \|  4096a b
+--R     + 
+--R                 +----------+                             +----------+3
+--R            +-+  |      1    4+-+4+-+3     +-+       4 2  |      1
+--R       - 8a\|2   |- -------- \|a \|b  log(\|x  - 512a b   |- -------- )
+--R                4|       5 3                             4|       5 3
+--R                \|  4096a b                              \|  4096a b
+--R     + 
+--R                                                         +-+4+-+ +-+   4+-+
+--R                +-+4+-+4+-+ +-+     +-+    +-+          \|2 \|b \|x  + \|a
+--R       - log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 2atan(-------------------)
+--R                                                                4+-+
+--R                                                                \|a
+--R     + 
+--R                +-+4+-+ +-+   4+-+
+--R               \|2 \|b \|x  - \|a
+--R       - 2atan(-------------------)
+--R                       4+-+
+--R                       \|a
+--R     + 
+--R                                                   +----------+3
+--R                                              4 2  |      1
+--R                                          512a b   |- --------
+--R                +----------+                      4|       5 3
+--R           +-+  |      1    4+-+4+-+3             \|  4096a b
+--R       16a\|2   |- -------- \|a \|b  atan(---------------------)
+--R               4|       5 3                         +-+
+--R               \|  4096a b                         \|x
+--R  /
+--R        +-+4+-+4+-+3
+--R     8a\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 1353
+t0:=1/((a^2+2*a*b*x^2+b^2*x^4)*sqrt(x))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R          2 4         2    2  +-+
+--R        (b x  + 2a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 1353
+r0:=-3/4*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(1/4)*sqrt(2))+_
+   3/4*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(1/4)*sqrt(2))-_
+   3/8*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(7/4)*_
+   b^(1/4)*sqrt(2))+3/8*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(7/4)*b^(1/4)*sqrt(2))+1/2*sqrt(x)/(a*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R            2           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 3a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              2             +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 3a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (6b x  + 6a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a       +-+4+-+3 4+-+ +-+
+--R       (6b x  + 6a)atan(-------------------) + 4\|2 \|a   \|b \|x
+--R                                4+-+
+--R                                \|a
+--R  /
+--R            2     2  +-+4+-+3 4+-+
+--R     (8a b x  + 8a )\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        +---------+                +---------+
+--R              2     2   |     1         +-+     2  |     1
+--R       (6a b x  + 6a )  |- ------- log(\|x  + 8a   |- -------)
+--R                       4|       7                 4|       7
+--R                       \|  4096a b                \|  4096a b
+--R     + 
+--R                          +---------+                +---------+
+--R                2     2   |     1         +-+     2  |     1
+--R       (- 6a b x  - 6a )  |- ------- log(\|x  - 8a   |- -------)
+--R                         4|       7                 4|       7
+--R                         \|  4096a b                \|  4096a b
+--R     + 
+--R                                                 +---------+
+--R                                              2  |     1
+--R                                            8a   |- -------
+--R                            +---------+         4|       7
+--R                 2      2   |     1             \|  4096a b    +-+
+--R       (- 12a b x  - 12a )  |- ------- atan(--------------- + \|x
+--R                           4|       7              +-+
+--R                           \|  4096a b            \|x
+--R  /
+--R           2     2
+--R     2a b x  + 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 165
+
+--S 166 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 3log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                +---------+                          +---------+
+--R           +-+  |     1    4+-+3 4+-+     +-+     2  |     1
+--R       24a\|2   |- ------- \|a   \|b log(\|x  + 8a   |- -------)
+--R               4|       7                           4|       7
+--R               \|  4096a b                          \|  4096a b
+--R     + 
+--R                  +---------+                          +---------+
+--R             +-+  |     1    4+-+3 4+-+     +-+     2  |     1
+--R       - 24a\|2   |- ------- \|a   \|b log(\|x  - 8a   |- -------)
+--R                 4|       7                           4|       7
+--R                 \|  4096a b                          \|  4096a b
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R               +-+4+-+4+-+ +-+     +-+    +-+          \|2 \|b \|x  + \|a
+--R       3log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 6atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R                +-+4+-+ +-+   4+-+
+--R               \|2 \|b \|x  - \|a
+--R       - 6atan(-------------------)
+--R                       4+-+
+--R                       \|a
+--R     + 
+--R                                                 +---------+
+--R                                              2  |     1
+--R                                            8a   |- -------
+--R                  +---------+                   4|       7
+--R             +-+  |     1    4+-+3 4+-+         \|  4096a b
+--R       - 48a\|2   |- ------- \|a   \|b atan(---------------)
+--R                 4|       7                        +-+
+--R                 \|  4096a b                      \|x
+--R  /
+--R        +-+4+-+3 4+-+
+--R     8a\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 167
+
+)clear all
+
+--S 168 of 1353
+t0:=1/(x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R          2 5         3    2   +-+
+--R        (b x  + 2a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 168
+
+--S 169 of 1353
+r0:=5/4*b^(1/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*sqrt(2))-_
+   5/4*b^(1/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*sqrt(2))-_
+   5/8*b^(1/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(9/4)*sqrt(2))+5/8*b^(1/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(9/4)*sqrt(2))+(-5/2)/(a^2*sqrt(x))+_
+   1/2/(a*(a+b*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R            2      4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 5a)\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              2      4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 5a)\|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R               2       4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (- 10b x  - 10a)\|b \|x atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R               2       4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (- 10b x  - 10a)\|b \|x atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R               2        +-+4+-+
+--R       (- 20b x  - 16a)\|2 \|a
+--R  /
+--R        2   2     3  +-+4+-+ +-+
+--R     (8a b x  + 8a )\|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          +--------+                          +--------+3
+--R            2   2     3   |   625b   +-+         +-+       7  |   625b
+--R       (- 2a b x  - 2a )  |- ------ \|x log(125b\|x  + 512a   |- ------ )
+--R                         4|       9                          4|       9
+--R                         \|  4096a                           \|  4096a
+--R     + 
+--R                        +--------+                          +--------+3
+--R          2   2     3   |   625b   +-+         +-+       7  |   625b
+--R       (2a b x  + 2a )  |- ------ \|x log(125b\|x  - 512a   |- ------ )
+--R                       4|       9                          4|       9
+--R                       \|  4096a                           \|  4096a
+--R     + 
+--R                                                    +--------+3
+--R                                                 7  |   625b
+--R                                             512a   |- ------
+--R                          +--------+               4|       9
+--R            2   2     3   |   625b   +-+           \|  4096a         2
+--R       (- 4a b x  - 4a )  |- ------ \|x atan(----------------- - 5b x  - 4a
+--R                         4|       9                    +-+
+--R                         \|  4096a                125b\|x
+--R  /
+--R        2   2     3  +-+
+--R     (2a b x  + 2a )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 170
+
+--S 171 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 5\|b log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  +--------+                          +--------+3
+--R           2 +-+  |   625b  4+-+         +-+       7  |   625b
+--R       - 8a \|2   |- ------ \|a log(125b\|x  + 512a   |- ------ )
+--R                 4|       9                          4|       9
+--R                 \|  4096a                           \|  4096a
+--R     + 
+--R                +--------+                          +--------+3
+--R         2 +-+  |   625b  4+-+         +-+       7  |   625b
+--R       8a \|2   |- ------ \|a log(125b\|x  - 512a   |- ------ )
+--R               4|       9                          4|       9
+--R               \|  4096a                           \|  4096a
+--R     + 
+--R        4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       5\|b log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   +-+4+-+ +-+   4+-+                +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  + \|a       4+-+     \|2 \|b \|x  - \|a
+--R       10\|b atan(-------------------) + 10\|b atan(-------------------)
+--R                          4+-+                              4+-+
+--R                          \|a                               \|a
+--R     + 
+--R                                             +--------+3
+--R                                          7  |   625b
+--R                                      512a   |- ------
+--R                   +--------+               4|       9
+--R            2 +-+  |   625b  4+-+           \|  4096a
+--R       - 16a \|2   |- ------ \|a atan(-----------------)
+--R                  4|       9                    +-+
+--R                  \|  4096a                125b\|x
+--R  /
+--R       2 +-+4+-+
+--R     8a \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 172
+
+)clear all
+
+--S 173 of 1353
+t0:=1/(x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R          2 6         4    2 2  +-+
+--R        (b x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 1353
+r0:=(-7/6)/(a^2*x^(3/2))+1/2/(a*x^(3/2)*(a+b*x^2))+7/4*b^(3/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*sqrt(2))-7/4*b^(3/4)*_
+   atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*sqrt(2))+7/8*b^(3/4)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(11/4)*_
+   sqrt(2))-7/8*b^(3/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21b x  - 21a x)\|b  \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             3         4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 21a x)\|b  \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R               3         4+-+3 +-+     \|2 \|b \|x  + \|a
+--R       (- 42b x  - 42a x)\|b  \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R               3         4+-+3 +-+     \|2 \|b \|x  - \|a
+--R       (- 42b x  - 42a x)\|b  \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R               2        +-+4+-+3
+--R       (- 28b x  - 16a)\|2 \|a
+--R  /
+--R         2   3      3   +-+4+-+3 +-+
+--R     (24a b x  + 24a x)\|2 \|a  \|x
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                           +---------+                      +---------+
+--R                           |        3                       |        3
+--R            2   3     3    |   2401b   +-+       +-+     3  |   2401b
+--R       (- 6a b x  - 6a x)  |- ------- \|x log(7b\|x  + 8a   |- -------)
+--R                          4|       11                      4|       11
+--R                          \|  4096a                        \|  4096a
+--R     + 
+--R                         +---------+                      +---------+
+--R                         |        3                       |        3
+--R          2   3     3    |   2401b   +-+       +-+     3  |   2401b
+--R       (6a b x  + 6a x)  |- ------- \|x log(7b\|x  - 8a   |- -------)
+--R                        4|       11                      4|       11
+--R                        \|  4096a                        \|  4096a
+--R     + 
+--R                                                    +---------+
+--R                                                    |        3
+--R                                                 3  |   2401b
+--R                           +---------+         8a   |- -------
+--R                           |        3              4|       11
+--R           2   3      3    |   2401b   +-+         \|  4096a         2
+--R       (12a b x  + 12a x)  |- ------- \|x atan(--------------- - 7b x  - 4a
+--R                          4|       11                  +-+
+--R                          \|  4096a                 7b\|x
+--R  /
+--R        2   3     3   +-+
+--R     (6a b x  + 6a x)\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 175
+
+--S 176 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       7\|b  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  +---------+                       +---------+
+--R                  |        3                        |        3
+--R           2 +-+  |   2401b  4+-+3       +-+     3  |   2401b
+--R       - 8a \|2   |- ------- \|a  log(7b\|x  + 8a   |- -------)
+--R                 4|       11                       4|       11
+--R                 \|  4096a                         \|  4096a
+--R     + 
+--R                +---------+                       +---------+
+--R                |        3                        |        3
+--R         2 +-+  |   2401b  4+-+3       +-+     3  |   2401b
+--R       8a \|2   |- ------- \|a  log(7b\|x  - 8a   |- -------)
+--R               4|       11                       4|       11
+--R               \|  4096a                         \|  4096a
+--R     + 
+--R          4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 7\|b  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    +-+4+-+ +-+   4+-+                 +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  + \|a       4+-+3     \|2 \|b \|x  - \|a
+--R       14\|b  atan(-------------------) + 14\|b  atan(-------------------)
+--R                           4+-+                               4+-+
+--R                           \|a                                \|a
+--R     + 
+--R                                           +---------+
+--R                                           |        3
+--R                                        3  |   2401b
+--R                 +---------+          8a   |- -------
+--R                 |        3               4|       11
+--R          2 +-+  |   2401b  4+-+3         \|  4096a
+--R       16a \|2   |- ------- \|a  atan(---------------)
+--R                4|       11                   +-+
+--R                \|  4096a                  7b\|x
+--R  /
+--R       2 +-+4+-+3
+--R     8a \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 1353
+t0:=1/(x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R          2 7         5    2 3  +-+
+--R        (b x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 1353
+r0:=(-9/10)/(a^2*x^(5/2))+1/2/(a*x^(5/2)*(a+b*x^2))-9/4*b^(5/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*sqrt(2))+9/4*b^(5/4)*_
+   atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*sqrt(2))+9/8*b^(5/4)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(13/4)*sqrt(2))-_
+   9/8*b^(5/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(13/4)*sqrt(2))+9/2*b/(a^3*sqrt(x))
+--R 
+--R
+--R   (2)
+--R             2 4          2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45b x  - 45a b x )\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2 4          2 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45b x  + 45a b x )\|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R           2 4          2 4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (90b x  + 90a b x )\|b \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R           2 4          2 4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (90b x  + 90a b x )\|b \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R            2 4           2      2  +-+4+-+
+--R       (180b x  + 144a b x  - 16a )\|2 \|a
+--R  /
+--R         3   4      4 2  +-+4+-+ +-+
+--R     (40a b x  + 40a x )\|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                            +---------+                            +---------+3
+--R                            |        5                             |        5
+--R           3   4      4 2   |   6561b   +-+        4 +-+       10  |   6561b
+--R       (10a b x  + 10a x )  |- ------- \|x log(729b \|x  + 512a    |- ------- )
+--R                           4|       13                            4|       13
+--R                           \|  4096a                              \|  4096a
+--R     + 
+--R                              +---------+                            +---------+3
+--R                              |        5                             |        5
+--R             3   4      4 2   |   6561b   +-+        4 +-+       10  |   6561b
+--R       (- 10a b x  - 10a x )  |- ------- \|x log(729b \|x  - 512a    |- ------- )
+--R                             4|       13                            4|       13
+--R                             \|  4096a                              \|  4096a
+--R     + 
+--R                                                        +---------+3
+--R                                                        |        5
+--R                                                    10  |   6561b
+--R                            +---------+         512a    |- -------
+--R                            |        5                 4|       13
+--R           3   4      4 2   |   6561b   +-+            \|  4096a         2 4
+--R       (20a b x  + 20a x )  |- ------- \|x atan(------------------- + 45b x
+--R                           4|       13                   4 +-+
+--R                           \|  4096a                 729b \|x
+--R     + 
+--R              2     2
+--R       36a b x  - 4a
+--R  /
+--R         3   4      4 2  +-+
+--R     (10a b x  + 10a x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 180
+
+--S 181 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       9b\|b log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                +---------+                            +---------+3
+--R                |        5                             |        5
+--R         3 +-+  |   6561b  4+-+        4 +-+       10  |   6561b
+--R       8a \|2   |- ------- \|a log(729b \|x  + 512a    |- ------- )
+--R               4|       13                            4|       13
+--R               \|  4096a                              \|  4096a
+--R     + 
+--R                  +---------+                            +---------+3
+--R                  |        5                             |        5
+--R           3 +-+  |   6561b  4+-+        4 +-+       10  |   6561b
+--R       - 8a \|2   |- ------- \|a log(729b \|x  - 512a    |- ------- )
+--R                 4|       13                            4|       13
+--R                 \|  4096a                              \|  4096a
+--R     + 
+--R           4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 9b\|b log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      +-+4+-+ +-+   4+-+                 +-+4+-+ +-+   4+-+
+--R            4+-+     \|2 \|b \|x  + \|a        4+-+     \|2 \|b \|x  - \|a
+--R       - 18b\|b atan(-------------------) - 18b\|b atan(-------------------)
+--R                             4+-+                               4+-+
+--R                             \|a                                \|a
+--R     + 
+--R                                             +---------+3
+--R                                             |        5
+--R                                         10  |   6561b
+--R                 +---------+         512a    |- -------
+--R                 |        5                 4|       13
+--R          3 +-+  |   6561b  4+-+            \|  4096a
+--R       16a \|2   |- ------- \|a atan(-------------------)
+--R                4|       13                   4 +-+
+--R                \|  4096a                 729b \|x
+--R  /
+--R       3 +-+4+-+
+--R     8a \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 182
+
+)clear all
+
+--S 183 of 1353
+t0:=x^(19/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          9 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 183
+
+--S 184 of 1353
+r0:=663/320*x^(5/2)/b^4-1/6*x^(17/2)/(b*(a+b*x^2)^3)-17/48*x^(13/2)/_
+   (b^2*(a+b*x^2)^2)-221/192*x^(9/2)/(b^3*(a+b*x^2))-663/128*a^(5/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(21/4)*sqrt(2))+663/128*_
+   a^(5/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(21/4)*sqrt(2))-_
+   663/256*a^(5/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(21/4)*sqrt(2))+663/256*a^(5/4)*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(21/4)*sqrt(2))-663/64*a*sqrt(x)/b^5
+--R 
+--R
+--R   (2)
+--R                 3 6         2 2 4         3   2        4 4+-+
+--R         (9945a b x  + 29835a b x  + 29835a b x  + 9945a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   3 6         2 2 4         3   2        4 4+-+
+--R         (- 9945a b x  - 29835a b x  - 29835a b x  - 9945a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  3 6         2 2 4         3   2         4 4+-+
+--R         (19890a b x  + 59670a b x  + 59670a b x  + 19890a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  3 6         2 2 4         3   2         4 4+-+
+--R         (19890a b x  + 59670a b x  + 59670a b x  + 19890a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R           4 8           3 6         2 2 4          3   2         4  +-+4+-+ +-+
+--R     (1536b x  - 26112a b x  - 99892a b x  - 111384a b x  - 39780a )\|2 \|b \|x
+--R  /
+--R           8 6           7 4         2 6 2        3 5  +-+4+-+
+--R     (3840b x  + 11520a b x  + 11520a b x  + 3840a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                        +----------------+
+--R                                                        |               5
+--R              8 6          7 4        2 6 2       3 5   |  193220905761a
+--R         (960b x  + 2880a b x  + 2880a b x  + 960a b )  |- --------------
+--R                                                       4|              21
+--R                                                       \|   4294967296b
+--R      *
+--R                               +----------------+
+--R                               |               5
+--R                  +-+       5  |  193220905761a
+--R         log(663a\|x  + 256b   |- --------------)
+--R                              4|              21
+--R                              \|   4294967296b
+--R     + 
+--R                                                          +----------------+
+--R                                                          |               5
+--R                8 6          7 4        2 6 2       3 5   |  193220905761a
+--R         (- 960b x  - 2880a b x  - 2880a b x  - 960a b )  |- --------------
+--R                                                         4|              21
+--R                                                         \|   4294967296b
+--R      *
+--R                               +----------------+
+--R                               |               5
+--R                  +-+       5  |  193220905761a
+--R         log(663a\|x  - 256b   |- --------------)
+--R                              4|              21
+--R                              \|   4294967296b
+--R     + 
+--R                                                            +----------------+
+--R                                                            |               5
+--R                 8 6          7 4        2 6 2        3 5   |  193220905761a
+--R         (- 1920b x  - 5760a b x  - 5760a b x  - 1920a b )  |- --------------
+--R                                                           4|              21
+--R                                                           \|   4294967296b
+--R      *
+--R                     +----------------+
+--R                     |               5
+--R                  5  |  193220905761a
+--R              256b   |- --------------
+--R                    4|              21
+--R                    \|   4294967296b
+--R         atan(------------------------)
+--R                           +-+
+--R                      663a\|x
+--R     + 
+--R            4 8          3 6         2 2 4         3   2        4  +-+
+--R       (384b x  - 6528a b x  - 24973a b x  - 27846a b x  - 9945a )\|x
+--R  /
+--R         8 6          7 4        2 6 2       3 5
+--R     960b x  + 2880a b x  + 2880a b x  + 960a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 185
+
+--S 186 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 663a\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  +----------------+                          +----------------+
+--R                  |               5                           |               5
+--R           5 +-+  |  193220905761a  4+-+         +-+       5  |  193220905761a
+--R       256b \|2   |- -------------- \|b log(663a\|x  + 256b   |- --------------)
+--R                 4|              21                          4|              21
+--R                 \|   4294967296b                            \|   4294967296b
+--R     + 
+--R       -
+--R                       +----------------+
+--R                       |               5
+--R                5 +-+  |  193220905761a  4+-+
+--R            256b \|2   |- -------------- \|b
+--R                      4|              21
+--R                      \|   4294967296b
+--R         *
+--R                                  +----------------+
+--R                                  |               5
+--R                     +-+       5  |  193220905761a
+--R            log(663a\|x  - 256b   |- --------------)
+--R                                 4|              21
+--R                                 \|   4294967296b
+--R     + 
+--R           4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       663a\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                        +-+4+-+ +-+   4+-+                   +-+4+-+ +-+   4+-+
+--R              4+-+     \|2 \|b \|x  + \|a          4+-+     \|2 \|b \|x  - \|a
+--R       - 1326a\|a atan(-------------------) - 1326a\|a atan(-------------------)
+--R                               4+-+                                 4+-+
+--R                               \|a                                  \|a
+--R     + 
+--R                                                      +----------------+
+--R                                                      |               5
+--R                                                   5  |  193220905761a
+--R                    +----------------+         256b   |- --------------
+--R                    |               5                4|              21
+--R             5 +-+  |  193220905761a  4+-+           \|   4294967296b
+--R       - 512b \|2   |- -------------- \|b atan(------------------------)
+--R                   4|              21                       +-+
+--R                   \|   4294967296b                    663a\|x
+--R  /
+--R         5 +-+4+-+
+--R     256b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 187
+
+)clear all
+
+--S 188 of 1353
+t0:=x^(17/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          8 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 1353
+r0:=385/192*x^(3/2)/b^4-1/6*x^(15/2)/(b*(a+b*x^2)^3)-5/16*x^(11/2)/(b^2*_
+   (a+b*x^2)^2)-55/64*x^(7/2)/(b^3*(a+b*x^2))+385/128*a^(3/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(19/4)*sqrt(2))-_
+   385/128*a^(3/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(19/4)*_
+   sqrt(2))-385/256*a^(3/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(19/4)*sqrt(2))+385/256*a^(3/4)*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(19/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3 6          2 4        2   2        3 4+-+3
+--R         (1155b x  + 3465a b x  + 3465a b x  + 1155a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+3
+--R         (- 1155b x  - 3465a b x  - 3465a b x  - 1155a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+3
+--R         (- 2310b x  - 6930a b x  - 6930a b x  - 2310a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+3
+--R         (- 2310b x  - 6930a b x  - 6930a b x  - 2310a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 7          2 5        2   3        3   +-+4+-+3 +-+
+--R       (512b x  + 3060a b x  + 3960a b x  + 1540a x)\|2 \|b  \|x
+--R  /
+--R          7 6          6 4        2 5 2       3 4  +-+4+-+3
+--R     (768b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                        +---------------+
+--R                                                        |              3
+--R                7 6         6 4       2 5 2       3 4   |  21970650625a
+--R         (- 192b x  - 576a b x  - 576a b x  - 192a b )  |- -------------
+--R                                                       4|             19
+--R                                                       \|  4294967296b
+--R      *
+--R                                           +---------------+3
+--R                                           |              3
+--R                      2 +-+            14  |  21970650625a
+--R         log(57066625a \|x  + 16777216b    |- ------------- )
+--R                                          4|             19
+--R                                          \|  4294967296b
+--R     + 
+--R                                                      +---------------+
+--R                                                      |              3
+--R              7 6         6 4       2 5 2       3 4   |  21970650625a
+--R         (192b x  + 576a b x  + 576a b x  + 192a b )  |- -------------
+--R                                                     4|             19
+--R                                                     \|  4294967296b
+--R      *
+--R                                           +---------------+3
+--R                                           |              3
+--R                      2 +-+            14  |  21970650625a
+--R         log(57066625a \|x  - 16777216b    |- ------------- )
+--R                                          4|             19
+--R                                          \|  4294967296b
+--R     + 
+--R                                                          +---------------+
+--R                                                          |              3
+--R                7 6          6 4        2 5 2       3 4   |  21970650625a
+--R         (- 384b x  - 1152a b x  - 1152a b x  - 384a b )  |- -------------
+--R                                                         4|             19
+--R                                                         \|  4294967296b
+--R      *
+--R                           +---------------+3
+--R                           |              3
+--R                       14  |  21970650625a
+--R              16777216b    |- -------------
+--R                          4|             19
+--R                          \|  4294967296b
+--R         atan(------------------------------)
+--R                               2 +-+
+--R                      57066625a \|x
+--R     + 
+--R            3 7         2 5       2   3       3   +-+
+--R       (128b x  + 765a b x  + 990a b x  + 385a x)\|x
+--R  /
+--R         7 6         6 4       2 5 2       3 4
+--R     192b x  + 576a b x  + 576a b x  + 192a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 190
+
+--S 191 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 385\|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R       -
+--R                       +---------------+
+--R                       |              3
+--R                4 +-+  |  21970650625a  4+-+3
+--R            256b \|2   |- ------------- \|b
+--R                      4|             19
+--R                      \|  4294967296b
+--R         *
+--R                                              +---------------+3
+--R                                              |              3
+--R                         2 +-+            14  |  21970650625a
+--R            log(57066625a \|x  + 16777216b    |- ------------- )
+--R                                             4|             19
+--R                                             \|  4294967296b
+--R     + 
+--R                    +---------------+
+--R                    |              3
+--R             4 +-+  |  21970650625a  4+-+3
+--R         256b \|2   |- ------------- \|b
+--R                   4|             19
+--R                   \|  4294967296b
+--R      *
+--R                                           +---------------+3
+--R                                           |              3
+--R                      2 +-+            14  |  21970650625a
+--R         log(57066625a \|x  - 16777216b    |- ------------- )
+--R                                          4|             19
+--R                                          \|  4294967296b
+--R     + 
+--R          4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       385\|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                     +-+4+-+ +-+   4+-+                  +-+4+-+ +-+   4+-+
+--R          4+-+3     \|2 \|b \|x  + \|a        4+-+3     \|2 \|b \|x  - \|a
+--R       770\|a  atan(-------------------) + 770\|a  atan(-------------------)
+--R                            4+-+                                4+-+
+--R                            \|a                                 \|a
+--R     + 
+--R                                                            +---------------+3
+--R                                                            |              3
+--R                                                        14  |  21970650625a
+--R                    +---------------+          16777216b    |- -------------
+--R                    |              3                       4|             19
+--R             4 +-+  |  21970650625a  4+-+3                 \|  4294967296b
+--R       - 512b \|2   |- ------------- \|b  atan(------------------------------)
+--R                   4|             19                            2 +-+
+--R                   \|  4294967296b                     57066625a \|x
+--R  /
+--R         4 +-+4+-+3
+--R     256b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 1353
+t0:=x^(15/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          7 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 1353
+r0:=-1/6*x^(13/2)/(b*(a+b*x^2)^3)-13/48*x^(9/2)/(b^2*(a+b*x^2)^2)-_
+   39/64*x^(5/2)/(b^3*(a+b*x^2))+195/128*a^(1/4)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(17/4)*sqrt(2))-195/128*a^(1/4)*_
+   atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(17/4)*sqrt(2))+_
+   195/256*a^(1/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(17/4)*sqrt(2))-195/256*a^(1/4)*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*sqrt(2))+195/64*sqrt(x)/b^4
+--R 
+--R
+--R   (2)
+--R                3 6          2 4        2   2       3 4+-+
+--R         (- 585b x  - 1755a b x  - 1755a b x  - 585a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              3 6          2 4        2   2       3 4+-+
+--R         (585b x  + 1755a b x  + 1755a b x  + 585a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+
+--R         (- 1170b x  - 3510a b x  - 3510a b x  - 1170a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+
+--R         (- 1170b x  - 3510a b x  - 3510a b x  - 1170a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R             3 6          2 4        2   2        3  +-+4+-+ +-+
+--R       (1536b x  + 5876a b x  + 6552a b x  + 2340a )\|2 \|b \|x
+--R  /
+--R          7 6          6 4        2 5 2       3 4  +-+4+-+
+--R     (768b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                        +---------------+
+--R                7 6         6 4       2 5 2       3 4   |   1445900625a
+--R         (- 192b x  - 576a b x  - 576a b x  - 192a b )  |- -------------
+--R                                                       4|             17
+--R                                                       \|  4294967296b
+--R      *
+--R                              +---------------+
+--R                 +-+       4  |   1445900625a
+--R         log(195\|x  + 256b   |- -------------)
+--R                             4|             17
+--R                             \|  4294967296b
+--R     + 
+--R                                                      +---------------+
+--R              7 6         6 4       2 5 2       3 4   |   1445900625a
+--R         (192b x  + 576a b x  + 576a b x  + 192a b )  |- -------------
+--R                                                     4|             17
+--R                                                     \|  4294967296b
+--R      *
+--R                              +---------------+
+--R                 +-+       4  |   1445900625a
+--R         log(195\|x  - 256b   |- -------------)
+--R                             4|             17
+--R                             \|  4294967296b
+--R     + 
+--R                                                        +---------------+
+--R              7 6          6 4        2 5 2       3 4   |   1445900625a
+--R         (384b x  + 1152a b x  + 1152a b x  + 384a b )  |- -------------
+--R                                                       4|             17
+--R                                                       \|  4294967296b
+--R      *
+--R                     +---------------+
+--R                  4  |   1445900625a
+--R              256b   |- -------------
+--R                    4|             17
+--R                    \|  4294967296b
+--R         atan(-----------------------)
+--R                          +-+
+--R                      195\|x
+--R     + 
+--R            3 6          2 4        2   2       3  +-+
+--R       (384b x  + 1469a b x  + 1638a b x  + 585a )\|x
+--R  /
+--R         7 6         6 4       2 5 2       3 4
+--R     192b x  + 576a b x  + 576a b x  + 192a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 195
+
+--S 196 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       195\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    +---------------+                         +---------------+
+--R             4 +-+  |   1445900625a  4+-+        +-+       4  |   1445900625a
+--R       - 256b \|2   |- ------------- \|b log(195\|x  + 256b   |- -------------)
+--R                   4|             17                         4|             17
+--R                   \|  4294967296b                           \|  4294967296b
+--R     + 
+--R                  +---------------+                         +---------------+
+--R           4 +-+  |   1445900625a  4+-+        +-+       4  |   1445900625a
+--R       256b \|2   |- ------------- \|b log(195\|x  - 256b   |- -------------)
+--R                 4|             17                         4|             17
+--R                 \|  4294967296b                           \|  4294967296b
+--R     + 
+--R            4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 195\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    +-+4+-+ +-+   4+-+                 +-+4+-+ +-+   4+-+
+--R          4+-+     \|2 \|b \|x  + \|a        4+-+     \|2 \|b \|x  - \|a
+--R       390\|a atan(-------------------) + 390\|a atan(-------------------)
+--R                           4+-+                               4+-+
+--R                           \|a                                \|a
+--R     + 
+--R                                                   +---------------+
+--R                                                4  |   1445900625a
+--R                                            256b   |- -------------
+--R                  +---------------+               4|             17
+--R           4 +-+  |   1445900625a  4+-+           \|  4294967296b
+--R       512b \|2   |- ------------- \|b atan(-----------------------)
+--R                 4|             17                      +-+
+--R                 \|  4294967296b                    195\|x
+--R  /
+--R         4 +-+4+-+
+--R     256b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 197
+
+)clear all
+
+--S 198 of 1353
+t0:=x^(13/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          6 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 198
+
+--S 199 of 1353
+r0:=-1/6*x^(11/2)/(b*(a+b*x^2)^3)-11/48*x^(7/2)/(b^2*(a+b*x^2)^2)-_
+   77/192*x^(3/2)/(b^3*(a+b*x^2))-77/128*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(1/4)*b^(15/4)*sqrt(2))+77/128*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(1/4)*b^(15/4)*sqrt(2))+77/256*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*_
+   b^(15/4)*sqrt(2))-77/256*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(1/4)*b^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                3 6         2 4       2   2       3
+--R         (- 231b x  - 693a b x  - 693a b x  - 231a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              3 6         2 4       2   2       3
+--R         (231b x  + 693a b x  + 693a b x  + 231a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R            3 6          2 4        2   2       3      \|2 \|b \|x  + \|a
+--R       (462b x  + 1386a b x  + 1386a b x  + 462a )atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R            3 6          2 4        2   2       3      \|2 \|b \|x  - \|a
+--R       (462b x  + 1386a b x  + 1386a b x  + 462a )atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R              2 5           3       2   +-+4+-+4+-+3 +-+
+--R       (- 612b x  - 792a b x  - 308a x)\|2 \|a \|b  \|x
+--R  /
+--R          6 6          5 4        2 4 2       3 3  +-+4+-+4+-+3
+--R     (768b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                              +-----------------+
+--R                6 6           5 4         2 4 2         3 3   |         1
+--R         (14784b x  + 44352a b x  + 44352a b x  + 14784a b )  |- ---------------
+--R                                                             4|               15
+--R                                                             \|  4294967296a b
+--R      *
+--R                                   +-----------------+3
+--R              +-+              11  |         1
+--R         log(\|x  + 16777216a b    |- --------------- )
+--R                                  4|               15
+--R                                  \|  4294967296a b
+--R     + 
+--R                  6 6           5 4         2 4 2         3 3
+--R         (- 14784b x  - 44352a b x  - 44352a b x  - 14784a b )
+--R      *
+--R          +-----------------+                          +-----------------+3
+--R          |         1             +-+              11  |         1
+--R          |- --------------- log(\|x  - 16777216a b    |- --------------- )
+--R         4|               15                          4|               15
+--R         \|  4294967296a b                            \|  4294967296a b
+--R     + 
+--R                                                              +-----------------+
+--R                6 6           5 4         2 4 2         3 3   |         1
+--R         (29568b x  + 88704a b x  + 88704a b x  + 29568a b )  |- ---------------
+--R                                                             4|               15
+--R                                                             \|  4294967296a b
+--R      *
+--R                             +-----------------+3
+--R                         11  |         1
+--R              16777216a b    |- ---------------
+--R                            4|               15
+--R                            \|  4294967296a b
+--R         atan(----------------------------------)
+--R                              +-+
+--R                             \|x
+--R     + 
+--R              2 5           3      2   +-+
+--R       (- 153b x  - 198a b x  - 77a x)\|x
+--R  /
+--R         6 6         5 4       2 4 2       3 3
+--R     192b x  + 576a b x  + 576a b x  + 192a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 200
+
+--S 201 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R       77log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      +-----------------+
+--R               3 +-+  |         1        4+-+4+-+3
+--R         19712b \|2   |- --------------- \|a \|b
+--R                     4|               15
+--R                     \|  4294967296a b
+--R      *
+--R                                   +-----------------+3
+--R              +-+              11  |         1
+--R         log(\|x  + 16777216a b    |- --------------- )
+--R                                  4|               15
+--R                                  \|  4294967296a b
+--R     + 
+--R       -
+--R                         +-----------------+
+--R                  3 +-+  |         1        4+-+4+-+3
+--R            19712b \|2   |- --------------- \|a \|b
+--R                        4|               15
+--R                        \|  4294967296a b
+--R         *
+--R                                      +-----------------+3
+--R                 +-+              11  |         1
+--R            log(\|x  - 16777216a b    |- --------------- )
+--R                                     4|               15
+--R                                     \|  4294967296a b
+--R     + 
+--R                                                             +-+4+-+ +-+   4+-+
+--R                  +-+4+-+4+-+ +-+     +-+    +-+            \|2 \|b \|x  + \|a
+--R       - 77log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 154atan(-------------------)
+--R                                                                    4+-+
+--R                                                                    \|a
+--R     + 
+--R                  +-+4+-+ +-+   4+-+
+--R                 \|2 \|b \|x  - \|a
+--R       - 154atan(-------------------)
+--R                         4+-+
+--R                         \|a
+--R     + 
+--R                      +-----------------+
+--R               3 +-+  |         1        4+-+4+-+3
+--R         39424b \|2   |- --------------- \|a \|b
+--R                     4|               15
+--R                     \|  4294967296a b
+--R      *
+--R                             +-----------------+3
+--R                         11  |         1
+--R              16777216a b    |- ---------------
+--R                            4|               15
+--R                            \|  4294967296a b
+--R         atan(----------------------------------)
+--R                              +-+
+--R                             \|x
+--R  /
+--R         3 +-+4+-+4+-+3
+--R     256b \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 202
+
+)clear all
+
+--S 203 of 1353
+t0:=x^(11/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          5 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 1353
+r0:=-1/6*x^(9/2)/(b*(a+b*x^2)^3)-3/16*x^(5/2)/(b^2*(a+b*x^2)^2)-_
+   15/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(13/4)*_
+   sqrt(2))+15/128*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*_
+   b^(13/4)*sqrt(2))-15/256*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(3/4)*b^(13/4)*sqrt(2))+15/256*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(3/4)*b^(13/4)*sqrt(2))-_
+   15/64*sqrt(x)/(b^3*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R             3 6         2 4       2   2      3
+--R         (45b x  + 135a b x  + 135a b x  + 45a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               3 6         2 4       2   2      3
+--R         (- 45b x  - 135a b x  - 135a b x  - 45a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  + \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  - \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R              2 4           2       2  +-+4+-+3 4+-+ +-+
+--R       (- 452b x  - 504a b x  - 180a )\|2 \|a   \|b \|x
+--R  /
+--R          6 6          5 4        2 4 2       3 3  +-+4+-+3 4+-+
+--R     (768b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                          +-----------------+
+--R               6 6          5 4        2 4 2        3 3   |         1
+--R         (2880b x  + 8640a b x  + 8640a b x  + 2880a b )  |- ---------------
+--R                                                         4|             3 13
+--R                                                         \|  4294967296a b
+--R      *
+--R                             +-----------------+
+--R              +-+         3  |         1
+--R         log(\|x  + 256a b   |- ---------------)
+--R                            4|             3 13
+--R                            \|  4294967296a b
+--R     + 
+--R                                                            +-----------------+
+--R                 6 6          5 4        2 4 2        3 3   |         1
+--R         (- 2880b x  - 8640a b x  - 8640a b x  - 2880a b )  |- ---------------
+--R                                                           4|             3 13
+--R                                                           \|  4294967296a b
+--R      *
+--R                             +-----------------+
+--R              +-+         3  |         1
+--R         log(\|x  - 256a b   |- ---------------)
+--R                            4|             3 13
+--R                            \|  4294967296a b
+--R     + 
+--R                                                              +-----------------+
+--R                 6 6           5 4         2 4 2        3 3   |         1
+--R         (- 5760b x  - 17280a b x  - 17280a b x  - 5760a b )  |- ---------------
+--R                                                             4|             3 13
+--R                                                             \|  4294967296a b
+--R      *
+--R                       +-----------------+
+--R                    3  |         1
+--R              256a b   |- ---------------
+--R                      4|             3 13
+--R                      \|  4294967296a b
+--R         atan(---------------------------)
+--R                           +-+
+--R                          \|x
+--R     + 
+--R              2 4           2      2  +-+
+--R       (- 113b x  - 126a b x  - 45a )\|x
+--R  /
+--R         6 6         5 4       2 4 2       3 3
+--R     192b x  + 576a b x  + 576a b x  + 192a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 205
+
+--S 206 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 15log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                     +-----------------+
+--R              3 +-+  |         1        4+-+3 4+-+
+--R         3840b \|2   |- --------------- \|a   \|b
+--R                    4|             3 13
+--R                    \|  4294967296a b
+--R      *
+--R                             +-----------------+
+--R              +-+         3  |         1
+--R         log(\|x  + 256a b   |- ---------------)
+--R                            4|             3 13
+--R                            \|  4294967296a b
+--R     + 
+--R       -
+--R                        +-----------------+
+--R                 3 +-+  |         1        4+-+3 4+-+
+--R            3840b \|2   |- --------------- \|a   \|b
+--R                       4|             3 13
+--R                       \|  4294967296a b
+--R         *
+--R                                +-----------------+
+--R                 +-+         3  |         1
+--R            log(\|x  - 256a b   |- ---------------)
+--R                               4|             3 13
+--R                               \|  4294967296a b
+--R     + 
+--R                                                          +-+4+-+ +-+   4+-+
+--R                +-+4+-+4+-+ +-+     +-+    +-+           \|2 \|b \|x  + \|a
+--R       15log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 30atan(-------------------)
+--R                                                                 4+-+
+--R                                                                 \|a
+--R     + 
+--R                 +-+4+-+ +-+   4+-+
+--R                \|2 \|b \|x  - \|a
+--R       - 30atan(-------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R                                                              +-----------------+
+--R                                                           3  |         1
+--R                                                     256a b   |- ---------------
+--R                   +-----------------+                       4|             3 13
+--R            3 +-+  |         1        4+-+3 4+-+             \|  4294967296a b
+--R     - 7680b \|2   |- --------------- \|a   \|b atan(---------------------------)
+--R                  4|             3 13                             +-+
+--R                  \|  4294967296a b                              \|x
+--R  /
+--R         3 +-+4+-+3 4+-+
+--R     256b \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 1353
+t0:=x^(9/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          4 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 1353
+r0:=-1/6*x^(7/2)/(b*(a+b*x^2)^3)-7/48*x^(3/2)/(b^2*(a+b*x^2)^2)+_
+   7/64*x^(3/2)/(a*b^2*(a+b*x^2))-7/128*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(5/4)*b^(11/4)*sqrt(2))+7/128*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*b^(11/4)*sqrt(2))+7/256*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*_
+   b^(11/4)*sqrt(2))-7/256*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(5/4)*b^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3 6        2 4      2   2      3
+--R         (- 21b x  - 63a b x  - 63a b x  - 21a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             3 6        2 4      2   2      3
+--R         (21b x  + 63a b x  + 63a b x  + 21a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  + \|a
+--R       (42b x  + 126a b x  + 126a b x  + 42a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  - \|a
+--R       (42b x  + 126a b x  + 126a b x  + 42a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R           2 5          3      2   +-+4+-+4+-+3 +-+
+--R       (84b x  - 72a b x  - 28a x)\|2 \|a \|b  \|x
+--R  /
+--R            5 6        2 4 4        3 3 2       4 2  +-+4+-+4+-+3
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                            +-----------------+
+--R                 5 6        2 4 4        3 3 2        4 2   |         1
+--R         (1344a b x  + 4032a b x  + 4032a b x  + 1344a b )  |- ---------------
+--R                                                           4|             5 11
+--R                                                           \|  4294967296a b
+--R      *
+--R                                  +-----------------+3
+--R              +-+            4 8  |         1
+--R         log(\|x  + 16777216a b   |- --------------- )
+--R                                 4|             5 11
+--R                                 \|  4294967296a b
+--R     + 
+--R                                                              +-----------------+
+--R                   5 6        2 4 4        3 3 2        4 2   |         1
+--R         (- 1344a b x  - 4032a b x  - 4032a b x  - 1344a b )  |- ---------------
+--R                                                             4|             5 11
+--R                                                             \|  4294967296a b
+--R      *
+--R                                  +-----------------+3
+--R              +-+            4 8  |         1
+--R         log(\|x  - 16777216a b   |- --------------- )
+--R                                 4|             5 11
+--R                                 \|  4294967296a b
+--R     + 
+--R                                                            +-----------------+
+--R                 5 6        2 4 4        3 3 2        4 2   |         1
+--R         (2688a b x  + 8064a b x  + 8064a b x  + 2688a b )  |- ---------------
+--R                                                           4|             5 11
+--R                                                           \|  4294967296a b
+--R      *
+--R                            +-----------------+3
+--R                       4 8  |         1
+--R              16777216a b   |- ---------------
+--R                           4|             5 11
+--R                           \|  4294967296a b
+--R         atan(---------------------------------)
+--R                              +-+
+--R                             \|x
+--R     + 
+--R           2 5          3     2   +-+
+--R       (21b x  - 18a b x  - 7a x)\|x
+--R  /
+--R           5 6       2 4 4       3 3 2       4 2
+--R     192a b x  + 576a b x  + 576a b x  + 192a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 210
+
+--S 211 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             +-+4+-+4+-+ +-+     +-+    +-+
+--R       7log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                       +-----------------+
+--R                2 +-+  |         1        4+-+4+-+3
+--R         1792a b \|2   |- --------------- \|a \|b
+--R                      4|             5 11
+--R                      \|  4294967296a b
+--R      *
+--R                                  +-----------------+3
+--R              +-+            4 8  |         1
+--R         log(\|x  + 16777216a b   |- --------------- )
+--R                                 4|             5 11
+--R                                 \|  4294967296a b
+--R     + 
+--R       -
+--R                          +-----------------+
+--R                   2 +-+  |         1        4+-+4+-+3
+--R            1792a b \|2   |- --------------- \|a \|b
+--R                         4|             5 11
+--R                         \|  4294967296a b
+--R         *
+--R                                     +-----------------+3
+--R                 +-+            4 8  |         1
+--R            log(\|x  - 16777216a b   |- --------------- )
+--R                                    4|             5 11
+--R                                    \|  4294967296a b
+--R     + 
+--R                                                           +-+4+-+ +-+   4+-+
+--R                 +-+4+-+4+-+ +-+     +-+    +-+           \|2 \|b \|x  + \|a
+--R       - 7log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 14atan(-------------------)
+--R                                                                  4+-+
+--R                                                                  \|a
+--R     + 
+--R                 +-+4+-+ +-+   4+-+
+--R                \|2 \|b \|x  - \|a
+--R       - 14atan(-------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R                       +-----------------+
+--R                2 +-+  |         1        4+-+4+-+3
+--R         3584a b \|2   |- --------------- \|a \|b
+--R                      4|             5 11
+--R                      \|  4294967296a b
+--R      *
+--R                            +-----------------+3
+--R                       4 8  |         1
+--R              16777216a b   |- ---------------
+--R                           4|             5 11
+--R                           \|  4294967296a b
+--R         atan(---------------------------------)
+--R                              +-+
+--R                             \|x
+--R  /
+--R           2 +-+4+-+4+-+3
+--R     256a b \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 212
+
+)clear all
+
+--S 213 of 1353
+t0:=x^(7/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          3 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 213
+
+--S 214 of 1353
+r0:=-1/6*x^(5/2)/(b*(a+b*x^2)^3)-5/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(7/4)*b^(9/4)*sqrt(2))+5/128*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(7/4)*b^(9/4)*sqrt(2))-5/256*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(7/4)*b^(9/4)*sqrt(2))+_
+   5/256*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(7/4)*b^(9/4)*sqrt(2))-5/48*sqrt(x)/(b^2*(a+b*x^2)^2)+_
+   5/192*sqrt(x)/(a*b^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R           3 6        2 4      2   2      3      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (15b x  + 45a b x  + 45a b x  + 15a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               3 6        2 4      2   2      3
+--R         (- 15b x  - 45a b x  - 45a b x  - 15a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R           3 6        2 4      2   2      3      \|2 \|b \|x  + \|a
+--R       (30b x  + 90a b x  + 90a b x  + 30a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R           3 6        2 4      2   2      3      \|2 \|b \|x  - \|a
+--R       (30b x  + 90a b x  + 90a b x  + 30a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R           2 4           2      2  +-+4+-+3 4+-+ +-+
+--R       (20b x  - 168a b x  - 60a )\|2 \|a   \|b \|x
+--R  /
+--R            5 6        2 4 4        3 3 2       4 2  +-+4+-+3 4+-+
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                          +----------------+
+--R                5 6        2 4 4        3 3 2       4 2   |         1
+--R         (960a b x  + 2880a b x  + 2880a b x  + 960a b )  |- --------------
+--R                                                         4|             7 9
+--R                                                         \|  4294967296a b
+--R      *
+--R                             +----------------+
+--R              +-+       2 2  |         1
+--R         log(\|x  + 256a b   |- --------------)
+--R                            4|             7 9
+--R                            \|  4294967296a b
+--R     + 
+--R                                                            +----------------+
+--R                  5 6        2 4 4        3 3 2       4 2   |         1
+--R         (- 960a b x  - 2880a b x  - 2880a b x  - 960a b )  |- --------------
+--R                                                           4|             7 9
+--R                                                           \|  4294967296a b
+--R      *
+--R                             +----------------+
+--R              +-+       2 2  |         1
+--R         log(\|x  - 256a b   |- --------------)
+--R                            4|             7 9
+--R                            \|  4294967296a b
+--R     + 
+--R                                                              +----------------+
+--R                   5 6        2 4 4        3 3 2        4 2   |         1
+--R         (- 1920a b x  - 5760a b x  - 5760a b x  - 1920a b )  |- --------------
+--R                                                             4|             7 9
+--R                                                             \|  4294967296a b
+--R      *
+--R                       +----------------+
+--R                  2 2  |         1
+--R              256a b   |- --------------
+--R                      4|             7 9
+--R                      \|  4294967296a b
+--R         atan(--------------------------)
+--R                          +-+
+--R                         \|x
+--R     + 
+--R          2 4          2      2  +-+
+--R       (5b x  - 42a b x  - 15a )\|x
+--R  /
+--R           5 6       2 4 4       3 3 2       4 2
+--R     192a b x  + 576a b x  + 576a b x  + 192a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 215
+
+--S 216 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 5log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                       +----------------+
+--R                2 +-+  |         1       4+-+3 4+-+
+--R         1280a b \|2   |- -------------- \|a   \|b
+--R                      4|             7 9
+--R                      \|  4294967296a b
+--R      *
+--R                             +----------------+
+--R              +-+       2 2  |         1
+--R         log(\|x  + 256a b   |- --------------)
+--R                            4|             7 9
+--R                            \|  4294967296a b
+--R     + 
+--R       -
+--R                          +----------------+
+--R                   2 +-+  |         1       4+-+3 4+-+
+--R            1280a b \|2   |- -------------- \|a   \|b
+--R                         4|             7 9
+--R                         \|  4294967296a b
+--R         *
+--R                                +----------------+
+--R                 +-+       2 2  |         1
+--R            log(\|x  - 256a b   |- --------------)
+--R                               4|             7 9
+--R                               \|  4294967296a b
+--R     + 
+--R                                                         +-+4+-+ +-+   4+-+
+--R               +-+4+-+4+-+ +-+     +-+    +-+           \|2 \|b \|x  + \|a
+--R       5log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 10atan(-------------------)
+--R                                                                4+-+
+--R                                                                \|a
+--R     + 
+--R                 +-+4+-+ +-+   4+-+
+--R                \|2 \|b \|x  - \|a
+--R       - 10atan(-------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R                                                               +----------------+
+--R                                                          2 2  |         1
+--R                                                      256a b   |- --------------
+--R                     +----------------+                       4|             7 9
+--R              2 +-+  |         1       4+-+3 4+-+             \|  4294967296a b
+--R     - 2560a b \|2   |- -------------- \|a   \|b atan(--------------------------)
+--R                    4|             7 9                            +-+
+--R                    \|  4294967296a b                            \|x
+--R  /
+--R           2 +-+4+-+3 4+-+
+--R     256a b \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 217
+
+)clear all
+
+--S 218 of 1353
+t0:=x^(5/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          2 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 1353
+r0:=-1/6*x^(3/2)/(b*(a+b*x^2)^3)+1/16*x^(3/2)/(a*b*(a+b*x^2)^2)+_
+   5/64*x^(3/2)/(a^2*b*(a+b*x^2))-5/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(9/4)*b^(7/4)*sqrt(2))+5/128*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(9/4)*b^(7/4)*sqrt(2))+5/256*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(9/4)*b^(7/4)*sqrt(2))-_
+   5/256*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(9/4)*b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3 6        2 4      2   2      3
+--R         (- 15b x  - 45a b x  - 45a b x  - 15a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             3 6        2 4      2   2      3
+--R         (15b x  + 45a b x  + 45a b x  + 15a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R           3 6        2 4      2   2      3      \|2 \|b \|x  + \|a
+--R       (30b x  + 90a b x  + 90a b x  + 30a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R           3 6        2 4      2   2      3      \|2 \|b \|x  - \|a
+--R       (30b x  + 90a b x  + 90a b x  + 30a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R           2 5           3      2   +-+4+-+4+-+3 +-+
+--R       (60b x  + 168a b x  - 20a x)\|2 \|a \|b  \|x
+--R  /
+--R          2 4 6        3 3 4        4 2 2       5   +-+4+-+4+-+3
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a b)\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                         +----------------+
+--R              2 4 6        3 3 4        4 2 2       5    |         1
+--R         (960a b x  + 2880a b x  + 2880a b x  + 960a b)  |- --------------
+--R                                                        4|             9 7
+--R                                                        \|  4294967296a b
+--R      *
+--R                                  +----------------+3
+--R              +-+            7 5  |         1
+--R         log(\|x  + 16777216a b   |- -------------- )
+--R                                 4|             9 7
+--R                                 \|  4294967296a b
+--R     + 
+--R                                                           +----------------+
+--R                2 4 6        3 3 4        4 2 2       5    |         1
+--R         (- 960a b x  - 2880a b x  - 2880a b x  - 960a b)  |- --------------
+--R                                                          4|             9 7
+--R                                                          \|  4294967296a b
+--R      *
+--R                                  +----------------+3
+--R              +-+            7 5  |         1
+--R         log(\|x  - 16777216a b   |- -------------- )
+--R                                 4|             9 7
+--R                                 \|  4294967296a b
+--R     + 
+--R                                                           +----------------+
+--R               2 4 6        3 3 4        4 2 2        5    |         1
+--R         (1920a b x  + 5760a b x  + 5760a b x  + 1920a b)  |- --------------
+--R                                                          4|             9 7
+--R                                                          \|  4294967296a b
+--R      *
+--R                            +----------------+3
+--R                       7 5  |         1
+--R              16777216a b   |- --------------
+--R                           4|             9 7
+--R                           \|  4294967296a b
+--R         atan(--------------------------------)
+--R                             +-+
+--R                            \|x
+--R     + 
+--R           2 5          3     2   +-+
+--R       (15b x  + 42a b x  - 5a x)\|x
+--R  /
+--R         2 4 6       3 3 4       4 2 2       5
+--R     192a b x  + 576a b x  + 576a b x  + 192a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 220
+
+--S 221 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             +-+4+-+4+-+ +-+     +-+    +-+
+--R       5log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      +----------------+
+--R              2  +-+  |         1       4+-+4+-+3
+--R         1280a b\|2   |- -------------- \|a \|b
+--R                     4|             9 7
+--R                     \|  4294967296a b
+--R      *
+--R                                  +----------------+3
+--R              +-+            7 5  |         1
+--R         log(\|x  + 16777216a b   |- -------------- )
+--R                                 4|             9 7
+--R                                 \|  4294967296a b
+--R     + 
+--R       -
+--R                         +----------------+
+--R                 2  +-+  |         1       4+-+4+-+3
+--R            1280a b\|2   |- -------------- \|a \|b
+--R                        4|             9 7
+--R                        \|  4294967296a b
+--R         *
+--R                                     +----------------+3
+--R                 +-+            7 5  |         1
+--R            log(\|x  - 16777216a b   |- -------------- )
+--R                                    4|             9 7
+--R                                    \|  4294967296a b
+--R     + 
+--R                                                           +-+4+-+ +-+   4+-+
+--R                 +-+4+-+4+-+ +-+     +-+    +-+           \|2 \|b \|x  + \|a
+--R       - 5log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 10atan(-------------------)
+--R                                                                  4+-+
+--R                                                                  \|a
+--R     + 
+--R                 +-+4+-+ +-+   4+-+
+--R                \|2 \|b \|x  - \|a
+--R       - 10atan(-------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R                      +----------------+
+--R              2  +-+  |         1       4+-+4+-+3
+--R         2560a b\|2   |- -------------- \|a \|b
+--R                     4|             9 7
+--R                     \|  4294967296a b
+--R      *
+--R                            +----------------+3
+--R                       7 5  |         1
+--R              16777216a b   |- --------------
+--R                           4|             9 7
+--R                           \|  4294967296a b
+--R         atan(--------------------------------)
+--R                             +-+
+--R                            \|x
+--R  /
+--R         2  +-+4+-+4+-+3
+--R     256a b\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 1353
+t0:=x^(3/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           +-+
+--R                         x\|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 1353
+r0:=-7/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(5/4)*_
+   sqrt(2))+7/128*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*_
+   b^(5/4)*sqrt(2))-7/256*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(11/4)*b^(5/4)*sqrt(2))+7/256*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(11/4)*b^(5/4)*sqrt(2))-_
+   1/6*sqrt(x)/(b*(a+b*x^2)^3)+1/48*sqrt(x)/(a*b*(a+b*x^2)^2)+_
+   7/192*sqrt(x)/(a^2*b*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R           3 6        2 4      2   2      3      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 63a b x  + 63a b x  + 21a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               3 6        2 4      2   2      3
+--R         (- 21b x  - 63a b x  - 63a b x  - 21a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  + \|a
+--R       (42b x  + 126a b x  + 126a b x  + 42a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  - \|a
+--R       (42b x  + 126a b x  + 126a b x  + 42a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R           2 4          2      2  +-+4+-+3 4+-+ +-+
+--R       (28b x  + 72a b x  - 84a )\|2 \|a   \|b \|x
+--R  /
+--R          2 4 6        3 3 4        4 2 2       5   +-+4+-+3 4+-+
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a b)\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                           +-----------------+
+--R               2 4 6        3 3 4        4 2 2        5    |         1
+--R         (1344a b x  + 4032a b x  + 4032a b x  + 1344a b)  |- ---------------
+--R                                                          4|             11 5
+--R                                                          \|  4294967296a  b
+--R      *
+--R                            +-----------------+
+--R              +-+       3   |         1
+--R         log(\|x  + 256a b  |- ---------------)
+--R                           4|             11 5
+--R                           \|  4294967296a  b
+--R     + 
+--R                                                             +-----------------+
+--R                 2 4 6        3 3 4        4 2 2        5    |         1
+--R         (- 1344a b x  - 4032a b x  - 4032a b x  - 1344a b)  |- ---------------
+--R                                                            4|             11 5
+--R                                                            \|  4294967296a  b
+--R      *
+--R                            +-----------------+
+--R              +-+       3   |         1
+--R         log(\|x  - 256a b  |- ---------------)
+--R                           4|             11 5
+--R                           \|  4294967296a  b
+--R     + 
+--R                                                             +-----------------+
+--R                 2 4 6        3 3 4        4 2 2        5    |         1
+--R         (- 2688a b x  - 8064a b x  - 8064a b x  - 2688a b)  |- ---------------
+--R                                                            4|             11 5
+--R                                                            \|  4294967296a  b
+--R      *
+--R                      +-----------------+
+--R                  3   |         1
+--R              256a b  |- ---------------
+--R                     4|             11 5
+--R                     \|  4294967296a  b
+--R         atan(--------------------------)
+--R                          +-+
+--R                         \|x
+--R     + 
+--R          2 4          2      2  +-+
+--R       (7b x  + 18a b x  - 21a )\|x
+--R  /
+--R         2 4 6       3 3 4       4 2 2       5
+--R     192a b x  + 576a b x  + 576a b x  + 192a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 225
+
+--S 226 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 7log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      +-----------------+
+--R              2  +-+  |         1        4+-+3 4+-+
+--R         1792a b\|2   |- --------------- \|a   \|b
+--R                     4|             11 5
+--R                     \|  4294967296a  b
+--R      *
+--R                            +-----------------+
+--R              +-+       3   |         1
+--R         log(\|x  + 256a b  |- ---------------)
+--R                           4|             11 5
+--R                           \|  4294967296a  b
+--R     + 
+--R       -
+--R                         +-----------------+
+--R                 2  +-+  |         1        4+-+3 4+-+
+--R            1792a b\|2   |- --------------- \|a   \|b
+--R                        4|             11 5
+--R                        \|  4294967296a  b
+--R         *
+--R                               +-----------------+
+--R                 +-+       3   |         1
+--R            log(\|x  - 256a b  |- ---------------)
+--R                              4|             11 5
+--R                              \|  4294967296a  b
+--R     + 
+--R                                                         +-+4+-+ +-+   4+-+
+--R               +-+4+-+4+-+ +-+     +-+    +-+           \|2 \|b \|x  + \|a
+--R       7log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 14atan(-------------------)
+--R                                                                4+-+
+--R                                                                \|a
+--R     + 
+--R                 +-+4+-+ +-+   4+-+
+--R                \|2 \|b \|x  - \|a
+--R       - 14atan(-------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R                                                              +-----------------+
+--R                                                          3   |         1
+--R                                                      256a b  |- ---------------
+--R                    +-----------------+                      4|             11 5
+--R            2  +-+  |         1        4+-+3 4+-+            \|  4294967296a  b
+--R     - 3584a b\|2   |- --------------- \|a   \|b atan(--------------------------)
+--R                   4|             11 5                            +-+
+--R                   \|  4294967296a  b                            \|x
+--R  /
+--R         2  +-+4+-+3 4+-+
+--R     256a b\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 227
+
+)clear all
+
+--S 228 of 1353
+t0:=sqrt(x)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           +-+
+--R                          \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 228
+
+--S 229 of 1353
+r0:=1/6*x^(3/2)/(a*(a+b*x^2)^3)+3/16*x^(3/2)/(a^2*(a+b*x^2)^2)+_
+   15/64*x^(3/2)/(a^3*(a+b*x^2))-15/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(13/4)*b^(3/4)*sqrt(2))+15/128*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(13/4)*b^(3/4)*sqrt(2))+15/256*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(13/4)*b^(3/4)*sqrt(2))-_
+   15/256*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(13/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3 6         2 4       2   2      3
+--R         (- 45b x  - 135a b x  - 135a b x  - 45a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             3 6         2 4       2   2      3
+--R         (45b x  + 135a b x  + 135a b x  + 45a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  + \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  - \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R            2 5           3       2   +-+4+-+4+-+3 +-+
+--R       (180b x  + 504a b x  + 452a x)\|2 \|a \|b  \|x
+--R  /
+--R          3 3 6        4 2 4        5   2       6  +-+4+-+4+-+3
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a )\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                          +-----------------+
+--R               3 3 6        4 2 4        5   2        6   |         1
+--R         (2880a b x  + 8640a b x  + 8640a b x  + 2880a )  |- ---------------
+--R                                                         4|             13 3
+--R                                                         \|  4294967296a  b
+--R      *
+--R                                   +-----------------+3
+--R              +-+            10 2  |         1
+--R         log(\|x  + 16777216a  b   |- --------------- )
+--R                                  4|             13 3
+--R                                  \|  4294967296a  b
+--R     + 
+--R                                                            +-----------------+
+--R                 3 3 6        4 2 4        5   2        6   |         1
+--R         (- 2880a b x  - 8640a b x  - 8640a b x  - 2880a )  |- ---------------
+--R                                                           4|             13 3
+--R                                                           \|  4294967296a  b
+--R      *
+--R                                   +-----------------+3
+--R              +-+            10 2  |         1
+--R         log(\|x  - 16777216a  b   |- --------------- )
+--R                                  4|             13 3
+--R                                  \|  4294967296a  b
+--R     + 
+--R                                                            +-----------------+
+--R               3 3 6         4 2 4         5   2        6   |         1
+--R         (5760a b x  + 17280a b x  + 17280a b x  + 5760a )  |- ---------------
+--R                                                           4|             13 3
+--R                                                           \|  4294967296a  b
+--R      *
+--R                             +-----------------+3
+--R                       10 2  |         1
+--R              16777216a  b   |- ---------------
+--R                            4|             13 3
+--R                            \|  4294967296a  b
+--R         atan(----------------------------------)
+--R                              +-+
+--R                             \|x
+--R     + 
+--R           2 5           3       2   +-+
+--R       (45b x  + 126a b x  + 113a x)\|x
+--R  /
+--R         3 3 6       4 2 4       5   2       6
+--R     192a b x  + 576a b x  + 576a b x  + 192a
+--R                                         Type: Union(Expression(Integer),...)
+--E 230
+
+--S 231 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R       15log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                     +-----------------+
+--R              3 +-+  |         1        4+-+4+-+3
+--R         3840a \|2   |- --------------- \|a \|b
+--R                    4|             13 3
+--R                    \|  4294967296a  b
+--R      *
+--R                                   +-----------------+3
+--R              +-+            10 2  |         1
+--R         log(\|x  + 16777216a  b   |- --------------- )
+--R                                  4|             13 3
+--R                                  \|  4294967296a  b
+--R     + 
+--R       -
+--R                        +-----------------+
+--R                 3 +-+  |         1        4+-+4+-+3
+--R            3840a \|2   |- --------------- \|a \|b
+--R                       4|             13 3
+--R                       \|  4294967296a  b
+--R         *
+--R                                      +-----------------+3
+--R                 +-+            10 2  |         1
+--R            log(\|x  - 16777216a  b   |- --------------- )
+--R                                     4|             13 3
+--R                                     \|  4294967296a  b
+--R     + 
+--R                                                            +-+4+-+ +-+   4+-+
+--R                  +-+4+-+4+-+ +-+     +-+    +-+           \|2 \|b \|x  + \|a
+--R       - 15log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 30atan(-------------------)
+--R                                                                   4+-+
+--R                                                                   \|a
+--R     + 
+--R                 +-+4+-+ +-+   4+-+
+--R                \|2 \|b \|x  - \|a
+--R       - 30atan(-------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R                     +-----------------+
+--R              3 +-+  |         1        4+-+4+-+3
+--R         7680a \|2   |- --------------- \|a \|b
+--R                    4|             13 3
+--R                    \|  4294967296a  b
+--R      *
+--R                             +-----------------+3
+--R                       10 2  |         1
+--R              16777216a  b   |- ---------------
+--R                            4|             13 3
+--R                            \|  4294967296a  b
+--R         atan(----------------------------------)
+--R                              +-+
+--R                             \|x
+--R  /
+--R         3 +-+4+-+4+-+3
+--R     256a \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 232
+
+)clear all
+
+--S 233 of 1353
+t0:=1/((a^2+2*a*b*x^2+b^2*x^4)^2*sqrt(x))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R          4 8       3 6     2 2 4     3   2    4  +-+
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 1353
+r0:=-77/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(15/4)*b^(1/4)*_
+   sqrt(2))+77/128*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(15/4)*_
+   b^(1/4)*sqrt(2))-77/256*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(15/4)*b^(1/4)*sqrt(2))+77/256*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(15/4)*b^(1/4)*sqrt(2))+_
+   1/6*sqrt(x)/(a*(a+b*x^2)^3)+11/48*sqrt(x)/(a^2*(a+b*x^2)^2)+_
+   77/192*sqrt(x)/(a^3*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R              3 6         2 4       2   2       3
+--R         (231b x  + 693a b x  + 693a b x  + 231a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                3 6         2 4       2   2       3
+--R         (- 231b x  - 693a b x  - 693a b x  - 231a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R            3 6          2 4        2   2       3      \|2 \|b \|x  + \|a
+--R       (462b x  + 1386a b x  + 1386a b x  + 462a )atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R            3 6          2 4        2   2       3      \|2 \|b \|x  - \|a
+--R       (462b x  + 1386a b x  + 1386a b x  + 462a )atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R            2 4           2       2  +-+4+-+3 4+-+ +-+
+--R       (308b x  + 792a b x  + 612a )\|2 \|a   \|b \|x
+--R  /
+--R          3 3 6        4 2 4        5   2       6  +-+4+-+3 4+-+
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a )\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                              +----------------+
+--R                3 3 6         4 2 4         5   2         6   |         1
+--R         (14784a b x  + 44352a b x  + 44352a b x  + 14784a )  |- --------------
+--R                                                             4|             15
+--R                                                             \|  4294967296a  b
+--R      *
+--R                           +----------------+
+--R              +-+       4  |         1
+--R         log(\|x  + 256a   |- --------------)
+--R                          4|             15
+--R                          \|  4294967296a  b
+--R     + 
+--R                  3 3 6         4 2 4         5   2         6
+--R         (- 14784a b x  - 44352a b x  - 44352a b x  - 14784a )
+--R      *
+--R          +----------------+                  +----------------+
+--R          |         1            +-+       4  |         1
+--R          |- -------------- log(\|x  - 256a   |- --------------)
+--R         4|             15                   4|             15
+--R         \|  4294967296a  b                  \|  4294967296a  b
+--R     + 
+--R                  3 3 6         4 2 4         5   2         6
+--R         (- 29568a b x  - 88704a b x  - 88704a b x  - 29568a )
+--R      *
+--R                                        +----------------+
+--R                                     4  |         1
+--R                                 256a   |- --------------
+--R          +----------------+           4|             15
+--R          |         1                  \|  4294967296a  b
+--R          |- -------------- atan(------------------------)
+--R         4|             15                  +-+
+--R         \|  4294967296a  b                \|x
+--R     + 
+--R           2 4           2       2  +-+
+--R       (77b x  + 198a b x  + 153a )\|x
+--R  /
+--R         3 3 6       4 2 4       5   2       6
+--R     192a b x  + 576a b x  + 576a b x  + 192a
+--R                                         Type: Union(Expression(Integer),...)
+--E 235
+
+--S 236 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 77log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      +----------------+
+--R               3 +-+  |         1       4+-+3 4+-+
+--R         19712a \|2   |- -------------- \|a   \|b
+--R                     4|             15
+--R                     \|  4294967296a  b
+--R      *
+--R                           +----------------+
+--R              +-+       4  |         1
+--R         log(\|x  + 256a   |- --------------)
+--R                          4|             15
+--R                          \|  4294967296a  b
+--R     + 
+--R       -
+--R                         +----------------+
+--R                  3 +-+  |         1       4+-+3 4+-+
+--R            19712a \|2   |- -------------- \|a   \|b
+--R                        4|             15
+--R                        \|  4294967296a  b
+--R         *
+--R                              +----------------+
+--R                 +-+       4  |         1
+--R            log(\|x  - 256a   |- --------------)
+--R                             4|             15
+--R                             \|  4294967296a  b
+--R     + 
+--R                                                           +-+4+-+ +-+   4+-+
+--R                +-+4+-+4+-+ +-+     +-+    +-+            \|2 \|b \|x  + \|a
+--R       77log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 154atan(-------------------)
+--R                                                                  4+-+
+--R                                                                  \|a
+--R     + 
+--R                  +-+4+-+ +-+   4+-+
+--R                 \|2 \|b \|x  - \|a
+--R       - 154atan(-------------------)
+--R                         4+-+
+--R                         \|a
+--R     + 
+--R                                                              +----------------+
+--R                                                           4  |         1
+--R                                                       256a   |- --------------
+--R                      +----------------+                     4|             15
+--R               3 +-+  |         1       4+-+3 4+-+           \|  4294967296a  b
+--R       - 39424a \|2   |- -------------- \|a   \|b atan(------------------------)
+--R                     4|             15                            +-+
+--R                     \|  4294967296a  b                          \|x
+--R  /
+--R         3 +-+4+-+3 4+-+
+--R     256a \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 1353
+t0:=1/(x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R          4 9       3 7     2 2 5     3   3    4   +-+
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 1353
+r0:=195/128*b^(1/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(17/4)*_
+   sqrt(2))-195/128*b^(1/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(17/4)*sqrt(2))-195/256*b^(1/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*_
+   b^(1/4)*sqrt(2)*sqrt(x))/(a^(17/4)*sqrt(2))+195/256*b^(1/4)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(17/4)*_
+   sqrt(2))+(-195/64)/(a^4*sqrt(x))+1/6/(a*(a+b*x^2)^3*sqrt(x))+_
+   13/48/(a^2*(a+b*x^2)^2*sqrt(x))+39/64/(a^3*(a+b*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R              3 6          2 4        2   2       3 4+-+ +-+
+--R         (585b x  + 1755a b x  + 1755a b x  + 585a )\|b \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                3 6          2 4        2   2       3 4+-+ +-+
+--R         (- 585b x  - 1755a b x  - 1755a b x  - 585a )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+ +-+
+--R         (- 1170b x  - 3510a b x  - 3510a b x  - 1170a )\|b \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+ +-+
+--R         (- 1170b x  - 3510a b x  - 3510a b x  - 1170a )\|b \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               3 6          2 4        2   2        3  +-+4+-+
+--R       (- 2340b x  - 6552a b x  - 5876a b x  - 1536a )\|2 \|a
+--R  /
+--R          4 3 6        5 2 4        6   2       7  +-+4+-+ +-+
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a )\|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                        +---------------+
+--R                4 3 6       5 2 4       6   2       7   |   1445900625b   +-+
+--R         (- 192a b x  - 576a b x  - 576a b x  - 192a )  |- ------------- \|x
+--R                                                       4|             17
+--R                                                       \|  4294967296a
+--R      *
+--R                                         +---------------+3
+--R                      +-+            13  |   1445900625b
+--R         log(7414875b\|x  + 16777216a    |- ------------- )
+--R                                        4|             17
+--R                                        \|  4294967296a
+--R     + 
+--R                                                      +---------------+
+--R              4 3 6       5 2 4       6   2       7   |   1445900625b   +-+
+--R         (192a b x  + 576a b x  + 576a b x  + 192a )  |- ------------- \|x
+--R                                                     4|             17
+--R                                                     \|  4294967296a
+--R      *
+--R                                         +---------------+3
+--R                      +-+            13  |   1445900625b
+--R         log(7414875b\|x  - 16777216a    |- ------------- )
+--R                                        4|             17
+--R                                        \|  4294967296a
+--R     + 
+--R                                                          +---------------+
+--R                4 3 6        5 2 4        6   2       7   |   1445900625b   +-+
+--R         (- 384a b x  - 1152a b x  - 1152a b x  - 384a )  |- ------------- \|x
+--R                                                         4|             17
+--R                                                         \|  4294967296a
+--R      *
+--R                           +---------------+3
+--R                       13  |   1445900625b
+--R              16777216a    |- -------------
+--R                          4|             17
+--R                          \|  4294967296a
+--R         atan(------------------------------)
+--R                                +-+
+--R                       7414875b\|x
+--R     + 
+--R             3 6          2 4        2   2       3
+--R       - 585b x  - 1638a b x  - 1469a b x  - 384a
+--R  /
+--R          4 3 6       5 2 4       6   2       7  +-+
+--R     (192a b x  + 576a b x  + 576a b x  + 192a )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 240
+
+--S 241 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 195\|b log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R       -
+--R                       +---------------+
+--R                4 +-+  |   1445900625b  4+-+
+--R            256a \|2   |- ------------- \|a
+--R                      4|             17
+--R                      \|  4294967296a
+--R         *
+--R                                            +---------------+3
+--R                         +-+            13  |   1445900625b
+--R            log(7414875b\|x  + 16777216a    |- ------------- )
+--R                                           4|             17
+--R                                           \|  4294967296a
+--R     + 
+--R                    +---------------+
+--R             4 +-+  |   1445900625b  4+-+
+--R         256a \|2   |- ------------- \|a
+--R                   4|             17
+--R                   \|  4294967296a
+--R      *
+--R                                         +---------------+3
+--R                      +-+            13  |   1445900625b
+--R         log(7414875b\|x  - 16777216a    |- ------------- )
+--R                                        4|             17
+--R                                        \|  4294967296a
+--R     + 
+--R          4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       195\|b log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    +-+4+-+ +-+   4+-+                 +-+4+-+ +-+   4+-+
+--R          4+-+     \|2 \|b \|x  + \|a        4+-+     \|2 \|b \|x  - \|a
+--R       390\|b atan(-------------------) + 390\|b atan(-------------------)
+--R                           4+-+                               4+-+
+--R                           \|a                                \|a
+--R     + 
+--R                                                           +---------------+3
+--R                                                       13  |   1445900625b
+--R                                              16777216a    |- -------------
+--R                    +---------------+                     4|             17
+--R             4 +-+  |   1445900625b  4+-+                 \|  4294967296a
+--R       - 512a \|2   |- ------------- \|a atan(------------------------------)
+--R                   4|             17                            +-+
+--R                   \|  4294967296a                     7414875b\|x
+--R  /
+--R         4 +-+4+-+
+--R     256a \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 242
+
+)clear all
+
+--S 243 of 1353
+t0:=1/(x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R          4 10       3 8     2 2 6     3   4    4 2  +-+
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 243
+
+--S 244 of 1353
+r0:=(-385/192)/(a^4*x^(3/2))+1/6/(a*x^(3/2)*(a+b*x^2)^3)+5/16/(a^2*x^(3/2)*_
+   (a+b*x^2)^2)+55/64/(a^3*x^(3/2)*(a+b*x^2))+385/128*b^(3/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(19/4)*sqrt(2))-_
+   385/128*b^(3/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(19/4)*_
+   sqrt(2))+385/256*b^(3/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(19/4)*sqrt(2))-385/256*b^(3/4)*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(19/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 3 7          2 5        2   3        3  4+-+3 +-+
+--R         (- 1155b x  - 3465a b x  - 3465a b x  - 1155a x)\|b  \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               3 7          2 5        2   3        3  4+-+3 +-+
+--R         (1155b x  + 3465a b x  + 3465a b x  + 1155a x)\|b  \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 3 7          2 5        2   3        3  4+-+3 +-+
+--R         (- 2310b x  - 6930a b x  - 6930a b x  - 2310a x)\|b  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 3 7          2 5        2   3        3  4+-+3 +-+
+--R         (- 2310b x  - 6930a b x  - 6930a b x  - 2310a x)\|b  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               3 6          2 4        2   2       3  +-+4+-+3
+--R       (- 1540b x  - 3960a b x  - 3060a b x  - 512a )\|2 \|a
+--R  /
+--R          4 3 7        5 2 5        6   3       7   +-+4+-+3 +-+
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a x)\|2 \|a  \|x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                         +---------------+
+--R                                                         |              3
+--R                4 3 7       5 2 5       6   3       7    |  21970650625b   +-+
+--R         (- 192a b x  - 576a b x  - 576a b x  - 192a x)  |- ------------- \|x
+--R                                                        4|             19
+--R                                                        \|  4294967296a
+--R      *
+--R                               +---------------+
+--R                               |              3
+--R                  +-+       5  |  21970650625b
+--R         log(385b\|x  + 256a   |- -------------)
+--R                              4|             19
+--R                              \|  4294967296a
+--R     + 
+--R                                                       +---------------+
+--R                                                       |              3
+--R              4 3 7       5 2 5       6   3       7    |  21970650625b   +-+
+--R         (192a b x  + 576a b x  + 576a b x  + 192a x)  |- ------------- \|x
+--R                                                      4|             19
+--R                                                      \|  4294967296a
+--R      *
+--R                               +---------------+
+--R                               |              3
+--R                  +-+       5  |  21970650625b
+--R         log(385b\|x  - 256a   |- -------------)
+--R                              4|             19
+--R                              \|  4294967296a
+--R     + 
+--R                                                         +---------------+
+--R                                                         |              3
+--R              4 3 7        5 2 5        6   3       7    |  21970650625b   +-+
+--R         (384a b x  + 1152a b x  + 1152a b x  + 384a x)  |- ------------- \|x
+--R                                                        4|             19
+--R                                                        \|  4294967296a
+--R      *
+--R                     +---------------+
+--R                     |              3
+--R                  5  |  21970650625b
+--R              256a   |- -------------
+--R                    4|             19
+--R                    \|  4294967296a
+--R         atan(-----------------------)
+--R                           +-+
+--R                      385b\|x
+--R     + 
+--R             3 6         2 4       2   2       3
+--R       - 385b x  - 990a b x  - 765a b x  - 128a
+--R  /
+--R          4 3 7       5 2 5       6   3       7   +-+
+--R     (192a b x  + 576a b x  + 576a b x  + 192a x)\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 245
+
+--S 246 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       385\|b  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    +---------------+                           +---------------+
+--R                    |              3                            |              3
+--R             4 +-+  |  21970650625b  4+-+3         +-+       5  |  21970650625b
+--R       - 256a \|2   |- ------------- \|a  log(385b\|x  + 256a   |- -------------)
+--R                   4|             19                           4|             19
+--R                   \|  4294967296a                             \|  4294967296a
+--R     + 
+--R                  +---------------+                           +---------------+
+--R                  |              3                            |              3
+--R           4 +-+  |  21970650625b  4+-+3         +-+       5  |  21970650625b
+--R       256a \|2   |- ------------- \|a  log(385b\|x  - 256a   |- -------------)
+--R                 4|             19                           4|             19
+--R                 \|  4294967296a                             \|  4294967296a
+--R     + 
+--R            4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 385\|b  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                     +-+4+-+ +-+   4+-+                  +-+4+-+ +-+   4+-+
+--R          4+-+3     \|2 \|b \|x  + \|a        4+-+3     \|2 \|b \|x  - \|a
+--R       770\|b  atan(-------------------) + 770\|b  atan(-------------------)
+--R                            4+-+                                4+-+
+--R                            \|a                                 \|a
+--R     + 
+--R                                                    +---------------+
+--R                                                    |              3
+--R                                                 5  |  21970650625b
+--R                  +---------------+          256a   |- -------------
+--R                  |              3                 4|             19
+--R           4 +-+  |  21970650625b  4+-+3           \|  4294967296a
+--R       512a \|2   |- ------------- \|a  atan(-----------------------)
+--R                 4|             19                        +-+
+--R                 \|  4294967296a                     385b\|x
+--R  /
+--R         4 +-+4+-+3
+--R     256a \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 247
+
+)clear all
+
+--S 248 of 1353
+t0:=1/(x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R          4 11       3 9     2 2 7     3   5    4 3  +-+
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 1353
+r0:=(-663/320)/(a^4*x^(5/2))+1/6/(a*x^(5/2)*(a+b*x^2)^3)+17/48/(a^2*x^(5/2)*_
+   (a+b*x^2)^2)+221/192/(a^3*x^(5/2)*(a+b*x^2))-663/128*b^(5/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(21/4)*sqrt(2))+_
+   663/128*b^(5/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(21/4)*_
+   sqrt(2))+663/256*b^(5/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(21/4)*sqrt(2))-663/256*b^(5/4)*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(21/4)*sqrt(2))+_
+   663/64*b/(a^5*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                 4 8           3 6         2 2 4        3   2 4+-+ +-+
+--R         (- 9945b x  - 29835a b x  - 29835a b x  - 9945a b x )\|b \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8           3 6         2 2 4        3   2 4+-+ +-+
+--R         (9945b x  + 29835a b x  + 29835a b x  + 9945a b x )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                4 8           3 6         2 2 4         3   2 4+-+ +-+
+--R         (19890b x  + 59670a b x  + 59670a b x  + 19890a b x )\|b \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                4 8           3 6         2 2 4         3   2 4+-+ +-+
+--R         (19890b x  + 59670a b x  + 59670a b x  + 19890a b x )\|b \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8            3 6         2 2 4         3   2        4  +-+4+-+
+--R       (39780b x  + 111384a b x  + 99892a b x  + 26112a b x  - 1536a )\|2 \|a
+--R  /
+--R           5 3 8         6 2 6         7   4        8 2  +-+4+-+ +-+
+--R     (3840a b x  + 11520a b x  + 11520a b x  + 3840a x )\|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 249
+
+--S 250 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                          +----------------+
+--R                                                          |               5
+--R              5 3 8        6 2 6        7   4       8 2   |  193220905761b   +-+
+--R         (960a b x  + 2880a b x  + 2880a b x  + 960a x )  |- -------------- \|x
+--R                                                         4|              21
+--R                                                         \|   4294967296a
+--R      *
+--R                                            +----------------+3
+--R                                            |               5
+--R                       4 +-+            16  |  193220905761b
+--R         log(291434247b \|x  + 16777216a    |- -------------- )
+--R                                           4|              21
+--R                                           \|   4294967296a
+--R     + 
+--R                                                            +----------------+
+--R                                                            |               5
+--R                5 3 8        6 2 6        7   4       8 2   |  193220905761b
+--R         (- 960a b x  - 2880a b x  - 2880a b x  - 960a x )  |- --------------
+--R                                                           4|              21
+--R                                                           \|   4294967296a
+--R      *
+--R                                                +----------------+3
+--R                                                |               5
+--R          +-+              4 +-+            16  |  193220905761b
+--R         \|x log(291434247b \|x  - 16777216a    |- -------------- )
+--R                                               4|              21
+--R                                               \|   4294967296a
+--R     + 
+--R                                                            +----------------+
+--R                                                            |               5
+--R               5 3 8        6 2 6        7   4        8 2   |  193220905761b
+--R         (1920a b x  + 5760a b x  + 5760a b x  + 1920a x )  |- --------------
+--R                                                           4|              21
+--R                                                           \|   4294967296a
+--R      *
+--R                               +----------------+3
+--R                               |               5
+--R                           16  |  193220905761b
+--R                  16777216a    |- --------------
+--R                              4|              21
+--R          +-+                 \|   4294967296a
+--R         \|x atan(-------------------------------)
+--R                                    4 +-+
+--R                          291434247b \|x
+--R     + 
+--R            4 8           3 6         2 2 4        3   2       4
+--R       9945b x  + 27846a b x  + 24973a b x  + 6528a b x  - 384a
+--R  /
+--R          5 3 8        6 2 6        7   4       8 2  +-+
+--R     (960a b x  + 2880a b x  + 2880a b x  + 960a x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 250
+
+--S 251 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       663b\|b log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    +----------------+
+--R                    |               5
+--R             5 +-+  |  193220905761b  4+-+
+--R         256a \|2   |- -------------- \|a
+--R                   4|              21
+--R                   \|   4294967296a
+--R      *
+--R                                            +----------------+3
+--R                                            |               5
+--R                       4 +-+            16  |  193220905761b
+--R         log(291434247b \|x  + 16777216a    |- -------------- )
+--R                                           4|              21
+--R                                           \|   4294967296a
+--R     + 
+--R       -
+--R                       +----------------+
+--R                       |               5
+--R                5 +-+  |  193220905761b  4+-+
+--R            256a \|2   |- -------------- \|a
+--R                      4|              21
+--R                      \|   4294967296a
+--R         *
+--R                                               +----------------+3
+--R                                               |               5
+--R                          4 +-+            16  |  193220905761b
+--R            log(291434247b \|x  - 16777216a    |- -------------- )
+--R                                              4|              21
+--R                                              \|   4294967296a
+--R     + 
+--R             4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 663b\|b log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                        +-+4+-+ +-+   4+-+                   +-+4+-+ +-+   4+-+
+--R              4+-+     \|2 \|b \|x  + \|a          4+-+     \|2 \|b \|x  - \|a
+--R       - 1326b\|b atan(-------------------) - 1326b\|b atan(-------------------)
+--R                               4+-+                                 4+-+
+--R                               \|a                                  \|a
+--R     + 
+--R                                                          +----------------+3
+--R                                                          |               5
+--R                                                      16  |  193220905761b
+--R                  +----------------+         16777216a    |- --------------
+--R                  |               5                      4|              21
+--R           5 +-+  |  193220905761b  4+-+                 \|   4294967296a
+--R       512a \|2   |- -------------- \|a atan(-------------------------------)
+--R                 4|              21                            4 +-+
+--R                 \|   4294967296a                    291434247b \|x
+--R  /
+--R         5 +-+4+-+
+--R     256a \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 1353
+t0:=x^(27/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      13 +-+
+--R                                     x  \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 1353
+r0:=13923/4096*x^(5/2)/b^6-1/10*x^(25/2)/(b*(a+b*x^2)^5)-5/32*x^(21/2)/_
+   (b^2*(a+b*x^2)^4)-35/128*x^(17/2)/(b^3*(a+b*x^2)^3)-595/1024*x^(13/2)/_
+   (b^4*(a+b*x^2)^2)-7735/4096*x^(9/2)/(b^5*(a+b*x^2))-69615/8192*a^(5/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(29/4)*sqrt(2))+_
+   69615/8192*a^(5/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(29/4)*_
+   sqrt(2))-69615/16384*a^(5/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(29/4)*sqrt(2))+69615/16384*a^(5/4)*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(29/4)*sqrt(2))-_
+   69615/4096*a*sqrt(x)/b^7
+--R 
+--R
+--R   (2)
+--R                    5 10           2 4 8           3 3 6           4 2 4
+--R           348075a b x   + 1740375a b x  + 3480750a b x  + 3480750a b x
+--R         + 
+--R                   5   2          6
+--R           1740375a b x  + 348075a
+--R      *
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      5 10           2 4 8           3 3 6           4 2 4
+--R           - 348075a b x   - 1740375a b x  - 3480750a b x  - 3480750a b x
+--R         + 
+--R                     5   2          6
+--R           - 1740375a b x  - 348075a
+--R      *
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    5 10           2 4 8           3 3 6           4 2 4
+--R           696150a b x   + 3480750a b x  + 6961500a b x  + 6961500a b x
+--R         + 
+--R                   5   2          6
+--R           3480750a b x  + 696150a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  + \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                    5 10           2 4 8           3 3 6           4 2 4
+--R           696150a b x   + 3480750a b x  + 6961500a b x  + 6961500a b x
+--R         + 
+--R                   5   2          6
+--R           3480750a b x  + 696150a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  - \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                 6 12            5 10           2 4 8            3 3 6
+--R           32768b x   - 819200a b x   - 5270300a b x  - 11804800a b x
+--R         + 
+--R                      4 2 4           5   2           6
+--R           - 12685400a b x  - 6683040a b x  - 1392300a
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|b \|x
+--R  /
+--R               12 10            11 8          2 10 6          3 9 4
+--R         81920b  x   + 409600a b  x  + 819200a b  x  + 819200a b x
+--R       + 
+--R                4 8 2         5 7
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+
+--R       \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 12 10            11 8          2 10 6          3 9 4
+--R           20480b  x   + 102400a b  x  + 204800a b  x  + 204800a b x
+--R         + 
+--R                  4 8 2         5 7
+--R           102400a b x  + 20480a b
+--R      *
+--R          +------------------------+
+--R          |                       5
+--R          |  23486121858315650625a
+--R          |- ----------------------
+--R         4|                     29
+--R         \|   72057594037927936b
+--R      *
+--R                                   +------------------------+
+--R                                   |                       5
+--R                    +-+         7  |  23486121858315650625a
+--R         log(69615a\|x  + 16384b   |- ----------------------)
+--R                                  4|                     29
+--R                                  \|   72057594037927936b
+--R     + 
+--R                   12 10            11 8          2 10 6          3 9 4
+--R           - 20480b  x   - 102400a b  x  - 204800a b  x  - 204800a b x
+--R         + 
+--R                    4 8 2         5 7
+--R           - 102400a b x  - 20480a b
+--R      *
+--R          +------------------------+
+--R          |                       5
+--R          |  23486121858315650625a
+--R          |- ----------------------
+--R         4|                     29
+--R         \|   72057594037927936b
+--R      *
+--R                                   +------------------------+
+--R                                   |                       5
+--R                    +-+         7  |  23486121858315650625a
+--R         log(69615a\|x  - 16384b   |- ----------------------)
+--R                                  4|                     29
+--R                                  \|   72057594037927936b
+--R     + 
+--R                   12 10            11 8          2 10 6          3 9 4
+--R           - 40960b  x   - 204800a b  x  - 409600a b  x  - 409600a b x
+--R         + 
+--R                    4 8 2         5 7
+--R           - 204800a b x  - 40960a b
+--R      *
+--R                                                  +------------------------+
+--R                                                  |                       5
+--R                                               7  |  23486121858315650625a
+--R          +------------------------+     16384b   |- ----------------------
+--R          |                       5              4|                     29
+--R          |  23486121858315650625a               \|   72057594037927936b
+--R          |- ---------------------- atan(----------------------------------)
+--R         4|                     29                          +-+
+--R         \|   72057594037927936b                     69615a\|x
+--R     + 
+--R                6 12            5 10           2 4 8           3 3 6
+--R           8192b x   - 204800a b x   - 1317575a b x  - 2951200a b x
+--R         + 
+--R                     4 2 4           5   2          6
+--R           - 3171350a b x  - 1670760a b x  - 348075a
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R             12 10            11 8          2 10 6          3 9 4          4 8 2
+--R       20480b  x   + 102400a b  x  + 204800a b  x  + 204800a b x  + 102400a b x
+--R     + 
+--R             5 7
+--R       20480a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 255
+
+--S 256 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 69615a\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      +------------------------+
+--R                      |                       5
+--R               7 +-+  |  23486121858315650625a  4+-+
+--R         16384b \|2   |- ---------------------- \|b
+--R                     4|                     29
+--R                     \|   72057594037927936b
+--R      *
+--R                                   +------------------------+
+--R                                   |                       5
+--R                    +-+         7  |  23486121858315650625a
+--R         log(69615a\|x  + 16384b   |- ----------------------)
+--R                                  4|                     29
+--R                                  \|   72057594037927936b
+--R     + 
+--R       -
+--R                         +------------------------+
+--R                         |                       5
+--R                  7 +-+  |  23486121858315650625a  4+-+
+--R            16384b \|2   |- ---------------------- \|b
+--R                        4|                     29
+--R                        \|   72057594037927936b
+--R         *
+--R                                      +------------------------+
+--R                                      |                       5
+--R                       +-+         7  |  23486121858315650625a
+--R            log(69615a\|x  - 16384b   |- ----------------------)
+--R                                     4|                     29
+--R                                     \|   72057594037927936b
+--R     + 
+--R             4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       69615a\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                4+-+     \|2 \|b \|x  + \|a
+--R       - 139230a\|a atan(-------------------)
+--R                                 4+-+
+--R                                 \|a
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                4+-+     \|2 \|b \|x  - \|a
+--R       - 139230a\|a atan(-------------------)
+--R                                 4+-+
+--R                                 \|a
+--R     + 
+--R       -
+--R                         +------------------------+
+--R                         |                       5
+--R                  7 +-+  |  23486121858315650625a  4+-+
+--R            32768b \|2   |- ---------------------- \|b
+--R                        4|                     29
+--R                        \|   72057594037927936b
+--R         *
+--R                          +------------------------+
+--R                          |                       5
+--R                       7  |  23486121858315650625a
+--R                 16384b   |- ----------------------
+--R                         4|                     29
+--R                         \|   72057594037927936b
+--R            atan(----------------------------------)
+--R                                    +-+
+--R                             69615a\|x
+--R  /
+--R           7 +-+4+-+
+--R     16384b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 257
+
+)clear all
+
+--S 258 of 1353
+t0:=x^(25/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      12 +-+
+--R                                     x  \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 258
+
+--S 259 of 1353
+r0:=33649/12288*x^(3/2)/b^6-1/10*x^(23/2)/(b*(a+b*x^2)^5)-23/160*x^(19/2)/_
+   (b^2*(a+b*x^2)^4)-437/1920*x^(15/2)/(b^3*(a+b*x^2)^3)-437/1024*_
+   x^(11/2)/(b^4*(a+b*x^2)^2)-4807/4096*x^(7/2)/(b^5*(a+b*x^2))+_
+   33649/8192*a^(3/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (b^(27/4)*sqrt(2))-33649/8192*a^(3/4)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(27/4)*sqrt(2))-33649/16384*a^(3/4)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(27/4)*_
+   sqrt(2))+33649/16384*a^(3/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(27/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  5 10             4 8           2 3 6           3 2 4
+--R           504735b x   + 2523675a b x  + 5047350a b x  + 5047350a b x
+--R         + 
+--R                   4   2          5
+--R           2523675a b x  + 504735a
+--R      *
+--R         4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    5 10             4 8           2 3 6           3 2 4
+--R           - 504735b x   - 2523675a b x  - 5047350a b x  - 5047350a b x
+--R         + 
+--R                     4   2          5
+--R           - 2523675a b x  - 504735a
+--R      *
+--R         4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                     5 10             4 8            2 3 6            3 2 4
+--R           - 1009470b x   - 5047350a b x  - 10094700a b x  - 10094700a b x
+--R         + 
+--R                     4   2           5
+--R           - 5047350a b x  - 1009470a
+--R      *
+--R                    +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  + \|a
+--R         \|a  atan(-------------------)
+--R                           4+-+
+--R                           \|a
+--R     + 
+--R                     5 10             4 8            2 3 6            3 2 4
+--R           - 1009470b x   - 5047350a b x  - 10094700a b x  - 10094700a b x
+--R         + 
+--R                     4   2           5
+--R           - 5047350a b x  - 1009470a
+--R      *
+--R                    +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  - \|a
+--R         \|a  atan(-------------------)
+--R                           4+-+
+--R                           \|a
+--R     + 
+--R                  5 11             4 9           2 3 7           3 2 5
+--R           163840b x   + 1749380a b x  + 4628704a b x  + 5471240a b x
+--R         + 
+--R                   4   3          5
+--R           3076480a b x  + 672980a x
+--R      *
+--R          +-+4+-+3 +-+
+--R         \|2 \|b  \|x
+--R  /
+--R                11 10             10 8           2 9 6           3 8 4
+--R         245760b  x   + 1228800a b  x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 4 7 2          5 6
+--R         1228800a b x  + 245760a b
+--R    *
+--R        +-+4+-+3
+--R       \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   11 10            10 8          2 9 6          3 8 4
+--R           - 61440b  x   - 307200a b  x  - 614400a b x  - 614400a b x
+--R         + 
+--R                    4 7 2         5 6
+--R           - 307200a b x  - 61440a b
+--R      *
+--R          +-----------------------+
+--R          |                      3
+--R          |  1282001840191550401a
+--R          |- ---------------------
+--R         4|                     27
+--R         \|   72057594037927936b
+--R      *
+--R                                                    +-----------------------+3
+--R                                                    |                      3
+--R                          2 +-+                 20  |  1282001840191550401a
+--R       log(38099255258449a \|x  + 4398046511104b    |- --------------------- )
+--R                                                   4|                     27
+--R                                                   \|   72057594037927936b
+--R     + 
+--R                 11 10            10 8          2 9 6          3 8 4
+--R           61440b  x   + 307200a b  x  + 614400a b x  + 614400a b x
+--R         + 
+--R                  4 7 2         5 6
+--R           307200a b x  + 61440a b
+--R      *
+--R          +-----------------------+
+--R          |                      3
+--R          |  1282001840191550401a
+--R          |- ---------------------
+--R         4|                     27
+--R         \|   72057594037927936b
+--R      *
+--R                                                    +-----------------------+3
+--R                                                    |                      3
+--R                          2 +-+                 20  |  1282001840191550401a
+--R       log(38099255258449a \|x  - 4398046511104b    |- --------------------- )
+--R                                                   4|                     27
+--R                                                   \|   72057594037927936b
+--R     + 
+--R                    11 10            10 8           2 9 6           3 8 4
+--R           - 122880b  x   - 614400a b  x  - 1228800a b x  - 1228800a b x
+--R         + 
+--R                    4 7 2          5 6
+--R           - 614400a b x  - 122880a b
+--R      *
+--R          +-----------------------+
+--R          |                      3
+--R          |  1282001840191550401a
+--R          |- ---------------------
+--R         4|                     27
+--R         \|   72057594037927936b
+--R      *
+--R                                +-----------------------+3
+--R                                |                      3
+--R                            20  |  1282001840191550401a
+--R              4398046511104b    |- ---------------------
+--R                               4|                     27
+--R                               \|   72057594037927936b
+--R         atan(-------------------------------------------)
+--R                                         2 +-+
+--R                          38099255258449a \|x
+--R     + 
+--R                 5 11            4 9           2 3 7           3 2 5
+--R           40960b x   + 437345a b x  + 1157176a b x  + 1367810a b x
+--R         + 
+--R                  4   3          5
+--R           769120a b x  + 168245a x
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R             11 10            10 8          2 9 6          3 8 4          4 7 2
+--R       61440b  x   + 307200a b  x  + 614400a b x  + 614400a b x  + 307200a b x
+--R     + 
+--R             5 6
+--R       61440a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 260
+
+--S 261 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 33649\|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R       -
+--R                         +-----------------------+
+--R                         |                      3
+--R                  6 +-+  |  1282001840191550401a  4+-+3
+--R            16384b \|2   |- --------------------- \|b
+--R                        4|                     27
+--R                        \|   72057594037927936b
+--R         *
+--R            log
+--R                                2 +-+
+--R                 38099255258449a \|x
+--R               + 
+--R                                   +-----------------------+3
+--R                                   |                      3
+--R                               20  |  1282001840191550401a
+--R                 4398046511104b    |- ---------------------
+--R                                  4|                     27
+--R                                  \|   72057594037927936b
+--R     + 
+--R                      +-----------------------+
+--R                      |                      3
+--R               6 +-+  |  1282001840191550401a  4+-+3
+--R         16384b \|2   |- --------------------- \|b
+--R                     4|                     27
+--R                     \|   72057594037927936b
+--R      *
+--R                                                    +-----------------------+3
+--R                                                    |                      3
+--R                          2 +-+                 20  |  1282001840191550401a
+--R       log(38099255258449a \|x  - 4398046511104b    |- --------------------- )
+--R                                                   4|                     27
+--R                                                   \|   72057594037927936b
+--R     + 
+--R            4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       33649\|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                       +-+4+-+ +-+   4+-+                    +-+4+-+ +-+   4+-+
+--R            4+-+3     \|2 \|b \|x  + \|a          4+-+3     \|2 \|b \|x  - \|a
+--R       67298\|a  atan(-------------------) + 67298\|a  atan(-------------------)
+--R                              4+-+                                  4+-+
+--R                              \|a                                   \|a
+--R     + 
+--R       -
+--R                         +-----------------------+
+--R                         |                      3
+--R                  6 +-+  |  1282001840191550401a  4+-+3
+--R            32768b \|2   |- --------------------- \|b
+--R                        4|                     27
+--R                        \|   72057594037927936b
+--R         *
+--R                                   +-----------------------+3
+--R                                   |                      3
+--R                               20  |  1282001840191550401a
+--R                 4398046511104b    |- ---------------------
+--R                                  4|                     27
+--R                                  \|   72057594037927936b
+--R            atan(-------------------------------------------)
+--R                                            2 +-+
+--R                             38099255258449a \|x
+--R  /
+--R           6 +-+4+-+3
+--R     16384b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 262
+
+)clear all
+
+--S 263 of 1353
+t0:=x^(23/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      11 +-+
+--R                                     x  \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 1353
+r0:=-1/10*x^(21/2)/(b*(a+b*x^2)^5)-21/160*x^(17/2)/(b^2*(a+b*x^2)^4)-_
+   119/640*x^(13/2)/(b^3*(a+b*x^2)^3)-1547/5120*x^(9/2)/(b^4*(a+b*x^2)^2)-_
+   13923/20480*x^(5/2)/(b^5*(a+b*x^2))+13923/8192*a^(1/4)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(25/4)*sqrt(2))-13923/8192*a^(1/4)*_
+   atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(25/4)*sqrt(2))+_
+   13923/16384*a^(1/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(25/4)*sqrt(2))-13923/16384*a^(1/4)*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(25/4)*sqrt(2))+_
+   13923/4096*sqrt(x)/b^6
+--R 
+--R
+--R   (2)
+--R                   5 10            4 8          2 3 6          3 2 4
+--R           - 69615b x   - 348075a b x  - 696150a b x  - 696150a b x
+--R         + 
+--R                    4   2         5
+--R           - 348075a b x  - 69615a
+--R      *
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           69615b x   + 348075a b x  + 696150a b x  + 696150a b x
+--R         + 
+--R                  4   2         5
+--R           348075a b x  + 69615a
+--R      *
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    5 10            4 8           2 3 6           3 2 4
+--R           - 139230b x   - 696150a b x  - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    4   2          5
+--R           - 696150a b x  - 139230a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  + \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                    5 10            4 8           2 3 6           3 2 4
+--R           - 139230b x   - 696150a b x  - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    4   2          5
+--R           - 696150a b x  - 139230a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  - \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                  5 10             4 8           2 3 6           3 2 4
+--R           163840b x   + 1054060a b x  + 2360960a b x  + 2537080a b x
+--R         + 
+--R                   4   2          5
+--R           1336608a b x  + 278460a
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|b \|x
+--R  /
+--R               11 10            10 8          2 9 6          3 8 4
+--R         81920b  x   + 409600a b  x  + 819200a b x  + 819200a b x
+--R       + 
+--R                4 7 2         5 6
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+
+--R       \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   11 10            10 8          2 9 6          3 8 4
+--R           - 20480b  x   - 102400a b  x  - 204800a b x  - 204800a b x
+--R         + 
+--R                    4 7 2         5 6
+--R           - 102400a b x  - 20480a b
+--R      *
+--R          +----------------------+
+--R          |   37577794973305041a
+--R          |- --------------------
+--R         4|                    25
+--R         \|  72057594037927936b
+--R      *
+--R                                  +----------------------+
+--R                   +-+         6  |   37577794973305041a
+--R         log(13923\|x  + 16384b   |- --------------------)
+--R                                 4|                    25
+--R                                 \|  72057594037927936b
+--R     + 
+--R                 11 10            10 8          2 9 6          3 8 4
+--R           20480b  x   + 102400a b  x  + 204800a b x  + 204800a b x
+--R         + 
+--R                  4 7 2         5 6
+--R           102400a b x  + 20480a b
+--R      *
+--R          +----------------------+
+--R          |   37577794973305041a
+--R          |- --------------------
+--R         4|                    25
+--R         \|  72057594037927936b
+--R      *
+--R                                  +----------------------+
+--R                   +-+         6  |   37577794973305041a
+--R         log(13923\|x  - 16384b   |- --------------------)
+--R                                 4|                    25
+--R                                 \|  72057594037927936b
+--R     + 
+--R                 11 10            10 8          2 9 6          3 8 4
+--R           40960b  x   + 204800a b  x  + 409600a b x  + 409600a b x
+--R         + 
+--R                  4 7 2         5 6
+--R           204800a b x  + 40960a b
+--R      *
+--R                                                +----------------------+
+--R                                             6  |   37577794973305041a
+--R                                       16384b   |- --------------------
+--R          +----------------------+             4|                    25
+--R          |   37577794973305041a               \|  72057594037927936b
+--R          |- -------------------- atan(--------------------------------)
+--R         4|                    25                        +-+
+--R         \|  72057594037927936b                    13923\|x
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           40960b x   + 263515a b x  + 590240a b x  + 634270a b x
+--R         + 
+--R                  4   2         5
+--R           334152a b x  + 69615a
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R             11 10            10 8          2 9 6          3 8 4          4 7 2
+--R       20480b  x   + 102400a b  x  + 204800a b x  + 204800a b x  + 102400a b x
+--R     + 
+--R             5 6
+--R       20480a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 265
+
+--S 266 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       13923\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R       -
+--R                         +----------------------+
+--R                  6 +-+  |   37577794973305041a  4+-+
+--R            16384b \|2   |- -------------------- \|b
+--R                        4|                    25
+--R                        \|  72057594037927936b
+--R         *
+--R                                     +----------------------+
+--R                      +-+         6  |   37577794973305041a
+--R            log(13923\|x  + 16384b   |- --------------------)
+--R                                    4|                    25
+--R                                    \|  72057594037927936b
+--R     + 
+--R                      +----------------------+
+--R               6 +-+  |   37577794973305041a  4+-+
+--R         16384b \|2   |- -------------------- \|b
+--R                     4|                    25
+--R                     \|  72057594037927936b
+--R      *
+--R                                  +----------------------+
+--R                   +-+         6  |   37577794973305041a
+--R         log(13923\|x  - 16384b   |- --------------------)
+--R                                 4|                    25
+--R                                 \|  72057594037927936b
+--R     + 
+--R              4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 13923\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      +-+4+-+ +-+   4+-+                   +-+4+-+ +-+   4+-+
+--R            4+-+     \|2 \|b \|x  + \|a          4+-+     \|2 \|b \|x  - \|a
+--R       27846\|a atan(-------------------) + 27846\|a atan(-------------------)
+--R                             4+-+                                 4+-+
+--R                             \|a                                  \|a
+--R     + 
+--R                      +----------------------+
+--R               6 +-+  |   37577794973305041a  4+-+
+--R         32768b \|2   |- -------------------- \|b
+--R                     4|                    25
+--R                     \|  72057594037927936b
+--R      *
+--R                       +----------------------+
+--R                    6  |   37577794973305041a
+--R              16384b   |- --------------------
+--R                      4|                    25
+--R                      \|  72057594037927936b
+--R         atan(--------------------------------)
+--R                                +-+
+--R                          13923\|x
+--R  /
+--R           6 +-+4+-+
+--R     16384b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 1353
+t0:=x^(21/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      10 +-+
+--R                                     x  \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 1353
+r0:=-1/10*x^(19/2)/(b*(a+b*x^2)^5)-19/160*x^(15/2)/(b^2*(a+b*x^2)^4)-_
+   19/128*x^(11/2)/(b^3*(a+b*x^2)^3)-209/1024*x^(7/2)/(b^4*(a+b*x^2)^2)-_
+   1463/4096*x^(3/2)/(b^5*(a+b*x^2))-4389/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(1/4)*b^(23/4)*sqrt(2))+4389/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(1/4)*b^(23/4)*sqrt(2))+4389/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*_
+   b^(23/4)*sqrt(2))-4389/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(1/4)*b^(23/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   5 10            4 8          2 3 6          3 2 4
+--R           - 21945b x   - 109725a b x  - 219450a b x  - 219450a b x
+--R         + 
+--R                    4   2         5
+--R           - 109725a b x  - 21945a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           21945b x   + 109725a b x  + 219450a b x  + 219450a b x
+--R         + 
+--R                  4   2         5
+--R           109725a b x  + 21945a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   2         5
+--R           219450a b x  + 43890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   2         5
+--R           219450a b x  + 43890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  4 9            3 7          2 2 5          3   3         4
+--R         (- 76060b x  - 201248a b x  - 237880a b x  - 133760a b x  - 29260a x)
+--R      *
+--R          +-+4+-+4+-+3 +-+
+--R         \|2 \|a \|b  \|x
+--R  /
+--R               10 10            9 8          2 8 6          3 7 4          4 6 2
+--R         81920b  x   + 409600a b x  + 819200a b x  + 819200a b x  + 409600a b x
+--R       + 
+--R               5 5
+--R         81920a b
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    10 10               9 8             2 8 6             3 7 4
+--R           89886720b  x   + 449433600a b x  + 898867200a b x  + 898867200a b x
+--R         + 
+--R                     4 6 2            5 5
+--R           449433600a b x  + 89886720a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                      23
+--R         \|  72057594037927936a b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                   17  |             1
+--R         log(\|x  + 4398046511104a b    |- ---------------------- )
+--R                                       4|                      23
+--R                                       \|  72057594037927936a b
+--R     + 
+--R                      10 10               9 8             2 8 6
+--R           - 89886720b  x   - 449433600a b x  - 898867200a b x
+--R         + 
+--R                       3 7 4             4 6 2            5 5
+--R           - 898867200a b x  - 449433600a b x  - 89886720a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                      23
+--R         \|  72057594037927936a b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                   17  |             1
+--R         log(\|x  - 4398046511104a b    |- ---------------------- )
+--R                                       4|                      23
+--R                                       \|  72057594037927936a b
+--R     + 
+--R                     10 10               9 8              2 8 6
+--R           179773440b  x   + 898867200a b x  + 1797734400a b x
+--R         + 
+--R                      3 7 4             4 6 2             5 5
+--R           1797734400a b x  + 898867200a b x  + 179773440a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                      23
+--R         \|  72057594037927936a b
+--R      *
+--R                                  +------------------------+3
+--R                              17  |             1
+--R              4398046511104a b    |- ----------------------
+--R                                 4|                      23
+--R                                 \|  72057594037927936a b
+--R         atan(----------------------------------------------)
+--R                                    +-+
+--R                                   \|x
+--R     + 
+--R                4 9           3 7         2 2 5         3   3        4   +-+
+--R       (- 19015b x  - 50312a b x  - 59470a b x  - 33440a b x  - 7315a x)\|x
+--R  /
+--R             10 10            9 8          2 8 6          3 7 4          4 6 2
+--R       20480b  x   + 102400a b x  + 204800a b x  + 204800a b x  + 102400a b x
+--R     + 
+--R             5 5
+--R       20480a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 270
+
+--S 271 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R       4389log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +------------------------+
+--R                  5 +-+  |             1           4+-+4+-+3
+--R         71909376b \|2   |- ---------------------- \|a \|b
+--R                        4|                      23
+--R                        \|  72057594037927936a b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                   17  |             1
+--R         log(\|x  + 4398046511104a b    |- ---------------------- )
+--R                                       4|                      23
+--R                                       \|  72057594037927936a b
+--R     + 
+--R       -
+--R                            +------------------------+
+--R                     5 +-+  |             1           4+-+4+-+3
+--R            71909376b \|2   |- ---------------------- \|a \|b
+--R                           4|                      23
+--R                           \|  72057594037927936a b
+--R         *
+--R                                           +------------------------+3
+--R                 +-+                   17  |             1
+--R            log(\|x  - 4398046511104a b    |- ---------------------- )
+--R                                          4|                      23
+--R                                          \|  72057594037927936a b
+--R     + 
+--R                    +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 4389log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   +-+4+-+ +-+   4+-+              +-+4+-+ +-+   4+-+
+--R                  \|2 \|b \|x  + \|a              \|2 \|b \|x  - \|a
+--R       - 8778atan(-------------------) - 8778atan(-------------------)
+--R                          4+-+                            4+-+
+--R                          \|a                             \|a
+--R     + 
+--R                          +------------------------+
+--R                   5 +-+  |             1           4+-+4+-+3
+--R         143818752b \|2   |- ---------------------- \|a \|b
+--R                         4|                      23
+--R                         \|  72057594037927936a b
+--R      *
+--R                                  +------------------------+3
+--R                              17  |             1
+--R              4398046511104a b    |- ----------------------
+--R                                 4|                      23
+--R                                 \|  72057594037927936a b
+--R         atan(----------------------------------------------)
+--R                                    +-+
+--R                                   \|x
+--R  /
+--R           5 +-+4+-+4+-+3
+--R     16384b \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 272
+
+)clear all
+
+--S 273 of 1353
+t0:=x^(19/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      9 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 273
+
+--S 274 of 1353
+r0:=-1/10*x^(17/2)/(b*(a+b*x^2)^5)-17/160*x^(13/2)/(b^2*(a+b*x^2)^4)-_
+   221/1920*x^(9/2)/(b^3*(a+b*x^2)^3)-663/5120*x^(5/2)/(b^4*(a+b*x^2)^2)-_
+   663/8192*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(21/4)*_
+   sqrt(2))+663/8192*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*_
+   b^(21/4)*sqrt(2))-663/16384*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(3/4)*b^(21/4)*sqrt(2))+663/16384*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(3/4)*b^(21/4)*sqrt(2))-_
+   663/4096*sqrt(x)/(b^5*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           9945b x   + 49725a b x  + 99450a b x  + 99450a b x  + 49725a b x
+--R         + 
+--R                5
+--R           9945a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 9945b x   - 49725a b x  - 99450a b x  - 99450a b x  - 49725a b x
+--R         + 
+--R                  5
+--R           - 9945a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                   4 8            3 6          2 2 4          3   2         4
+--R         (- 150580b x  - 337280a b x  - 362440a b x  - 190944a b x  - 39780a )
+--R      *
+--R          +-+4+-+3 4+-+ +-+
+--R         \|2 \|a   \|b \|x
+--R  /
+--R                10 10             9 8           2 8 6           3 7 4
+--R         245760b  x   + 1228800a b x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 4 6 2          5 5
+--R         1228800a b x  + 245760a b
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    10 10               9 8             2 8 6             3 7 4
+--R           40734720b  x   + 203673600a b x  + 407347200a b x  + 407347200a b x
+--R         + 
+--R                     4 6 2            5 5
+--R           203673600a b x  + 40734720a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    3 21
+--R         \|  72057594037927936a b
+--R      *
+--R                               +------------------------+
+--R              +-+           5  |             1
+--R         log(\|x  + 16384a b   |- ----------------------)
+--R                              4|                    3 21
+--R                              \|  72057594037927936a b
+--R     + 
+--R                      10 10               9 8             2 8 6
+--R           - 40734720b  x   - 203673600a b x  - 407347200a b x
+--R         + 
+--R                       3 7 4             4 6 2            5 5
+--R           - 407347200a b x  - 203673600a b x  - 40734720a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    3 21
+--R         \|  72057594037927936a b
+--R      *
+--R                               +------------------------+
+--R              +-+           5  |             1
+--R         log(\|x  - 16384a b   |- ----------------------)
+--R                              4|                    3 21
+--R                              \|  72057594037927936a b
+--R     + 
+--R                      10 10               9 8             2 8 6
+--R           - 81469440b  x   - 407347200a b x  - 814694400a b x
+--R         + 
+--R                       3 7 4             4 6 2            5 5
+--R           - 814694400a b x  - 407347200a b x  - 81469440a b
+--R      *
+--R                                                    +------------------------+
+--R                                                 5  |             1
+--R                                         16384a b   |- ----------------------
+--R          +------------------------+               4|                    3 21
+--R          |             1                          \|  72057594037927936a b
+--R          |- ---------------------- atan(------------------------------------)
+--R         4|                    3 21                       +-+
+--R         \|  72057594037927936a b                        \|x
+--R     + 
+--R                4 8           3 6         2 2 4         3   2        4  +-+
+--R       (- 37645b x  - 84320a b x  - 90610a b x  - 47736a b x  - 9945a )\|x
+--R  /
+--R             10 10            9 8          2 8 6          3 7 4          4 6 2
+--R       61440b  x   + 307200a b x  + 614400a b x  + 614400a b x  + 307200a b x
+--R     + 
+--R             5 5
+--R       61440a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 275
+
+--S 276 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 663log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +------------------------+
+--R                  5 +-+  |             1           4+-+3 4+-+
+--R         10862592b \|2   |- ---------------------- \|a   \|b
+--R                        4|                    3 21
+--R                        \|  72057594037927936a b
+--R      *
+--R                               +------------------------+
+--R              +-+           5  |             1
+--R         log(\|x  + 16384a b   |- ----------------------)
+--R                              4|                    3 21
+--R                              \|  72057594037927936a b
+--R     + 
+--R       -
+--R                            +------------------------+
+--R                     5 +-+  |             1           4+-+3 4+-+
+--R            10862592b \|2   |- ---------------------- \|a   \|b
+--R                           4|                    3 21
+--R                           \|  72057594037927936a b
+--R         *
+--R                                  +------------------------+
+--R                 +-+           5  |             1
+--R            log(\|x  - 16384a b   |- ----------------------)
+--R                                 4|                    3 21
+--R                                 \|  72057594037927936a b
+--R     + 
+--R                                                             +-+4+-+ +-+   4+-+
+--R                 +-+4+-+4+-+ +-+     +-+    +-+             \|2 \|b \|x  + \|a
+--R       663log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 1326atan(-------------------)
+--R                                                                    4+-+
+--R                                                                    \|a
+--R     + 
+--R                   +-+4+-+ +-+   4+-+
+--R                  \|2 \|b \|x  - \|a
+--R       - 1326atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R       -
+--R                            +------------------------+
+--R                     5 +-+  |             1           4+-+3 4+-+
+--R            21725184b \|2   |- ---------------------- \|a   \|b
+--R                           4|                    3 21
+--R                           \|  72057594037927936a b
+--R         *
+--R                            +------------------------+
+--R                         5  |             1
+--R                 16384a b   |- ----------------------
+--R                           4|                    3 21
+--R                           \|  72057594037927936a b
+--R            atan(------------------------------------)
+--R                                  +-+
+--R                                 \|x
+--R  /
+--R           5 +-+4+-+3 4+-+
+--R     16384b \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 277
+
+)clear all
+
+--S 278 of 1353
+t0:=x^(17/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      8 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 1353
+r0:=-1/10*x^(15/2)/(b*(a+b*x^2)^5)-3/32*x^(11/2)/(b^2*(a+b*x^2)^4)-_
+   11/128*x^(7/2)/(b^3*(a+b*x^2)^3)-77/1024*x^(3/2)/(b^4*(a+b*x^2)^2)+_
+   231/4096*x^(3/2)/(a*b^4*(a+b*x^2))-231/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(5/4)*b^(19/4)*sqrt(2))+231/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*b^(19/4)*sqrt(2))+231/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*_
+   b^(19/4)*sqrt(2))-231/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(5/4)*b^(19/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1155b x   - 5775a b x  - 11550a b x  - 11550a b x  - 5775a b x
+--R         + 
+--R                  5
+--R           - 1155a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1155b x   + 5775a b x  + 11550a b x  + 11550a b x  + 5775a b x
+--R         + 
+--R                5
+--R           1155a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 9           3 7         2 2 5        3   3        4   +-+4+-+
+--R         (4620b x  - 10592a b x  - 12520a b x  - 7040a b x  - 1540a x)\|2 \|a
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R                 9 10          2 8 8          3 7 6          4 6 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                5 5 2         6 4
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     9 10            2 8 8            3 7 6            4 6 4
+--R           4730880a b x   + 23654400a b x  + 47308800a b x  + 47308800a b x
+--R         + 
+--R                    5 5 2           6 4
+--R           23654400a b x  + 4730880a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    5 19
+--R         \|  72057594037927936a b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 4 14  |             1
+--R         log(\|x  + 4398046511104a b    |- ---------------------- )
+--R                                       4|                    5 19
+--R                                       \|  72057594037927936a b
+--R     + 
+--R                       9 10            2 8 8            3 7 6            4 6 4
+--R           - 4730880a b x   - 23654400a b x  - 47308800a b x  - 47308800a b x
+--R         + 
+--R                      5 5 2           6 4
+--R           - 23654400a b x  - 4730880a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    5 19
+--R         \|  72057594037927936a b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 4 14  |             1
+--R         log(\|x  - 4398046511104a b    |- ---------------------- )
+--R                                       4|                    5 19
+--R                                       \|  72057594037927936a b
+--R     + 
+--R                     9 10            2 8 8            3 7 6            4 6 4
+--R           9461760a b x   + 47308800a b x  + 94617600a b x  + 94617600a b x
+--R         + 
+--R                    5 5 2           6 4
+--R           47308800a b x  + 9461760a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    5 19
+--R         \|  72057594037927936a b
+--R      *
+--R                                  +------------------------+3
+--R                            4 14  |             1
+--R              4398046511104a b    |- ----------------------
+--R                                 4|                    5 19
+--R                                 \|  72057594037927936a b
+--R         atan(----------------------------------------------)
+--R                                    +-+
+--R                                   \|x
+--R     + 
+--R             4 9          3 7        2 2 5        3   3       4   +-+
+--R       (1155b x  - 2648a b x  - 3130a b x  - 1760a b x  - 385a x)\|x
+--R  /
+--R               9 10          2 8 8          3 7 6          4 6 4          5 5 2
+--R       20480a b x   + 102400a b x  + 204800a b x  + 204800a b x  + 102400a b x
+--R     + 
+--R             6 4
+--R       20480a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 280
+
+--S 281 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+4+-+4+-+ +-+     +-+    +-+
+--R       231log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                          +------------------------+
+--R                   4 +-+  |             1           4+-+4+-+3
+--R         3784704a b \|2   |- ---------------------- \|a \|b
+--R                         4|                    5 19
+--R                         \|  72057594037927936a b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 4 14  |             1
+--R         log(\|x  + 4398046511104a b    |- ---------------------- )
+--R                                       4|                    5 19
+--R                                       \|  72057594037927936a b
+--R     + 
+--R       -
+--R                             +------------------------+
+--R                      4 +-+  |             1           4+-+4+-+3
+--R            3784704a b \|2   |- ---------------------- \|a \|b
+--R                            4|                    5 19
+--R                            \|  72057594037927936a b
+--R         *
+--R                                           +------------------------+3
+--R                 +-+                 4 14  |             1
+--R            log(\|x  - 4398046511104a b    |- ---------------------- )
+--R                                          4|                    5 19
+--R                                          \|  72057594037927936a b
+--R     + 
+--R                   +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 231log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  +-+4+-+ +-+   4+-+             +-+4+-+ +-+   4+-+
+--R                 \|2 \|b \|x  + \|a             \|2 \|b \|x  - \|a
+--R       - 462atan(-------------------) - 462atan(-------------------)
+--R                         4+-+                           4+-+
+--R                         \|a                            \|a
+--R     + 
+--R                          +------------------------+
+--R                   4 +-+  |             1           4+-+4+-+3
+--R         7569408a b \|2   |- ---------------------- \|a \|b
+--R                         4|                    5 19
+--R                         \|  72057594037927936a b
+--R      *
+--R                                  +------------------------+3
+--R                            4 14  |             1
+--R              4398046511104a b    |- ----------------------
+--R                                 4|                    5 19
+--R                                 \|  72057594037927936a b
+--R         atan(----------------------------------------------)
+--R                                    +-+
+--R                                   \|x
+--R  /
+--R             4 +-+4+-+4+-+3
+--R     16384a b \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 1353
+t0:=x^(15/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      7 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 1353
+r0:=-1/10*x^(13/2)/(b*(a+b*x^2)^5)-13/160*x^(9/2)/(b^2*(a+b*x^2)^4)-_
+   39/640*x^(5/2)/(b^3*(a+b*x^2)^3)-117/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(7/4)*b^(17/4)*sqrt(2))+117/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(17/4)*sqrt(2))-117/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(7/4)*_
+   b^(17/4)*sqrt(2))+117/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(7/4)*b^(17/4)*sqrt(2))-39/1024*sqrt(x)/(b^4*_
+   (a+b*x^2)^2)+39/4096*sqrt(x)/(a*b^4*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (585b x   + 2925a b x  + 5850a b x  + 5850a b x  + 2925a b x  + 585a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 585b x   - 2925a b x  - 5850a b x  - 5850a b x  - 2925a b x
+--R           + 
+--R                   5
+--R             - 585a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1170b x   + 5850a b x  + 11700a b x  + 11700a b x  + 5850a b x
+--R         + 
+--R                5
+--R           1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1170b x   + 5850a b x  + 11700a b x  + 11700a b x  + 5850a b x
+--R         + 
+--R                5
+--R           1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8           3 6         2 2 4         3   2        4  +-+4+-+3
+--R         (780b x  - 19840a b x  - 21320a b x  - 11232a b x  - 2340a )\|2 \|a
+--R      *
+--R         4+-+ +-+
+--R         \|b \|x
+--R  /
+--R                 9 10          2 8 8          3 7 6          4 6 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                5 5 2         6 4
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     9 10            2 8 8            3 7 6            4 6 4
+--R           2396160a b x   + 11980800a b x  + 23961600a b x  + 23961600a b x
+--R         + 
+--R                    5 5 2           6 4
+--R           11980800a b x  + 2396160a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    7 17
+--R         \|  72057594037927936a b
+--R      *
+--R                               +------------------------+
+--R              +-+         2 4  |             1
+--R         log(\|x  + 16384a b   |- ----------------------)
+--R                              4|                    7 17
+--R                              \|  72057594037927936a b
+--R     + 
+--R                       9 10            2 8 8            3 7 6            4 6 4
+--R           - 2396160a b x   - 11980800a b x  - 23961600a b x  - 23961600a b x
+--R         + 
+--R                      5 5 2           6 4
+--R           - 11980800a b x  - 2396160a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    7 17
+--R         \|  72057594037927936a b
+--R      *
+--R                               +------------------------+
+--R              +-+         2 4  |             1
+--R         log(\|x  - 16384a b   |- ----------------------)
+--R                              4|                    7 17
+--R                              \|  72057594037927936a b
+--R     + 
+--R                       9 10            2 8 8            3 7 6            4 6 4
+--R           - 4792320a b x   - 23961600a b x  - 47923200a b x  - 47923200a b x
+--R         + 
+--R                      5 5 2           6 4
+--R           - 23961600a b x  - 4792320a b
+--R      *
+--R                                                    +------------------------+
+--R                                               2 4  |             1
+--R                                         16384a b   |- ----------------------
+--R          +------------------------+               4|                    7 17
+--R          |             1                          \|  72057594037927936a b
+--R          |- ---------------------- atan(------------------------------------)
+--R         4|                    7 17                       +-+
+--R         \|  72057594037927936a b                        \|x
+--R     + 
+--R            4 8          3 6        2 2 4        3   2       4  +-+
+--R       (195b x  - 4960a b x  - 5330a b x  - 2808a b x  - 585a )\|x
+--R  /
+--R               9 10          2 8 8          3 7 6          4 6 4          5 5 2
+--R       20480a b x   + 102400a b x  + 204800a b x  + 204800a b x  + 102400a b x
+--R     + 
+--R             6 4
+--R       20480a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 285
+
+--S 286 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 117log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                          +------------------------+
+--R                   4 +-+  |             1           4+-+3 4+-+
+--R         1916928a b \|2   |- ---------------------- \|a   \|b
+--R                         4|                    7 17
+--R                         \|  72057594037927936a b
+--R      *
+--R                               +------------------------+
+--R              +-+         2 4  |             1
+--R         log(\|x  + 16384a b   |- ----------------------)
+--R                              4|                    7 17
+--R                              \|  72057594037927936a b
+--R     + 
+--R       -
+--R                             +------------------------+
+--R                      4 +-+  |             1           4+-+3 4+-+
+--R            1916928a b \|2   |- ---------------------- \|a   \|b
+--R                            4|                    7 17
+--R                            \|  72057594037927936a b
+--R         *
+--R                                  +------------------------+
+--R                 +-+         2 4  |             1
+--R            log(\|x  - 16384a b   |- ----------------------)
+--R                                 4|                    7 17
+--R                                 \|  72057594037927936a b
+--R     + 
+--R                                                            +-+4+-+ +-+   4+-+
+--R                 +-+4+-+4+-+ +-+     +-+    +-+            \|2 \|b \|x  + \|a
+--R       117log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 234atan(-------------------)
+--R                                                                   4+-+
+--R                                                                   \|a
+--R     + 
+--R                  +-+4+-+ +-+   4+-+
+--R                 \|2 \|b \|x  - \|a
+--R       - 234atan(-------------------)
+--R                         4+-+
+--R                         \|a
+--R     + 
+--R       -
+--R                             +------------------------+
+--R                      4 +-+  |             1           4+-+3 4+-+
+--R            3833856a b \|2   |- ---------------------- \|a   \|b
+--R                            4|                    7 17
+--R                            \|  72057594037927936a b
+--R         *
+--R                            +------------------------+
+--R                       2 4  |             1
+--R                 16384a b   |- ----------------------
+--R                           4|                    7 17
+--R                           \|  72057594037927936a b
+--R            atan(------------------------------------)
+--R                                  +-+
+--R                                 \|x
+--R  /
+--R             4 +-+4+-+3 4+-+
+--R     16384a b \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 287
+
+)clear all
+
+--S 288 of 1353
+t0:=x^(13/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      6 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 288
+
+--S 289 of 1353
+r0:=-1/10*x^(11/2)/(b*(a+b*x^2)^5)-11/160*x^(7/2)/(b^2*(a+b*x^2)^4)-_
+   77/1920*x^(3/2)/(b^3*(a+b*x^2)^3)+77/5120*x^(3/2)/(a*b^3*(a+b*x^2)^2)+_
+   77/4096*x^(3/2)/(a^2*b^3*(a+b*x^2))-77/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(9/4)*b^(15/4)*sqrt(2))+77/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*b^(15/4)*sqrt(2))+77/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(9/4)*_
+   b^(15/4)*sqrt(2))-77/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(9/4)*b^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1155b x   - 5775a b x  - 11550a b x  - 11550a b x  - 5775a b x
+--R         + 
+--R                  5
+--R           - 1155a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1155b x   + 5775a b x  + 11550a b x  + 11550a b x  + 5775a b x
+--R         + 
+--R                5
+--R           1155a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 9           3 7         2 2 5        3   3        4   +-+4+-+
+--R         (4620b x  + 22176a b x  - 12520a b x  - 7040a b x  - 1540a x)\|2 \|a
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R                2 8 10           3 7 8           4 6 6           5 5 4
+--R         245760a b x   + 1228800a b x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 6 4 2          7 3
+--R         1228800a b x  + 245760a b
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   2 8 10            3 7 8            4 6 6            5 5 4
+--R           4730880a b x   + 23654400a b x  + 47308800a b x  + 47308800a b x
+--R         + 
+--R                    6 4 2           7 3
+--R           23654400a b x  + 4730880a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    9 15
+--R         \|  72057594037927936a b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 7 11  |             1
+--R         log(\|x  + 4398046511104a b    |- ---------------------- )
+--R                                       4|                    9 15
+--R                                       \|  72057594037927936a b
+--R     + 
+--R                     2 8 10            3 7 8            4 6 6            5 5 4
+--R           - 4730880a b x   - 23654400a b x  - 47308800a b x  - 47308800a b x
+--R         + 
+--R                      6 4 2           7 3
+--R           - 23654400a b x  - 4730880a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    9 15
+--R         \|  72057594037927936a b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 7 11  |             1
+--R         log(\|x  - 4398046511104a b    |- ---------------------- )
+--R                                       4|                    9 15
+--R                                       \|  72057594037927936a b
+--R     + 
+--R                   2 8 10            3 7 8            4 6 6            5 5 4
+--R           9461760a b x   + 47308800a b x  + 94617600a b x  + 94617600a b x
+--R         + 
+--R                    6 4 2           7 3
+--R           47308800a b x  + 9461760a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    9 15
+--R         \|  72057594037927936a b
+--R      *
+--R                                  +------------------------+3
+--R                            7 11  |             1
+--R              4398046511104a b    |- ----------------------
+--R                                 4|                    9 15
+--R                                 \|  72057594037927936a b
+--R         atan(----------------------------------------------)
+--R                                    +-+
+--R                                   \|x
+--R     + 
+--R             4 9          3 7        2 2 5        3   3       4   +-+
+--R       (1155b x  + 5544a b x  - 3130a b x  - 1760a b x  - 385a x)\|x
+--R  /
+--R             2 8 10          3 7 8          4 6 6          5 5 4          6 4 2
+--R       61440a b x   + 307200a b x  + 614400a b x  + 614400a b x  + 307200a b x
+--R     + 
+--R             7 3
+--R       61440a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 290
+
+--S 291 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R       77log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                          +------------------------+
+--R                 2 3 +-+  |             1           4+-+4+-+3
+--R         1261568a b \|2   |- ---------------------- \|a \|b
+--R                         4|                    9 15
+--R                         \|  72057594037927936a b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 7 11  |             1
+--R         log(\|x  + 4398046511104a b    |- ---------------------- )
+--R                                       4|                    9 15
+--R                                       \|  72057594037927936a b
+--R     + 
+--R       -
+--R                             +------------------------+
+--R                    2 3 +-+  |             1           4+-+4+-+3
+--R            1261568a b \|2   |- ---------------------- \|a \|b
+--R                            4|                    9 15
+--R                            \|  72057594037927936a b
+--R         *
+--R                                           +------------------------+3
+--R                 +-+                 7 11  |             1
+--R            log(\|x  - 4398046511104a b    |- ---------------------- )
+--R                                          4|                    9 15
+--R                                          \|  72057594037927936a b
+--R     + 
+--R                                                             +-+4+-+ +-+   4+-+
+--R                  +-+4+-+4+-+ +-+     +-+    +-+            \|2 \|b \|x  + \|a
+--R       - 77log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 154atan(-------------------)
+--R                                                                    4+-+
+--R                                                                    \|a
+--R     + 
+--R                  +-+4+-+ +-+   4+-+
+--R                 \|2 \|b \|x  - \|a
+--R       - 154atan(-------------------)
+--R                         4+-+
+--R                         \|a
+--R     + 
+--R                          +------------------------+
+--R                 2 3 +-+  |             1           4+-+4+-+3
+--R         2523136a b \|2   |- ---------------------- \|a \|b
+--R                         4|                    9 15
+--R                         \|  72057594037927936a b
+--R      *
+--R                                  +------------------------+3
+--R                            7 11  |             1
+--R              4398046511104a b    |- ----------------------
+--R                                 4|                    9 15
+--R                                 \|  72057594037927936a b
+--R         atan(----------------------------------------------)
+--R                                    +-+
+--R                                   \|x
+--R  /
+--R           2 3 +-+4+-+4+-+3
+--R     16384a b \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 292
+
+)clear all
+
+--S 293 of 1353
+t0:=x^(11/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      5 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 1353
+r0:=-1/10*x^(9/2)/(b*(a+b*x^2)^5)-9/160*x^(5/2)/(b^2*(a+b*x^2)^4)-_
+   63/8192*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(13/4)*_
+   sqrt(2))+63/8192*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*_
+   b^(13/4)*sqrt(2))-63/16384*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(11/4)*b^(13/4)*sqrt(2))+63/16384*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(11/4)*b^(13/4)*sqrt(2))-_
+   3/128*sqrt(x)/(b^3*(a+b*x^2)^3)+3/1024*sqrt(x)/(a*b^3*(a+b*x^2)^2)+_
+   21/4096*sqrt(x)/(a^2*b^3*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x  + 315a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 315b x   - 1575a b x  - 3150a b x  - 3150a b x  - 1575a b x
+--R           + 
+--R                   5
+--R             - 315a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (630b x   + 3150a b x  + 6300a b x  + 6300a b x  + 3150a b x  + 630a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (630b x   + 3150a b x  + 6300a b x  + 6300a b x  + 3150a b x  + 630a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R          4 8          3 6         2 2 4        3   2        4  +-+4+-+3 4+-+ +-+
+--R     (420b x  + 1920a b x  - 11480a b x  - 6048a b x  - 1260a )\|2 \|a   \|b \|x
+--R  /
+--R               2 8 10          3 7 8          4 6 6          5 5 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                6 4 2         7 3
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 294
+
+--S 295 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   2 8 10           3 7 8            4 6 6            5 5 4
+--R           1290240a b x   + 6451200a b x  + 12902400a b x  + 12902400a b x
+--R         + 
+--R                   6 4 2           7 3
+--R           6451200a b x  + 1290240a b
+--R      *
+--R          +-------------------------+
+--R          |             1
+--R          |- -----------------------
+--R         4|                    11 13
+--R         \|  72057594037927936a  b
+--R      *
+--R                               +-------------------------+
+--R              +-+         3 3  |             1
+--R         log(\|x  + 16384a b   |- -----------------------)
+--R                              4|                    11 13
+--R                              \|  72057594037927936a  b
+--R     + 
+--R                     2 8 10           3 7 8            4 6 6            5 5 4
+--R           - 1290240a b x   - 6451200a b x  - 12902400a b x  - 12902400a b x
+--R         + 
+--R                     6 4 2           7 3
+--R           - 6451200a b x  - 1290240a b
+--R      *
+--R          +-------------------------+
+--R          |             1
+--R          |- -----------------------
+--R         4|                    11 13
+--R         \|  72057594037927936a  b
+--R      *
+--R                               +-------------------------+
+--R              +-+         3 3  |             1
+--R         log(\|x  - 16384a b   |- -----------------------)
+--R                              4|                    11 13
+--R                              \|  72057594037927936a  b
+--R     + 
+--R                     2 8 10            3 7 8            4 6 6            5 5 4
+--R           - 2580480a b x   - 12902400a b x  - 25804800a b x  - 25804800a b x
+--R         + 
+--R                      6 4 2           7 3
+--R           - 12902400a b x  - 2580480a b
+--R      *
+--R                                                   +-------------------------+
+--R                                              3 3  |             1
+--R                                        16384a b   |- -----------------------
+--R        +-------------------------+               4|                    11 13
+--R        |             1                           \|  72057594037927936a  b
+--R        |- ----------------------- atan(-------------------------------------)
+--R       4|                    11 13                        +-+
+--R       \|  72057594037927936a  b                         \|x
+--R     + 
+--R            4 8         3 6        2 2 4        3   2       4  +-+
+--R       (105b x  + 480a b x  - 2870a b x  - 1512a b x  - 315a )\|x
+--R  /
+--R             2 8 10          3 7 8          4 6 6          5 5 4          6 4 2
+--R       20480a b x   + 102400a b x  + 204800a b x  + 204800a b x  + 102400a b x
+--R     + 
+--R             7 3
+--R       20480a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 295
+
+--S 296 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 63log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                          +-------------------------+
+--R                 2 3 +-+  |             1            4+-+3 4+-+
+--R         1032192a b \|2   |- ----------------------- \|a   \|b
+--R                         4|                    11 13
+--R                         \|  72057594037927936a  b
+--R      *
+--R                               +-------------------------+
+--R              +-+         3 3  |             1
+--R         log(\|x  + 16384a b   |- -----------------------)
+--R                              4|                    11 13
+--R                              \|  72057594037927936a  b
+--R     + 
+--R       -
+--R                             +-------------------------+
+--R                    2 3 +-+  |             1            4+-+3 4+-+
+--R            1032192a b \|2   |- ----------------------- \|a   \|b
+--R                            4|                    11 13
+--R                            \|  72057594037927936a  b
+--R         *
+--R                                  +-------------------------+
+--R                 +-+         3 3  |             1
+--R            log(\|x  - 16384a b   |- -----------------------)
+--R                                 4|                    11 13
+--R                                 \|  72057594037927936a  b
+--R     + 
+--R                                                           +-+4+-+ +-+   4+-+
+--R                +-+4+-+4+-+ +-+     +-+    +-+            \|2 \|b \|x  + \|a
+--R       63log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 126atan(-------------------)
+--R                                                                  4+-+
+--R                                                                  \|a
+--R     + 
+--R                  +-+4+-+ +-+   4+-+
+--R                 \|2 \|b \|x  - \|a
+--R       - 126atan(-------------------)
+--R                         4+-+
+--R                         \|a
+--R     + 
+--R       -
+--R                             +-------------------------+
+--R                    2 3 +-+  |             1            4+-+3 4+-+
+--R            2064384a b \|2   |- ----------------------- \|a   \|b
+--R                            4|                    11 13
+--R                            \|  72057594037927936a  b
+--R         *
+--R                            +-------------------------+
+--R                       3 3  |             1
+--R                 16384a b   |- -----------------------
+--R                           4|                    11 13
+--R                           \|  72057594037927936a  b
+--R            atan(-------------------------------------)
+--R                                   +-+
+--R                                  \|x
+--R  /
+--R           2 3 +-+4+-+3 4+-+
+--R     16384a b \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 1353
+t0:=x^(9/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      4 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 1353
+r0:=-1/10*x^(7/2)/(b*(a+b*x^2)^5)-7/160*x^(3/2)/(b^2*(a+b*x^2)^4)+_
+   7/640*x^(3/2)/(a*b^2*(a+b*x^2)^3)+63/5120*x^(3/2)/(a^2*b^2*(a+_
+   b*x^2)^2)+63/4096*x^(3/2)/(a^3*b^2*(a+b*x^2))-63/8192*atan(1-_
+   b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*b^(11/4)*sqrt(2))+_
+   63/8192*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*b^(11/4)*_
+   sqrt(2))+63/16384*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(13/4)*b^(11/4)*sqrt(2))-63/16384*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(13/4)*b^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 315b x   - 1575a b x  - 3150a b x  - 3150a b x  - 1575a b x
+--R           + 
+--R                   5
+--R             - 315a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x  + 315a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (630b x   + 3150a b x  + 6300a b x  + 6300a b x  + 3150a b x  + 630a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (630b x   + 3150a b x  + 6300a b x  + 6300a b x  + 3150a b x  + 630a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 9          3 7         2 2 5        3   3       4   +-+4+-+
+--R         (1260b x  + 6048a b x  + 11480a b x  - 1920a b x  - 420a x)\|2 \|a
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R               3 7 10          4 6 8          5 5 6          6 4 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                7 3 2         8 2
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   3 7 10           4 6 8            5 5 6            6 4 4
+--R           1290240a b x   + 6451200a b x  + 12902400a b x  + 12902400a b x
+--R         + 
+--R                   7 3 2           8 2
+--R           6451200a b x  + 1290240a b
+--R      *
+--R          +-------------------------+
+--R          |             1
+--R          |- -----------------------
+--R         4|                    13 11
+--R         \|  72057594037927936a  b
+--R      *
+--R                                        +-------------------------+3
+--R              +-+                 10 8  |             1
+--R         log(\|x  + 4398046511104a  b   |- ----------------------- )
+--R                                       4|                    13 11
+--R                                       \|  72057594037927936a  b
+--R     + 
+--R                     3 7 10           4 6 8            5 5 6            6 4 4
+--R           - 1290240a b x   - 6451200a b x  - 12902400a b x  - 12902400a b x
+--R         + 
+--R                     7 3 2           8 2
+--R           - 6451200a b x  - 1290240a b
+--R      *
+--R          +-------------------------+
+--R          |             1
+--R          |- -----------------------
+--R         4|                    13 11
+--R         \|  72057594037927936a  b
+--R      *
+--R                                        +-------------------------+3
+--R              +-+                 10 8  |             1
+--R         log(\|x  - 4398046511104a  b   |- ----------------------- )
+--R                                       4|                    13 11
+--R                                       \|  72057594037927936a  b
+--R     + 
+--R                   3 7 10            4 6 8            5 5 6            6 4 4
+--R           2580480a b x   + 12902400a b x  + 25804800a b x  + 25804800a b x
+--R         + 
+--R                    7 3 2           8 2
+--R           12902400a b x  + 2580480a b
+--R      *
+--R          +-------------------------+
+--R          |             1
+--R          |- -----------------------
+--R         4|                    13 11
+--R         \|  72057594037927936a  b
+--R      *
+--R                                  +-------------------------+3
+--R                            10 8  |             1
+--R              4398046511104a  b   |- -----------------------
+--R                                 4|                    13 11
+--R                                 \|  72057594037927936a  b
+--R         atan(-----------------------------------------------)
+--R                                     +-+
+--R                                    \|x
+--R     + 
+--R            4 9          3 7        2 2 5       3   3       4   +-+
+--R       (315b x  + 1512a b x  + 2870a b x  - 480a b x  - 105a x)\|x
+--R  /
+--R             3 7 10          4 6 8          5 5 6          6 4 4          7 3 2
+--R       20480a b x   + 102400a b x  + 204800a b x  + 204800a b x  + 102400a b x
+--R     + 
+--R             8 2
+--R       20480a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 300
+
+--S 301 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R       63log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                          +-------------------------+
+--R                 3 2 +-+  |             1            4+-+4+-+3
+--R         1032192a b \|2   |- ----------------------- \|a \|b
+--R                         4|                    13 11
+--R                         \|  72057594037927936a  b
+--R      *
+--R                                        +-------------------------+3
+--R              +-+                 10 8  |             1
+--R         log(\|x  + 4398046511104a  b   |- ----------------------- )
+--R                                       4|                    13 11
+--R                                       \|  72057594037927936a  b
+--R     + 
+--R       -
+--R                             +-------------------------+
+--R                    3 2 +-+  |             1            4+-+4+-+3
+--R            1032192a b \|2   |- ----------------------- \|a \|b
+--R                            4|                    13 11
+--R                            \|  72057594037927936a  b
+--R         *
+--R                                           +-------------------------+3
+--R                 +-+                 10 8  |             1
+--R            log(\|x  - 4398046511104a  b   |- ----------------------- )
+--R                                          4|                    13 11
+--R                                          \|  72057594037927936a  b
+--R     + 
+--R                                                             +-+4+-+ +-+   4+-+
+--R                  +-+4+-+4+-+ +-+     +-+    +-+            \|2 \|b \|x  + \|a
+--R       - 63log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 126atan(-------------------)
+--R                                                                    4+-+
+--R                                                                    \|a
+--R     + 
+--R                  +-+4+-+ +-+   4+-+
+--R                 \|2 \|b \|x  - \|a
+--R       - 126atan(-------------------)
+--R                         4+-+
+--R                         \|a
+--R     + 
+--R                          +-------------------------+
+--R                 3 2 +-+  |             1            4+-+4+-+3
+--R         2064384a b \|2   |- ----------------------- \|a \|b
+--R                         4|                    13 11
+--R                         \|  72057594037927936a  b
+--R      *
+--R                                  +-------------------------+3
+--R                            10 8  |             1
+--R              4398046511104a  b   |- -----------------------
+--R                                 4|                    13 11
+--R                                 \|  72057594037927936a  b
+--R         atan(-----------------------------------------------)
+--R                                     +-+
+--R                                    \|x
+--R  /
+--R           3 2 +-+4+-+4+-+3
+--R     16384a b \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 302
+
+)clear all
+
+--S 303 of 1353
+t0:=x^(7/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      3 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 303
+
+--S 304 of 1353
+r0:=-1/10*x^(5/2)/(b*(a+b*x^2)^5)-77/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(15/4)*b^(9/4)*sqrt(2))+77/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(15/4)*b^(9/4)*sqrt(2))-77/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(15/4)*_
+   b^(9/4)*sqrt(2))+77/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(15/4)*b^(9/4)*sqrt(2))-1/32*sqrt(x)/(b^2*_
+   (a+b*x^2)^4)+1/384*sqrt(x)/(a*b^2*(a+b*x^2)^3)+11/3072*sqrt(x)/_
+   (a^2*b^2*(a+b*x^2)^2)+77/12288*sqrt(x)/(a^3*b^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1155b x   + 5775a b x  + 11550a b x  + 11550a b x  + 5775a b x
+--R         + 
+--R                5
+--R           1155a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1155b x   - 5775a b x  - 11550a b x  - 11550a b x  - 5775a b x
+--R         + 
+--R                  5
+--R           - 1155a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6         2 2 4         3   2        4  +-+4+-+3
+--R         (1540b x  + 7040a b x  + 12520a b x  - 22176a b x  - 4620a )\|2 \|a
+--R      *
+--R         4+-+ +-+
+--R         \|b \|x
+--R  /
+--R                3 7 10           4 6 8           5 5 6           6 4 4
+--R         245760a b x   + 1228800a b x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 7 3 2          8 2
+--R         1228800a b x  + 245760a b
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   3 7 10            4 6 8            5 5 6            6 4 4
+--R           4730880a b x   + 23654400a b x  + 47308800a b x  + 47308800a b x
+--R         + 
+--R                    7 3 2           8 2
+--R           23654400a b x  + 4730880a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    15 9
+--R         \|  72057594037927936a  b
+--R      *
+--R                               +------------------------+
+--R              +-+         4 2  |             1
+--R         log(\|x  + 16384a b   |- ----------------------)
+--R                              4|                    15 9
+--R                              \|  72057594037927936a  b
+--R     + 
+--R                     3 7 10            4 6 8            5 5 6            6 4 4
+--R           - 4730880a b x   - 23654400a b x  - 47308800a b x  - 47308800a b x
+--R         + 
+--R                      7 3 2           8 2
+--R           - 23654400a b x  - 4730880a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    15 9
+--R         \|  72057594037927936a  b
+--R      *
+--R                               +------------------------+
+--R              +-+         4 2  |             1
+--R         log(\|x  - 16384a b   |- ----------------------)
+--R                              4|                    15 9
+--R                              \|  72057594037927936a  b
+--R     + 
+--R                     3 7 10            4 6 8            5 5 6            6 4 4
+--R           - 9461760a b x   - 47308800a b x  - 94617600a b x  - 94617600a b x
+--R         + 
+--R                      7 3 2           8 2
+--R           - 47308800a b x  - 9461760a b
+--R      *
+--R                                                    +------------------------+
+--R                                               4 2  |             1
+--R                                         16384a b   |- ----------------------
+--R          +------------------------+               4|                    15 9
+--R          |             1                          \|  72057594037927936a  b
+--R          |- ---------------------- atan(------------------------------------)
+--R         4|                    15 9                       +-+
+--R         \|  72057594037927936a  b                       \|x
+--R     + 
+--R            4 8          3 6        2 2 4        3   2        4  +-+
+--R       (385b x  + 1760a b x  + 3130a b x  - 5544a b x  - 1155a )\|x
+--R  /
+--R             3 7 10          4 6 8          5 5 6          6 4 4          7 3 2
+--R       61440a b x   + 307200a b x  + 614400a b x  + 614400a b x  + 307200a b x
+--R     + 
+--R             8 2
+--R       61440a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 305
+
+--S 306 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 77log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                          +------------------------+
+--R                 3 2 +-+  |             1           4+-+3 4+-+
+--R         1261568a b \|2   |- ---------------------- \|a   \|b
+--R                         4|                    15 9
+--R                         \|  72057594037927936a  b
+--R      *
+--R                               +------------------------+
+--R              +-+         4 2  |             1
+--R         log(\|x  + 16384a b   |- ----------------------)
+--R                              4|                    15 9
+--R                              \|  72057594037927936a  b
+--R     + 
+--R       -
+--R                             +------------------------+
+--R                    3 2 +-+  |             1           4+-+3 4+-+
+--R            1261568a b \|2   |- ---------------------- \|a   \|b
+--R                            4|                    15 9
+--R                            \|  72057594037927936a  b
+--R         *
+--R                                  +------------------------+
+--R                 +-+         4 2  |             1
+--R            log(\|x  - 16384a b   |- ----------------------)
+--R                                 4|                    15 9
+--R                                 \|  72057594037927936a  b
+--R     + 
+--R                                                           +-+4+-+ +-+   4+-+
+--R                +-+4+-+4+-+ +-+     +-+    +-+            \|2 \|b \|x  + \|a
+--R       77log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 154atan(-------------------)
+--R                                                                  4+-+
+--R                                                                  \|a
+--R     + 
+--R                  +-+4+-+ +-+   4+-+
+--R                 \|2 \|b \|x  - \|a
+--R       - 154atan(-------------------)
+--R                         4+-+
+--R                         \|a
+--R     + 
+--R       -
+--R                             +------------------------+
+--R                    3 2 +-+  |             1           4+-+3 4+-+
+--R            2523136a b \|2   |- ---------------------- \|a   \|b
+--R                            4|                    15 9
+--R                            \|  72057594037927936a  b
+--R         *
+--R                            +------------------------+
+--R                       4 2  |             1
+--R                 16384a b   |- ----------------------
+--R                           4|                    15 9
+--R                           \|  72057594037927936a  b
+--R            atan(------------------------------------)
+--R                                  +-+
+--R                                 \|x
+--R  /
+--R           3 2 +-+4+-+3 4+-+
+--R     16384a b \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 307
+
+)clear all
+
+--S 308 of 1353
+t0:=x^(5/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      2 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 1353
+r0:=-1/10*x^(3/2)/(b*(a+b*x^2)^5)+3/160*x^(3/2)/(a*b*(a+b*x^2)^4)+_
+   13/640*x^(3/2)/(a^2*b*(a+b*x^2)^3)+117/5120*x^(3/2)/(a^3*b*(a+b*x^2)^2)+_
+   117/4096*x^(3/2)/(a^4*b*(a+b*x^2))-117/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(17/4)*b^(7/4)*sqrt(2))+117/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(17/4)*b^(7/4)*sqrt(2))+117/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(17/4)*_
+   b^(7/4)*sqrt(2))-117/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(17/4)*b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 585b x   - 2925a b x  - 5850a b x  - 5850a b x  - 2925a b x
+--R           + 
+--R                   5
+--R             - 585a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (585b x   + 2925a b x  + 5850a b x  + 5850a b x  + 2925a b x  + 585a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1170b x   + 5850a b x  + 11700a b x  + 11700a b x  + 5850a b x
+--R         + 
+--R                5
+--R           1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1170b x   + 5850a b x  + 11700a b x  + 11700a b x  + 5850a b x
+--R         + 
+--R                5
+--R           1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 9           3 7         2 2 5         3   3       4   +-+4+-+
+--R         (2340b x  + 11232a b x  + 21320a b x  + 19840a b x  - 780a x)\|2 \|a
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R               4 6 10          5 5 8          6 4 6          7 3 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                8 2 2         9
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   4 6 10            5 5 8            6 4 6            7 3 4
+--R           2396160a b x   + 11980800a b x  + 23961600a b x  + 23961600a b x
+--R         + 
+--R                    8 2 2           9
+--R           11980800a b x  + 2396160a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    17 7
+--R         \|  72057594037927936a  b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 13 5  |             1
+--R         log(\|x  + 4398046511104a  b   |- ---------------------- )
+--R                                       4|                    17 7
+--R                                       \|  72057594037927936a  b
+--R     + 
+--R                     4 6 10            5 5 8            6 4 6            7 3 4
+--R           - 2396160a b x   - 11980800a b x  - 23961600a b x  - 23961600a b x
+--R         + 
+--R                      8 2 2           9
+--R           - 11980800a b x  - 2396160a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    17 7
+--R         \|  72057594037927936a  b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 13 5  |             1
+--R         log(\|x  - 4398046511104a  b   |- ---------------------- )
+--R                                       4|                    17 7
+--R                                       \|  72057594037927936a  b
+--R     + 
+--R                   4 6 10            5 5 8            6 4 6            7 3 4
+--R           4792320a b x   + 23961600a b x  + 47923200a b x  + 47923200a b x
+--R         + 
+--R                    8 2 2           9
+--R           23961600a b x  + 4792320a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    17 7
+--R         \|  72057594037927936a  b
+--R      *
+--R                                  +------------------------+3
+--R                            13 5  |             1
+--R              4398046511104a  b   |- ----------------------
+--R                                 4|                    17 7
+--R                                 \|  72057594037927936a  b
+--R         atan(----------------------------------------------)
+--R                                    +-+
+--R                                   \|x
+--R     + 
+--R            4 9          3 7        2 2 5        3   3       4   +-+
+--R       (585b x  + 2808a b x  + 5330a b x  + 4960a b x  - 195a x)\|x
+--R  /
+--R             4 6 10          5 5 8          6 4 6          7 3 4          8 2 2
+--R       20480a b x   + 102400a b x  + 204800a b x  + 204800a b x  + 102400a b x
+--R     + 
+--R             9
+--R       20480a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 310
+
+--S 311 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+4+-+4+-+ +-+     +-+    +-+
+--R       117log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +------------------------+
+--R                 4  +-+  |             1           4+-+4+-+3
+--R         1916928a b\|2   |- ---------------------- \|a \|b
+--R                        4|                    17 7
+--R                        \|  72057594037927936a  b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 13 5  |             1
+--R         log(\|x  + 4398046511104a  b   |- ---------------------- )
+--R                                       4|                    17 7
+--R                                       \|  72057594037927936a  b
+--R     + 
+--R       -
+--R                            +------------------------+
+--R                    4  +-+  |             1           4+-+4+-+3
+--R            1916928a b\|2   |- ---------------------- \|a \|b
+--R                           4|                    17 7
+--R                           \|  72057594037927936a  b
+--R         *
+--R                                           +------------------------+3
+--R                 +-+                 13 5  |             1
+--R            log(\|x  - 4398046511104a  b   |- ---------------------- )
+--R                                          4|                    17 7
+--R                                          \|  72057594037927936a  b
+--R     + 
+--R                   +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 117log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  +-+4+-+ +-+   4+-+             +-+4+-+ +-+   4+-+
+--R                 \|2 \|b \|x  + \|a             \|2 \|b \|x  - \|a
+--R       - 234atan(-------------------) - 234atan(-------------------)
+--R                         4+-+                           4+-+
+--R                         \|a                            \|a
+--R     + 
+--R                         +------------------------+
+--R                 4  +-+  |             1           4+-+4+-+3
+--R         3833856a b\|2   |- ---------------------- \|a \|b
+--R                        4|                    17 7
+--R                        \|  72057594037927936a  b
+--R      *
+--R                                  +------------------------+3
+--R                            13 5  |             1
+--R              4398046511104a  b   |- ----------------------
+--R                                 4|                    17 7
+--R                                 \|  72057594037927936a  b
+--R         atan(----------------------------------------------)
+--R                                    +-+
+--R                                   \|x
+--R  /
+--R           4  +-+4+-+4+-+3
+--R     16384a b\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 1353
+t0:=x^(3/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        +-+
+--R                                      x\|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 1353
+r0:=-231/8192*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(19/4)*b^(5/4)*_
+   sqrt(2))+231/8192*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(19/4)*_
+   b^(5/4)*sqrt(2))-231/16384*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(19/4)*b^(5/4)*sqrt(2))+231/16384*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(19/4)*b^(5/4)*sqrt(2))-_
+   1/10*sqrt(x)/(b*(a+b*x^2)^5)+1/160*sqrt(x)/(a*b*(a+b*x^2)^4)+_
+   1/128*sqrt(x)/(a^2*b*(a+b*x^2)^3)+11/1024*sqrt(x)/(a^3*b*(a+b*x^2)^2)+_
+   77/4096*sqrt(x)/(a^4*b*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1155b x   + 5775a b x  + 11550a b x  + 11550a b x  + 5775a b x
+--R         + 
+--R                5
+--R           1155a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1155b x   - 5775a b x  - 11550a b x  - 11550a b x  - 5775a b x
+--R         + 
+--R                  5
+--R           - 1155a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6         2 2 4         3   2        4  +-+4+-+3
+--R         (1540b x  + 7040a b x  + 12520a b x  + 10592a b x  - 4620a )\|2 \|a
+--R      *
+--R         4+-+ +-+
+--R         \|b \|x
+--R  /
+--R               4 6 10          5 5 8          6 4 6          7 3 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                8 2 2         9
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   4 6 10            5 5 8            6 4 6            7 3 4
+--R           4730880a b x   + 23654400a b x  + 47308800a b x  + 47308800a b x
+--R         + 
+--R                    8 2 2           9
+--R           23654400a b x  + 4730880a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    19 5
+--R         \|  72057594037927936a  b
+--R      *
+--R                              +------------------------+
+--R              +-+         5   |             1
+--R         log(\|x  + 16384a b  |- ----------------------)
+--R                             4|                    19 5
+--R                             \|  72057594037927936a  b
+--R     + 
+--R                     4 6 10            5 5 8            6 4 6            7 3 4
+--R           - 4730880a b x   - 23654400a b x  - 47308800a b x  - 47308800a b x
+--R         + 
+--R                      8 2 2           9
+--R           - 23654400a b x  - 4730880a b
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    19 5
+--R         \|  72057594037927936a  b
+--R      *
+--R                              +------------------------+
+--R              +-+         5   |             1
+--R         log(\|x  - 16384a b  |- ----------------------)
+--R                             4|                    19 5
+--R                             \|  72057594037927936a  b
+--R     + 
+--R                     4 6 10            5 5 8            6 4 6            7 3 4
+--R           - 9461760a b x   - 47308800a b x  - 94617600a b x  - 94617600a b x
+--R         + 
+--R                      8 2 2           9
+--R           - 47308800a b x  - 9461760a b
+--R      *
+--R                                                   +------------------------+
+--R                                               5   |             1
+--R                                         16384a b  |- ----------------------
+--R          +------------------------+              4|                    19 5
+--R          |             1                         \|  72057594037927936a  b
+--R          |- ---------------------- atan(-----------------------------------)
+--R         4|                    19 5                       +-+
+--R         \|  72057594037927936a  b                       \|x
+--R     + 
+--R            4 8          3 6        2 2 4        3   2        4  +-+
+--R       (385b x  + 1760a b x  + 3130a b x  + 2648a b x  - 1155a )\|x
+--R  /
+--R             4 6 10          5 5 8          6 4 6          7 3 4          8 2 2
+--R       20480a b x   + 102400a b x  + 204800a b x  + 204800a b x  + 102400a b x
+--R     + 
+--R             9
+--R       20480a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 315
+
+--S 316 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 231log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +------------------------+
+--R                 4  +-+  |             1           4+-+3 4+-+
+--R         3784704a b\|2   |- ---------------------- \|a   \|b
+--R                        4|                    19 5
+--R                        \|  72057594037927936a  b
+--R      *
+--R                              +------------------------+
+--R              +-+         5   |             1
+--R         log(\|x  + 16384a b  |- ----------------------)
+--R                             4|                    19 5
+--R                             \|  72057594037927936a  b
+--R     + 
+--R       -
+--R                            +------------------------+
+--R                    4  +-+  |             1           4+-+3 4+-+
+--R            3784704a b\|2   |- ---------------------- \|a   \|b
+--R                           4|                    19 5
+--R                           \|  72057594037927936a  b
+--R         *
+--R                                 +------------------------+
+--R                 +-+         5   |             1
+--R            log(\|x  - 16384a b  |- ----------------------)
+--R                                4|                    19 5
+--R                                \|  72057594037927936a  b
+--R     + 
+--R                                                            +-+4+-+ +-+   4+-+
+--R                 +-+4+-+4+-+ +-+     +-+    +-+            \|2 \|b \|x  + \|a
+--R       231log(- \|2 \|a \|b \|x  + x\|b  + \|a ) - 462atan(-------------------)
+--R                                                                   4+-+
+--R                                                                   \|a
+--R     + 
+--R                  +-+4+-+ +-+   4+-+
+--R                 \|2 \|b \|x  - \|a
+--R       - 462atan(-------------------)
+--R                         4+-+
+--R                         \|a
+--R     + 
+--R       -
+--R                            +------------------------+
+--R                    4  +-+  |             1           4+-+3 4+-+
+--R            7569408a b\|2   |- ---------------------- \|a   \|b
+--R                           4|                    19 5
+--R                           \|  72057594037927936a  b
+--R         *
+--R                           +------------------------+
+--R                       5   |             1
+--R                 16384a b  |- ----------------------
+--R                          4|                    19 5
+--R                          \|  72057594037927936a  b
+--R            atan(-----------------------------------)
+--R                                  +-+
+--R                                 \|x
+--R  /
+--R           4  +-+4+-+3 4+-+
+--R     16384a b\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 317
+
+)clear all
+
+--S 318 of 1353
+t0:=sqrt(x)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                       +-+
+--R                                      \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 318
+
+--S 319 of 1353
+r0:=1/10*x^(3/2)/(a*(a+b*x^2)^5)+17/160*x^(3/2)/(a^2*(a+b*x^2)^4)+_
+   221/1920*x^(3/2)/(a^3*(a+b*x^2)^3)+663/5120*x^(3/2)/(a^4*(a+b*x^2)^2)+_
+   663/4096*x^(3/2)/(a^5*(a+b*x^2))-663/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(21/4)*b^(3/4)*sqrt(2))+663/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(21/4)*b^(3/4)*sqrt(2))+663/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(21/4)*_
+   b^(3/4)*sqrt(2))-663/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(21/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 9945b x   - 49725a b x  - 99450a b x  - 99450a b x  - 49725a b x
+--R         + 
+--R                  5
+--R           - 9945a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           9945b x   + 49725a b x  + 99450a b x  + 99450a b x  + 49725a b x
+--R         + 
+--R                5
+--R           9945a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                4 9            3 7          2 2 5          3   3          4
+--R         (39780b x  + 190944a b x  + 362440a b x  + 337280a b x  + 150580a x)
+--R      *
+--R          +-+4+-+4+-+3 +-+
+--R         \|2 \|a \|b  \|x
+--R  /
+--R                5 5 10           6 4 8           7 3 6           8 2 4
+--R         245760a b x   + 1228800a b x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 9   2          10
+--R         1228800a b x  + 245760a
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    5 5 10             6 4 8             7 3 6             8 2 4
+--R           40734720a b x   + 203673600a b x  + 407347200a b x  + 407347200a b x
+--R         + 
+--R                     9   2            10
+--R           203673600a b x  + 40734720a
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    21 3
+--R         \|  72057594037927936a  b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 16 2  |             1
+--R         log(\|x  + 4398046511104a  b   |- ---------------------- )
+--R                                       4|                    21 3
+--R                                       \|  72057594037927936a  b
+--R     + 
+--R                      5 5 10             6 4 8             7 3 6
+--R           - 40734720a b x   - 203673600a b x  - 407347200a b x
+--R         + 
+--R                       8 2 4             9   2            10
+--R           - 407347200a b x  - 203673600a b x  - 40734720a
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    21 3
+--R         \|  72057594037927936a  b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 16 2  |             1
+--R         log(\|x  - 4398046511104a  b   |- ---------------------- )
+--R                                       4|                    21 3
+--R                                       \|  72057594037927936a  b
+--R     + 
+--R                    5 5 10             6 4 8             7 3 6             8 2 4
+--R           81469440a b x   + 407347200a b x  + 814694400a b x  + 814694400a b x
+--R         + 
+--R                     9   2            10
+--R           407347200a b x  + 81469440a
+--R      *
+--R          +------------------------+
+--R          |             1
+--R          |- ----------------------
+--R         4|                    21 3
+--R         \|  72057594037927936a  b
+--R      *
+--R                                  +------------------------+3
+--R                            16 2  |             1
+--R              4398046511104a  b   |- ----------------------
+--R                                 4|                    21 3
+--R                                 \|  72057594037927936a  b
+--R         atan(----------------------------------------------)
+--R                                    +-+
+--R                                   \|x
+--R     + 
+--R             4 9           3 7         2 2 5         3   3         4   +-+
+--R       (9945b x  + 47736a b x  + 90610a b x  + 84320a b x  + 37645a x)\|x
+--R  /
+--R             5 5 10          6 4 8          7 3 6          8 2 4          9   2
+--R       61440a b x   + 307200a b x  + 614400a b x  + 614400a b x  + 307200a b x
+--R     + 
+--R             10
+--R       61440a
+--R                                         Type: Union(Expression(Integer),...)
+--E 320
+
+--S 321 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+4+-+4+-+ +-+     +-+    +-+
+--R       663log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +------------------------+
+--R                  5 +-+  |             1           4+-+4+-+3
+--R         10862592a \|2   |- ---------------------- \|a \|b
+--R                        4|                    21 3
+--R                        \|  72057594037927936a  b
+--R      *
+--R                                        +------------------------+3
+--R              +-+                 16 2  |             1
+--R         log(\|x  + 4398046511104a  b   |- ---------------------- )
+--R                                       4|                    21 3
+--R                                       \|  72057594037927936a  b
+--R     + 
+--R       -
+--R                            +------------------------+
+--R                     5 +-+  |             1           4+-+4+-+3
+--R            10862592a \|2   |- ---------------------- \|a \|b
+--R                           4|                    21 3
+--R                           \|  72057594037927936a  b
+--R         *
+--R                                           +------------------------+3
+--R                 +-+                 16 2  |             1
+--R            log(\|x  - 4398046511104a  b   |- ---------------------- )
+--R                                          4|                    21 3
+--R                                          \|  72057594037927936a  b
+--R     + 
+--R                   +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 663log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   +-+4+-+ +-+   4+-+              +-+4+-+ +-+   4+-+
+--R                  \|2 \|b \|x  + \|a              \|2 \|b \|x  - \|a
+--R       - 1326atan(-------------------) - 1326atan(-------------------)
+--R                          4+-+                            4+-+
+--R                          \|a                             \|a
+--R     + 
+--R                         +------------------------+
+--R                  5 +-+  |             1           4+-+4+-+3
+--R         21725184a \|2   |- ---------------------- \|a \|b
+--R                        4|                    21 3
+--R                        \|  72057594037927936a  b
+--R      *
+--R                                  +------------------------+3
+--R                            16 2  |             1
+--R              4398046511104a  b   |- ----------------------
+--R                                 4|                    21 3
+--R                                 \|  72057594037927936a  b
+--R         atan(----------------------------------------------)
+--R                                    +-+
+--R                                   \|x
+--R  /
+--R           5 +-+4+-+4+-+3
+--R     16384a \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 322
+
+)clear all
+
+--S 323 of 1353
+t0:=1/((a^2+2*a*b*x^2+b^2*x^4)^3*sqrt(x))
+--R 
+--R
+--R                                           1
+--R   (1)  ----------------------------------------------------------------------
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6  +-+
+--R        (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 1353
+r0:=-4389/8192*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(23/4)*b^(1/4)*_
+   sqrt(2))+4389/8192*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(23/4)*_
+   b^(1/4)*sqrt(2))-4389/16384*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(23/4)*b^(1/4)*sqrt(2))+4389/16384*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(23/4)*b^(1/4)*sqrt(2))+_
+   1/10*sqrt(x)/(a*(a+b*x^2)^5)+19/160*sqrt(x)/(a^2*(a+b*x^2)^4)+_
+   19/128*sqrt(x)/(a^3*(a+b*x^2)^3)+209/1024*sqrt(x)/(a^4*(a+b*x^2)^2)+_
+   1463/4096*sqrt(x)/(a^5*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           21945b x   + 109725a b x  + 219450a b x  + 219450a b x
+--R         + 
+--R                  4   2         5
+--R           109725a b x  + 21945a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10            4 8          2 3 6          3 2 4
+--R           - 21945b x   - 109725a b x  - 219450a b x  - 219450a b x
+--R         + 
+--R                    4   2         5
+--R           - 109725a b x  - 21945a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   2         5
+--R           219450a b x  + 43890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   2         5
+--R           219450a b x  + 43890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                4 8            3 6          2 2 4          3   2         4  +-+
+--R         (29260b x  + 133760a b x  + 237880a b x  + 201248a b x  + 76060a )\|2
+--R      *
+--R         4+-+3 4+-+ +-+
+--R         \|a   \|b \|x
+--R  /
+--R               5 5 10          6 4 8          7 3 6          8 2 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                9   2         10
+--R         409600a b x  + 81920a
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    5 5 10             6 4 8             7 3 6             8 2 4
+--R           89886720a b x   + 449433600a b x  + 898867200a b x  + 898867200a b x
+--R         + 
+--R                     9   2            10
+--R           449433600a b x  + 89886720a
+--R      *
+--R        +-----------------------+                    +-----------------------+
+--R        |            1                +-+         6  |            1
+--R        |- --------------------- log(\|x  + 16384a   |- ---------------------)
+--R       4|                    23                     4|                    23
+--R       \|  72057594037927936a  b                    \|  72057594037927936a  b
+--R     + 
+--R                      5 5 10             6 4 8             7 3 6
+--R           - 89886720a b x   - 449433600a b x  - 898867200a b x
+--R         + 
+--R                       8 2 4             9   2            10
+--R           - 898867200a b x  - 449433600a b x  - 89886720a
+--R      *
+--R        +-----------------------+                    +-----------------------+
+--R        |            1                +-+         6  |            1
+--R        |- --------------------- log(\|x  - 16384a   |- ---------------------)
+--R       4|                    23                     4|                    23
+--R       \|  72057594037927936a  b                    \|  72057594037927936a  b
+--R     + 
+--R                       5 5 10             6 4 8              7 3 6
+--R           - 179773440a b x   - 898867200a b x  - 1797734400a b x
+--R         + 
+--R                        8 2 4             9   2             10
+--R           - 1797734400a b x  - 898867200a b x  - 179773440a
+--R      *
+--R                                                 +-----------------------+
+--R                                              6  |            1
+--R                                        16384a   |- ---------------------
+--R          +-----------------------+             4|                    23
+--R          |            1                        \|  72057594037927936a  b
+--R          |- --------------------- atan(---------------------------------)
+--R         4|                    23                       +-+
+--R         \|  72057594037927936a  b                     \|x
+--R     + 
+--R             4 8           3 6         2 2 4         3   2         4  +-+
+--R       (7315b x  + 33440a b x  + 59470a b x  + 50312a b x  + 19015a )\|x
+--R  /
+--R             5 5 10          6 4 8          7 3 6          8 2 4          9   2
+--R       20480a b x   + 102400a b x  + 204800a b x  + 204800a b x  + 102400a b x
+--R     + 
+--R             10
+--R       20480a
+--R                                         Type: Union(Expression(Integer),...)
+--E 325
+
+--S 326 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 4389log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-----------------------+
+--R                  5 +-+  |            1           4+-+3 4+-+
+--R         71909376a \|2   |- --------------------- \|a   \|b
+--R                        4|                    23
+--R                        \|  72057594037927936a  b
+--R      *
+--R                             +-----------------------+
+--R              +-+         6  |            1
+--R         log(\|x  + 16384a   |- ---------------------)
+--R                            4|                    23
+--R                            \|  72057594037927936a  b
+--R     + 
+--R       -
+--R                            +-----------------------+
+--R                     5 +-+  |            1           4+-+3 4+-+
+--R            71909376a \|2   |- --------------------- \|a   \|b
+--R                           4|                    23
+--R                           \|  72057594037927936a  b
+--R         *
+--R                                +-----------------------+
+--R                 +-+         6  |            1
+--R            log(\|x  - 16384a   |- ---------------------)
+--R                               4|                    23
+--R                               \|  72057594037927936a  b
+--R     + 
+--R                  +-+4+-+4+-+ +-+     +-+    +-+
+--R       4389log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   +-+4+-+ +-+   4+-+              +-+4+-+ +-+   4+-+
+--R                  \|2 \|b \|x  + \|a              \|2 \|b \|x  - \|a
+--R       - 8778atan(-------------------) - 8778atan(-------------------)
+--R                          4+-+                            4+-+
+--R                          \|a                             \|a
+--R     + 
+--R       -
+--R                             +-----------------------+
+--R                      5 +-+  |            1           4+-+3 4+-+
+--R            143818752a \|2   |- --------------------- \|a   \|b
+--R                            4|                    23
+--R                            \|  72057594037927936a  b
+--R         *
+--R                          +-----------------------+
+--R                       6  |            1
+--R                 16384a   |- ---------------------
+--R                         4|                    23
+--R                         \|  72057594037927936a  b
+--R            atan(---------------------------------)
+--R                                 +-+
+--R                                \|x
+--R  /
+--R           5 +-+4+-+3 4+-+
+--R     16384a \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 1353
+t0:=1/(x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R   (1)
+--R                                      1
+--R   -----------------------------------------------------------------------
+--R     6 13       5 11      2 4 9      3 3 7      4 2 5     5   3    6   +-+
+--R   (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 1353
+r0:=13923/8192*b^(1/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(25/4)*_
+   sqrt(2))-13923/8192*b^(1/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(25/4)*sqrt(2))-13923/16384*b^(1/4)*log(sqrt(a)+x*sqrt(b)-_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(25/4)*sqrt(2))+13923/16384*_
+   b^(1/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(25/4)*sqrt(2))+(-13923/4096)/(a^6*sqrt(x))+1/10/(a*(a+b*x^2)^5*_
+   sqrt(x))+21/160/(a^2*(a+b*x^2)^4*sqrt(x))+119/640/(a^3*(a+b*x^2)^3*_
+   sqrt(x))+1547/5120/(a^4*(a+b*x^2)^2*sqrt(x))+13923/20480/(a^5*_
+   (a+b*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           69615b x   + 348075a b x  + 696150a b x  + 696150a b x
+--R         + 
+--R                  4   2         5
+--R           348075a b x  + 69615a
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10            4 8          2 3 6          3 2 4
+--R           - 69615b x   - 348075a b x  - 696150a b x  - 696150a b x
+--R         + 
+--R                    4   2         5
+--R           - 348075a b x  - 69615a
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    5 10            4 8           2 3 6           3 2 4
+--R           - 139230b x   - 696150a b x  - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    4   2          5
+--R           - 696150a b x  - 139230a
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  + \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                    5 10            4 8           2 3 6           3 2 4
+--R           - 139230b x   - 696150a b x  - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    4   2          5
+--R           - 696150a b x  - 139230a
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  - \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                    5 10             4 8           2 3 6           3 2 4
+--R           - 278460b x   - 1336608a b x  - 2537080a b x  - 2360960a b x
+--R         + 
+--R                     4   2          5
+--R           - 1054060a b x  - 163840a
+--R      *
+--R          +-+4+-+
+--R         \|2 \|a
+--R  /
+--R               6 5 10          7 4 8          8 3 6          9 2 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                10   2         11
+--R         409600a  b x  + 81920a
+--R    *
+--R        +-+4+-+ +-+
+--R       \|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   6 5 10          7 4 8          8 3 6          9 2 4
+--R           - 20480a b x   - 102400a b x  - 204800a b x  - 204800a b x
+--R         + 
+--R                    10   2         11
+--R           - 102400a  b x  - 20480a
+--R      *
+--R          +----------------------+
+--R          |   37577794973305041b   +-+
+--R          |- -------------------- \|x
+--R         4|                    25
+--R         \|  72057594037927936a
+--R      *
+--R                                                    +----------------------+3
+--R                            +-+                 19  |   37577794973305041b
+--R         log(2698972561467b\|x  + 4398046511104a    |- -------------------- )
+--R                                                   4|                    25
+--R                                                   \|  72057594037927936a
+--R     + 
+--R                 6 5 10          7 4 8          8 3 6          9 2 4
+--R           20480a b x   + 102400a b x  + 204800a b x  + 204800a b x
+--R         + 
+--R                  10   2         11
+--R           102400a  b x  + 20480a
+--R      *
+--R          +----------------------+
+--R          |   37577794973305041b   +-+
+--R          |- -------------------- \|x
+--R         4|                    25
+--R         \|  72057594037927936a
+--R      *
+--R                                                    +----------------------+3
+--R                            +-+                 19  |   37577794973305041b
+--R         log(2698972561467b\|x  - 4398046511104a    |- -------------------- )
+--R                                                   4|                    25
+--R                                                   \|  72057594037927936a
+--R     + 
+--R                   6 5 10          7 4 8          8 3 6          9 2 4
+--R           - 40960a b x   - 204800a b x  - 409600a b x  - 409600a b x
+--R         + 
+--R                    10   2         11
+--R           - 204800a  b x  - 40960a
+--R      *
+--R          +----------------------+
+--R          |   37577794973305041b   +-+
+--R          |- -------------------- \|x
+--R         4|                    25
+--R         \|  72057594037927936a
+--R      *
+--R                                +----------------------+3
+--R                            19  |   37577794973305041b
+--R              4398046511104a    |- --------------------
+--R                               4|                    25
+--R                               \|  72057594037927936a
+--R         atan(------------------------------------------)
+--R                                         +-+
+--R                          2698972561467b\|x
+--R     + 
+--R               5 10            4 8          2 3 6          3 2 4          4   2
+--R       - 69615b x   - 334152a b x  - 634270a b x  - 590240a b x  - 263515a b x
+--R     + 
+--R               5
+--R       - 40960a
+--R  /
+--R               6 5 10          7 4 8          8 3 6          9 2 4
+--R         20480a b x   + 102400a b x  + 204800a b x  + 204800a b x
+--R       + 
+--R                10   2         11
+--R         102400a  b x  + 20480a
+--R    *
+--R        +-+
+--R       \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 330
+
+--S 331 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 13923\|b log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R       -
+--R                         +----------------------+
+--R                  6 +-+  |   37577794973305041b  4+-+
+--R            16384a \|2   |- -------------------- \|a
+--R                        4|                    25
+--R                        \|  72057594037927936a
+--R         *
+--R                                                     +----------------------+3
+--R                             +-+                 19  |   37577794973305041b
+--R          log(2698972561467b\|x  + 4398046511104a    |- -------------------- )
+--R                                                    4|                    25
+--R                                                    \|  72057594037927936a
+--R     + 
+--R                      +----------------------+
+--R               6 +-+  |   37577794973305041b  4+-+
+--R         16384a \|2   |- -------------------- \|a
+--R                     4|                    25
+--R                     \|  72057594037927936a
+--R      *
+--R                                                    +----------------------+3
+--R                            +-+                 19  |   37577794973305041b
+--R         log(2698972561467b\|x  - 4398046511104a    |- -------------------- )
+--R                                                   4|                    25
+--R                                                   \|  72057594037927936a
+--R     + 
+--R            4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       13923\|b log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      +-+4+-+ +-+   4+-+                   +-+4+-+ +-+   4+-+
+--R            4+-+     \|2 \|b \|x  + \|a          4+-+     \|2 \|b \|x  - \|a
+--R       27846\|b atan(-------------------) + 27846\|b atan(-------------------)
+--R                             4+-+                                 4+-+
+--R                             \|a                                  \|a
+--R     + 
+--R       -
+--R                         +----------------------+
+--R                  6 +-+  |   37577794973305041b  4+-+
+--R            32768a \|2   |- -------------------- \|a
+--R                        4|                    25
+--R                        \|  72057594037927936a
+--R         *
+--R                                   +----------------------+3
+--R                               19  |   37577794973305041b
+--R                 4398046511104a    |- --------------------
+--R                                  4|                    25
+--R                                  \|  72057594037927936a
+--R            atan(------------------------------------------)
+--R                                            +-+
+--R                             2698972561467b\|x
+--R  /
+--R           6 +-+4+-+
+--R     16384a \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 332
+
+)clear all
+
+--S 333 of 1353
+t0:=1/(x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R   (1)
+--R                                       1
+--R   -------------------------------------------------------------------------
+--R     6 14       5 12      2 4 10      3 3 8      4 2 6     5   4    6 2  +-+
+--R   (b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 333
+
+--S 334 of 1353
+r0:=(-33649/12288)/(a^6*x^(3/2))+1/10/(a*x^(3/2)*(a+b*x^2)^5)+_
+   23/160/(a^2*x^(3/2)*(a+b*x^2)^4)+437/1920/(a^3*x^(3/2)*(a+b*x^2)^3)+_
+   437/1024/(a^4*x^(3/2)*(a+b*x^2)^2)+4807/4096/(a^5*x^(3/2)*(a+b*x^2))+_
+   33649/8192*b^(3/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(27/4)*_
+   sqrt(2))-33649/8192*b^(3/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(27/4)*sqrt(2))+33649/16384*b^(3/4)*log(sqrt(a)+x*sqrt(b)-_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(27/4)*sqrt(2))-33649/16384*_
+   b^(3/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(27/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                    5 11             4 9           2 3 7           3 2 5
+--R           - 504735b x   - 2523675a b x  - 5047350a b x  - 5047350a b x
+--R         + 
+--R                     4   3          5
+--R           - 2523675a b x  - 504735a x
+--R      *
+--R         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b  \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 11             4 9           2 3 7           3 2 5
+--R           504735b x   + 2523675a b x  + 5047350a b x  + 5047350a b x
+--R         + 
+--R                   4   3          5
+--R           2523675a b x  + 504735a x
+--R      *
+--R         4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b  \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                     5 11             4 9            2 3 7            3 2 5
+--R           - 1009470b x   - 5047350a b x  - 10094700a b x  - 10094700a b x
+--R         + 
+--R                     4   3           5
+--R           - 5047350a b x  - 1009470a x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|b \|x  + \|a
+--R         \|b  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|a
+--R     + 
+--R                     5 11             4 9            2 3 7            3 2 5
+--R           - 1009470b x   - 5047350a b x  - 10094700a b x  - 10094700a b x
+--R         + 
+--R                     4   3           5
+--R           - 5047350a b x  - 1009470a x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|b \|x  - \|a
+--R         \|b  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|a
+--R     + 
+--R                    5 10             4 8           2 3 6           3 2 4
+--R           - 672980b x   - 3076480a b x  - 5471240a b x  - 4628704a b x
+--R         + 
+--R                     4   2          5
+--R           - 1749380a b x  - 163840a
+--R      *
+--R          +-+4+-+3
+--R         \|2 \|a
+--R  /
+--R                6 5 11           7 4 9           8 3 7           9 2 5
+--R         245760a b x   + 1228800a b x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 10   3          11
+--R         1228800a  b x  + 245760a  x
+--R    *
+--R        +-+4+-+3 +-+
+--R       \|2 \|a  \|x
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   6 5 11          7 4 9          8 3 7          9 2 5
+--R           - 61440a b x   - 307200a b x  - 614400a b x  - 614400a b x
+--R         + 
+--R                    10   3         11
+--R           - 307200a  b x  - 61440a  x
+--R      *
+--R          +-----------------------+
+--R          |                      3
+--R          |  1282001840191550401b   +-+
+--R          |- --------------------- \|x
+--R         4|                     27
+--R         \|   72057594037927936a
+--R      *
+--R                                   +-----------------------+
+--R                                   |                      3
+--R                    +-+         7  |  1282001840191550401b
+--R         log(33649b\|x  + 16384a   |- ---------------------)
+--R                                  4|                     27
+--R                                  \|   72057594037927936a
+--R     + 
+--R                 6 5 11          7 4 9          8 3 7          9 2 5
+--R           61440a b x   + 307200a b x  + 614400a b x  + 614400a b x
+--R         + 
+--R                  10   3         11
+--R           307200a  b x  + 61440a  x
+--R      *
+--R          +-----------------------+
+--R          |                      3
+--R          |  1282001840191550401b   +-+
+--R          |- --------------------- \|x
+--R         4|                     27
+--R         \|   72057594037927936a
+--R      *
+--R                                   +-----------------------+
+--R                                   |                      3
+--R                    +-+         7  |  1282001840191550401b
+--R         log(33649b\|x  - 16384a   |- ---------------------)
+--R                                  4|                     27
+--R                                  \|   72057594037927936a
+--R     + 
+--R                  6 5 11          7 4 9           8 3 7           9 2 5
+--R           122880a b x   + 614400a b x  + 1228800a b x  + 1228800a b x
+--R         + 
+--R                  10   3          11
+--R           614400a  b x  + 122880a  x
+--R      *
+--R                                                     +-----------------------+
+--R                                                     |                      3
+--R                                                  7  |  1282001840191550401b
+--R          +-----------------------+         16384a   |- ---------------------
+--R          |                      3                  4|                     27
+--R          |  1282001840191550401b   +-+             \|   72057594037927936a
+--R          |- --------------------- \|x atan(---------------------------------)
+--R         4|                     27                             +-+
+--R         \|   72057594037927936a                        33649b\|x
+--R     + 
+--R                5 10            4 8           2 3 6           3 2 4
+--R       - 168245b x   - 769120a b x  - 1367810a b x  - 1157176a b x
+--R     + 
+--R                4   2         5
+--R       - 437345a b x  - 40960a
+--R  /
+--R               6 5 11          7 4 9          8 3 7          9 2 5
+--R         61440a b x   + 307200a b x  + 614400a b x  + 614400a b x
+--R       + 
+--R                10   3         11
+--R         307200a  b x  + 61440a  x
+--R    *
+--R        +-+
+--R       \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 335
+
+--S 336 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       33649\|b  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R       -
+--R                         +-----------------------+
+--R                         |                      3
+--R                  6 +-+  |  1282001840191550401b  4+-+3
+--R            16384a \|2   |- --------------------- \|a
+--R                        4|                     27
+--R                        \|   72057594037927936a
+--R         *
+--R                                      +-----------------------+
+--R                                      |                      3
+--R                       +-+         7  |  1282001840191550401b
+--R            log(33649b\|x  + 16384a   |- ---------------------)
+--R                                     4|                     27
+--R                                     \|   72057594037927936a
+--R     + 
+--R                      +-----------------------+
+--R                      |                      3
+--R               6 +-+  |  1282001840191550401b  4+-+3
+--R         16384a \|2   |- --------------------- \|a
+--R                     4|                     27
+--R                     \|   72057594037927936a
+--R      *
+--R                                   +-----------------------+
+--R                                   |                      3
+--R                    +-+         7  |  1282001840191550401b
+--R         log(33649b\|x  - 16384a   |- ---------------------)
+--R                                  4|                     27
+--R                                  \|   72057594037927936a
+--R     + 
+--R              4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 33649\|b  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                       +-+4+-+ +-+   4+-+                    +-+4+-+ +-+   4+-+
+--R            4+-+3     \|2 \|b \|x  + \|a          4+-+3     \|2 \|b \|x  - \|a
+--R       67298\|b  atan(-------------------) + 67298\|b  atan(-------------------)
+--R                              4+-+                                  4+-+
+--R                              \|a                                   \|a
+--R     + 
+--R                      +-----------------------+
+--R                      |                      3
+--R               6 +-+  |  1282001840191550401b  4+-+3
+--R         32768a \|2   |- --------------------- \|a
+--R                     4|                     27
+--R                     \|   72057594037927936a
+--R      *
+--R                       +-----------------------+
+--R                       |                      3
+--R                    7  |  1282001840191550401b
+--R              16384a   |- ---------------------
+--R                      4|                     27
+--R                      \|   72057594037927936a
+--R         atan(---------------------------------)
+--R                                 +-+
+--R                          33649b\|x
+--R  /
+--R           6 +-+4+-+3
+--R     16384a \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 337
+
+)clear all
+
+--S 338 of 1353
+t0:=1/(x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R   (1)
+--R                                       1
+--R   -------------------------------------------------------------------------
+--R     6 15       5 13      2 4 11      3 3 9      4 2 7     5   5    6 3  +-+
+--R   (b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 1353
+r0:=(-13923/4096)/(a^6*x^(5/2))+1/10/(a*x^(5/2)*(a+b*x^2)^5)+_
+   5/32/(a^2*x^(5/2)*(a+b*x^2)^4)+35/128/(a^3*x^(5/2)*(a+b*x^2)^3)+_
+   595/1024/(a^4*x^(5/2)*(a+b*x^2)^2)+7735/4096/(a^5*x^(5/2)*(a+b*x^2))-_
+   69615/8192*b^(5/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(29/4)*_
+   sqrt(2))+69615/8192*b^(5/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(29/4)*sqrt(2))+69615/16384*b^(5/4)*log(sqrt(a)+x*sqrt(b)-_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(29/4)*sqrt(2))-69615/16384*_
+   b^(5/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(29/4)*sqrt(2))+69615/4096*b/(a^7*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                    6 12             5 10           2 4 8           3 3 6
+--R           - 348075b x   - 1740375a b x   - 3480750a b x  - 3480750a b x
+--R         + 
+--R                     4 2 4          5   2
+--R           - 1740375a b x  - 348075a b x
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  6 12             5 10           2 4 8           3 3 6
+--R           348075b x   + 1740375a b x   + 3480750a b x  + 3480750a b x
+--R         + 
+--R                   4 2 4          5   2
+--R           1740375a b x  + 348075a b x
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  6 12             5 10           2 4 8           3 3 6
+--R           696150b x   + 3480750a b x   + 6961500a b x  + 6961500a b x
+--R         + 
+--R                   4 2 4          5   2
+--R           3480750a b x  + 696150a b x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  + \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                  6 12             5 10           2 4 8           3 3 6
+--R           696150b x   + 3480750a b x   + 6961500a b x  + 6961500a b x
+--R         + 
+--R                   4 2 4          5   2
+--R           3480750a b x  + 696150a b x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  - \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                   6 12             5 10            2 4 8            3 3 6
+--R           1392300b x   + 6683040a b x   + 12685400a b x  + 11804800a b x
+--R         + 
+--R                   4 2 4          5   2         6
+--R           5270300a b x  + 819200a b x  - 32768a
+--R      *
+--R          +-+4+-+
+--R         \|2 \|a
+--R  /
+--R               7 5 12          8 4 10          9 3 8          10 2 6
+--R         81920a b x   + 409600a b x   + 819200a b x  + 819200a  b x
+--R       + 
+--R                11   4         12 2
+--R         409600a  b x  + 81920a  x
+--R    *
+--R        +-+4+-+ +-+
+--R       \|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 7 5 12          8 4 10          9 3 8          10 2 6
+--R           20480a b x   + 102400a b x   + 204800a b x  + 204800a  b x
+--R         + 
+--R                  11   4         12 2
+--R           102400a  b x  + 20480a  x
+--R      *
+--R          +------------------------+
+--R          |                       5
+--R          |  23486121858315650625b   +-+
+--R          |- ---------------------- \|x
+--R         4|                     29
+--R         \|   72057594037927936a
+--R      *
+--R                                                     +------------------------+3
+--R                                                     |                       5
+--R                           4 +-+                 22  |  23486121858315650625b
+--R       log(337371570183375b \|x  + 4398046511104a    |- ---------------------- )
+--R                                                    4|                     29
+--R                                                    \|   72057594037927936a
+--R     + 
+--R                   7 5 12          8 4 10          9 3 8          10 2 6
+--R           - 20480a b x   - 102400a b x   - 204800a b x  - 204800a  b x
+--R         + 
+--R                    11   4         12 2
+--R           - 102400a  b x  - 20480a  x
+--R      *
+--R          +------------------------+
+--R          |                       5
+--R          |  23486121858315650625b   +-+
+--R          |- ---------------------- \|x
+--R         4|                     29
+--R         \|   72057594037927936a
+--R      *
+--R                                                     +------------------------+3
+--R                                                     |                       5
+--R                           4 +-+                 22  |  23486121858315650625b
+--R       log(337371570183375b \|x  - 4398046511104a    |- ---------------------- )
+--R                                                    4|                     29
+--R                                                    \|   72057594037927936a
+--R     + 
+--R                 7 5 12          8 4 10          9 3 8          10 2 6
+--R           40960a b x   + 204800a b x   + 409600a b x  + 409600a  b x
+--R         + 
+--R                  11   4         12 2
+--R           204800a  b x  + 40960a  x
+--R      *
+--R          +------------------------+
+--R          |                       5
+--R          |  23486121858315650625b   +-+
+--R          |- ---------------------- \|x
+--R         4|                     29
+--R         \|   72057594037927936a
+--R      *
+--R                                +------------------------+3
+--R                                |                       5
+--R                            22  |  23486121858315650625b
+--R              4398046511104a    |- ----------------------
+--R                               4|                     29
+--R                               \|   72057594037927936a
+--R         atan(--------------------------------------------)
+--R                                          4 +-+
+--R                          337371570183375b \|x
+--R     + 
+--R              6 12             5 10           2 4 8           3 3 6
+--R       348075b x   + 1670760a b x   + 3171350a b x  + 2951200a b x
+--R     + 
+--R               4 2 4          5   2        6
+--R       1317575a b x  + 204800a b x  - 8192a
+--R  /
+--R               7 5 12          8 4 10          9 3 8          10 2 6
+--R         20480a b x   + 102400a b x   + 204800a b x  + 204800a  b x
+--R       + 
+--R                11   4         12 2
+--R         102400a  b x  + 20480a  x
+--R    *
+--R        +-+
+--R       \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 340
+
+--S 341 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       69615b\|b log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      +------------------------+
+--R                      |                       5
+--R               7 +-+  |  23486121858315650625b  4+-+
+--R         16384a \|2   |- ---------------------- \|a
+--R                     4|                     29
+--R                     \|   72057594037927936a
+--R      *
+--R                                                     +------------------------+3
+--R                                                     |                       5
+--R                           4 +-+                 22  |  23486121858315650625b
+--R       log(337371570183375b \|x  + 4398046511104a    |- ---------------------- )
+--R                                                    4|                     29
+--R                                                    \|   72057594037927936a
+--R     + 
+--R       -
+--R                         +------------------------+
+--R                         |                       5
+--R                  7 +-+  |  23486121858315650625b  4+-+
+--R            16384a \|2   |- ---------------------- \|a
+--R                        4|                     29
+--R                        \|   72057594037927936a
+--R         *
+--R            log
+--R                                 4 +-+
+--R                 337371570183375b \|x
+--R               + 
+--R                                     +------------------------+3
+--R                                     |                       5
+--R                                 22  |  23486121858315650625b
+--R                 - 4398046511104a    |- ----------------------
+--R                                    4|                     29
+--R                                    \|   72057594037927936a
+--R     + 
+--R               4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 69615b\|b log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                4+-+     \|2 \|b \|x  + \|a
+--R       - 139230b\|b atan(-------------------)
+--R                                 4+-+
+--R                                 \|a
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                4+-+     \|2 \|b \|x  - \|a
+--R       - 139230b\|b atan(-------------------)
+--R                                 4+-+
+--R                                 \|a
+--R     + 
+--R                      +------------------------+
+--R                      |                       5
+--R               7 +-+  |  23486121858315650625b  4+-+
+--R         32768a \|2   |- ---------------------- \|a
+--R                     4|                     29
+--R                     \|   72057594037927936a
+--R      *
+--R                                +------------------------+3
+--R                                |                       5
+--R                            22  |  23486121858315650625b
+--R              4398046511104a    |- ----------------------
+--R                               4|                     29
+--R                               \|   72057594037927936a
+--R         atan(--------------------------------------------)
+--R                                          4 +-+
+--R                          337371570183375b \|x
+--R  /
+--R           7 +-+4+-+
+--R     16384a \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 1353
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R               +-------------------+
+--R         3 +-+ | 2 4         2    2
+--R   (1)  x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 1353
+r0:=2/13*x^(9/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+8/117*a*x^(9/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                              +-------------------+
+--R              6        4  +-+ | 2 4         2    2
+--R        (18b x  + 26a x )\|x \|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------
+--R                             2
+--R                       117b x  + 117a
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R              6        4  +-+
+--R        (18b x  + 26a x )\|x
+--R   (3)  ---------------------
+--R                 117
+--R                                         Type: Union(Expression(Integer),...)
+--E 345
+
+--S 346 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +-------------------+
+--R               6        4  +-+ | 2 4         2    2
+--R       (- 18b x  - 26a x )\|x \|b x  + 2a b x  + a
+--R     + 
+--R           2 8          6      2 4  +-+
+--R       (18b x  + 44a b x  + 26a x )\|x
+--R  /
+--R           2
+--R     117b x  + 117a
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-------------------+
+--R            6      4  | 2 4         2    2     2 8         6    2 4
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  -----------------------------------------------------------
+--R                              +-------------------+
+--R                          +-+ | 2 4         2    2
+--R                         \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 347
+
+)clear all
+
+--S 348 of 1353
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R               +-------------------+
+--R         2 +-+ | 2 4         2    2
+--R   (1)  x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 348
+
+--S 349 of 1353
+r0:=2/11*x^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+8/77*a*x^(7/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                              +-------------------+
+--R              5        3  +-+ | 2 4         2    2
+--R        (14b x  + 22a x )\|x \|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------
+--R                             2
+--R                        77b x  + 77a
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R              5        3  +-+
+--R        (14b x  + 22a x )\|x
+--R   (3)  ---------------------
+--R                  77
+--R                                         Type: Union(Expression(Integer),...)
+--E 350
+
+--S 351 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +-------------------+
+--R               5        3  +-+ | 2 4         2    2
+--R       (- 14b x  - 22a x )\|x \|b x  + 2a b x  + a
+--R     + 
+--R           2 7          5      2 3  +-+
+--R       (14b x  + 36a b x  + 22a x )\|x
+--R  /
+--R          2
+--R     77b x  + 77a
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-------------------+
+--R            5      3  | 2 4         2    2     2 7         5    2 3
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  -----------------------------------------------------------
+--R                              +-------------------+
+--R                          +-+ | 2 4         2    2
+--R                         \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 352
+
+)clear all
+
+--S 353 of 1353
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R   (1)  x\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 1353
+r0:=2/9*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+8/45*a*x^(5/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                              +-------------------+
+--R              4        2  +-+ | 2 4         2    2
+--R        (10b x  + 18a x )\|x \|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------
+--R                             2
+--R                        45b x  + 45a
+--R                                                    Type: Expression(Integer)
+--E 354
+
+--S 355 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4        2  +-+
+--R        (10b x  + 18a x )\|x
+--R   (3)  ---------------------
+--R                  45
+--R                                         Type: Union(Expression(Integer),...)
+--E 355
+
+--S 356 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +-------------------+
+--R               4        2  +-+ | 2 4         2    2
+--R       (- 10b x  - 18a x )\|x \|b x  + 2a b x  + a
+--R     + 
+--R           2 6          4      2 2  +-+
+--R       (10b x  + 28a b x  + 18a x )\|x
+--R  /
+--R          2
+--R     45b x  + 45a
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-------------------+
+--R            4      2  | 2 4         2    2     2 6         4    2 2
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  -----------------------------------------------------------
+--R                              +-------------------+
+--R                          +-+ | 2 4         2    2
+--R                         \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 1353
+t0:=x^(1/2)*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R             +-------------------+
+--R         +-+ | 2 4         2    2
+--R   (1)  \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 1353
+r0:=2/7*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+8/21*a*x^(3/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                            +-------------------+
+--R             3          +-+ | 2 4         2    2
+--R        (6b x  + 14a x)\|x \|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------
+--R                            2
+--R                       21b x  + 21a
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3          +-+
+--R        (6b x  + 14a x)\|x
+--R   (3)  -------------------
+--R                 21
+--R                                         Type: Union(Expression(Integer),...)
+--E 360
+
+--S 361 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +-------------------+
+--R          3          +-+ | 2 4         2    2       2 5          3      2   +-+
+--R   (- 6b x  - 14a x)\|x \|b x  + 2a b x  + a   + (6b x  + 20a b x  + 14a x)\|x
+--R   ----------------------------------------------------------------------------
+--R                                        2
+--R                                   21b x  + 21a
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R            3        | 2 4         2    2     2 5         3    2
+--R        (b x  + a x)\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  ---------------------------------------------------------
+--R                             +-------------------+
+--R                         +-+ | 2 4         2    2
+--R                        \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 362
+
+)clear all
+
+--S 363 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^(1/2)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                  +-+
+--R                 \|x
+--R                                                    Type: Expression(Integer)
+--E 363
+
+--S 364 of 1353
+r0:=2/5*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+8/5*a*sqrt(x)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                          +-------------------+
+--R             2        +-+ | 2 4         2    2
+--R        (2b x  + 10a)\|x \|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------
+--R                           2
+--R                       5b x  + 5a
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2        +-+
+--R        (2b x  + 10a)\|x
+--R   (3)  -----------------
+--R                5
+--R                                         Type: Union(Expression(Integer),...)
+--E 365
+
+--S 366 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +-------------------+
+--R          2        +-+ | 2 4         2    2       2 4          2      2  +-+
+--R   (- 2b x  - 10a)\|x \|b x  + 2a b x  + a   + (2b x  + 12a b x  + 10a )\|x
+--R   -------------------------------------------------------------------------
+--R                                       2
+--R                                   5b x  + 5a
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                           +-------------------+
+--R                       +-+ | 2 4         2    2
+--R                      \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 367
+
+)clear all
+
+--S 368 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^(3/2)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   +-+
+--R                 x\|x
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 1353
+r0:=2/3*sqrt(a^2+2*a*b*x^2+b^2*x^4)/sqrt(x)-8/3*a*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/((a+b*x^2)*sqrt(x))
+--R 
+--R
+--R                     +-------------------+
+--R             2       | 2 4         2    2
+--R        (2b x  - 6a)\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------
+--R                      2       +-+
+--R                 (3b x  + 3a)\|x
+--R                                                    Type: Expression(Integer)
+--E 369
+
+--S 370 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2
+--R        2b x  - 6a
+--R   (3)  ----------
+--R             +-+
+--R           3\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 370
+
+--S 371 of 1353
+m0:=a0-r0
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2      2 4         2     2
+--R        (- 2b x  + 6a)\|b x  + 2a b x  + a   + 2b x  - 4a b x  - 6a
+--R   (4)  ------------------------------------------------------------
+--R                                   2       +-+
+--R                              (3b x  + 3a)\|x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                            +-------------------+
+--R                        +-+ | 2 4         2    2
+--R                      x\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^(5/2)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                 2 +-+
+--R                x \|x
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 1353
+r0:=2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^(3/2)-8/3*a*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(x^(3/2)*(a+b*x^2))
+--R 
+--R
+--R                     +-------------------+
+--R             2       | 2 4         2    2
+--R        (6b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------
+--R                     3         +-+
+--R                (3b x  + 3a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2
+--R        6b x  - 2a
+--R   (3)  ----------
+--R             +-+
+--R          3x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 375
+
+--S 376 of 1353
+m0:=a0-r0
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2      2 4         2     2
+--R        (- 6b x  + 2a)\|b x  + 2a b x  + a   + 6b x  + 4a b x  - 2a
+--R   (4)  ------------------------------------------------------------
+--R                                  3         +-+
+--R                             (3b x  + 3a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                            +-------------------+
+--R                      2 +-+ | 2 4         2    2
+--R                     x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 377
+
+)clear all
+
+--S 378 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^(7/2)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                 3 +-+
+--R                x \|x
+--R                                                    Type: Expression(Integer)
+--E 378
+
+--S 379 of 1353
+r0:=-2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^(5/2)+8/5*a*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(x^(5/2)*(a+b*x^2))
+--R 
+--R
+--R                        +-------------------+
+--R                2       | 2 4         2    2
+--R        (- 10b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                      4       2  +-+
+--R                 (5b x  + 5a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R        - 10b x  - 2a
+--R   (3)  -------------
+--R             2 +-+
+--R           5x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 380
+
+--S 381 of 1353
+m0:=a0-r0
+--R 
+--R
+--R                      +-------------------+
+--R              2       | 2 4         2    2       2 4          2     2
+--R        (10b x  + 2a)\|b x  + 2a b x  + a   - 10b x  - 12a b x  - 2a
+--R   (4)  -------------------------------------------------------------
+--R                                  4       2  +-+
+--R                             (5b x  + 5a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2     2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                            +-------------------+
+--R                      3 +-+ | 2 4         2    2
+--R                     x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 382
+
+)clear all
+
+--S 383 of 1353
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                    +-------------------+
+--R          2 7         5    2 3  +-+ | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 1353
+r0:=2/21*x^(9/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+64/1547*a^2*x^(9/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/13923*a^3*x^(9/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+8/119*a*x^(9/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R                                                        +-------------------+
+--R         3 10          2 8        2   6        3 4  +-+ | 2 4         2    2
+--R   (1326b x   + 4914a b x  + 6426a b x  + 3094a x )\|x \|b x  + 2a b x  + a
+--R   --------------------------------------------------------------------------
+--R                                       2
+--R                               13923b x  + 13923a
+--R                                                    Type: Expression(Integer)
+--E 384
+
+--S 385 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3 10          2 8        2   6        3 4  +-+
+--R        (1326b x   + 4914a b x  + 6426a b x  + 3094a x )\|x
+--R   (3)  ----------------------------------------------------
+--R                                13923
+--R                                         Type: Union(Expression(Integer),...)
+--E 385
+
+--S 386 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3 10          2 8        2   6        3 4  +-+
+--R         (- 1326b x   - 4914a b x  - 6426a b x  - 3094a x )\|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             4 12          3 10         2 2 8        3   6        4 4  +-+
+--R       (1326b x   + 6240a b x   + 11340a b x  + 9520a b x  + 3094a x )\|x
+--R  /
+--R             2
+--R     13923b x  + 13923a
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                          +-------------------+
+--R         3 10       2 8     2   6    3 4  | 2 4         2    2     4 12
+--R       (b x   + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 10     2 2 8     3   6    4 4
+--R       - 4a b x   - 6a b x  - 4a b x  - a x
+--R  /
+--R          +-------------------+
+--R      +-+ | 2 4         2    2
+--R     \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 1353
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                    +-------------------+
+--R          2 6         4    2 2  +-+ | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 1353
+r0:=2/19*x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+64/1045*a^2*x^(7/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/7315*a^3*x^(7/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+8/95*a*x^(7/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R                                                      +-------------------+
+--R        3 9          2 7        2   5        3 3  +-+ | 2 4         2    2
+--R   (770b x  + 2926a b x  + 3990a b x  + 2090a x )\|x \|b x  + 2a b x  + a
+--R   ------------------------------------------------------------------------
+--R                                      2
+--R                               7315b x  + 7315a
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 9          2 7        2   5        3 3  +-+
+--R        (770b x  + 2926a b x  + 3990a b x  + 2090a x )\|x
+--R   (3)  --------------------------------------------------
+--R                               7315
+--R                                         Type: Union(Expression(Integer),...)
+--E 390
+
+--S 391 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                3 9          2 7        2   5        3 3  +-+
+--R         (- 770b x  - 2926a b x  - 3990a b x  - 2090a x )\|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 11          3 9        2 2 7        3   5        4 3  +-+
+--R       (770b x   + 3696a b x  + 6916a b x  + 6080a b x  + 2090a x )\|x
+--R  /
+--R            2
+--R     7315b x  + 7315a
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                         +-------------------+
+--R         3 9       2 7     2   5    3 3  | 2 4         2    2     4 11       3 9
+--R       (b x  + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 7     3   5    4 3
+--R       - 6a b x  - 4a b x  - a x
+--R  /
+--R          +-------------------+
+--R      +-+ | 2 4         2    2
+--R     \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 392
+
+)clear all
+
+--S 393 of 1353
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                   +-------------------+
+--R          2 5         3    2   +-+ | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 393
+
+--S 394 of 1353
+r0:=2/17*x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+64/663*a^2*x^(5/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/3315*a^3*x^(5/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+24/221*a*x^(5/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R                                                      +-------------------+
+--R        3 8          2 6        2   4        3 2  +-+ | 2 4         2    2
+--R   (390b x  + 1530a b x  + 2210a b x  + 1326a x )\|x \|b x  + 2a b x  + a
+--R   ------------------------------------------------------------------------
+--R                                      2
+--R                               3315b x  + 3315a
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 8          2 6        2   4        3 2  +-+
+--R        (390b x  + 1530a b x  + 2210a b x  + 1326a x )\|x
+--R   (3)  --------------------------------------------------
+--R                               3315
+--R                                         Type: Union(Expression(Integer),...)
+--E 395
+
+--S 396 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                3 8          2 6        2   4        3 2  +-+
+--R         (- 390b x  - 1530a b x  - 2210a b x  - 1326a x )\|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 10          3 8        2 2 6        3   4        4 2  +-+
+--R       (390b x   + 1920a b x  + 3740a b x  + 3536a b x  + 1326a x )\|x
+--R  /
+--R            2
+--R     3315b x  + 3315a
+--R                                                    Type: Expression(Integer)
+--E 396
+
+--S 397 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                         +-------------------+
+--R         3 8       2 6     2   4    3 2  | 2 4         2    2     4 10       3 8
+--R       (b x  + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   4    4 2
+--R       - 6a b x  - 4a b x  - a x
+--R  /
+--R          +-------------------+
+--R      +-+ | 2 4         2    2
+--R     \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 397
+
+)clear all
+
+--S 398 of 1353
+t0:=x^(1/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 4         2    2  +-+ | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 1353
+r0:=2/15*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+64/385*a^2*x^(3/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/1155*a^3*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+8/55*a*x^(3/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                       +-------------------+
+--R             3 7         2 5       2   3       3   +-+ | 2 4         2    2
+--R        (154b x  + 630a b x  + 990a b x  + 770a x)\|x \|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------------------------------
+--R                                         2
+--R                                  1155b x  + 1155a
+--R                                                    Type: Expression(Integer)
+--E 399
+
+--S 400 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 7         2 5       2   3       3   +-+
+--R        (154b x  + 630a b x  + 990a b x  + 770a x)\|x
+--R   (3)  ----------------------------------------------
+--R                             1155
+--R                                         Type: Union(Expression(Integer),...)
+--E 400
+
+--S 401 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                        +-------------------+
+--R              3 7         2 5       2   3       3   +-+ | 2 4         2    2
+--R       (- 154b x  - 630a b x  - 990a b x  - 770a x)\|x \|b x  + 2a b x  + a
+--R     + 
+--R            4 9         3 7        2 2 5        3   3       4   +-+
+--R       (154b x  + 784a b x  + 1620a b x  + 1760a b x  + 770a x)\|x
+--R  /
+--R            2
+--R     1155b x  + 1155a
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                        +-------------------+
+--R         3 7       2 5     2   3    3   | 2 4         2    2     4 9       3 7
+--R       (b x  + 3a b x  + 3a b x  + a x)\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 5     3   3    4
+--R       - 6a b x  - 4a b x  - a x
+--R  /
+--R          +-------------------+
+--R      +-+ | 2 4         2    2
+--R     \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(1/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             +-+
+--R                            \|x
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 1353
+r0:=2/13*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x)+64/195*a^2*sqrt(x)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/195*a^3*sqrt(x)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+8/39*a*(a+b*x^2)*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                     +-------------------+
+--R            3 6         2 4       2   2       3  +-+ | 2 4         2    2
+--R        (30b x  + 130a b x  + 234a b x  + 390a )\|x \|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------------
+--R                                        2
+--R                                  195b x  + 195a
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 6         2 4       2   2       3  +-+
+--R        (30b x  + 130a b x  + 234a b x  + 390a )\|x
+--R   (3)  --------------------------------------------
+--R                             195
+--R                                         Type: Union(Expression(Integer),...)
+--E 405
+
+--S 406 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +-------------------+
+--R             3 6         2 4       2   2       3  +-+ | 2 4         2    2
+--R       (- 30b x  - 130a b x  - 234a b x  - 390a )\|x \|b x  + 2a b x  + a
+--R     + 
+--R           4 8         3 6       2 2 4       3   2       4  +-+
+--R       (30b x  + 160a b x  + 364a b x  + 624a b x  + 390a )\|x
+--R  /
+--R           2
+--R     195b x  + 195a
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R          +-------------------+
+--R      +-+ | 2 4         2    2
+--R     \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 407
+
+)clear all
+
+--S 408 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(3/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             +-+
+--R                           x\|x
+--R                                                    Type: Expression(Integer)
+--E 408
+
+--S 409 of 1353
+r0:=2/11*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/sqrt(x)+192/77*a*b*x^(3/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/77*a^2*b*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)-24/11*a*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/sqrt(x)
+--R 
+--R
+--R                                                +-------------------+
+--R            3 6        2 4       2   2       3  | 2 4         2    2
+--R        (14b x  + 66a b x  + 154a b x  - 154a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------------
+--R                                    2        +-+
+--R                              (77b x  + 77a)\|x
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 6        2 4       2   2       3
+--R        14b x  + 66a b x  + 154a b x  - 154a
+--R   (3)  -------------------------------------
+--R                           +-+
+--R                        77\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 410
+
+--S 411 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +-------------------+
+--R             3 6        2 4       2   2       3  | 2 4         2    2       4 8
+--R       (- 14b x  - 66a b x  - 154a b x  + 154a )\|b x  + 2a b x  + a   + 14b x
+--R     + 
+--R            3 6       2 2 4       4
+--R       80a b x  + 220a b x  - 154a
+--R  /
+--R           2        +-+
+--R     (77b x  + 77a)\|x
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R           +-------------------+
+--R       +-+ | 2 4         2    2
+--R     x\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 412
+
+)clear all
+
+--S 413 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(5/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                            2 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 1353
+r0:=22/3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(3/2)-64/9*b^2*x^(5/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)-256/45*a*b^2*x^(5/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)-8*a*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^(3/2)
+--R 
+--R
+--R                                               +-------------------+
+--R            3 6        2 4       2   2      3  | 2 4         2    2
+--R        (10b x  + 54a b x  + 270a b x  - 30a )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------
+--R                                  3          +-+
+--R                            (45b x  + 45a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 414
+
+--S 415 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 6        2 4       2   2      3
+--R        10b x  + 54a b x  + 270a b x  - 30a
+--R   (3)  ------------------------------------
+--R                           +-+
+--R                       45x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 415
+
+--S 416 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                +-------------------+
+--R             3 6        2 4       2   2      3  | 2 4         2    2       4 8
+--R       (- 10b x  - 54a b x  - 270a b x  + 30a )\|b x  + 2a b x  + a   + 10b x
+--R     + 
+--R            3 6       2 2 4       3   2      4
+--R       64a b x  + 324a b x  + 240a b x  - 30a
+--R  /
+--R           3          +-+
+--R     (45b x  + 45a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R            +-------------------+
+--R      2 +-+ | 2 4         2    2
+--R     x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(7/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                            3 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 1353
+r0:=-26/5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(5/2)+192/35*b^2*x^(3/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/35*a*b^2*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+24/5*a*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^(5/2)
+--R 
+--R
+--R                                               +-------------------+
+--R            3 6        2 4       2   2      3  | 2 4         2    2
+--R        (10b x  + 70a b x  - 210a b x  - 14a )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------
+--R                                  4        2  +-+
+--R                            (35b x  + 35a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 6        2 4       2   2      3
+--R        10b x  + 70a b x  - 210a b x  - 14a
+--R   (3)  ------------------------------------
+--R                         2 +-+
+--R                      35x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 420
+
+--S 421 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                +-------------------+
+--R             3 6        2 4       2   2      3  | 2 4         2    2       4 8
+--R       (- 10b x  - 70a b x  + 210a b x  + 14a )\|b x  + 2a b x  + a   + 10b x
+--R     + 
+--R            3 6       2 2 4       3   2      4
+--R       80a b x  - 140a b x  - 224a b x  - 14a
+--R  /
+--R           4        2  +-+
+--R     (35b x  + 35a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 6       2 4     2   2    3  | 2 4         2    2     4 8       3 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x  - 4a b x
+--R     + 
+--R           2 2 4     3   2    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R            +-------------------+
+--R      3 +-+ | 2 4         2    2
+--R     x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 422
+
+)clear all
+
+--S 423 of 1353
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 11       3 9     2 2 7     3   5    4 3  +-+ | 2 4         2    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 423
+
+--S 424 of 1353
+r0:=128/3045*a^2*x^(9/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/145*a*x^(9/2)*_
+   (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/29*x^(9/2)*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)+4096/224315*a^4*x^(9/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+   16384/2018835*a^5*x^(9/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+   512/17255*a^3*x^(9/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R                5 14            4 12           2 3 10           3 2 8
+--R         139230b x   + 807534a b x   + 1922700a b x   + 2375100a b x
+--R       + 
+--R                 4   6          5 4
+--R         1552950a b x  + 448630a x
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R  /
+--R               2
+--R     2018835b x  + 2018835a
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                5 14            4 12           2 3 10           3 2 8
+--R         139230b x   + 807534a b x   + 1922700a b x   + 2375100a b x
+--R       + 
+--R                 4   6          5 4
+--R         1552950a b x  + 448630a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     2018835
+--R                                         Type: Union(Expression(Integer),...)
+--E 425
+
+--S 426 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    5 14            4 12           2 3 10           3 2 8
+--R           - 139230b x   - 807534a b x   - 1922700a b x   - 2375100a b x
+--R         + 
+--R                     4   6          5 4
+--R           - 1552950a b x  - 448630a x
+--R      *
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R         \|x \|b x  + 2a b x  + a
+--R     + 
+--R                  6 16            5 14           2 4 12           3 3 10
+--R           139230b x   + 946764a b x   + 2730234a b x   + 4297800a b x
+--R         + 
+--R                   4 2 8           5   6          6 4
+--R           3928050a b x  + 2001580a b x  + 448630a x
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R               2
+--R     2018835b x  + 2018835a
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 14       4 12      2 3 10      3 2 8     4   6    5 4
+--R         (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 16       5 14      2 4 12      3 3 10      4 2 8     5   6    6 4
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x  - 6a b x  - a x
+--R  /
+--R          +-------------------+
+--R      +-+ | 2 4         2    2
+--R     \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 427
+
+)clear all
+
+--S 428 of 1353
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 10       3 8     2 2 6     3   4    4 2  +-+ | 2 4         2    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 1353
+r0:=640/11799*a^2*x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+40/621*a*x^(7/2)*_
+   (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/27*x^(7/2)*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)+4096/129789*a^4*x^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+   16384/908523*a^5*x^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+   512/11799*a^3*x^(7/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R               5 13            4 11          2 3 9           3 2 7
+--R         67298b x   + 395010a b x   + 956340a b x  + 1211364a b x
+--R       + 
+--R                4   5          5 3
+--R         825930a b x  + 259578a x
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     908523b x  + 908523a
+--R                                                    Type: Expression(Integer)
+--E 429
+
+--S 430 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               5 13            4 11          2 3 9           3 2 7
+--R         67298b x   + 395010a b x   + 956340a b x  + 1211364a b x
+--R       + 
+--R                4   5          5 3
+--R         825930a b x  + 259578a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     908523
+--R                                         Type: Union(Expression(Integer),...)
+--E 430
+
+--S 431 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 13            4 11          2 3 9           3 2 7
+--R           - 67298b x   - 395010a b x   - 956340a b x  - 1211364a b x
+--R         + 
+--R                    4   5          5 3
+--R           - 825930a b x  - 259578a x
+--R      *
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R         \|x \|b x  + 2a b x  + a
+--R     + 
+--R                 6 15            5 13           2 4 11           3 3 9
+--R           67298b x   + 462308a b x   + 1351350a b x   + 2167704a b x
+--R         + 
+--R                   4 2 7           5   5          6 3
+--R           2037294a b x  + 1085508a b x  + 259578a x
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R              2
+--R     908523b x  + 908523a
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 13       4 11      2 3 9      3 2 7     4   5    5 3
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 15       5 13      2 4 11      3 3 9      4 2 7     5   5    6 3
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a x
+--R  /
+--R          +-------------------+
+--R      +-+ | 2 4         2    2
+--R     \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 1353
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 9       3 7     2 2 5     3   3    4   +-+ | 2 4         2    2
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 1353
+r0:=128/1785*a^2*x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/105*a*x^(5/2)*_
+   (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/25*x^(5/2)*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)+4096/69615*a^4*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+   16384/348075*a^5*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+   512/7735*a^3*x^(5/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R               5 12            4 10          2 3 8          3 2 6          4   4
+--R         27846b x   + 165750a b x   + 409500a b x  + 535500a b x  + 386750a b x
+--R       + 
+--R                5 2
+--R         139230a x
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     348075b x  + 348075a
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               5 12            4 10          2 3 8          3 2 6          4   4
+--R         27846b x   + 165750a b x   + 409500a b x  + 535500a b x  + 386750a b x
+--R       + 
+--R                5 2
+--R         139230a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     348075
+--R                                         Type: Union(Expression(Integer),...)
+--E 435
+
+--S 436 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 12            4 10          2 3 8          3 2 6
+--R           - 27846b x   - 165750a b x   - 409500a b x  - 535500a b x
+--R         + 
+--R                    4   4          5 2
+--R           - 386750a b x  - 139230a x
+--R      *
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R         \|x \|b x  + 2a b x  + a
+--R     + 
+--R                 6 14            5 12          2 4 10          3 3 8
+--R           27846b x   + 193596a b x   + 575250a b x   + 945000a b x
+--R         + 
+--R                  4 2 6          5   4          6 2
+--R           922250a b x  + 525980a b x  + 139230a x
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R              2
+--R     348075b x  + 348075a
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 12       4 10      2 3 8      3 2 6     4   4    5 2
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 14       5 12      2 4 10      3 3 8      4 2 6     5   4    6 2
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a x
+--R  /
+--R          +-------------------+
+--R      +-+ | 2 4         2    2
+--R     \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 437
+
+)clear all
+
+--S 438 of 1353
+t0:=x^(1/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                      +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  +-+ | 2 4         2    2
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 438
+
+--S 439 of 1353
+r0:=128/1311*a^2*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+40/437*a*x^(3/2)*_
+   (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/23*x^(3/2)*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)+4096/33649*a^4*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+   16384/100947*a^5*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+   512/4807*a^3*x^(3/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R              5 11           4 9          2 3 7          3 2 5          4   3
+--R         8778b x   + 53130a b x  + 134596a b x  + 183540a b x  + 144210a b x
+--R       + 
+--R               5
+--R         67298a x
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     100947b x  + 100947a
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              5 11           4 9          2 3 7          3 2 5          4   3
+--R         8778b x   + 53130a b x  + 134596a b x  + 183540a b x  + 144210a b x
+--R       + 
+--R               5
+--R         67298a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     100947
+--R                                         Type: Union(Expression(Integer),...)
+--E 440
+
+--S 441 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 11           4 9          2 3 7          3 2 5
+--R           - 8778b x   - 53130a b x  - 134596a b x  - 183540a b x
+--R         + 
+--R                    4   3         5
+--R           - 144210a b x  - 67298a x
+--R      *
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R         \|x \|b x  + 2a b x  + a
+--R     + 
+--R                6 13           5 11          2 4 9          3 3 7          4 2 5
+--R           8778b x   + 61908a b x   + 187726a b x  + 318136a b x  + 327750a b x
+--R         + 
+--R                  5   3         6
+--R           211508a b x  + 67298a x
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R              2
+--R     100947b x  + 100947a
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 11       4 9      2 3 7      3 2 5     4   3    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a x)
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 13       5 11      2 4 9      3 3 7      4 2 5     5   3    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a x
+--R  /
+--R          +-------------------+
+--R      +-+ | 2 4         2    2
+--R     \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 442
+
+)clear all
+
+--S 443 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^(1/2)
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       +-+
+--R                                      \|x
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 1353
+r0:=640/4641*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x)+40/357*a*(a+b*x^2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x)+2/21*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)*_
+   sqrt(x)+4096/13923*a^4*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+   16384/13923*a^5*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+   2560/13923*a^3*(a+b*x^2)*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R              5 10          4 8         2 3 6         3 2 4         4   2
+--R         1326b x   + 8190a b x  + 21420a b x  + 30940a b x  + 27846a b x
+--R       + 
+--R               5
+--R         27846a
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R  /
+--R             2
+--R     13923b x  + 13923a
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              5 10          4 8         2 3 6         3 2 4         4   2
+--R         1326b x   + 8190a b x  + 21420a b x  + 30940a b x  + 27846a b x
+--R       + 
+--R               5
+--R         27846a
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     13923
+--R                                         Type: Union(Expression(Integer),...)
+--E 445
+
+--S 446 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 10          4 8         2 3 6         3 2 4         4   2
+--R           - 1326b x   - 8190a b x  - 21420a b x  - 30940a b x  - 27846a b x
+--R         + 
+--R                   5
+--R           - 27846a
+--R      *
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R         \|x \|b x  + 2a b x  + a
+--R     + 
+--R                6 12          5 10         2 4 8         3 3 6         4 2 4
+--R           1326b x   + 9516a b x   + 29610a b x  + 52360a b x  + 58786a b x
+--R         + 
+--R                 5   2         6
+--R           55692a b x  + 27846a
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R             2
+--R     13923b x  + 13923a
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R          +-------------------+
+--R      +-+ | 2 4         2    2
+--R     \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^(3/2)
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       +-+
+--R                                     x\|x
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 1353
+r0:=128/57*a*b*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)-40/19*a*(a+b*x^2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/sqrt(x)+2/19*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)/sqrt(x)+4096/1463*a^3*b*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)+16384/4389*a^4*b*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)+512/209*a^2*b*x^(3/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R            5 10          4 8        2 3 6         3 2 4         4   2        5
+--R       (462b x   + 2926a b x  + 7980a b x  + 12540a b x  + 14630a b x  - 8778a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             2          +-+
+--R     (4389b x  + 4389a)\|x
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       5 10          4 8        2 3 6         3 2 4         4   2        5
+--R   462b x   + 2926a b x  + 7980a b x  + 12540a b x  + 14630a b x  - 8778a
+--R   -----------------------------------------------------------------------
+--R                                        +-+
+--R                                   4389\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 450
+
+--S 451 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 10          4 8        2 3 6         3 2 4         4   2
+--R           - 462b x   - 2926a b x  - 7980a b x  - 12540a b x  - 14630a b x
+--R         + 
+--R                5
+--R           8778a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R           6 12          5 10         2 4 8         3 3 6         4 2 4
+--R       462b x   + 3388a b x   + 10906a b x  + 20520a b x  + 27170a b x
+--R     + 
+--R            5   2        6
+--R       5852a b x  - 8778a
+--R  /
+--R             2          +-+
+--R     (4389b x  + 4389a)\|x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R           +-------------------+
+--R       +-+ | 2 4         2    2
+--R     x\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 452
+
+)clear all
+
+--S 453 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^(5/2)
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                      2 +-+
+--R                                     x \|x
+--R                                                    Type: Expression(Integer)
+--E 453
+
+--S 454 of 1353
+r0:=-640/51*b^2*x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)-40/3*a*(a+b*x^2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(3/2)+38/3*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)/x^(3/2)-20480/1989*a^2*b^2*x^(5/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)-16384/1989*a^3*b^2*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)-2560/221*a*b^2*x^(5/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R            5 10          4 8        2 3 6        3 2 4         4   2        5
+--R       (234b x   + 1530a b x  + 4420a b x  + 7956a b x  + 19890a b x  - 1326a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             3            +-+
+--R     (1989b x  + 1989a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5 10          4 8        2 3 6        3 2 4         4   2        5
+--R        234b x   + 1530a b x  + 4420a b x  + 7956a b x  + 19890a b x  - 1326a
+--R   (3)  ----------------------------------------------------------------------
+--R                                             +-+
+--R                                       1989x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 455
+
+--S 456 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 10          4 8        2 3 6        3 2 4         4   2
+--R           - 234b x   - 1530a b x  - 4420a b x  - 7956a b x  - 19890a b x
+--R         + 
+--R                5
+--R           1326a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R           6 12          5 10        2 4 8         3 3 6         4 2 4
+--R       234b x   + 1764a b x   + 5950a b x  + 12376a b x  + 27846a b x
+--R     + 
+--R             5   2        6
+--R       18564a b x  - 1326a
+--R  /
+--R             3            +-+
+--R     (1989b x  + 1989a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R            +-------------------+
+--R      2 +-+ | 2 4         2    2
+--R     x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 457
+
+)clear all
+
+--S 458 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^(7/2)
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                      3 +-+
+--R                                     x \|x
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 1353
+r0:=128/15*b^2*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8*a*(a+b*x^2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(5/2)-42/5*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)/x^(5/2)+4096/385*a^2*b^2*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)+16384/1155*a^3*b^2*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)+512/55*a*b^2*x^(3/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R            5 10          4 8        2 3 6        3 2 4         4   2       5
+--R       (154b x   + 1050a b x  + 3300a b x  + 7700a b x  - 11550a b x  - 462a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             4          2  +-+
+--R     (1155b x  + 1155a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5 10          4 8        2 3 6        3 2 4         4   2       5
+--R        154b x   + 1050a b x  + 3300a b x  + 7700a b x  - 11550a b x  - 462a
+--R   (3)  ---------------------------------------------------------------------
+--R                                           2 +-+
+--R                                      1155x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 460
+
+--S 461 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 10          4 8        2 3 6        3 2 4         4   2
+--R             - 154b x   - 1050a b x  - 3300a b x  - 7700a b x  + 11550a b x
+--R           + 
+--R                 5
+--R             462a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R           6 12          5 10        2 4 8         3 3 6        4 2 4
+--R       154b x   + 1204a b x   + 4350a b x  + 11000a b x  - 3850a b x
+--R     + 
+--R               5   2       6
+--R       - 12012a b x  - 462a
+--R  /
+--R             4          2  +-+
+--R     (1155b x  + 1155a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R         (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       - b x   - 6a b x   - 15a b x  - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R            +-------------------+
+--R      3 +-+ | 2 4         2    2
+--R     x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 1353
+t0:=x^(7/2)/sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 3 +-+
+--R                x \|x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 1353
+r0:=2/5*x^(5/2)*(a+b*x^2)/(b*sqrt(a^2+2*a*b*x^2+b^2*x^4))-a^(5/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(9/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))+a^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1/2*a^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/2*a^(5/4)*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-2*a*(a+b*x^2)*sqrt(x)/(b^2*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              2     2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5a b x  + 5a )\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                2     2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5a b x  - 5a )\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2      2 4+-+     \|2 \|b \|x  + \|a
+--R       (10a b x  + 10a )\|a atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2      2 4+-+     \|2 \|b \|x  - \|a
+--R       (10a b x  + 10a )\|a atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R          2 4          2      2  +-+4+-+ +-+
+--R       (4b x  - 16a b x  - 20a )\|2 \|b \|x
+--R  /
+--R                  +-------------------+
+--R        2 +-+4+-+ | 2 4         2    2
+--R     10b \|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +------+                 +------+
+--R            |    5                   |    5
+--R         2  |   a         +-+     2  |   a
+--R       5b   |- ---- log(a\|x  + 2b   |- ----)
+--R           4|     9                 4|     9
+--R           \|  16b                  \|  16b
+--R     + 
+--R                                                                         +------+
+--R                                                                         |    5
+--R                                                                      2  |   a
+--R              +------+                 +------+        +------+     2b   |- ----
+--R              |    5                   |    5          |    5           4|     9
+--R           2  |   a         +-+     2  |   a        2  |   a            \|  16b
+--R       - 5b   |- ---- log(a\|x  - 2b   |- ---- - 10b   |- ---- atan(------------)
+--R             4|     9                 4|     9        4|     9            +-+
+--R             \|  16b                  \|  16b         \|  16b           a\|x
+--R     + 
+--R            2        +-+
+--R       (2b x  - 10a)\|x
+--R  /
+--R       2
+--R     5b
+--R                                         Type: Union(Expression(Integer),...)
+--E 465
+
+--S 466 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2     2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5a b x  - 5a )\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 +------+                                           +------+
+--R                 |    5       +-------------------+                 |    5
+--R          2 +-+  |   a   4+-+ | 2 4         2    2       +-+     2  |   a
+--R       10b \|2   |- ---- \|b \|b x  + 2a b x  + a  log(a\|x  + 2b   |- ----)
+--R                4|     9                                           4|     9
+--R                \|  16b                                            \|  16b
+--R     + 
+--R                   +------+                                           +------+
+--R                   |    5       +-------------------+                 |    5
+--R            2 +-+  |   a   4+-+ | 2 4         2    2       +-+     2  |   a
+--R       - 10b \|2   |- ---- \|b \|b x  + 2a b x  + a  log(a\|x  - 2b   |- ----)
+--R                  4|     9                                           4|     9
+--R                  \|  16b                                            \|  16b
+--R     + 
+--R              2     2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5a b x  + 5a )\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                    +-+4+-+ +-+   4+-+
+--R                 2      2 4+-+     \|2 \|b \|x  + \|a
+--R       (- 10a b x  - 10a )\|a atan(-------------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                    +-+4+-+ +-+   4+-+
+--R                 2      2 4+-+     \|2 \|b \|x  - \|a
+--R       (- 10a b x  - 10a )\|a atan(-------------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                                               +------+
+--R                                                               |    5
+--R                                                            2  |   a
+--R                   +------+                               2b   |- ----
+--R                   |    5       +-------------------+         4|     9
+--R            2 +-+  |   a   4+-+ | 2 4         2    2          \|  16b
+--R       - 20b \|2   |- ---- \|b \|b x  + 2a b x  + a  atan(------------)
+--R                  4|     9                                      +-+
+--R                  \|  16b                                     a\|x
+--R     + 
+--R                                 +-------------------+
+--R            2        +-+4+-+ +-+ | 2 4         2    2
+--R       (4b x  - 20a)\|2 \|b \|x \|b x  + 2a b x  + a
+--R     + 
+--R            2 4          2      2  +-+4+-+ +-+
+--R       (- 4b x  + 16a b x  + 20a )\|2 \|b \|x
+--R  /
+--R                  +-------------------+
+--R        2 +-+4+-+ | 2 4         2    2
+--R     10b \|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +-------------------+
+--R         4 | 2 4         2    2       6      4
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  --------------------------------------
+--R                        +-------------------+
+--R             2      +-+ | 2 4         2    2
+--R         (b x  + a)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 467
+
+)clear all
+
+--S 468 of 1353
+t0:=x^(5/2)/sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 2 +-+
+--R                x \|x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 468
+
+--S 469 of 1353
+r0:=2/3*x^(3/2)*(a+b*x^2)/(b*sqrt(a^2+2*a*b*x^2+b^2*x^4))+a^(3/4)*_
+   (a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(7/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-a^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   1/2*a^(3/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/2*a^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2      4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 3a)\|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              2      4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 3a)\|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                +-+4+-+ +-+   4+-+
+--R              2      4+-+3     \|2 \|b \|x  + \|a
+--R       (- 6b x  - 6a)\|a  atan(-------------------)
+--R                                       4+-+
+--R                                       \|a
+--R     + 
+--R                              +-+4+-+ +-+   4+-+
+--R            2      4+-+3     \|2 \|b \|x  - \|a          3         +-+4+-+3 +-+
+--R     (- 6b x  - 6a)\|a  atan(-------------------) + (4b x  + 4a x)\|2 \|b  \|x
+--R                                     4+-+
+--R                                     \|a
+--R  /
+--R                 +-------------------+
+--R        +-+4+-+3 | 2 4         2    2
+--R     6b\|2 \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +------+                  +------+3
+--R             |    3                    |    3
+--R             |   a        2 +-+     5  |   a
+--R       - 3b  |- ---- log(a \|x  + 8b   |- ---- )
+--R            4|     7                  4|     7
+--R            \|  16b                   \|  16b
+--R     + 
+--R                                                                      +------+3
+--R                                                                      |    3
+--R                                                                   5  |   a
+--R           +------+                  +------+3      +------+     8b   |- ----
+--R           |    3                    |    3         |    3           4|     7
+--R           |   a        2 +-+     5  |   a          |   a            \|  16b
+--R       3b  |- ---- log(a \|x  - 8b   |- ----  - 6b  |- ---- atan(-------------)
+--R          4|     7                  4|     7       4|     7           2 +-+
+--R          \|  16b                   \|  16b        \|  16b           a \|x
+--R     + 
+--R          +-+
+--R       2x\|x
+--R  /
+--R     3b
+--R                                         Type: Union(Expression(Integer),...)
+--E 470
+
+--S 471 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2      4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 3a)\|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 +------+                                             +------+3
+--R                 |    3        +-------------------+                  |    3
+--R            +-+  |   a   4+-+3 | 2 4         2    2      2 +-+     5  |   a
+--R       - 6b\|2   |- ---- \|b  \|b x  + 2a b x  + a  log(a \|x  + 8b   |- ---- )
+--R                4|     7                                             4|     7
+--R                \|  16b                                              \|  16b
+--R     + 
+--R               +------+                                             +------+3
+--R               |    3        +-------------------+                  |    3
+--R          +-+  |   a   4+-+3 | 2 4         2    2      2 +-+     5  |   a
+--R       6b\|2   |- ---- \|b  \|b x  + 2a b x  + a  log(a \|x  - 8b   |- ---- )
+--R              4|     7                                             4|     7
+--R              \|  16b                                              \|  16b
+--R     + 
+--R            2      4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 3a)\|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                              +-+4+-+ +-+   4+-+
+--R            2      4+-+3     \|2 \|b \|x  + \|a
+--R       (6b x  + 6a)\|a  atan(-------------------)
+--R                                     4+-+
+--R                                     \|a
+--R     + 
+--R                              +-+4+-+ +-+   4+-+
+--R            2      4+-+3     \|2 \|b \|x  - \|a
+--R       (6b x  + 6a)\|a  atan(-------------------)
+--R                                     4+-+
+--R                                     \|a
+--R     + 
+--R                                                               +------+3
+--R                                                               |    3
+--R                                                            5  |   a
+--R                  +------+                                8b   |- ----
+--R                  |    3        +-------------------+         4|     7
+--R             +-+  |   a   4+-+3 | 2 4         2    2          \|  16b
+--R       - 12b\|2   |- ---- \|b  \|b x  + 2a b x  + a  atan(-------------)
+--R                 4|     7                                      2 +-+
+--R                 \|  16b                                      a \|x
+--R     + 
+--R                       +-------------------+
+--R          +-+4+-+3 +-+ | 2 4         2    2           3         +-+4+-+3 +-+
+--R       4x\|2 \|b  \|x \|b x  + 2a b x  + a   + (- 4b x  - 4a x)\|2 \|b  \|x
+--R  /
+--R                 +-------------------+
+--R        +-+4+-+3 | 2 4         2    2
+--R     6b\|2 \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +-------------------+
+--R         3 | 2 4         2    2       5      3
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  --------------------------------------
+--R                        +-------------------+
+--R             2      +-+ | 2 4         2    2
+--R         (b x  + a)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 472
+
+)clear all
+
+--S 473 of 1353
+t0:=x^(3/2)/sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                   +-+
+--R                 x\|x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 1353
+r0:=a^(1/4)*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(5/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-a^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   1/2*a^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1/2*a^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+2*(a+b*x^2)*sqrt(x)/_
+   (b*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             2     4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2     4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R              2      4+-+     \|2 \|b \|x  + \|a
+--R       (- 2b x  - 2a)\|a atan(-------------------)
+--R                                      4+-+
+--R                                      \|a
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R              2      4+-+     \|2 \|b \|x  - \|a          2       +-+4+-+ +-+
+--R       (- 2b x  - 2a)\|a atan(-------------------) + (4b x  + 4a)\|2 \|b \|x
+--R                                      4+-+
+--R                                      \|a
+--R  /
+--R                +-------------------+
+--R        +-+4+-+ | 2 4         2    2
+--R     2b\|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 474
+
+--S 475 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +------+               +------+     +------+               +------+
+--R            |    a       +-+       |    a       |    a       +-+       |    a
+--R       - b  |- ---- log(\|x  + 2b  |- ---- + b  |- ---- log(\|x  - 2b  |- ----)
+--R           4|     5               4|     5     4|     5               4|     5
+--R           \|  16b                \|  16b      \|  16b                \|  16b
+--R     + 
+--R                            +------+
+--R                            |    a
+--R                        2b  |- ----
+--R           +------+        4|     5
+--R           |    a          \|  16b      +-+
+--R       2b  |- ---- atan(----------- + 2\|x
+--R          4|     5           +-+
+--R          \|  16b           \|x
+--R  /
+--R     b
+--R                                         Type: Union(Expression(Integer),...)
+--E 475
+
+--S 476 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2     4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 +------+     +-------------------+               +------+
+--R            +-+  |    a  4+-+ | 2 4         2    2      +-+       |    a
+--R       - 2b\|2   |- ---- \|b \|b x  + 2a b x  + a  log(\|x  + 2b  |- ----)
+--R                4|     5                                         4|     5
+--R                \|  16b                                          \|  16b
+--R     + 
+--R               +------+     +-------------------+               +------+
+--R          +-+  |    a  4+-+ | 2 4         2    2      +-+       |    a
+--R       2b\|2   |- ---- \|b \|b x  + 2a b x  + a  log(\|x  - 2b  |- ----)
+--R              4|     5                                         4|     5
+--R              \|  16b                                          \|  16b
+--R     + 
+--R             2     4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R            2      4+-+     \|2 \|b \|x  + \|a
+--R       (2b x  + 2a)\|a atan(-------------------)
+--R                                    4+-+
+--R                                    \|a
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R            2      4+-+     \|2 \|b \|x  - \|a
+--R       (2b x  + 2a)\|a atan(-------------------)
+--R                                    4+-+
+--R                                    \|a
+--R     + 
+--R                                                          +------+
+--R                                                          |    a
+--R                                                      2b  |- ----
+--R               +------+     +-------------------+        4|     5
+--R          +-+  |    a  4+-+ | 2 4         2    2         \|  16b
+--R       4b\|2   |- ---- \|b \|b x  + 2a b x  + a  atan(-----------)
+--R              4|     5                                     +-+
+--R              \|  16b                                     \|x
+--R     + 
+--R                     +-------------------+
+--R         +-+4+-+ +-+ | 2 4         2    2           2       +-+4+-+ +-+
+--R       4\|2 \|b \|x \|b x  + 2a b x  + a   + (- 4b x  - 4a)\|2 \|b \|x
+--R  /
+--R                +-------------------+
+--R        +-+4+-+ | 2 4         2    2
+--R     2b\|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +-------------------+
+--R         2 | 2 4         2    2       4      2
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  --------------------------------------
+--R                        +-------------------+
+--R             2      +-+ | 2 4         2    2
+--R         (b x  + a)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 1353
+t0:=sqrt(x)/sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  +-+
+--R                 \|x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 1353
+r0:=-(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(1/4)*b^(3/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(1/4)*b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   1/2*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(1/4)*b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1/2*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R  /
+--R                    +-------------------+
+--R       +-+4+-+4+-+3 | 2 4         2    2
+--R     2\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      +--------+                  +--------+3
+--R      |     1        +-+       2  |     1
+--R      |- ------ log(\|x  + 8a b   |- ------ )
+--R     4|       3                  4|       3
+--R     \|  16a b                   \|  16a b
+--R   + 
+--R        +--------+                  +--------+3
+--R        |     1        +-+       2  |     1
+--R     -  |- ------ log(\|x  - 8a b   |- ------ )
+--R       4|       3                  4|       3
+--R       \|  16a b                   \|  16a b
+--R   + 
+--R                              +--------+3
+--R                           2  |     1
+--R                       8a b   |- ------
+--R        +--------+           4|       3
+--R        |     1              \|  16a b
+--R     2  |- ------ atan(-----------------)
+--R       4|       3              +-+
+--R       \|  16a b              \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 480
+
+--S 481 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                +--------+          +-------------------+
+--R           +-+  |     1   4+-+4+-+3 | 2 4         2    2
+--R         2\|2   |- ------ \|a \|b  \|b x  + 2a b x  + a
+--R               4|       3
+--R               \|  16a b
+--R      *
+--R                           +--------+3
+--R              +-+       2  |     1
+--R         log(\|x  + 8a b   |- ------ )
+--R                          4|       3
+--R                          \|  16a b
+--R     + 
+--R       -
+--R                   +--------+          +-------------------+
+--R              +-+  |     1   4+-+4+-+3 | 2 4         2    2
+--R            2\|2   |- ------ \|a \|b  \|b x  + 2a b x  + a
+--R                  4|       3
+--R                  \|  16a b
+--R         *
+--R                              +--------+3
+--R                 +-+       2  |     1
+--R            log(\|x  - 8a b   |- ------ )
+--R                             4|       3
+--R                             \|  16a b
+--R     + 
+--R             2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                           +-+4+-+ +-+   4+-+
+--R              2           \|2 \|b \|x  + \|a
+--R       (- 2b x  - 2a)atan(-------------------)
+--R                                  4+-+
+--R                                  \|a
+--R     + 
+--R                           +-+4+-+ +-+   4+-+
+--R              2           \|2 \|b \|x  - \|a
+--R       (- 2b x  - 2a)atan(-------------------)
+--R                                  4+-+
+--R                                  \|a
+--R     + 
+--R                                                                   +--------+3
+--R                                                                2  |     1
+--R                                                            8a b   |- ------
+--R              +--------+          +-------------------+           4|       3
+--R         +-+  |     1   4+-+4+-+3 | 2 4         2    2            \|  16a b
+--R       4\|2   |- ------ \|a \|b  \|b x  + 2a b x  + a  atan(-----------------)
+--R             4|       3                                             +-+
+--R             \|  16a b                                             \|x
+--R  /
+--R                    +-------------------+
+--R       +-+4+-+4+-+3 | 2 4         2    2
+--R     2\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          +-------------------+
+--R          | 2 4         2    2       3
+--R        x\|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  ------------------------------------
+--R                       +-------------------+
+--R            2      +-+ | 2 4         2    2
+--R        (b x  + a)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 482
+
+)clear all
+
+--S 483 of 1353
+t0:=1/(sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R             +-------------------+
+--R         +-+ | 2 4         2    2
+--R        \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 1353
+r0:=-(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(1/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(3/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   1/2*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(3/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/2*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(3/4)*_
+   b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R           2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R  /
+--R                     +-------------------+
+--R       +-+4+-+3 4+-+ | 2 4         2    2
+--R     2\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      +-------+               +-------+    +-------+               +-------+
+--R      |    1        +-+       |    1       |    1        +-+       |    1
+--R      |- ----- log(\|x  + 2a  |- -----) -  |- ----- log(\|x  - 2a  |- -----)
+--R     4|     3                4|     3     4|     3                4|     3
+--R     \|  16a b               \|  16a b    \|  16a b               \|  16a b
+--R   + 
+--R                            +-------+
+--R                            |    1
+--R                        2a  |- -----
+--R          +-------+        4|     3
+--R          |    1           \|  16a b
+--R     - 2  |- ----- atan(------------)
+--R         4|     3            +-+
+--R         \|  16a b          \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 485
+
+--S 486 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              +-------+           +-------------------+               +-------+
+--R         +-+  |    1   4+-+3 4+-+ | 2 4         2    2      +-+       |    1
+--R       2\|2   |- ----- \|a   \|b \|b x  + 2a b x  + a  log(\|x  + 2a  |- -----)
+--R             4|     3                                                4|     3
+--R             \|  16a b                                               \|  16a b
+--R     + 
+--R                +-------+           +-------------------+               +-------+
+--R           +-+  |    1   4+-+3 4+-+ | 2 4         2    2      +-+       |    1
+--R       - 2\|2   |- ----- \|a   \|b \|b x  + 2a b x  + a  log(\|x  - 2a  |- -----)
+--R               4|     3                                                4|     3
+--R               \|  16a b                                               \|  16a b
+--R     + 
+--R           2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                           +-+4+-+ +-+   4+-+
+--R              2           \|2 \|b \|x  + \|a
+--R       (- 2b x  - 2a)atan(-------------------)
+--R                                  4+-+
+--R                                  \|a
+--R     + 
+--R                           +-+4+-+ +-+   4+-+
+--R              2           \|2 \|b \|x  - \|a
+--R       (- 2b x  - 2a)atan(-------------------)
+--R                                  4+-+
+--R                                  \|a
+--R     + 
+--R                                                                  +-------+
+--R                                                                  |    1
+--R                                                              2a  |- -----
+--R                +-------+           +-------------------+        4|     3
+--R           +-+  |    1   4+-+3 4+-+ | 2 4         2    2         \|  16a b
+--R       - 4\|2   |- ----- \|a   \|b \|b x  + 2a b x  + a  atan(------------)
+--R               4|     3                                            +-+
+--R               \|  16a b                                          \|x
+--R  /
+--R                     +-------------------+
+--R       +-+4+-+3 4+-+ | 2 4         2    2
+--R     2\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +-------------------+
+--R           | 2 4         2    2       2
+--R          \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ------------------------------------
+--R                       +-------------------+
+--R            2      +-+ | 2 4         2    2
+--R        (b x  + a)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 487
+
+)clear all
+
+--S 488 of 1353
+t0:=1/(x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R        x\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 1353
+r0:=b^(1/4)*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-b^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   1/2*b^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/2*b^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-2*(a+b*x^2)/(a*sqrt(x)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R           2     4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             2     4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)\|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R              2      4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (- 2b x  - 2a)\|b \|x atan(-------------------)
+--R                                          4+-+
+--R                                          \|a
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R              2      4+-+ +-+     \|2 \|b \|x  - \|a            2       +-+4+-+
+--R       (- 2b x  - 2a)\|b \|x atan(-------------------) + (- 4b x  - 4a)\|2 \|a
+--R                                          4+-+
+--R                                          \|a
+--R  /
+--R                    +-------------------+
+--R        +-+4+-+ +-+ | 2 4         2    2
+--R     2a\|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +------+                     +------+3
+--R            |    b   +-+      +-+     4  |    b
+--R       - a  |- ---- \|x log(b\|x  + 8a   |- ---- )
+--R           4|     5                     4|     5
+--R           \|  16a                      \|  16a
+--R     + 
+--R          +------+                     +------+3
+--R          |    b   +-+      +-+     4  |    b
+--R       a  |- ---- \|x log(b\|x  - 8a   |- ---- )
+--R         4|     5                     4|     5
+--R         \|  16a                      \|  16a
+--R     + 
+--R                                   +------+3
+--R                                4  |    b
+--R                              8a   |- ----
+--R             +------+             4|     5
+--R             |    b   +-+         \|  16a
+--R       - 2a  |- ---- \|x atan(------------- - 2
+--R            4|     5                +-+
+--R            \|  16a               b\|x
+--R  /
+--R       +-+
+--R     a\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 490
+
+--S 491 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2     4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 +------+         +-------------------+                 +------+3
+--R            +-+  |    b  4+-+ +-+ | 2 4         2    2       +-+     4  |    b
+--R       - 2a\|2   |- ---- \|a \|x \|b x  + 2a b x  + a  log(b\|x  + 8a   |- ---- )
+--R                4|     5                                               4|     5
+--R                \|  16a                                                \|  16a
+--R     + 
+--R               +------+         +-------------------+                 +------+3
+--R          +-+  |    b  4+-+ +-+ | 2 4         2    2       +-+     4  |    b
+--R       2a\|2   |- ---- \|a \|x \|b x  + 2a b x  + a  log(b\|x  - 8a   |- ---- )
+--R              4|     5                                               4|     5
+--R              \|  16a                                                \|  16a
+--R     + 
+--R           2     4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)\|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R            2      4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (2b x  + 2a)\|b \|x atan(-------------------)
+--R                                        4+-+
+--R                                        \|a
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R            2      4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (2b x  + 2a)\|b \|x atan(-------------------)
+--R                                        4+-+
+--R                                        \|a
+--R     + 
+--R                                                                 +------+3
+--R                                                              4  |    b
+--R                                                            8a   |- ----
+--R                 +------+         +-------------------+         4|     5
+--R            +-+  |    b  4+-+ +-+ | 2 4         2    2          \|  16a
+--R       - 4a\|2   |- ---- \|a \|x \|b x  + 2a b x  + a  atan(-------------)
+--R                4|     5                                          +-+
+--R                \|  16a                                         b\|x
+--R     + 
+--R                   +-------------------+
+--R           +-+4+-+ | 2 4         2    2         2       +-+4+-+
+--R       - 4\|2 \|a \|b x  + 2a b x  + a   + (4b x  + 4a)\|2 \|a
+--R  /
+--R                    +-------------------+
+--R        +-+4+-+ +-+ | 2 4         2    2
+--R     2a\|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R            +-------------------+
+--R            | 2 4         2    2       2
+--R           \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  --------------------------------------
+--R                         +-------------------+
+--R            3        +-+ | 2 4         2    2
+--R        (b x  + a x)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 1353
+t0:=1/(x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R               +-------------------+
+--R         2 +-+ | 2 4         2    2
+--R        x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 1353
+r0:=-2/3*(a+b*x^2)/(a*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+b^(3/4)*_
+   (a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-b^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   1/2*b^(3/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1/2*b^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              3        4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 3a x)\|b  \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R            3        4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 3a x)\|b  \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                      +-+4+-+ +-+   4+-+
+--R              3        4+-+3 +-+     \|2 \|b \|x  + \|a
+--R       (- 6b x  - 6a x)\|b  \|x atan(-------------------)
+--R                                             4+-+
+--R                                             \|a
+--R     + 
+--R                                      +-+4+-+ +-+   4+-+
+--R              3        4+-+3 +-+     \|2 \|b \|x  - \|a
+--R       (- 6b x  - 6a x)\|b  \|x atan(-------------------)
+--R                                             4+-+
+--R                                             \|a
+--R     + 
+--R              2       +-+4+-+3
+--R       (- 4b x  - 4a)\|2 \|a
+--R  /
+--R                       +-------------------+
+--R          +-+4+-+3 +-+ | 2 4         2    2
+--R     6a x\|2 \|a  \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +------+                     +------+
+--R               |    3                       |    3
+--R               |   b    +-+      +-+     2  |   b
+--R       - 3a x  |- ---- \|x log(b\|x  + 2a   |- ----)
+--R              4|     7                     4|     7
+--R              \|  16a                      \|  16a
+--R     + 
+--R             +------+                     +------+
+--R             |    3                       |    3
+--R             |   b    +-+      +-+     2  |   b
+--R       3a x  |- ---- \|x log(b\|x  - 2a   |- ----)
+--R            4|     7                     4|     7
+--R            \|  16a                      \|  16a
+--R     + 
+--R                                   +------+
+--R                                   |    3
+--R                                2  |   b
+--R             +------+         2a   |- ----
+--R             |    3               4|     7
+--R             |   b    +-+         \|  16a
+--R       6a x  |- ---- \|x atan(------------ - 2
+--R            4|     7                +-+
+--R            \|  16a               b\|x
+--R  /
+--R          +-+
+--R     3a x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 495
+
+--S 496 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3        4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 3a x)\|b  \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R       -
+--R                      +------+
+--R                      |    3            +-------------------+
+--R                 +-+  |   b   4+-+3 +-+ | 2 4         2    2
+--R            6a x\|2   |- ---- \|a  \|x \|b x  + 2a b x  + a
+--R                     4|     7
+--R                     \|  16a
+--R         *
+--R                             +------+
+--R                             |    3
+--R                  +-+     2  |   b
+--R            log(b\|x  + 2a   |- ----)
+--R                            4|     7
+--R                            \|  16a
+--R     + 
+--R                 +------+                                                +------+
+--R                 |    3            +-------------------+                 |    3
+--R            +-+  |   b   4+-+3 +-+ | 2 4         2    2       +-+     2  |   b
+--R       6a x\|2   |- ---- \|a  \|x \|b x  + 2a b x  + a  log(b\|x  - 2a   |- ----)
+--R                4|     7                                                4|     7
+--R                \|  16a                                                 \|  16a
+--R     + 
+--R              3        4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 3a x)\|b  \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                    +-+4+-+ +-+   4+-+
+--R            3        4+-+3 +-+     \|2 \|b \|x  + \|a
+--R       (6b x  + 6a x)\|b  \|x atan(-------------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                    +-+4+-+ +-+   4+-+
+--R            3        4+-+3 +-+     \|2 \|b \|x  - \|a
+--R       (6b x  + 6a x)\|b  \|x atan(-------------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                                                   +------+
+--R                                                                   |    3
+--R                                                                2  |   b
+--R                  +------+                                    2a   |- ----
+--R                  |    3            +-------------------+         4|     7
+--R             +-+  |   b   4+-+3 +-+ | 2 4         2    2          \|  16a
+--R       12a x\|2   |- ---- \|a  \|x \|b x  + 2a b x  + a  atan(------------)
+--R                 4|     7                                           +-+
+--R                 \|  16a                                          b\|x
+--R     + 
+--R                    +-------------------+
+--R           +-+4+-+3 | 2 4         2    2         2       +-+4+-+3
+--R       - 4\|2 \|a  \|b x  + 2a b x  + a   + (4b x  + 4a)\|2 \|a
+--R  /
+--R                       +-------------------+
+--R          +-+4+-+3 +-+ | 2 4         2    2
+--R     6a x\|2 \|a  \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R            +-------------------+
+--R            | 2 4         2    2       2
+--R           \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ---------------------------------------
+--R                          +-------------------+
+--R            4      2  +-+ | 2 4         2    2
+--R        (b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 497
+
+)clear all
+
+--S 498 of 1353
+t0:=1/(x^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R               +-------------------+
+--R         3 +-+ | 2 4         2    2
+--R        x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 1353
+r0:=-2/5*(a+b*x^2)/(a*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-b^(5/4)*_
+   (a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+b^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   1/2*b^(5/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1/2*b^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+2*b*(a+b*x^2)/(a^2*_
+   sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2 4         2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 5a b x )\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R          2 4         2 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 5a b x )\|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R           2 4          2 4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (10b x  + 10a b x )\|b \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R           2 4          2 4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (10b x  + 10a b x )\|b \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R           2 4          2     2  +-+4+-+
+--R       (20b x  + 16a b x  - 4a )\|2 \|a
+--R  /
+--R                        +-------------------+
+--R        2 2 +-+4+-+ +-+ | 2 4         2    2
+--R     10a x \|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +------+                      +------+3
+--R              |    5                        |    5
+--R         2 2  |   b    +-+     4 +-+     7  |   b
+--R       5a x   |- ---- \|x log(b \|x  + 8a   |- ---- )
+--R             4|     9                      4|     9
+--R             \|  16a                       \|  16a
+--R     + 
+--R                +------+                      +------+3
+--R                |    5                        |    5
+--R           2 2  |   b    +-+     4 +-+     7  |   b
+--R       - 5a x   |- ---- \|x log(b \|x  - 8a   |- ---- )
+--R               4|     9                      4|     9
+--R               \|  16a                       \|  16a
+--R     + 
+--R                                     +------+3
+--R                                     |    5
+--R                                  7  |   b
+--R               +------+         8a   |- ----
+--R               |    5               4|     9
+--R          2 2  |   b    +-+         \|  16a          2
+--R       10a x   |- ---- \|x atan(------------- + 10b x  - 2a
+--R              4|     9               4 +-+
+--R              \|  16a               b \|x
+--R  /
+--R       2 2 +-+
+--R     5a x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 500
+
+--S 501 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          2 4         2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 5a b x )\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                     +------+
+--R                     |    5           +-------------------+
+--R            2 2 +-+  |   b   4+-+ +-+ | 2 4         2    2
+--R         10a x \|2   |- ---- \|a \|x \|b x  + 2a b x  + a
+--R                    4|     9
+--R                    \|  16a
+--R      *
+--R                           +------+3
+--R                           |    5
+--R              4 +-+     7  |   b
+--R         log(b \|x  + 8a   |- ---- )
+--R                          4|     9
+--R                          \|  16a
+--R     + 
+--R       -
+--R                        +------+
+--R                        |    5           +-------------------+
+--R               2 2 +-+  |   b   4+-+ +-+ | 2 4         2    2
+--R            10a x \|2   |- ---- \|a \|x \|b x  + 2a b x  + a
+--R                       4|     9
+--R                       \|  16a
+--R         *
+--R                              +------+3
+--R                              |    5
+--R                 4 +-+     7  |   b
+--R            log(b \|x  - 8a   |- ---- )
+--R                             4|     9
+--R                             \|  16a
+--R     + 
+--R            2 4         2 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 5a b x )\|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                          +-+4+-+ +-+   4+-+
+--R             2 4          2 4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (- 10b x  - 10a b x )\|b \|x atan(-------------------)
+--R                                                 4+-+
+--R                                                 \|a
+--R     + 
+--R                                          +-+4+-+ +-+   4+-+
+--R             2 4          2 4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (- 10b x  - 10a b x )\|b \|x atan(-------------------)
+--R                                                 4+-+
+--R                                                 \|a
+--R     + 
+--R                                                                   +------+3
+--R                                                                   |    5
+--R                                                                7  |   b
+--R                   +------+                                   8a   |- ----
+--R                   |    5           +-------------------+         4|     9
+--R          2 2 +-+  |   b   4+-+ +-+ | 2 4         2    2          \|  16a
+--R       20a x \|2   |- ---- \|a \|x \|b x  + 2a b x  + a  atan(-------------)
+--R                  4|     9                                         4 +-+
+--R                  \|  16a                                         b \|x
+--R     + 
+--R                             +-------------------+
+--R             2       +-+4+-+ | 2 4         2    2
+--R       (20b x  - 4a)\|2 \|a \|b x  + 2a b x  + a
+--R     + 
+--R             2 4          2     2  +-+4+-+
+--R       (- 20b x  - 16a b x  + 4a )\|2 \|a
+--R  /
+--R                        +-------------------+
+--R        2 2 +-+4+-+ +-+ | 2 4         2    2
+--R     10a x \|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R            +-------------------+
+--R            | 2 4         2    2       2
+--R           \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ---------------------------------------
+--R                          +-------------------+
+--R            5      3  +-+ | 2 4         2    2
+--R        (b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 502
+
+)clear all
+
+--S 503 of 1353
+t0:=x^(15/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            7 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 1353
+r0:=1/4*a*x^(9/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+   17/16*x^(9/2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+117/80*x^(5/2)*_
+   (a+b*x^2)/(b^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))-117/32*a^(5/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(17/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))+117/32*a^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   117/64*a^(5/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+117/64*a^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-117/16*a*(a+b*x^2)*_
+   sqrt(x)/(b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              2 4        2   2       3 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (585a b x  + 1170a b x  + 585a )\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  2 4        2   2       3 4+-+
+--R         (- 585a b x  - 1170a b x  - 585a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                   +-+4+-+ +-+   4+-+
+--R               2 4        2   2        3 4+-+     \|2 \|b \|x  + \|a
+--R       (1170a b x  + 2340a b x  + 1170a )\|a atan(-------------------)
+--R                                                          4+-+
+--R                                                          \|a
+--R     + 
+--R                                                   +-+4+-+ +-+   4+-+
+--R               2 4        2   2        3 4+-+     \|2 \|b \|x  - \|a
+--R       (1170a b x  + 2340a b x  + 1170a )\|a atan(-------------------)
+--R                                                          4+-+
+--R                                                          \|a
+--R     + 
+--R            3 6          2 4        2   2        3  +-+4+-+ +-+
+--R       (128b x  - 1664a b x  - 4212a b x  - 2340a )\|2 \|b \|x
+--R  /
+--R                                 +-------------------+
+--R          5 2         4  +-+4+-+ | 2 4         2    2
+--R     (320b x  + 320a b )\|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 504
+
+--S 505 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                        +-------------+
+--R                                        |            5
+--R             6 4         5 2      2 4   |  187388721a
+--R         (80b x  + 160a b x  + 80a b )  |- -----------
+--R                                       4|           17
+--R                                       \|  16777216b
+--R      *
+--R                              +-------------+
+--R                              |            5
+--R                  +-+      4  |  187388721a
+--R         log(117a\|x  + 64b   |- -----------)
+--R                             4|           17
+--R                             \|  16777216b
+--R     + 
+--R                                          +-------------+
+--R                                          |            5
+--R               6 4         5 2      2 4   |  187388721a
+--R         (- 80b x  - 160a b x  - 80a b )  |- -----------
+--R                                         4|           17
+--R                                         \|  16777216b
+--R      *
+--R                              +-------------+
+--R                              |            5
+--R                  +-+      4  |  187388721a
+--R         log(117a\|x  - 64b   |- -----------)
+--R                             4|           17
+--R                             \|  16777216b
+--R     + 
+--R                                            +-------------+
+--R                                            |            5
+--R                6 4         5 2       2 4   |  187388721a
+--R         (- 160b x  - 320a b x  - 160a b )  |- -----------
+--R                                           4|           17
+--R                                           \|  16777216b
+--R      *
+--R                    +-------------+
+--R                    |            5
+--R                 4  |  187388721a
+--R              64b   |- -----------
+--R                   4|           17
+--R                   \|  16777216b
+--R         atan(--------------------)
+--R                         +-+
+--R                    117a\|x
+--R     + 
+--R           3 6         2 4        2   2       3  +-+
+--R       (32b x  - 416a b x  - 1053a b x  - 585a )\|x
+--R  /
+--R        6 4         5 2      2 4
+--R     80b x  + 160a b x  + 80a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 505
+
+--S 506 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  3 6        2 2 4        3   2       4 4+-+
+--R         (- 585a b x  - 1755a b x  - 1755a b x  - 585a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                              +-------------+
+--R                                              |            5
+--R              6 4         5 2       2 4  +-+  |  187388721a  4+-+
+--R         (320b x  + 640a b x  + 320a b )\|2   |- ----------- \|b
+--R                                             4|           17
+--R                                             \|  16777216b
+--R      *
+--R                                                    +-------------+
+--R          +-------------------+                     |            5
+--R          | 2 4         2    2          +-+      4  |  187388721a
+--R         \|b x  + 2a b x  + a  log(117a\|x  + 64b   |- -----------)
+--R                                                   4|           17
+--R                                                   \|  16777216b
+--R     + 
+--R                                                +-------------+
+--R                                                |            5
+--R                6 4         5 2       2 4  +-+  |  187388721a  4+-+
+--R         (- 320b x  - 640a b x  - 320a b )\|2   |- ----------- \|b
+--R                                               4|           17
+--R                                               \|  16777216b
+--R      *
+--R                                                    +-------------+
+--R          +-------------------+                     |            5
+--R          | 2 4         2    2          +-+      4  |  187388721a
+--R         \|b x  + 2a b x  + a  log(117a\|x  - 64b   |- -----------)
+--R                                                   4|           17
+--R                                                   \|  16777216b
+--R     + 
+--R                3 6        2 2 4        3   2       4 4+-+
+--R         (585a b x  + 1755a b x  + 1755a b x  + 585a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   3 6        2 2 4        3   2        4 4+-+
+--R         (- 1170a b x  - 3510a b x  - 3510a b x  - 1170a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                   3 6        2 2 4        3   2        4 4+-+
+--R         (- 1170a b x  - 3510a b x  - 3510a b x  - 1170a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                                                 +-------------+
+--R                                                 |            5
+--R                6 4          5 2       2 4  +-+  |  187388721a  4+-+
+--R         (- 640b x  - 1280a b x  - 640a b )\|2   |- ----------- \|b
+--R                                                4|           17
+--R                                                \|  16777216b
+--R      *
+--R                                          +-------------+
+--R                                          |            5
+--R                                       4  |  187388721a
+--R                                    64b   |- -----------
+--R          +-------------------+          4|           17
+--R          | 2 4         2    2           \|  16777216b
+--R         \|b x  + 2a b x  + a  atan(--------------------)
+--R                                               +-+
+--R                                          117a\|x
+--R     + 
+--R              3 6          2 4        2   2        3  +-+4+-+ +-+
+--R         (128b x  - 1664a b x  - 4212a b x  - 2340a )\|2 \|b \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              4 8          3 6        2 2 4        3   2        4  +-+4+-+ +-+
+--R       (- 128b x  + 1536a b x  + 5876a b x  + 6552a b x  + 2340a )\|2 \|b \|x
+--R  /
+--R                                             +-------------------+
+--R          6 4         5 2       2 4  +-+4+-+ | 2 4         2    2
+--R     (320b x  + 640a b x  + 320a b )\|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +-------------------+
+--R                  8 | 2 4         2    2       10      8
+--R                 x \|b x  + 2a b x  + a   - b x   - a x
+--R   (5)  ---------------------------------------------------------
+--R                                            +-------------------+
+--R          3 6       2 4     2   2    3  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 1353
+t0:=x^(13/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            6 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 1353
+r0:=1/4*a*x^(7/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+   15/16*x^(7/2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/48*x^(3/2)*_
+   (a+b*x^2)/(b^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/32*a^(3/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(15/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-77/32*a^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   77/64*a^(3/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/64*a^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2 4           2       2 4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (231b x  + 462a b x  + 231a )\|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                2 4           2       2 4+-+3
+--R         (- 231b x  - 462a b x  - 231a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                 +-+4+-+ +-+   4+-+
+--R              2 4           2       2 4+-+3     \|2 \|b \|x  + \|a
+--R       (- 462b x  - 924a b x  - 462a )\|a  atan(-------------------)
+--R                                                        4+-+
+--R                                                        \|a
+--R     + 
+--R                                                 +-+4+-+ +-+   4+-+
+--R              2 4           2       2 4+-+3     \|2 \|b \|x  - \|a
+--R       (- 462b x  - 924a b x  - 462a )\|a  atan(-------------------)
+--R                                                        4+-+
+--R                                                        \|a
+--R     + 
+--R            2 5           3       2   +-+4+-+3 +-+
+--R       (128b x  + 484a b x  + 308a x)\|2 \|b  \|x
+--R  /
+--R                                  +-------------------+
+--R          4 2         3  +-+4+-+3 | 2 4         2    2
+--R     (192b x  + 192a b )\|2 \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         +-------------+
+--R                                         |            3
+--R               5 4        4 2      2 3   |   35153041a
+--R         (- 48b x  - 96a b x  - 48a b )  |- -----------
+--R                                        4|           15
+--R                                        \|  16777216b
+--R      *
+--R                                       +-------------+3
+--R                                       |            3
+--R                    2 +-+          11  |   35153041a
+--R         log(456533a \|x  + 262144b    |- ----------- )
+--R                                      4|           15
+--R                                      \|  16777216b
+--R     + 
+--R                                       +-------------+
+--R                                       |            3
+--R             5 4        4 2      2 3   |   35153041a
+--R         (48b x  + 96a b x  + 48a b )  |- -----------
+--R                                      4|           15
+--R                                      \|  16777216b
+--R      *
+--R                                       +-------------+3
+--R                                       |            3
+--R                    2 +-+          11  |   35153041a
+--R         log(456533a \|x  - 262144b    |- ----------- )
+--R                                      4|           15
+--R                                      \|  16777216b
+--R     + 
+--R                                          +-------------+
+--R                                          |            3
+--R               5 4         4 2      2 3   |   35153041a
+--R         (- 96b x  - 192a b x  - 96a b )  |- -----------
+--R                                         4|           15
+--R                                         \|  16777216b
+--R      *
+--R                         +-------------+3
+--R                         |            3
+--R                     11  |   35153041a
+--R              262144b    |- -----------
+--R                        4|           15
+--R                        \|  16777216b
+--R         atan(--------------------------)
+--R                            2 +-+
+--R                     456533a \|x
+--R     + 
+--R           2 5           3      2   +-+
+--R       (32b x  + 121a b x  + 77a x)\|x
+--R  /
+--R        5 4        4 2      2 3
+--R     48b x  + 96a b x  + 48a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 510
+
+--S 511 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                3 6         2 4       2   2       3 4+-+3
+--R         (- 231b x  - 693a b x  - 693a b x  - 231a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                +-------------+
+--R                                                |            3
+--R                5 4         4 2       2 3  +-+  |   35153041a  4+-+3
+--R         (- 192b x  - 384a b x  - 192a b )\|2   |- ----------- \|b
+--R                                               4|           15
+--R                                               \|  16777216b
+--R      *
+--R                                                             +-------------+3
+--R          +-------------------+                              |            3
+--R          | 2 4         2    2            2 +-+          11  |   35153041a
+--R         \|b x  + 2a b x  + a  log(456533a \|x  + 262144b    |- ----------- )
+--R                                                            4|           15
+--R                                                            \|  16777216b
+--R     + 
+--R                                              +-------------+
+--R                                              |            3
+--R              5 4         4 2       2 3  +-+  |   35153041a  4+-+3
+--R         (192b x  + 384a b x  + 192a b )\|2   |- ----------- \|b
+--R                                             4|           15
+--R                                             \|  16777216b
+--R      *
+--R                                                             +-------------+3
+--R          +-------------------+                              |            3
+--R          | 2 4         2    2            2 +-+          11  |   35153041a
+--R         \|b x  + 2a b x  + a  log(456533a \|x  - 262144b    |- ----------- )
+--R                                                            4|           15
+--R                                                            \|  16777216b
+--R     + 
+--R              3 6         2 4       2   2       3 4+-+3
+--R         (231b x  + 693a b x  + 693a b x  + 231a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                             +-+4+-+ +-+   4+-+
+--R            3 6          2 4        2   2       3 4+-+3     \|2 \|b \|x  + \|a
+--R       (462b x  + 1386a b x  + 1386a b x  + 462a )\|a  atan(-------------------)
+--R                                                                    4+-+
+--R                                                                    \|a
+--R     + 
+--R                                                             +-+4+-+ +-+   4+-+
+--R            3 6          2 4        2   2       3 4+-+3     \|2 \|b \|x  - \|a
+--R       (462b x  + 1386a b x  + 1386a b x  + 462a )\|a  atan(-------------------)
+--R                                                                    4+-+
+--R                                                                    \|a
+--R     + 
+--R                                                +-------------+
+--R                                                |            3
+--R                5 4         4 2       2 3  +-+  |   35153041a  4+-+3
+--R         (- 384b x  - 768a b x  - 384a b )\|2   |- ----------- \|b
+--R                                               4|           15
+--R                                               \|  16777216b
+--R      *
+--R                                               +-------------+3
+--R                                               |            3
+--R                                           11  |   35153041a
+--R                                    262144b    |- -----------
+--R          +-------------------+               4|           15
+--R          | 2 4         2    2                \|  16777216b
+--R         \|b x  + 2a b x  + a  atan(--------------------------)
+--R                                                  2 +-+
+--R                                           456533a \|x
+--R     + 
+--R                                                   +-------------------+
+--R            2 5           3       2   +-+4+-+3 +-+ | 2 4         2    2
+--R       (128b x  + 484a b x  + 308a x)\|2 \|b  \|x \|b x  + 2a b x  + a
+--R     + 
+--R              3 7         2 5       2   3       3   +-+4+-+3 +-+
+--R       (- 128b x  - 612a b x  - 792a b x  - 308a x)\|2 \|b  \|x
+--R  /
+--R                                              +-------------------+
+--R          5 4         4 2       2 3  +-+4+-+3 | 2 4         2    2
+--R     (192b x  + 384a b x  + 192a b )\|2 \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                   7 | 2 4         2    2       9      7
+--R                  x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  ---------------------------------------------------------
+--R                                            +-------------------+
+--R          3 6       2 4     2   2    3  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 512
+
+)clear all
+
+--S 513 of 1353
+t0:=x^(11/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            5 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 513
+
+--S 514 of 1353
+r0:=1/4*a*x^(5/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+   13/16*x^(5/2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/32*a^(1/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(13/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-45/32*a^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   45/64*a^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-45/64*a^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/16*(a+b*x^2)*sqrt(x)/_
+   (b^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             2 4          2      2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45b x  - 90a b x  - 45a )\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2 4          2      2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45b x  + 90a b x  + 45a )\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                              +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+     \|2 \|b \|x  + \|a
+--R       (- 90b x  - 180a b x  - 90a )\|a atan(-------------------)
+--R                                                     4+-+
+--R                                                     \|a
+--R     + 
+--R                                              +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+     \|2 \|b \|x  - \|a
+--R       (- 90b x  - 180a b x  - 90a )\|a atan(-------------------)
+--R                                                     4+-+
+--R                                                     \|a
+--R     + 
+--R            2 4           2       2  +-+4+-+ +-+
+--R       (128b x  + 324a b x  + 180a )\|2 \|b \|x
+--R  /
+--R                               +-------------------+
+--R         4 2        3  +-+4+-+ | 2 4         2    2
+--R     (64b x  + 64a b )\|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         +-------------+
+--R               5 4        4 2      2 3   |    4100625a
+--R         (- 16b x  - 32a b x  - 16a b )  |- -----------
+--R                                        4|           13
+--R                                        \|  16777216b
+--R      *
+--R                            +-------------+
+--R                +-+      3  |    4100625a
+--R         log(45\|x  + 64b   |- -----------)
+--R                           4|           13
+--R                           \|  16777216b
+--R     + 
+--R                                       +-------------+
+--R             5 4        4 2      2 3   |    4100625a
+--R         (16b x  + 32a b x  + 16a b )  |- -----------
+--R                                      4|           13
+--R                                      \|  16777216b
+--R      *
+--R                            +-------------+
+--R                +-+      3  |    4100625a
+--R         log(45\|x  - 64b   |- -----------)
+--R                           4|           13
+--R                           \|  16777216b
+--R     + 
+--R                                                               +-------------+
+--R                                                            3  |    4100625a
+--R                                                         64b   |- -----------
+--R                                     +-------------+          4|           13
+--R           5 4        4 2      2 3   |    4100625a            \|  16777216b
+--R       (32b x  + 64a b x  + 32a b )  |- ----------- atan(--------------------)
+--R                                    4|           13                +-+
+--R                                    \|  16777216b               45\|x
+--R     + 
+--R           2 4          2      2  +-+
+--R       (32b x  + 81a b x  + 45a )\|x
+--R  /
+--R        5 4        4 2      2 3
+--R     16b x  + 32a b x  + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 515
+
+--S 516 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3 6         2 4       2   2      3 4+-+
+--R         (45b x  + 135a b x  + 135a b x  + 45a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                              +-------------+
+--R               5 4         4 2      2 3  +-+  |    4100625a  4+-+
+--R         (- 64b x  - 128a b x  - 64a b )\|2   |- ----------- \|b
+--R                                             4|           13
+--R                                             \|  16777216b
+--R      *
+--R          +-------------------+                   +-------------+
+--R          | 2 4         2    2        +-+      3  |    4100625a
+--R         \|b x  + 2a b x  + a  log(45\|x  + 64b   |- -----------)
+--R                                                 4|           13
+--R                                                 \|  16777216b
+--R     + 
+--R                                            +-------------+
+--R             5 4         4 2      2 3  +-+  |    4100625a  4+-+
+--R         (64b x  + 128a b x  + 64a b )\|2   |- ----------- \|b
+--R                                           4|           13
+--R                                           \|  16777216b
+--R      *
+--R          +-------------------+                   +-------------+
+--R          | 2 4         2    2        +-+      3  |    4100625a
+--R         \|b x  + 2a b x  + a  log(45\|x  - 64b   |- -----------)
+--R                                                 4|           13
+--R                                                 \|  16777216b
+--R     + 
+--R               3 6         2 4       2   2      3 4+-+
+--R         (- 45b x  - 135a b x  - 135a b x  - 45a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3 4+-+     \|2 \|b \|x  + \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )\|a atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3 4+-+     \|2 \|b \|x  - \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )\|a atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R                                              +-------------+
+--R              5 4         4 2       2 3  +-+  |    4100625a  4+-+
+--R         (128b x  + 256a b x  + 128a b )\|2   |- ----------- \|b
+--R                                             4|           13
+--R                                             \|  16777216b
+--R      *
+--R                                          +-------------+
+--R                                       3  |    4100625a
+--R                                    64b   |- -----------
+--R          +-------------------+          4|           13
+--R          | 2 4         2    2           \|  16777216b
+--R         \|b x  + 2a b x  + a  atan(--------------------)
+--R                                              +-+
+--R                                           45\|x
+--R     + 
+--R                                                 +-------------------+
+--R            2 4           2       2  +-+4+-+ +-+ | 2 4         2    2
+--R       (128b x  + 324a b x  + 180a )\|2 \|b \|x \|b x  + 2a b x  + a
+--R     + 
+--R              3 6         2 4       2   2       3  +-+4+-+ +-+
+--R       (- 128b x  - 452a b x  - 504a b x  - 180a )\|2 \|b \|x
+--R  /
+--R                                           +-------------------+
+--R         5 4         4 2      2 3  +-+4+-+ | 2 4         2    2
+--R     (64b x  + 128a b x  + 64a b )\|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                   6 | 2 4         2    2       8      6
+--R                  x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  ---------------------------------------------------------
+--R                                            +-------------------+
+--R          3 6       2 4     2   2    3  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 517
+
+)clear all
+
+--S 518 of 1353
+t0:=x^(9/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            4 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 1353
+r0:=1/4*a*x^(3/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+   11/16*x^(3/2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))-21/32*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(1/4)*b^(11/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+21/32*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(1/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   21/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(1/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-21/64*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*_
+   b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             2 4          2      2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21b x  - 42a b x  - 21a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2 4          2      2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 42a b x  + 21a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  + \|a
+--R       (42b x  + 84a b x  + 42a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  - \|a
+--R       (42b x  + 84a b x  + 42a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R               3          +-+4+-+4+-+3 +-+
+--R       (- 44b x  - 28a x)\|2 \|a \|b  \|x
+--R  /
+--R                                    +-------------------+
+--R         3 2        2  +-+4+-+4+-+3 | 2 4         2    2
+--R     (64b x  + 64a b )\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                          +---------------+
+--R              4 4         3 2       2 2   |        1
+--R         (336b x  + 672a b x  + 336a b )  |- -------------
+--R                                         4|             11
+--R                                         \|  16777216a b
+--R      *
+--R                                +---------------+3
+--R              +-+            8  |        1
+--R         log(\|x  + 262144a b   |- ------------- )
+--R                               4|             11
+--R                               \|  16777216a b
+--R     + 
+--R                                            +---------------+
+--R                4 4         3 2       2 2   |        1
+--R         (- 336b x  - 672a b x  - 336a b )  |- -------------
+--R                                           4|             11
+--R                                           \|  16777216a b
+--R      *
+--R                                +---------------+3
+--R              +-+            8  |        1
+--R         log(\|x  - 262144a b   |- ------------- )
+--R                               4|             11
+--R                               \|  16777216a b
+--R     + 
+--R                                           +---------------+
+--R              4 4          3 2       2 2   |        1
+--R         (672b x  + 1344a b x  + 672a b )  |- -------------
+--R                                          4|             11
+--R                                          \|  16777216a b
+--R      *
+--R                          +---------------+3
+--R                       8  |        1
+--R              262144a b   |- -------------
+--R                         4|             11
+--R                         \|  16777216a b
+--R         atan(-----------------------------)
+--R                            +-+
+--R                           \|x
+--R     + 
+--R               3         +-+
+--R       (- 11b x  - 7a x)\|x
+--R  /
+--R        4 4        3 2      2 2
+--R     16b x  + 32a b x  + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 520
+
+--S 521 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3 6        2 4      2   2      3      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 63a b x  + 63a b x  + 21a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                 +---------------+
+--R               4 4          3 2        2 2  +-+  |        1       4+-+4+-+3
+--R         (1344b x  + 2688a b x  + 1344a b )\|2   |- ------------- \|a \|b
+--R                                                4|             11
+--R                                                \|  16777216a b
+--R      *
+--R          +-------------------+                       +---------------+3
+--R          | 2 4         2    2      +-+            8  |        1
+--R         \|b x  + 2a b x  + a  log(\|x  + 262144a b   |- ------------- )
+--R                                                     4|             11
+--R                                                     \|  16777216a b
+--R     + 
+--R                                                   +---------------+
+--R                 4 4          3 2        2 2  +-+  |        1       4+-+4+-+3
+--R         (- 1344b x  - 2688a b x  - 1344a b )\|2   |- ------------- \|a \|b
+--R                                                  4|             11
+--R                                                  \|  16777216a b
+--R      *
+--R          +-------------------+                       +---------------+3
+--R          | 2 4         2    2      +-+            8  |        1
+--R         \|b x  + 2a b x  + a  log(\|x  - 262144a b   |- ------------- )
+--R                                                     4|             11
+--R                                                     \|  16777216a b
+--R     + 
+--R               3 6        2 4      2   2      3
+--R         (- 21b x  - 63a b x  - 63a b x  - 21a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R             3 6         2 4       2   2      3      \|2 \|b \|x  + \|a
+--R       (- 42b x  - 126a b x  - 126a b x  - 42a )atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|a
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R             3 6         2 4       2   2      3      \|2 \|b \|x  - \|a
+--R       (- 42b x  - 126a b x  - 126a b x  - 42a )atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|a
+--R     + 
+--R                                                 +---------------+
+--R               4 4          3 2        2 2  +-+  |        1       4+-+4+-+3
+--R         (2688b x  + 5376a b x  + 2688a b )\|2   |- ------------- \|a \|b
+--R                                                4|             11
+--R                                                \|  16777216a b
+--R      *
+--R                                                +---------------+3
+--R                                             8  |        1
+--R                                    262144a b   |- -------------
+--R          +-------------------+                4|             11
+--R          | 2 4         2    2                 \|  16777216a b
+--R         \|b x  + 2a b x  + a  atan(-----------------------------)
+--R                                                  +-+
+--R                                                 \|x
+--R     + 
+--R                                           +-------------------+
+--R               3          +-+4+-+4+-+3 +-+ | 2 4         2    2
+--R       (- 44b x  - 28a x)\|2 \|a \|b  \|x \|b x  + 2a b x  + a
+--R     + 
+--R           2 5          3      2   +-+4+-+4+-+3 +-+
+--R       (44b x  + 72a b x  + 28a x)\|2 \|a \|b  \|x
+--R  /
+--R                                                +-------------------+
+--R         4 4         3 2      2 2  +-+4+-+4+-+3 | 2 4         2    2
+--R     (64b x  + 128a b x  + 64a b )\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                   5 | 2 4         2    2       7      5
+--R                  x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  ---------------------------------------------------------
+--R                                            +-------------------+
+--R          3 6       2 4     2   2    3  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 1353
+t0:=x^(7/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            3 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 1353
+r0:=1/4*a*(a+b*x^2)*sqrt(x)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+   5/32*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*_
+   b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+5/32*(a+b*x^2)*atan(1+_
+   b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(9/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-5/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*_
+   b^(1/4)*sqrt(2)*sqrt(x))/(a^(3/4)*b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+5/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(3/4)*b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   9/16*sqrt(x)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R          2 4          2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 10a b x  + 5a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R            2 4          2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 10a b x  - 5a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  + \|a
+--R       (10b x  + 20a b x  + 10a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  - \|a
+--R       (10b x  + 20a b x  + 10a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R               2        +-+4+-+3 4+-+ +-+
+--R       (- 36b x  - 20a)\|2 \|a   \|b \|x
+--R  /
+--R                                     +-------------------+
+--R         3 2        2  +-+4+-+3 4+-+ | 2 4         2    2
+--R     (64b x  + 64a b )\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                        +--------------+
+--R             4 4         3 2      2 2   |        1
+--R         (80b x  + 160a b x  + 80a b )  |- ------------
+--R                                       4|           3 9
+--R                                       \|  16777216a b
+--R      *
+--R                            +--------------+
+--R              +-+        2  |        1
+--R         log(\|x  + 64a b   |- ------------)
+--R                           4|           3 9
+--R                           \|  16777216a b
+--R     + 
+--R                                          +--------------+
+--R               4 4         3 2      2 2   |        1
+--R         (- 80b x  - 160a b x  - 80a b )  |- ------------
+--R                                         4|           3 9
+--R                                         \|  16777216a b
+--R      *
+--R                            +--------------+
+--R              +-+        2  |        1
+--R         log(\|x  - 64a b   |- ------------)
+--R                           4|           3 9
+--R                           \|  16777216a b
+--R     + 
+--R                                            +--------------+
+--R                4 4         3 2       2 2   |        1
+--R         (- 160b x  - 320a b x  - 160a b )  |- ------------
+--R                                           4|           3 9
+--R                                           \|  16777216a b
+--R      *
+--R                      +--------------+
+--R                   2  |        1
+--R              64a b   |- ------------
+--R                     4|           3 9
+--R                     \|  16777216a b
+--R         atan(-----------------------)
+--R                         +-+
+--R                        \|x
+--R     + 
+--R              2       +-+
+--R       (- 9b x  - 5a)\|x
+--R  /
+--R        4 4        3 2      2 2
+--R     16b x  + 32a b x  + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 525
+
+--S 526 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3 6        2 4      2   2     3      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 15a b x  - 15a b x  - 5a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                              +--------------+
+--R              4 4         3 2       2 2  +-+  |        1      4+-+3 4+-+
+--R         (320b x  + 640a b x  + 320a b )\|2   |- ------------ \|a   \|b
+--R                                             4|           3 9
+--R                                             \|  16777216a b
+--R      *
+--R          +-------------------+                   +--------------+
+--R          | 2 4         2    2      +-+        2  |        1
+--R         \|b x  + 2a b x  + a  log(\|x  + 64a b   |- ------------)
+--R                                                 4|           3 9
+--R                                                 \|  16777216a b
+--R     + 
+--R                                                +--------------+
+--R                4 4         3 2       2 2  +-+  |        1      4+-+3 4+-+
+--R         (- 320b x  - 640a b x  - 320a b )\|2   |- ------------ \|a   \|b
+--R                                               4|           3 9
+--R                                               \|  16777216a b
+--R      *
+--R          +-------------------+                   +--------------+
+--R          | 2 4         2    2      +-+        2  |        1
+--R         \|b x  + 2a b x  + a  log(\|x  - 64a b   |- ------------)
+--R                                                 4|           3 9
+--R                                                 \|  16777216a b
+--R     + 
+--R          3 6        2 4      2   2     3        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 15a b x  + 15a b x  + 5a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R             3 6        2 4      2   2      3      \|2 \|b \|x  + \|a
+--R       (- 10b x  - 30a b x  - 30a b x  - 10a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R             3 6        2 4      2   2      3      \|2 \|b \|x  - \|a
+--R       (- 10b x  - 30a b x  - 30a b x  - 10a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                 +--------------+
+--R                4 4          3 2       2 2  +-+  |        1      4+-+3 4+-+
+--R         (- 640b x  - 1280a b x  - 640a b )\|2   |- ------------ \|a   \|b
+--R                                                4|           3 9
+--R                                                \|  16777216a b
+--R      *
+--R                                            +--------------+
+--R                                         2  |        1
+--R                                    64a b   |- ------------
+--R          +-------------------+            4|           3 9
+--R          | 2 4         2    2             \|  16777216a b
+--R         \|b x  + 2a b x  + a  atan(-----------------------)
+--R                                               +-+
+--R                                              \|x
+--R     + 
+--R                                          +-------------------+
+--R               2        +-+4+-+3 4+-+ +-+ | 2 4         2    2
+--R       (- 36b x  - 20a)\|2 \|a   \|b \|x \|b x  + 2a b x  + a
+--R     + 
+--R           2 4          2      2  +-+4+-+3 4+-+ +-+
+--R       (36b x  + 56a b x  + 20a )\|2 \|a   \|b \|x
+--R  /
+--R                                                 +-------------------+
+--R         4 4         3 2      2 2  +-+4+-+3 4+-+ | 2 4         2    2
+--R     (64b x  + 128a b x  + 64a b )\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                   4 | 2 4         2    2       6      4
+--R                  x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  ---------------------------------------------------------
+--R                                            +-------------------+
+--R          3 6       2 4     2   2    3  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 527
+
+)clear all
+
+--S 528 of 1353
+t0:=x^(5/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            2 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 528
+
+--S 529 of 1353
+r0:=1/4*x^(7/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-1/16*x^(3/2)/_
+   (a*b*sqrt(a^2+2*a*b*x^2+b^2*x^4))-3/32*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(5/4)*b^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   3/32*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*b^(7/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/64*(a+b*x^2)*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*b^(7/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-3/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*b^(7/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2 4         2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 6a b x  - 3a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R          2 4         2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 6a b x  + 3a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|b \|x  + \|a
+--R       (6b x  + 12a b x  + 6a )atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|b \|x  - \|a
+--R       (6b x  + 12a b x  + 6a )atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R             3         +-+4+-+4+-+3 +-+
+--R       (12b x  - 4a x)\|2 \|a \|b  \|x
+--R  /
+--R                                     +-------------------+
+--R           2 2      2   +-+4+-+4+-+3 | 2 4         2    2
+--R     (64a b x  + 64a b)\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                        +--------------+
+--R               3 4      2 2 2      3    |        1
+--R         (48a b x  + 96a b x  + 48a b)  |- ------------
+--R                                       4|           5 7
+--R                                       \|  16777216a b
+--R      *
+--R                                +--------------+3
+--R              +-+          4 5  |        1
+--R         log(\|x  + 262144a b   |- ------------ )
+--R                               4|           5 7
+--R                               \|  16777216a b
+--R     + 
+--R                                          +--------------+
+--R                 3 4      2 2 2      3    |        1
+--R         (- 48a b x  - 96a b x  - 48a b)  |- ------------
+--R                                         4|           5 7
+--R                                         \|  16777216a b
+--R      *
+--R                                +--------------+3
+--R              +-+          4 5  |        1
+--R         log(\|x  - 262144a b   |- ------------ )
+--R                               4|           5 7
+--R                               \|  16777216a b
+--R     + 
+--R                                         +--------------+
+--R               3 4       2 2 2      3    |        1
+--R         (96a b x  + 192a b x  + 96a b)  |- ------------
+--R                                        4|           5 7
+--R                                        \|  16777216a b
+--R      *
+--R                          +--------------+3
+--R                     4 5  |        1
+--R              262144a b   |- ------------
+--R                         4|           5 7
+--R                         \|  16777216a b
+--R         atan(----------------------------)
+--R                           +-+
+--R                          \|x
+--R     + 
+--R            3        +-+
+--R       (3b x  - a x)\|x
+--R  /
+--R          3 4      2 2 2      3
+--R     16a b x  + 32a b x  + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 530
+
+--S 531 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          3 6       2 4     2   2     3      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 9a b x  + 9a b x  + 3a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                               +--------------+
+--R                3 4       2 2 2       3   +-+  |        1      4+-+4+-+3
+--R         (192a b x  + 384a b x  + 192a b)\|2   |- ------------ \|a \|b
+--R                                              4|           5 7
+--R                                              \|  16777216a b
+--R      *
+--R          +-------------------+                       +--------------+3
+--R          | 2 4         2    2      +-+          4 5  |        1
+--R         \|b x  + 2a b x  + a  log(\|x  + 262144a b   |- ------------ )
+--R                                                     4|           5 7
+--R                                                     \|  16777216a b
+--R     + 
+--R                                                 +--------------+
+--R                  3 4       2 2 2       3   +-+  |        1      4+-+4+-+3
+--R         (- 192a b x  - 384a b x  - 192a b)\|2   |- ------------ \|a \|b
+--R                                                4|           5 7
+--R                                                \|  16777216a b
+--R      *
+--R          +-------------------+                       +--------------+3
+--R          | 2 4         2    2      +-+          4 5  |        1
+--R         \|b x  + 2a b x  + a  log(\|x  - 262144a b   |- ------------ )
+--R                                                     4|           5 7
+--R                                                     \|  16777216a b
+--R     + 
+--R            3 6       2 4     2   2     3        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 9a b x  - 9a b x  - 3a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R            3 6        2 4      2   2     3      \|2 \|b \|x  + \|a
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R            3 6        2 4      2   2     3      \|2 \|b \|x  - \|a
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R                                               +--------------+
+--R                3 4       2 2 2       3   +-+  |        1      4+-+4+-+3
+--R         (384a b x  + 768a b x  + 384a b)\|2   |- ------------ \|a \|b
+--R                                              4|           5 7
+--R                                              \|  16777216a b
+--R      *
+--R                                                +--------------+3
+--R                                           4 5  |        1
+--R                                    262144a b   |- ------------
+--R          +-------------------+                4|           5 7
+--R          | 2 4         2    2                 \|  16777216a b
+--R         \|b x  + 2a b x  + a  atan(----------------------------)
+--R                                                 +-+
+--R                                                \|x
+--R     + 
+--R                                        +-------------------+
+--R             3         +-+4+-+4+-+3 +-+ | 2 4         2    2
+--R       (12b x  - 4a x)\|2 \|a \|b  \|x \|b x  + 2a b x  + a
+--R     + 
+--R             2 5         3     2   +-+4+-+4+-+3 +-+
+--R       (- 12b x  - 8a b x  + 4a x)\|2 \|a \|b  \|x
+--R  /
+--R                                                 +-------------------+
+--R           3 4       2 2 2      3   +-+4+-+4+-+3 | 2 4         2    2
+--R     (64a b x  + 128a b x  + 64a b)\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                   3 | 2 4         2    2       5      3
+--R                  x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  ---------------------------------------------------------
+--R                                            +-------------------+
+--R          3 6       2 4     2   2    3  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 532
+
+)clear all
+
+--S 533 of 1353
+t0:=x^(3/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                             +-+
+--R                           x\|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 1353
+r0:=1/4*x^(5/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-3/32*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(5/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/32*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(7/4)*b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   3/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(7/4)*b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/64*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(7/4)*b^(5/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-3/16*sqrt(x)/(a*b*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R          2 4         2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 6a b x  + 3a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R            2 4         2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 6a b x  - 3a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|b \|x  + \|a
+--R       (6b x  + 12a b x  + 6a )atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|b \|x  - \|a
+--R       (6b x  + 12a b x  + 6a )atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R            2        +-+4+-+3 4+-+ +-+
+--R       (4b x  - 12a)\|2 \|a   \|b \|x
+--R  /
+--R                                      +-------------------+
+--R           2 2      2   +-+4+-+3 4+-+ | 2 4         2    2
+--R     (64a b x  + 64a b)\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                        +--------------+
+--R               3 4      2 2 2      3    |        1
+--R         (48a b x  + 96a b x  + 48a b)  |- ------------
+--R                                       4|           7 5
+--R                                       \|  16777216a b
+--R      *
+--R                           +--------------+
+--R              +-+      2   |        1
+--R         log(\|x  + 64a b  |- ------------)
+--R                          4|           7 5
+--R                          \|  16777216a b
+--R     + 
+--R                                          +--------------+
+--R                 3 4      2 2 2      3    |        1
+--R         (- 48a b x  - 96a b x  - 48a b)  |- ------------
+--R                                         4|           7 5
+--R                                         \|  16777216a b
+--R      *
+--R                           +--------------+
+--R              +-+      2   |        1
+--R         log(\|x  - 64a b  |- ------------)
+--R                          4|           7 5
+--R                          \|  16777216a b
+--R     + 
+--R                                           +--------------+
+--R                 3 4       2 2 2      3    |        1
+--R         (- 96a b x  - 192a b x  - 96a b)  |- ------------
+--R                                          4|           7 5
+--R                                          \|  16777216a b
+--R      *
+--R                     +--------------+
+--R                 2   |        1
+--R              64a b  |- ------------
+--R                    4|           7 5
+--R                    \|  16777216a b
+--R         atan(----------------------)
+--R                        +-+
+--R                       \|x
+--R     + 
+--R           2       +-+
+--R       (b x  - 3a)\|x
+--R  /
+--R          3 4      2 2 2      3
+--R     16a b x  + 32a b x  + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 535
+
+--S 536 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3 6       2 4     2   2     3      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 9a b x  - 9a b x  - 3a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                               +--------------+
+--R                3 4       2 2 2       3   +-+  |        1      4+-+3 4+-+
+--R         (192a b x  + 384a b x  + 192a b)\|2   |- ------------ \|a   \|b
+--R                                              4|           7 5
+--R                                              \|  16777216a b
+--R      *
+--R          +-------------------+                  +--------------+
+--R          | 2 4         2    2      +-+      2   |        1
+--R         \|b x  + 2a b x  + a  log(\|x  + 64a b  |- ------------)
+--R                                                4|           7 5
+--R                                                \|  16777216a b
+--R     + 
+--R                                                 +--------------+
+--R                  3 4       2 2 2       3   +-+  |        1      4+-+3 4+-+
+--R         (- 192a b x  - 384a b x  - 192a b)\|2   |- ------------ \|a   \|b
+--R                                                4|           7 5
+--R                                                \|  16777216a b
+--R      *
+--R          +-------------------+                  +--------------+
+--R          | 2 4         2    2      +-+      2   |        1
+--R         \|b x  + 2a b x  + a  log(\|x  - 64a b  |- ------------)
+--R                                                4|           7 5
+--R                                                \|  16777216a b
+--R     + 
+--R          3 6       2 4     2   2     3        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 9a b x  + 9a b x  + 3a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R            3 6        2 4      2   2     3      \|2 \|b \|x  + \|a
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R            3 6        2 4      2   2     3      \|2 \|b \|x  - \|a
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R                                                 +--------------+
+--R                  3 4       2 2 2       3   +-+  |        1      4+-+3 4+-+
+--R         (- 384a b x  - 768a b x  - 384a b)\|2   |- ------------ \|a   \|b
+--R                                                4|           7 5
+--R                                                \|  16777216a b
+--R      *
+--R                                           +--------------+
+--R                                       2   |        1
+--R                                    64a b  |- ------------
+--R          +-------------------+           4|           7 5
+--R          | 2 4         2    2            \|  16777216a b
+--R         \|b x  + 2a b x  + a  atan(----------------------)
+--R                                              +-+
+--R                                             \|x
+--R     + 
+--R                                       +-------------------+
+--R            2        +-+4+-+3 4+-+ +-+ | 2 4         2    2
+--R       (4b x  - 12a)\|2 \|a   \|b \|x \|b x  + 2a b x  + a
+--R     + 
+--R            2 4         2      2  +-+4+-+3 4+-+ +-+
+--R       (- 4b x  + 8a b x  + 12a )\|2 \|a   \|b \|x
+--R  /
+--R                                                  +-------------------+
+--R           3 4       2 2 2      3   +-+4+-+3 4+-+ | 2 4         2    2
+--R     (64a b x  + 128a b x  + 64a b)\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                   2 | 2 4         2    2       4      2
+--R                  x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  ---------------------------------------------------------
+--R                                            +-------------------+
+--R          3 6       2 4     2   2    3  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 537
+
+)clear all
+
+--S 538 of 1353
+t0:=sqrt(x)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                             +-+
+--R                            \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 1353
+r0:=1/4*x^(3/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/16*x^(3/2)/_
+   (a^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))-5/32*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+5/32*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(9/4)*b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+5/64*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(9/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-5/64*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(9/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2 4          2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 10a b x  - 5a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R          2 4          2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 10a b x  + 5a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  + \|a
+--R       (10b x  + 20a b x  + 10a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  - \|a
+--R       (10b x  + 20a b x  + 10a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R             3          +-+4+-+4+-+3 +-+
+--R       (20b x  + 36a x)\|2 \|a \|b  \|x
+--R  /
+--R                                    +-------------------+
+--R         2   2      3  +-+4+-+4+-+3 | 2 4         2    2
+--R     (64a b x  + 64a )\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                        +--------------+
+--R             2 2 4       3   2      4   |        1
+--R         (80a b x  + 160a b x  + 80a )  |- ------------
+--R                                       4|           9 3
+--R                                       \|  16777216a b
+--R      *
+--R                                +--------------+3
+--R              +-+          7 2  |        1
+--R         log(\|x  + 262144a b   |- ------------ )
+--R                               4|           9 3
+--R                               \|  16777216a b
+--R     + 
+--R                                          +--------------+
+--R               2 2 4       3   2      4   |        1
+--R         (- 80a b x  - 160a b x  - 80a )  |- ------------
+--R                                         4|           9 3
+--R                                         \|  16777216a b
+--R      *
+--R                                +--------------+3
+--R              +-+          7 2  |        1
+--R         log(\|x  - 262144a b   |- ------------ )
+--R                               4|           9 3
+--R                               \|  16777216a b
+--R     + 
+--R                                          +--------------+
+--R              2 2 4       3   2       4   |        1
+--R         (160a b x  + 320a b x  + 160a )  |- ------------
+--R                                         4|           9 3
+--R                                         \|  16777216a b
+--R      *
+--R                          +--------------+3
+--R                     7 2  |        1
+--R              262144a b   |- ------------
+--R                         4|           9 3
+--R                         \|  16777216a b
+--R         atan(----------------------------)
+--R                           +-+
+--R                          \|x
+--R     + 
+--R            3         +-+
+--R       (5b x  + 9a x)\|x
+--R  /
+--R        2 2 4      3   2      4
+--R     16a b x  + 32a b x  + 16a
+--R                                         Type: Union(Expression(Integer),...)
+--E 540
+
+--S 541 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          3 6        2 4      2   2     3      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 15a b x  + 15a b x  + 5a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                              +--------------+
+--R              2 2 4       3   2       4  +-+  |        1      4+-+4+-+3
+--R         (320a b x  + 640a b x  + 320a )\|2   |- ------------ \|a \|b
+--R                                             4|           9 3
+--R                                             \|  16777216a b
+--R      *
+--R          +-------------------+                       +--------------+3
+--R          | 2 4         2    2      +-+          7 2  |        1
+--R         \|b x  + 2a b x  + a  log(\|x  + 262144a b   |- ------------ )
+--R                                                     4|           9 3
+--R                                                     \|  16777216a b
+--R     + 
+--R                                                +--------------+
+--R                2 2 4       3   2       4  +-+  |        1      4+-+4+-+3
+--R         (- 320a b x  - 640a b x  - 320a )\|2   |- ------------ \|a \|b
+--R                                               4|           9 3
+--R                                               \|  16777216a b
+--R      *
+--R          +-------------------+                       +--------------+3
+--R          | 2 4         2    2      +-+          7 2  |        1
+--R         \|b x  + 2a b x  + a  log(\|x  - 262144a b   |- ------------ )
+--R                                                     4|           9 3
+--R                                                     \|  16777216a b
+--R     + 
+--R              3 6        2 4      2   2     3
+--R         (- 5b x  - 15a b x  - 15a b x  - 5a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R             3 6        2 4      2   2      3      \|2 \|b \|x  + \|a
+--R       (- 10b x  - 30a b x  - 30a b x  - 10a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R             3 6        2 4      2   2      3      \|2 \|b \|x  - \|a
+--R       (- 10b x  - 30a b x  - 30a b x  - 10a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                               +--------------+
+--R              2 2 4        3   2       4  +-+  |        1      4+-+4+-+3
+--R         (640a b x  + 1280a b x  + 640a )\|2   |- ------------ \|a \|b
+--R                                              4|           9 3
+--R                                              \|  16777216a b
+--R      *
+--R                                                +--------------+3
+--R                                           7 2  |        1
+--R                                    262144a b   |- ------------
+--R          +-------------------+                4|           9 3
+--R          | 2 4         2    2                 \|  16777216a b
+--R         \|b x  + 2a b x  + a  atan(----------------------------)
+--R                                                 +-+
+--R                                                \|x
+--R     + 
+--R                                         +-------------------+
+--R             3          +-+4+-+4+-+3 +-+ | 2 4         2    2
+--R       (20b x  + 36a x)\|2 \|a \|b  \|x \|b x  + 2a b x  + a
+--R     + 
+--R             2 5          3      2   +-+4+-+4+-+3 +-+
+--R       (- 20b x  - 56a b x  - 36a x)\|2 \|a \|b  \|x
+--R  /
+--R                                                +-------------------+
+--R         2 2 4       3   2      4  +-+4+-+4+-+3 | 2 4         2    2
+--R     (64a b x  + 128a b x  + 64a )\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                     | 2 4         2    2       3
+--R                   x\|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  ---------------------------------------------------------
+--R                                            +-------------------+
+--R          3 6       2 4     2   2    3  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 542
+
+)clear all
+
+--S 543 of 1353
+t0:=1/((a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x))
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R                                  +-------------------+
+--R          2 4         2    2  +-+ | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 1353
+r0:=1/4*(a+b*x^2)*sqrt(x)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-21/32*_
+   (a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(1/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+21/32*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))-21/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(11/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   21/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(11/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+7/16*sqrt(x)/_
+   (a^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R           2 4          2      2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 42a b x  + 21a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             2 4          2      2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21b x  - 42a b x  - 21a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  + \|a
+--R       (42b x  + 84a b x  + 42a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  - \|a
+--R       (42b x  + 84a b x  + 42a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R             2        +-+4+-+3 4+-+ +-+
+--R       (28b x  + 44a)\|2 \|a   \|b \|x
+--R  /
+--R                                     +-------------------+
+--R         2   2      3  +-+4+-+3 4+-+ | 2 4         2    2
+--R     (64a b x  + 64a )\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                          +--------------+
+--R              2 2 4       3   2       4   |        1
+--R         (336a b x  + 672a b x  + 336a )  |- ------------
+--R                                         4|           11
+--R                                         \|  16777216a  b
+--R      *
+--R                          +--------------+
+--R              +-+      3  |        1
+--R         log(\|x  + 64a   |- ------------)
+--R                         4|           11
+--R                         \|  16777216a  b
+--R     + 
+--R                                            +--------------+
+--R                2 2 4       3   2       4   |        1
+--R         (- 336a b x  - 672a b x  - 336a )  |- ------------
+--R                                           4|           11
+--R                                           \|  16777216a  b
+--R      *
+--R                          +--------------+
+--R              +-+      3  |        1
+--R         log(\|x  - 64a   |- ------------)
+--R                         4|           11
+--R                         \|  16777216a  b
+--R     + 
+--R                                             +--------------+
+--R                2 2 4        3   2       4   |        1
+--R         (- 672a b x  - 1344a b x  - 672a )  |- ------------
+--R                                            4|           11
+--R                                            \|  16777216a  b
+--R      *
+--R                    +--------------+
+--R                 3  |        1
+--R              64a   |- ------------
+--R                   4|           11
+--R                   \|  16777216a  b
+--R         atan(---------------------)
+--R                        +-+
+--R                       \|x
+--R     + 
+--R            2        +-+
+--R       (7b x  + 11a)\|x
+--R  /
+--R        2 2 4      3   2      4
+--R     16a b x  + 32a b x  + 16a
+--R                                         Type: Union(Expression(Integer),...)
+--E 545
+
+--S 546 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               3 6        2 4      2   2      3
+--R         (- 21b x  - 63a b x  - 63a b x  - 21a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                 +--------------+
+--R               2 2 4        3   2        4  +-+  |        1      4+-+3 4+-+
+--R         (1344a b x  + 2688a b x  + 1344a )\|2   |- ------------ \|a   \|b
+--R                                                4|           11
+--R                                                \|  16777216a  b
+--R      *
+--R          +-------------------+                 +--------------+
+--R          | 2 4         2    2      +-+      3  |        1
+--R         \|b x  + 2a b x  + a  log(\|x  + 64a   |- ------------)
+--R                                               4|           11
+--R                                               \|  16777216a  b
+--R     + 
+--R                                                   +--------------+
+--R                 2 2 4        3   2        4  +-+  |        1      4+-+3 4+-+
+--R         (- 1344a b x  - 2688a b x  - 1344a )\|2   |- ------------ \|a   \|b
+--R                                                  4|           11
+--R                                                  \|  16777216a  b
+--R      *
+--R          +-------------------+                 +--------------+
+--R          | 2 4         2    2      +-+      3  |        1
+--R         \|b x  + 2a b x  + a  log(\|x  - 64a   |- ------------)
+--R                                               4|           11
+--R                                               \|  16777216a  b
+--R     + 
+--R             3 6        2 4      2   2      3
+--R         (21b x  + 63a b x  + 63a b x  + 21a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R             3 6         2 4       2   2      3      \|2 \|b \|x  + \|a
+--R       (- 42b x  - 126a b x  - 126a b x  - 42a )atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|a
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R             3 6         2 4       2   2      3      \|2 \|b \|x  - \|a
+--R       (- 42b x  - 126a b x  - 126a b x  - 42a )atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|a
+--R     + 
+--R                                                   +--------------+
+--R                 2 2 4        3   2        4  +-+  |        1      4+-+3 4+-+
+--R         (- 2688a b x  - 5376a b x  - 2688a )\|2   |- ------------ \|a   \|b
+--R                                                  4|           11
+--R                                                  \|  16777216a  b
+--R      *
+--R                                          +--------------+
+--R                                       3  |        1
+--R                                    64a   |- ------------
+--R          +-------------------+          4|           11
+--R          | 2 4         2    2           \|  16777216a  b
+--R         \|b x  + 2a b x  + a  atan(---------------------)
+--R                                              +-+
+--R                                             \|x
+--R     + 
+--R                                        +-------------------+
+--R             2        +-+4+-+3 4+-+ +-+ | 2 4         2    2
+--R       (28b x  + 44a)\|2 \|a   \|b \|x \|b x  + 2a b x  + a
+--R     + 
+--R             2 4          2      2  +-+4+-+3 4+-+ +-+
+--R       (- 28b x  - 72a b x  - 44a )\|2 \|a   \|b \|x
+--R  /
+--R                                                 +-------------------+
+--R         2 2 4       3   2      4  +-+4+-+3 4+-+ | 2 4         2    2
+--R     (64a b x  + 128a b x  + 64a )\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                     | 2 4         2    2       2
+--R                    \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ---------------------------------------------------------
+--R                                            +-------------------+
+--R          3 6       2 4     2   2    3  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 547
+
+)clear all
+
+--S 548 of 1353
+t0:=1/(x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R                                   +-------------------+
+--R          2 5         3    2   +-+ | 2 4         2    2
+--R        (b x  + 2a b x  + a x)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 1353
+r0:=1/4*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x))+45/32*b^(1/4)*_
+   (a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-45/32*b^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   45/64*b^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/64*b^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+9/16/(a^2*sqrt(x)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-45/16*(a+b*x^2)/(a^3*sqrt(x)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R           2 4          2      2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45b x  + 90a b x  + 45a )\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               2 4          2      2 4+-+ +-+
+--R         (- 45b x  - 90a b x  - 45a )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (- 90b x  - 180a b x  - 90a )\|b \|x atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (- 90b x  - 180a b x  - 90a )\|b \|x atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R              2 4           2       2  +-+4+-+
+--R       (- 180b x  - 324a b x  - 128a )\|2 \|a
+--R  /
+--R                                   +-------------------+
+--R         3   2      4  +-+4+-+ +-+ | 2 4         2    2
+--R     (64a b x  + 64a )\|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         +-------------+
+--R               3 2 4      4   2      5   |    4100625b   +-+
+--R         (- 16a b x  - 32a b x  - 16a )  |- ----------- \|x
+--R                                        4|           13
+--R                                        \|  16777216a
+--R      *
+--R                                     +-------------+3
+--R                    +-+          10  |    4100625b
+--R         log(91125b\|x  + 262144a    |- ----------- )
+--R                                    4|           13
+--R                                    \|  16777216a
+--R     + 
+--R                                       +-------------+
+--R             3 2 4      4   2      5   |    4100625b   +-+
+--R         (16a b x  + 32a b x  + 16a )  |- ----------- \|x
+--R                                      4|           13
+--R                                      \|  16777216a
+--R      *
+--R                                     +-------------+3
+--R                    +-+          10  |    4100625b
+--R         log(91125b\|x  - 262144a    |- ----------- )
+--R                                    4|           13
+--R                                    \|  16777216a
+--R     + 
+--R                                         +-------------+
+--R               3 2 4      4   2      5   |    4100625b   +-+
+--R         (- 32a b x  - 64a b x  - 32a )  |- ----------- \|x
+--R                                        4|           13
+--R                                        \|  16777216a
+--R      *
+--R                         +-------------+3
+--R                     10  |    4100625b
+--R              262144a    |- -----------
+--R                        4|           13
+--R                        \|  16777216a
+--R         atan(--------------------------)
+--R                             +-+
+--R                      91125b\|x
+--R     + 
+--R            2 4          2      2
+--R       - 45b x  - 81a b x  - 32a
+--R  /
+--R         3 2 4      4   2      5  +-+
+--R     (16a b x  + 32a b x  + 16a )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 550
+
+--S 551 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               3 6         2 4       2   2      3 4+-+ +-+
+--R         (- 45b x  - 135a b x  - 135a b x  - 45a )\|b \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                              +-------------+
+--R               3 2 4       4   2      5  +-+  |    4100625b  4+-+ +-+
+--R         (- 64a b x  - 128a b x  - 64a )\|2   |- ----------- \|a \|x
+--R                                             4|           13
+--R                                             \|  16777216a
+--R      *
+--R          +-------------------+                            +-------------+3
+--R          | 2 4         2    2            +-+          10  |    4100625b
+--R         \|b x  + 2a b x  + a  log(91125b\|x  + 262144a    |- ----------- )
+--R                                                          4|           13
+--R                                                          \|  16777216a
+--R     + 
+--R                                            +-------------+
+--R             3 2 4       4   2      5  +-+  |    4100625b  4+-+ +-+
+--R         (64a b x  + 128a b x  + 64a )\|2   |- ----------- \|a \|x
+--R                                           4|           13
+--R                                           \|  16777216a
+--R      *
+--R          +-------------------+                            +-------------+3
+--R          | 2 4         2    2            +-+          10  |    4100625b
+--R         \|b x  + 2a b x  + a  log(91125b\|x  - 262144a    |- ----------- )
+--R                                                          4|           13
+--R                                                          \|  16777216a
+--R     + 
+--R             3 6         2 4       2   2      3 4+-+ +-+
+--R         (45b x  + 135a b x  + 135a b x  + 45a )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                            +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3 4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )\|b \|x atan(-------------------)
+--R                                                                   4+-+
+--R                                                                   \|a
+--R     + 
+--R                                                            +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3 4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )\|b \|x atan(-------------------)
+--R                                                                   4+-+
+--R                                                                   \|a
+--R     + 
+--R                                                +-------------+
+--R                3 2 4       4   2       5  +-+  |    4100625b  4+-+ +-+
+--R         (- 128a b x  - 256a b x  - 128a )\|2   |- ----------- \|a \|x
+--R                                               4|           13
+--R                                               \|  16777216a
+--R      *
+--R                                               +-------------+3
+--R                                           10  |    4100625b
+--R                                    262144a    |- -----------
+--R          +-------------------+               4|           13
+--R          | 2 4         2    2                \|  16777216a
+--R         \|b x  + 2a b x  + a  atan(--------------------------)
+--R                                                   +-+
+--R                                            91125b\|x
+--R     + 
+--R                                               +-------------------+
+--R              2 4           2       2  +-+4+-+ | 2 4         2    2
+--R       (- 180b x  - 324a b x  - 128a )\|2 \|a \|b x  + 2a b x  + a
+--R     + 
+--R            3 6         2 4       2   2       3  +-+4+-+
+--R       (180b x  + 504a b x  + 452a b x  + 128a )\|2 \|a
+--R  /
+--R                                               +-------------------+
+--R         3 2 4       4   2      5  +-+4+-+ +-+ | 2 4         2    2
+--R     (64a b x  + 128a b x  + 64a )\|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-------------------+
+--R                      | 2 4         2    2       2
+--R                     \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ----------------------------------------------------------
+--R                                             +-------------------+
+--R          3 7       2 5     2   3    3   +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a x)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 1353
+t0:=1/(x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                                1
+--R   (1)  -------------------------------------------------
+--R                                    +-------------------+
+--R          2 6         4    2 2  +-+ | 2 4         2    2
+--R        (b x  + 2a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 1353
+r0:=1/4*(a+b*x^2)/(a*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+   11/16/(a^2*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-77/48*(a+b*x^2)/_
+   (a^3*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/32*b^(3/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(15/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-77/32*b^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   77/64*b^(3/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-77/64*b^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                2 5           3       2  4+-+3 +-+
+--R         (- 231b x  - 462a b x  - 231a x)\|b  \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              2 5           3       2  4+-+3 +-+
+--R         (231b x  + 462a b x  + 231a x)\|b  \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R              2 5           3       2  4+-+3 +-+     \|2 \|b \|x  + \|a
+--R       (- 462b x  - 924a b x  - 462a x)\|b  \|x atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|a
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R              2 5           3       2  4+-+3 +-+     \|2 \|b \|x  - \|a
+--R       (- 462b x  - 924a b x  - 462a x)\|b  \|x atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|a
+--R     + 
+--R              2 4           2       2  +-+4+-+3
+--R       (- 308b x  - 484a b x  - 128a )\|2 \|a
+--R  /
+--R                                       +-------------------+
+--R          3   3       4   +-+4+-+3 +-+ | 2 4         2    2
+--R     (192a b x  + 192a x)\|2 \|a  \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                          +-------------+
+--R                                          |            3
+--R               3 2 5      4   3      5    |   35153041b   +-+
+--R         (- 48a b x  - 96a b x  - 48a x)  |- ----------- \|x
+--R                                         4|           15
+--R                                         \|  16777216a
+--R      *
+--R                             +-------------+
+--R                             |            3
+--R                 +-+      4  |   35153041b
+--R         log(77b\|x  + 64a   |- -----------)
+--R                            4|           15
+--R                            \|  16777216a
+--R     + 
+--R                                        +-------------+
+--R                                        |            3
+--R             3 2 5      4   3      5    |   35153041b   +-+
+--R         (48a b x  + 96a b x  + 48a x)  |- ----------- \|x
+--R                                       4|           15
+--R                                       \|  16777216a
+--R      *
+--R                             +-------------+
+--R                             |            3
+--R                 +-+      4  |   35153041b
+--R         log(77b\|x  - 64a   |- -----------)
+--R                            4|           15
+--R                            \|  16777216a
+--R     + 
+--R                                         +-------------+
+--R                                         |            3
+--R             3 2 5       4   3      5    |   35153041b   +-+
+--R         (96a b x  + 192a b x  + 96a x)  |- ----------- \|x
+--R                                        4|           15
+--R                                        \|  16777216a
+--R      *
+--R                    +-------------+
+--R                    |            3
+--R                 4  |   35153041b
+--R              64a   |- -----------
+--R                   4|           15
+--R                   \|  16777216a
+--R         atan(--------------------)
+--R                         +-+
+--R                     77b\|x
+--R     + 
+--R            2 4           2      2
+--R       - 77b x  - 121a b x  - 32a
+--R  /
+--R         3 2 5      4   3      5   +-+
+--R     (48a b x  + 96a b x  + 48a x)\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 555
+
+--S 556 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3 7         2 5       2   3       3  4+-+3 +-+
+--R         (231b x  + 693a b x  + 693a b x  + 231a x)\|b  \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                 +-------------+
+--R                                                 |            3
+--R                3 2 5       4   3       5   +-+  |   35153041b  4+-+3 +-+
+--R         (- 192a b x  - 384a b x  - 192a x)\|2   |- ----------- \|a  \|x
+--R                                                4|           15
+--R                                                \|  16777216a
+--R      *
+--R                                                   +-------------+
+--R          +-------------------+                    |            3
+--R          | 2 4         2    2         +-+      4  |   35153041b
+--R         \|b x  + 2a b x  + a  log(77b\|x  + 64a   |- -----------)
+--R                                                  4|           15
+--R                                                  \|  16777216a
+--R     + 
+--R                                               +-------------+
+--R                                               |            3
+--R              3 2 5       4   3       5   +-+  |   35153041b  4+-+3 +-+
+--R         (192a b x  + 384a b x  + 192a x)\|2   |- ----------- \|a  \|x
+--R                                              4|           15
+--R                                              \|  16777216a
+--R      *
+--R                                                   +-------------+
+--R          +-------------------+                    |            3
+--R          | 2 4         2    2         +-+      4  |   35153041b
+--R         \|b x  + 2a b x  + a  log(77b\|x  - 64a   |- -----------)
+--R                                                  4|           15
+--R                                                  \|  16777216a
+--R     + 
+--R                3 7         2 5       2   3       3  4+-+3 +-+
+--R         (- 231b x  - 693a b x  - 693a b x  - 231a x)\|b  \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              3 7          2 5        2   3       3  4+-+3 +-+
+--R         (462b x  + 1386a b x  + 1386a b x  + 462a x)\|b  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              3 7          2 5        2   3       3  4+-+3 +-+
+--R         (462b x  + 1386a b x  + 1386a b x  + 462a x)\|b  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                                               +-------------+
+--R                                               |            3
+--R              3 2 5       4   3       5   +-+  |   35153041b  4+-+3 +-+
+--R         (384a b x  + 768a b x  + 384a x)\|2   |- ----------- \|a  \|x
+--R                                              4|           15
+--R                                              \|  16777216a
+--R      *
+--R                                          +-------------+
+--R                                          |            3
+--R                                       4  |   35153041b
+--R                                    64a   |- -----------
+--R          +-------------------+          4|           15
+--R          | 2 4         2    2           \|  16777216a
+--R         \|b x  + 2a b x  + a  atan(--------------------)
+--R                                               +-+
+--R                                           77b\|x
+--R     + 
+--R                                                +-------------------+
+--R              2 4           2       2  +-+4+-+3 | 2 4         2    2
+--R       (- 308b x  - 484a b x  - 128a )\|2 \|a  \|b x  + 2a b x  + a
+--R     + 
+--R            3 6         2 4       2   2       3  +-+4+-+3
+--R       (308b x  + 792a b x  + 612a b x  + 128a )\|2 \|a
+--R  /
+--R                                                   +-------------------+
+--R          3 2 5       4   3       5   +-+4+-+3 +-+ | 2 4         2    2
+--R     (192a b x  + 384a b x  + 192a x)\|2 \|a  \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-------------------+
+--R                      | 2 4         2    2       2
+--R                     \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -----------------------------------------------------------
+--R                                              +-------------------+
+--R          3 8       2 6     2   4    3 2  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 557
+
+)clear all
+
+--S 558 of 1353
+t0:=1/(x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                                1
+--R   (1)  -------------------------------------------------
+--R                                    +-------------------+
+--R          2 7         5    2 3  +-+ | 2 4         2    2
+--R        (b x  + 2a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 1353
+r0:=1/4*(a+b*x^2)/(a*x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+   13/16/(a^2*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-117/80*(a+b*x^2)/_
+   (a^3*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-117/32*b^(5/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(17/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))+117/32*b^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   117/64*b^(5/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-117/64*b^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+117/16*b*(a+b*x^2)/_
+   (a^4*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                3 6          2 4       2   2 4+-+ +-+
+--R         (- 585b x  - 1170a b x  - 585a b x )\|b \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              3 6          2 4       2   2 4+-+ +-+
+--R         (585b x  + 1170a b x  + 585a b x )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                         +-+4+-+ +-+   4+-+
+--R             3 6          2 4        2   2 4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (1170b x  + 2340a b x  + 1170a b x )\|b \|x atan(-------------------)
+--R                                                                4+-+
+--R                                                                \|a
+--R     + 
+--R                                                         +-+4+-+ +-+   4+-+
+--R             3 6          2 4        2   2 4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (1170b x  + 2340a b x  + 1170a b x )\|b \|x atan(-------------------)
+--R                                                                4+-+
+--R                                                                \|a
+--R     + 
+--R             3 6          2 4        2   2       3  +-+4+-+
+--R       (2340b x  + 4212a b x  + 1664a b x  - 128a )\|2 \|a
+--R  /
+--R                                       +-------------------+
+--R          4   4       5 2  +-+4+-+ +-+ | 2 4         2    2
+--R     (320a b x  + 320a x )\|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                          +-------------+
+--R                                          |            5
+--R             4 2 6       5   4      6 2   |  187388721b   +-+
+--R         (80a b x  + 160a b x  + 80a x )  |- ----------- \|x
+--R                                         4|           17
+--R                                         \|  16777216a
+--R      *
+--R                                        +-------------+3
+--R                                        |            5
+--R                     4 +-+          13  |  187388721b
+--R         log(1601613b \|x  + 262144a    |- ----------- )
+--R                                       4|           17
+--R                                       \|  16777216a
+--R     + 
+--R                                            +-------------+
+--R                                            |            5
+--R               4 2 6       5   4      6 2   |  187388721b   +-+
+--R         (- 80a b x  - 160a b x  - 80a x )  |- ----------- \|x
+--R                                           4|           17
+--R                                           \|  16777216a
+--R      *
+--R                                        +-------------+3
+--R                                        |            5
+--R                     4 +-+          13  |  187388721b
+--R         log(1601613b \|x  - 262144a    |- ----------- )
+--R                                       4|           17
+--R                                       \|  16777216a
+--R     + 
+--R                                            +-------------+
+--R                                            |            5
+--R              4 2 6       5   4       6 2   |  187388721b   +-+
+--R         (160a b x  + 320a b x  + 160a x )  |- ----------- \|x
+--R                                           4|           17
+--R                                           \|  16777216a
+--R      *
+--R                         +-------------+3
+--R                         |            5
+--R                     13  |  187388721b
+--R              262144a    |- -----------
+--R                        4|           17
+--R                        \|  16777216a
+--R         atan(--------------------------)
+--R                             4 +-+
+--R                     1601613b \|x
+--R     + 
+--R           3 6          2 4       2   2      3
+--R       585b x  + 1053a b x  + 416a b x  - 32a
+--R  /
+--R         4 2 6       5   4      6 2  +-+
+--R     (80a b x  + 160a b x  + 80a x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 560
+
+--S 561 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              4 8          3 6        2 2 4       3   2 4+-+ +-+
+--R         (585b x  + 1755a b x  + 1755a b x  + 585a b x )\|b \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                +-------------+
+--R                                                |            5
+--R              4 2 6       5   4       6 2  +-+  |  187388721b  4+-+ +-+
+--R         (320a b x  + 640a b x  + 320a x )\|2   |- ----------- \|a \|x
+--R                                               4|           17
+--R                                               \|  16777216a
+--R      *
+--R                                                              +-------------+3
+--R          +-------------------+                               |            5
+--R          | 2 4         2    2             4 +-+          13  |  187388721b
+--R         \|b x  + 2a b x  + a  log(1601613b \|x  + 262144a    |- ----------- )
+--R                                                             4|           17
+--R                                                             \|  16777216a
+--R     + 
+--R                                                  +-------------+
+--R                                                  |            5
+--R                4 2 6       5   4       6 2  +-+  |  187388721b  4+-+ +-+
+--R         (- 320a b x  - 640a b x  - 320a x )\|2   |- ----------- \|a \|x
+--R                                                 4|           17
+--R                                                 \|  16777216a
+--R      *
+--R                                                              +-------------+3
+--R          +-------------------+                               |            5
+--R          | 2 4         2    2             4 +-+          13  |  187388721b
+--R         \|b x  + 2a b x  + a  log(1601613b \|x  - 262144a    |- ----------- )
+--R                                                             4|           17
+--R                                                             \|  16777216a
+--R     + 
+--R                4 8          3 6        2 2 4       3   2 4+-+ +-+
+--R         (- 585b x  - 1755a b x  - 1755a b x  - 585a b x )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 4 8          3 6        2 2 4        3   2 4+-+ +-+
+--R         (- 1170b x  - 3510a b x  - 3510a b x  - 1170a b x )\|b \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 4 8          3 6        2 2 4        3   2 4+-+ +-+
+--R         (- 1170b x  - 3510a b x  - 3510a b x  - 1170a b x )\|b \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                                                 +-------------+
+--R                                                 |            5
+--R              4 2 6        5   4       6 2  +-+  |  187388721b  4+-+ +-+
+--R         (640a b x  + 1280a b x  + 640a x )\|2   |- ----------- \|a \|x
+--R                                                4|           17
+--R                                                \|  16777216a
+--R      *
+--R                                               +-------------+3
+--R                                               |            5
+--R                                           13  |  187388721b
+--R                                    262144a    |- -----------
+--R          +-------------------+               4|           17
+--R          | 2 4         2    2                \|  16777216a
+--R         \|b x  + 2a b x  + a  atan(--------------------------)
+--R                                                   4 +-+
+--R                                           1601613b \|x
+--R     + 
+--R               3 6          2 4        2   2       3  +-+4+-+
+--R         (2340b x  + 4212a b x  + 1664a b x  - 128a )\|2 \|a
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               4 8          3 6        2 2 4        3   2       4  +-+4+-+
+--R       (- 2340b x  - 6552a b x  - 5876a b x  - 1536a b x  + 128a )\|2 \|a
+--R  /
+--R                                                   +-------------------+
+--R          4 2 6       5   4       6 2  +-+4+-+ +-+ | 2 4         2    2
+--R     (320a b x  + 640a b x  + 320a x )\|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-------------------+
+--R                      | 2 4         2    2       2
+--R                     \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -----------------------------------------------------------
+--R                                              +-------------------+
+--R          3 9       2 7     2   5    3 3  +-+ | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 562
+
+)clear all
+
+--S 563 of 1353
+t0:=x^(23/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                     11 +-+
+--R                                    x  \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 1353
+r0:=1/8*a*x^(17/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   11/32*x^(17/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+119/256*a*x^(9/2)*_
+   (a+b*x^2)/(b^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-2023/1024*x^(9/2)/(b^4*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+13923/5120*x^(5/2)*(a+b*x^2)/(b^5*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-13923/2048*a^(5/4)*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   13923/2048*a^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (b^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-13923/4096*a^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+13923/4096*a^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-13923/1024*a*(a+b*x^2)*_
+   sqrt(x)/(b^6*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                  4 8          2 3 6          3 2 4          4   2         5
+--R         (69615a b x  + 278460a b x  + 417690a b x  + 278460a b x  + 69615a )
+--R      *
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    4 8          2 3 6          3 2 4          4   2         5
+--R         (- 69615a b x  - 278460a b x  - 417690a b x  - 278460a b x  - 69615a )
+--R      *
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   4 8          2 3 6          3 2 4          4   2          5
+--R         (139230a b x  + 556920a b x  + 835380a b x  + 556920a b x  + 139230a )
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  + \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                   4 8          2 3 6          3 2 4          4   2          5
+--R         (139230a b x  + 556920a b x  + 835380a b x  + 556920a b x  + 139230a )
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  - \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                5 10            4 8          2 3 6           3 2 4
+--R           8192b x   - 172032a b x  - 882028a b x  - 1478932a b x
+--R         + 
+--R                     4   2          5
+--R           - 1058148a b x  - 278460a
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|b \|x
+--R  /
+--R              9 6           8 4         2 7 2         3 6  +-+4+-+
+--R       (20480b x  + 61440a b x  + 61440a b x  + 20480a b )\|2 \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 564
+
+--S 565 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               10 8           9 6         2 8 4         3 7 2        4 6
+--R         (5120b  x  + 20480a b x  + 30720a b x  + 20480a b x  + 5120a b )
+--R      *
+--R        +---------------------+                         +---------------------+
+--R        |                    5                          |                    5
+--R        |  37577794973305041a             +-+        6  |  37577794973305041a
+--R        |- ------------------- log(13923a\|x  + 4096b   |- -------------------)
+--R       4|                   25                         4|                   25
+--R       \|   281474976710656b                           \|   281474976710656b
+--R     + 
+--R                 10 8           9 6         2 8 4         3 7 2        4 6
+--R         (- 5120b  x  - 20480a b x  - 30720a b x  - 20480a b x  - 5120a b )
+--R      *
+--R        +---------------------+                         +---------------------+
+--R        |                    5                          |                    5
+--R        |  37577794973305041a             +-+        6  |  37577794973305041a
+--R        |- ------------------- log(13923a\|x  - 4096b   |- -------------------)
+--R       4|                   25                         4|                   25
+--R       \|   281474976710656b                           \|   281474976710656b
+--R     + 
+--R                  10 8           9 6         2 8 4         3 7 2         4 6
+--R         (- 10240b  x  - 40960a b x  - 61440a b x  - 40960a b x  - 10240a b )
+--R      *
+--R                                              +---------------------+
+--R                                              |                    5
+--R                                           6  |  37577794973305041a
+--R          +---------------------+     4096b   |- -------------------
+--R          |                    5             4|                   25
+--R          |  37577794973305041a              \|   281474976710656b
+--R          |- ------------------- atan(------------------------------)
+--R         4|                   25                       +-+
+--R         \|   281474976710656b                  13923a\|x
+--R     + 
+--R                5 10           4 8          2 3 6          3 2 4          4   2
+--R           2048b x   - 43008a b x  - 220507a b x  - 369733a b x  - 264537a b x
+--R         + 
+--R                   5
+--R           - 69615a
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R          10 8           9 6         2 8 4         3 7 2        4 6
+--R     5120b  x  + 20480a b x  + 30720a b x  + 20480a b x  + 5120a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 565
+
+--S 566 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     5 10          2 4 8          3 3 6          4 2 4
+--R           - 69615a b x   - 348075a b x  - 696150a b x  - 696150a b x
+--R         + 
+--R                    5   2         6
+--R           - 348075a b x  - 69615a
+--R      *
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                10 8           9 6          2 8 4         3 7 2         4 6  +-+
+--R         (20480b  x  + 81920a b x  + 122880a b x  + 81920a b x  + 20480a b )\|2
+--R      *
+--R          +---------------------+
+--R          |                    5      +-------------------+
+--R          |  37577794973305041a  4+-+ | 2 4         2    2
+--R          |- ------------------- \|b \|b x  + 2a b x  + a
+--R         4|                   25
+--R         \|   281474976710656b
+--R      *
+--R                                  +---------------------+
+--R                                  |                    5
+--R                    +-+        6  |  37577794973305041a
+--R         log(13923a\|x  + 4096b   |- -------------------)
+--R                                 4|                   25
+--R                                 \|   281474976710656b
+--R     + 
+--R                  10 8           9 6          2 8 4         3 7 2         4 6
+--R         (- 20480b  x  - 81920a b x  - 122880a b x  - 81920a b x  - 20480a b )
+--R      *
+--R               +---------------------+
+--R               |                    5      +-------------------+
+--R          +-+  |  37577794973305041a  4+-+ | 2 4         2    2
+--R         \|2   |- ------------------- \|b \|b x  + 2a b x  + a
+--R              4|                   25
+--R              \|   281474976710656b
+--R      *
+--R                                  +---------------------+
+--R                                  |                    5
+--R                    +-+        6  |  37577794973305041a
+--R         log(13923a\|x  - 4096b   |- -------------------)
+--R                                 4|                   25
+--R                                 \|   281474976710656b
+--R     + 
+--R                   5 10          2 4 8          3 3 6          4 2 4
+--R           69615a b x   + 348075a b x  + 696150a b x  + 696150a b x
+--R         + 
+--R                  5   2         6
+--R           348075a b x  + 69615a
+--R      *
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      5 10          2 4 8           3 3 6           4 2 4
+--R           - 139230a b x   - 696150a b x  - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    5   2          6
+--R           - 696150a b x  - 139230a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  + \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                      5 10          2 4 8           3 3 6           4 2 4
+--R           - 139230a b x   - 696150a b x  - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    5   2          6
+--R           - 696150a b x  - 139230a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  - \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                  10 8            9 6          2 8 4          3 7 2         4 6
+--R         (- 40960b  x  - 163840a b x  - 245760a b x  - 163840a b x  - 40960a b )
+--R      *
+--R               +---------------------+
+--R               |                    5      +-------------------+
+--R          +-+  |  37577794973305041a  4+-+ | 2 4         2    2
+--R         \|2   |- ------------------- \|b \|b x  + 2a b x  + a
+--R              4|                   25
+--R              \|   281474976710656b
+--R      *
+--R                      +---------------------+
+--R                      |                    5
+--R                   6  |  37577794973305041a
+--R              4096b   |- -------------------
+--R                     4|                   25
+--R                     \|   281474976710656b
+--R         atan(------------------------------)
+--R                               +-+
+--R                        13923a\|x
+--R     + 
+--R                5 10            4 8          2 3 6           3 2 4
+--R           8192b x   - 172032a b x  - 882028a b x  - 1478932a b x
+--R         + 
+--R                     4   2          5
+--R           - 1058148a b x  - 278460a
+--R      *
+--R                      +-------------------+
+--R          +-+4+-+ +-+ | 2 4         2    2
+--R         \|2 \|b \|x \|b x  + 2a b x  + a
+--R     + 
+--R                  6 12            5 10           2 4 8           3 3 6
+--R           - 8192b x   + 163840a b x   + 1054060a b x  + 2360960a b x
+--R         + 
+--R                   4 2 4           5   2          6
+--R           2537080a b x  + 1336608a b x  + 278460a
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|b \|x
+--R  /
+--R              10 8           9 6          2 8 4         3 7 2         4 6  +-+
+--R       (20480b  x  + 81920a b x  + 122880a b x  + 81920a b x  + 20480a b )\|2
+--R    *
+--R            +-------------------+
+--R       4+-+ | 2 4         2    2
+--R       \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R         +-------------------+
+--R      12 | 2 4         2    2       14      12
+--R     x  \|b x  + 2a b x  + a   - b x   - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 567
+
+)clear all
+
+--S 568 of 1353
+t0:=x^(21/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                     10 +-+
+--R                                    x  \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 1353
+r0:=1/8*a*x^(15/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   31/96*x^(15/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+95/256*a*x^(7/2)*_
+   (a+b*x^2)/(b^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-1425/1024*x^(7/2)/(b^4*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+7315/3072*x^(3/2)*(a+b*x^2)/(b^5*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+7315/2048*a^(3/4)*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(23/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   7315/2048*a^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (b^(23/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-7315/4096*a^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(23/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+7315/4096*a^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(23/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                4 8           3 6          2 2 4         3   2         4 4+-+3
+--R         (21945b x  + 87780a b x  + 131670a b x  + 87780a b x  + 21945a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  4 8           3 6          2 2 4         3   2         4 4+-+3
+--R         (- 21945b x  - 87780a b x  - 131670a b x  - 87780a b x  - 21945a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  4 8            3 6          2 2 4          3   2         4
+--R         (- 43890b x  - 175560a b x  - 263340a b x  - 175560a b x  - 43890a )
+--R      *
+--R                    +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  + \|a
+--R         \|a  atan(-------------------)
+--R                           4+-+
+--R                           \|a
+--R     + 
+--R                  4 8            3 6          2 2 4          3   2         4
+--R         (- 43890b x  - 175560a b x  - 263340a b x  - 175560a b x  - 43890a )
+--R      *
+--R                    +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  - \|a
+--R         \|a  atan(-------------------)
+--R                           4+-+
+--R                           \|a
+--R     + 
+--R               4 9           3 7          2 2 5          3   3         4   +-+
+--R         (8192b x  + 67868a b x  + 133380a b x  + 104500a b x  + 29260a x)\|2
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R              8 6           7 4         2 6 2         3 5  +-+4+-+3
+--R       (12288b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 9 8           8 6         2 7 4         3 6 2        4 5
+--R         (- 3072b x  - 12288a b x  - 18432a b x  - 12288a b x  - 3072a b )
+--R      *
+--R          +--------------------+
+--R          |                   3
+--R          |  2863237160100625a
+--R          |- ------------------
+--R         4|                  23
+--R         \|  281474976710656b
+--R      *
+--R                                                  +--------------------+3
+--R                                                  |                   3
+--R                          2 +-+               17  |  2863237160100625a
+--R         log(391419980875a \|x  + 68719476736b    |- ------------------ )
+--R                                                 4|                  23
+--R                                                 \|  281474976710656b
+--R     + 
+--R               9 8           8 6         2 7 4         3 6 2        4 5
+--R         (3072b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a b )
+--R      *
+--R          +--------------------+
+--R          |                   3
+--R          |  2863237160100625a
+--R          |- ------------------
+--R         4|                  23
+--R         \|  281474976710656b
+--R      *
+--R                                                  +--------------------+3
+--R                                                  |                   3
+--R                          2 +-+               17  |  2863237160100625a
+--R         log(391419980875a \|x  - 68719476736b    |- ------------------ )
+--R                                                 4|                  23
+--R                                                 \|  281474976710656b
+--R     + 
+--R                 9 8           8 6         2 7 4         3 6 2        4 5
+--R         (- 6144b x  - 24576a b x  - 36864a b x  - 24576a b x  - 6144a b )
+--R      *
+--R                                                     +--------------------+3
+--R                                                     |                   3
+--R                                                 17  |  2863237160100625a
+--R          +--------------------+     68719476736b    |- ------------------
+--R          |                   3                     4|                  23
+--R          |  2863237160100625a                      \|  281474976710656b
+--R          |- ------------------ atan(--------------------------------------)
+--R         4|                  23                             2 +-+
+--R         \|  281474976710656b                  391419980875a \|x
+--R     + 
+--R             4 9           3 7         2 2 5         3   3        4   +-+
+--R       (2048b x  + 16967a b x  + 33345a b x  + 26125a b x  + 7315a x)\|x
+--R  /
+--R          9 8           8 6         2 7 4         3 6 2        4 5
+--R     3072b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 570
+
+--S 571 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 10            4 8          2 3 6          3 2 4
+--R           - 21945b x   - 109725a b x  - 219450a b x  - 219450a b x
+--R         + 
+--R                    4   2         5
+--R           - 109725a b x  - 21945a
+--R      *
+--R         4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  9 8           8 6         2 7 4         3 6 2         4 5  +-+
+--R         (- 12288b x  - 49152a b x  - 73728a b x  - 49152a b x  - 12288a b )\|2
+--R      *
+--R          +--------------------+
+--R          |                   3       +-------------------+
+--R          |  2863237160100625a  4+-+3 | 2 4         2    2
+--R          |- ------------------ \|b  \|b x  + 2a b x  + a
+--R         4|                  23
+--R         \|  281474976710656b
+--R      *
+--R                                                  +--------------------+3
+--R                                                  |                   3
+--R                          2 +-+               17  |  2863237160100625a
+--R         log(391419980875a \|x  + 68719476736b    |- ------------------ )
+--R                                                 4|                  23
+--R                                                 \|  281474976710656b
+--R     + 
+--R                9 8           8 6         2 7 4         3 6 2         4 5  +-+
+--R         (12288b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a b )\|2
+--R      *
+--R          +--------------------+
+--R          |                   3       +-------------------+
+--R          |  2863237160100625a  4+-+3 | 2 4         2    2
+--R          |- ------------------ \|b  \|b x  + 2a b x  + a
+--R         4|                  23
+--R         \|  281474976710656b
+--R      *
+--R                                                  +--------------------+3
+--R                                                  |                   3
+--R                          2 +-+               17  |  2863237160100625a
+--R         log(391419980875a \|x  - 68719476736b    |- ------------------ )
+--R                                                 4|                  23
+--R                                                 \|  281474976710656b
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           21945b x   + 109725a b x  + 219450a b x  + 219450a b x
+--R         + 
+--R                  4   2         5
+--R           109725a b x  + 21945a
+--R      *
+--R         4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   2         5
+--R           219450a b x  + 43890a
+--R      *
+--R                    +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  + \|a
+--R         \|a  atan(-------------------)
+--R                           4+-+
+--R                           \|a
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   2         5
+--R           219450a b x  + 43890a
+--R      *
+--R                    +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  - \|a
+--R         \|a  atan(-------------------)
+--R                           4+-+
+--R                           \|a
+--R     + 
+--R                  9 8           8 6          2 7 4         3 6 2         4 5
+--R         (- 24576b x  - 98304a b x  - 147456a b x  - 98304a b x  - 24576a b )
+--R      *
+--R               +--------------------+
+--R               |                   3       +-------------------+
+--R          +-+  |  2863237160100625a  4+-+3 | 2 4         2    2
+--R         \|2   |- ------------------ \|b  \|b x  + 2a b x  + a
+--R              4|                  23
+--R              \|  281474976710656b
+--R      *
+--R                              +--------------------+3
+--R                              |                   3
+--R                          17  |  2863237160100625a
+--R              68719476736b    |- ------------------
+--R                             4|                  23
+--R                             \|  281474976710656b
+--R         atan(--------------------------------------)
+--R                                     2 +-+
+--R                        391419980875a \|x
+--R     + 
+--R               4 9           3 7          2 2 5          3   3         4   +-+
+--R         (8192b x  + 67868a b x  + 133380a b x  + 104500a b x  + 29260a x)\|2
+--R      *
+--R                   +-------------------+
+--R         4+-+3 +-+ | 2 4         2    2
+--R         \|b  \|x \|b x  + 2a b x  + a
+--R     + 
+--R                  5 11           4 9          2 3 7          3 2 5
+--R           - 8192b x   - 76060a b x  - 201248a b x  - 237880a b x
+--R         + 
+--R                    4   3         5
+--R           - 133760a b x  - 29260a x
+--R      *
+--R          +-+4+-+3 +-+
+--R         \|2 \|b  \|x
+--R  /
+--R              9 8           8 6         2 7 4         3 6 2         4 5  +-+
+--R       (12288b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a b )\|2
+--R    *
+--R             +-------------------+
+--R       4+-+3 | 2 4         2    2
+--R       \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R         +-------------------+
+--R      11 | 2 4         2    2       13      11
+--R     x  \|b x  + 2a b x  + a   - b x   - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 572
+
+)clear all
+
+--S 573 of 1353
+t0:=x^(19/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      9 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 1353
+r0:=1/8*a*x^(13/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   29/96*x^(13/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+221/768*a*x^(5/2)*_
+   (a+b*x^2)/(b^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-2873/3072*x^(5/2)/(b^4*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+3315/2048*a^(1/4)*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   3315/2048*a^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (b^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3315/4096*a^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-3315/4096*a^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3315/1024*(a+b*x^2)*_
+   sqrt(x)/(b^5*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                 4 8           3 6         2 2 4         3   2        4 4+-+
+--R         (- 9945b x  - 39780a b x  - 59670a b x  - 39780a b x  - 9945a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8           3 6         2 2 4         3   2        4 4+-+
+--R         (9945b x  + 39780a b x  + 59670a b x  + 39780a b x  + 9945a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  4 8           3 6          2 2 4         3   2         4 4+-+
+--R         (- 19890b x  - 79560a b x  - 119340a b x  - 79560a b x  - 19890a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  4 8           3 6          2 2 4         3   2         4 4+-+
+--R         (- 19890b x  - 79560a b x  - 119340a b x  - 79560a b x  - 19890a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                4 8            3 6          2 2 4          3   2         4  +-+
+--R         (24576b x  + 126004a b x  + 211276a b x  + 151164a b x  + 39780a )\|2
+--R      *
+--R         4+-+ +-+
+--R         \|b \|x
+--R  /
+--R              8 6           7 4         2 6 2         3 5  +-+4+-+
+--R       (12288b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 9 8           8 6         2 7 4         3 6 2        4 5
+--R         (- 3072b x  - 12288a b x  - 18432a b x  - 12288a b x  - 3072a b )
+--R      *
+--R          +--------------------+                       +--------------------+
+--R          |   120763066100625a           +-+        5  |   120763066100625a
+--R          |- ------------------ log(3315\|x  + 4096b   |- ------------------)
+--R         4|                  21                       4|                  21
+--R         \|  281474976710656b                         \|  281474976710656b
+--R     + 
+--R               9 8           8 6         2 7 4         3 6 2        4 5
+--R         (3072b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a b )
+--R      *
+--R          +--------------------+                       +--------------------+
+--R          |   120763066100625a           +-+        5  |   120763066100625a
+--R          |- ------------------ log(3315\|x  - 4096b   |- ------------------)
+--R         4|                  21                       4|                  21
+--R         \|  281474976710656b                         \|  281474976710656b
+--R     + 
+--R               9 8           8 6         2 7 4         3 6 2        4 5
+--R         (6144b x  + 24576a b x  + 36864a b x  + 24576a b x  + 6144a b )
+--R      *
+--R                                             +--------------------+
+--R                                          5  |   120763066100625a
+--R                                     4096b   |- ------------------
+--R          +--------------------+            4|                  21
+--R          |   120763066100625a              \|  281474976710656b
+--R          |- ------------------ atan(-----------------------------)
+--R         4|                  21                      +-+
+--R         \|  281474976710656b                   3315\|x
+--R     + 
+--R             4 8           3 6         2 2 4         3   2        4  +-+
+--R       (6144b x  + 31501a b x  + 52819a b x  + 37791a b x  + 9945a )\|x
+--R  /
+--R          9 8           8 6         2 7 4         3 6 2        4 5
+--R     3072b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 575
+
+--S 576 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           9945b x   + 49725a b x  + 99450a b x  + 99450a b x  + 49725a b x
+--R         + 
+--R                5
+--R           9945a
+--R      *
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  9 8           8 6         2 7 4         3 6 2         4 5  +-+
+--R         (- 12288b x  - 49152a b x  - 73728a b x  - 49152a b x  - 12288a b )\|2
+--R      *
+--R          +--------------------+     +-------------------+
+--R          |   120763066100625a  4+-+ | 2 4         2    2
+--R          |- ------------------ \|b \|b x  + 2a b x  + a
+--R         4|                  21
+--R         \|  281474976710656b
+--R      *
+--R                                +--------------------+
+--R                  +-+        5  |   120763066100625a
+--R         log(3315\|x  + 4096b   |- ------------------)
+--R                               4|                  21
+--R                               \|  281474976710656b
+--R     + 
+--R                9 8           8 6         2 7 4         3 6 2         4 5  +-+
+--R         (12288b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a b )\|2
+--R      *
+--R          +--------------------+     +-------------------+
+--R          |   120763066100625a  4+-+ | 2 4         2    2
+--R          |- ------------------ \|b \|b x  + 2a b x  + a
+--R         4|                  21
+--R         \|  281474976710656b
+--R      *
+--R                                +--------------------+
+--R                  +-+        5  |   120763066100625a
+--R         log(3315\|x  - 4096b   |- ------------------)
+--R                               4|                  21
+--R                               \|  281474976710656b
+--R     + 
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 9945b x   - 49725a b x  - 99450a b x  - 99450a b x  - 49725a b x
+--R         + 
+--R                  5
+--R           - 9945a
+--R      *
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  + \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  - \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                9 8           8 6          2 7 4         3 6 2         4 5  +-+
+--R         (24576b x  + 98304a b x  + 147456a b x  + 98304a b x  + 24576a b )\|2
+--R      *
+--R          +--------------------+     +-------------------+
+--R          |   120763066100625a  4+-+ | 2 4         2    2
+--R          |- ------------------ \|b \|b x  + 2a b x  + a
+--R         4|                  21
+--R         \|  281474976710656b
+--R      *
+--R                      +--------------------+
+--R                   5  |   120763066100625a
+--R              4096b   |- ------------------
+--R                     4|                  21
+--R                     \|  281474976710656b
+--R         atan(-----------------------------)
+--R                              +-+
+--R                         3315\|x
+--R     + 
+--R                4 8            3 6          2 2 4          3   2         4  +-+
+--R         (24576b x  + 126004a b x  + 211276a b x  + 151164a b x  + 39780a )\|2
+--R      *
+--R                  +-------------------+
+--R         4+-+ +-+ | 2 4         2    2
+--R         \|b \|x \|b x  + 2a b x  + a
+--R     + 
+--R                   5 10            4 8          2 3 6          3 2 4
+--R           - 24576b x   - 150580a b x  - 337280a b x  - 362440a b x
+--R         + 
+--R                    4   2         5
+--R           - 190944a b x  - 39780a
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|b \|x
+--R  /
+--R              9 8           8 6         2 7 4         3 6 2         4 5  +-+4+-+
+--R       (12288b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a b )\|2 \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R         +-------------------+
+--R      10 | 2 4         2    2       12      10
+--R     x  \|b x  + 2a b x  + a   - b x   - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 577
+
+)clear all
+
+--S 578 of 1353
+t0:=x^(17/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      8 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 1353
+r0:=1/8*a*x^(11/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   9/32*x^(11/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+55/256*a*x^(3/2)*_
+   (a+b*x^2)/(b^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-605/1024*x^(3/2)/(b^4*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-1155/2048*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(1/4)*b^(19/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+1155/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(1/4)*b^(19/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1155/4096*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(1/4)*b^(19/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1155/4096*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(1/4)*b^(19/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                 4 8          3 6        2 2 4        3   2        4
+--R         (- 1155b x  - 4620a b x  - 6930a b x  - 4620a b x  - 1155a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1155b x  + 4620a b x  + 6930a b x  + 4620a b x  + 1155a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8          3 6         2 2 4        3   2        4
+--R         (2310b x  + 9240a b x  + 13860a b x  + 9240a b x  + 2310a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6         2 2 4        3   2        4
+--R         (2310b x  + 9240a b x  + 13860a b x  + 9240a b x  + 2310a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               3 7          2 5        2   3        3   +-+4+-+4+-+3 +-+
+--R       (- 3572b x  - 7020a b x  - 5500a b x  - 1540a x)\|2 \|a \|b  \|x
+--R  /
+--R             7 6           6 4         2 5 2        3 4  +-+4+-+4+-+3
+--R       (4096b x  + 12288a b x  + 12288a b x  + 4096a b )\|2 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   8 8             7 6           2 6 4           3 5 2
+--R           1182720b x  + 4730880a b x  + 7096320a b x  + 4730880a b x
+--R         + 
+--R                   4 4
+--R           1182720a b
+--R      *
+--R          +----------------------+
+--R          |            1
+--R          |- --------------------
+--R         4|                    19
+--R         \|  281474976710656a b
+--R      *
+--R                                      +----------------------+3
+--R              +-+                 14  |            1
+--R         log(\|x  + 68719476736a b    |- -------------------- )
+--R                                     4|                    19
+--R                                     \|  281474976710656a b
+--R     + 
+--R                     8 8             7 6           2 6 4           3 5 2
+--R           - 1182720b x  - 4730880a b x  - 7096320a b x  - 4730880a b x
+--R         + 
+--R                     4 4
+--R           - 1182720a b
+--R      *
+--R          +----------------------+
+--R          |            1
+--R          |- --------------------
+--R         4|                    19
+--R         \|  281474976710656a b
+--R      *
+--R                                      +----------------------+3
+--R              +-+                 14  |            1
+--R         log(\|x  - 68719476736a b    |- -------------------- )
+--R                                     4|                    19
+--R                                     \|  281474976710656a b
+--R     + 
+--R                   8 8             7 6            2 6 4           3 5 2
+--R           2365440b x  + 9461760a b x  + 14192640a b x  + 9461760a b x
+--R         + 
+--R                   4 4
+--R           2365440a b
+--R      *
+--R                                                       +----------------------+3
+--R                                                   14  |            1
+--R                                     68719476736a b    |- --------------------
+--R        +----------------------+                      4|                    19
+--R        |            1                                \|  281474976710656a b
+--R        |- -------------------- atan(------------------------------------------)
+--R       4|                    19                          +-+
+--R       \|  281474976710656a b                           \|x
+--R     + 
+--R              3 7          2 5        2   3       3   +-+
+--R       (- 893b x  - 1755a b x  - 1375a b x  - 385a x)\|x
+--R  /
+--R          8 8          7 6        2 6 4        3 5 2        4 4
+--R     1024b x  + 4096a b x  + 6144a b x  + 4096a b x  + 1024a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 580
+
+--S 581 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1155b x   + 5775a b x  + 11550a b x  + 11550a b x  + 5775a b x
+--R         + 
+--R                5
+--R           1155a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   8 8              7 6            2 6 4            3 5 2
+--R           4730880b x  + 18923520a b x  + 28385280a b x  + 18923520a b x
+--R         + 
+--R                   4 4
+--R           4730880a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                    19
+--R              \|  281474976710656a b
+--R      *
+--R                                      +----------------------+3
+--R              +-+                 14  |            1
+--R         log(\|x  + 68719476736a b    |- -------------------- )
+--R                                     4|                    19
+--R                                     \|  281474976710656a b
+--R     + 
+--R                     8 8              7 6            2 6 4            3 5 2
+--R           - 4730880b x  - 18923520a b x  - 28385280a b x  - 18923520a b x
+--R         + 
+--R                     4 4
+--R           - 4730880a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                    19
+--R              \|  281474976710656a b
+--R      *
+--R                                      +----------------------+3
+--R              +-+                 14  |            1
+--R         log(\|x  - 68719476736a b    |- -------------------- )
+--R                                     4|                    19
+--R                                     \|  281474976710656a b
+--R     + 
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1155b x   - 5775a b x  - 11550a b x  - 11550a b x  - 5775a b x
+--R         + 
+--R                  5
+--R           - 1155a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 2310b x   - 11550a b x  - 23100a b x  - 23100a b x  - 11550a b x
+--R         + 
+--R                  5
+--R           - 2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 2310b x   - 11550a b x  - 23100a b x  - 23100a b x  - 11550a b x
+--R         + 
+--R                  5
+--R           - 2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                   8 8              7 6            2 6 4            3 5 2
+--R           9461760b x  + 37847040a b x  + 56770560a b x  + 37847040a b x
+--R         + 
+--R                   4 4
+--R           9461760a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                    19
+--R              \|  281474976710656a b
+--R      *
+--R                                +----------------------+3
+--R                            14  |            1
+--R              68719476736a b    |- --------------------
+--R                               4|                    19
+--R                               \|  281474976710656a b
+--R         atan(------------------------------------------)
+--R                                  +-+
+--R                                 \|x
+--R     + 
+--R                 3 7          2 5        2   3        3   +-+4+-+4+-+3 +-+
+--R         (- 3572b x  - 7020a b x  - 5500a b x  - 1540a x)\|2 \|a \|b  \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               4 9           3 7         2 2 5        3   3        4   +-+4+-+
+--R         (3572b x  + 10592a b x  + 12520a b x  + 7040a b x  + 1540a x)\|2 \|a
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R             8 8           7 6         2 6 4         3 5 2        4 4  +-+4+-+
+--R       (4096b x  + 16384a b x  + 24576a b x  + 16384a b x  + 4096a b )\|2 \|a
+--R    *
+--R             +-------------------+
+--R       4+-+3 | 2 4         2    2
+--R       \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R        +-------------------+
+--R      9 | 2 4         2    2       11      9
+--R     x \|b x  + 2a b x  + a   - b x   - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 1353
+t0:=x^(15/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      7 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 1353
+r0:=1/8*a*x^(9/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   25/96*x^(9/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+39/256*a*(a+b*x^2)*_
+   sqrt(x)/(b^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-195/2048*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(17/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+195/2048*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))-195/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(3/4)*b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   195/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(3/4)*b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   351/1024*sqrt(x)/(b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (585b x  + 2340a b x  + 3510a b x  + 2340a b x  + 585a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                4 8          3 6        2 2 4        3   2       4
+--R         (- 585b x  - 2340a b x  - 3510a b x  - 2340a b x  - 585a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1170b x  + 4680a b x  + 7020a b x  + 4680a b x  + 1170a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1170b x  + 4680a b x  + 7020a b x  + 4680a b x  + 1170a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               3 6           2 4        2   2        3  +-+4+-+3 4+-+ +-+
+--R       (- 7412b x  - 12428a b x  - 8892a b x  - 2340a )\|2 \|a   \|b \|x
+--R  /
+--R              7 6           6 4         2 5 2         3 4  +-+4+-+3 4+-+
+--R       (12288b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    8 8             7 6           2 6 4           3 5 2
+--R             599040b x  + 2396160a b x  + 3594240a b x  + 2396160a b x
+--R           + 
+--R                    4 4
+--R             599040a b
+--R      *
+--R          +----------------------+                     +----------------------+
+--R          |            1               +-+          4  |            1
+--R          |- -------------------- log(\|x  + 4096a b   |- --------------------)
+--R         4|                  3 17                     4|                  3 17
+--R         \|  281474976710656a b                       \|  281474976710656a b
+--R     + 
+--R                    8 8             7 6           2 6 4           3 5 2
+--R           - 599040b x  - 2396160a b x  - 3594240a b x  - 2396160a b x
+--R         + 
+--R                    4 4
+--R           - 599040a b
+--R      *
+--R          +----------------------+                     +----------------------+
+--R          |            1               +-+          4  |            1
+--R          |- -------------------- log(\|x  - 4096a b   |- --------------------)
+--R         4|                  3 17                     4|                  3 17
+--R         \|  281474976710656a b                       \|  281474976710656a b
+--R     + 
+--R                     8 8             7 6           2 6 4           3 5 2
+--R           - 1198080b x  - 4792320a b x  - 7188480a b x  - 4792320a b x
+--R         + 
+--R                     4 4
+--R           - 1198080a b
+--R      *
+--R                                                 +----------------------+
+--R                                              4  |            1
+--R                                       4096a b   |- --------------------
+--R          +----------------------+              4|                  3 17
+--R          |            1                        \|  281474976710656a b
+--R          |- -------------------- atan(---------------------------------)
+--R         4|                  3 17                      +-+
+--R         \|  281474976710656a b                       \|x
+--R     + 
+--R               3 6          2 4        2   2       3  +-+
+--R       (- 1853b x  - 3107a b x  - 2223a b x  - 585a )\|x
+--R  /
+--R          8 8           7 6         2 6 4         3 5 2        4 4
+--R     3072b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 585
+
+--S 586 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 585b x   - 2925a b x  - 5850a b x  - 5850a b x  - 2925a b x
+--R           + 
+--R                   5
+--R             - 585a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   8 8             7 6            2 6 4           3 5 2
+--R           2396160b x  + 9584640a b x  + 14376960a b x  + 9584640a b x
+--R         + 
+--R                   4 4
+--R           2396160a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  3 17
+--R              \|  281474976710656a b
+--R      *
+--R                              +----------------------+
+--R              +-+          4  |            1
+--R         log(\|x  + 4096a b   |- --------------------)
+--R                             4|                  3 17
+--R                             \|  281474976710656a b
+--R     + 
+--R                     8 8             7 6            2 6 4           3 5 2
+--R           - 2396160b x  - 9584640a b x  - 14376960a b x  - 9584640a b x
+--R         + 
+--R                     4 4
+--R           - 2396160a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  3 17
+--R              \|  281474976710656a b
+--R      *
+--R                              +----------------------+
+--R              +-+          4  |            1
+--R         log(\|x  - 4096a b   |- --------------------)
+--R                             4|                  3 17
+--R                             \|  281474976710656a b
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (585b x   + 2925a b x  + 5850a b x  + 5850a b x  + 2925a b x  + 585a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1170b x   - 5850a b x  - 11700a b x  - 11700a b x  - 5850a b x
+--R         + 
+--R                  5
+--R           - 1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1170b x   - 5850a b x  - 11700a b x  - 11700a b x  - 5850a b x
+--R         + 
+--R                  5
+--R           - 1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                     8 8              7 6            2 6 4            3 5 2
+--R           - 4792320b x  - 19169280a b x  - 28753920a b x  - 19169280a b x
+--R         + 
+--R                     4 4
+--R           - 4792320a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  3 17
+--R              \|  281474976710656a b
+--R      *
+--R                        +----------------------+
+--R                     4  |            1
+--R              4096a b   |- --------------------
+--R                       4|                  3 17
+--R                       \|  281474976710656a b
+--R         atan(---------------------------------)
+--R                              +-+
+--R                             \|x
+--R     + 
+--R                 3 6           2 4        2   2        3  +-+4+-+3 4+-+ +-+
+--R         (- 7412b x  - 12428a b x  - 8892a b x  - 2340a )\|2 \|a   \|b \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               4 8           3 6         2 2 4         3   2        4  +-+4+-+3
+--R         (7412b x  + 19840a b x  + 21320a b x  + 11232a b x  + 2340a )\|2 \|a
+--R      *
+--R         4+-+ +-+
+--R         \|b \|x
+--R  /
+--R              8 8           7 6         2 6 4         3 5 2         4 4  +-+
+--R       (12288b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a b )\|2
+--R    *
+--R                  +-------------------+
+--R       4+-+3 4+-+ | 2 4         2    2
+--R       \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R        +-------------------+
+--R      8 | 2 4         2    2       10      8
+--R     x \|b x  + 2a b x  + a   - b x   - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 587
+
+)clear all
+
+--S 588 of 1353
+t0:=x^(13/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      6 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 588
+
+--S 589 of 1353
+r0:=1/8*a*x^(7/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   23/96*x^(7/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+77/768*x^(7/2)*_
+   (a+b*x^2)/(a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-77/3072*x^(3/2)/(a*b^3*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-77/2048*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(5/4)*b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   77/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*_
+   b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*_
+   b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-77/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*_
+   b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                4 8         3 6        2 2 4       3   2       4
+--R         (- 231b x  - 924a b x  - 1386a b x  - 924a b x  - 231a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (231b x  + 924a b x  + 1386a b x  + 924a b x  + 231a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (462b x  + 1848a b x  + 2772a b x  + 1848a b x  + 462a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (462b x  + 1848a b x  + 2772a b x  + 1848a b x  + 462a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 7          2 5        2   3       3   +-+4+-+4+-+3 +-+
+--R       (924b x  - 1404a b x  - 1100a b x  - 308a x)\|2 \|a \|b  \|x
+--R  /
+--R                6 6         2 5 4         3 4 2         4 3  +-+4+-+4+-+3
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      7 8          2 6 6           3 5 4          4 4 2
+--R             236544a b x  + 946176a b x  + 1419264a b x  + 946176a b x
+--R           + 
+--R                    5 3
+--R             236544a b
+--R      *
+--R          +----------------------+
+--R          |            1
+--R          |- --------------------
+--R         4|                  5 15
+--R         \|  281474976710656a b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               4 11  |            1
+--R         log(\|x  + 68719476736a b    |- -------------------- )
+--R                                     4|                  5 15
+--R                                     \|  281474976710656a b
+--R     + 
+--R                      7 8          2 6 6           3 5 4          4 4 2
+--R           - 236544a b x  - 946176a b x  - 1419264a b x  - 946176a b x
+--R         + 
+--R                    5 3
+--R           - 236544a b
+--R      *
+--R          +----------------------+
+--R          |            1
+--R          |- --------------------
+--R         4|                  5 15
+--R         \|  281474976710656a b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               4 11  |            1
+--R         log(\|x  - 68719476736a b    |- -------------------- )
+--R                                     4|                  5 15
+--R                                     \|  281474976710656a b
+--R     + 
+--R                    7 8           2 6 6           3 5 4           4 4 2
+--R           473088a b x  + 1892352a b x  + 2838528a b x  + 1892352a b x
+--R         + 
+--R                  5 3
+--R           473088a b
+--R      *
+--R                                                       +----------------------+3
+--R                                                 4 11  |            1
+--R                                     68719476736a b    |- --------------------
+--R        +----------------------+                      4|                  5 15
+--R        |            1                                \|  281474976710656a b
+--R        |- -------------------- atan(------------------------------------------)
+--R       4|                  5 15                          +-+
+--R       \|  281474976710656a b                           \|x
+--R     + 
+--R            3 7         2 5       2   3      3   +-+
+--R       (231b x  - 351a b x  - 275a b x  - 77a x)\|x
+--R  /
+--R            7 8         2 6 6         3 5 4         4 4 2        5 3
+--R     3072a b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 590
+
+--S 591 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (231b x   + 1155a b x  + 2310a b x  + 2310a b x  + 1155a b x  + 231a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    7 8           2 6 6           3 5 4           4 4 2
+--R           946176a b x  + 3784704a b x  + 5677056a b x  + 3784704a b x
+--R         + 
+--R                  5 3
+--R           946176a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  5 15
+--R              \|  281474976710656a b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               4 11  |            1
+--R         log(\|x  + 68719476736a b    |- -------------------- )
+--R                                     4|                  5 15
+--R                                     \|  281474976710656a b
+--R     + 
+--R                      7 8           2 6 6           3 5 4           4 4 2
+--R           - 946176a b x  - 3784704a b x  - 5677056a b x  - 3784704a b x
+--R         + 
+--R                    5 3
+--R           - 946176a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  5 15
+--R              \|  281474976710656a b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               4 11  |            1
+--R         log(\|x  - 68719476736a b    |- -------------------- )
+--R                                     4|                  5 15
+--R                                     \|  281474976710656a b
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 231b x   - 1155a b x  - 2310a b x  - 2310a b x  - 1155a b x
+--R           + 
+--R                   5
+--R             - 231a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 462b x   - 2310a b x  - 4620a b x  - 4620a b x  - 2310a b x
+--R           + 
+--R                   5
+--R             - 462a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 462b x   - 2310a b x  - 4620a b x  - 4620a b x  - 2310a b x
+--R           + 
+--R                   5
+--R             - 462a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                     7 8           2 6 6            3 5 4           4 4 2
+--R           1892352a b x  + 7569408a b x  + 11354112a b x  + 7569408a b x
+--R         + 
+--R                   5 3
+--R           1892352a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  5 15
+--R              \|  281474976710656a b
+--R      *
+--R                                +----------------------+3
+--R                          4 11  |            1
+--R              68719476736a b    |- --------------------
+--R                               4|                  5 15
+--R                               \|  281474976710656a b
+--R         atan(------------------------------------------)
+--R                                  +-+
+--R                                 \|x
+--R     + 
+--R              3 7          2 5        2   3       3   +-+4+-+4+-+3 +-+
+--R         (924b x  - 1404a b x  - 1100a b x  - 308a x)\|2 \|a \|b  \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 9         3 7        2 2 5        3   3       4   +-+4+-+4+-+3 +-+
+--R     (- 924b x  + 480a b x  + 2504a b x  + 1408a b x  + 308a x)\|2 \|a \|b  \|x
+--R  /
+--R                7 8         2 6 6         3 5 4         4 4 2         5 3  +-+
+--R       (12288a b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a b )\|2
+--R    *
+--R                 +-------------------+
+--R       4+-+4+-+3 | 2 4         2    2
+--R       \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R        +-------------------+
+--R      7 | 2 4         2    2       9      7
+--R     x \|b x  + 2a b x  + a   - b x  - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 592
+
+)clear all
+
+--S 593 of 1353
+t0:=x^(11/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      5 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 1353
+r0:=1/8*a*x^(5/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   7/32*x^(5/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+15/256*x^(5/2)*_
+   (a+b*x^2)/(a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-45/2048*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(13/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/2048*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))-45/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(7/4)*b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   45/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(7/4)*b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   45/1024*sqrt(x)/(a*b^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (45b x  + 180a b x  + 270a b x  + 180a b x  + 45a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8         3 6       2 2 4       3   2      4
+--R         (- 45b x  - 180a b x  - 270a b x  - 180a b x  - 45a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (90b x  + 360a b x  + 540a b x  + 360a b x  + 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (90b x  + 360a b x  + 540a b x  + 360a b x  + 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R           3 6         2 4       2   2       3  +-+4+-+3 4+-+ +-+
+--R       (60b x  - 956a b x  - 684a b x  - 180a )\|2 \|a   \|b \|x
+--R  /
+--R               6 6         2 5 4         3 4 2        4 3  +-+4+-+3 4+-+
+--R       (4096a b x  + 12288a b x  + 12288a b x  + 4096a b )\|2 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  7 8          2 6 6          3 5 4          4 4 2         5 3
+--R         (46080a b x  + 184320a b x  + 276480a b x  + 184320a b x  + 46080a b )
+--R      *
+--R          +----------------------+                     +----------------------+
+--R          |            1               +-+        2 3  |            1
+--R          |- -------------------- log(\|x  + 4096a b   |- --------------------)
+--R         4|                  7 13                     4|                  7 13
+--R         \|  281474976710656a b                       \|  281474976710656a b
+--R     + 
+--R                       7 8          2 6 6          3 5 4          4 4 2
+--R             - 46080a b x  - 184320a b x  - 276480a b x  - 184320a b x
+--R           + 
+--R                     5 3
+--R             - 46080a b
+--R      *
+--R          +----------------------+                     +----------------------+
+--R          |            1               +-+        2 3  |            1
+--R          |- -------------------- log(\|x  - 4096a b   |- --------------------)
+--R         4|                  7 13                     4|                  7 13
+--R         \|  281474976710656a b                       \|  281474976710656a b
+--R     + 
+--R                       7 8          2 6 6          3 5 4          4 4 2
+--R             - 92160a b x  - 368640a b x  - 552960a b x  - 368640a b x
+--R           + 
+--R                     5 3
+--R             - 92160a b
+--R      *
+--R                                                 +----------------------+
+--R                                            2 3  |            1
+--R                                       4096a b   |- --------------------
+--R          +----------------------+              4|                  7 13
+--R          |            1                        \|  281474976710656a b
+--R          |- -------------------- atan(---------------------------------)
+--R         4|                  7 13                      +-+
+--R         \|  281474976710656a b                       \|x
+--R     + 
+--R           3 6         2 4       2   2      3  +-+
+--R       (15b x  - 239a b x  - 171a b x  - 45a )\|x
+--R  /
+--R            7 8        2 6 6        3 5 4        4 4 2        5 3
+--R     1024a b x  + 4096a b x  + 6144a b x  + 4096a b x  + 1024a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 595
+
+--S 596 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 45b x   - 225a b x  - 450a b x  - 450a b x  - 225a b x  - 45a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      7 8          2 6 6           3 5 4          4 4 2
+--R             184320a b x  + 737280a b x  + 1105920a b x  + 737280a b x
+--R           + 
+--R                    5 3
+--R             184320a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  7 13
+--R              \|  281474976710656a b
+--R      *
+--R                              +----------------------+
+--R              +-+        2 3  |            1
+--R         log(\|x  + 4096a b   |- --------------------)
+--R                             4|                  7 13
+--R                             \|  281474976710656a b
+--R     + 
+--R                      7 8          2 6 6           3 5 4          4 4 2
+--R           - 184320a b x  - 737280a b x  - 1105920a b x  - 737280a b x
+--R         + 
+--R                    5 3
+--R           - 184320a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  7 13
+--R              \|  281474976710656a b
+--R      *
+--R                              +----------------------+
+--R              +-+        2 3  |            1
+--R         log(\|x  - 4096a b   |- --------------------)
+--R                             4|                  7 13
+--R                             \|  281474976710656a b
+--R     + 
+--R             5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (45b x   + 225a b x  + 450a b x  + 450a b x  + 225a b x  + 45a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 90b x   - 450a b x  - 900a b x  - 900a b x  - 450a b x  - 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 90b x   - 450a b x  - 900a b x  - 900a b x  - 450a b x  - 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                      7 8           2 6 6           3 5 4           4 4 2
+--R           - 368640a b x  - 1474560a b x  - 2211840a b x  - 1474560a b x
+--R         + 
+--R                    5 3
+--R           - 368640a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  7 13
+--R              \|  281474976710656a b
+--R      *
+--R                        +----------------------+
+--R                   2 3  |            1
+--R              4096a b   |- --------------------
+--R                       4|                  7 13
+--R                       \|  281474976710656a b
+--R         atan(---------------------------------)
+--R                              +-+
+--R                             \|x
+--R     + 
+--R             3 6         2 4       2   2       3  +-+4+-+3 4+-+ +-+
+--R         (60b x  - 956a b x  - 684a b x  - 180a )\|2 \|a   \|b \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             4 8         3 6        2 2 4       3   2       4  +-+4+-+3 4+-+ +-+
+--R       (- 60b x  + 896a b x  + 1640a b x  + 864a b x  + 180a )\|2 \|a   \|b \|x
+--R  /
+--R               7 8         2 6 6         3 5 4         4 4 2        5 3  +-+
+--R       (4096a b x  + 16384a b x  + 24576a b x  + 16384a b x  + 4096a b )\|2
+--R    *
+--R                  +-------------------+
+--R       4+-+3 4+-+ | 2 4         2    2
+--R       \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R        +-------------------+
+--R      6 | 2 4         2    2       8      6
+--R     x \|b x  + 2a b x  + a   - b x  - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 597
+
+)clear all
+
+--S 598 of 1353
+t0:=x^(9/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      4 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 1353
+r0:=1/8*a*x^(3/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   19/96*x^(3/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+7/256*x^(3/2)*_
+   (a+b*x^2)/(a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+35/1024*x^(3/2)/_
+   (a^2*b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))-35/2048*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+35/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(9/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+35/4096*(a+_
+   b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(9/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-35/4096*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(9/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                4 8         3 6       2 2 4       3   2       4
+--R         (- 105b x  - 420a b x  - 630a b x  - 420a b x  - 105a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8         3 6       2 2 4       3   2       4
+--R         (105b x  + 420a b x  + 630a b x  + 420a b x  + 105a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (210b x  + 840a b x  + 1260a b x  + 840a b x  + 210a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (210b x  + 840a b x  + 1260a b x  + 840a b x  + 210a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 7          2 5       2   3       3   +-+4+-+4+-+3 +-+
+--R       (420b x  + 1596a b x  - 500a b x  - 140a x)\|2 \|a \|b  \|x
+--R  /
+--R              2 5 6         3 4 4         4 3 2         5 2  +-+4+-+4+-+3
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    2 6 8          3 5 6          4 4 4          5 3 2
+--R             107520a b x  + 430080a b x  + 645120a b x  + 430080a b x
+--R           + 
+--R                    6 2
+--R             107520a b
+--R      *
+--R          +----------------------+
+--R          |            1
+--R          |- --------------------
+--R         4|                  9 11
+--R         \|  281474976710656a b
+--R      *
+--R                                     +----------------------+3
+--R              +-+               7 8  |            1
+--R         log(\|x  + 68719476736a b   |- -------------------- )
+--R                                    4|                  9 11
+--R                                    \|  281474976710656a b
+--R     + 
+--R                    2 6 8          3 5 6          4 4 4          5 3 2
+--R           - 107520a b x  - 430080a b x  - 645120a b x  - 430080a b x
+--R         + 
+--R                    6 2
+--R           - 107520a b
+--R      *
+--R          +----------------------+
+--R          |            1
+--R          |- --------------------
+--R         4|                  9 11
+--R         \|  281474976710656a b
+--R      *
+--R                                     +----------------------+3
+--R              +-+               7 8  |            1
+--R         log(\|x  - 68719476736a b   |- -------------------- )
+--R                                    4|                  9 11
+--R                                    \|  281474976710656a b
+--R     + 
+--R                    2 6 8          3 5 6           4 4 4          5 3 2
+--R             215040a b x  + 860160a b x  + 1290240a b x  + 860160a b x
+--R           + 
+--R                    6 2
+--R             215040a b
+--R      *
+--R                                                      +----------------------+3
+--R                                                 7 8  |            1
+--R                                     68719476736a b   |- --------------------
+--R        +----------------------+                     4|                  9 11
+--R        |            1                               \|  281474976710656a b
+--R        |- -------------------- atan(-----------------------------------------)
+--R       4|                  9 11                          +-+
+--R       \|  281474976710656a b                           \|x
+--R     + 
+--R            3 7         2 5       2   3      3   +-+
+--R       (105b x  + 399a b x  - 125a b x  - 35a x)\|x
+--R  /
+--R          2 6 8         3 5 6         4 4 4         5 3 2        6 2
+--R     3072a b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 600
+
+--S 601 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (105b x   + 525a b x  + 1050a b x  + 1050a b x  + 525a b x  + 105a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  2 6 8           3 5 6           4 4 4           5 3 2
+--R           430080a b x  + 1720320a b x  + 2580480a b x  + 1720320a b x
+--R         + 
+--R                  6 2
+--R           430080a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  9 11
+--R              \|  281474976710656a b
+--R      *
+--R                                     +----------------------+3
+--R              +-+               7 8  |            1
+--R         log(\|x  + 68719476736a b   |- -------------------- )
+--R                                    4|                  9 11
+--R                                    \|  281474976710656a b
+--R     + 
+--R                    2 6 8           3 5 6           4 4 4           5 3 2
+--R           - 430080a b x  - 1720320a b x  - 2580480a b x  - 1720320a b x
+--R         + 
+--R                    6 2
+--R           - 430080a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  9 11
+--R              \|  281474976710656a b
+--R      *
+--R                                     +----------------------+3
+--R              +-+               7 8  |            1
+--R         log(\|x  - 68719476736a b   |- -------------------- )
+--R                                    4|                  9 11
+--R                                    \|  281474976710656a b
+--R     + 
+--R                5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (- 105b x   - 525a b x  - 1050a b x  - 1050a b x  - 525a b x  - 105a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 210b x   - 1050a b x  - 2100a b x  - 2100a b x  - 1050a b x
+--R           + 
+--R                   5
+--R             - 210a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 210b x   - 1050a b x  - 2100a b x  - 2100a b x  - 1050a b x
+--R           + 
+--R                   5
+--R             - 210a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  2 6 8           3 5 6           4 4 4           5 3 2
+--R           860160a b x  + 3440640a b x  + 5160960a b x  + 3440640a b x
+--R         + 
+--R                  6 2
+--R           860160a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  9 11
+--R              \|  281474976710656a b
+--R      *
+--R                               +----------------------+3
+--R                          7 8  |            1
+--R              68719476736a b   |- --------------------
+--R                              4|                  9 11
+--R                              \|  281474976710656a b
+--R         atan(-----------------------------------------)
+--R                                  +-+
+--R                                 \|x
+--R     + 
+--R              3 7          2 5       2   3       3   +-+4+-+4+-+3 +-+
+--R         (420b x  + 1596a b x  - 500a b x  - 140a x)\|2 \|a \|b  \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 9          3 7        2 2 5       3   3       4   +-+4+-+4+-+3 +-+
+--R     (- 420b x  - 2016a b x  - 1096a b x  + 640a b x  + 140a x)\|2 \|a \|b  \|x
+--R  /
+--R              2 6 8         3 5 6         4 4 4         5 3 2         6 2  +-+
+--R       (12288a b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a b )\|2
+--R    *
+--R                 +-------------------+
+--R       4+-+4+-+3 | 2 4         2    2
+--R       \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R        +-------------------+
+--R      5 | 2 4         2    2       7      5
+--R     x \|b x  + 2a b x  + a   - b x  - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 602
+
+)clear all
+
+--S 603 of 1353
+t0:=x^(7/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      3 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 1353
+r0:=1/8*a*(a+b*x^2)*sqrt(x)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   17/96*sqrt(x)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/768*(a+b*x^2)*_
+   sqrt(x)/(a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-35/2048*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(9/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+35/2048*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))-35/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(11/4)*b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   35/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(11/4)*b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   35/3072*sqrt(x)/(a^2*b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              4 8         3 6       2 2 4       3   2       4
+--R         (105b x  + 420a b x  + 630a b x  + 420a b x  + 105a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                4 8         3 6       2 2 4       3   2       4
+--R         (- 105b x  - 420a b x  - 630a b x  - 420a b x  - 105a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (210b x  + 840a b x  + 1260a b x  + 840a b x  + 210a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (210b x  + 840a b x  + 1260a b x  + 840a b x  + 210a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 6         2 4        2   2       3  +-+4+-+3 4+-+ +-+
+--R       (140b x  + 500a b x  - 1596a b x  - 420a )\|2 \|a   \|b \|x
+--R  /
+--R              2 5 6         3 4 4         4 3 2         5 2  +-+4+-+3 4+-+
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    2 6 8          3 5 6          4 4 4          5 3 2
+--R             107520a b x  + 430080a b x  + 645120a b x  + 430080a b x
+--R           + 
+--R                    6 2
+--R             107520a b
+--R      *
+--R          +----------------------+                     +----------------------+
+--R          |            1               +-+        3 2  |            1
+--R          |- -------------------- log(\|x  + 4096a b   |- --------------------)
+--R         4|                  11 9                     4|                  11 9
+--R         \|  281474976710656a  b                      \|  281474976710656a  b
+--R     + 
+--R                    2 6 8          3 5 6          4 4 4          5 3 2
+--R           - 107520a b x  - 430080a b x  - 645120a b x  - 430080a b x
+--R         + 
+--R                    6 2
+--R           - 107520a b
+--R      *
+--R          +----------------------+                     +----------------------+
+--R          |            1               +-+        3 2  |            1
+--R          |- -------------------- log(\|x  - 4096a b   |- --------------------)
+--R         4|                  11 9                     4|                  11 9
+--R         \|  281474976710656a  b                      \|  281474976710656a  b
+--R     + 
+--R                    2 6 8          3 5 6           4 4 4          5 3 2
+--R           - 215040a b x  - 860160a b x  - 1290240a b x  - 860160a b x
+--R         + 
+--R                    6 2
+--R           - 215040a b
+--R      *
+--R                                                 +----------------------+
+--R                                            3 2  |            1
+--R                                       4096a b   |- --------------------
+--R          +----------------------+              4|                  11 9
+--R          |            1                        \|  281474976710656a  b
+--R          |- -------------------- atan(---------------------------------)
+--R         4|                  11 9                      +-+
+--R         \|  281474976710656a  b                      \|x
+--R     + 
+--R           3 6         2 4       2   2       3  +-+
+--R       (35b x  + 125a b x  - 399a b x  - 105a )\|x
+--R  /
+--R          2 6 8         3 5 6         4 4 4         5 3 2        6 2
+--R     3072a b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 605
+
+--S 606 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (- 105b x   - 525a b x  - 1050a b x  - 1050a b x  - 525a b x  - 105a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  2 6 8           3 5 6           4 4 4           5 3 2
+--R           430080a b x  + 1720320a b x  + 2580480a b x  + 1720320a b x
+--R         + 
+--R                  6 2
+--R           430080a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  11 9
+--R              \|  281474976710656a  b
+--R      *
+--R                              +----------------------+
+--R              +-+        3 2  |            1
+--R         log(\|x  + 4096a b   |- --------------------)
+--R                             4|                  11 9
+--R                             \|  281474976710656a  b
+--R     + 
+--R                    2 6 8           3 5 6           4 4 4           5 3 2
+--R           - 430080a b x  - 1720320a b x  - 2580480a b x  - 1720320a b x
+--R         + 
+--R                    6 2
+--R           - 430080a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  11 9
+--R              \|  281474976710656a  b
+--R      *
+--R                              +----------------------+
+--R              +-+        3 2  |            1
+--R         log(\|x  - 4096a b   |- --------------------)
+--R                             4|                  11 9
+--R                             \|  281474976710656a  b
+--R     + 
+--R              5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (105b x   + 525a b x  + 1050a b x  + 1050a b x  + 525a b x  + 105a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 210b x   - 1050a b x  - 2100a b x  - 2100a b x  - 1050a b x
+--R           + 
+--R                   5
+--R             - 210a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 210b x   - 1050a b x  - 2100a b x  - 2100a b x  - 1050a b x
+--R           + 
+--R                   5
+--R             - 210a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                    2 6 8           3 5 6           4 4 4           5 3 2
+--R           - 860160a b x  - 3440640a b x  - 5160960a b x  - 3440640a b x
+--R         + 
+--R                    6 2
+--R           - 860160a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  11 9
+--R              \|  281474976710656a  b
+--R      *
+--R                        +----------------------+
+--R                   3 2  |            1
+--R              4096a b   |- --------------------
+--R                       4|                  11 9
+--R                       \|  281474976710656a  b
+--R         atan(---------------------------------)
+--R                              +-+
+--R                             \|x
+--R     + 
+--R              3 6         2 4        2   2       3  +-+4+-+3 4+-+ +-+
+--R         (140b x  + 500a b x  - 1596a b x  - 420a )\|2 \|a   \|b \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 8         3 6        2 2 4        3   2       4  +-+4+-+3 4+-+ +-+
+--R     (- 140b x  - 640a b x  + 1096a b x  + 2016a b x  + 420a )\|2 \|a   \|b \|x
+--R  /
+--R              2 6 8         3 5 6         4 4 4         5 3 2         6 2  +-+
+--R       (12288a b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a b )\|2
+--R    *
+--R                  +-------------------+
+--R       4+-+3 4+-+ | 2 4         2    2
+--R       \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R        +-------------------+
+--R      4 | 2 4         2    2       6      4
+--R     x \|b x  + 2a b x  + a   - b x  - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 607
+
+)clear all
+
+--S 608 of 1353
+t0:=x^(5/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      2 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 1353
+r0:=1/8*x^(7/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-3/32*x^(3/2)/_
+   (a*b*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+9/256*x^(3/2)*(a+b*x^2)/(a^2*b*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))+45/1024*x^(3/2)/(a^3*b*sqrt(a^2+2*a*b*_
+   x^2+b^2*x^4))-45/2048*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(13/4)*b^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/2048*_
+   (a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*b^(7/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/4096*(a+b*x^2)*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(13/4)*b^(7/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-45/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(13/4)*b^(7/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R               4 8         3 6       2 2 4       3   2      4
+--R         (- 45b x  - 180a b x  - 270a b x  - 180a b x  - 45a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (45b x  + 180a b x  + 270a b x  + 180a b x  + 45a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (90b x  + 360a b x  + 540a b x  + 360a b x  + 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (90b x  + 360a b x  + 540a b x  + 360a b x  + 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 7         2 5       2   3      3   +-+4+-+4+-+3 +-+
+--R       (180b x  + 684a b x  + 956a b x  - 60a x)\|2 \|a \|b  \|x
+--R  /
+--R             3 4 6         4 3 4         5 2 2        6   +-+4+-+4+-+3
+--R       (4096a b x  + 12288a b x  + 12288a b x  + 4096a b)\|2 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 5 8          4 4 6          5 3 4          6 2 2         7
+--R         (46080a b x  + 184320a b x  + 276480a b x  + 184320a b x  + 46080a b)
+--R      *
+--R          +----------------------+
+--R          |            1
+--R          |- --------------------
+--R         4|                  13 7
+--R         \|  281474976710656a  b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               10 5  |            1
+--R         log(\|x  + 68719476736a  b   |- -------------------- )
+--R                                     4|                  13 7
+--R                                     \|  281474976710656a  b
+--R     + 
+--R                  3 5 8          4 4 6          5 3 4          6 2 2         7
+--R         (- 46080a b x  - 184320a b x  - 276480a b x  - 184320a b x  - 46080a b)
+--R      *
+--R          +----------------------+
+--R          |            1
+--R          |- --------------------
+--R         4|                  13 7
+--R         \|  281474976710656a  b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               10 5  |            1
+--R         log(\|x  - 68719476736a  b   |- -------------------- )
+--R                                     4|                  13 7
+--R                                     \|  281474976710656a  b
+--R     + 
+--R                3 5 8          4 4 6          5 3 4          6 2 2         7
+--R         (92160a b x  + 368640a b x  + 552960a b x  + 368640a b x  + 92160a b)
+--R      *
+--R                                                       +----------------------+3
+--R                                                 10 5  |            1
+--R                                     68719476736a  b   |- --------------------
+--R        +----------------------+                      4|                  13 7
+--R        |            1                                \|  281474976710656a  b
+--R        |- -------------------- atan(------------------------------------------)
+--R       4|                  13 7                          +-+
+--R       \|  281474976710656a  b                          \|x
+--R     + 
+--R           3 7         2 5       2   3      3   +-+
+--R       (45b x  + 171a b x  + 239a b x  - 15a x)\|x
+--R  /
+--R          3 5 8        4 4 6        5 3 4        6 2 2        7
+--R     1024a b x  + 4096a b x  + 6144a b x  + 4096a b x  + 1024a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 610
+
+--S 611 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (45b x   + 225a b x  + 450a b x  + 450a b x  + 225a b x  + 45a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    3 5 8          4 4 6           5 3 4          6 2 2
+--R             184320a b x  + 737280a b x  + 1105920a b x  + 737280a b x
+--R           + 
+--R                    7
+--R             184320a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  13 7
+--R              \|  281474976710656a  b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               10 5  |            1
+--R         log(\|x  + 68719476736a  b   |- -------------------- )
+--R                                     4|                  13 7
+--R                                     \|  281474976710656a  b
+--R     + 
+--R                    3 5 8          4 4 6           5 3 4          6 2 2
+--R           - 184320a b x  - 737280a b x  - 1105920a b x  - 737280a b x
+--R         + 
+--R                    7
+--R           - 184320a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  13 7
+--R              \|  281474976710656a  b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               10 5  |            1
+--R         log(\|x  - 68719476736a  b   |- -------------------- )
+--R                                     4|                  13 7
+--R                                     \|  281474976710656a  b
+--R     + 
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 45b x   - 225a b x  - 450a b x  - 450a b x  - 225a b x  - 45a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 90b x   - 450a b x  - 900a b x  - 900a b x  - 450a b x  - 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 90b x   - 450a b x  - 900a b x  - 900a b x  - 450a b x  - 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  3 5 8           4 4 6           5 3 4           6 2 2
+--R           368640a b x  + 1474560a b x  + 2211840a b x  + 1474560a b x
+--R         + 
+--R                  7
+--R           368640a b
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  13 7
+--R              \|  281474976710656a  b
+--R      *
+--R                                +----------------------+3
+--R                          10 5  |            1
+--R              68719476736a  b   |- --------------------
+--R                               4|                  13 7
+--R                               \|  281474976710656a  b
+--R         atan(------------------------------------------)
+--R                                  +-+
+--R                                 \|x
+--R     + 
+--R              3 7         2 5       2   3      3   +-+4+-+4+-+3 +-+
+--R         (180b x  + 684a b x  + 956a b x  - 60a x)\|2 \|a \|b  \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 9         3 7        2 2 5       3   3      4   +-+4+-+4+-+3 +-+
+--R     (- 180b x  - 864a b x  - 1640a b x  - 896a b x  + 60a x)\|2 \|a \|b  \|x
+--R  /
+--R             3 5 8         4 4 6         5 3 4         6 2 2        7   +-+4+-+
+--R       (4096a b x  + 16384a b x  + 24576a b x  + 16384a b x  + 4096a b)\|2 \|a
+--R    *
+--R             +-------------------+
+--R       4+-+3 | 2 4         2    2
+--R       \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R        +-------------------+
+--R      3 | 2 4         2    2       5      3
+--R     x \|b x  + 2a b x  + a   - b x  - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 612
+
+)clear all
+
+--S 613 of 1353
+t0:=x^(3/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                       +-+
+--R                                     x\|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 1353
+r0:=1/8*x^(5/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-11/96*sqrt(x)/_
+   (a*b*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+11/768*(a+b*x^2)*sqrt(x)/(a^2*b*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))-77/2048*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(15/4)*b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   77/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(15/4)*_
+   b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-77/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(15/4)*_
+   b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(15/4)*_
+   b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/3072*sqrt(x)/(a^3*b*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (231b x  + 924a b x  + 1386a b x  + 924a b x  + 231a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                4 8         3 6        2 2 4       3   2       4
+--R         (- 231b x  - 924a b x  - 1386a b x  - 924a b x  - 231a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (462b x  + 1848a b x  + 2772a b x  + 1848a b x  + 462a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (462b x  + 1848a b x  + 2772a b x  + 1848a b x  + 462a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 6          2 4        2   2       3  +-+4+-+3 4+-+ +-+
+--R       (308b x  + 1100a b x  + 1404a b x  - 924a )\|2 \|a   \|b \|x
+--R  /
+--R              3 4 6         4 3 4         5 2 2         6   +-+4+-+3 4+-+
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a b)\|2 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 614
+
+--S 615 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    3 5 8          4 4 6           5 3 4          6 2 2
+--R             236544a b x  + 946176a b x  + 1419264a b x  + 946176a b x
+--R           + 
+--R                    7
+--R             236544a b
+--R      *
+--R          +----------------------+                    +----------------------+
+--R          |            1               +-+        4   |            1
+--R          |- -------------------- log(\|x  + 4096a b  |- --------------------)
+--R         4|                  15 5                    4|                  15 5
+--R         \|  281474976710656a  b                     \|  281474976710656a  b
+--R     + 
+--R                    3 5 8          4 4 6           5 3 4          6 2 2
+--R           - 236544a b x  - 946176a b x  - 1419264a b x  - 946176a b x
+--R         + 
+--R                    7
+--R           - 236544a b
+--R      *
+--R          +----------------------+                    +----------------------+
+--R          |            1               +-+        4   |            1
+--R          |- -------------------- log(\|x  - 4096a b  |- --------------------)
+--R         4|                  15 5                    4|                  15 5
+--R         \|  281474976710656a  b                     \|  281474976710656a  b
+--R     + 
+--R                    3 5 8           4 4 6           5 3 4           6 2 2
+--R           - 473088a b x  - 1892352a b x  - 2838528a b x  - 1892352a b x
+--R         + 
+--R                    7
+--R           - 473088a b
+--R      *
+--R                                                +----------------------+
+--R                                            4   |            1
+--R                                       4096a b  |- --------------------
+--R          +----------------------+             4|                  15 5
+--R          |            1                       \|  281474976710656a  b
+--R          |- -------------------- atan(--------------------------------)
+--R         4|                  15 5                     +-+
+--R         \|  281474976710656a  b                     \|x
+--R     + 
+--R           3 6         2 4       2   2       3  +-+
+--R       (77b x  + 275a b x  + 351a b x  - 231a )\|x
+--R  /
+--R          3 5 8         4 4 6         5 3 4         6 2 2        7
+--R     3072a b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 615
+
+--S 616 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 231b x   - 1155a b x  - 2310a b x  - 2310a b x  - 1155a b x
+--R           + 
+--R                   5
+--R             - 231a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  3 5 8           4 4 6           5 3 4           6 2 2
+--R           946176a b x  + 3784704a b x  + 5677056a b x  + 3784704a b x
+--R         + 
+--R                  7
+--R           946176a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  15 5
+--R              \|  281474976710656a  b
+--R      *
+--R                             +----------------------+
+--R              +-+        4   |            1
+--R         log(\|x  + 4096a b  |- --------------------)
+--R                            4|                  15 5
+--R                            \|  281474976710656a  b
+--R     + 
+--R                    3 5 8           4 4 6           5 3 4           6 2 2
+--R           - 946176a b x  - 3784704a b x  - 5677056a b x  - 3784704a b x
+--R         + 
+--R                    7
+--R           - 946176a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  15 5
+--R              \|  281474976710656a  b
+--R      *
+--R                             +----------------------+
+--R              +-+        4   |            1
+--R         log(\|x  - 4096a b  |- --------------------)
+--R                            4|                  15 5
+--R                            \|  281474976710656a  b
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (231b x   + 1155a b x  + 2310a b x  + 2310a b x  + 1155a b x  + 231a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 462b x   - 2310a b x  - 4620a b x  - 4620a b x  - 2310a b x
+--R           + 
+--R                   5
+--R             - 462a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 462b x   - 2310a b x  - 4620a b x  - 4620a b x  - 2310a b x
+--R           + 
+--R                   5
+--R             - 462a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                     3 5 8           4 4 6            5 3 4           6 2 2
+--R           - 1892352a b x  - 7569408a b x  - 11354112a b x  - 7569408a b x
+--R         + 
+--R                     7
+--R           - 1892352a b
+--R      *
+--R               +----------------------+           +-------------------+
+--R          +-+  |            1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- -------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  15 5
+--R              \|  281474976710656a  b
+--R      *
+--R                       +----------------------+
+--R                   4   |            1
+--R              4096a b  |- --------------------
+--R                      4|                  15 5
+--R                      \|  281474976710656a  b
+--R         atan(--------------------------------)
+--R                             +-+
+--R                            \|x
+--R     + 
+--R              3 6          2 4        2   2       3  +-+4+-+3 4+-+ +-+
+--R         (308b x  + 1100a b x  + 1404a b x  - 924a )\|2 \|a   \|b \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 8          3 6        2 2 4       3   2       4  +-+4+-+3 4+-+ +-+
+--R     (- 308b x  - 1408a b x  - 2504a b x  - 480a b x  + 924a )\|2 \|a   \|b \|x
+--R  /
+--R              3 5 8         4 4 6         5 3 4         6 2 2         7   +-+
+--R       (12288a b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a b)\|2
+--R    *
+--R                  +-------------------+
+--R       4+-+3 4+-+ | 2 4         2    2
+--R       \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R        +-------------------+
+--R      2 | 2 4         2    2       4      2
+--R     x \|b x  + 2a b x  + a   - b x  - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 617
+
+)clear all
+
+--S 618 of 1353
+t0:=sqrt(x)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                       +-+
+--R                                      \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 1353
+r0:=1/8*x^(3/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+13/96*x^(3/2)/_
+   (a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+39/256*x^(3/2)*(a+b*x^2)/(a^3*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))+195/1024*x^(3/2)/(a^4*sqrt(a^2+2*a*b*_
+   x^2+b^2*x^4))-195/2048*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(17/4)*b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   195/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(17/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+195/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(17/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-195/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(17/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                4 8          3 6        2 2 4        3   2       4
+--R         (- 585b x  - 2340a b x  - 3510a b x  - 2340a b x  - 585a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (585b x  + 2340a b x  + 3510a b x  + 2340a b x  + 585a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1170b x  + 4680a b x  + 7020a b x  + 4680a b x  + 1170a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1170b x  + 4680a b x  + 7020a b x  + 4680a b x  + 1170a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R             3 7          2 5         2   3        3   +-+4+-+4+-+3 +-+
+--R       (2340b x  + 8892a b x  + 12428a b x  + 7412a x)\|2 \|a \|b  \|x
+--R  /
+--R              4 3 6         5 2 4         6   2         7  +-+4+-+4+-+3
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a )\|2 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 619
+
+--S 620 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    4 4 8           5 3 6           6 2 4           7   2
+--R             599040a b x  + 2396160a b x  + 3594240a b x  + 2396160a b x
+--R           + 
+--R                    8
+--R             599040a
+--R      *
+--R          +----------------------+
+--R          |            1
+--R          |- --------------------
+--R         4|                  17 3
+--R         \|  281474976710656a  b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               13 2  |            1
+--R         log(\|x  + 68719476736a  b   |- -------------------- )
+--R                                     4|                  17 3
+--R                                     \|  281474976710656a  b
+--R     + 
+--R                    4 4 8           5 3 6           6 2 4           7   2
+--R           - 599040a b x  - 2396160a b x  - 3594240a b x  - 2396160a b x
+--R         + 
+--R                    8
+--R           - 599040a
+--R      *
+--R          +----------------------+
+--R          |            1
+--R          |- --------------------
+--R         4|                  17 3
+--R         \|  281474976710656a  b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               13 2  |            1
+--R         log(\|x  - 68719476736a  b   |- -------------------- )
+--R                                     4|                  17 3
+--R                                     \|  281474976710656a  b
+--R     + 
+--R                   4 4 8           5 3 6           6 2 4           7   2
+--R           1198080a b x  + 4792320a b x  + 7188480a b x  + 4792320a b x
+--R         + 
+--R                   8
+--R           1198080a
+--R      *
+--R                                                       +----------------------+3
+--R                                                 13 2  |            1
+--R                                     68719476736a  b   |- --------------------
+--R        +----------------------+                      4|                  17 3
+--R        |            1                                \|  281474976710656a  b
+--R        |- -------------------- atan(------------------------------------------)
+--R       4|                  17 3                          +-+
+--R       \|  281474976710656a  b                          \|x
+--R     + 
+--R            3 7          2 5        2   3        3   +-+
+--R       (585b x  + 2223a b x  + 3107a b x  + 1853a x)\|x
+--R  /
+--R          4 4 8         5 3 6         6 2 4         7   2        8
+--R     3072a b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a
+--R                                         Type: Union(Expression(Integer),...)
+--E 620
+
+--S 621 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (585b x   + 2925a b x  + 5850a b x  + 5850a b x  + 2925a b x  + 585a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   4 4 8           5 3 6            6 2 4           7   2
+--R           2396160a b x  + 9584640a b x  + 14376960a b x  + 9584640a b x
+--R         + 
+--R                   8
+--R           2396160a
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  17 3
+--R              \|  281474976710656a  b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               13 2  |            1
+--R         log(\|x  + 68719476736a  b   |- -------------------- )
+--R                                     4|                  17 3
+--R                                     \|  281474976710656a  b
+--R     + 
+--R                     4 4 8           5 3 6            6 2 4           7   2
+--R           - 2396160a b x  - 9584640a b x  - 14376960a b x  - 9584640a b x
+--R         + 
+--R                     8
+--R           - 2396160a
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  17 3
+--R              \|  281474976710656a  b
+--R      *
+--R                                      +----------------------+3
+--R              +-+               13 2  |            1
+--R         log(\|x  - 68719476736a  b   |- -------------------- )
+--R                                     4|                  17 3
+--R                                     \|  281474976710656a  b
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 585b x   - 2925a b x  - 5850a b x  - 5850a b x  - 2925a b x
+--R           + 
+--R                   5
+--R             - 585a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1170b x   - 5850a b x  - 11700a b x  - 11700a b x  - 5850a b x
+--R         + 
+--R                  5
+--R           - 1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1170b x   - 5850a b x  - 11700a b x  - 11700a b x  - 5850a b x
+--R         + 
+--R                  5
+--R           - 1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                   4 4 8            5 3 6            6 2 4            7   2
+--R           4792320a b x  + 19169280a b x  + 28753920a b x  + 19169280a b x
+--R         + 
+--R                   8
+--R           4792320a
+--R      *
+--R               +----------------------+          +-------------------+
+--R          +-+  |            1          4+-+4+-+3 | 2 4         2    2
+--R         \|2   |- -------------------- \|a \|b  \|b x  + 2a b x  + a
+--R              4|                  17 3
+--R              \|  281474976710656a  b
+--R      *
+--R                                +----------------------+3
+--R                          13 2  |            1
+--R              68719476736a  b   |- --------------------
+--R                               4|                  17 3
+--R                               \|  281474976710656a  b
+--R         atan(------------------------------------------)
+--R                                  +-+
+--R                                 \|x
+--R     + 
+--R               3 7          2 5         2   3        3   +-+4+-+4+-+3 +-+
+--R         (2340b x  + 8892a b x  + 12428a b x  + 7412a x)\|2 \|a \|b  \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                 4 9           3 7         2 2 5         3   3        4   +-+
+--R         (- 2340b x  - 11232a b x  - 21320a b x  - 19840a b x  - 7412a x)\|2
+--R      *
+--R         4+-+4+-+3 +-+
+--R         \|a \|b  \|x
+--R  /
+--R              4 4 8         5 3 6         6 2 4         7   2         8  +-+4+-+
+--R       (12288a b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a )\|2 \|a
+--R    *
+--R             +-------------------+
+--R       4+-+3 | 2 4         2    2
+--R       \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R       +-------------------+
+--R       | 2 4         2    2       3
+--R     x\|b x  + 2a b x  + a   - b x  - a x
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 622
+
+)clear all
+
+--S 623 of 1353
+t0:=1/((a^2+2*a*b*x^2+b^2*x^4)^(5/2)*sqrt(x))
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R                                                      +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  +-+ | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 1353
+r0:=1/8*(a+b*x^2)*sqrt(x)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+5/32*sqrt(x)/_
+   (a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+55/256*(a+b*x^2)*sqrt(x)/(a^3*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))-1155/2048*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(19/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+1155/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(19/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1155/4096*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(19/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1155/4096*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(19/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+385/1024*_
+   sqrt(x)/(a^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1155b x  + 4620a b x  + 6930a b x  + 4620a b x  + 1155a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 4 8          3 6        2 2 4        3   2        4
+--R         (- 1155b x  - 4620a b x  - 6930a b x  - 4620a b x  - 1155a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8          3 6         2 2 4        3   2        4
+--R         (2310b x  + 9240a b x  + 13860a b x  + 9240a b x  + 2310a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6         2 2 4        3   2        4
+--R         (2310b x  + 9240a b x  + 13860a b x  + 9240a b x  + 2310a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R             3 6          2 4        2   2        3  +-+4+-+3 4+-+ +-+
+--R       (1540b x  + 5500a b x  + 7020a b x  + 3572a )\|2 \|a   \|b \|x
+--R  /
+--R             4 3 6         5 2 4         6   2        7  +-+4+-+3 4+-+
+--R       (4096a b x  + 12288a b x  + 12288a b x  + 4096a )\|2 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 624
+
+--S 625 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   4 4 8           5 3 6           6 2 4           7   2
+--R           1182720a b x  + 4730880a b x  + 7096320a b x  + 4730880a b x
+--R         + 
+--R                   8
+--R           1182720a
+--R      *
+--R          +---------------------+                   +---------------------+
+--R          |           1               +-+        5  |           1
+--R          |- ------------------- log(\|x  + 4096a   |- -------------------)
+--R         4|                  19                    4|                  19
+--R         \|  281474976710656a  b                   \|  281474976710656a  b
+--R     + 
+--R                     4 4 8           5 3 6           6 2 4           7   2
+--R           - 1182720a b x  - 4730880a b x  - 7096320a b x  - 4730880a b x
+--R         + 
+--R                     8
+--R           - 1182720a
+--R      *
+--R          +---------------------+                   +---------------------+
+--R          |           1               +-+        5  |           1
+--R          |- ------------------- log(\|x  - 4096a   |- -------------------)
+--R         4|                  19                    4|                  19
+--R         \|  281474976710656a  b                   \|  281474976710656a  b
+--R     + 
+--R                     4 4 8           5 3 6            6 2 4           7   2
+--R           - 2365440a b x  - 9461760a b x  - 14192640a b x  - 9461760a b x
+--R         + 
+--R                     8
+--R           - 2365440a
+--R      *
+--R                                              +---------------------+
+--R                                           5  |           1
+--R                                      4096a   |- -------------------
+--R          +---------------------+            4|                  19
+--R          |           1                      \|  281474976710656a  b
+--R          |- ------------------- atan(------------------------------)
+--R         4|                  19                     +-+
+--R         \|  281474976710656a  b                   \|x
+--R     + 
+--R            3 6          2 4        2   2       3  +-+
+--R       (385b x  + 1375a b x  + 1755a b x  + 893a )\|x
+--R  /
+--R          4 4 8        5 3 6        6 2 4        7   2        8
+--R     1024a b x  + 4096a b x  + 6144a b x  + 4096a b x  + 1024a
+--R                                         Type: Union(Expression(Integer),...)
+--E 625
+
+--S 626 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1155b x   - 5775a b x  - 11550a b x  - 11550a b x  - 5775a b x
+--R         + 
+--R                  5
+--R           - 1155a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   4 4 8            5 3 6            6 2 4            7   2
+--R           4730880a b x  + 18923520a b x  + 28385280a b x  + 18923520a b x
+--R         + 
+--R                   8
+--R           4730880a
+--R      *
+--R               +---------------------+           +-------------------+
+--R          +-+  |           1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- ------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  19
+--R              \|  281474976710656a  b
+--R      *
+--R                            +---------------------+
+--R              +-+        5  |           1
+--R         log(\|x  + 4096a   |- -------------------)
+--R                           4|                  19
+--R                           \|  281474976710656a  b
+--R     + 
+--R                     4 4 8            5 3 6            6 2 4            7   2
+--R           - 4730880a b x  - 18923520a b x  - 28385280a b x  - 18923520a b x
+--R         + 
+--R                     8
+--R           - 4730880a
+--R      *
+--R               +---------------------+           +-------------------+
+--R          +-+  |           1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- ------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  19
+--R              \|  281474976710656a  b
+--R      *
+--R                            +---------------------+
+--R              +-+        5  |           1
+--R         log(\|x  - 4096a   |- -------------------)
+--R                           4|                  19
+--R                           \|  281474976710656a  b
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1155b x   + 5775a b x  + 11550a b x  + 11550a b x  + 5775a b x
+--R         + 
+--R                5
+--R           1155a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 2310b x   - 11550a b x  - 23100a b x  - 23100a b x  - 11550a b x
+--R         + 
+--R                  5
+--R           - 2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 2310b x   - 11550a b x  - 23100a b x  - 23100a b x  - 11550a b x
+--R         + 
+--R                  5
+--R           - 2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                     4 4 8            5 3 6            6 2 4            7   2
+--R           - 9461760a b x  - 37847040a b x  - 56770560a b x  - 37847040a b x
+--R         + 
+--R                     8
+--R           - 9461760a
+--R      *
+--R               +---------------------+           +-------------------+
+--R          +-+  |           1          4+-+3 4+-+ | 2 4         2    2
+--R         \|2   |- ------------------- \|a   \|b \|b x  + 2a b x  + a
+--R              4|                  19
+--R              \|  281474976710656a  b
+--R      *
+--R                      +---------------------+
+--R                   5  |           1
+--R              4096a   |- -------------------
+--R                     4|                  19
+--R                     \|  281474976710656a  b
+--R         atan(------------------------------)
+--R                            +-+
+--R                           \|x
+--R     + 
+--R               3 6          2 4        2   2        3  +-+4+-+3 4+-+ +-+
+--R         (1540b x  + 5500a b x  + 7020a b x  + 3572a )\|2 \|a   \|b \|x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                 4 8          3 6         2 2 4         3   2        4  +-+4+-+3
+--R         (- 1540b x  - 7040a b x  - 12520a b x  - 10592a b x  - 3572a )\|2 \|a
+--R      *
+--R         4+-+ +-+
+--R         \|b \|x
+--R  /
+--R             4 4 8         5 3 6         6 2 4         7   2        8  +-+4+-+3
+--R       (4096a b x  + 16384a b x  + 24576a b x  + 16384a b x  + 4096a )\|2 \|a
+--R    *
+--R            +-------------------+
+--R       4+-+ | 2 4         2    2
+--R       \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 4         2    2       2
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 10       4 8      2 3 6      3 2 4     4   2    5  +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 627
+
+)clear all
+
+--S 628 of 1353
+t0:=1/(x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R                                                       +-------------------+
+--R          4 9       3 7     2 2 5     3   3    4   +-+ | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 628
+
+--S 629 of 1353
+r0:=1/8*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)*sqrt(x))+17/96/(a^2*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x))+221/768*(a+b*x^2)/(a^3*(a^2+_
+   2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x))+3315/2048*b^(1/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(21/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-3315/2048*b^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   3315/4096*b^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   3315/4096*b^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   663/1024/(a^4*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-3315/1024*(a+b*x^2)/_
+   (a^5*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R               4 8           3 6         2 2 4         3   2        4 4+-+ +-+
+--R         (9945b x  + 39780a b x  + 59670a b x  + 39780a b x  + 9945a )\|b \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 4 8           3 6         2 2 4         3   2        4 4+-+ +-+
+--R         (- 9945b x  - 39780a b x  - 59670a b x  - 39780a b x  - 9945a )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  4 8           3 6          2 2 4         3   2         4 4+-+
+--R         (- 19890b x  - 79560a b x  - 119340a b x  - 79560a b x  - 19890a )\|b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|b \|x  + \|a
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                  4 8           3 6          2 2 4         3   2         4 4+-+
+--R         (- 19890b x  - 79560a b x  - 119340a b x  - 79560a b x  - 19890a )\|b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|b \|x  - \|a
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                  4 8            3 6          2 2 4          3   2         4
+--R         (- 39780b x  - 151164a b x  - 211276a b x  - 126004a b x  - 24576a )
+--R      *
+--R          +-+4+-+
+--R         \|2 \|a
+--R  /
+--R              5 3 6         6 2 4         7   2         8  +-+4+-+ +-+
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a )\|2 \|a \|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 5 4 8         6 3 6         7 2 4         8   2        9
+--R         (- 3072a b x  - 12288a b x  - 18432a b x  - 12288a b x  - 3072a )
+--R      *
+--R          +--------------------+
+--R          |   120763066100625b   +-+
+--R          |- ------------------ \|x
+--R         4|                  21
+--R         \|  281474976710656a
+--R      *
+--R                                                +--------------------+3
+--R                          +-+               16  |   120763066100625b
+--R         log(36429280875b\|x  + 68719476736a    |- ------------------ )
+--R                                               4|                  21
+--R                                               \|  281474976710656a
+--R     + 
+--R               5 4 8         6 3 6         7 2 4         8   2        9
+--R         (3072a b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a )
+--R      *
+--R          +--------------------+
+--R          |   120763066100625b   +-+
+--R          |- ------------------ \|x
+--R         4|                  21
+--R         \|  281474976710656a
+--R      *
+--R                                                +--------------------+3
+--R                          +-+               16  |   120763066100625b
+--R         log(36429280875b\|x  - 68719476736a    |- ------------------ )
+--R                                               4|                  21
+--R                                               \|  281474976710656a
+--R     + 
+--R                 5 4 8         6 3 6         7 2 4         8   2        9
+--R         (- 6144a b x  - 24576a b x  - 36864a b x  - 24576a b x  - 6144a )
+--R      *
+--R                                                       +--------------------+3
+--R                                                   16  |   120763066100625b
+--R                                       68719476736a    |- ------------------
+--R        +--------------------+                        4|                  21
+--R        |   120763066100625b   +-+                    \|  281474976710656a
+--R        |- ------------------ \|x atan(--------------------------------------)
+--R       4|                  21                                  +-+
+--R       \|  281474976710656a                       36429280875b\|x
+--R     + 
+--R              4 8           3 6         2 2 4         3   2        4
+--R       - 9945b x  - 37791a b x  - 52819a b x  - 31501a b x  - 6144a
+--R  /
+--R           5 4 8         6 3 6         7 2 4         8   2        9  +-+
+--R     (3072a b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 630
+
+--S 631 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 9945b x   - 49725a b x  - 99450a b x  - 99450a b x  - 49725a b x
+--R         + 
+--R                  5
+--R           - 9945a
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 4 8         6 3 6         7 2 4         8   2         9  +-+
+--R         (- 12288a b x  - 49152a b x  - 73728a b x  - 49152a b x  - 12288a )\|2
+--R      *
+--R          +--------------------+         +-------------------+
+--R          |   120763066100625b  4+-+ +-+ | 2 4         2    2
+--R          |- ------------------ \|a \|x \|b x  + 2a b x  + a
+--R         4|                  21
+--R         \|  281474976710656a
+--R      *
+--R                                                +--------------------+3
+--R                          +-+               16  |   120763066100625b
+--R         log(36429280875b\|x  + 68719476736a    |- ------------------ )
+--R                                               4|                  21
+--R                                               \|  281474976710656a
+--R     + 
+--R                5 4 8         6 3 6         7 2 4         8   2         9  +-+
+--R         (12288a b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a )\|2
+--R      *
+--R          +--------------------+         +-------------------+
+--R          |   120763066100625b  4+-+ +-+ | 2 4         2    2
+--R          |- ------------------ \|a \|x \|b x  + 2a b x  + a
+--R         4|                  21
+--R         \|  281474976710656a
+--R      *
+--R                                                +--------------------+3
+--R                          +-+               16  |   120763066100625b
+--R         log(36429280875b\|x  - 68719476736a    |- ------------------ )
+--R                                               4|                  21
+--R                                               \|  281474976710656a
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           9945b x   + 49725a b x  + 99450a b x  + 99450a b x  + 49725a b x
+--R         + 
+--R                5
+--R           9945a
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  + \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  - \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                  5 4 8         6 3 6          7 2 4         8   2         9
+--R         (- 24576a b x  - 98304a b x  - 147456a b x  - 98304a b x  - 24576a )
+--R      *
+--R               +--------------------+         +-------------------+
+--R          +-+  |   120763066100625b  4+-+ +-+ | 2 4         2    2
+--R         \|2   |- ------------------ \|a \|x \|b x  + 2a b x  + a
+--R              4|                  21
+--R              \|  281474976710656a
+--R      *
+--R                              +--------------------+3
+--R                          16  |   120763066100625b
+--R              68719476736a    |- ------------------
+--R                             4|                  21
+--R                             \|  281474976710656a
+--R         atan(--------------------------------------)
+--R                                      +-+
+--R                         36429280875b\|x
+--R     + 
+--R                  4 8            3 6          2 2 4          3   2         4
+--R         (- 39780b x  - 151164a b x  - 211276a b x  - 126004a b x  - 24576a )
+--R      *
+--R                  +-------------------+
+--R          +-+4+-+ | 2 4         2    2
+--R         \|2 \|a \|b x  + 2a b x  + a
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           39780b x   + 190944a b x  + 362440a b x  + 337280a b x
+--R         + 
+--R                  4   2         5
+--R           150580a b x  + 24576a
+--R      *
+--R          +-+4+-+
+--R         \|2 \|a
+--R  /
+--R              5 4 8         6 3 6         7 2 4         8   2         9  +-+4+-+
+--R       (12288a b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a )\|2 \|a
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 4         2    2       2
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 11       4 9      2 3 7      3 2 5     4   3    5   +-+
+--R       (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a x)\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 632
+
+)clear all
+
+--S 633 of 1353
+t0:=1/(x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                           1
+--R   (1)  ----------------------------------------------------------------------
+--R                                                         +-------------------+
+--R          4 10       3 8     2 2 6     3   4    4 2  +-+ | 2 4         2    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 633
+
+--S 634 of 1353
+r0:=1/8*(a+b*x^2)/(a*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+19/96/(a^2*_
+   x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+95/256*(a+b*x^2)/(a^3*x^(3/2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1045/1024/(a^4*x^(3/2)*sqrt(a^2+2*a*_
+   b*x^2+b^2*x^4))-7315/3072*(a+b*x^2)/(a^5*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+7315/2048*b^(3/4)*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(23/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-7315/2048*_
+   b^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(23/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+7315/4096*b^(3/4)*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(23/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-7315/4096*b^(3/4)*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(23/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                  4 9           3 7          2 2 5         3   3         4
+--R         (- 21945b x  - 87780a b x  - 131670a b x  - 87780a b x  - 21945a x)
+--R      *
+--R         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b  \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                4 9           3 7          2 2 5         3   3         4  4+-+3
+--R         (21945b x  + 87780a b x  + 131670a b x  + 87780a b x  + 21945a x)\|b
+--R      *
+--R          +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  4 9            3 7          2 2 5          3   3         4
+--R         (- 43890b x  - 175560a b x  - 263340a b x  - 175560a b x  - 43890a x)
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|b \|x  + \|a
+--R         \|b  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|a
+--R     + 
+--R                  4 9            3 7          2 2 5          3   3         4
+--R         (- 43890b x  - 175560a b x  - 263340a b x  - 175560a b x  - 43890a x)
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|b \|x  - \|a
+--R         \|b  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|a
+--R     + 
+--R              4 8            3 6          2 2 4         3   2        4  +-+4+-+3
+--R     (- 29260b x  - 104500a b x  - 133380a b x  - 67868a b x  - 8192a )\|2 \|a
+--R  /
+--R              5 3 7         6 2 5         7   3         8   +-+4+-+3 +-+
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a x)\|2 \|a  \|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 634
+
+--S 635 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 5 4 9         6 3 7         7 2 5         8   3        9
+--R         (- 3072a b x  - 12288a b x  - 18432a b x  - 12288a b x  - 3072a x)
+--R      *
+--R        +--------------------+                            +--------------------+
+--R        |                   3                             |                   3
+--R        |  2863237160100625b   +-+          +-+        6  |  2863237160100625b
+--R        |- ------------------ \|x log(7315b\|x  + 4096a   |- ------------------)
+--R       4|                  23                            4|                  23
+--R       \|  281474976710656a                              \|  281474976710656a
+--R     + 
+--R               5 4 9         6 3 7         7 2 5         8   3        9
+--R         (3072a b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a x)
+--R      *
+--R        +--------------------+                            +--------------------+
+--R        |                   3                             |                   3
+--R        |  2863237160100625b   +-+          +-+        6  |  2863237160100625b
+--R        |- ------------------ \|x log(7315b\|x  - 4096a   |- ------------------)
+--R       4|                  23                            4|                  23
+--R       \|  281474976710656a                              \|  281474976710656a
+--R     + 
+--R               5 4 9         6 3 7         7 2 5         8   3        9
+--R         (6144a b x  + 24576a b x  + 36864a b x  + 24576a b x  + 6144a x)
+--R      *
+--R                                                 +--------------------+
+--R                                                 |                   3
+--R                                              6  |  2863237160100625b
+--R          +--------------------+         4096a   |- ------------------
+--R          |                   3                 4|                  23
+--R          |  2863237160100625b   +-+            \|  281474976710656a
+--R          |- ------------------ \|x atan(-----------------------------)
+--R         4|                  23                          +-+
+--R         \|  281474976710656a                      7315b\|x
+--R     + 
+--R              4 8           3 6         2 2 4         3   2        4
+--R       - 7315b x  - 26125a b x  - 33345a b x  - 16967a b x  - 2048a
+--R  /
+--R           5 4 9         6 3 7         7 2 5         8   3        9   +-+
+--R     (3072a b x  + 12288a b x  + 18432a b x  + 12288a b x  + 3072a x)\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 635
+
+--S 636 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 11            4 9          2 3 7          3 2 5
+--R           21945b x   + 109725a b x  + 219450a b x  + 219450a b x
+--R         + 
+--R                  4   3         5
+--R           109725a b x  + 21945a x
+--R      *
+--R         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b  \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 4 9         6 3 7         7 2 5         8   3         9
+--R         (- 12288a b x  - 49152a b x  - 73728a b x  - 49152a b x  - 12288a x)
+--R      *
+--R               +--------------------+
+--R               |                   3           +-------------------+
+--R          +-+  |  2863237160100625b  4+-+3 +-+ | 2 4         2    2
+--R         \|2   |- ------------------ \|a  \|x \|b x  + 2a b x  + a
+--R              4|                  23
+--R              \|  281474976710656a
+--R      *
+--R                                 +--------------------+
+--R                                 |                   3
+--R                   +-+        6  |  2863237160100625b
+--R         log(7315b\|x  + 4096a   |- ------------------)
+--R                                4|                  23
+--R                                \|  281474976710656a
+--R     + 
+--R                5 4 9         6 3 7         7 2 5         8   3         9   +-+
+--R         (12288a b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a x)\|2
+--R      *
+--R          +--------------------+
+--R          |                   3           +-------------------+
+--R          |  2863237160100625b  4+-+3 +-+ | 2 4         2    2
+--R          |- ------------------ \|a  \|x \|b x  + 2a b x  + a
+--R         4|                  23
+--R         \|  281474976710656a
+--R      *
+--R                                 +--------------------+
+--R                                 |                   3
+--R                   +-+        6  |  2863237160100625b
+--R         log(7315b\|x  - 4096a   |- ------------------)
+--R                                4|                  23
+--R                                \|  281474976710656a
+--R     + 
+--R                   5 11            4 9          2 3 7          3 2 5
+--R           - 21945b x   - 109725a b x  - 219450a b x  - 219450a b x
+--R         + 
+--R                    4   3         5
+--R           - 109725a b x  - 21945a x
+--R      *
+--R         4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b  \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 11            4 9          2 3 7          3 2 5
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   3         5
+--R           219450a b x  + 43890a x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|b \|x  + \|a
+--R         \|b  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|a
+--R     + 
+--R                 5 11            4 9          2 3 7          3 2 5
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   3         5
+--R           219450a b x  + 43890a x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|b \|x  - \|a
+--R         \|b  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|a
+--R     + 
+--R                5 4 9         6 3 7          7 2 5         8   3         9   +-+
+--R         (24576a b x  + 98304a b x  + 147456a b x  + 98304a b x  + 24576a x)\|2
+--R      *
+--R          +--------------------+
+--R          |                   3           +-------------------+
+--R          |  2863237160100625b  4+-+3 +-+ | 2 4         2    2
+--R          |- ------------------ \|a  \|x \|b x  + 2a b x  + a
+--R         4|                  23
+--R         \|  281474976710656a
+--R      *
+--R                      +--------------------+
+--R                      |                   3
+--R                   6  |  2863237160100625b
+--R              4096a   |- ------------------
+--R                     4|                  23
+--R                     \|  281474976710656a
+--R         atan(-----------------------------)
+--R                              +-+
+--R                        7315b\|x
+--R     + 
+--R                  4 8            3 6          2 2 4         3   2        4  +-+
+--R         (- 29260b x  - 104500a b x  - 133380a b x  - 67868a b x  - 8192a )\|2
+--R      *
+--R               +-------------------+
+--R         4+-+3 | 2 4         2    2
+--R         \|a  \|b x  + 2a b x  + a
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4         4   2
+--R           29260b x   + 133760a b x  + 237880a b x  + 201248a b x  + 76060a b x
+--R         + 
+--R                5
+--R           8192a
+--R      *
+--R          +-+4+-+3
+--R         \|2 \|a
+--R  /
+--R              5 4 9         6 3 7         7 2 5         8   3         9   +-+
+--R       (12288a b x  + 49152a b x  + 73728a b x  + 49152a b x  + 12288a x)\|2
+--R    *
+--R                 +-------------------+
+--R       4+-+3 +-+ | 2 4         2    2
+--R       \|a  \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 4         2    2       2
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 12       4 10      2 3 8      3 2 6     4   4    5 2  +-+
+--R       (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a x )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 637
+
+)clear all
+
+--S 638 of 1353
+t0:=1/(x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                           1
+--R   (1)  ----------------------------------------------------------------------
+--R                                                         +-------------------+
+--R          4 11       3 9     2 2 7     3   5    4 3  +-+ | 2 4         2    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 1353
+r0:=1/8*(a+b*x^2)/(a*x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+7/32/(a^2*_
+   x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+119/256*(a+b*x^2)/(a^3*x^(5/2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1547/1024/(a^4*x^(5/2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-13923/5120*(a+b*x^2)/(a^5*x^(5/2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-13923/2048*b^(5/4)*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   13923/2048*b^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+13923/4096*b^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-13923/4096*b^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+13923/1024*b*(a+_
+   b*x^2)/(a^6*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                     5 10            4 8          2 3 6          3 2 4
+--R             - 69615b x   - 278460a b x  - 417690a b x  - 278460a b x
+--R           + 
+--R                     4   2
+--R             - 69615a b x
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10            4 8          2 3 6          3 2 4         4   2
+--R         (69615b x   + 278460a b x  + 417690a b x  + 278460a b x  + 69615a b x )
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    5 10            4 8          2 3 6          3 2 4
+--R             139230b x   + 556920a b x  + 835380a b x  + 556920a b x
+--R           + 
+--R                    4   2
+--R             139230a b x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  + \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                    5 10            4 8          2 3 6          3 2 4
+--R             139230b x   + 556920a b x  + 835380a b x  + 556920a b x
+--R           + 
+--R                    4   2
+--R             139230a b x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  - \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                  5 10             4 8           2 3 6          3 2 4
+--R           278460b x   + 1058148a b x  + 1478932a b x  + 882028a b x
+--R         + 
+--R                  4   2        5
+--R           172032a b x  - 8192a
+--R      *
+--R          +-+4+-+
+--R         \|2 \|a
+--R  /
+--R              6 3 8         7 2 6         8   4         9 2  +-+4+-+ +-+
+--R       (20480a b x  + 61440a b x  + 61440a b x  + 20480a x )\|2 \|a \|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 639
+
+--S 640 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               6 4 10         7 3 8         8 2 6         9   4        10 2
+--R         (5120a b x   + 20480a b x  + 30720a b x  + 20480a b x  + 5120a  x )
+--R      *
+--R          +---------------------+
+--R          |                    5
+--R          |  37577794973305041b   +-+
+--R          |- ------------------- \|x
+--R         4|                   25
+--R         \|   281474976710656a
+--R      *
+--R                                                   +---------------------+3
+--R                                                   |                    5
+--R                           4 +-+               19  |  37577794973305041b
+--R         log(2698972561467b \|x  + 68719476736a    |- ------------------- )
+--R                                                  4|                   25
+--R                                                  \|   281474976710656a
+--R     + 
+--R                 6 4 10         7 3 8         8 2 6         9   4        10 2
+--R         (- 5120a b x   - 20480a b x  - 30720a b x  - 20480a b x  - 5120a  x )
+--R      *
+--R          +---------------------+
+--R          |                    5
+--R          |  37577794973305041b   +-+
+--R          |- ------------------- \|x
+--R         4|                   25
+--R         \|   281474976710656a
+--R      *
+--R                                                   +---------------------+3
+--R                                                   |                    5
+--R                           4 +-+               19  |  37577794973305041b
+--R         log(2698972561467b \|x  - 68719476736a    |- ------------------- )
+--R                                                  4|                   25
+--R                                                  \|   281474976710656a
+--R     + 
+--R                6 4 10         7 3 8         8 2 6         9   4         10 2
+--R         (10240a b x   + 40960a b x  + 61440a b x  + 40960a b x  + 10240a  x )
+--R      *
+--R                                                        +---------------------+3
+--R                                                        |                    5
+--R                                                    19  |  37577794973305041b
+--R        +---------------------+         68719476736a    |- -------------------
+--R        |                    5                         4|                   25
+--R        |  37577794973305041b   +-+                    \|   281474976710656a
+--R        |- ------------------- \|x atan(---------------------------------------)
+--R       4|                   25                                  4 +-+
+--R       \|   281474976710656a                      2698972561467b \|x
+--R     + 
+--R             5 10            4 8          2 3 6          3 2 4         4   2
+--R       69615b x   + 264537a b x  + 369733a b x  + 220507a b x  + 43008a b x
+--R     + 
+--R              5
+--R       - 2048a
+--R  /
+--R           6 4 10         7 3 8         8 2 6         9   4        10 2  +-+
+--R     (5120a b x   + 20480a b x  + 30720a b x  + 20480a b x  + 5120a  x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 640
+
+--S 641 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 6 12            5 10          2 4 8          3 3 6
+--R           69615b x   + 348075a b x   + 696150a b x  + 696150a b x
+--R         + 
+--R                  4 2 4         5   2
+--R           348075a b x  + 69615a b x
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                6 4 10         7 3 8          8 2 6         9   4         10 2
+--R         (20480a b x   + 81920a b x  + 122880a b x  + 81920a b x  + 20480a  x )
+--R      *
+--R               +---------------------+
+--R               |                    5          +-------------------+
+--R          +-+  |  37577794973305041b  4+-+ +-+ | 2 4         2    2
+--R         \|2   |- ------------------- \|a \|x \|b x  + 2a b x  + a
+--R              4|                   25
+--R              \|   281474976710656a
+--R      *
+--R                                                   +---------------------+3
+--R                                                   |                    5
+--R                           4 +-+               19  |  37577794973305041b
+--R         log(2698972561467b \|x  + 68719476736a    |- ------------------- )
+--R                                                  4|                   25
+--R                                                  \|   281474976710656a
+--R     + 
+--R                     6 4 10         7 3 8          8 2 6         9   4
+--R             - 20480a b x   - 81920a b x  - 122880a b x  - 81920a b x
+--R           + 
+--R                     10 2
+--R             - 20480a  x
+--R      *
+--R               +---------------------+
+--R               |                    5          +-------------------+
+--R          +-+  |  37577794973305041b  4+-+ +-+ | 2 4         2    2
+--R         \|2   |- ------------------- \|a \|x \|b x  + 2a b x  + a
+--R              4|                   25
+--R              \|   281474976710656a
+--R      *
+--R                                                   +---------------------+3
+--R                                                   |                    5
+--R                           4 +-+               19  |  37577794973305041b
+--R         log(2698972561467b \|x  - 68719476736a    |- ------------------- )
+--R                                                  4|                   25
+--R                                                  \|   281474976710656a
+--R     + 
+--R                   6 12            5 10          2 4 8          3 3 6
+--R           - 69615b x   - 348075a b x   - 696150a b x  - 696150a b x
+--R         + 
+--R                    4 2 4         5   2
+--R           - 348075a b x  - 69615a b x
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    6 12            5 10           2 4 8           3 3 6
+--R           - 139230b x   - 696150a b x   - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    4 2 4          5   2
+--R           - 696150a b x  - 139230a b x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  + \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                    6 12            5 10           2 4 8           3 3 6
+--R           - 139230b x   - 696150a b x   - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    4 2 4          5   2
+--R           - 696150a b x  - 139230a b x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  - \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                   6 4 10          7 3 8          8 2 6          9   4
+--R             40960a b x   + 163840a b x  + 245760a b x  + 163840a b x
+--R           + 
+--R                   10 2
+--R             40960a  x
+--R      *
+--R               +---------------------+
+--R               |                    5          +-------------------+
+--R          +-+  |  37577794973305041b  4+-+ +-+ | 2 4         2    2
+--R         \|2   |- ------------------- \|a \|x \|b x  + 2a b x  + a
+--R              4|                   25
+--R              \|   281474976710656a
+--R      *
+--R                              +---------------------+3
+--R                              |                    5
+--R                          19  |  37577794973305041b
+--R              68719476736a    |- -------------------
+--R                             4|                   25
+--R                             \|   281474976710656a
+--R         atan(---------------------------------------)
+--R                                      4 +-+
+--R                        2698972561467b \|x
+--R     + 
+--R                  5 10             4 8           2 3 6          3 2 4
+--R           278460b x   + 1058148a b x  + 1478932a b x  + 882028a b x
+--R         + 
+--R                  4   2        5
+--R           172032a b x  - 8192a
+--R      *
+--R                  +-------------------+
+--R          +-+4+-+ | 2 4         2    2
+--R         \|2 \|a \|b x  + 2a b x  + a
+--R     + 
+--R                    6 12             5 10           2 4 8           3 3 6
+--R           - 278460b x   - 1336608a b x   - 2537080a b x  - 2360960a b x
+--R         + 
+--R                     4 2 4          5   2        6
+--R           - 1054060a b x  - 163840a b x  + 8192a
+--R      *
+--R          +-+4+-+
+--R         \|2 \|a
+--R  /
+--R              6 4 10         7 3 8          8 2 6         9   4         10 2
+--R       (20480a b x   + 81920a b x  + 122880a b x  + 81920a b x  + 20480a  x )
+--R    *
+--R                    +-------------------+
+--R        +-+4+-+ +-+ | 2 4         2    2
+--R       \|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 4         2    2       2
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 13       4 11      2 3 9      3 2 7     4   5    5 3  +-+
+--R       (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a x )\|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 642
+
+)clear all
+
+--S 643 of 1353
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R         m  2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 1353
+--r0:=x^(1+m)*(a^2+2*a*b*x^2+b^2*x^4)^p*hypergeometric(1/2*(1+m),-2*p,1/2*(3+m),-b*x^2/a)/((1+m)*((a+b*x^2)/a)^(2*p))
+--E 644
+
+--S 645 of 1353
+--a0:=integrate(t0,x)
+--E 645
+
+--S 646 of 1353
+--m0:=a0-r0
+--E 646
+
+--S 647 of 1353
+--d0:=normalize(D(m0,x))
+--E 647
+
+)clear all
+
+--S 648 of 1353
+t0:=x^9*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R         9  2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 1353
+r0:=6*a^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^5*(2+p)*(1+2*p)*(3+2*p)*_
+   (5+2*p))+3*a^2*x^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^3*(2+p)*_
+   (3+2*p)*(5+2*p))-a*x^6*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^2*(2+p)*_
+   (5+2*p))+1/2*x^8*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b*(5+2*p))-_
+   3*a^3*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^5*(1+p)*(2+p)*(3+2*p)*(5+2*p))
+--R 
+--R
+--R   (2)
+--R             3      3   2 4         2    2 p + 1
+--R       (- 12a p - 6a )(b x  + 2a b x  + a )
+--R     + 
+--R              5 4      5 3      5 2      5      5  10
+--R           (4b p  + 20b p  + 35b p  + 25b p + 6b )x
+--R         + 
+--R                4 4        4 3        4 2       4   8
+--R           (4a b p  + 12a b p  + 11a b p  + 3a b p)x
+--R         + 
+--R                2 3 3      2 3 2     2 3   6       3 2 2      3 2      3 2  4
+--R           (- 8a b p  - 12a b p  - 4a b p)x  + (12a b p  + 18a b p + 6a b )x
+--R         + 
+--R               4         4   2      5       5
+--R           (12a b p + 12a b)x  + 12a p + 12a
+--R      *
+--R           2 4         2    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        5 5       5 4       5 3       5 2       5       5
+--R     16b p  + 120b p  + 340b p  + 450b p  + 274b p + 60b
+--R                                                    Type: Expression(Integer)
+--E 649
+
+--S 650 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            5 4      5 3      5 2      5      5  10
+--R         (4b p  + 20b p  + 35b p  + 25b p + 6b )x
+--R       + 
+--R              4 4        4 3        4 2       4   8
+--R         (4a b p  + 12a b p  + 11a b p  + 3a b p)x
+--R       + 
+--R              2 3 3      2 3 2     2 3   6       3 2 2     3 2   4      4     2
+--R         (- 8a b p  - 12a b p  - 4a b p)x  + (12a b p  + 6a b p)x  - 12a b p x
+--R       + 
+--R           5
+--R         6a
+--R    *
+--R                2 4         2    2
+--R         p log(b x  + 2a b x  + a )
+--R       %e
+--R  /
+--R        5 5       5 4       5 3       5 2       5       5
+--R     16b p  + 120b p  + 340b p  + 450b p  + 274b p + 60b
+--R                                         Type: Union(Expression(Integer),...)
+--E 650
+
+--S 651 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 4      5 3      5 2      5      5  10
+--R           (4b p  + 20b p  + 35b p  + 25b p + 6b )x
+--R         + 
+--R                4 4        4 3        4 2       4   8
+--R           (4a b p  + 12a b p  + 11a b p  + 3a b p)x
+--R         + 
+--R                2 3 3      2 3 2     2 3   6       3 2 2     3 2   4
+--R           (- 8a b p  - 12a b p  - 4a b p)x  + (12a b p  + 6a b p)x
+--R         + 
+--R                4     2     5
+--R           - 12a b p x  + 6a
+--R      *
+--R                  2 4         2    2
+--R           p log(b x  + 2a b x  + a )
+--R         %e
+--R     + 
+--R           3      3   2 4         2    2 p + 1
+--R       (12a p + 6a )(b x  + 2a b x  + a )
+--R     + 
+--R                5 4      5 3      5 2      5      5  10
+--R           (- 4b p  - 20b p  - 35b p  - 25b p - 6b )x
+--R         + 
+--R                  4 4        4 3        4 2       4   8
+--R           (- 4a b p  - 12a b p  - 11a b p  - 3a b p)x
+--R         + 
+--R              2 3 3      2 3 2     2 3   6         3 2 2      3 2      3 2  4
+--R           (8a b p  + 12a b p  + 4a b p)x  + (- 12a b p  - 18a b p - 6a b )x
+--R         + 
+--R                 4         4   2      5       5
+--R           (- 12a b p - 12a b)x  - 12a p - 12a
+--R      *
+--R           2 4         2    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        5 5       5 4       5 3       5 2       5       5
+--R     16b p  + 120b p  + 340b p  + 450b p  + 274b p + 60b
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 652
+
+)clear all
+
+--S 653 of 1353
+t0:=x^7*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R         7  2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 653
+
+--S 654 of 1353
+r0:=-3/2*a^3*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^4*(2+p)*(1+2*p)*_
+   (3+2*p))-3/4*a*x^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^2*(2+p)*_
+   (3+2*p))+1/4*x^6*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b*(2+p))+_
+   3/4*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^4*(1+p)*(2+p)*(3+2*p))
+--R 
+--R
+--R   (2)
+--R          2      2   2 4         2    2 p + 1
+--R       (6a p + 3a )(b x  + 2a b x  + a )
+--R     + 
+--R              4 3      4 2      4      4  8        3 3       3 2       3   6
+--R           (4b p  + 12b p  + 11b p + 3b )x  + (4a b p  + 6a b p  + 2a b p)x
+--R         + 
+--R                2 2 2     2 2      2 2  4        3        3   2     4      4
+--R           (- 6a b p  - 9a b p - 3a b )x  + (- 6a b p - 6a b)x  - 6a p - 6a
+--R      *
+--R           2 4         2    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        4 4      4 3       4 2       4       4
+--R     16b p  + 80b p  + 140b p  + 100b p + 24b
+--R                                                    Type: Expression(Integer)
+--E 654
+
+--S 655 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4 3      4 2      4      4  8        3 3       3 2       3   6
+--R         (4b p  + 12b p  + 11b p + 3b )x  + (4a b p  + 6a b p  + 2a b p)x
+--R       + 
+--R              2 2 2     2 2   4     3     2     4
+--R         (- 6a b p  - 3a b p)x  + 6a b p x  - 3a
+--R    *
+--R                2 4         2    2
+--R         p log(b x  + 2a b x  + a )
+--R       %e
+--R  /
+--R        4 4      4 3       4 2       4       4
+--R     16b p  + 80b p  + 140b p  + 100b p + 24b
+--R                                         Type: Union(Expression(Integer),...)
+--E 655
+
+--S 656 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              4 3      4 2      4      4  8        3 3       3 2       3   6
+--R           (4b p  + 12b p  + 11b p + 3b )x  + (4a b p  + 6a b p  + 2a b p)x
+--R         + 
+--R                2 2 2     2 2   4     3     2     4
+--R           (- 6a b p  - 3a b p)x  + 6a b p x  - 3a
+--R      *
+--R                  2 4         2    2
+--R           p log(b x  + 2a b x  + a )
+--R         %e
+--R     + 
+--R            2      2   2 4         2    2 p + 1
+--R       (- 6a p - 3a )(b x  + 2a b x  + a )
+--R     + 
+--R                4 3      4 2      4      4  8          3 3       3 2       3   6
+--R           (- 4b p  - 12b p  - 11b p - 3b )x  + (- 4a b p  - 6a b p  - 2a b p)x
+--R         + 
+--R              2 2 2     2 2      2 2  4      3        3   2     4      4
+--R           (6a b p  + 9a b p + 3a b )x  + (6a b p + 6a b)x  + 6a p + 6a
+--R      *
+--R           2 4         2    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        4 4      4 3       4 2       4       4
+--R     16b p  + 80b p  + 140b p  + 100b p + 24b
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 657
+
+)clear all
+
+--S 658 of 1353
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R         5  2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 658
+
+--S 659 of 1353
+r0:=a^2*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^3*(1+2*p)*(3+2*p))+_
+   1/2*x^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b*(3+2*p))-_
+   1/2*a*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^3*(1+p)*(3+2*p))
+--R 
+--R
+--R   (2)
+--R                     2 4         2    2 p + 1
+--R       (- 2a p - a)(b x  + 2a b x  + a )
+--R     + 
+--R              3 2     3     3  6        2 2       2       2  4
+--R           (2b p  + 3b p + b )x  + (2a b p  + 3a b p + a b )x
+--R         + 
+--R              2        2   2     3      3
+--R           (2a b p + 2a b)x  + 2a p + 2a
+--R      *
+--R           2 4         2    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R       3 3      3 2      3      3
+--R     8b p  + 24b p  + 22b p + 6b
+--R                                                    Type: Expression(Integer)
+--E 659
+
+--S 660 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 2     3     3  6        2 2      2   4     2     2    3
+--R       ((2b p  + 3b p + b )x  + (2a b p  + a b p)x  - 2a b p x  + a )
+--R    *
+--R                2 4         2    2
+--R         p log(b x  + 2a b x  + a )
+--R       %e
+--R  /
+--R       3 3      3 2      3      3
+--R     8b p  + 24b p  + 22b p + 6b
+--R                                         Type: Union(Expression(Integer),...)
+--E 660
+
+--S 661 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3 2     3     3  6        2 2      2   4     2     2    3
+--R         ((2b p  + 3b p + b )x  + (2a b p  + a b p)x  - 2a b p x  + a )
+--R      *
+--R                  2 4         2    2
+--R           p log(b x  + 2a b x  + a )
+--R         %e
+--R     + 
+--R                   2 4         2    2 p + 1
+--R       (2a p + a)(b x  + 2a b x  + a )
+--R     + 
+--R                3 2     3     3  6          2 2       2       2  4
+--R           (- 2b p  - 3b p - b )x  + (- 2a b p  - 3a b p - a b )x
+--R         + 
+--R                2        2   2     3      3
+--R           (- 2a b p - 2a b)x  - 2a p - 2a
+--R      *
+--R           2 4         2    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R       3 3      3 2      3      3
+--R     8b p  + 24b p  + 22b p + 6b
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 662
+
+)clear all
+
+--S 663 of 1353
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R         3  2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 663
+
+--S 664 of 1353
+r0:=-1/2*a*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^2*(1+2*p))+_
+   1/4*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^2*(1+p))
+--R 
+--R
+--R   (2)
+--R                 2 4         2    2 p + 1
+--R       (2p + 1)(b x  + 2a b x  + a )
+--R     + 
+--R                          2     2      2   2 4         2    2 p
+--R       ((- 2a b p - 2a b)x  - 2a p - 2a )(b x  + 2a b x  + a )
+--R  /
+--R       2 2      2      2
+--R     8b p  + 12b p + 4b
+--R                                                    Type: Expression(Integer)
+--E 664
+
+--S 665 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                 2 4         2    2
+--R            2     2  4           2    2   p log(b x  + 2a b x  + a )
+--R        ((2b p + b )x  + 2a b p x  - a )%e
+--R   (3)  ------------------------------------------------------------
+--R                               2 2      2      2
+--R                             8b p  + 12b p + 4b
+--R                                         Type: Union(Expression(Integer),...)
+--E 665
+
+--S 666 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                2 4         2    2
+--R           2     2  4           2    2   p log(b x  + 2a b x  + a )
+--R       ((2b p + b )x  + 2a b p x  - a )%e
+--R     + 
+--R                   2 4         2    2 p + 1
+--R       (- 2p - 1)(b x  + 2a b x  + a )
+--R     + 
+--R                        2     2      2   2 4         2    2 p
+--R       ((2a b p + 2a b)x  + 2a p + 2a )(b x  + 2a b x  + a )
+--R  /
+--R       2 2      2      2
+--R     8b p  + 12b p + 4b
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 667
+
+)clear all
+
+--S 668 of 1353
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R            2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 668
+
+--S 669 of 1353
+r0:=1/2*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b*(1+2*p))
+--R 
+--R
+--R            2       2 4         2    2 p
+--R        (b x  + a)(b x  + 2a b x  + a )
+--R   (2)  --------------------------------
+--R                    4b p + 2b
+--R                                                    Type: Expression(Integer)
+--E 669
+
+--S 670 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           2 4         2    2
+--R            2       p log(b x  + 2a b x  + a )
+--R        (b x  + a)%e
+--R   (3)  --------------------------------------
+--R                       4b p + 2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 670
+
+--S 671 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      2 4         2    2
+--R       2       p log(b x  + 2a b x  + a )         2       2 4         2    2 p
+--R   (b x  + a)%e                           + (- b x  - a)(b x  + 2a b x  + a )
+--R   ---------------------------------------------------------------------------
+--R                                    4b p + 2b
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 672
+
+)clear all
+
+--S 673 of 1353
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^p/x
+--R 
+--R
+--R          2 4         2    2 p
+--R        (b x  + 2a b x  + a )
+--R   (1)  ----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 673
+
+--S 674 of 1353
+--r0:=1/4*(a^2+2*a*b*x^2+b^2*x^4)^p*hypergeometric(-2*p,-2*p,1-2*p,-a/(b*x^2))/(p*((a+b*x^2)/(b*x^2))^(2*p))
+--E 674
+
+--S 675 of 1353
+--a0:=integrate(t0,x)
+--E 675
+
+--S 676 of 1353
+--m0:=a0-r0
+--E 676
+
+--S 677 of 1353
+--d0:=normalize(D(m0,x))
+--E 677
+
+)clear all
+
+--S 678 of 1353
+t0:=x^m*(a+b*x^2+c*x^4)
+--R 
+--R
+--R            4      2      m
+--R   (1)  (c x  + b x  + a)x
+--R                                                    Type: Expression(Integer)
+--E 678
+
+--S 679 of 1353
+r0:=a*x^(1+m)/(1+m)+b*x^(3+m)/(3+m)+c*x^(5+m)/(5+m)
+--R 
+--R
+--R   (2)
+--R           2              m + 5       2              m + 3
+--R       (c m  + 4c m + 3c)x      + (b m  + 6b m + 5b)x
+--R     + 
+--R           2               m + 1
+--R       (a m  + 8a m + 15a)x
+--R  /
+--R      3     2
+--R     m  + 9m  + 23m + 15
+--R                                                    Type: Expression(Integer)
+--E 679
+
+--S 680 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2              5       2              3       2
+--R       ((c m  + 4c m + 3c)x  + (b m  + 6b m + 5b)x  + (a m  + 8a m + 15a)x)
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      3     2
+--R     m  + 9m  + 23m + 15
+--R                                         Type: Union(Expression(Integer),...)
+--E 680
+
+--S 681 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2              5       2              3       2
+--R         ((c m  + 4c m + 3c)x  + (b m  + 6b m + 5b)x  + (a m  + 8a m + 15a)x)
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R             2              m + 5         2              m + 3
+--R       (- c m  - 4c m - 3c)x      + (- b m  - 6b m - 5b)x
+--R     + 
+--R             2               m + 1
+--R       (- a m  - 8a m - 15a)x
+--R  /
+--R      3     2
+--R     m  + 9m  + 23m + 15
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 682
+
+)clear all
+
+--S 683 of 1353
+t0:=x^4*(a+b*x^2+c*x^4)
+--R 
+--R
+--R           8      6      4
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 683
+
+--S 684 of 1353
+r0:=1/5*a*x^5+1/7*b*x^7+1/9*c*x^9
+--R 
+--R
+--R        1    9   1    7   1    5
+--R   (2)  - c x  + - b x  + - a x
+--R        9        7        5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 684
+
+--S 685 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    9   1    7   1    5
+--R   (3)  - c x  + - b x  + - a x
+--R        9        7        5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 685
+
+--S 686 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 686
+
+--S 687 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 687
+
+)clear all
+
+--S 688 of 1353
+t0:=x^3*(a+b*x^2+c*x^4)
+--R 
+--R
+--R           7      5      3
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 688
+
+--S 689 of 1353
+r0:=1/4*a*x^4+1/6*b*x^6+1/8*c*x^8
+--R 
+--R
+--R        1    8   1    6   1    4
+--R   (2)  - c x  + - b x  + - a x
+--R        8        6        4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 689
+
+--S 690 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    8   1    6   1    4
+--R   (3)  - c x  + - b x  + - a x
+--R        8        6        4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 690
+
+--S 691 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 691
+
+--S 692 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 692
+
+)clear all
+
+--S 693 of 1353
+t0:=x^2*(a+b*x^2+c*x^4)
+--R 
+--R
+--R           6      4      2
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 693
+
+--S 694 of 1353
+r0:=1/3*a*x^3+1/5*b*x^5+1/7*c*x^7
+--R 
+--R
+--R        1    7   1    5   1    3
+--R   (2)  - c x  + - b x  + - a x
+--R        7        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 694
+
+--S 695 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    7   1    5   1    3
+--R   (3)  - c x  + - b x  + - a x
+--R        7        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 695
+
+--S 696 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 696
+
+--S 697 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 697
+
+)clear all
+
+--S 698 of 1353
+t0:=x*(a+b*x^2+c*x^4)
+--R 
+--R
+--R           5      3
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 698
+
+--S 699 of 1353
+r0:=1/2*a*x^2+1/4*b*x^4+1/6*c*x^6
+--R 
+--R
+--R        1    6   1    4   1    2
+--R   (2)  - c x  + - b x  + - a x
+--R        6        4        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 699
+
+--S 700 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    6   1    4   1    2
+--R   (3)  - c x  + - b x  + - a x
+--R        6        4        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 700
+
+--S 701 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 701
+
+--S 702 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 702
+
+)clear all
+
+--S 703 of 1353
+t0:=a+b*x^2+c*x^4
+--R 
+--R
+--R           4      2
+--R   (1)  c x  + b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 703
+
+--S 704 of 1353
+r0:=a*x+1/3*b*x^3+1/5*c*x^5
+--R 
+--R
+--R        1    5   1    3
+--R   (2)  - c x  + - b x  + a x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 704
+
+--S 705 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    5   1    3
+--R   (3)  - c x  + - b x  + a x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 705
+
+--S 706 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 706
+
+--S 707 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 707
+
+)clear all
+
+--S 708 of 1353
+t0:=(a+b*x^2+c*x^4)/x
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R               x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 708
+
+--S 709 of 1353
+r0:=1/2*b*x^2+1/4*c*x^4+a*log(x)
+--R 
+--R
+--R                       4       2
+--R        4a log(x) + c x  + 2b x
+--R   (2)  ------------------------
+--R                    4
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       4       2
+--R        4a log(x) + c x  + 2b x
+--R   (3)  ------------------------
+--R                    4
+--R                                         Type: Union(Expression(Integer),...)
+--E 710
+
+--S 711 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 712
+
+)clear all
+
+--S 713 of 1353
+t0:=(a+b*x^2+c*x^4)/x^2
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R                2
+--R               x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 713
+
+--S 714 of 1353
+r0:=-a/x+b*x+1/3*c*x^3
+--R 
+--R
+--R           4       2
+--R        c x  + 3b x  - 3a
+--R   (2)  -----------------
+--R                3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 714
+
+--S 715 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4       2
+--R        c x  + 3b x  - 3a
+--R   (3)  -----------------
+--R                3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 715
+
+--S 716 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 717
+
+)clear all
+
+--S 718 of 1353
+t0:=(a+b*x^2+c*x^4)/x^3
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R                3
+--R               x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 718
+
+--S 719 of 1353
+r0:=-1/2*a/x^2+1/2*c*x^2+b*log(x)
+--R 
+--R
+--R            2            4
+--R        2b x log(x) + c x  - a
+--R   (2)  ----------------------
+--R                    2
+--R                  2x
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2            4
+--R        2b x log(x) + c x  - a
+--R   (3)  ----------------------
+--R                    2
+--R                  2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 720
+
+--S 721 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 722
+
+)clear all
+
+--S 723 of 1353
+t0:=(a+b*x^2+c*x^4)/x^4
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R                4
+--R               x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 723
+
+--S 724 of 1353
+r0:=-1/3*a/x^3-b/x+c*x
+--R 
+--R
+--R           4      2   1
+--R        c x  - b x  - - a
+--R                      3
+--R   (2)  -----------------
+--R                 3
+--R                x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 724
+
+--S 725 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4       2
+--R        3c x  - 3b x  - a
+--R   (3)  -----------------
+--R                 3
+--R               3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 725
+
+--S 726 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 726
+
+--S 727 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 727
+
+)clear all
+
+--S 728 of 1353
+t0:=x^m*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 8         6            2  4         2    2  m
+--R   (1)  (c x  + 2b c x  + (2a c + b )x  + 2a b x  + a )x
+--R                                                    Type: Expression(Integer)
+--E 728
+
+--S 729 of 1353
+r0:=a^2*x^(1+m)/(1+m)+2*a*b*x^(3+m)/(3+m)+(b^2+2*a*c)*x^(5+m)/(5+m)+_
+   2*b*c*x^(7+m)/(7+m)+c^2*x^(9+m)/(9+m)
+--R 
+--R
+--R   (2)
+--R         2 4      2 3      2 2       2        2  m + 9
+--R       (c m  + 16c m  + 86c m  + 176c m + 105c )x
+--R     + 
+--R              4          3           2                      m + 7
+--R       (2b c m  + 36b c m  + 208b c m  + 444b c m + 270b c)x
+--R     + 
+--R                    2  4               2  3                 2  2
+--R           (2a c + b )m  + (40a c + 20b )m  + (260a c + 130b )m
+--R         + 
+--R                         2                  2
+--R           (600a c + 300b )m + 378a c + 189b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R              4          3           2                      m + 3
+--R       (2a b m  + 44a b m  + 328a b m  + 916a b m + 630a b)x
+--R     + 
+--R         2 4      2 3       2 2       2        2  m + 1
+--R       (a m  + 24a m  + 206a m  + 744a m + 945a )x
+--R  /
+--R      5      4       3       2
+--R     m  + 25m  + 230m  + 950m  + 1689m + 945
+--R                                                    Type: Expression(Integer)
+--E 729
+
+--S 730 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 4      2 3      2 2       2        2  9
+--R         (c m  + 16c m  + 86c m  + 176c m + 105c )x
+--R       + 
+--R                4          3           2                      7
+--R         (2b c m  + 36b c m  + 208b c m  + 444b c m + 270b c)x
+--R       + 
+--R                      2  4               2  3                 2  2
+--R             (2a c + b )m  + (40a c + 20b )m  + (260a c + 130b )m
+--R           + 
+--R                           2                  2
+--R             (600a c + 300b )m + 378a c + 189b
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                4          3           2                      3
+--R         (2a b m  + 44a b m  + 328a b m  + 916a b m + 630a b)x
+--R       + 
+--R           2 4      2 3       2 2       2        2
+--R         (a m  + 24a m  + 206a m  + 744a m + 945a )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      5      4       3       2
+--R     m  + 25m  + 230m  + 950m  + 1689m + 945
+--R                                         Type: Union(Expression(Integer),...)
+--E 730
+
+--S 731 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2 4      2 3      2 2       2        2  9
+--R           (c m  + 16c m  + 86c m  + 176c m + 105c )x
+--R         + 
+--R                  4          3           2                      7
+--R           (2b c m  + 36b c m  + 208b c m  + 444b c m + 270b c)x
+--R         + 
+--R                        2  4               2  3                 2  2
+--R               (2a c + b )m  + (40a c + 20b )m  + (260a c + 130b )m
+--R             + 
+--R                             2                  2
+--R               (600a c + 300b )m + 378a c + 189b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                  4          3           2                      3
+--R           (2a b m  + 44a b m  + 328a b m  + 916a b m + 630a b)x
+--R         + 
+--R             2 4      2 3       2 2       2        2
+--R           (a m  + 24a m  + 206a m  + 744a m + 945a )x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           2 4      2 3      2 2       2        2  m + 9
+--R       (- c m  - 16c m  - 86c m  - 176c m - 105c )x
+--R     + 
+--R                4          3           2                      m + 7
+--R       (- 2b c m  - 36b c m  - 208b c m  - 444b c m - 270b c)x
+--R     + 
+--R                      2  4                 2  3                   2  2
+--R           (- 2a c - b )m  + (- 40a c - 20b )m  + (- 260a c - 130b )m
+--R         + 
+--R                           2                  2
+--R           (- 600a c - 300b )m - 378a c - 189b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R                4          3           2                      m + 3
+--R       (- 2a b m  - 44a b m  - 328a b m  - 916a b m - 630a b)x
+--R     + 
+--R           2 4      2 3       2 2       2        2  m + 1
+--R       (- a m  - 24a m  - 206a m  - 744a m - 945a )x
+--R  /
+--R      5      4       3       2
+--R     m  + 25m  + 230m  + 950m  + 1689m + 945
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 732
+
+)clear all
+
+--S 733 of 1353
+t0:=x^4*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 12         10            2  8         6    2 4
+--R   (1)  c x   + 2b c x   + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 733
+
+--S 734 of 1353
+r0:=1/5*a^2*x^5+2/7*a*b*x^7+1/9*(b^2+2*a*c)*x^9+2/11*b*c*x^11+1/13*c^2*x^13
+--R 
+--R
+--R         1  2 13    2      11    2       1  2  9   2      7   1  2 5
+--R   (2)  -- c x   + -- b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        13         11            9       9         7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 734
+
+--S 735 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  2 13    2      11    2       1  2  9   2      7   1  2 5
+--R   (3)  -- c x   + -- b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        13         11            9       9         7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 735
+
+--S 736 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 736
+
+--S 737 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 737
+
+)clear all
+
+--S 738 of 1353
+t0:=x^3*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 11         9            2  7         5    2 3
+--R   (1)  c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 738
+
+--S 739 of 1353
+r0:=1/4*a^2*x^4+1/3*a*b*x^6+1/8*(b^2+2*a*c)*x^8+1/5*b*c*x^10+1/12*c^2*x^12
+--R 
+--R
+--R         1  2 12   1      10    1       1  2  8   1      6   1  2 4
+--R   (2)  -- c x   + - b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        12         5            4       8         3          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 739
+
+--S 740 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  2 12   1      10    1       1  2  8   1      6   1  2 4
+--R   (3)  -- c x   + - b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        12         5            4       8         3          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 740
+
+--S 741 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 741
+
+--S 742 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 742
+
+)clear all
+
+--S 743 of 1353
+t0:=x^2*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 10         8            2  6         4    2 2
+--R   (1)  c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 743
+
+--S 744 of 1353
+r0:=1/3*a^2*x^3+2/5*a*b*x^5+1/7*(b^2+2*a*c)*x^7+2/9*b*c*x^9+1/11*c^2*x^11
+--R 
+--R
+--R         1  2 11   2      9    2       1  2  7   2      5   1  2 3
+--R   (2)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        11         9           7       7         5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 744
+
+--S 745 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  2 11   2      9    2       1  2  7   2      5   1  2 3
+--R   (3)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        11         9           7       7         5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 745
+
+--S 746 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 746
+
+--S 747 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 747
+
+)clear all
+
+--S 748 of 1353
+t0:=x*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 9         7            2  5         3    2
+--R   (1)  c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 748
+
+--S 749 of 1353
+r0:=1/2*a^2*x^2+1/2*a*b*x^4+1/6*(b^2+2*a*c)*x^6+1/4*b*c*x^8+1/10*c^2*x^10
+--R 
+--R
+--R         1  2 10   1      8    1       1  2  6   1      4   1  2 2
+--R   (2)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        10         4           3       6         2          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 749
+
+--S 750 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  2 10   1      8    1       1  2  6   1      4   1  2 2
+--R   (3)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        10         4           3       6         2          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 750
+
+--S 751 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 751
+
+--S 752 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 752
+
+)clear all
+
+--S 753 of 1353
+t0:=(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R   (1)  c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 753
+
+--S 754 of 1353
+r0:=a^2*x+2/3*a*b*x^3+1/5*(b^2+2*a*c)*x^5+2/7*b*c*x^7+1/9*c^2*x^9
+--R 
+--R
+--R        1  2 9   2      7    2       1  2  5   2      3    2
+--R   (2)  - c x  + - b c x  + (- a c + - b )x  + - a b x  + a x
+--R        9        7           5       5         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 754
+
+--S 755 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  2 9   2      7    2       1  2  5   2      3    2
+--R   (3)  - c x  + - b c x  + (- a c + - b )x  + - a b x  + a x
+--R        9        7           5       5         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 755
+
+--S 756 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 756
+
+--S 757 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 757
+
+)clear all
+
+--S 758 of 1353
+t0:=(a+b*x^2+c*x^4)^2/x
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                              x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 758
+
+--S 759 of 1353
+r0:=a*b*x^2+1/4*(b^2+2*a*c)*x^4+1/3*b*c*x^6+1/8*c^2*x^8+a^2*log(x)
+--R 
+--R
+--R           2           2 8         6              2  4          2
+--R        24a log(x) + 3c x  + 8b c x  + (12a c + 6b )x  + 24a b x
+--R   (2)  ---------------------------------------------------------
+--R                                    24
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2           2 8         6              2  4          2
+--R        24a log(x) + 3c x  + 8b c x  + (12a c + 6b )x  + 24a b x
+--R   (3)  ---------------------------------------------------------
+--R                                    24
+--R                                         Type: Union(Expression(Integer),...)
+--E 760
+
+--S 761 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 762
+
+)clear all
+
+--S 763 of 1353
+t0:=(a+b*x^2+c*x^4)^2/x^2
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                               2
+--R                              x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 763
+
+--S 764 of 1353
+r0:=-a^2/x+2*a*b*x+1/3*(b^2+2*a*c)*x^3+2/5*b*c*x^5+1/7*c^2*x^7
+--R 
+--R
+--R           2 8          6               2  4           2       2
+--R        15c x  + 42b c x  + (70a c + 35b )x  + 210a b x  - 105a
+--R   (2)  --------------------------------------------------------
+--R                                  105x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 764
+
+--S 765 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 8          6               2  4           2       2
+--R        15c x  + 42b c x  + (70a c + 35b )x  + 210a b x  - 105a
+--R   (3)  --------------------------------------------------------
+--R                                  105x
+--R                                         Type: Union(Expression(Integer),...)
+--E 765
+
+--S 766 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 767
+
+)clear all
+
+--S 768 of 1353
+t0:=(a+b*x^2+c*x^4)^2/x^3
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                               3
+--R                              x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 768
+
+--S 769 of 1353
+r0:=-1/2*a^2/x^2+1/2*(b^2+2*a*c)*x^2+1/2*b*c*x^4+1/6*c^2*x^6+2*a*b*log(x)
+--R 
+--R
+--R               2          2 8         6             2  4     2
+--R        12a b x log(x) + c x  + 3b c x  + (6a c + 3b )x  - 3a
+--R   (2)  ------------------------------------------------------
+--R                                    2
+--R                                  6x
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2          2 8         6             2  4     2
+--R        12a b x log(x) + c x  + 3b c x  + (6a c + 3b )x  - 3a
+--R   (3)  ------------------------------------------------------
+--R                                    2
+--R                                  6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 770
+
+--S 771 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 771
+
+--S 772 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 772
+
+)clear all
+
+--S 773 of 1353
+t0:=(a+b*x^2+c*x^4)^2/x^4
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                               4
+--R                              x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 773
+
+--S 774 of 1353
+r0:=-1/3*a^2/x^3-2*a*b/x+(b^2+2*a*c)*x+2/3*b*c*x^3+1/5*c^2*x^5
+--R 
+--R
+--R        1  2 8   2      6            2  4         2   1  2
+--R        - c x  + - b c x  + (2a c + b )x  - 2a b x  - - a
+--R        5        3                                    3
+--R   (2)  --------------------------------------------------
+--R                                 3
+--R                                x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 774
+
+--S 775 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 8          6               2  4          2     2
+--R        3c x  + 10b c x  + (30a c + 15b )x  - 30a b x  - 5a
+--R   (3)  ----------------------------------------------------
+--R                                   3
+--R                                15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 775
+
+--S 776 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 777
+
+)clear all
+
+--S 778 of 1353
+t0:=(a+b*x^2+c*x^4)^2/x^7
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                               7
+--R                              x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 778
+
+--S 779 of 1353
+r0:=-1/6*a^2/x^6-1/2*a*b/x^4+1/2*(-b^2-2*a*c)/x^2+1/2*c^2*x^2+2*b*c*log(x)
+--R 
+--R
+--R               6           2 8               2  4         2    2
+--R        12b c x log(x) + 3c x  + (- 6a c - 3b )x  - 3a b x  - a
+--R   (2)  --------------------------------------------------------
+--R                                     6
+--R                                   6x
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R               6           2 8               2  4         2    2
+--R        12b c x log(x) + 3c x  + (- 6a c - 3b )x  - 3a b x  - a
+--R   (3)  --------------------------------------------------------
+--R                                     6
+--R                                   6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 780
+
+--S 781 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 781
+
+--S 782 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 782
+
+)clear all
+
+--S 783 of 1353
+t0:=(a+b*x^2+c*x^4)^2/x^13
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                              13
+--R                             x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 783
+
+--S 784 of 1353
+r0:=-1/12*a^2/x^12-1/5*a*b/x^10+1/8*(-b^2-2*a*c)/x^8-1/3*b*c/x^6-1/4*c^2/x^4
+--R 
+--R
+--R          1  2 8   1      6      1       1  2  4   1      2    1  2
+--R        - - c x  - - b c x  + (- - a c - - b )x  - - a b x  - -- a
+--R          4        3             4       8         5          12
+--R   (2)  -----------------------------------------------------------
+--R                                     12
+--R                                    x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 784
+
+--S 785 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 8          6                 2  4          2      2
+--R        - 30c x  - 40b c x  + (- 30a c - 15b )x  - 24a b x  - 10a
+--R   (3)  ----------------------------------------------------------
+--R                                      12
+--R                                  120x
+--R                                         Type: Union(Expression(Integer),...)
+--E 785
+
+--S 786 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 787
+
+)clear all
+
+--S 788 of 1353
+t0:=x^m*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  *
+--R      m
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 788
+
+--S 789 of 1353
+r0:=a^3*x^(1+m)/(1+m)+3*a^2*b*x^(3+m)/(3+m)+3*a*(b^2+a*c)*x^(5+m)/(5+m)+_
+   b*(b^2+6*a*c)*x^(7+m)/(7+m)+3*c*(b^2+a*c)*x^(9+m)/(9+m)+_
+   3*b*c^2*x^(11+m)/(11+m)+c^3*x^(13+m)/(13+m)
+--R 
+--R
+--R   (2)
+--R           3 6      3 5       3 4        3 3         3 2         3          3
+--R         (c m  + 36c m  + 505c m  + 3480c m  + 12139c m  + 19524c m + 10395c )
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R               2 6         2 5          2 4           2 3           2 2
+--R           3b c m  + 114b c m  + 1665b c m  + 11820b c m  + 42117b c m
+--R         + 
+--R                   2            2
+--R           68706b c m + 36855b c
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                2     2   6          2       2   5           2        2   4
+--R           (3a c  + 3b c)m  + (120a c  + 120b c)m  + (1839a c  + 1839b c)m
+--R         + 
+--R                    2         2   3            2         2   2
+--R           (13584a c  + 13584b c)m  + (49881a c  + 49881b c)m
+--R         + 
+--R                    2         2              2         2
+--R           (83064a c  + 83064b c)m + 45045a c  + 45045b c
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                      3  6                  3  5                    3  4
+--R           (6a b c + b )m  + (252a b c + 42b )m  + (4074a b c + 679b )m
+--R         + 
+--R                              3  3                        3  2
+--R           (31752a b c + 5292b )m  + (122010a b c + 20335b )m
+--R         + 
+--R                                3                         3
+--R           (209916a b c + 34986b )m + 115830a b c + 19305b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R              2        2  6        2          2  5         2           2  4
+--R           (3a c + 3a b )m  + (132a c + 132a b )m  + (2259a c + 2259a b )m
+--R         + 
+--R                  2            2  3          2            2  2
+--R           (18840a c + 18840a b )m  + (77937a c + 77937a b )m
+--R         + 
+--R                   2             2           2            2
+--R           (142308a c + 142308a b )m + 81081a c + 81081a b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R             2   6       2   5        2   4         2   3          2   2
+--R           3a b m  + 138a b m  + 2505a b m  + 22620a b m  + 104277a b m
+--R         + 
+--R                  2             2
+--R           219162a b m + 135135a b
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R           3 6      3 5       3 4        3 3         3 2          3           3
+--R         (a m  + 48a m  + 925a m  + 9120a m  + 48259a m  + 129072a m + 135135a )
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R      7      6       5         4         3          2
+--R     m  + 49m  + 973m  + 10045m  + 57379m  + 177331m  + 264207m + 135135
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3 6      3 5       3 4        3 3         3 2         3          3
+--R           (c m  + 36c m  + 505c m  + 3480c m  + 12139c m  + 19524c m + 10395c )
+--R        *
+--R            13
+--R           x
+--R       + 
+--R                 2 6         2 5          2 4           2 3           2 2
+--R             3b c m  + 114b c m  + 1665b c m  + 11820b c m  + 42117b c m
+--R           + 
+--R                     2            2
+--R             68706b c m + 36855b c
+--R        *
+--R            11
+--R           x
+--R       + 
+--R                  2     2   6          2       2   5           2        2   4
+--R             (3a c  + 3b c)m  + (120a c  + 120b c)m  + (1839a c  + 1839b c)m
+--R           + 
+--R                      2         2   3            2         2   2
+--R             (13584a c  + 13584b c)m  + (49881a c  + 49881b c)m
+--R           + 
+--R                      2         2              2         2
+--R             (83064a c  + 83064b c)m + 45045a c  + 45045b c
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                        3  6                  3  5                    3  4
+--R             (6a b c + b )m  + (252a b c + 42b )m  + (4074a b c + 679b )m
+--R           + 
+--R                                3  3                        3  2
+--R             (31752a b c + 5292b )m  + (122010a b c + 20335b )m
+--R           + 
+--R                                  3                         3
+--R             (209916a b c + 34986b )m + 115830a b c + 19305b
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                2        2  6        2          2  5         2           2  4
+--R             (3a c + 3a b )m  + (132a c + 132a b )m  + (2259a c + 2259a b )m
+--R           + 
+--R                    2            2  3          2            2  2
+--R             (18840a c + 18840a b )m  + (77937a c + 77937a b )m
+--R           + 
+--R                     2             2           2            2
+--R             (142308a c + 142308a b )m + 81081a c + 81081a b
+--R        *
+--R            5
+--R           x
+--R       + 
+--R               2   6       2   5        2   4         2   3          2   2
+--R             3a b m  + 138a b m  + 2505a b m  + 22620a b m  + 104277a b m
+--R           + 
+--R                    2             2
+--R             219162a b m + 135135a b
+--R        *
+--R            3
+--R           x
+--R       + 
+--R         3 6      3 5       3 4        3 3         3 2          3           3
+--R       (a m  + 48a m  + 925a m  + 9120a m  + 48259a m  + 129072a m + 135135a )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      7      6       5         4         3          2
+--R     m  + 49m  + 973m  + 10045m  + 57379m  + 177331m  + 264207m + 135135
+--R                                         Type: Union(Expression(Integer),...)
+--E 790
+
+--S 791 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  3 6      3 5       3 4        3 3         3 2         3
+--R                 c m  + 36c m  + 505c m  + 3480c m  + 12139c m  + 19524c m
+--R               + 
+--R                       3
+--R                 10395c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                   2 6         2 5          2 4           2 3           2 2
+--R               3b c m  + 114b c m  + 1665b c m  + 11820b c m  + 42117b c m
+--R             + 
+--R                       2            2
+--R               68706b c m + 36855b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                    2     2   6          2       2   5           2        2   4
+--R               (3a c  + 3b c)m  + (120a c  + 120b c)m  + (1839a c  + 1839b c)m
+--R             + 
+--R                        2         2   3            2         2   2
+--R               (13584a c  + 13584b c)m  + (49881a c  + 49881b c)m
+--R             + 
+--R                        2         2              2         2
+--R               (83064a c  + 83064b c)m + 45045a c  + 45045b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                          3  6                  3  5                    3  4
+--R               (6a b c + b )m  + (252a b c + 42b )m  + (4074a b c + 679b )m
+--R             + 
+--R                                  3  3                        3  2
+--R               (31752a b c + 5292b )m  + (122010a b c + 20335b )m
+--R             + 
+--R                                    3                         3
+--R               (209916a b c + 34986b )m + 115830a b c + 19305b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                  2        2  6        2          2  5         2           2  4
+--R               (3a c + 3a b )m  + (132a c + 132a b )m  + (2259a c + 2259a b )m
+--R             + 
+--R                      2            2  3          2            2  2
+--R               (18840a c + 18840a b )m  + (77937a c + 77937a b )m
+--R             + 
+--R                       2             2           2            2
+--R               (142308a c + 142308a b )m + 81081a c + 81081a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                 2   6       2   5        2   4         2   3          2   2
+--R               3a b m  + 138a b m  + 2505a b m  + 22620a b m  + 104277a b m
+--R             + 
+--R                      2             2
+--R               219162a b m + 135135a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                3 6      3 5       3 4        3 3         3 2          3
+--R               a m  + 48a m  + 925a m  + 9120a m  + 48259a m  + 129072a m
+--R             + 
+--R                      3
+--R               135135a
+--R          *
+--R             x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R             3 6      3 5       3 4        3 3         3 2         3          3
+--R         (- c m  - 36c m  - 505c m  - 3480c m  - 12139c m  - 19524c m - 10395c )
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                 2 6         2 5          2 4           2 3           2 2
+--R           - 3b c m  - 114b c m  - 1665b c m  - 11820b c m  - 42117b c m
+--R         + 
+--R                     2            2
+--R           - 68706b c m - 36855b c
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                  2     2   6            2       2   5
+--R           (- 3a c  - 3b c)m  + (- 120a c  - 120b c)m
+--R         + 
+--R                     2        2   4              2         2   3
+--R           (- 1839a c  - 1839b c)m  + (- 13584a c  - 13584b c)m
+--R         + 
+--R                      2         2   2              2         2              2
+--R           (- 49881a c  - 49881b c)m  + (- 83064a c  - 83064b c)m - 45045a c
+--R         + 
+--R                   2
+--R           - 45045b c
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                        3  6                    3  5                      3  4
+--R           (- 6a b c - b )m  + (- 252a b c - 42b )m  + (- 4074a b c - 679b )m
+--R         + 
+--R                                3  3                          3  2
+--R           (- 31752a b c - 5292b )m  + (- 122010a b c - 20335b )m
+--R         + 
+--R                                  3                         3
+--R           (- 209916a b c - 34986b )m - 115830a b c - 19305b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R                2        2  6          2          2  5
+--R           (- 3a c - 3a b )m  + (- 132a c - 132a b )m
+--R         + 
+--R                   2           2  4            2            2  3
+--R           (- 2259a c - 2259a b )m  + (- 18840a c - 18840a b )m
+--R         + 
+--R                    2            2  2             2             2           2
+--R           (- 77937a c - 77937a b )m  + (- 142308a c - 142308a b )m - 81081a c
+--R         + 
+--R                     2
+--R           - 81081a b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R               2   6       2   5        2   4         2   3          2   2
+--R           - 3a b m  - 138a b m  - 2505a b m  - 22620a b m  - 104277a b m
+--R         + 
+--R                    2             2
+--R           - 219162a b m - 135135a b
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R                3 6      3 5       3 4        3 3         3 2          3
+--R             - a m  - 48a m  - 925a m  - 9120a m  - 48259a m  - 129072a m
+--R           + 
+--R                      3
+--R             - 135135a
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R      7      6       5         4         3          2
+--R     m  + 49m  + 973m  + 10045m  + 57379m  + 177331m  + 264207m + 135135
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 792
+
+)clear all
+
+--S 793 of 1353
+t0:=x^4*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 16       2 14        2     2   12              3  10      2        2  8
+--R     c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x   + (3a c + 3a b )x
+--R   + 
+--R       2   6    3 4
+--R     3a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 793
+
+--S 794 of 1353
+r0:=1/5*a^3*x^5+3/7*a^2*b*x^7+1/3*a*(b^2+a*c)*x^9+1/11*b*(b^2+6*a*c)*x^11+_
+   3/13*c*(b^2+a*c)*x^13+1/5*b*c^2*x^15+1/17*c^3*x^17
+--R 
+--R
+--R   (2)
+--R      1  3 17   1    2 15     3    2    3  2   13     6          1  3  11
+--R     -- c x   + - b c x   + (-- a c  + -- b c)x   + (-- a b c + -- b )x
+--R     17         5            13        13            11         11
+--R   + 
+--R      1  2    1    2  9   3  2   7   1  3 5
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      3       3           7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 794
+
+--S 795 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3 17   1    2 15     3    2    3  2   13     6          1  3  11
+--R     -- c x   + - b c x   + (-- a c  + -- b c)x   + (-- a b c + -- b )x
+--R     17         5            13        13            11         11
+--R   + 
+--R      1  2    1    2  9   3  2   7   1  3 5
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      3       3           7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 795
+
+--S 796 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 796
+
+--S 797 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 797
+
+)clear all
+
+--S 798 of 1353
+t0:=x^3*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 15       2 13        2     2   11              3  9      2        2  7
+--R     c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R   + 
+--R       2   5    3 3
+--R     3a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 798
+
+--S 799 of 1353
+r0:=1/4*a^3*x^4+1/2*a^2*b*x^6+3/8*a*(b^2+a*c)*x^8+1/10*b*(b^2+6*a*c)*x^10+_
+   1/4*c*(b^2+a*c)*x^12+3/14*b*c^2*x^14+1/16*c^3*x^16
+--R 
+--R
+--R   (2)
+--R      1  3 16    3    2 14    1    2   1  2   12    3          1  3  10
+--R     -- c x   + -- b c x   + (- a c  + - b c)x   + (- a b c + -- b )x
+--R     16         14            4        4            5         10
+--R   + 
+--R      3  2    3    2  8   1  2   6   1  3 4
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      8       8           2          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 799
+
+--S 800 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3 16    3    2 14    1    2   1  2   12    3          1  3  10
+--R     -- c x   + -- b c x   + (- a c  + - b c)x   + (- a b c + -- b )x
+--R     16         14            4        4            5         10
+--R   + 
+--R      3  2    3    2  8   1  2   6   1  3 4
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      8       8           2          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 800
+
+--S 801 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 801
+
+--S 802 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 802
+
+)clear all
+
+--S 803 of 1353
+t0:=x^2*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 14       2 12        2     2   10              3  8      2        2  6
+--R     c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R   + 
+--R       2   4    3 2
+--R     3a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 803
+
+--S 804 of 1353
+r0:=1/3*a^3*x^3+3/5*a^2*b*x^5+3/7*a*(b^2+a*c)*x^7+1/9*b*(b^2+6*a*c)*x^9+_
+   3/11*c*(b^2+a*c)*x^11+3/13*b*c^2*x^13+1/15*c^3*x^15
+--R 
+--R
+--R   (2)
+--R      1  3 15    3    2 13     3    2    3  2   11    2         1  3  9
+--R     -- c x   + -- b c x   + (-- a c  + -- b c)x   + (- a b c + - b )x
+--R     15         13            11        11            3         9
+--R   + 
+--R      3  2    3    2  7   3  2   5   1  3 3
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      7       7           5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 804
+
+--S 805 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3 15    3    2 13     3    2    3  2   11    2         1  3  9
+--R     -- c x   + -- b c x   + (-- a c  + -- b c)x   + (- a b c + - b )x
+--R     15         13            11        11            3         9
+--R   + 
+--R      3  2    3    2  7   3  2   5   1  3 3
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      7       7           5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 805
+
+--S 806 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 806
+
+--S 807 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 807
+
+)clear all
+
+--S 808 of 1353
+t0:=x*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 13       2 11        2     2   9              3  7      2        2  5
+--R     c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R   + 
+--R       2   3    3
+--R     3a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 808
+
+--S 809 of 1353
+r0:=1/2*a^3*x^2+3/4*a^2*b*x^4+1/2*a*(b^2+a*c)*x^6+1/8*b*(b^2+6*a*c)*x^8+_
+   3/10*c*(b^2+a*c)*x^10+1/4*b*c^2*x^12+1/14*c^3*x^14
+--R 
+--R
+--R   (2)
+--R      1  3 14   1    2 12     3    2    3  2   10    3         1  3  8
+--R     -- c x   + - b c x   + (-- a c  + -- b c)x   + (- a b c + - b )x
+--R     14         4            10        10            4         8
+--R   + 
+--R      1  2    1    2  6   3  2   4   1  3 2
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      2       2           4          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 809
+
+--S 810 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3 14   1    2 12     3    2    3  2   10    3         1  3  8
+--R     -- c x   + - b c x   + (-- a c  + -- b c)x   + (- a b c + - b )x
+--R     14         4            10        10            4         8
+--R   + 
+--R      1  2    1    2  6   3  2   4   1  3 2
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      2       2           4          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 810
+
+--S 811 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 811
+
+--S 812 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 812
+
+)clear all
+
+--S 813 of 1353
+t0:=(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 12       2 10        2     2   8              3  6      2        2  4
+--R     c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R   + 
+--R       2   2    3
+--R     3a b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 813
+
+--S 814 of 1353
+r0:=a^3*x+a^2*b*x^3+3/5*a*(b^2+a*c)*x^5+1/7*b*(b^2+6*a*c)*x^7+_
+   1/3*c*(b^2+a*c)*x^9+3/11*b*c^2*x^11+1/13*c^3*x^13
+--R 
+--R
+--R   (2)
+--R      1  3 13    3    2 11    1    2   1  2   9    6         1  3  7
+--R     -- c x   + -- b c x   + (- a c  + - b c)x  + (- a b c + - b )x
+--R     13         11            3        3           7         7
+--R   + 
+--R      3  2    3    2  5    2   3    3
+--R     (- a c + - a b )x  + a b x  + a x
+--R      5       5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 814
+
+--S 815 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3 13    3    2 11    1    2   1  2   9    6         1  3  7
+--R     -- c x   + -- b c x   + (- a c  + - b c)x  + (- a b c + - b )x
+--R     13         11            3        3           7         7
+--R   + 
+--R      3  2    3    2  5    2   3    3
+--R     (- a c + - a b )x  + a b x  + a x
+--R      5       5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 815
+
+--S 816 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 816
+
+--S 817 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 817
+
+)clear all
+
+--S 818 of 1353
+t0:=(a+b*x^2+c*x^4)^3/x
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 818
+
+--S 819 of 1353
+r0:=3/2*a^2*b*x^2+3/4*a*(b^2+a*c)*x^4+1/6*b*(b^2+6*a*c)*x^6+_
+   3/8*c*(b^2+a*c)*x^8+3/10*b*c^2*x^10+1/12*c^3*x^12+a^3*log(x)
+--R 
+--R
+--R   (2)
+--R           3            3 12        2 10         2      2   8
+--R       120a log(x) + 10c x   + 36b c x   + (45a c  + 45b c)x
+--R     + 
+--R                      3  6       2         2  4       2   2
+--R       (120a b c + 20b )x  + (90a c + 90a b )x  + 180a b x
+--R  /
+--R     120
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3            3 12        2 10         2      2   8
+--R       120a log(x) + 10c x   + 36b c x   + (45a c  + 45b c)x
+--R     + 
+--R                      3  6       2         2  4       2   2
+--R       (120a b c + 20b )x  + (90a c + 90a b )x  + 180a b x
+--R  /
+--R     120
+--R                                         Type: Union(Expression(Integer),...)
+--E 820
+
+--S 821 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 822
+
+)clear all
+
+--S 823 of 1353
+t0:=(a+b*x^2+c*x^4)^3/x^2
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      2
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 823
+
+--S 824 of 1353
+r0:=-a^3/x+3*a^2*b*x+a*(b^2+a*c)*x^3+1/5*b*(b^2+6*a*c)*x^5+_
+   3/7*c*(b^2+a*c)*x^7+1/3*b*c^2*x^9+1/11*c^3*x^11
+--R 
+--R
+--R   (2)
+--R           3 12         2 10          2       2   8                    3  6
+--R       105c x   + 385b c x   + (495a c  + 495b c)x  + (1386a b c + 231b )x
+--R     + 
+--R             2           2  4        2   2        3
+--R       (1155a c + 1155a b )x  + 3465a b x  - 1155a
+--R  /
+--R     1155x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 824
+
+--S 825 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 12         2 10          2       2   8                    3  6
+--R       105c x   + 385b c x   + (495a c  + 495b c)x  + (1386a b c + 231b )x
+--R     + 
+--R             2           2  4        2   2        3
+--R       (1155a c + 1155a b )x  + 3465a b x  - 1155a
+--R  /
+--R     1155x
+--R                                         Type: Union(Expression(Integer),...)
+--E 825
+
+--S 826 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 827
+
+)clear all
+
+--S 828 of 1353
+t0:=(a+b*x^2+c*x^4)^3/x^3
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      3
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 828
+
+--S 829 of 1353
+r0:=-1/2*a^3/x^2+3/2*a*(b^2+a*c)*x^2+1/4*b*(b^2+6*a*c)*x^4+_
+   1/2*c*(b^2+a*c)*x^6+3/8*b*c^2*x^8+1/10*c^3*x^10+3*a^2*b*log(x)
+--R 
+--R
+--R   (2)
+--R           2   2           3 12        2 10         2      2   8
+--R       120a b x log(x) + 4c x   + 15b c x   + (20a c  + 20b c)x
+--R     + 
+--R                     3  6       2         2  4      3
+--R       (60a b c + 10b )x  + (60a c + 60a b )x  - 20a
+--R  /
+--R        2
+--R     40x
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2   2           3 12        2 10         2      2   8
+--R       120a b x log(x) + 4c x   + 15b c x   + (20a c  + 20b c)x
+--R     + 
+--R                     3  6       2         2  4      3
+--R       (60a b c + 10b )x  + (60a c + 60a b )x  - 20a
+--R  /
+--R        2
+--R     40x
+--R                                         Type: Union(Expression(Integer),...)
+--E 830
+
+--S 831 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 832
+
+)clear all
+
+--S 833 of 1353
+t0:=(a+b*x^2+c*x^4)^3/x^4
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      4
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 833
+
+--S 834 of 1353
+r0:=-1/3*a^3/x^3-3*a^2*b/x+3*a*(b^2+a*c)*x+1/3*b*(b^2+6*a*c)*x^3+_
+   3/5*c*(b^2+a*c)*x^5+3/7*b*c^2*x^7+1/9*c^3*x^9
+--R 
+--R
+--R   (2)
+--R       1  3 12   3    2 10    3    2   3  2   8             1  3  6
+--R       - c x   + - b c x   + (- a c  + - b c)x  + (2a b c + - b )x
+--R       9         7            5        5                    3
+--R     + 
+--R          2        2  4     2   2   1  3
+--R       (3a c + 3a b )x  - 3a b x  - - a
+--R                                    3
+--R  /
+--R      3
+--R     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 834
+
+--S 835 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3 12         2 10          2       2   8                   3  6
+--R       35c x   + 135b c x   + (189a c  + 189b c)x  + (630a b c + 105b )x
+--R     + 
+--R            2          2  4       2   2       3
+--R       (945a c + 945a b )x  - 945a b x  - 105a
+--R  /
+--R         3
+--R     315x
+--R                                         Type: Union(Expression(Integer),...)
+--E 835
+
+--S 836 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 837
+
+)clear all
+
+--S 838 of 1353
+t0:=x^m/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 838
+
+--S 839 of 1353
+--r0:=2*c*x^(1+m)*hypergeometric(1,1/2*(1+m),1/2*(3+m),-2*c*x^2/(b-sqrt(b^2-4*a*c)))/((1+m)*(b-sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))-2*c*x^(1+m)*hypergeometric(1,1/2*(1+m),1/2*(3+m),-2*c*x^2/(b+sqrt(b^2-4*a*c)))/((1+m)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))
+--E 839
+
+--S 840 of 1353
+--a0:=integrate(t0,x)
+--E 840
+
+--S 841 of 1353
+--m0:=a0-r0
+--E 841
+
+--S 842 of 1353
+--d0:=normalize(D(m0,x))
+--E 842
+
+)clear all
+
+--S 843 of 1353
+t0:=x^5/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                5
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 843
+
+--S 844 of 1353
+r0:=1/2*x^2/c-1/4*b*log(a+b*x^2+c*x^4)/c^2-1/2*(b^2-2*a*c)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                2
+--R                 2          2c x  + b
+--R       (4a c - 2b )atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                          +-----------+
+--R                   4      2            2  |          2
+--R       (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 844
+
+--S 845 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2
+--R           (2a c - b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                            +-----------+
+--R                     4      2            2  |          2
+--R         (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         2 |          2
+--R       4c \|- 4a c + b
+--R     ,
+--R
+--R                                        +---------+
+--R                                 2      |        2
+--R                     2      (2c x  + b)\|4a c - b
+--R         (- 4a c + 2b )atan(-----------------------)
+--R                                           2
+--R                                   4a c - b
+--R       + 
+--R                                            +---------+
+--R                     4      2            2  |        2
+--R         (- b log(c x  + b x  + a) + 2c x )\|4a c - b
+--R    /
+--R           +---------+
+--R         2 |        2
+--R       4c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 845
+
+--S 846 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                  2
+--R                   2          2c x  + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 846
+
+--S 847 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+             2
+--R                  2  |        2          2c x  + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                     +-----------+          2      |        2
+--R                  2  |          2      (2c x  + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     2c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 848
+
+--S 849 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 849
+
+)clear all
+
+--S 850 of 1353
+t0:=x^4/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 850
+
+--S 851 of 1353
+r0:=x/c-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+_
+   (-b^2+2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R              +-----------+              | +-----------+
+--R              |          2            2  | |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R              +-----------+              |   +-----------+
+--R              |          2            2  |   |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R         +-+ |          2  +-+ |   |          2       | |          2
+--R       x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-----------------------------------------------------+
+--R           |                 +--------------------+
+--R           |                 |   2 2       2     4
+--R           |      4     2 3  |- a c  + 2a b c - b               3
+--R           |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R           |                 |        7      2 6
+--R           |                \|   64a c  - 16b c
+--R         c |-----------------------------------------------------
+--R           |                        4     2 3
+--R          \|                    8a c  - 2b c
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                    (16a b c  - 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                  + 
+--R                       4
+--R                    - b
+--R             *
+--R                 +-----------------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |                 |   2 2       2     4
+--R                 |      4     2 3  |- a c  + 2a b c - b               3
+--R                 |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R                 |                 |        7      2 6
+--R                 |                \|   64a c  - 16b c
+--R                 |-----------------------------------------------------
+--R                 |                        4     2 3
+--R                \|                    8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       -
+--R              +-------------------------------------------------------+
+--R              |                   +--------------------+
+--R              |                   |   2 2       2     4
+--R              |        4     2 3  |- a c  + 2a b c - b               3
+--R              |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R              |                   |        7      2 6
+--R              |                  \|   64a c  - 16b c
+--R            c |-------------------------------------------------------
+--R              |                         4     2 3
+--R             \|                     8a c  - 2b c
+--R         *
+--R            log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                             4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                     (16a b c  - 4b c ) |--------------------  + 4a c  - 5a b c
+--R                                        |        7      2 6
+--R                                       \|   64a c  - 16b c
+--R                   + 
+--R                      4
+--R                     b
+--R                *
+--R                    +-------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |        4     2 3  |- a c  + 2a b c - b               3
+--R                    |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R                    |                   |        7      2 6
+--R                    |                  \|   64a c  - 16b c
+--R                    |-------------------------------------------------------
+--R                    |                         4     2 3
+--R                   \|                     8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R           +-------------------------------------------------------+
+--R           |                   +--------------------+
+--R           |                   |   2 2       2     4
+--R           |        4     2 3  |- a c  + 2a b c - b               3
+--R           |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R           |                   |        7      2 6
+--R           |                  \|   64a c  - 16b c
+--R         c |-------------------------------------------------------
+--R           |                         4     2 3
+--R          \|                     8a c  - 2b c
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                  (- 16a b c  + 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                + 
+--R                     4
+--R                  - b
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |        4     2 3  |- a c  + 2a b c - b               3
+--R                 |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R                 |                   |        7      2 6
+--R                 |                  \|   64a c  - 16b c
+--R                 |-------------------------------------------------------
+--R                 |                         4     2 3
+--R                \|                     8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       -
+--R              +-----------------------------------------------------+
+--R              |                 +--------------------+
+--R              |                 |   2 2       2     4
+--R              |      4     2 3  |- a c  + 2a b c - b               3
+--R              |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R              |                 |        7      2 6
+--R              |                \|   64a c  - 16b c
+--R            c |-----------------------------------------------------
+--R              |                        4     2 3
+--R             \|                    8a c  - 2b c
+--R         *
+--R            log
+--R                                          +--------------------+
+--R                                          |   2 2       2     4
+--R                               4     3 3  |- a c  + 2a b c - b       2 2
+--R                     (- 16a b c  + 4b c ) |--------------------  + 4a c
+--R                                          |        7      2 6
+--R                                         \|   64a c  - 16b c
+--R                   + 
+--R                           2     4
+--R                     - 5a b c + b
+--R                *
+--R                    +-----------------------------------------------------+
+--R                    |                 +--------------------+
+--R                    |                 |   2 2       2     4
+--R                    |      4     2 3  |- a c  + 2a b c - b               3
+--R                    |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R                    |                 |        7      2 6
+--R                    |                \|   64a c  - 16b c
+--R                    |-----------------------------------------------------
+--R                    |                        4     2 3
+--R                   \|                    8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R       2x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 852
+
+--S 853 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------------------------------------+
+--R          |                 +--------------------+
+--R          |                 |   2 2       2     4
+--R          |      4     2 3  |- a c  + 2a b c - b               3
+--R          |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R          |                 |        7      2 6
+--R          |                \|   64a c  - 16b c
+--R          |-----------------------------------------------------
+--R          |                        4     2 3
+--R         \|                    8a c  - 2b c
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                    (16a b c  - 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                  + 
+--R                       4
+--R                    - b
+--R             *
+--R                 +-----------------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |                 |   2 2       2     4
+--R                 |      4     2 3  |- a c  + 2a b c - b               3
+--R                 |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R                 |                 |        7      2 6
+--R                 |                \|   64a c  - 16b c
+--R                 |-----------------------------------------------------
+--R                 |                        4     2 3
+--R                \|                    8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            c\|2 \|- 4a c + b  \|c
+--R         *
+--R             +-------------------------------------------------------+
+--R             |                   +--------------------+
+--R             |                   |   2 2       2     4
+--R             |        4     2 3  |- a c  + 2a b c - b               3
+--R             |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R             |                   |        7      2 6
+--R             |                  \|   64a c  - 16b c
+--R             |-------------------------------------------------------
+--R             |                         4     2 3
+--R            \|                     8a c  - 2b c
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                             4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                     (16a b c  - 4b c ) |--------------------  + 4a c  - 5a b c
+--R                                        |        7      2 6
+--R                                       \|   64a c  - 16b c
+--R                   + 
+--R                      4
+--R                     b
+--R                *
+--R                    +-------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |        4     2 3  |- a c  + 2a b c - b               3
+--R                    |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R                    |                   |        7      2 6
+--R                    |                  \|   64a c  - 16b c
+--R                    |-------------------------------------------------------
+--R                    |                         4     2 3
+--R                   \|                     8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2  +-+
+--R         c\|2 \|- 4a c + b  \|c
+--R      *
+--R          +-------------------------------------------------------+
+--R          |                   +--------------------+
+--R          |                   |   2 2       2     4
+--R          |        4     2 3  |- a c  + 2a b c - b               3
+--R          |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R          |                   |        7      2 6
+--R          |                  \|   64a c  - 16b c
+--R          |-------------------------------------------------------
+--R          |                         4     2 3
+--R         \|                     8a c  - 2b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                  (- 16a b c  + 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                + 
+--R                     4
+--R                  - b
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |        4     2 3  |- a c  + 2a b c - b               3
+--R                 |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R                 |                   |        7      2 6
+--R                 |                  \|   64a c  - 16b c
+--R                 |-------------------------------------------------------
+--R                 |                         4     2 3
+--R                \|                     8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       -
+--R                                    +--------------------+ +------------------+
+--R                  +-----------+     |   +-----------+      | +-----------+
+--R              +-+ |          2  +-+ |   |          2       | |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +-----------------------------------------------------+
+--R             |                 +--------------------+
+--R             |                 |   2 2       2     4
+--R             |      4     2 3  |- a c  + 2a b c - b               3
+--R             |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R             |                 |        7      2 6
+--R             |                \|   64a c  - 16b c
+--R             |-----------------------------------------------------
+--R             |                        4     2 3
+--R            \|                    8a c  - 2b c
+--R         *
+--R            log
+--R                                          +--------------------+
+--R                                          |   2 2       2     4
+--R                               4     3 3  |- a c  + 2a b c - b       2 2
+--R                     (- 16a b c  + 4b c ) |--------------------  + 4a c
+--R                                          |        7      2 6
+--R                                         \|   64a c  - 16b c
+--R                   + 
+--R                           2     4
+--R                     - 5a b c + b
+--R                *
+--R                    +-----------------------------------------------------+
+--R                    |                 +--------------------+
+--R                    |                 |   2 2       2     4
+--R                    |      4     2 3  |- a c  + 2a b c - b               3
+--R                    |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R                    |                 |        7      2 6
+--R                    |                \|   64a c  - 16b c
+--R                    |-----------------------------------------------------
+--R                    |                        4     2 3
+--R                   \|                    8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R                                         +------------------+
+--R             +-----------+               | +-----------+
+--R             |          2             2  | |          2
+--R         (2b\|- 4a c + b   + 4a c - 2b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R             +-----------+               |   +-----------+
+--R             |          2             2  |   |          2
+--R         (2b\|- 4a c + b   - 4a c + 2b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 853
+
+--S 854 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 854
+
+)clear all
+
+--S 855 of 1353
+t0:=x^3/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 855
+
+--S 856 of 1353
+r0:=1/4*log(a+b*x^2+c*x^4)/c+1/2*b*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                        2                               +-----------+
+--R                    2c x  + b             4      2      |          2
+--R        2b atanh(--------------) + log(c x  + b x  + a)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  -------------------------------------------------------------
+--R                                  +-----------+
+--R                                  |          2
+--R                               4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 856
+
+--S 857 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                              +-----------+
+--R                4      2      |          2
+--R         log(c x  + b x  + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       4c\|- 4a c + b
+--R     ,
+--R                          +---------+
+--R                   2      |        2                          +---------+
+--R              (2c x  + b)\|4a c - b             4      2      |        2
+--R    - 2b atan(-----------------------) + log(c x  + b x  + a)\|4a c - b
+--R                             2
+--R                     4a c - b
+--R    ---------------------------------------------------------------------]
+--R                                   +---------+
+--R                                   |        2
+--R                                4c\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 857
+
+--S 858 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                         2
+--R                     2c x  + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 858
+
+--S 859 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 859
+
+--S 860 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             2
+--R           |        2          2c x  + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          2      |        2
+--R           |          2      (2c x  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     2c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 860
+
+--S 861 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 861
+
+)clear all
+
+--S 862 of 1353
+t0:=x^2/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 862
+
+--S 863 of 1353
+r0:=-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(b-sqrt(b^2-4*a*c))/_
+   (sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*_
+   sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +--------------------+
+--R          |   +-----------+                   +-+ +-+
+--R          |   |          2                  x\|2 \|c
+--R       - \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                      |   |          2
+--R                                     \|- \|- 4a c + b   + b
+--R     + 
+--R        +------------------+
+--R        | +-----------+                  +-+ +-+
+--R        | |          2                 x\|2 \|c
+--R       \|\|- 4a c + b   + b atan(---------------------)
+--R                                  +------------------+
+--R                                  | +-----------+
+--R                                  | |          2
+--R                                 \|\|- 4a c + b   + b
+--R  /
+--R          +-----------+
+--R      +-+ |          2  +-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 863
+
+--S 864 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +---------------------------------------+
+--R          |                +-----------------+
+--R          |      2     2   |         1
+--R          |(16a c  - 4b c) |- ---------------  + b
+--R          |                |       3      2 2
+--R          |               \|  64a c  - 16b c
+--R          |---------------------------------------
+--R          |                  2     2
+--R         \|              8a c  - 2b c
+--R      *
+--R         log
+--R                                +-----------------+
+--R                      2     2   |         1
+--R                (16a c  - 4b c) |- ---------------
+--R                                |       3      2 2
+--R                               \|  64a c  - 16b c
+--R             *
+--R                 +---------------------------------------+
+--R                 |                +-----------------+
+--R                 |      2     2   |         1
+--R                 |(16a c  - 4b c) |- ---------------  + b
+--R                 |                |       3      2 2
+--R                 |               \|  64a c  - 16b c
+--R                 |---------------------------------------
+--R                 |                  2     2
+--R                \|              8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +-----------------------------------------+
+--R             |                  +-----------------+
+--R             |        2     2   |         1
+--R             |(- 16a c  + 4b c) |- ---------------  + b
+--R             |                  |       3      2 2
+--R             |                 \|  64a c  - 16b c
+--R             |-----------------------------------------
+--R             |                   2     2
+--R            \|               8a c  - 2b c
+--R         *
+--R            log
+--R                                   +-----------------+
+--R                         2     2   |         1
+--R                   (16a c  - 4b c) |- ---------------
+--R                                   |       3      2 2
+--R                                  \|  64a c  - 16b c
+--R                *
+--R                    +-----------------------------------------+
+--R                    |                  +-----------------+
+--R                    |        2     2   |         1
+--R                    |(- 16a c  + 4b c) |- ---------------  + b
+--R                    |                  |       3      2 2
+--R                    |                 \|  64a c  - 16b c
+--R                    |-----------------------------------------
+--R                    |                   2     2
+--R                   \|               8a c  - 2b c
+--R               + 
+--R                 x
+--R     + 
+--R          +-----------------------------------------+
+--R          |                  +-----------------+
+--R          |        2     2   |         1
+--R          |(- 16a c  + 4b c) |- ---------------  + b
+--R          |                  |       3      2 2
+--R          |                 \|  64a c  - 16b c
+--R          |-----------------------------------------
+--R          |                   2     2
+--R         \|               8a c  - 2b c
+--R      *
+--R         log
+--R                                  +-----------------+
+--R                        2     2   |         1
+--R                (- 16a c  + 4b c) |- ---------------
+--R                                  |       3      2 2
+--R                                 \|  64a c  - 16b c
+--R             *
+--R                 +-----------------------------------------+
+--R                 |                  +-----------------+
+--R                 |        2     2   |         1
+--R                 |(- 16a c  + 4b c) |- ---------------  + b
+--R                 |                  |       3      2 2
+--R                 |                 \|  64a c  - 16b c
+--R                 |-----------------------------------------
+--R                 |                   2     2
+--R                \|               8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +---------------------------------------+
+--R             |                +-----------------+
+--R             |      2     2   |         1
+--R             |(16a c  - 4b c) |- ---------------  + b
+--R             |                |       3      2 2
+--R             |               \|  64a c  - 16b c
+--R             |---------------------------------------
+--R             |                  2     2
+--R            \|              8a c  - 2b c
+--R         *
+--R            log
+--R                                     +-----------------+
+--R                           2     2   |         1
+--R                   (- 16a c  + 4b c) |- ---------------
+--R                                     |       3      2 2
+--R                                    \|  64a c  - 16b c
+--R                *
+--R                    +---------------------------------------+
+--R                    |                +-----------------+
+--R                    |      2     2   |         1
+--R                    |(16a c  - 4b c) |- ---------------  + b
+--R                    |                |       3      2 2
+--R                    |               \|  64a c  - 16b c
+--R                    |---------------------------------------
+--R                    |                  2     2
+--R                   \|              8a c  - 2b c
+--R               + 
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 864
+
+--S 865 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +---------------------------------------+
+--R                                |                +-----------------+
+--R                                |      2     2   |         1
+--R                                |(16a c  - 4b c) |- ---------------  + b
+--R              +-----------+     |                |       3      2 2
+--R          +-+ |          2  +-+ |               \|  64a c  - 16b c
+--R         \|2 \|- 4a c + b  \|c  |---------------------------------------
+--R                                |                  2     2
+--R                               \|              8a c  - 2b c
+--R      *
+--R         log
+--R                                +-----------------+
+--R                      2     2   |         1
+--R                (16a c  - 4b c) |- ---------------
+--R                                |       3      2 2
+--R                               \|  64a c  - 16b c
+--R             *
+--R                 +---------------------------------------+
+--R                 |                +-----------------+
+--R                 |      2     2   |         1
+--R                 |(16a c  - 4b c) |- ---------------  + b
+--R                 |                |       3      2 2
+--R                 |               \|  64a c  - 16b c
+--R                 |---------------------------------------
+--R                 |                  2     2
+--R                \|              8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                                   +-----------------------------------------+
+--R                                   |                  +-----------------+
+--R                                   |        2     2   |         1
+--R                                   |(- 16a c  + 4b c) |- ---------------  + b
+--R                 +-----------+     |                  |       3      2 2
+--R             +-+ |          2  +-+ |                 \|  64a c  - 16b c
+--R            \|2 \|- 4a c + b  \|c  |-----------------------------------------
+--R                                   |                   2     2
+--R                                  \|               8a c  - 2b c
+--R         *
+--R            log
+--R                                   +-----------------+
+--R                         2     2   |         1
+--R                   (16a c  - 4b c) |- ---------------
+--R                                   |       3      2 2
+--R                                  \|  64a c  - 16b c
+--R                *
+--R                    +-----------------------------------------+
+--R                    |                  +-----------------+
+--R                    |        2     2   |         1
+--R                    |(- 16a c  + 4b c) |- ---------------  + b
+--R                    |                  |       3      2 2
+--R                    |                 \|  64a c  - 16b c
+--R                    |-----------------------------------------
+--R                    |                   2     2
+--R                   \|               8a c  - 2b c
+--R               + 
+--R                 x
+--R     + 
+--R                                +-----------------------------------------+
+--R                                |                  +-----------------+
+--R                                |        2     2   |         1
+--R                                |(- 16a c  + 4b c) |- ---------------  + b
+--R              +-----------+     |                  |       3      2 2
+--R          +-+ |          2  +-+ |                 \|  64a c  - 16b c
+--R         \|2 \|- 4a c + b  \|c  |-----------------------------------------
+--R                                |                   2     2
+--R                               \|               8a c  - 2b c
+--R      *
+--R         log
+--R                                  +-----------------+
+--R                        2     2   |         1
+--R                (- 16a c  + 4b c) |- ---------------
+--R                                  |       3      2 2
+--R                                 \|  64a c  - 16b c
+--R             *
+--R                 +-----------------------------------------+
+--R                 |                  +-----------------+
+--R                 |        2     2   |         1
+--R                 |(- 16a c  + 4b c) |- ---------------  + b
+--R                 |                  |       3      2 2
+--R                 |                 \|  64a c  - 16b c
+--R                 |-----------------------------------------
+--R                 |                   2     2
+--R                \|               8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                                   +---------------------------------------+
+--R                                   |                +-----------------+
+--R                                   |      2     2   |         1
+--R                                   |(16a c  - 4b c) |- ---------------  + b
+--R                 +-----------+     |                |       3      2 2
+--R             +-+ |          2  +-+ |               \|  64a c  - 16b c
+--R            \|2 \|- 4a c + b  \|c  |---------------------------------------
+--R                                   |                  2     2
+--R                                  \|              8a c  - 2b c
+--R         *
+--R            log
+--R                                     +-----------------+
+--R                           2     2   |         1
+--R                   (- 16a c  + 4b c) |- ---------------
+--R                                     |       3      2 2
+--R                                    \|  64a c  - 16b c
+--R                *
+--R                    +---------------------------------------+
+--R                    |                +-----------------+
+--R                    |      2     2   |         1
+--R                    |(16a c  - 4b c) |- ---------------  + b
+--R                    |                |       3      2 2
+--R                    |               \|  64a c  - 16b c
+--R                    |---------------------------------------
+--R                    |                  2     2
+--R                   \|              8a c  - 2b c
+--R               + 
+--R                 x
+--R     + 
+--R         +--------------------+
+--R         |   +-----------+                   +-+ +-+
+--R         |   |          2                  x\|2 \|c
+--R       2\|- \|- 4a c + b   + b atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                     |   |          2
+--R                                    \|- \|- 4a c + b   + b
+--R     + 
+--R           +------------------+
+--R           | +-----------+                  +-+ +-+
+--R           | |          2                 x\|2 \|c
+--R       - 2\|\|- 4a c + b   + b atan(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                     | |          2
+--R                                    \|\|- 4a c + b   + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 865
+
+--S 866 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 866
+
+)clear all
+
+--S 867 of 1353
+t0:=x/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 867
+
+--S 868 of 1353
+r0:=-atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                       2
+--R                   2c x  + b
+--R          atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R   (2)  - ---------------------
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 868
+
+--S 869 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                            +-----------+
+--R                 2 4         2           2  |          2         2     2   2
+--R              (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               4      2
+--R            c x  + b x  + a
+--R    /
+--R         +-----------+
+--R         |          2
+--R       2\|- 4a c + b
+--R     ,
+--R                     +---------+
+--R              2      |        2
+--R         (2c x  + b)\|4a c - b
+--R    atan(-----------------------)
+--R                        2
+--R                4a c - b
+--R    -----------------------------]
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 869
+
+--S 870 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                            +-----------+
+--R                 2 4         2           2  |          2         2     2   2
+--R              (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               4      2
+--R            c x  + b x  + a
+--R     + 
+--R                     2
+--R                 2c x  + b
+--R       2atanh(--------------)
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R  /
+--R       +-----------+
+--R       |          2
+--R     2\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 870
+
+--S 871 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 871
+
+--S 872 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        +---------+             2
+--R        |        2          2c x  + b
+--R       \|4a c - b  atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                      +---------+
+--R        +-----------+          2      |        2
+--R        |          2      (2c x  + b)\|4a c - b
+--R       \|- 4a c + b  atan(-----------------------)
+--R                                         2
+--R                                 4a c - b
+--R  /
+--R      +-----------+ +---------+
+--R      |          2  |        2
+--R     \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 873
+
+)clear all
+
+--S 874 of 1353
+t0:=1/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 874
+
+--S 875 of 1353
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/_
+   (sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                +------------------+
+--R                | +-----------+                   +-+ +-+
+--R        +-+ +-+ | |          2                  x\|2 \|c
+--R       \|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                          +--------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + b
+--R     + 
+--R                  +--------------------+
+--R                  |   +-----------+                  +-+ +-+
+--R          +-+ +-+ |   |          2                 x\|2 \|c
+--R       - \|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                              | |          2
+--R                                             \|\|- 4a c + b   + b
+--R  /
+--R                    +--------------------+ +------------------+
+--R      +-----------+ |   +-----------+      | +-----------+
+--R      |          2  |   |          2       | |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 875
+
+--S 876 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +--------------------------------------+
+--R          |                +----------------+
+--R          |    2        2  |         1
+--R          |(16a c - 4a b ) |- --------------  + b
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |--------------------------------------
+--R          |               2        2
+--R         \|             8a c - 2a b
+--R      *
+--R         log
+--R                                   +----------------+
+--R                     2          3  |         1                  2
+--R                ((16a b c - 4a b ) |- --------------  + 4a c - b )
+--R                                   |     3       2 2
+--R                                  \|  64a c - 16a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |                +----------------+
+--R                 |    2        2  |         1
+--R                 |(16a c - 4a b ) |- --------------  + b
+--R                 |                |     3       2 2
+--R                 |               \|  64a c - 16a b
+--R                 |--------------------------------------
+--R                 |               2        2
+--R                \|             8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R             +----------------------------------------+
+--R             |                  +----------------+
+--R             |      2        2  |         1
+--R             |(- 16a c + 4a b ) |- --------------  + b
+--R             |                  |     3       2 2
+--R             |                 \|  64a c - 16a b
+--R             |----------------------------------------
+--R             |                2        2
+--R            \|              8a c - 2a b
+--R         *
+--R            log
+--R                                      +----------------+
+--R                        2          3  |         1                  2
+--R                   ((16a b c - 4a b ) |- --------------  - 4a c + b )
+--R                                      |     3       2 2
+--R                                     \|  64a c - 16a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |                  +----------------+
+--R                    |      2        2  |         1
+--R                    |(- 16a c + 4a b ) |- --------------  + b
+--R                    |                  |     3       2 2
+--R                    |                 \|  64a c - 16a b
+--R                    |----------------------------------------
+--R                    |                2        2
+--R                   \|              8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R          +----------------------------------------+
+--R          |                  +----------------+
+--R          |      2        2  |         1
+--R          |(- 16a c + 4a b ) |- --------------  + b
+--R          |                  |     3       2 2
+--R          |                 \|  64a c - 16a b
+--R          |----------------------------------------
+--R          |                2        2
+--R         \|              8a c - 2a b
+--R      *
+--R         log
+--R                                     +----------------+
+--R                       2          3  |         1                  2
+--R                ((- 16a b c + 4a b ) |- --------------  + 4a c - b )
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |                  +----------------+
+--R                 |      2        2  |         1
+--R                 |(- 16a c + 4a b ) |- --------------  + b
+--R                 |                  |     3       2 2
+--R                 |                 \|  64a c - 16a b
+--R                 |----------------------------------------
+--R                 |                2        2
+--R                \|              8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R             +--------------------------------------+
+--R             |                +----------------+
+--R             |    2        2  |         1
+--R             |(16a c - 4a b ) |- --------------  + b
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |--------------------------------------
+--R             |               2        2
+--R            \|             8a c - 2a b
+--R         *
+--R            log
+--R                                        +----------------+
+--R                          2          3  |         1                  2
+--R                   ((- 16a b c + 4a b ) |- --------------  - 4a c + b )
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |                +----------------+
+--R                    |    2        2  |         1
+--R                    |(16a c - 4a b ) |- --------------  + b
+--R                    |                |     3       2 2
+--R                    |               \|  64a c - 16a b
+--R                    |--------------------------------------
+--R                    |               2        2
+--R                   \|             8a c - 2a b
+--R               + 
+--R                 2c x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 876
+
+--S 877 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2  |   |          2       | |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +--------------------------------------+
+--R          |                +----------------+
+--R          |    2        2  |         1
+--R          |(16a c - 4a b ) |- --------------  + b
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |--------------------------------------
+--R          |               2        2
+--R         \|             8a c - 2a b
+--R      *
+--R         log
+--R                                   +----------------+
+--R                     2          3  |         1                  2
+--R                ((16a b c - 4a b ) |- --------------  + 4a c - b )
+--R                                   |     3       2 2
+--R                                  \|  64a c - 16a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |                +----------------+
+--R                 |    2        2  |         1
+--R                 |(16a c - 4a b ) |- --------------  + b
+--R                 |                |     3       2 2
+--R                 |               \|  64a c - 16a b
+--R                 |--------------------------------------
+--R                 |               2        2
+--R                \|             8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R                           +----------------------------------------+
+--R                           |                  +----------------+
+--R                           |      2        2  |         1
+--R                           |(- 16a c + 4a b ) |- --------------  + b
+--R             +-----------+ |                  |     3       2 2
+--R             |          2  |                 \|  64a c - 16a b
+--R            \|- 4a c + b   |----------------------------------------
+--R                           |                2        2
+--R                          \|              8a c - 2a b
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                      +----------------+
+--R                        2          3  |         1                  2
+--R                   ((16a b c - 4a b ) |- --------------  - 4a c + b )
+--R                                      |     3       2 2
+--R                                     \|  64a c - 16a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |                  +----------------+
+--R                    |      2        2  |         1
+--R                    |(- 16a c + 4a b ) |- --------------  + b
+--R                    |                  |     3       2 2
+--R                    |                 \|  64a c - 16a b
+--R                    |----------------------------------------
+--R                    |                2        2
+--R                   \|              8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R                        +----------------------------------------+
+--R                        |                  +----------------+
+--R                        |      2        2  |         1
+--R                        |(- 16a c + 4a b ) |- --------------  + b
+--R          +-----------+ |                  |     3       2 2
+--R          |          2  |                 \|  64a c - 16a b
+--R         \|- 4a c + b   |----------------------------------------
+--R                        |                2        2
+--R                       \|              8a c - 2a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                     +----------------+
+--R                       2          3  |         1                  2
+--R                ((- 16a b c + 4a b ) |- --------------  + 4a c - b )
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |                  +----------------+
+--R                 |      2        2  |         1
+--R                 |(- 16a c + 4a b ) |- --------------  + b
+--R                 |                  |     3       2 2
+--R                 |                 \|  64a c - 16a b
+--R                 |----------------------------------------
+--R                 |                2        2
+--R                \|              8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R             |          2  |   |          2       | |          2
+--R            \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +--------------------------------------+
+--R             |                +----------------+
+--R             |    2        2  |         1
+--R             |(16a c - 4a b ) |- --------------  + b
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |--------------------------------------
+--R             |               2        2
+--R            \|             8a c - 2a b
+--R         *
+--R            log
+--R                                        +----------------+
+--R                          2          3  |         1                  2
+--R                   ((- 16a b c + 4a b ) |- --------------  - 4a c + b )
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |                +----------------+
+--R                    |    2        2  |         1
+--R                    |(16a c - 4a b ) |- --------------  + b
+--R                    |                |     3       2 2
+--R                    |               \|  64a c - 16a b
+--R                    |--------------------------------------
+--R                    |               2        2
+--R                   \|             8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R                   +------------------+
+--R                   | +-----------+                   +-+ +-+
+--R           +-+ +-+ | |          2                  x\|2 \|c
+--R       - 2\|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                             +--------------------+
+--R                                             |   +-----------+
+--R                                             |   |          2
+--R                                            \|- \|- 4a c + b   + b
+--R     + 
+--R                 +--------------------+
+--R                 |   +-----------+                  +-+ +-+
+--R         +-+ +-+ |   |          2                 x\|2 \|c
+--R       2\|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                             | |          2
+--R                                            \|\|- 4a c + b   + b
+--R  /
+--R                     +--------------------+ +------------------+
+--R       +-----------+ |   +-----------+      | +-----------+
+--R       |          2  |   |          2       | |          2
+--R     2\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--S 878 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 878
+
+)clear all
+
+--S 879 of 1353
+t0:=1/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 879
+
+--S 880 of 1353
+r0:=log(x)/a-1/4*log(a+b*x^2+c*x^4)/a+1/2*b*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                   2                                             +-----------+
+--R               2c x  + b                4      2                 |          2
+--R   2b atanh(--------------) + (- log(c x  + b x  + a) + 4log(x))\|- 4a c + b
+--R             +-----------+
+--R             |          2
+--R            \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                    +-----------+
+--R                                    |          2
+--R                                 4a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 880
+
+--S 881 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                            +-----------+
+--R                   4      2                 |          2
+--R         (- log(c x  + b x  + a) + 4log(x))\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       4a\|- 4a c + b
+--R     ,
+--R
+--R                               +---------+
+--R                        2      |        2
+--R                   (2c x  + b)\|4a c - b
+--R         - 2b atan(-----------------------)
+--R                                  2
+--R                          4a c - b
+--R       + 
+--R                                            +---------+
+--R                   4      2                 |        2
+--R         (- log(c x  + b x  + a) + 4log(x))\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       4a\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 881
+
+--S 882 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                         2
+--R                     2c x  + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     4a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 883
+
+--S 884 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             2
+--R           |        2          2c x  + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          2      |        2
+--R           |          2      (2c x  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     2a\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 884
+
+--S 885 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 885
+
+)clear all
+
+--S 886 of 1353
+t0:=1/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 886
+
+--S 887 of 1353
+r0:=(-1)/(a*x)-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (1+b/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (1-b/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                       +------------------+
+--R              +-----------+            | +-----------+
+--R              |          2         +-+ | |          2
+--R         (- x\|- 4a c + b   - b x)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                       +--------------------+
+--R              +-----------+            |   +-----------+
+--R              |          2         +-+ |   |          2
+--R         (- x\|- 4a c + b   + b x)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R       - \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R         +-+ |          2  |   |          2       | |          2
+--R     a x\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                +----------------------------------------------------+
+--R                |                +--------------------+
+--R                |                |   2 2       2     4
+--R                |    4      3 2  |- a c  + 2a b c - b               3
+--R                |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R                |                |      7       6 2
+--R                |               \|   64a c - 16a b
+--R            a x |----------------------------------------------------
+--R                |                      4      3 2
+--R               \|                    8a c - 2a b
+--R         *
+--R            log
+--R                                                +--------------------+
+--R                                                |   2 2       2     4
+--R                         5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                     (32a c  - 24a b c + 4a b ) |--------------------  + 4a b c
+--R                                                |      7       6 2
+--R                                               \|   64a c - 16a b
+--R                   + 
+--R                           3     5
+--R                     - 5a b c + b
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |                +--------------------+
+--R                    |                |   2 2       2     4
+--R                    |    4      3 2  |- a c  + 2a b c - b               3
+--R                    |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R                    |                |      7       6 2
+--R                    |               \|   64a c - 16a b
+--R                    |----------------------------------------------------
+--R                    |                      4      3 2
+--R                   \|                    8a c - 2a b
+--R               + 
+--R                      3     2 2
+--R                 (2a c  - 2b c )x
+--R     + 
+--R             +------------------------------------------------------+
+--R             |                  +--------------------+
+--R             |                  |   2 2       2     4
+--R             |      4      3 2  |- a c  + 2a b c - b               3
+--R             |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R             |                  |      7       6 2
+--R             |                 \|   64a c - 16a b
+--R         a x |------------------------------------------------------
+--R             |                       4      3 2
+--R            \|                     8a c - 2a b
+--R      *
+--R         log
+--R                                             +--------------------+
+--R                                             |   2 2       2     4
+--R                      5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                  (32a c  - 24a b c + 4a b ) |--------------------  - 4a b c
+--R                                             |      7       6 2
+--R                                            \|   64a c - 16a b
+--R                + 
+--R                      3     5
+--R                  5a b c - b
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                  +--------------------+
+--R                 |                  |   2 2       2     4
+--R                 |      4      3 2  |- a c  + 2a b c - b               3
+--R                 |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R                 |                  |      7       6 2
+--R                 |                 \|   64a c - 16a b
+--R                 |------------------------------------------------------
+--R                 |                       4      3 2
+--R                \|                     8a c - 2a b
+--R            + 
+--R                   3     2 2
+--R              (2a c  - 2b c )x
+--R     + 
+--R       -
+--R                +------------------------------------------------------+
+--R                |                  +--------------------+
+--R                |                  |   2 2       2     4
+--R                |      4      3 2  |- a c  + 2a b c - b               3
+--R                |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R                |                  |      7       6 2
+--R                |                 \|   64a c - 16a b
+--R            a x |------------------------------------------------------
+--R                |                       4      3 2
+--R               \|                     8a c - 2a b
+--R         *
+--R            log
+--R                                                  +--------------------+
+--R                                                  |   2 2       2     4
+--R                           5 2      4 2      3 4  |- a c  + 2a b c - b
+--R                     (- 32a c  + 24a b c - 4a b ) |--------------------
+--R                                                  |      7       6 2
+--R                                                 \|   64a c - 16a b
+--R                   + 
+--R                       2   2       3     5
+--R                     4a b c  - 5a b c + b
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                  +--------------------+
+--R                    |                  |   2 2       2     4
+--R                    |      4      3 2  |- a c  + 2a b c - b               3
+--R                    |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R                    |                  |      7       6 2
+--R                    |                 \|   64a c - 16a b
+--R                    |------------------------------------------------------
+--R                    |                       4      3 2
+--R                   \|                     8a c - 2a b
+--R               + 
+--R                      3     2 2
+--R                 (2a c  - 2b c )x
+--R     + 
+--R             +----------------------------------------------------+
+--R             |                +--------------------+
+--R             |                |   2 2       2     4
+--R             |    4      3 2  |- a c  + 2a b c - b               3
+--R             |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R             |                |      7       6 2
+--R             |               \|   64a c - 16a b
+--R         a x |----------------------------------------------------
+--R             |                      4      3 2
+--R            \|                    8a c - 2a b
+--R      *
+--R         log
+--R                                               +--------------------+
+--R                                               |   2 2       2     4
+--R                        5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                  (- 32a c  + 24a b c - 4a b ) |--------------------  - 4a b c
+--R                                               |      7       6 2
+--R                                              \|   64a c - 16a b
+--R                + 
+--R                      3     5
+--R                  5a b c - b
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |                +--------------------+
+--R                 |                |   2 2       2     4
+--R                 |    4      3 2  |- a c  + 2a b c - b               3
+--R                 |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R                 |                |      7       6 2
+--R                 |               \|   64a c - 16a b
+--R                 |----------------------------------------------------
+--R                 |                      4      3 2
+--R                \|                    8a c - 2a b
+--R            + 
+--R                   3     2 2
+--R              (2a c  - 2b c )x
+--R     + 
+--R       - 2
+--R  /
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 888
+
+--S 889 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R              +-+ |          2  |   |          2       | |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------------------------------+
+--R             |                +--------------------+
+--R             |                |   2 2       2     4
+--R             |    4      3 2  |- a c  + 2a b c - b               3
+--R             |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R             |                |      7       6 2
+--R             |               \|   64a c - 16a b
+--R             |----------------------------------------------------
+--R             |                      4      3 2
+--R            \|                    8a c - 2a b
+--R         *
+--R            log
+--R                                                +--------------------+
+--R                                                |   2 2       2     4
+--R                         5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                     (32a c  - 24a b c + 4a b ) |--------------------  + 4a b c
+--R                                                |      7       6 2
+--R                                               \|   64a c - 16a b
+--R                   + 
+--R                           3     5
+--R                     - 5a b c + b
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |                +--------------------+
+--R                    |                |   2 2       2     4
+--R                    |    4      3 2  |- a c  + 2a b c - b               3
+--R                    |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R                    |                |      7       6 2
+--R                    |               \|   64a c - 16a b
+--R                    |----------------------------------------------------
+--R                    |                      4      3 2
+--R                   \|                    8a c - 2a b
+--R               + 
+--R                      3     2 2
+--R                 (2a c  - 2b c )x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2
+--R         a\|2 \|- 4a c + b
+--R      *
+--R          +------------------------------------------------------+
+--R          |                  +--------------------+
+--R          |                  |   2 2       2     4
+--R          |      4      3 2  |- a c  + 2a b c - b               3
+--R          |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R          |                  |      7       6 2
+--R          |                 \|   64a c - 16a b
+--R          |------------------------------------------------------
+--R          |                       4      3 2
+--R         \|                     8a c - 2a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                             +--------------------+
+--R                                             |   2 2       2     4
+--R                      5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                  (32a c  - 24a b c + 4a b ) |--------------------  - 4a b c
+--R                                             |      7       6 2
+--R                                            \|   64a c - 16a b
+--R                + 
+--R                      3     5
+--R                  5a b c - b
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                  +--------------------+
+--R                 |                  |   2 2       2     4
+--R                 |      4      3 2  |- a c  + 2a b c - b               3
+--R                 |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R                 |                  |      7       6 2
+--R                 |                 \|   64a c - 16a b
+--R                 |------------------------------------------------------
+--R                 |                       4      3 2
+--R                \|                     8a c - 2a b
+--R            + 
+--R                   3     2 2
+--R              (2a c  - 2b c )x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2
+--R            a\|2 \|- 4a c + b
+--R         *
+--R             +------------------------------------------------------+
+--R             |                  +--------------------+
+--R             |                  |   2 2       2     4
+--R             |      4      3 2  |- a c  + 2a b c - b               3
+--R             |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R             |                  |      7       6 2
+--R             |                 \|   64a c - 16a b
+--R             |------------------------------------------------------
+--R             |                       4      3 2
+--R            \|                     8a c - 2a b
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                                  +--------------------+
+--R                                                  |   2 2       2     4
+--R                           5 2      4 2      3 4  |- a c  + 2a b c - b
+--R                     (- 32a c  + 24a b c - 4a b ) |--------------------
+--R                                                  |      7       6 2
+--R                                                 \|   64a c - 16a b
+--R                   + 
+--R                       2   2       3     5
+--R                     4a b c  - 5a b c + b
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                  +--------------------+
+--R                    |                  |   2 2       2     4
+--R                    |      4      3 2  |- a c  + 2a b c - b               3
+--R                    |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R                    |                  |      7       6 2
+--R                    |                 \|   64a c - 16a b
+--R                    |------------------------------------------------------
+--R                    |                       4      3 2
+--R                   \|                     8a c - 2a b
+--R               + 
+--R                      3     2 2
+--R                 (2a c  - 2b c )x
+--R     + 
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R           +-+ |          2  |   |          2       | |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------------------------------+
+--R          |                +--------------------+
+--R          |                |   2 2       2     4
+--R          |    4      3 2  |- a c  + 2a b c - b               3
+--R          |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R          |                |      7       6 2
+--R          |               \|   64a c - 16a b
+--R          |----------------------------------------------------
+--R          |                      4      3 2
+--R         \|                    8a c - 2a b
+--R      *
+--R         log
+--R                                               +--------------------+
+--R                                               |   2 2       2     4
+--R                        5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                  (- 32a c  + 24a b c - 4a b ) |--------------------  - 4a b c
+--R                                               |      7       6 2
+--R                                              \|   64a c - 16a b
+--R                + 
+--R                      3     5
+--R                  5a b c - b
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |                +--------------------+
+--R                 |                |   2 2       2     4
+--R                 |    4      3 2  |- a c  + 2a b c - b               3
+--R                 |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R                 |                |      7       6 2
+--R                 |               \|   64a c - 16a b
+--R                 |----------------------------------------------------
+--R                 |                      4      3 2
+--R                \|                    8a c - 2a b
+--R            + 
+--R                   3     2 2
+--R              (2a c  - 2b c )x
+--R     + 
+--R                                    +------------------+
+--R            +-----------+           | +-----------+
+--R            |          2        +-+ | |          2
+--R         (2\|- 4a c + b   + 2b)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                    +--------------------+
+--R            +-----------+           |   +-----------+
+--R            |          2        +-+ |   |          2
+--R         (2\|- 4a c + b   - 2b)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R     2a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 889
+
+--S 890 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 890
+
+)clear all
+
+--S 891 of 1353
+t0:=1/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 891
+
+--S 892 of 1353
+r0:=(-1/2)/(a*x^2)-b*log(x)/a^2+1/4*b*log(a+b*x^2+c*x^4)/a^2-1/2*(b^2-2*a*c)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                  2
+--R                 2  2         2c x  + b
+--R       (4a c - 2b )x atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R           2       4      2            2             |          2
+--R       (b x log(c x  + b x  + a) - 4b x log(x) - 2a)\|- 4a c + b
+--R  /
+--R           +-----------+
+--R       2 2 |          2
+--R     4a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 892
+
+--S 893 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2  2
+--R           (2a c - b )x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                                       +-----------+
+--R             2       4      2            2             |          2
+--R         (b x log(c x  + b x  + a) - 4b x log(x) - 2a)\|- 4a c + b
+--R    /
+--R             +-----------+
+--R         2 2 |          2
+--R       4a x \|- 4a c + b
+--R     ,
+--R
+--R                                          +---------+
+--R                                   2      |        2
+--R                     2  2     (2c x  + b)\|4a c - b
+--R         (- 4a c + 2b )x atan(-----------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R                                                       +---------+
+--R             2       4      2            2             |        2
+--R         (b x log(c x  + b x  + a) - 4b x log(x) - 2a)\|4a c - b
+--R    /
+--R             +---------+
+--R         2 2 |        2
+--R       4a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 893
+
+--S 894 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                  2
+--R                   2          2c x  + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 894
+
+--S 895 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 895
+
+--S 896 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+             2
+--R                  2  |        2          2c x  + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                     +-----------+          2      |        2
+--R                  2  |          2      (2c x  + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     2a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 896
+
+--S 897 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 897
+
+)clear all
+
+--S 898 of 1353
+t0:=1/(x^4*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           8      6      4
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 898
+
+--S 899 of 1353
+r0:=(-1/3)/(a*x^3)+b/(a^2*x)+atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(a^2*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(a^2*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                      +------------------+
+--R                +-----------+                         | +-----------+
+--R              3 |          2                2  3  +-+ | |          2
+--R         (3b x \|- 4a c + b   + (- 6a c + 3b )x )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                    +--------------------+
+--R                +-----------+                       |   +-----------+
+--R              3 |          2              2  3  +-+ |   |          2
+--R         (3b x \|- 4a c + b   + (6a c - 3b )x )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                   +--------------------+ +------------------+
+--R                     +-----------+ |   +-----------+      | +-----------+
+--R          2      +-+ |          2  |   |          2       | |          2
+--R     (3b x  - a)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R       2 3 +-+ |          2  |   |          2       | |          2
+--R     3a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 899
+
+--S 900 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R              2 3
+--R            3a x
+--R         *
+--R            ROOT
+--R                                   +-----------------------------------------+
+--R                                   |   4 4     3 2 3      2 4 2       6     8
+--R                       6      5 2  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   (16a c - 4a b ) |-----------------------------------------
+--R                                   |                11       10 2
+--R                                  \|             64a  c - 16a  b
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R            log
+--R                           7   2      6 3      5 5
+--R                       (48a b c  - 28a b c + 4a b )
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |                11       10 2
+--R                       \|             64a  c - 16a  b
+--R                   + 
+--R                       4 4      3 2 3      2 4 2       6     8
+--R                     4a c  - 17a b c  + 20a b c  - 8a b c + b
+--R                *
+--R                   ROOT
+--R                                6      5 2
+--R                            (16a c - 4a b )
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |                11       10 2
+--R                            \|             64a  c - 16a  b
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                          6      5 2
+--R                        8a c - 2a b
+--R               + 
+--R                    2 5       2 4     4 3
+--R                 (2a c  - 6a b c  + 2b c )x
+--R     + 
+--R           2 3
+--R         3a x
+--R      *
+--R         ROOT
+--R                                  +-----------------------------------------+
+--R                                  |   4 4     3 2 3      2 4 2       6     8
+--R                      6      5 2  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (- 16a c + 4a b ) |-----------------------------------------
+--R                                  |                11       10 2
+--R                                 \|             64a  c - 16a  b
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                        7   2      6 3      5 5
+--R                    (48a b c  - 28a b c + 4a b )
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |                11       10 2
+--R                    \|             64a  c - 16a  b
+--R                + 
+--R                      4 4      3 2 3      2 4 2       6     8
+--R                  - 4a c  + 17a b c  - 20a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                               6      5 2
+--R                         (- 16a c + 4a b )
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |                11       10 2
+--R                         \|             64a  c - 16a  b
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                       6      5 2
+--R                     8a c - 2a b
+--R            + 
+--R                 2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )x
+--R     + 
+--R       -
+--R              2 3
+--R            3a x
+--R         *
+--R            ROOT
+--R                                     +-----------------------------------------+
+--R                                     |   4 4     3 2 3      2 4 2       6     8
+--R                         6      5 2  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   (- 16a c + 4a b ) |-----------------------------------------
+--R                                     |                11       10 2
+--R                                    \|             64a  c - 16a  b
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R            log
+--R                             7   2      6 3      5 5
+--R                       (- 48a b c  + 28a b c - 4a b )
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |                11       10 2
+--R                       \|             64a  c - 16a  b
+--R                   + 
+--R                       4 4      3 2 3      2 4 2       6     8
+--R                     4a c  - 17a b c  + 20a b c  - 8a b c + b
+--R                *
+--R                   ROOT
+--R                                  6      5 2
+--R                            (- 16a c + 4a b )
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |                11       10 2
+--R                            \|             64a  c - 16a  b
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                          6      5 2
+--R                        8a c - 2a b
+--R               + 
+--R                    2 5       2 4     4 3
+--R                 (2a c  - 6a b c  + 2b c )x
+--R     + 
+--R           2 3
+--R         3a x
+--R      *
+--R         ROOT
+--R                                +-----------------------------------------+
+--R                                |   4 4     3 2 3      2 4 2       6     8
+--R                    6      5 2  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (16a c - 4a b ) |-----------------------------------------
+--R                                |                11       10 2
+--R                               \|             64a  c - 16a  b
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                          7   2      6 3      5 5
+--R                    (- 48a b c  + 28a b c - 4a b )
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |                11       10 2
+--R                    \|             64a  c - 16a  b
+--R                + 
+--R                      4 4      3 2 3      2 4 2       6     8
+--R                  - 4a c  + 17a b c  - 20a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                             6      5 2
+--R                         (16a c - 4a b )
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |                11       10 2
+--R                         \|             64a  c - 16a  b
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                       6      5 2
+--R                     8a c - 2a b
+--R            + 
+--R                 2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )x
+--R     + 
+--R           2
+--R       6b x  - 2a
+--R  /
+--R       2 3
+--R     6a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 900
+
+--S 901 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                 +--------------------+
+--R                   +-----------+ |   +-----------+
+--R             2 +-+ |          2  |   |          2
+--R            a \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                   +-----------------------------------------+
+--R                                   |   4 4     3 2 3      2 4 2       6     8
+--R                       6      5 2  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   (16a c - 4a b ) |-----------------------------------------
+--R                                   |                11       10 2
+--R                                  \|             64a  c - 16a  b
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                           7   2      6 3      5 5
+--R                       (48a b c  - 28a b c + 4a b )
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |                11       10 2
+--R                       \|             64a  c - 16a  b
+--R                   + 
+--R                       4 4      3 2 3      2 4 2       6     8
+--R                     4a c  - 17a b c  + 20a b c  - 8a b c + b
+--R                *
+--R                   ROOT
+--R                                6      5 2
+--R                            (16a c - 4a b )
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |                11       10 2
+--R                            \|             64a  c - 16a  b
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                          6      5 2
+--R                        8a c - 2a b
+--R               + 
+--R                    2 5       2 4     4 3
+--R                 (2a c  - 6a b c  + 2b c )x
+--R     + 
+--R                              +--------------------+
+--R                +-----------+ |   +-----------+
+--R          2 +-+ |          2  |   |          2
+--R         a \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                  +-----------------------------------------+
+--R                                  |   4 4     3 2 3      2 4 2       6     8
+--R                      6      5 2  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (- 16a c + 4a b ) |-----------------------------------------
+--R                                  |                11       10 2
+--R                                 \|             64a  c - 16a  b
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                        7   2      6 3      5 5
+--R                    (48a b c  - 28a b c + 4a b )
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |                11       10 2
+--R                    \|             64a  c - 16a  b
+--R                + 
+--R                      4 4      3 2 3      2 4 2       6     8
+--R                  - 4a c  + 17a b c  - 20a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                               6      5 2
+--R                         (- 16a c + 4a b )
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |                11       10 2
+--R                         \|             64a  c - 16a  b
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                       6      5 2
+--R                     8a c - 2a b
+--R            + 
+--R                 2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )x
+--R     + 
+--R       -
+--R                                 +--------------------+
+--R                   +-----------+ |   +-----------+
+--R             2 +-+ |          2  |   |          2
+--R            a \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                     +-----------------------------------------+
+--R                                     |   4 4     3 2 3      2 4 2       6     8
+--R                         6      5 2  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   (- 16a c + 4a b ) |-----------------------------------------
+--R                                     |                11       10 2
+--R                                    \|             64a  c - 16a  b
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                             7   2      6 3      5 5
+--R                       (- 48a b c  + 28a b c - 4a b )
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |                11       10 2
+--R                       \|             64a  c - 16a  b
+--R                   + 
+--R                       4 4      3 2 3      2 4 2       6     8
+--R                     4a c  - 17a b c  + 20a b c  - 8a b c + b
+--R                *
+--R                   ROOT
+--R                                  6      5 2
+--R                            (- 16a c + 4a b )
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |                11       10 2
+--R                            \|             64a  c - 16a  b
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                          6      5 2
+--R                        8a c - 2a b
+--R               + 
+--R                    2 5       2 4     4 3
+--R                 (2a c  - 6a b c  + 2b c )x
+--R     + 
+--R                              +--------------------+
+--R                +-----------+ |   +-----------+
+--R          2 +-+ |          2  |   |          2
+--R         a \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                +-----------------------------------------+
+--R                                |   4 4     3 2 3      2 4 2       6     8
+--R                    6      5 2  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (16a c - 4a b ) |-----------------------------------------
+--R                                |                11       10 2
+--R                               \|             64a  c - 16a  b
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          7   2      6 3      5 5
+--R                    (- 48a b c  + 28a b c - 4a b )
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |                11       10 2
+--R                    \|             64a  c - 16a  b
+--R                + 
+--R                      4 4      3 2 3      2 4 2       6     8
+--R                  - 4a c  + 17a b c  - 20a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                             6      5 2
+--R                         (16a c - 4a b )
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |                11       10 2
+--R                         \|             64a  c - 16a  b
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                       6      5 2
+--R                     8a c - 2a b
+--R            + 
+--R                 2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )x
+--R     + 
+--R                                               +------------------+
+--R               +-----------+                   | +-----------+
+--R               |          2             2  +-+ | |          2
+--R         (- 2b\|- 4a c + b   + 4a c - 2b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                               +--------------------+
+--R               +-----------+                   |   +-----------+
+--R               |          2             2  +-+ |   |          2
+--R         (- 2b\|- 4a c + b   - 4a c + 2b )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R       2 +-+ |          2  |   |          2       | |          2
+--R     2a \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 902
+
+)clear all
+
+--S 903 of 1353
+t0:=1/(x^5*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           9      7      5
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 903
+
+--S 904 of 1353
+r0:=(-1/4)/(a*x^4)+1/2*b/(a^2*x^2)+(b^2-a*c)*log(x)/a^3-1/4*(b^2-a*c)*_
+   log(a+b*x^2+c*x^4)/a^3+1/2*b*(b^2-3*a*c)*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                      2
+--R                     3  4         2c x  + b
+--R       (- 6a b c + 2b )x atanh(--------------)
+--R                                +-----------+
+--R                                |          2
+--R                               \|- 4a c + b
+--R     + 
+--R                   2  4       4      2                    2  4               2
+--R           (a c - b )x log(c x  + b x  + a) + (- 4a c + 4b )x log(x) + 2a b x
+--R         + 
+--R              2
+--R           - a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       3 4 |          2
+--R     4a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3  4
+--R           (3a b c - b )x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                     2  4       4      2                    2  4               2
+--R             (a c - b )x log(c x  + b x  + a) + (- 4a c + 4b )x log(x) + 2a b x
+--R           + 
+--R                2
+--R             - a
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             +-----------+
+--R         3 4 |          2
+--R       4a x \|- 4a c + b
+--R     ,
+--R
+--R                                          +---------+
+--R                                   2      |        2
+--R                     3  4     (2c x  + b)\|4a c - b
+--R         (6a b c - 2b )x atan(-----------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R                     2  4       4      2                    2  4               2
+--R             (a c - b )x log(c x  + b x  + a) + (- 4a c + 4b )x log(x) + 2a b x
+--R           + 
+--R                2
+--R             - a
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R             +---------+
+--R         3 4 |        2
+--R       4a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 905
+
+--S 906 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (3a b c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                  2
+--R                   3          2c x  + b
+--R       (6a b c - 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     4a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 906
+
+--S 907 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 907
+
+--S 908 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+             2
+--R                  3  |        2          2c x  + b
+--R       (3a b c - b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                     +-----------+          2      |        2
+--R                  3  |          2      (2c x  + b)\|4a c - b
+--R       (3a b c - b )\|- 4a c + b  atan(-----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       3 |          2  |        2
+--R     2a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 908
+
+--S 909 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 909
+
+)clear all
+
+--S 910 of 1353
+t0:=x^4/(a-b*x^2+c*x^4)
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  - b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 910
+
+--S 911 of 1353
+r0:=x/c-atanh(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+(-b^2+2*a*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atanh(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R              +-----------+              | +-----------+
+--R              |          2            2  | |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   + b
+--R      *
+--R                        +-+ +-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R                |   |          2
+--R               \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R              +-----------+              |   +-----------+
+--R              |          2            2  |   |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R                | |          2
+--R               \|\|- 4a c + b   + b
+--R     + 
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R         +-+ |          2  +-+ |   |          2       | |          2
+--R       x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 911
+
+--S 912 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R              +-----------------------------------------------------+
+--R              |                 +--------------------+
+--R              |                 |   2 2       2     4
+--R              |      4     2 3  |- a c  + 2a b c - b               3
+--R              |(16a c  - 4b c ) |--------------------  + 3a b c - b
+--R              |                 |        7      2 6
+--R              |                \|   64a c  - 16b c
+--R            c |-----------------------------------------------------
+--R              |                        4     2 3
+--R             \|                    8a c  - 2b c
+--R         *
+--R            log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                             4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                     (16a b c  - 4b c ) |--------------------  + 4a c  - 5a b c
+--R                                        |        7      2 6
+--R                                       \|   64a c  - 16b c
+--R                   + 
+--R                      4
+--R                     b
+--R                *
+--R                    +-----------------------------------------------------+
+--R                    |                 +--------------------+
+--R                    |                 |   2 2       2     4
+--R                    |      4     2 3  |- a c  + 2a b c - b               3
+--R                    |(16a c  - 4b c ) |--------------------  + 3a b c - b
+--R                    |                 |        7      2 6
+--R                    |                \|   64a c  - 16b c
+--R                    |-----------------------------------------------------
+--R                    |                        4     2 3
+--R                   \|                    8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R           +-------------------------------------------------------+
+--R           |                   +--------------------+
+--R           |                   |   2 2       2     4
+--R           |        4     2 3  |- a c  + 2a b c - b               3
+--R           |(- 16a c  + 4b c ) |--------------------  + 3a b c - b
+--R           |                   |        7      2 6
+--R           |                  \|   64a c  - 16b c
+--R         c |-------------------------------------------------------
+--R           |                         4     2 3
+--R          \|                     8a c  - 2b c
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                    (16a b c  - 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                  + 
+--R                       4
+--R                    - b
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |        4     2 3  |- a c  + 2a b c - b               3
+--R                 |(- 16a c  + 4b c ) |--------------------  + 3a b c - b
+--R                 |                   |        7      2 6
+--R                 |                  \|   64a c  - 16b c
+--R                 |-------------------------------------------------------
+--R                 |                         4     2 3
+--R                \|                     8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       -
+--R              +-------------------------------------------------------+
+--R              |                   +--------------------+
+--R              |                   |   2 2       2     4
+--R              |        4     2 3  |- a c  + 2a b c - b               3
+--R              |(- 16a c  + 4b c ) |--------------------  + 3a b c - b
+--R              |                   |        7      2 6
+--R              |                  \|   64a c  - 16b c
+--R            c |-------------------------------------------------------
+--R              |                         4     2 3
+--R             \|                     8a c  - 2b c
+--R         *
+--R            log
+--R                                          +--------------------+
+--R                                          |   2 2       2     4
+--R                               4     3 3  |- a c  + 2a b c - b       2 2
+--R                     (- 16a b c  + 4b c ) |--------------------  + 4a c
+--R                                          |        7      2 6
+--R                                         \|   64a c  - 16b c
+--R                   + 
+--R                           2     4
+--R                     - 5a b c + b
+--R                *
+--R                    +-------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |        4     2 3  |- a c  + 2a b c - b               3
+--R                    |(- 16a c  + 4b c ) |--------------------  + 3a b c - b
+--R                    |                   |        7      2 6
+--R                    |                  \|   64a c  - 16b c
+--R                    |-------------------------------------------------------
+--R                    |                         4     2 3
+--R                   \|                     8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R           +-----------------------------------------------------+
+--R           |                 +--------------------+
+--R           |                 |   2 2       2     4
+--R           |      4     2 3  |- a c  + 2a b c - b               3
+--R           |(16a c  - 4b c ) |--------------------  + 3a b c - b
+--R           |                 |        7      2 6
+--R           |                \|   64a c  - 16b c
+--R         c |-----------------------------------------------------
+--R           |                        4     2 3
+--R          \|                    8a c  - 2b c
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                  (- 16a b c  + 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                + 
+--R                     4
+--R                  - b
+--R             *
+--R                 +-----------------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |                 |   2 2       2     4
+--R                 |      4     2 3  |- a c  + 2a b c - b               3
+--R                 |(16a c  - 4b c ) |--------------------  + 3a b c - b
+--R                 |                 |        7      2 6
+--R                 |                \|   64a c  - 16b c
+--R                 |-----------------------------------------------------
+--R                 |                        4     2 3
+--R                \|                    8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       2x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 912
+
+--S 913 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                    +--------------------+ +------------------+
+--R                  +-----------+     |   +-----------+      | +-----------+
+--R              +-+ |          2  +-+ |   |          2       | |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +-----------------------------------------------------+
+--R             |                 +--------------------+
+--R             |                 |   2 2       2     4
+--R             |      4     2 3  |- a c  + 2a b c - b               3
+--R             |(16a c  - 4b c ) |--------------------  + 3a b c - b
+--R             |                 |        7      2 6
+--R             |                \|   64a c  - 16b c
+--R             |-----------------------------------------------------
+--R             |                        4     2 3
+--R            \|                    8a c  - 2b c
+--R         *
+--R            log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                             4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                     (16a b c  - 4b c ) |--------------------  + 4a c  - 5a b c
+--R                                        |        7      2 6
+--R                                       \|   64a c  - 16b c
+--R                   + 
+--R                      4
+--R                     b
+--R                *
+--R                    +-----------------------------------------------------+
+--R                    |                 +--------------------+
+--R                    |                 |   2 2       2     4
+--R                    |      4     2 3  |- a c  + 2a b c - b               3
+--R                    |(16a c  - 4b c ) |--------------------  + 3a b c - b
+--R                    |                 |        7      2 6
+--R                    |                \|   64a c  - 16b c
+--R                    |-----------------------------------------------------
+--R                    |                        4     2 3
+--R                   \|                    8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2  +-+
+--R         c\|2 \|- 4a c + b  \|c
+--R      *
+--R          +-------------------------------------------------------+
+--R          |                   +--------------------+
+--R          |                   |   2 2       2     4
+--R          |        4     2 3  |- a c  + 2a b c - b               3
+--R          |(- 16a c  + 4b c ) |--------------------  + 3a b c - b
+--R          |                   |        7      2 6
+--R          |                  \|   64a c  - 16b c
+--R          |-------------------------------------------------------
+--R          |                         4     2 3
+--R         \|                     8a c  - 2b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                    (16a b c  - 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                  + 
+--R                       4
+--R                    - b
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |        4     2 3  |- a c  + 2a b c - b               3
+--R                 |(- 16a c  + 4b c ) |--------------------  + 3a b c - b
+--R                 |                   |        7      2 6
+--R                 |                  \|   64a c  - 16b c
+--R                 |-------------------------------------------------------
+--R                 |                         4     2 3
+--R                \|                     8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            c\|2 \|- 4a c + b  \|c
+--R         *
+--R             +-------------------------------------------------------+
+--R             |                   +--------------------+
+--R             |                   |   2 2       2     4
+--R             |        4     2 3  |- a c  + 2a b c - b               3
+--R             |(- 16a c  + 4b c ) |--------------------  + 3a b c - b
+--R             |                   |        7      2 6
+--R             |                  \|   64a c  - 16b c
+--R             |-------------------------------------------------------
+--R             |                         4     2 3
+--R            \|                     8a c  - 2b c
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                          +--------------------+
+--R                                          |   2 2       2     4
+--R                               4     3 3  |- a c  + 2a b c - b       2 2
+--R                     (- 16a b c  + 4b c ) |--------------------  + 4a c
+--R                                          |        7      2 6
+--R                                         \|   64a c  - 16b c
+--R                   + 
+--R                           2     4
+--R                     - 5a b c + b
+--R                *
+--R                    +-------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |        4     2 3  |- a c  + 2a b c - b               3
+--R                    |(- 16a c  + 4b c ) |--------------------  + 3a b c - b
+--R                    |                   |        7      2 6
+--R                    |                  \|   64a c  - 16b c
+--R                    |-------------------------------------------------------
+--R                    |                         4     2 3
+--R                   \|                     8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------------------------------------+
+--R          |                 +--------------------+
+--R          |                 |   2 2       2     4
+--R          |      4     2 3  |- a c  + 2a b c - b               3
+--R          |(16a c  - 4b c ) |--------------------  + 3a b c - b
+--R          |                 |        7      2 6
+--R          |                \|   64a c  - 16b c
+--R          |-----------------------------------------------------
+--R          |                        4     2 3
+--R         \|                    8a c  - 2b c
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                  (- 16a b c  + 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                + 
+--R                     4
+--R                  - b
+--R             *
+--R                 +-----------------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |                 |   2 2       2     4
+--R                 |      4     2 3  |- a c  + 2a b c - b               3
+--R                 |(16a c  - 4b c ) |--------------------  + 3a b c - b
+--R                 |                 |        7      2 6
+--R                 |                \|   64a c  - 16b c
+--R                 |-----------------------------------------------------
+--R                 |                        4     2 3
+--R                \|                    8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R                                         +------------------+
+--R             +-----------+               | +-----------+
+--R             |          2             2  | |          2
+--R         (2b\|- 4a c + b   + 4a c - 2b )\|\|- 4a c + b   + b
+--R      *
+--R                        +-+ +-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R                |   |          2
+--R               \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R             +-----------+               |   +-----------+
+--R             |          2             2  |   |          2
+--R         (2b\|- 4a c + b   - 4a c + 2b )\|- \|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R                | |          2
+--R               \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 913
+
+--S 914 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 914
+
+)clear all
+
+--S 915 of 1353
+t0:=x^3/(a-b*x^2+c*x^4)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  - b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 915
+
+--S 916 of 1353
+r0:=1/4*log(a-b*x^2+c*x^4)/c+1/2*b*atanh((b-2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                          2                               +-----------+
+--R                      2c x  - b             4      2      |          2
+--R        - 2b atanh(--------------) + log(c x  - b x  + a)\|- 4a c + b
+--R                    +-----------+
+--R                    |          2
+--R                   \|- 4a c + b
+--R   (2)  ---------------------------------------------------------------
+--R                                   +-----------+
+--R                                   |          2
+--R                                4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 916
+
+--S 917 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  - 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  - b x  + a
+--R       + 
+--R                              +-----------+
+--R                4      2      |          2
+--R         log(c x  - b x  + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       4c\|- 4a c + b
+--R     ,
+--R                        +---------+
+--R                 2      |        2                          +---------+
+--R            (2c x  - b)\|4a c - b             4      2      |        2
+--R    2b atan(-----------------------) + log(c x  - b x  + a)\|4a c - b
+--R                           2
+--R                   4a c - b
+--R    -------------------------------------------------------------------]
+--R                                  +---------+
+--R                                  |        2
+--R                               4c\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 917
+
+--S 918 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  - 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  - b x  + a
+--R     + 
+--R                       2
+--R                   2c x  - b
+--R       2b atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 918
+
+--S 919 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 919
+
+--S 920 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R         +---------+             2
+--R         |        2          2c x  - b
+--R       b\|4a c - b  atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R     + 
+--R                                       +---------+
+--R         +-----------+          2      |        2
+--R         |          2      (2c x  - b)\|4a c - b
+--R       b\|- 4a c + b  atan(-----------------------)
+--R                                          2
+--R                                  4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     2c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 920
+
+--S 921 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 921
+
+)clear all
+
+--S 922 of 1353
+t0:=x^2/(a-b*x^2+c*x^4)
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  - b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 922
+
+--S 923 of 1353
+r0:=atanh(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(b-sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))-_
+   atanh(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(b+_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +--------------------+
+--R        |   +-----------+                    +-+ +-+
+--R        |   |          2                   x\|2 \|c
+--R       \|- \|- 4a c + b   + b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                     |   |          2
+--R                                    \|- \|- 4a c + b   + b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R       - \|\|- 4a c + b   + b atanh(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                     | |          2
+--R                                    \|\|- 4a c + b   + b
+--R  /
+--R          +-----------+
+--R      +-+ |          2  +-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 923
+
+--S 924 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +---------------------------------------+
+--R          |                +-----------------+
+--R          |      2     2   |         1
+--R          |(16a c  - 4b c) |- ---------------  - b
+--R          |                |       3      2 2
+--R          |               \|  64a c  - 16b c
+--R          |---------------------------------------
+--R          |                  2     2
+--R         \|              8a c  - 2b c
+--R      *
+--R         log
+--R                                +-----------------+
+--R                      2     2   |         1
+--R                (16a c  - 4b c) |- ---------------
+--R                                |       3      2 2
+--R                               \|  64a c  - 16b c
+--R             *
+--R                 +---------------------------------------+
+--R                 |                +-----------------+
+--R                 |      2     2   |         1
+--R                 |(16a c  - 4b c) |- ---------------  - b
+--R                 |                |       3      2 2
+--R                 |               \|  64a c  - 16b c
+--R                 |---------------------------------------
+--R                 |                  2     2
+--R                \|              8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +-----------------------------------------+
+--R             |                  +-----------------+
+--R             |        2     2   |         1
+--R             |(- 16a c  + 4b c) |- ---------------  - b
+--R             |                  |       3      2 2
+--R             |                 \|  64a c  - 16b c
+--R             |-----------------------------------------
+--R             |                   2     2
+--R            \|               8a c  - 2b c
+--R         *
+--R            log
+--R                                   +-----------------+
+--R                         2     2   |         1
+--R                   (16a c  - 4b c) |- ---------------
+--R                                   |       3      2 2
+--R                                  \|  64a c  - 16b c
+--R                *
+--R                    +-----------------------------------------+
+--R                    |                  +-----------------+
+--R                    |        2     2   |         1
+--R                    |(- 16a c  + 4b c) |- ---------------  - b
+--R                    |                  |       3      2 2
+--R                    |                 \|  64a c  - 16b c
+--R                    |-----------------------------------------
+--R                    |                   2     2
+--R                   \|               8a c  - 2b c
+--R               + 
+--R                 x
+--R     + 
+--R          +-----------------------------------------+
+--R          |                  +-----------------+
+--R          |        2     2   |         1
+--R          |(- 16a c  + 4b c) |- ---------------  - b
+--R          |                  |       3      2 2
+--R          |                 \|  64a c  - 16b c
+--R          |-----------------------------------------
+--R          |                   2     2
+--R         \|               8a c  - 2b c
+--R      *
+--R         log
+--R                                  +-----------------+
+--R                        2     2   |         1
+--R                (- 16a c  + 4b c) |- ---------------
+--R                                  |       3      2 2
+--R                                 \|  64a c  - 16b c
+--R             *
+--R                 +-----------------------------------------+
+--R                 |                  +-----------------+
+--R                 |        2     2   |         1
+--R                 |(- 16a c  + 4b c) |- ---------------  - b
+--R                 |                  |       3      2 2
+--R                 |                 \|  64a c  - 16b c
+--R                 |-----------------------------------------
+--R                 |                   2     2
+--R                \|               8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +---------------------------------------+
+--R             |                +-----------------+
+--R             |      2     2   |         1
+--R             |(16a c  - 4b c) |- ---------------  - b
+--R             |                |       3      2 2
+--R             |               \|  64a c  - 16b c
+--R             |---------------------------------------
+--R             |                  2     2
+--R            \|              8a c  - 2b c
+--R         *
+--R            log
+--R                                     +-----------------+
+--R                           2     2   |         1
+--R                   (- 16a c  + 4b c) |- ---------------
+--R                                     |       3      2 2
+--R                                    \|  64a c  - 16b c
+--R                *
+--R                    +---------------------------------------+
+--R                    |                +-----------------+
+--R                    |      2     2   |         1
+--R                    |(16a c  - 4b c) |- ---------------  - b
+--R                    |                |       3      2 2
+--R                    |               \|  64a c  - 16b c
+--R                    |---------------------------------------
+--R                    |                  2     2
+--R                   \|              8a c  - 2b c
+--R               + 
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 924
+
+--S 925 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +---------------------------------------+
+--R                                |                +-----------------+
+--R                                |      2     2   |         1
+--R                                |(16a c  - 4b c) |- ---------------  - b
+--R              +-----------+     |                |       3      2 2
+--R          +-+ |          2  +-+ |               \|  64a c  - 16b c
+--R         \|2 \|- 4a c + b  \|c  |---------------------------------------
+--R                                |                  2     2
+--R                               \|              8a c  - 2b c
+--R      *
+--R         log
+--R                                +-----------------+
+--R                      2     2   |         1
+--R                (16a c  - 4b c) |- ---------------
+--R                                |       3      2 2
+--R                               \|  64a c  - 16b c
+--R             *
+--R                 +---------------------------------------+
+--R                 |                +-----------------+
+--R                 |      2     2   |         1
+--R                 |(16a c  - 4b c) |- ---------------  - b
+--R                 |                |       3      2 2
+--R                 |               \|  64a c  - 16b c
+--R                 |---------------------------------------
+--R                 |                  2     2
+--R                \|              8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                                   +-----------------------------------------+
+--R                                   |                  +-----------------+
+--R                                   |        2     2   |         1
+--R                                   |(- 16a c  + 4b c) |- ---------------  - b
+--R                 +-----------+     |                  |       3      2 2
+--R             +-+ |          2  +-+ |                 \|  64a c  - 16b c
+--R            \|2 \|- 4a c + b  \|c  |-----------------------------------------
+--R                                   |                   2     2
+--R                                  \|               8a c  - 2b c
+--R         *
+--R            log
+--R                                   +-----------------+
+--R                         2     2   |         1
+--R                   (16a c  - 4b c) |- ---------------
+--R                                   |       3      2 2
+--R                                  \|  64a c  - 16b c
+--R                *
+--R                    +-----------------------------------------+
+--R                    |                  +-----------------+
+--R                    |        2     2   |         1
+--R                    |(- 16a c  + 4b c) |- ---------------  - b
+--R                    |                  |       3      2 2
+--R                    |                 \|  64a c  - 16b c
+--R                    |-----------------------------------------
+--R                    |                   2     2
+--R                   \|               8a c  - 2b c
+--R               + 
+--R                 x
+--R     + 
+--R                                +-----------------------------------------+
+--R                                |                  +-----------------+
+--R                                |        2     2   |         1
+--R                                |(- 16a c  + 4b c) |- ---------------  - b
+--R              +-----------+     |                  |       3      2 2
+--R          +-+ |          2  +-+ |                 \|  64a c  - 16b c
+--R         \|2 \|- 4a c + b  \|c  |-----------------------------------------
+--R                                |                   2     2
+--R                               \|               8a c  - 2b c
+--R      *
+--R         log
+--R                                  +-----------------+
+--R                        2     2   |         1
+--R                (- 16a c  + 4b c) |- ---------------
+--R                                  |       3      2 2
+--R                                 \|  64a c  - 16b c
+--R             *
+--R                 +-----------------------------------------+
+--R                 |                  +-----------------+
+--R                 |        2     2   |         1
+--R                 |(- 16a c  + 4b c) |- ---------------  - b
+--R                 |                  |       3      2 2
+--R                 |                 \|  64a c  - 16b c
+--R                 |-----------------------------------------
+--R                 |                   2     2
+--R                \|               8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                                   +---------------------------------------+
+--R                                   |                +-----------------+
+--R                                   |      2     2   |         1
+--R                                   |(16a c  - 4b c) |- ---------------  - b
+--R                 +-----------+     |                |       3      2 2
+--R             +-+ |          2  +-+ |               \|  64a c  - 16b c
+--R            \|2 \|- 4a c + b  \|c  |---------------------------------------
+--R                                   |                  2     2
+--R                                  \|              8a c  - 2b c
+--R         *
+--R            log
+--R                                     +-----------------+
+--R                           2     2   |         1
+--R                   (- 16a c  + 4b c) |- ---------------
+--R                                     |       3      2 2
+--R                                    \|  64a c  - 16b c
+--R                *
+--R                    +---------------------------------------+
+--R                    |                +-----------------+
+--R                    |      2     2   |         1
+--R                    |(16a c  - 4b c) |- ---------------  - b
+--R                    |                |       3      2 2
+--R                    |               \|  64a c  - 16b c
+--R                    |---------------------------------------
+--R                    |                  2     2
+--R                   \|              8a c  - 2b c
+--R               + 
+--R                 x
+--R     + 
+--R           +--------------------+
+--R           |   +-----------+                    +-+ +-+
+--R           |   |          2                   x\|2 \|c
+--R       - 2\|- \|- 4a c + b   + b atanh(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R         +------------------+
+--R         | +-----------+                   +-+ +-+
+--R         | |          2                  x\|2 \|c
+--R       2\|\|- 4a c + b   + b atanh(---------------------)
+--R                                    +------------------+
+--R                                    | +-----------+
+--R                                    | |          2
+--R                                   \|\|- 4a c + b   + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 925
+
+--S 926 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 926
+
+)clear all
+
+--S 927 of 1353
+t0:=x/(a-b*x^2+c*x^4)
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  - b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 927
+
+--S 928 of 1353
+r0:=atanh((b-2*c*x^2)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                       2
+--R                   2c x  - b
+--R          atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R   (2)  - ---------------------
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 928
+
+--S 929 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                            +-----------+
+--R                 2 4         2           2  |          2         2     2   2
+--R              (2c x  - 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                          3
+--R              - 4a b c + b
+--R         /
+--R               4      2
+--R            c x  - b x  + a
+--R    /
+--R         +-----------+
+--R         |          2
+--R       2\|- 4a c + b
+--R     ,
+--R                     +---------+
+--R              2      |        2
+--R         (2c x  - b)\|4a c - b
+--R    atan(-----------------------)
+--R                        2
+--R                4a c - b
+--R    -----------------------------]
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 929
+
+--S 930 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                            +-----------+
+--R                 2 4         2           2  |          2         2     2   2
+--R              (2c x  - 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                          3
+--R              - 4a b c + b
+--R         /
+--R               4      2
+--R            c x  - b x  + a
+--R     + 
+--R                     2
+--R                 2c x  - b
+--R       2atanh(--------------)
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R  /
+--R       +-----------+
+--R       |          2
+--R     2\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 930
+
+--S 931 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 931
+
+--S 932 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        +---------+             2
+--R        |        2          2c x  - b
+--R       \|4a c - b  atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                      +---------+
+--R        +-----------+          2      |        2
+--R        |          2      (2c x  - b)\|4a c - b
+--R       \|- 4a c + b  atan(-----------------------)
+--R                                         2
+--R                                 4a c - b
+--R  /
+--R      +-----------+ +---------+
+--R      |          2  |        2
+--R     \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 932
+
+--S 933 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 933
+
+)clear all
+
+--S 934 of 1353
+t0:=1/(a-b*x^2+c*x^4)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  - b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 934
+
+--S 935 of 1353
+r0:=atanh(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/_
+   (sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-atanh(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                +------------------+
+--R                | +-----------+                    +-+ +-+
+--R        +-+ +-+ | |          2                   x\|2 \|c
+--R       \|2 \|c \|\|- 4a c + b   + b atanh(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                           |   |          2
+--R                                          \|- \|- 4a c + b   + b
+--R     + 
+--R                  +--------------------+
+--R                  |   +-----------+                   +-+ +-+
+--R          +-+ +-+ |   |          2                  x\|2 \|c
+--R       - \|2 \|c \|- \|- 4a c + b   + b atanh(---------------------)
+--R                                               +------------------+
+--R                                               | +-----------+
+--R                                               | |          2
+--R                                              \|\|- 4a c + b   + b
+--R  /
+--R                    +--------------------+ +------------------+
+--R      +-----------+ |   +-----------+      | +-----------+
+--R      |          2  |   |          2       | |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 935
+
+--S 936 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +--------------------------------------+
+--R             |                +----------------+
+--R             |    2        2  |         1
+--R             |(16a c - 4a b ) |- --------------  - b
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |--------------------------------------
+--R             |               2        2
+--R            \|             8a c - 2a b
+--R         *
+--R            log
+--R                                      +----------------+
+--R                        2          3  |         1                  2
+--R                   ((16a b c - 4a b ) |- --------------  - 4a c + b )
+--R                                      |     3       2 2
+--R                                     \|  64a c - 16a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |                +----------------+
+--R                    |    2        2  |         1
+--R                    |(16a c - 4a b ) |- --------------  - b
+--R                    |                |     3       2 2
+--R                    |               \|  64a c - 16a b
+--R                    |--------------------------------------
+--R                    |               2        2
+--R                   \|             8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R          +----------------------------------------+
+--R          |                  +----------------+
+--R          |      2        2  |         1
+--R          |(- 16a c + 4a b ) |- --------------  - b
+--R          |                  |     3       2 2
+--R          |                 \|  64a c - 16a b
+--R          |----------------------------------------
+--R          |                2        2
+--R         \|              8a c - 2a b
+--R      *
+--R         log
+--R                                   +----------------+
+--R                     2          3  |         1                  2
+--R                ((16a b c - 4a b ) |- --------------  + 4a c - b )
+--R                                   |     3       2 2
+--R                                  \|  64a c - 16a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |                  +----------------+
+--R                 |      2        2  |         1
+--R                 |(- 16a c + 4a b ) |- --------------  - b
+--R                 |                  |     3       2 2
+--R                 |                 \|  64a c - 16a b
+--R                 |----------------------------------------
+--R                 |                2        2
+--R                \|              8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R             +----------------------------------------+
+--R             |                  +----------------+
+--R             |      2        2  |         1
+--R             |(- 16a c + 4a b ) |- --------------  - b
+--R             |                  |     3       2 2
+--R             |                 \|  64a c - 16a b
+--R             |----------------------------------------
+--R             |                2        2
+--R            \|              8a c - 2a b
+--R         *
+--R            log
+--R                                        +----------------+
+--R                          2          3  |         1                  2
+--R                   ((- 16a b c + 4a b ) |- --------------  - 4a c + b )
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |                  +----------------+
+--R                    |      2        2  |         1
+--R                    |(- 16a c + 4a b ) |- --------------  - b
+--R                    |                  |     3       2 2
+--R                    |                 \|  64a c - 16a b
+--R                    |----------------------------------------
+--R                    |                2        2
+--R                   \|              8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R          +--------------------------------------+
+--R          |                +----------------+
+--R          |    2        2  |         1
+--R          |(16a c - 4a b ) |- --------------  - b
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |--------------------------------------
+--R          |               2        2
+--R         \|             8a c - 2a b
+--R      *
+--R         log
+--R                                     +----------------+
+--R                       2          3  |         1                  2
+--R                ((- 16a b c + 4a b ) |- --------------  + 4a c - b )
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |                +----------------+
+--R                 |    2        2  |         1
+--R                 |(16a c - 4a b ) |- --------------  - b
+--R                 |                |     3       2 2
+--R                 |               \|  64a c - 16a b
+--R                 |--------------------------------------
+--R                 |               2        2
+--R                \|             8a c - 2a b
+--R            + 
+--R              2c x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 936
+
+--S 937 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R             |          2  |   |          2       | |          2
+--R            \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +--------------------------------------+
+--R             |                +----------------+
+--R             |    2        2  |         1
+--R             |(16a c - 4a b ) |- --------------  - b
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |--------------------------------------
+--R             |               2        2
+--R            \|             8a c - 2a b
+--R         *
+--R            log
+--R                                      +----------------+
+--R                        2          3  |         1                  2
+--R                   ((16a b c - 4a b ) |- --------------  - 4a c + b )
+--R                                      |     3       2 2
+--R                                     \|  64a c - 16a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |                +----------------+
+--R                    |    2        2  |         1
+--R                    |(16a c - 4a b ) |- --------------  - b
+--R                    |                |     3       2 2
+--R                    |               \|  64a c - 16a b
+--R                    |--------------------------------------
+--R                    |               2        2
+--R                   \|             8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R                        +----------------------------------------+
+--R                        |                  +----------------+
+--R                        |      2        2  |         1
+--R                        |(- 16a c + 4a b ) |- --------------  - b
+--R          +-----------+ |                  |     3       2 2
+--R          |          2  |                 \|  64a c - 16a b
+--R         \|- 4a c + b   |----------------------------------------
+--R                        |                2        2
+--R                       \|              8a c - 2a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                   +----------------+
+--R                     2          3  |         1                  2
+--R                ((16a b c - 4a b ) |- --------------  + 4a c - b )
+--R                                   |     3       2 2
+--R                                  \|  64a c - 16a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |                  +----------------+
+--R                 |      2        2  |         1
+--R                 |(- 16a c + 4a b ) |- --------------  - b
+--R                 |                  |     3       2 2
+--R                 |                 \|  64a c - 16a b
+--R                 |----------------------------------------
+--R                 |                2        2
+--R                \|              8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R                           +----------------------------------------+
+--R                           |                  +----------------+
+--R                           |      2        2  |         1
+--R                           |(- 16a c + 4a b ) |- --------------  - b
+--R             +-----------+ |                  |     3       2 2
+--R             |          2  |                 \|  64a c - 16a b
+--R            \|- 4a c + b   |----------------------------------------
+--R                           |                2        2
+--R                          \|              8a c - 2a b
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                        +----------------+
+--R                          2          3  |         1                  2
+--R                   ((- 16a b c + 4a b ) |- --------------  - 4a c + b )
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |                  +----------------+
+--R                    |      2        2  |         1
+--R                    |(- 16a c + 4a b ) |- --------------  - b
+--R                    |                  |     3       2 2
+--R                    |                 \|  64a c - 16a b
+--R                    |----------------------------------------
+--R                    |                2        2
+--R                   \|              8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2  |   |          2       | |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +--------------------------------------+
+--R          |                +----------------+
+--R          |    2        2  |         1
+--R          |(16a c - 4a b ) |- --------------  - b
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |--------------------------------------
+--R          |               2        2
+--R         \|             8a c - 2a b
+--R      *
+--R         log
+--R                                     +----------------+
+--R                       2          3  |         1                  2
+--R                ((- 16a b c + 4a b ) |- --------------  + 4a c - b )
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |                +----------------+
+--R                 |    2        2  |         1
+--R                 |(16a c - 4a b ) |- --------------  - b
+--R                 |                |     3       2 2
+--R                 |               \|  64a c - 16a b
+--R                 |--------------------------------------
+--R                 |               2        2
+--R                \|             8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R                   +------------------+
+--R                   | +-----------+                    +-+ +-+
+--R           +-+ +-+ | |          2                   x\|2 \|c
+--R       - 2\|2 \|c \|\|- 4a c + b   + b atanh(-----------------------)
+--R                                              +--------------------+
+--R                                              |   +-----------+
+--R                                              |   |          2
+--R                                             \|- \|- 4a c + b   + b
+--R     + 
+--R                 +--------------------+
+--R                 |   +-----------+                   +-+ +-+
+--R         +-+ +-+ |   |          2                  x\|2 \|c
+--R       2\|2 \|c \|- \|- 4a c + b   + b atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                              | |          2
+--R                                             \|\|- 4a c + b   + b
+--R  /
+--R                     +--------------------+ +------------------+
+--R       +-----------+ |   +-----------+      | +-----------+
+--R       |          2  |   |          2       | |          2
+--R     2\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 937
+
+--S 938 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 938
+
+)clear all
+
+--S 939 of 1353
+t0:=x^3/(a+b+2*a*x^2+a*x^4)
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  --------------------
+--R           4       2
+--R        a x  + 2a x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 939
+
+--S 940 of 1353
+r0:=1/4*log(a+b+2*a*x^2+a*x^4)/a-1/2*atan((1+x^2)*sqrt(a)/sqrt(b))/_
+   (sqrt(a)*sqrt(b))
+--R 
+--R
+--R                    2      +-+
+--R                  (x  + 1)\|a            4       2          +-+ +-+
+--R        - 2a atan(------------) + log(a x  + 2a x  + b + a)\|a \|b
+--R                       +-+
+--R                      \|b
+--R   (2)  -----------------------------------------------------------
+--R                                    +-+ +-+
+--R                                 4a\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 940
+
+--S 941 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   4       2          +-----+         2
+--R               (a x  + 2a x  - b + a)\|- a b  - 2a b x  - 2a b
+--R         a log(-----------------------------------------------)
+--R                                4       2
+--R                             a x  + 2a x  + b + a
+--R       + 
+--R                4       2          +-----+
+--R         log(a x  + 2a x  + b + a)\|- a b
+--R    /
+--R          +-----+
+--R       4a\|- a b
+--R     ,
+--R                2      +---+
+--R              (x  + 1)\|a b            4       2          +---+
+--R    - 2a atan(--------------) + log(a x  + 2a x  + b + a)\|a b
+--R                     b
+--R    -----------------------------------------------------------]
+--R                                 +---+
+--R                              4a\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 941
+
+--S 942 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       4       2          +-----+         2
+--R        +-+ +-+    (a x  + 2a x  - b + a)\|- a b  - 2a b x  - 2a b
+--R       \|a \|b log(-----------------------------------------------)
+--R                                    4       2
+--R                                 a x  + 2a x  + b + a
+--R     + 
+--R                       2      +-+
+--R         +-----+     (x  + 1)\|a
+--R       2\|- a b atan(------------)
+--R                          +-+
+--R                         \|b
+--R  /
+--R       +-----+ +-+ +-+
+--R     4\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 942
+
+--S 943 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 943
+
+--S 944 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R                         2      +---+                 2      +-+
+--R           +-+ +-+     (x  + 1)\|a b      +---+     (x  + 1)\|a
+--R        - \|a \|b atan(--------------) + \|a b atan(------------)
+--R                              b                          +-+
+--R                                                        \|b
+--R   (6)  ---------------------------------------------------------
+--R                               +-+ +-+ +---+
+--R                             2\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 944
+
+--S 945 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 945
+
+)clear all
+
+--S 946 of 1353
+t0:=x^2/(a+b+2*a*x^2+a*x^4)
+--R 
+--R
+--R                  2
+--R                 x
+--R   (1)  --------------------
+--R           4       2
+--R        a x  + 2a x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 946
+
+--S 947 of 1353
+r0:=1/2*atan((-a)^(1/4)*x/sqrt(sqrt(-a)-sqrt(b)))*sqrt(sqrt(-a)-sqrt(b))/_
+   ((-a)^(3/4)*sqrt(b))-1/2*atan((-a)^(1/4)*x/sqrt(sqrt(-a)+sqrt(b)))*_
+   sqrt(sqrt(-a)+sqrt(b))/((-a)^(3/4)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R        +---------------+            4+---+
+--R        |   +-+    +---+            x\|- a
+--R       \|- \|b  + \|- a  atan(------------------)
+--R                               +---------------+
+--R                               |   +-+    +---+
+--R                              \|- \|b  + \|- a
+--R     + 
+--R          +-------------+           4+---+
+--R          | +-+    +---+           x\|- a
+--R       - \|\|b  + \|- a  atan(----------------)
+--R                               +-------------+
+--R                               | +-+    +---+
+--R                              \|\|b  + \|- a
+--R  /
+--R      4+---+3 +-+
+--R     2\|- a  \|b
+--R                                                    Type: Expression(Integer)
+--E 947
+
+--S 948 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        +------------------+                    +------------------+
+--R        |     +-------+                         |     +-------+
+--R        |     |    1                            |     |    1
+--R        |8a b |- -----  + 1                     |8a b |- -----  + 1
+--R        |     |     3                 +-------+ |     |     3
+--R        |    \|  64a b             2  |    1    |    \|  64a b
+--R        |------------------ log(16a b |- -----  |------------------  + x)
+--R       \|       4a b                  |     3  \|       4a b
+--R                                     \|  64a b
+--R     + 
+--R          +--------------------+                    +--------------------+
+--R          |       +-------+                         |       +-------+
+--R          |       |    1                            |       |    1
+--R          |- 8a b |- -----  + 1                     |- 8a b |- -----  + 1
+--R          |       |     3                 +-------+ |       |     3
+--R          |      \|  64a b             2  |    1    |      \|  64a b
+--R       -  |-------------------- log(16a b |- -----  |--------------------  + x)
+--R         \|        4a b                   |     3  \|        4a b
+--R                                         \|  64a b
+--R     + 
+--R        +--------------------+                      +--------------------+
+--R        |       +-------+                           |       +-------+
+--R        |       |    1                              |       |    1
+--R        |- 8a b |- -----  + 1                       |- 8a b |- -----  + 1
+--R        |       |     3                   +-------+ |       |     3
+--R        |      \|  64a b               2  |    1    |      \|  64a b
+--R        |-------------------- log(- 16a b |- -----  |--------------------  + x)
+--R       \|        4a b                     |     3  \|        4a b
+--R                                         \|  64a b
+--R     + 
+--R          +------------------+                      +------------------+
+--R          |     +-------+                           |     +-------+
+--R          |     |    1                              |     |    1
+--R          |8a b |- -----  + 1                       |8a b |- -----  + 1
+--R          |     |     3                   +-------+ |     |     3
+--R          |    \|  64a b               2  |    1    |    \|  64a b
+--R       -  |------------------ log(- 16a b |- -----  |------------------  + x)
+--R         \|       4a b                    |     3  \|       4a b
+--R                                         \|  64a b
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 948
+
+--S 949 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +------------------+
+--R                     |     +-------+
+--R                     |     |    1
+--R                     |8a b |- -----  + 1
+--R                     |     |     3
+--R         4+---+3 +-+ |    \|  64a b
+--R         \|- a  \|b  |------------------
+--R                    \|       4a b
+--R      *
+--R                             +------------------+
+--R                             |     +-------+
+--R                             |     |    1
+--R                             |8a b |- -----  + 1
+--R                   +-------+ |     |     3
+--R                2  |    1    |    \|  64a b
+--R         log(16a b |- -----  |------------------  + x)
+--R                   |     3  \|       4a b
+--R                  \|  64a b
+--R     + 
+--R       -
+--R                        +--------------------+
+--R                        |       +-------+
+--R                        |       |    1
+--R                        |- 8a b |- -----  + 1
+--R                        |       |     3
+--R            4+---+3 +-+ |      \|  64a b
+--R            \|- a  \|b  |--------------------
+--R                       \|        4a b
+--R         *
+--R                                +--------------------+
+--R                                |       +-------+
+--R                                |       |    1
+--R                                |- 8a b |- -----  + 1
+--R                      +-------+ |       |     3
+--R                   2  |    1    |      \|  64a b
+--R            log(16a b |- -----  |--------------------  + x)
+--R                      |     3  \|        4a b
+--R                     \|  64a b
+--R     + 
+--R                     +--------------------+
+--R                     |       +-------+
+--R                     |       |    1
+--R                     |- 8a b |- -----  + 1
+--R                     |       |     3
+--R         4+---+3 +-+ |      \|  64a b
+--R         \|- a  \|b  |--------------------
+--R                    \|        4a b
+--R      *
+--R                               +--------------------+
+--R                               |       +-------+
+--R                               |       |    1
+--R                               |- 8a b |- -----  + 1
+--R                     +-------+ |       |     3
+--R                  2  |    1    |      \|  64a b
+--R         log(- 16a b |- -----  |--------------------  + x)
+--R                     |     3  \|        4a b
+--R                    \|  64a b
+--R     + 
+--R       -
+--R                        +------------------+
+--R                        |     +-------+
+--R                        |     |    1
+--R                        |8a b |- -----  + 1
+--R                        |     |     3
+--R            4+---+3 +-+ |    \|  64a b
+--R            \|- a  \|b  |------------------
+--R                       \|       4a b
+--R         *
+--R                                  +------------------+
+--R                                  |     +-------+
+--R                                  |     |    1
+--R                                  |8a b |- -----  + 1
+--R                        +-------+ |     |     3
+--R                     2  |    1    |    \|  64a b
+--R            log(- 16a b |- -----  |------------------  + x)
+--R                        |     3  \|       4a b
+--R                       \|  64a b
+--R     + 
+--R          +---------------+            4+---+
+--R          |   +-+    +---+            x\|- a
+--R       - \|- \|b  + \|- a  atan(------------------)
+--R                                 +---------------+
+--R                                 |   +-+    +---+
+--R                                \|- \|b  + \|- a
+--R     + 
+--R        +-------------+           4+---+
+--R        | +-+    +---+           x\|- a
+--R       \|\|b  + \|- a  atan(----------------)
+--R                             +-------------+
+--R                             | +-+    +---+
+--R                            \|\|b  + \|- a
+--R  /
+--R      4+---+3 +-+
+--R     2\|- a  \|b
+--R                                                    Type: Expression(Integer)
+--E 949
+
+--S 950 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 950
+
+)clear all
+
+--S 951 of 1353
+t0:=x/(a+b+2*a*x^2+a*x^4)
+--R 
+--R
+--R                  x
+--R   (1)  --------------------
+--R           4       2
+--R        a x  + 2a x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 951
+
+--S 952 of 1353
+r0:=1/2*atan((1+x^2)*sqrt(a)/sqrt(b))/(sqrt(a)*sqrt(b))
+--R 
+--R
+--R               2      +-+
+--R             (x  + 1)\|a
+--R        atan(------------)
+--R                  +-+
+--R                 \|b
+--R   (2)  ------------------
+--R               +-+ +-+
+--R             2\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 952
+
+--S 953 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4       2          +-----+         2
+--R        (a x  + 2a x  - b + a)\|- a b  + 2a b x  + 2a b         2      +---+
+--R    log(-----------------------------------------------)      (x  + 1)\|a b
+--R                         4       2                       atan(--------------)
+--R                      a x  + 2a x  + b + a                           b
+--R   [----------------------------------------------------,--------------------]
+--R                            +-----+                               +---+
+--R                          4\|- a b                              2\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 953
+
+--S 954 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       4       2          +-----+         2
+--R        +-+ +-+    (a x  + 2a x  - b + a)\|- a b  + 2a b x  + 2a b
+--R       \|a \|b log(-----------------------------------------------)
+--R                                    4       2
+--R                                 a x  + 2a x  + b + a
+--R     + 
+--R                         2      +-+
+--R           +-----+     (x  + 1)\|a
+--R       - 2\|- a b atan(------------)
+--R                            +-+
+--R                           \|b
+--R  /
+--R       +-----+ +-+ +-+
+--R     4\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 954
+
+--S 955 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 955
+
+--S 956 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R                       2      +---+                 2      +-+
+--R         +-+ +-+     (x  + 1)\|a b      +---+     (x  + 1)\|a
+--R        \|a \|b atan(--------------) - \|a b atan(------------)
+--R                            b                          +-+
+--R                                                      \|b
+--R   (6)  -------------------------------------------------------
+--R                              +-+ +-+ +---+
+--R                            2\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 957
+
+)clear all
+
+--S 958 of 1353
+t0:=1/(a+b+2*a*x^2+a*x^4)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           4       2
+--R        a x  + 2a x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 958
+
+--S 959 of 1353
+r0:=-1/2*atan((-a)^(1/4)*x/sqrt(sqrt(-a)-sqrt(b)))/((-a)^(1/4)*sqrt(b)*_
+   sqrt(sqrt(-a)-sqrt(b)))+1/2*atan((-a)^(1/4)*x/sqrt(sqrt(-a)+sqrt(b)))/_
+   ((-a)^(1/4)*sqrt(b)*sqrt(sqrt(-a)+sqrt(b)))
+--R 
+--R
+--R   (2)
+--R          +-------------+            4+---+
+--R          | +-+    +---+            x\|- a
+--R       - \|\|b  + \|- a  atan(------------------)
+--R                               +---------------+
+--R                               |   +-+    +---+
+--R                              \|- \|b  + \|- a
+--R     + 
+--R        +---------------+           4+---+
+--R        |   +-+    +---+           x\|- a
+--R       \|- \|b  + \|- a  atan(----------------)
+--R                               +-------------+
+--R                               | +-+    +---+
+--R                              \|\|b  + \|- a
+--R  /
+--R                 +---------------+ +-------------+
+--R      4+---+ +-+ |   +-+    +---+  | +-+    +---+
+--R     2\|- a \|b \|- \|b  + \|- a  \|\|b  + \|- a
+--R                                                    Type: Expression(Integer)
+--E 959
+
+--S 960 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +---------------------------------------------+
+--R          |             +--------------------------+
+--R          |   2         |              1
+--R          |(8b  + 8a b) |- ------------------------  + 1
+--R          |             |       3       2 2      3
+--R          |            \|  64a b  + 128a b  + 64a b
+--R          |---------------------------------------------
+--R          |                    2
+--R         \|                  4b  + 4a b
+--R      *
+--R         log
+--R                                  +--------------------------+
+--R                       2      2   |              1
+--R                ((16a b  + 16a b) |- ------------------------  + 2b)
+--R                                  |       3       2 2      3
+--R                                 \|  64a b  + 128a b  + 64a b
+--R             *
+--R                 +---------------------------------------------+
+--R                 |             +--------------------------+
+--R                 |   2         |              1
+--R                 |(8b  + 8a b) |- ------------------------  + 1
+--R                 |             |       3       2 2      3
+--R                 |            \|  64a b  + 128a b  + 64a b
+--R                 |---------------------------------------------
+--R                 |                    2
+--R                \|                  4b  + 4a b
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +-----------------------------------------------+
+--R             |               +--------------------------+
+--R             |     2         |              1
+--R             |(- 8b  - 8a b) |- ------------------------  + 1
+--R             |               |       3       2 2      3
+--R             |              \|  64a b  + 128a b  + 64a b
+--R             |-----------------------------------------------
+--R             |                     2
+--R            \|                   4b  + 4a b
+--R         *
+--R            log
+--R                                     +--------------------------+
+--R                          2      2   |              1
+--R                   ((16a b  + 16a b) |- ------------------------  - 2b)
+--R                                     |       3       2 2      3
+--R                                    \|  64a b  + 128a b  + 64a b
+--R                *
+--R                    +-----------------------------------------------+
+--R                    |               +--------------------------+
+--R                    |     2         |              1
+--R                    |(- 8b  - 8a b) |- ------------------------  + 1
+--R                    |               |       3       2 2      3
+--R                    |              \|  64a b  + 128a b  + 64a b
+--R                    |-----------------------------------------------
+--R                    |                     2
+--R                   \|                   4b  + 4a b
+--R               + 
+--R                 x
+--R     + 
+--R          +-----------------------------------------------+
+--R          |               +--------------------------+
+--R          |     2         |              1
+--R          |(- 8b  - 8a b) |- ------------------------  + 1
+--R          |               |       3       2 2      3
+--R          |              \|  64a b  + 128a b  + 64a b
+--R          |-----------------------------------------------
+--R          |                     2
+--R         \|                   4b  + 4a b
+--R      *
+--R         log
+--R                                    +--------------------------+
+--R                         2      2   |              1
+--R                ((- 16a b  - 16a b) |- ------------------------  + 2b)
+--R                                    |       3       2 2      3
+--R                                   \|  64a b  + 128a b  + 64a b
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |               +--------------------------+
+--R                 |     2         |              1
+--R                 |(- 8b  - 8a b) |- ------------------------  + 1
+--R                 |               |       3       2 2      3
+--R                 |              \|  64a b  + 128a b  + 64a b
+--R                 |-----------------------------------------------
+--R                 |                     2
+--R                \|                   4b  + 4a b
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +---------------------------------------------+
+--R             |             +--------------------------+
+--R             |   2         |              1
+--R             |(8b  + 8a b) |- ------------------------  + 1
+--R             |             |       3       2 2      3
+--R             |            \|  64a b  + 128a b  + 64a b
+--R             |---------------------------------------------
+--R             |                    2
+--R            \|                  4b  + 4a b
+--R         *
+--R            log
+--R                                       +--------------------------+
+--R                            2      2   |              1
+--R                   ((- 16a b  - 16a b) |- ------------------------  - 2b)
+--R                                       |       3       2 2      3
+--R                                      \|  64a b  + 128a b  + 64a b
+--R                *
+--R                    +---------------------------------------------+
+--R                    |             +--------------------------+
+--R                    |   2         |              1
+--R                    |(8b  + 8a b) |- ------------------------  + 1
+--R                    |             |       3       2 2      3
+--R                    |            \|  64a b  + 128a b  + 64a b
+--R                    |---------------------------------------------
+--R                    |                    2
+--R                   \|                  4b  + 4a b
+--R               + 
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 960
+
+--S 961 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    +---------------+
+--R         4+---+ +-+ |   +-+    +---+
+--R         \|- a \|b \|- \|b  + \|- a
+--R      *
+--R          +---------------------------------------------+
+--R          |             +--------------------------+
+--R          |   2         |              1
+--R          |(8b  + 8a b) |- ------------------------  + 1
+--R          |             |       3       2 2      3        +-------------+
+--R          |            \|  64a b  + 128a b  + 64a b       | +-+    +---+
+--R          |--------------------------------------------- \|\|b  + \|- a
+--R          |                    2
+--R         \|                  4b  + 4a b
+--R      *
+--R         log
+--R                                  +--------------------------+
+--R                       2      2   |              1
+--R                ((16a b  + 16a b) |- ------------------------  + 2b)
+--R                                  |       3       2 2      3
+--R                                 \|  64a b  + 128a b  + 64a b
+--R             *
+--R                 +---------------------------------------------+
+--R                 |             +--------------------------+
+--R                 |   2         |              1
+--R                 |(8b  + 8a b) |- ------------------------  + 1
+--R                 |             |       3       2 2      3
+--R                 |            \|  64a b  + 128a b  + 64a b
+--R                 |---------------------------------------------
+--R                 |                    2
+--R                \|                  4b  + 4a b
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                       +---------------+
+--R            4+---+ +-+ |   +-+    +---+
+--R            \|- a \|b \|- \|b  + \|- a
+--R         *
+--R             +-----------------------------------------------+
+--R             |               +--------------------------+
+--R             |     2         |              1
+--R             |(- 8b  - 8a b) |- ------------------------  + 1
+--R             |               |       3       2 2      3        +-------------+
+--R             |              \|  64a b  + 128a b  + 64a b       | +-+    +---+
+--R             |----------------------------------------------- \|\|b  + \|- a
+--R             |                     2
+--R            \|                   4b  + 4a b
+--R         *
+--R            log
+--R                                     +--------------------------+
+--R                          2      2   |              1
+--R                   ((16a b  + 16a b) |- ------------------------  - 2b)
+--R                                     |       3       2 2      3
+--R                                    \|  64a b  + 128a b  + 64a b
+--R                *
+--R                    +-----------------------------------------------+
+--R                    |               +--------------------------+
+--R                    |     2         |              1
+--R                    |(- 8b  - 8a b) |- ------------------------  + 1
+--R                    |               |       3       2 2      3
+--R                    |              \|  64a b  + 128a b  + 64a b
+--R                    |-----------------------------------------------
+--R                    |                     2
+--R                   \|                   4b  + 4a b
+--R               + 
+--R                 x
+--R     + 
+--R                    +---------------+
+--R         4+---+ +-+ |   +-+    +---+
+--R         \|- a \|b \|- \|b  + \|- a
+--R      *
+--R          +-----------------------------------------------+
+--R          |               +--------------------------+
+--R          |     2         |              1
+--R          |(- 8b  - 8a b) |- ------------------------  + 1
+--R          |               |       3       2 2      3        +-------------+
+--R          |              \|  64a b  + 128a b  + 64a b       | +-+    +---+
+--R          |----------------------------------------------- \|\|b  + \|- a
+--R          |                     2
+--R         \|                   4b  + 4a b
+--R      *
+--R         log
+--R                                    +--------------------------+
+--R                         2      2   |              1
+--R                ((- 16a b  - 16a b) |- ------------------------  + 2b)
+--R                                    |       3       2 2      3
+--R                                   \|  64a b  + 128a b  + 64a b
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |               +--------------------------+
+--R                 |     2         |              1
+--R                 |(- 8b  - 8a b) |- ------------------------  + 1
+--R                 |               |       3       2 2      3
+--R                 |              \|  64a b  + 128a b  + 64a b
+--R                 |-----------------------------------------------
+--R                 |                     2
+--R                \|                   4b  + 4a b
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                       +---------------+
+--R            4+---+ +-+ |   +-+    +---+
+--R            \|- a \|b \|- \|b  + \|- a
+--R         *
+--R             +---------------------------------------------+
+--R             |             +--------------------------+
+--R             |   2         |              1
+--R             |(8b  + 8a b) |- ------------------------  + 1
+--R             |             |       3       2 2      3        +-------------+
+--R             |            \|  64a b  + 128a b  + 64a b       | +-+    +---+
+--R             |--------------------------------------------- \|\|b  + \|- a
+--R             |                    2
+--R            \|                  4b  + 4a b
+--R         *
+--R            log
+--R                                       +--------------------------+
+--R                            2      2   |              1
+--R                   ((- 16a b  - 16a b) |- ------------------------  - 2b)
+--R                                       |       3       2 2      3
+--R                                      \|  64a b  + 128a b  + 64a b
+--R                *
+--R                    +---------------------------------------------+
+--R                    |             +--------------------------+
+--R                    |   2         |              1
+--R                    |(8b  + 8a b) |- ------------------------  + 1
+--R                    |             |       3       2 2      3
+--R                    |            \|  64a b  + 128a b  + 64a b
+--R                    |---------------------------------------------
+--R                    |                    2
+--R                   \|                  4b  + 4a b
+--R               + 
+--R                 x
+--R     + 
+--R        +-------------+            4+---+
+--R        | +-+    +---+            x\|- a
+--R       \|\|b  + \|- a  atan(------------------)
+--R                             +---------------+
+--R                             |   +-+    +---+
+--R                            \|- \|b  + \|- a
+--R     + 
+--R          +---------------+           4+---+
+--R          |   +-+    +---+           x\|- a
+--R       - \|- \|b  + \|- a  atan(----------------)
+--R                                 +-------------+
+--R                                 | +-+    +---+
+--R                                \|\|b  + \|- a
+--R  /
+--R                 +---------------+ +-------------+
+--R      4+---+ +-+ |   +-+    +---+  | +-+    +---+
+--R     2\|- a \|b \|- \|b  + \|- a  \|\|b  + \|- a
+--R                                                    Type: Expression(Integer)
+--E 961
+
+--S 962 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 962
+
+)clear all
+
+--S 963 of 1353
+t0:=1/(x*(a+b+2*a*x^2+a*x^4))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R           5       3
+--R        a x  + 2a x  + (b + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 963
+
+--S 964 of 1353
+r0:=log(x)/(a+b)-1/4*log(a+b+2*a*x^2+a*x^4)/(a+b)-1/2*atan((1+x^2)*_
+   sqrt(a)/sqrt(b))*sqrt(a)/((a+b)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                 2      +-+
+--R       +-+     (x  + 1)\|a               4       2                     +-+
+--R   - 2\|a atan(------------) + (- log(a x  + 2a x  + b + a) + 4log(x))\|b
+--R                    +-+
+--R                   \|b
+--R   -----------------------------------------------------------------------
+--R                                          +-+
+--R                                (4b + 4a)\|b
+--R                                                    Type: Expression(Integer)
+--E 964
+
+--S 965 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                  +---+
+--R                          2       |  a       4       2
+--R          +---+    (- 2b x  - 2b) |- -  + a x  + 2a x  - b + a
+--R          |  a                   \|  b
+--R          |- - log(-------------------------------------------)
+--R         \|  b                    4       2
+--R                               a x  + 2a x  + b + a
+--R       + 
+--R                  4       2
+--R         - log(a x  + 2a x  + b + a) + 4log(x)
+--R    /
+--R       4b + 4a
+--R     ,
+--R                   +-+
+--R                   |a
+--R       +-+       b |-
+--R       |a         \|b            4       2
+--R    2  |- atan(-------- - log(a x  + 2a x  + b + a) + 4log(x)
+--R      \|b         2
+--R               a x  + a
+--R    ---------------------------------------------------------]
+--R                             4b + 4a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 965
+
+--S 966 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                    +---+
+--R                            2       |  a       4       2
+--R        +---+        (- 2b x  - 2b) |- -  + a x  + 2a x  - b + a
+--R        |  a  +-+                  \|  b
+--R        |- - \|b log(-------------------------------------------)
+--R       \|  b                        4       2
+--R                                 a x  + 2a x  + b + a
+--R     + 
+--R                   2      +-+
+--R         +-+     (x  + 1)\|a
+--R       2\|a atan(------------)
+--R                      +-+
+--R                     \|b
+--R  /
+--R               +-+
+--R     (4b + 4a)\|b
+--R                                                    Type: Expression(Integer)
+--E 966
+
+--S 967 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 967
+
+--S 968 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R                         +-+
+--R                         |a
+--R         +-+           b |-                 2      +-+
+--R         |a  +-+        \|b       +-+     (x  + 1)\|a
+--R         |- \|b atan(--------) + \|a atan(------------)
+--R        \|b             2                      +-+
+--R                     a x  + a                 \|b
+--R   (6)  -----------------------------------------------
+--R                                   +-+
+--R                         (2b + 2a)\|b
+--R                                                    Type: Expression(Integer)
+--E 968
+
+--S 969 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 969
+
+)clear all
+
+--S 970 of 1353
+t0:=1/(x^2*(a+b+2*a*x^2+a*x^4))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           6       4           2
+--R        a x  + 2a x  + (b + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 970
+
+--S 971 of 1353
+r0:=(-1)/((a+b)*x)-1/2*(-a)^(1/4)*atan((-a)^(1/4)*x/sqrt(sqrt(-a)-_
+   sqrt(b)))*(sqrt(-a)+sqrt(b))/((a+b)*sqrt(b)*sqrt(sqrt(-a)-sqrt(b)))-_
+   1/2*(-a)^(1/4)*atan((-a)^(1/4)*x/sqrt(sqrt(-a)+sqrt(b)))*_
+   (1-sqrt(-a)/sqrt(b))/((a+b)*sqrt(sqrt(-a)+sqrt(b)))
+--R 
+--R
+--R   (2)
+--R                                       +-------------+            4+---+
+--R           4+---+ +-+     +---+4+---+  | +-+    +---+            x\|- a
+--R       (- x\|- a \|b  - x\|- a \|- a )\|\|b  + \|- a  atan(------------------)
+--R                                                            +---------------+
+--R                                                            |   +-+    +---+
+--R                                                           \|- \|b  + \|- a
+--R     + 
+--R                                       +---------------+           4+---+
+--R           4+---+ +-+     +---+4+---+  |   +-+    +---+           x\|- a
+--R       (- x\|- a \|b  + x\|- a \|- a )\|- \|b  + \|- a  atan(----------------)
+--R                                                              +-------------+
+--R                                                              | +-+    +---+
+--R                                                             \|\|b  + \|- a
+--R     + 
+--R               +---------------+ +-------------+
+--R           +-+ |   +-+    +---+  | +-+    +---+
+--R       - 2\|b \|- \|b  + \|- a  \|\|b  + \|- a
+--R  /
+--R                    +---------------+ +-------------+
+--R                +-+ |   +-+    +---+  | +-+    +---+
+--R     (2b + 2a)x\|b \|- \|b  + \|- a  \|\|b  + \|- a
+--R                                                    Type: Expression(Integer)
+--E 971
+
+--S 972 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         (- b - a)x
+--R      *
+--R         ROOT
+--R                     4        3      2 2     3
+--R                  (8b  + 24a b  + 24a b  + 8a b)
+--R               *
+--R                  ROOT
+--R                            2     2      3
+--R                       - a b  + 6a b - 9a
+--R                    /
+--R                            7         6       2 5        3 4       4 3       5 2
+--R                         64b  + 384a b  + 960a b  + 1280a b  + 960a b  + 384a b
+--R                       + 
+--R                            6
+--R                         64a b
+--R              + 
+--R                          2
+--R                - 3a b + a
+--R           /
+--R                4        3      2 2     3
+--R              4b  + 12a b  + 12a b  + 4a b
+--R      *
+--R         log
+--R                        5        4      3 2      4
+--R                    (16b  + 32a b  - 32a b  - 16a b)
+--R                 *
+--R                    ROOT
+--R                              2     2      3
+--R                         - a b  + 6a b - 9a
+--R                      /
+--R                              7         6       2 5        3 4       4 3
+--R                           64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                         + 
+--R                               5 2      6
+--R                           384a b  + 64a b
+--R                + 
+--R                      2      2
+--R                  4a b  - 12a b
+--R             *
+--R                ROOT
+--R                            4        3      2 2     3
+--R                         (8b  + 24a b  + 24a b  + 8a b)
+--R                      *
+--R                         ROOT
+--R                                   2     2      3
+--R                              - a b  + 6a b - 9a
+--R                           /
+--R                                   7         6       2 5        3 4       4 3
+--R                                64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                              + 
+--R                                    5 2      6
+--R                                384a b  + 64a b
+--R                     + 
+--R                                 2
+--R                       - 3a b + a
+--R                  /
+--R                       4        3      2 2     3
+--R                     4b  + 12a b  + 12a b  + 4a b
+--R            + 
+--R                       2
+--R              (a b - 3a )x
+--R     + 
+--R         (b + a)x
+--R      *
+--R         ROOT
+--R                       4        3      2 2     3
+--R                  (- 8b  - 24a b  - 24a b  - 8a b)
+--R               *
+--R                  ROOT
+--R                            2     2      3
+--R                       - a b  + 6a b - 9a
+--R                    /
+--R                            7         6       2 5        3 4       4 3       5 2
+--R                         64b  + 384a b  + 960a b  + 1280a b  + 960a b  + 384a b
+--R                       + 
+--R                            6
+--R                         64a b
+--R              + 
+--R                          2
+--R                - 3a b + a
+--R           /
+--R                4        3      2 2     3
+--R              4b  + 12a b  + 12a b  + 4a b
+--R      *
+--R         log
+--R                        5        4      3 2      4
+--R                    (16b  + 32a b  - 32a b  - 16a b)
+--R                 *
+--R                    ROOT
+--R                              2     2      3
+--R                         - a b  + 6a b - 9a
+--R                      /
+--R                              7         6       2 5        3 4       4 3
+--R                           64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                         + 
+--R                               5 2      6
+--R                           384a b  + 64a b
+--R                + 
+--R                        2      2
+--R                  - 4a b  + 12a b
+--R             *
+--R                ROOT
+--R                              4        3      2 2     3
+--R                         (- 8b  - 24a b  - 24a b  - 8a b)
+--R                      *
+--R                         ROOT
+--R                                   2     2      3
+--R                              - a b  + 6a b - 9a
+--R                           /
+--R                                   7         6       2 5        3 4       4 3
+--R                                64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                              + 
+--R                                    5 2      6
+--R                                384a b  + 64a b
+--R                     + 
+--R                                 2
+--R                       - 3a b + a
+--R                  /
+--R                       4        3      2 2     3
+--R                     4b  + 12a b  + 12a b  + 4a b
+--R            + 
+--R                       2
+--R              (a b - 3a )x
+--R     + 
+--R         (- b - a)x
+--R      *
+--R         ROOT
+--R                       4        3      2 2     3
+--R                  (- 8b  - 24a b  - 24a b  - 8a b)
+--R               *
+--R                  ROOT
+--R                            2     2      3
+--R                       - a b  + 6a b - 9a
+--R                    /
+--R                            7         6       2 5        3 4       4 3       5 2
+--R                         64b  + 384a b  + 960a b  + 1280a b  + 960a b  + 384a b
+--R                       + 
+--R                            6
+--R                         64a b
+--R              + 
+--R                          2
+--R                - 3a b + a
+--R           /
+--R                4        3      2 2     3
+--R              4b  + 12a b  + 12a b  + 4a b
+--R      *
+--R         log
+--R                          5        4      3 2      4
+--R                    (- 16b  - 32a b  + 32a b  + 16a b)
+--R                 *
+--R                    ROOT
+--R                              2     2      3
+--R                         - a b  + 6a b - 9a
+--R                      /
+--R                              7         6       2 5        3 4       4 3
+--R                           64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                         + 
+--R                               5 2      6
+--R                           384a b  + 64a b
+--R                + 
+--R                      2      2
+--R                  4a b  - 12a b
+--R             *
+--R                ROOT
+--R                              4        3      2 2     3
+--R                         (- 8b  - 24a b  - 24a b  - 8a b)
+--R                      *
+--R                         ROOT
+--R                                   2     2      3
+--R                              - a b  + 6a b - 9a
+--R                           /
+--R                                   7         6       2 5        3 4       4 3
+--R                                64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                              + 
+--R                                    5 2      6
+--R                                384a b  + 64a b
+--R                     + 
+--R                                 2
+--R                       - 3a b + a
+--R                  /
+--R                       4        3      2 2     3
+--R                     4b  + 12a b  + 12a b  + 4a b
+--R            + 
+--R                       2
+--R              (a b - 3a )x
+--R     + 
+--R         (b + a)x
+--R      *
+--R         ROOT
+--R                     4        3      2 2     3
+--R                  (8b  + 24a b  + 24a b  + 8a b)
+--R               *
+--R                  ROOT
+--R                            2     2      3
+--R                       - a b  + 6a b - 9a
+--R                    /
+--R                            7         6       2 5        3 4       4 3       5 2
+--R                         64b  + 384a b  + 960a b  + 1280a b  + 960a b  + 384a b
+--R                       + 
+--R                            6
+--R                         64a b
+--R              + 
+--R                          2
+--R                - 3a b + a
+--R           /
+--R                4        3      2 2     3
+--R              4b  + 12a b  + 12a b  + 4a b
+--R      *
+--R         log
+--R                          5        4      3 2      4
+--R                    (- 16b  - 32a b  + 32a b  + 16a b)
+--R                 *
+--R                    ROOT
+--R                              2     2      3
+--R                         - a b  + 6a b - 9a
+--R                      /
+--R                              7         6       2 5        3 4       4 3
+--R                           64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                         + 
+--R                               5 2      6
+--R                           384a b  + 64a b
+--R                + 
+--R                        2      2
+--R                  - 4a b  + 12a b
+--R             *
+--R                ROOT
+--R                            4        3      2 2     3
+--R                         (8b  + 24a b  + 24a b  + 8a b)
+--R                      *
+--R                         ROOT
+--R                                   2     2      3
+--R                              - a b  + 6a b - 9a
+--R                           /
+--R                                   7         6       2 5        3 4       4 3
+--R                                64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                              + 
+--R                                    5 2      6
+--R                                384a b  + 64a b
+--R                     + 
+--R                                 2
+--R                       - 3a b + a
+--R                  /
+--R                       4        3      2 2     3
+--R                     4b  + 12a b  + 12a b  + 4a b
+--R            + 
+--R                       2
+--R              (a b - 3a )x
+--R     + 
+--R       - 2
+--R  /
+--R     (2b + 2a)x
+--R                                         Type: Union(Expression(Integer),...)
+--E 972
+
+--S 973 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +---------------+
+--R                   +-+ |   +-+    +---+
+--R         (- b - a)\|b \|- \|b  + \|- a
+--R      *
+--R         ROOT
+--R                     4        3      2 2     3
+--R                  (8b  + 24a b  + 24a b  + 8a b)
+--R               *
+--R                  ROOT
+--R                            2     2      3
+--R                       - a b  + 6a b - 9a
+--R                    /
+--R                            7         6       2 5        3 4       4 3       5 2
+--R                         64b  + 384a b  + 960a b  + 1280a b  + 960a b  + 384a b
+--R                       + 
+--R                            6
+--R                         64a b
+--R              + 
+--R                          2
+--R                - 3a b + a
+--R           /
+--R                4        3      2 2     3
+--R              4b  + 12a b  + 12a b  + 4a b
+--R      *
+--R          +-------------+
+--R          | +-+    +---+
+--R         \|\|b  + \|- a
+--R      *
+--R         log
+--R                        5        4      3 2      4
+--R                    (16b  + 32a b  - 32a b  - 16a b)
+--R                 *
+--R                    ROOT
+--R                              2     2      3
+--R                         - a b  + 6a b - 9a
+--R                      /
+--R                              7         6       2 5        3 4       4 3
+--R                           64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                         + 
+--R                               5 2      6
+--R                           384a b  + 64a b
+--R                + 
+--R                      2      2
+--R                  4a b  - 12a b
+--R             *
+--R                ROOT
+--R                            4        3      2 2     3
+--R                         (8b  + 24a b  + 24a b  + 8a b)
+--R                      *
+--R                         ROOT
+--R                                   2     2      3
+--R                              - a b  + 6a b - 9a
+--R                           /
+--R                                   7         6       2 5        3 4       4 3
+--R                                64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                              + 
+--R                                    5 2      6
+--R                                384a b  + 64a b
+--R                     + 
+--R                                 2
+--R                       - 3a b + a
+--R                  /
+--R                       4        3      2 2     3
+--R                     4b  + 12a b  + 12a b  + 4a b
+--R            + 
+--R                       2
+--R              (a b - 3a )x
+--R     + 
+--R                     +---------------+
+--R                 +-+ |   +-+    +---+
+--R         (b + a)\|b \|- \|b  + \|- a
+--R      *
+--R         ROOT
+--R                       4        3      2 2     3
+--R                  (- 8b  - 24a b  - 24a b  - 8a b)
+--R               *
+--R                  ROOT
+--R                            2     2      3
+--R                       - a b  + 6a b - 9a
+--R                    /
+--R                            7         6       2 5        3 4       4 3       5 2
+--R                         64b  + 384a b  + 960a b  + 1280a b  + 960a b  + 384a b
+--R                       + 
+--R                            6
+--R                         64a b
+--R              + 
+--R                          2
+--R                - 3a b + a
+--R           /
+--R                4        3      2 2     3
+--R              4b  + 12a b  + 12a b  + 4a b
+--R      *
+--R          +-------------+
+--R          | +-+    +---+
+--R         \|\|b  + \|- a
+--R      *
+--R         log
+--R                        5        4      3 2      4
+--R                    (16b  + 32a b  - 32a b  - 16a b)
+--R                 *
+--R                    ROOT
+--R                              2     2      3
+--R                         - a b  + 6a b - 9a
+--R                      /
+--R                              7         6       2 5        3 4       4 3
+--R                           64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                         + 
+--R                               5 2      6
+--R                           384a b  + 64a b
+--R                + 
+--R                        2      2
+--R                  - 4a b  + 12a b
+--R             *
+--R                ROOT
+--R                              4        3      2 2     3
+--R                         (- 8b  - 24a b  - 24a b  - 8a b)
+--R                      *
+--R                         ROOT
+--R                                   2     2      3
+--R                              - a b  + 6a b - 9a
+--R                           /
+--R                                   7         6       2 5        3 4       4 3
+--R                                64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                              + 
+--R                                    5 2      6
+--R                                384a b  + 64a b
+--R                     + 
+--R                                 2
+--R                       - 3a b + a
+--R                  /
+--R                       4        3      2 2     3
+--R                     4b  + 12a b  + 12a b  + 4a b
+--R            + 
+--R                       2
+--R              (a b - 3a )x
+--R     + 
+--R                       +---------------+
+--R                   +-+ |   +-+    +---+
+--R         (- b - a)\|b \|- \|b  + \|- a
+--R      *
+--R         ROOT
+--R                       4        3      2 2     3
+--R                  (- 8b  - 24a b  - 24a b  - 8a b)
+--R               *
+--R                  ROOT
+--R                            2     2      3
+--R                       - a b  + 6a b - 9a
+--R                    /
+--R                            7         6       2 5        3 4       4 3       5 2
+--R                         64b  + 384a b  + 960a b  + 1280a b  + 960a b  + 384a b
+--R                       + 
+--R                            6
+--R                         64a b
+--R              + 
+--R                          2
+--R                - 3a b + a
+--R           /
+--R                4        3      2 2     3
+--R              4b  + 12a b  + 12a b  + 4a b
+--R      *
+--R          +-------------+
+--R          | +-+    +---+
+--R         \|\|b  + \|- a
+--R      *
+--R         log
+--R                          5        4      3 2      4
+--R                    (- 16b  - 32a b  + 32a b  + 16a b)
+--R                 *
+--R                    ROOT
+--R                              2     2      3
+--R                         - a b  + 6a b - 9a
+--R                      /
+--R                              7         6       2 5        3 4       4 3
+--R                           64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                         + 
+--R                               5 2      6
+--R                           384a b  + 64a b
+--R                + 
+--R                      2      2
+--R                  4a b  - 12a b
+--R             *
+--R                ROOT
+--R                              4        3      2 2     3
+--R                         (- 8b  - 24a b  - 24a b  - 8a b)
+--R                      *
+--R                         ROOT
+--R                                   2     2      3
+--R                              - a b  + 6a b - 9a
+--R                           /
+--R                                   7         6       2 5        3 4       4 3
+--R                                64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                              + 
+--R                                    5 2      6
+--R                                384a b  + 64a b
+--R                     + 
+--R                                 2
+--R                       - 3a b + a
+--R                  /
+--R                       4        3      2 2     3
+--R                     4b  + 12a b  + 12a b  + 4a b
+--R            + 
+--R                       2
+--R              (a b - 3a )x
+--R     + 
+--R                     +---------------+
+--R                 +-+ |   +-+    +---+
+--R         (b + a)\|b \|- \|b  + \|- a
+--R      *
+--R         ROOT
+--R                     4        3      2 2     3
+--R                  (8b  + 24a b  + 24a b  + 8a b)
+--R               *
+--R                  ROOT
+--R                            2     2      3
+--R                       - a b  + 6a b - 9a
+--R                    /
+--R                            7         6       2 5        3 4       4 3       5 2
+--R                         64b  + 384a b  + 960a b  + 1280a b  + 960a b  + 384a b
+--R                       + 
+--R                            6
+--R                         64a b
+--R              + 
+--R                          2
+--R                - 3a b + a
+--R           /
+--R                4        3      2 2     3
+--R              4b  + 12a b  + 12a b  + 4a b
+--R      *
+--R          +-------------+
+--R          | +-+    +---+
+--R         \|\|b  + \|- a
+--R      *
+--R         log
+--R                          5        4      3 2      4
+--R                    (- 16b  - 32a b  + 32a b  + 16a b)
+--R                 *
+--R                    ROOT
+--R                              2     2      3
+--R                         - a b  + 6a b - 9a
+--R                      /
+--R                              7         6       2 5        3 4       4 3
+--R                           64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                         + 
+--R                               5 2      6
+--R                           384a b  + 64a b
+--R                + 
+--R                        2      2
+--R                  - 4a b  + 12a b
+--R             *
+--R                ROOT
+--R                            4        3      2 2     3
+--R                         (8b  + 24a b  + 24a b  + 8a b)
+--R                      *
+--R                         ROOT
+--R                                   2     2      3
+--R                              - a b  + 6a b - 9a
+--R                           /
+--R                                   7         6       2 5        3 4       4 3
+--R                                64b  + 384a b  + 960a b  + 1280a b  + 960a b
+--R                              + 
+--R                                    5 2      6
+--R                                384a b  + 64a b
+--R                     + 
+--R                                 2
+--R                       - 3a b + a
+--R                  /
+--R                       4        3      2 2     3
+--R                     4b  + 12a b  + 12a b  + 4a b
+--R            + 
+--R                       2
+--R              (a b - 3a )x
+--R     + 
+--R                                   +-------------+            4+---+
+--R        4+---+ +-+    +---+4+---+  | +-+    +---+            x\|- a
+--R       (\|- a \|b  + \|- a \|- a )\|\|b  + \|- a  atan(------------------)
+--R                                                        +---------------+
+--R                                                        |   +-+    +---+
+--R                                                       \|- \|b  + \|- a
+--R     + 
+--R                                   +---------------+           4+---+
+--R        4+---+ +-+    +---+4+---+  |   +-+    +---+           x\|- a
+--R       (\|- a \|b  - \|- a \|- a )\|- \|b  + \|- a  atan(----------------)
+--R                                                          +-------------+
+--R                                                          | +-+    +---+
+--R                                                         \|\|b  + \|- a
+--R  /
+--R                   +---------------+ +-------------+
+--R               +-+ |   +-+    +---+  | +-+    +---+
+--R     (2b + 2a)\|b \|- \|b  + \|- a  \|\|b  + \|- a
+--R                                                    Type: Expression(Integer)
+--E 973
+
+--S 974 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 974
+
+)clear all
+
+--S 975 of 1353
+t0:=1/(x^3*(a+b+2*a*x^2+a*x^4))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           7       5           3
+--R        a x  + 2a x  + (b + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 975
+
+--S 976 of 1353
+r0:=(-1/2)/((a+b)*x^2)-2*a*log(x)/(a+b)^2+1/2*a*log(a+b+2*a*x^2+a*x^4)/_
+   (a+b)^2+1/2*(a-b)*atan((1+x^2)*sqrt(a)/sqrt(b))*sqrt(a)/((a+b)^2*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                             2      +-+
+--R                 2 +-+     (x  + 1)\|a
+--R       (- b + a)x \|a atan(------------)
+--R                                +-+
+--R                               \|b
+--R     + 
+--R           2       4       2                2                +-+
+--R       (a x log(a x  + 2a x  + b + a) - 4a x log(x) - b - a)\|b
+--R  /
+--R        2            2  2 +-+
+--R     (2b  + 4a b + 2a )x \|b
+--R                                                    Type: Expression(Integer)
+--E 976
+
+--S 977 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                           +---+
+--R                                   2       |  a       4       2
+--R                   +---+    (- 2b x  - 2b) |- -  + a x  + 2a x  - b + a
+--R                 2 |  a                   \|  b
+--R         (b - a)x  |- - log(-------------------------------------------)
+--R                  \|  b                    4       2
+--R                                        a x  + 2a x  + b + a
+--R       + 
+--R             2       4       2                2
+--R         2a x log(a x  + 2a x  + b + a) - 8a x log(x) - 2b - 2a
+--R    /
+--R          2            2  2
+--R       (4b  + 8a b + 4a )x
+--R     ,
+--R
+--R                               +-+
+--R                               |a
+--R                   +-+       b |-
+--R                 2 |a         \|b         2       4       2
+--R         (b - a)x  |- atan(--------) + a x log(a x  + 2a x  + b + a)
+--R                  \|b         2
+--R                           a x  + a
+--R       + 
+--R               2
+--R         - 4a x log(x) - b - a
+--R    /
+--R          2            2  2
+--R       (2b  + 4a b + 2a )x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 977
+
+--S 978 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                           +---+
+--R                                   2       |  a       4       2
+--R               +---+        (- 2b x  - 2b) |- -  + a x  + 2a x  - b + a
+--R               |  a  +-+                  \|  b
+--R       (b - a) |- - \|b log(-------------------------------------------)
+--R              \|  b                        4       2
+--R                                        a x  + 2a x  + b + a
+--R     + 
+--R                           2      +-+
+--R                 +-+     (x  + 1)\|a
+--R       (2b - 2a)\|a atan(------------)
+--R                              +-+
+--R                             \|b
+--R  /
+--R        2            2  +-+
+--R     (4b  + 8a b + 4a )\|b
+--R                                                    Type: Expression(Integer)
+--E 978
+
+--S 979 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 979
+
+--S 980 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R                                +-+
+--R                                |a
+--R                +-+           b |-                        2      +-+
+--R                |a  +-+        \|b              +-+     (x  + 1)\|a
+--R        (b - a) |- \|b atan(--------) + (b - a)\|a atan(------------)
+--R               \|b             2                             +-+
+--R                            a x  + a                        \|b
+--R   (6)  -------------------------------------------------------------
+--R                               2            2  +-+
+--R                            (2b  + 4a b + 2a )\|b
+--R                                                    Type: Expression(Integer)
+--E 980
+
+--S 981 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 981
+
+)clear all
+
+--S 982 of 1353
+t0:=x^m/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               m
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 982
+
+--S 983 of 1353
+--r0:=x^(1+m)*AppellF1(1/2*(1+m),2,2,1/2*(3+m),-2*c*x^2/(b+sqrt(b^2-4*a*c)),-2*c*x^2/(b-sqrt(b^2-4*a*c)))*(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))^2*(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))^2/((1+m)*(a+b*x^2+c*x^4)^2)
+--E 983
+
+--S 984 of 1353
+--a0:=integrate(t0,x)
+--E 984
+
+--S 985 of 1353
+--m0:=a0-r0
+--E 985
+
+--S 986 of 1353
+--d0:=normalize(D(m0,x))
+--E 986
+
+)clear all
+
+--S 987 of 1353
+t0:=x^7/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               7
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 987
+
+--S 988 of 1353
+r0:=-1/2*b*x^2/(c*(b^2-4*a*c))+1/2*x^4*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+_
+   c*x^4))+1/2*b*(b^2-6*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*_
+   (b^2-4*a*c)^(3/2))+1/4*log(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                  2     3   4         2      4  2      2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x  + 12a b c - 2a b )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 2    2   4              3  2     2       2        4      2
+--R           ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )log(c x  + b x  + a)
+--R         + 
+--R                  2     2   4           2
+--R           (- 4a c  + 2b c)x  + 2a b c x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              4     2 3  4           3     3 2  2      2 3       2 2
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 988
+
+--S 989 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2    3   4        2     4  2     2         3
+--R           ((6a b c  - b c)x  + (6a b c - b )x  + 6a b c - a b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                     2    2   4              3  2     2       2
+--R               ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                         3  2     2        2
+--R             (6a b c - 2b )x  + 4a c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                4     2 3  4           3     3 2  2      2 3       2 2
+--R         ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                      2     3   4           2      4  2      2          3
+--R           ((- 12a b c  + 2b c)x  + (- 12a b c + 2b )x  - 12a b c + 2a b )
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                     2    2   4              3  2     2       2
+--R               ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                         3  2     2        2
+--R             (6a b c - 2b )x  + 4a c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                4     2 3  4           3     3 2  2      2 3       2 2
+--R         ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 989
+
+--S 990 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (6a b c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                     2                       +-----------+
+--R                      3          2c x  + b                2  |          2
+--R       (- 12a b c + 2b )atanh(--------------) + (4a c - 2b )\|- 4a c + b
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                      +-----------+
+--R           3     2 2  |          2
+--R     (16a c  - 4b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 990
+
+--S 991 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 991
+
+--S 992 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+             2
+--R                    3  |        2          2c x  + b
+--R       (- 6a b c + b )\|4a c - b  atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                                                     +---------+
+--R                       +-----------+          2      |        2
+--R                    3  |          2      (2c x  + b)\|4a c - b
+--R       (- 6a b c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                        2
+--R                                                4a c - b
+--R     + 
+--R                   +-----------+ +---------+
+--R                2  |          2  |        2
+--R       (2a c - b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                     +-----------+ +---------+
+--R          3     2 2  |          2  |        2
+--R     (8a c  - 2b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 993
+
+)clear all
+
+--S 994 of 1353
+t0:=x^6/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               6
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 994
+
+--S 995 of 1353
+r0:=-1/2*b*x/(c*(b^2-4*a*c))+1/2*x^3*(2*a+b*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b^2-6*a*c-b*(b^2-8*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*(b^2-6*a*c+b*(b^2-8*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*_
+   (b^2-4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                             +-----------+
+--R                 2    2   4              3  2     2       2  |          2
+--R           ((6a c  - b c)x  + (6a b c - b )x  + 6a c - a b )\|- 4a c + b
+--R         + 
+--R                    2    3   4          2     4  2     2         3
+--R           (- 8a b c  + b c)x  + (- 8a b c + b )x  - 8a b c + a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                                             +-----------+
+--R                 2    2   4              3  2     2       2  |          2
+--R           ((6a c  - b c)x  + (6a b c - b )x  + 6a c - a b )\|- 4a c + b
+--R         + 
+--R                  2    3   4        2     4  2     2         3
+--R           (8a b c  - b c)x  + (8a b c - b )x  + 8a b c - a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                         +--------------------+
+--R                                       +-----------+     |   +-----------+
+--R                     2  3          +-+ |          2  +-+ |   |          2
+--R         ((- 2a c + b )x  + a b x)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R             3     2 2  4          2     3   2     2 2       2   +-+
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|2
+--R    *
+--R                          +--------------------+ +------------------+
+--R        +-----------+     |   +-----------+      | +-----------+
+--R        |          2  +-+ |   |          2       | |          2
+--R       \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 995
+
+--S 996 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3    2 2  4          2    3   2     2 2      2
+--R         ((4a c  - b c )x  + (4a b c  - b c)x  + 4a c  - a b c)
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                           4 7         3 2 6        2 4 5         6 4      8 3
+--R                    (12288a c  - 10240a b c  + 3072a b c  - 384a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                        3   3      2 3 2        5     7
+--R                  - 144a b c  + 88a b c  - 17a b c + b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                 3    2 2  4            2    3   2     2 2      2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c)x  - 4a c  + a b c)
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                           4 7         3 2 6        2 4 5         6 4      8 3
+--R                    (12288a c  - 10240a b c  + 3072a b c  - 384a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                      3   3      2 3 2        5     7
+--R                  144a b c  - 88a b c  + 17a b c - b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R               3    2 2  4          2    3   2     2 2      2
+--R         ((4a c  - b c )x  + (4a b c  - b c)x  + 4a c  - a b c)
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                4 7         3 2 6        2 4 5         6 4
+--R                        - 12288a c  + 10240a b c  - 3072a b c  + 384a b c
+--R                      + 
+--R                             8 3
+--R                        - 16b c
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                        3   3      2 3 2        5     7
+--R                  - 144a b c  + 88a b c  - 17a b c + b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                 3    2 2  4            2    3   2     2 2      2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c)x  - 4a c  + a b c)
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                4 7         3 2 6        2 4 5         6 4
+--R                        - 12288a c  + 10240a b c  - 3072a b c  + 384a b c
+--R                      + 
+--R                             8 3
+--R                        - 16b c
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                      3   3      2 3 2        5     7
+--R                  144a b c  - 88a b c  + 17a b c - b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                  2  3
+--R       (- 2a c + b )x  + a b x
+--R  /
+--R          3     2 2  4          2     3   2     2 2       2
+--R     (8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 996
+
+--S 997 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +--------------------+
+--R                           +-----------+     |   +-----------+
+--R              2    2   +-+ |          2  +-+ |   |          2
+--R         (4a c  - b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                           4 7         3 2 6        2 4 5         6 4      8 3
+--R                    (12288a c  - 10240a b c  + 3072a b c  - 384a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                        3   3      2 3 2        5     7
+--R                  - 144a b c  + 88a b c  - 17a b c + b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                             +-----------+
+--R                2    2   +-+ |          2  +-+
+--R         (- 4a c  + b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                           4 7         3 2 6        2 4 5         6 4      8 3
+--R                    (12288a c  - 10240a b c  + 3072a b c  - 384a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                      3   3      2 3 2        5     7
+--R                  144a b c  - 88a b c  + 17a b c - b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                           +-----------+
+--R              2    2   +-+ |          2  +-+
+--R         (4a c  - b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                4 7         3 2 6        2 4 5         6 4
+--R                        - 12288a c  + 10240a b c  - 3072a b c  + 384a b c
+--R                      + 
+--R                             8 3
+--R                        - 16b c
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                        3   3      2 3 2        5     7
+--R                  - 144a b c  + 88a b c  - 17a b c + b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                                               +--------------------+
+--R                             +-----------+     |   +-----------+
+--R                2    2   +-+ |          2  +-+ |   |          2
+--R         (- 4a c  + b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                4 7         3 2 6        2 4 5         6 4
+--R                        - 12288a c  + 10240a b c  - 3072a b c  + 384a b c
+--R                      + 
+--R                             8 3
+--R                        - 16b c
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                      3   3      2 3 2        5     7
+--R                  144a b c  - 88a b c  + 17a b c - b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                                                     +------------------+
+--R                        +-----------+                | +-----------+
+--R                     2  |          2              3  | |          2
+--R         ((- 6a c + b )\|- 4a c + b   + 8a b c - b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                        +-----------+                |   +-----------+
+--R                     2  |          2              3  |   |          2
+--R         ((- 6a c + b )\|- 4a c + b   - 8a b c + b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                            +--------------------+
+--R                          +-----------+     |   +-----------+
+--R            2     2   +-+ |          2  +-+ |   |          2
+--R       (8a c  - 2b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 998
+
+)clear all
+
+--S 999 of 1353
+t0:=x^5/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               5
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 999
+
+--S 1000 of 1353
+r0:=1/2*x^2*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   2*a*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                               2
+--R                4         2     2          2c x  + b
+--R       (- 4a c x  - 4a b x  - 4a )atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                        +-----------+
+--R             4       2  |          2
+--R       (- b x  - 2a x )\|- 4a c + b
+--R  /
+--R                                                          +-----------+
+--R           2     2   4               3  2     2        2  |          2
+--R     ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+--S 1001 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 4           2     2
+--R           (2a c x  + 2a b c x  + 2a c)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                 +-----------+
+--R                     2  2        |          2
+--R         ((- 2a c + b )x  + a b)\|- 4a c + b
+--R    /
+--R                                                                 +-----------+
+--R             3     2 2  4          2     3   2     2 2       2   |          2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|- 4a c + b
+--R     ,
+--R
+--R                                                      +---------+
+--R                                               2      |        2
+--R              2 4           2     2       (2c x  + b)\|4a c - b
+--R         (4a c x  + 4a b c x  + 4a c)atan(-----------------------)
+--R                                                         2
+--R                                                 4a c - b
+--R       + 
+--R                                 +---------+
+--R                     2  2        |        2
+--R         ((- 2a c + b )x  + a b)\|4a c - b
+--R    /
+--R                                                                 +---------+
+--R             3     2 2  4          2     3   2     2 2       2   |        2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1001
+
+--S 1002 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         2a c
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                         2            +-----------+
+--R                     2c x  + b        |          2
+--R       4a c atanh(--------------) + b\|- 4a c + b
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R          2     2   |          2
+--R     (8a c  - 2b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+--S 1003 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1003
+
+--S 1004 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            +---------+             2
+--R            |        2          2c x  + b
+--R       4a c\|4a c - b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                          +---------+
+--R            +-----------+          2      |        2
+--R            |          2      (2c x  + b)\|4a c - b
+--R       4a c\|- 4a c + b  atan(-----------------------)
+--R                                             2
+--R                                     4a c - b
+--R     + 
+--R         +-----------+ +---------+
+--R         |          2  |        2
+--R       b\|- 4a c + b  \|4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R          2     2   |          2  |        2
+--R     (8a c  - 2b c)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1004
+
+--S 1005 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1005
+
+)clear all
+
+--S 1006 of 1353
+t0:=x^4/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               4
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1006
+
+--S 1007 of 1353
+r0:=1/2*x*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+(-b^2-4*a*c)/sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^2+4*a*c+b*sqrt(b^2-_
+   4*a*c))/((b^2-4*a*c)^(3/2)*sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                   +-----------+
+--R                   4    2 2        |          2         2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (4a c  + b c)x
+--R         + 
+--R                      3  2     2       2
+--R           (4a b c + b )x  + 4a c + a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2           2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (- 4a c  - b c)x
+--R         + 
+--R                        3  2     2       2
+--R           (- 4a b c - b )x  - 4a c - a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                               +--------------------+
+--R                             +-----------+     |   +-----------+
+--R               3         +-+ |          2  +-+ |   |          2
+--R         (- b x  - 2a x)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                                                                +-----------+
+--R             2     2   4               3  2     2        2  +-+ |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2 \|- 4a c + b
+--R    *
+--R            +--------------------+ +------------------+
+--R            |   +-----------+      | +-----------+
+--R        +-+ |   |          2       | |          2
+--R       \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1007
+
+--S 1008 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     2 2        2      4
+--R                  32a c  - 16a b c + 2b
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       2 2        2      4
+--R                  - 32a c  + 16a b c - 2b
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     2 2        2      4
+--R                  32a c  - 16a b c + 2b
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       2 2        2      4
+--R                  - 32a c  + 16a b c - 2b
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R            3
+--R       - b x  - 2a x
+--R  /
+--R          2     2   4               3  2     2        2
+--R     (8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1008
+
+--S 1009 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +--------------------+
+--R                         +-----------+     |   +-----------+
+--R                  2  +-+ |          2  +-+ |   |          2
+--R         (4a c - b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     2 2        2      4
+--R                  32a c  - 16a b c + 2b
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                           +-----------+
+--R                    2  +-+ |          2  +-+
+--R         (- 4a c + b )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       2 2        2      4
+--R                  - 32a c  + 16a b c - 2b
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                         +-----------+
+--R                  2  +-+ |          2  +-+
+--R         (4a c - b )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     2 2        2      4
+--R                  32a c  - 16a b c + 2b
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                                             +--------------------+
+--R                           +-----------+     |   +-----------+
+--R                    2  +-+ |          2  +-+ |   |          2
+--R         (- 4a c + b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       2 2        2      4
+--R                  - 32a c  + 16a b c - 2b
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                                       +------------------+
+--R            +-----------+              | +-----------+
+--R            |          2            2  | |          2
+--R         (b\|- 4a c + b   - 4a c - b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                       +--------------------+
+--R            +-----------+              |   +-----------+
+--R            |          2            2  |   |          2
+--R         (b\|- 4a c + b   + 4a c + b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                          +--------------------+
+--R                        +-----------+     |   +-----------+
+--R                 2  +-+ |          2  +-+ |   |          2
+--R       (8a c - 2b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1009
+
+--S 1010 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1010
+
+)clear all
+
+--S 1011 of 1353
+t0:=x^3/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               3
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1011
+
+--S 1012 of 1353
+r0:=1/2*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-b*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                        2                        +-----------+
+--R          4     2 2                 2c x  + b            2       |          2
+--R   (2b c x  + 2b x  + 2a b)atanh(--------------) + (- b x  - 2a)\|- 4a c + b
+--R                                  +-----------+
+--R                                  |          2
+--R                                 \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                                             +-----------+
+--R              2     2   4               3  2     2        2  |          2
+--R        ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1012
+
+--S 1013 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 4    2 2
+--R           (b c x  + b x  + a b)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                       +-----------+
+--R               2       |          2
+--R         (- b x  - 2a)\|- 4a c + b
+--R    /
+--R                                                            +-----------+
+--R             2     2   4               3  2     2        2  |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R     ,
+--R
+--R                                                    +---------+
+--R                                             2      |        2
+--R                  4     2 2             (2c x  + b)\|4a c - b
+--R         (- 2b c x  - 2b x  - 2a b)atan(-----------------------)
+--R                                                       2
+--R                                               4a c - b
+--R       + 
+--R                       +---------+
+--R               2       |        2
+--R         (- b x  - 2a)\|4a c - b
+--R    /
+--R                                                            +---------+
+--R             2     2   4               3  2     2        2  |        2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1013
+
+--S 1014 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                         2
+--R                     2c x  + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R                  +-----------+
+--R               2  |          2
+--R     (8a c - 2b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1014
+
+--S 1015 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1015
+
+--S 1016 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             2
+--R           |        2          2c x  + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          2      |        2
+--R           |          2      (2c x  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1016
+
+--S 1017 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1017
+
+)clear all
+
+--S 1018 of 1353
+t0:=x^2/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               2
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1018
+
+--S 1019 of 1353
+r0:=-1/2*x*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(2*b-sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(2*b+sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                               +-----------+
+--R               4       2       |          2          4     2 2         +-+
+--R         ((2c x  + 2b x  + 2a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                               +-----------+
+--R               4       2       |          2          4     2 2         +-+
+--R         ((2c x  + 2b x  + 2a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                     +--------------------+ +------------------+
+--R                       +-----------+ |   +-----------+      | +-----------+
+--R          3        +-+ |          2  |   |          2       | |          2
+--R     (2c x  + b x)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                                +-----------+
+--R             2     2   4               3  2     2        2  +-+ |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2 \|- 4a c + b
+--R    *
+--R        +--------------------+ +------------------+
+--R        |   +-----------+      | +-----------+
+--R        |   |          2       | |          2
+--R       \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1019
+
+--S 1020 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                       2   2       3     5
+--R                  - 16a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                     2   2       3     5
+--R                  16a b c  - 8a b c + b
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                       2   2       3     5
+--R                  - 16a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                     2   2       3     5
+--R                  16a b c  - 8a b c + b
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R           3
+--R       2c x  + b x
+--R  /
+--R          2     2   4               3  2     2        2
+--R     (8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1020
+
+--S 1021 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       +--------------------+
+--R                         +-----------+ |   +-----------+
+--R                  2  +-+ |          2  |   |          2
+--R         (4a c - b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                       2   2       3     5
+--R                  - 16a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                           +-----------+
+--R                    2  +-+ |          2
+--R         (- 4a c + b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                     2   2       3     5
+--R                  16a b c  - 8a b c + b
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                         +-----------+
+--R                  2  +-+ |          2
+--R         (4a c - b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                       2   2       3     5
+--R                  - 16a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R                    2  +-+ |          2  |   |          2
+--R         (- 4a c + b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                     2   2       3     5
+--R                  16a b c  - 8a b c + b
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                                      +------------------+
+--R              +-----------+           | +-----------+
+--R              |          2        +-+ | |          2
+--R         (- 2\|- 4a c + b   + 4b)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                      +--------------------+
+--R              +-----------+           |   +-----------+
+--R              |          2        +-+ |   |          2
+--R         (- 2\|- 4a c + b   - 4b)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                    +--------------------+ +------------------+
+--R                      +-----------+ |   +-----------+      | +-----------+
+--R               2  +-+ |          2  |   |          2       | |          2
+--R     (8a c - 2b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1021
+
+--S 1022 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1022
+
+)clear all
+
+--S 1023 of 1353
+t0:=x/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1023
+
+--S 1024 of 1353
+r0:=1/2*(-b-2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+2*c*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                          2                      +-----------+
+--R        2 4         2                 2c x  + b           2      |          2
+--R   (- 4c x  - 4b c x  - 4a c)atanh(--------------) + (2c x  + b)\|- 4a c + b
+--R                                    +-----------+
+--R                                    |          2
+--R                                   \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                                             +-----------+
+--R              2     2   4               3  2     2        2  |          2
+--R        ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1024
+
+--S 1025 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              2 4         2
+--R           (2c x  + 2b c x  + 2a c)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                     +-----------+
+--R              2      |          2
+--R         (2c x  + b)\|- 4a c + b
+--R    /
+--R                                                            +-----------+
+--R             2     2   4               3  2     2        2  |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R     ,
+--R
+--R                                                  +---------+
+--R                                           2      |        2
+--R            2 4         2             (2c x  + b)\|4a c - b
+--R         (4c x  + 4b c x  + 4a c)atan(-----------------------)
+--R                                                     2
+--R                                             4a c - b
+--R       + 
+--R                     +---------+
+--R              2      |        2
+--R         (2c x  + b)\|4a c - b
+--R    /
+--R                                                            +---------+
+--R             2     2   4               3  2     2        2  |        2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1025
+
+--S 1026 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         c
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                       2
+--R                   2c x  + b
+--R       2c atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R              2  |          2
+--R     (4a c - b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1026
+
+--S 1027 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1027
+
+--S 1028 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +---------+             2
+--R          |        2          2c x  + b
+--R       2c\|4a c - b  atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                        +---------+
+--R          +-----------+          2      |        2
+--R          |          2      (2c x  + b)\|4a c - b
+--R       2c\|- 4a c + b  atan(-----------------------)
+--R                                           2
+--R                                   4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1028
+
+--S 1029 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1029
+
+)clear all
+
+--S 1030 of 1353
+t0:=1/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1030
+
+--S 1031 of 1353
+r0:=1/2*x*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b+(b^2-_
+   12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (b+(-b^2+12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                   +-----------+
+--R                   4    2 2        |          2          2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (12a c  - b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c - b )x  + 12a c - a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2            2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (- 12a c  + b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c + b )x  - 12a c + a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R                 3            2    +-+ |          2  |   |          2
+--R         (- b c x  + (2a c - b )x)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R           2 2       2   4      2          3  2     3      2 2  +-+
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1031
+
+--S 1032 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 2      2   4      2         3  2     3     2 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      4 4       3 2 3       2 4 2        6     8
+--R                  864a c  - 672a b c  + 190a b c  - 23a b c + b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R               2 2      2   4        2         3  2     3     2 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        4 4       3 2 3       2 4 2        6     8
+--R                  - 864a c  + 672a b c  - 190a b c  + 23a b c - b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R             2 2      2   4      2         3  2     3     2 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      4 4       3 2 3       2 4 2        6     8
+--R                  864a c  - 672a b c  + 190a b c  - 23a b c + b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R               2 2      2   4        2         3  2     3     2 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        4 4       3 2 3       2 4 2        6     8
+--R                  - 864a c  + 672a b c  - 190a b c  + 23a b c - b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R              3            2
+--R       - b c x  + (2a c - b )x
+--R  /
+--R        2 2       2   4      2          3  2     3      2 2
+--R     (8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1032
+
+--S 1033 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            2       2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      4 4       3 2 3       2 4 2        6     8
+--R                  864a c  - 672a b c  + 190a b c  - 23a b c + b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R                             +-----------+
+--R              2       2  +-+ |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        4 4       3 2 3       2 4 2        6     8
+--R                  - 864a c  + 672a b c  - 190a b c  + 23a b c - b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R                           +-----------+
+--R            2       2  +-+ |          2
+--R         (4a c - a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      4 4       3 2 3       2 4 2        6     8
+--R                  864a c  - 672a b c  + 190a b c  - 23a b c + b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              2       2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        4 4       3 2 3       2 4 2        6     8
+--R                  - 864a c  + 672a b c  - 190a b c  + 23a b c - b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R                                            +------------------+
+--R            +-----------+                   | +-----------+
+--R            |          2             2  +-+ | |          2
+--R         (b\|- 4a c + b   - 12a c + b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R            +-----------+                   |   +-----------+
+--R            |          2             2  +-+ |   |          2
+--R         (b\|- 4a c + b   + 12a c - b )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R          2        2  +-+ |          2  |   |          2
+--R       (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1033
+
+--S 1034 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1034
+
+)clear all
+
+--S 1035 of 1353
+t0:=1/(x*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R         2 9         7            2  5         3    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1035
+
+--S 1036 of 1353
+r0:=1/2*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*b*(b^2-_
+   6*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^(3/2))+_
+   log(x)/a^2-1/4*log(a+b*x^2+c*x^4)/a^2
+--R 
+--R
+--R   (2)
+--R                  2     3   4         2      4  2      2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x  + 12a b c - 2a b )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    2   4                3  2     2       2
+--R             ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                  2     2   4                3  2      2        2
+--R           ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )log(x)
+--R         + 
+--R                     2     2        2
+--R           - 2a b c x  + 4a c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                 +-----------+
+--R          3 2     2 2   4       3        2 3  2      4      3 2  |          2
+--R     ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1036
+
+--S 1037 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2    3   4        2     4  2     2         3
+--R           ((6a b c  - b c)x  + (6a b c - b )x  + 6a b c - a b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                       2    2   4                3  2     2       2
+--R               ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                    2     2   4                3  2      2        2
+--R             ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )log(x)
+--R           + 
+--R                       2     2        2
+--R             - 2a b c x  + 4a c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                                   +-----------+
+--R            3 2     2 2   4       3        2 3  2      4      3 2  |          2
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|- 4a c + b
+--R     ,
+--R
+--R                      2     3   4           2      4  2      2          3
+--R           ((- 12a b c  + 2b c)x  + (- 12a b c + 2b )x  - 12a b c + 2a b )
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2    2   4                3  2     2       2
+--R               ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                    2     2   4                3  2      2        2
+--R             ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )log(x)
+--R           + 
+--R                       2     2        2
+--R             - 2a b c x  + 4a c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                   +---------+
+--R            3 2     2 2   4       3        2 3  2      4      3 2  |        2
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1037
+
+--S 1038 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (6a b c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                     2
+--R                      3          2c x  + b
+--R       (- 12a b c + 2b )atanh(--------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                     +-----------+
+--R         3      2 2  |          2
+--R     (16a c - 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1038
+
+--S 1039 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1039
+
+--S 1040 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+             2
+--R                    3  |        2          2c x  + b
+--R       (- 6a b c + b )\|4a c - b  atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                                                     +---------+
+--R                       +-----------+          2      |        2
+--R                    3  |          2      (2c x  + b)\|4a c - b
+--R       (- 6a b c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                        2
+--R                                                4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R        3      2 2  |          2  |        2
+--R     (8a c - 2a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1040
+
+--S 1041 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1041
+
+)clear all
+
+--S 1042 of 1353
+t0:=1/(x^2*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R         2 10         8            2  6         4    2 2
+--R        c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1042
+
+--S 1043 of 1353
+r0:=1/2*(-3*b^2+10*a*c)/(a^2*(b^2-4*a*c)*x)+1/2*(b^2-2*a*c+b*c*x^2)/_
+   (a*(b^2-4*a*c)*x*(a+b*x^2+c*x^4))-1/2*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2-10*a*c+b*(3*b^2-16*a*c)/_
+   sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2-_
+   10*a*c+(-3*b^3+16*a*b*c)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2     2   5                  3  3         2        2
+--R             ((- 10a c  + 3b c)x  + (- 10a b c + 3b )x  + (- 10a c + 3a b )x)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   5           2      4  3         2          3
+--R           (- 16a b c  + 3b c)x  + (- 16a b c + 3b )x  + (- 16a b c + 3a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2     2   5                  3  3         2        2
+--R             ((- 10a c  + 3b c)x  + (- 10a b c + 3b )x  + (- 10a c + 3a b )x)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   5         2      4  3       2          3
+--R           (16a b c  - 3b c)x  + (16a b c - 3b )x  + (16a b c - 3a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2     2   4                  3  2     2        2  +-+
+--R         ((- 10a c  + 3b c)x  + (- 11a b c + 3b )x  - 8a c + 2a b )\|2
+--R      *
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2  |   |          2       | |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R           3 2     2 2   5      3        2 3  3      4      3 2    +-+
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x)\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1043
+
+--S 1044 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 2    2 2   5        3       2 3  3        4     3 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  + (- 4a c + a b )x)
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5         4 3 4         3 5 3        2 7 2         9
+--R                  5200a b c  - 14408a b c  + 10549a b c  - 3330a b c  + 486a b c
+--R                + 
+--R                       11
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R             3 2    2 2   5      3       2 3  3      4     3 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                + 
+--R                          9       11
+--R                  - 486a b c + 27b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R               3 2    2 2   5        3       2 3  3        4     3 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  + (- 4a c + a b )x)
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5         4 3 4         3 5 3        2 7 2         9
+--R                  5200a b c  - 14408a b c  + 10549a b c  - 3330a b c  + 486a b c
+--R                + 
+--R                       11
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R             3 2    2 2   5      3       2 3  3      4     3 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                + 
+--R                          9       11
+--R                  - 486a b c + 27b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R               2     2   4                  3  2     2        2
+--R       (- 10a c  + 3b c)x  + (- 11a b c + 3b )x  - 8a c + 2a b
+--R  /
+--R        3 2     2 2   5      3        2 3  3      4      3 2
+--R     (8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1044
+
+--S 1045 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              3     2 2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5         4 3 4         3 5 3        2 7 2         9
+--R                  5200a b c  - 14408a b c  + 10549a b c  - 3330a b c  + 486a b c
+--R                + 
+--R                       11
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R                           +-----------+
+--R            3     2 2  +-+ |          2
+--R         (4a c - a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                + 
+--R                          9       11
+--R                  - 486a b c + 27b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R                             +-----------+
+--R              3     2 2  +-+ |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5         4 3 4         3 5 3        2 7 2         9
+--R                  5200a b c  - 14408a b c  + 10549a b c  - 3330a b c  + 486a b c
+--R                + 
+--R                       11
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            3     2 2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                + 
+--R                          9       11
+--R                  - 486a b c + 27b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R                                                           +------------------+
+--R                        +-----------+                      | +-----------+
+--R                     2  |          2                3  +-+ | |          2
+--R         ((10a c - 3b )\|- 4a c + b   + 16a b c - 3b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                        +-----------+
+--R                     2  |          2                3  +-+
+--R         ((10a c - 3b )\|- 4a c + b   - 16a b c + 3b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R          3      2 2  +-+ |          2  |   |          2
+--R       (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1045
+
+--S 1046 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1046
+
+)clear all
+
+--S 1047 of 1353
+t0:=1/(x^3*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R         2 11         9            2  7         5    2 3
+--R        c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1047
+
+--S 1048 of 1353
+r0:=(-b^2+3*a*c)/(a^2*(b^2-4*a*c)*x^2)+1/2*(b^2-2*a*c+b*c*x^2)/_
+   (a*(b^2-4*a*c)*x^2*(a+b*x^2+c*x^4))-(b^4-6*a*b^2*c+6*a^2*c^2)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(3/2))-_
+   2*b*log(x)/a^3+1/2*b*log(a+b*x^2+c*x^4)/a^3
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   6       2   2        3      5  4
+--R           (12a c  - 12a b c  + 2b c)x  + (12a b c  - 12a b c + 2b )x
+--R         + 
+--R               3 2      2 2        4  2
+--R           (12a c  - 12a b c + 2a b )x
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    3   6        2     4  4      2         3  2
+--R             ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)x  + (- 16a b c + 4b )x
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R                2 2       2   4        2          3  2     3     2 2
+--R           (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x  - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                  +-----------+
+--R         4 2     3 2   6      4        3 3  4      5      4 2  2  |          2
+--R     ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1048
+
+--S 1049 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3       2 2    4   6      2   2       3     5  4
+--R             (6a c  - 6a b c  + b c)x  + (6a b c  - 6a b c + b )x
+--R           + 
+--R                3 2     2 2       4  2
+--R             (6a c  - 6a b c + a b )x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                       2    3   6        2     4  4      2         3  2
+--R               ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)x  + (- 16a b c + 4b )x
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                  2 2       2   4        2          3  2     3     2 2
+--R             (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x  - 4a c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             4 2     3 2   6      4        3 3  4      5      4 2  2
+--R         ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2 3        2 2     4   6         2   2        3      5  4
+--R             (- 12a c  + 12a b c  - 2b c)x  + (- 12a b c  + 12a b c - 2b )x
+--R           + 
+--R                   3 2      2 2        4  2
+--R             (- 12a c  + 12a b c - 2a b )x
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2    3   6        2     4  4      2         3  2
+--R               ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)x  + (- 16a b c + 4b )x
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                  2 2       2   4        2          3  2     3     2 2
+--R             (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x  - 4a c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                    +---------+
+--R           4 2     3 2   6      4        3 3  4      5      4 2  2  |        2
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1049
+
+--S 1050 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (6a c  - 6a b c + b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                              2
+--R             2 2        2      4          2c x  + b
+--R       (- 12a c  + 12a b c - 2b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R        4      3 2  |          2
+--R     (8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1050
+
+--S 1051 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1051
+
+--S 1052 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                               +---------+             2
+--R            2 2       2     4  |        2          2c x  + b
+--R       (- 6a c  + 6a b c - b )\|4a c - b  atanh(--------------)
+--R                                                 +-----------+
+--R                                                 |          2
+--R                                                \|- 4a c + b
+--R     + 
+--R                                                             +---------+
+--R                               +-----------+          2      |        2
+--R            2 2       2     4  |          2      (2c x  + b)\|4a c - b
+--R       (- 6a c  + 6a b c - b )\|- 4a c + b  atan(-----------------------)
+--R                                                                2
+--R                                                        4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R        4     3 2  |          2  |        2
+--R     (4a c - a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1052
+
+--S 1053 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1053
+
+)clear all
+
+--S 1054 of 1353
+t0:=1/(x^4*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                1
+--R   (1)  -------------------------------------------------
+--R         2 12         10            2  8         6    2 4
+--R        c x   + 2b c x   + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1054
+
+--S 1055 of 1353
+r0:=1/6*(-5*b^2+14*a*c)/(a^2*(b^2-4*a*c)*x^3)+1/2*b*(5*b^2-19*a*c)/_
+   (a^3*(b^2-4*a*c)*x)+1/2*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^3*_
+   (a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(5*b^3-19*a*b*c+(5*b^4-29*a*b^2*c+28*a^2*c^2)/sqrt(b^2-4*a*c))/_
+   (a^3*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(5*b^3-19*a*b*c+(-5*b^4+_
+   29*a*b^2*c-28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2      3   7         2       4  5       2           3  3
+--R             ((57a b c  - 15b c)x  + (57a b c - 15b )x  + (57a b c - 15a b )x )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 3        2 2      4   7         2   2        3       5  5
+--R           (- 84a c  + 87a b c  - 15b c)x  + (- 84a b c  + 87a b c - 15b )x
+--R         + 
+--R                 3 2      2 2         4  3
+--R           (- 84a c  + 87a b c - 15a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2      3   7         2       4  5       2           3  3
+--R             ((57a b c  - 15b c)x  + (57a b c - 15b )x  + (57a b c - 15a b )x )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 3        2 2      4   7       2   2        3       5  5
+--R           (84a c  - 87a b c  + 15b c)x  + (84a b c  - 87a b c + 15b )x
+--R         + 
+--R               3 2      2 2         4  3
+--R           (84a c  - 87a b c + 15a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2      3   6         2 2        2       4  4
+--R           (57a b c  - 15b c)x  + (- 14a c  + 62a b c - 15b )x
+--R         + 
+--R               2           3  2     3      2 2
+--R           (40a b c - 10a b )x  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            4 2     3 2   7       4        3 3  5       5      4 2  3  +-+
+--R       ((24a c  - 6a b c)x  + (24a b c - 6a b )x  + (24a c - 6a b )x )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1055
+
+--S 1056 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4 2     3 2   7         4        3 3  5         5      4 2  3
+--R         ((- 12a c  + 3a b c)x  + (- 12a b c + 3a b )x  + (- 12a c + 3a b )x )
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        7 7         6 2 6          5 4 5          4 6 4
+--R                  10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                + 
+--R                        3 8 3         2 10 2          12        14
+--R                  75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R              4 2     3 2   7       4        3 3  5       5      4 2  3
+--R         ((12a c  - 3a b c)x  + (12a b c - 3a b )x  + (12a c - 3a b )x )
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          7 7         6 2 6          5 4 5          4 6 4
+--R                  - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                + 
+--R                          3 8 3         2 10 2          12        14
+--R                  - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R                4 2     3 2   7         4        3 3  5         5      4 2  3
+--R         ((- 12a c  + 3a b c)x  + (- 12a b c + 3a b )x  + (- 12a c + 3a b )x )
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        7 7         6 2 6          5 4 5          4 6 4
+--R                  10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                + 
+--R                        3 8 3         2 10 2          12        14
+--R                  75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R              4 2     3 2   7       4        3 3  5       5      4 2  3
+--R         ((12a c  - 3a b c)x  + (12a b c - 3a b )x  + (12a c - 3a b )x )
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          7 7         6 2 6          5 4 5          4 6 4
+--R                  - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                + 
+--R                          3 8 3         2 10 2          12        14
+--R                  - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R               2      3   6         2 2        2       4  4
+--R       (57a b c  - 15b c)x  + (- 14a c  + 62a b c - 15b )x
+--R     + 
+--R           2           3  2     3      2 2
+--R       (40a b c - 10a b )x  - 8a c + 2a b
+--R  /
+--R         4 2     3 2   7       4        3 3  5       5      4 2  3
+--R     (24a c  - 6a b c)x  + (24a b c - 6a b )x  + (24a c - 6a b )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1056
+
+--S 1057 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              4     3 2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        7 7         6 2 6          5 4 5          4 6 4
+--R                  10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                + 
+--R                        3 8 3         2 10 2          12        14
+--R                  75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            4     3 2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          7 7         6 2 6          5 4 5          4 6 4
+--R                  - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                + 
+--R                          3 8 3         2 10 2          12        14
+--R                  - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              4     3 2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        7 7         6 2 6          5 4 5          4 6 4
+--R                  10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                + 
+--R                        3 8 3         2 10 2          12        14
+--R                  75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            4     3 2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          7 7         6 2 6          5 4 5          4 6 4
+--R                  - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                + 
+--R                          3 8 3         2 10 2          12        14
+--R                  - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4  +-+
+--R         ((- 19a b c + 5b )\|- 4a c + b   + 28a c  - 29a b c + 5b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4  +-+
+--R         ((- 19a b c + 5b )\|- 4a c + b   - 28a c  + 29a b c - 5b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R          4      3 2  +-+ |          2  |   |          2
+--R       (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1057
+
+--S 1058 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1058
+
+)clear all
+
+--S 1059 of 1353
+t0:=x^m/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      m
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1059
+
+--S 1060 of 1353
+--r0:=x^(1+m)*AppellF1(1/2*(1+m),3,3,1/2*(3+m),-2*c*x^2/(b+sqrt(b^2-4*a*c)),-2*c*x^2/(b-sqrt(b^2-4*a*c)))*(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))^3*(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))^3/((1+m)*(a+b*x^2+c*x^4)^3)
+--E 1060
+
+--S 1061 of 1353
+--a0:=integrate(t0,x)
+--E 1061
+
+--S 1062 of 1353
+--m0:=a0-r0
+--E 1062
+
+--S 1063 of 1353
+--d0:=normalize(D(m0,x))
+--E 1063
+
+)clear all
+
+--S 1064 of 1353
+t0:=x^11/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      11
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1064
+
+--S 1065 of 1353
+r0:=-1/2*b*(b^2-7*a*c)*x^2/(c^2*(b^2-4*a*c)^2)+1/4*(b^2-16*a*c)*x^4/(c*_
+   (b^2-4*a*c)^2)+1/4*x^8*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/4*x^6*(6*a*b-(b^2-16*a*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+_
+   1/2*b*(b^4-10*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c^3*(b^2-4*a*c)^(5/2))+1/4*log(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  8        2 2 3        4 2     6   6
+--R           (60a b c  - 20a b c  + 2b c )x  + (120a b c  - 40a b c  + 4b c)x
+--R         + 
+--R                3   3      2 3 2        5      7  4
+--R           (120a b c  + 20a b c  - 16a b c + 2b )x
+--R         + 
+--R                3 2 2      2 4        6  2      4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )x  + 60a b c  - 20a b c + 2a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2 4       2 3    4 2  8       2   3        3 2     5   6
+--R               (16a c  - 8a b c  + b c )x  + (32a b c  - 16a b c  + 2b c)x
+--R             + 
+--R                   3 3       4     6  4       3   2      2 3        5  2
+--R               (32a c  - 6a b c + b )x  + (32a b c  - 16a b c + 2a b )x
+--R             + 
+--R                  4 2     3 2     2 4
+--R               16a c  - 8a b c + a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                 2 4        2 3     4 2  8      2   3        3 2     5   6
+--R           (- 24a c  + 21a b c  - 3b c )x  + (2a b c  + 12a b c  - 2b c)x
+--R         + 
+--R                 3 3      2 2 2       4   4       3   2     2 3   2
+--R           (- 16a c  + 29a b c  - 4a b c)x  + (14a b c  - 2a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 7        2 6     4 5  8        2   6        3 5     5 4  6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R       + 
+--R              3 6        4 4     6 3  4        3   5      2 3 4       5 3  2
+--R         (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R       + 
+--R            4 5      3 2 4     2 4 3
+--R         64a c  - 32a b c  + 4a b c
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1065
+
+--S 1066 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   4        3 3    5 2  8       2 2 3        4 2     6   6
+--R             (30a b c  - 10a b c  + b c )x  + (60a b c  - 20a b c  + 2b c)x
+--R           + 
+--R                 3   3      2 3 2       5     7  4
+--R             (60a b c  + 10a b c  - 8a b c + b )x
+--R           + 
+--R                 3 2 2      2 4        6  2      4   2      3 3     2 5
+--R             (60a b c  - 20a b c + 2a b )x  + 30a b c  - 10a b c + a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                     2 4       2 3    4 2  8       2   3        3 2     5   6
+--R                 (16a c  - 8a b c  + b c )x  + (32a b c  - 16a b c  + 2b c)x
+--R               + 
+--R                     3 3       4     6  4       3   2      2 3        5  2
+--R                 (32a c  - 6a b c + b )x  + (32a b c  - 16a b c + 2a b )x
+--R               + 
+--R                    4 2     3 2     2 4
+--R                 16a c  - 8a b c + a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                 2   3        3 2     5   6
+--R             (50a b c  - 30a b c  + 4b c)x
+--R           + 
+--R                 3 3      2 2 2        4      6  4
+--R             (32a c  + 11a b c  - 19a b c + 3b )x
+--R           + 
+--R                 3   2      2 3        5  2      4 2      3 2      2 4
+--R             (62a b c  - 44a b c + 6a b )x  + 24a c  - 21a b c + 3a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 7        2 6     4 5  8        2   6        3 5     5 4  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 6        4 4     6 3  4        3   5      2 3 4       5 3  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 5      3 2 4     2 4 3
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2   4        3 3     5 2  8
+--R             (- 60a b c  + 20a b c  - 2b c )x
+--R           + 
+--R                    2 2 3        4 2     6   6
+--R             (- 120a b c  + 40a b c  - 4b c)x
+--R           + 
+--R                    3   3      2 3 2        5      7  4
+--R             (- 120a b c  - 20a b c  + 16a b c - 2b )x
+--R           + 
+--R                    3 2 2      2 4        6  2      4   2      3 3      2 5
+--R             (- 120a b c  + 40a b c - 4a b )x  - 60a b c  + 20a b c - 2a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                     2 4       2 3    4 2  8       2   3        3 2     5   6
+--R                 (16a c  - 8a b c  + b c )x  + (32a b c  - 16a b c  + 2b c)x
+--R               + 
+--R                     3 3       4     6  4       3   2      2 3        5  2
+--R                 (32a c  - 6a b c + b )x  + (32a b c  - 16a b c + 2a b )x
+--R               + 
+--R                    4 2     3 2     2 4
+--R                 16a c  - 8a b c + a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                 2   3        3 2     5   6
+--R             (50a b c  - 30a b c  + 4b c)x
+--R           + 
+--R                 3 3      2 2 2        4      6  4
+--R             (32a c  + 11a b c  - 19a b c + 3b )x
+--R           + 
+--R                 3   2      2 3        5  2      4 2      3 2      2 4
+--R             (62a b c  - 44a b c + 6a b )x  + 24a c  - 21a b c + 3a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 7        2 6     4 5  8        2   6        3 5     5 4  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 6        4 4     6 3  4        3   5      2 3 4       5 3  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 5      3 2 4     2 4 3
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1066
+
+--S 1067 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2   2        3     5
+--R         (30a b c  - 10a b c + b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                                2
+--R             2   2        3      5          2c x  + b
+--R       (- 60a b c  + 20a b c - 2b )atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R     + 
+--R                                +-----------+
+--R           2 2        2      4  |          2
+--R       (24a c  - 21a b c + 3b )\|- 4a c + b
+--R  /
+--R                                 +-----------+
+--R         2 5        2 4     4 3  |          2
+--R     (64a c  - 32a b c  + 4b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1067
+
+--S 1068 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1068
+
+--S 1069 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                    +---------+             2
+--R             2   2        3      5  |        2          2c x  + b
+--R       (- 60a b c  + 20a b c - 2b )\|4a c - b  atanh(--------------)
+--R                                                      +-----------+
+--R                                                      |          2
+--R                                                     \|- 4a c + b
+--R     + 
+--R                                                                  +---------+
+--R                                    +-----------+          2      |        2
+--R             2   2        3      5  |          2      (2c x  + b)\|4a c - b
+--R       (- 60a b c  + 20a b c - 2b )\|- 4a c + b  atan(-----------------------)
+--R                                                                     2
+--R                                                             4a c - b
+--R     + 
+--R                                +-----------+ +---------+
+--R           2 2        2      4  |          2  |        2
+--R       (24a c  - 21a b c + 3b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                                 +-----------+ +---------+
+--R         2 5        2 4     4 3  |          2  |        2
+--R     (64a c  - 32a b c  + 4b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1069
+
+--S 1070 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1070
+
+)clear all
+
+--S 1071 of 1353
+t0:=x^10/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      10
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1071
+
+--S 1072 of 1353
+r0:=-3/8*b*(b^2-8*a*c)*x/(c^2*(b^2-4*a*c)^2)+1/8*(b^2-28*a*c)*_
+   x^3/(c*(b^2-4*a*c)^2)+1/4*x^7*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+_
+   c*x^4)^2)+1/8*x^5*(12*a*b-(b^2-28*a*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+_
+   c*x^4))+3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b^4-_
+   9*a*b^2*c+28*a^2*c^2-b*(b^4-11*a*b^2*c+44*a^2*c^2)/sqrt(b^2-4*a*c))/_
+   (c^(5/2)*(b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+3/8*atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^4-9*a*b^2*c+28*a^2*c^2+_
+   b*(b^4-11*a*b^2*c+44*a^2*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*(b^2-4*a*c)^2*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (84a c  - 27a b c  + 3b c )x  + (168a b c  - 54a b c  + 6b c)x
+--R             + 
+--R                    3 3      2 2 2        4      6  4
+--R               (168a c  + 30a b c  - 21a b c + 3b )x
+--R             + 
+--R                    3   2      2 3        5  2      4 2      3 2      2 4
+--R               (168a b c  - 54a b c + 6a b )x  + 84a c  - 27a b c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2   4        3 3     5 2  8
+--R           (- 132a b c  + 33a b c  - 3b c )x
+--R         + 
+--R                  2 2 3        4 2     6   6
+--R           (- 264a b c  + 66a b c  - 6b c)x
+--R         + 
+--R                  3   3      2 3 2        5      7  4
+--R           (- 264a b c  - 66a b c  + 27a b c - 3b )x
+--R         + 
+--R                  3 2 2      2 4        6  2       4   2      3 3      2 5
+--R           (- 264a b c  + 66a b c - 6a b )x  - 132a b c  + 33a b c - 3a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (84a c  - 27a b c  + 3b c )x  + (168a b c  - 54a b c  + 6b c)x
+--R             + 
+--R                    3 3      2 2 2        4      6  4
+--R               (168a c  + 30a b c  - 21a b c + 3b )x
+--R             + 
+--R                    3   2      2 3        5  2      4 2      3 2      2 4
+--R               (168a b c  - 54a b c + 6a b )x  + 84a c  - 27a b c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2   4        3 3     5 2  8        2 2 3        4 2     6   6
+--R           (132a b c  - 33a b c  + 3b c )x  + (264a b c  - 66a b c  + 6b c)x
+--R         + 
+--R                3   3      2 3 2        5      7  4
+--R           (264a b c  + 66a b c  - 27a b c + 3b )x
+--R         + 
+--R                3 2 2      2 4        6  2       4   2      3 3      2 5
+--R           (264a b c  - 66a b c + 6a b )x  + 132a b c  - 33a b c + 3a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                 2 3        2 2     4   7      2   2        3      5  5
+--R           (- 44a c  + 37a b c  - 5b c)x  + (4a b c  + 20a b c - 3b )x
+--R         + 
+--R                 3 2      2 2        4  3       3        2 3
+--R           (- 28a c  + 49a b c - 6a b )x  + (24a b c - 3a b )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 6        2 5     4 4  8        2   5         3 4      5 3  6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R       + 
+--R              3 5        4 3     6 2  4        3   4       2 3 3        5 2  2
+--R         (256a c  - 48a b c  + 8b c )x  + (256a b c  - 128a b c  + 16a b c )x
+--R       + 
+--R             4 4      3 2 3     2 4 2
+--R         128a c  - 64a b c  + 8a b c
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1072
+
+--S 1073 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 6        2 5     4 4  8        2   5        3 4     5 3  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 5        4 3     6 2  4        3   4      2 3 3       5 2  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 4      3 2 3     2 4 2
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R         ROOT
+--R                           5 10          4 2 9          3 4 8         2 6 7
+--R                    262144a c   - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 6       10 5
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                               7 12            6 2 11            5 4 10
+--R                      58720256a c   - 83886080a b c   + 50855936a b c
+--R                    + 
+--R                                 4 6 9           3 8 8          2 10 7
+--R                      - 17039360a b c  + 3440640a b c  - 425984a b  c
+--R                    + 
+--R                              12 6        14 5
+--R                      30720a b  c  - 1024b  c
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                           6   6          5 3 5          4 5 4          3 7 3
+--R                  - 903168a b c  + 993024a b c  - 449856a b c  + 108432a b c
+--R                + 
+--R                          2 9 2          11       13
+--R                  - 14868a b c  + 1116a b  c - 36b
+--R             *
+--R                ROOT
+--R                                  5 10          4 2 9          3 4 8
+--R                           262144a c   - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 7          8 6       10 5
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     6 4          5 2 3          4 4 2         3 6        2 8
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c + 567a b )x
+--R     + 
+--R                 2 6        2 5     4 4  8          2   5        3 4     5 3  6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c )x
+--R         + 
+--R                  3 5        4 3     6 2  4
+--R           (- 128a c  + 24a b c  - 4b c )x
+--R         + 
+--R                  3   4      2 3 3       5 2  2      4 4      3 2 3     2 4 2
+--R           (- 128a b c  + 64a b c  - 8a b c )x  - 64a c  + 32a b c  - 4a b c
+--R      *
+--R         ROOT
+--R                             5 10          4 2 9          3 4 8         2 6 7
+--R                    - 262144a c   + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 6       10 5
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                               7 12            6 2 11            5 4 10
+--R                      58720256a c   - 83886080a b c   + 50855936a b c
+--R                    + 
+--R                                 4 6 9           3 8 8          2 10 7
+--R                      - 17039360a b c  + 3440640a b c  - 425984a b  c
+--R                    + 
+--R                              12 6        14 5
+--R                      30720a b  c  - 1024b  c
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                         6   6          5 3 5          4 5 4          3 7 3
+--R                  903168a b c  - 993024a b c  + 449856a b c  - 108432a b c
+--R                + 
+--R                        2 9 2          11       13
+--R                  14868a b c  - 1116a b  c + 36b
+--R             *
+--R                ROOT
+--R                                    5 10          4 2 9          3 4 8
+--R                           - 262144a c   + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 7          8 6       10 5
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     6 4          5 2 3          4 4 2         3 6        2 8
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c + 567a b )x
+--R     + 
+--R               2 6        2 5     4 4  8        2   5        3 4     5 3  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 5        4 3     6 2  4        3   4      2 3 3       5 2  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 4      3 2 3     2 4 2
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R         ROOT
+--R                             5 10          4 2 9          3 4 8         2 6 7
+--R                    - 262144a c   + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 6       10 5
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                 7 12            6 2 11            5 4 10
+--R                      - 58720256a c   + 83886080a b c   - 50855936a b c
+--R                    + 
+--R                               4 6 9           3 8 8          2 10 7
+--R                      17039360a b c  - 3440640a b c  + 425984a b  c
+--R                    + 
+--R                                12 6        14 5
+--R                      - 30720a b  c  + 1024b  c
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                           6   6          5 3 5          4 5 4          3 7 3
+--R                  - 903168a b c  + 993024a b c  - 449856a b c  + 108432a b c
+--R                + 
+--R                          2 9 2          11       13
+--R                  - 14868a b c  + 1116a b  c - 36b
+--R             *
+--R                ROOT
+--R                                    5 10          4 2 9          3 4 8
+--R                           - 262144a c   + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 7          8 6       10 5
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     6 4          5 2 3          4 4 2         3 6        2 8
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c + 567a b )x
+--R     + 
+--R                 2 6        2 5     4 4  8          2   5        3 4     5 3  6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c )x
+--R         + 
+--R                  3 5        4 3     6 2  4
+--R           (- 128a c  + 24a b c  - 4b c )x
+--R         + 
+--R                  3   4      2 3 3       5 2  2      4 4      3 2 3     2 4 2
+--R           (- 128a b c  + 64a b c  - 8a b c )x  - 64a c  + 32a b c  - 4a b c
+--R      *
+--R         ROOT
+--R                           5 10          4 2 9          3 4 8         2 6 7
+--R                    262144a c   - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 6       10 5
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                 7 12            6 2 11            5 4 10
+--R                      - 58720256a c   + 83886080a b c   - 50855936a b c
+--R                    + 
+--R                               4 6 9           3 8 8          2 10 7
+--R                      17039360a b c  - 3440640a b c  + 425984a b  c
+--R                    + 
+--R                                12 6        14 5
+--R                      - 30720a b  c  + 1024b  c
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                         6   6          5 3 5          4 5 4          3 7 3
+--R                  903168a b c  - 993024a b c  + 449856a b c  - 108432a b c
+--R                + 
+--R                        2 9 2          11       13
+--R                  14868a b c  - 1116a b  c + 36b
+--R             *
+--R                ROOT
+--R                                  5 10          4 2 9          3 4 8
+--R                           262144a c   - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 7          8 6       10 5
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     6 4          5 2 3          4 4 2         3 6        2 8
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c + 567a b )x
+--R     + 
+--R             2 3        2 2     4   7      2   2        3      5  5
+--R       (- 44a c  + 37a b c  - 5b c)x  + (4a b c  + 20a b c - 3b )x
+--R     + 
+--R             3 2      2 2        4  3       3        2 3
+--R       (- 28a c  + 49a b c - 6a b )x  + (24a b c - 3a b )x
+--R  /
+--R            2 6        2 5     4 4  8        2   5         3 4      5 3  6
+--R       (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R     + 
+--R            3 5        4 3     6 2  4        3   4       2 3 3        5 2  2
+--R       (256a c  - 48a b c  + 8b c )x  + (256a b c  - 128a b c  + 16a b c )x
+--R     + 
+--R           4 4      3 2 3     2 4 2
+--R       128a c  - 64a b c  + 8a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1073
+
+--S 1074 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +-----------+
+--R             2 4        2 3     4 2  +-+ |          2  +-+
+--R         (64a c  - 32a b c  + 4b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           5 10          4 2 9          3 4 8         2 6 7
+--R                    262144a c   - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 6       10 5
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                               7 12            6 2 11            5 4 10
+--R                      58720256a c   - 83886080a b c   + 50855936a b c
+--R                    + 
+--R                                 4 6 9           3 8 8          2 10 7
+--R                      - 17039360a b c  + 3440640a b c  - 425984a b  c
+--R                    + 
+--R                              12 6        14 5
+--R                      30720a b  c  - 1024b  c
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                           6   6          5 3 5          4 5 4          3 7 3
+--R                  - 903168a b c  + 993024a b c  - 449856a b c  + 108432a b c
+--R                + 
+--R                          2 9 2          11       13
+--R                  - 14868a b c  + 1116a b  c - 36b
+--R             *
+--R                ROOT
+--R                                  5 10          4 2 9          3 4 8
+--R                           262144a c   - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 7          8 6       10 5
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     6 4          5 2 3          4 4 2         3 6        2 8
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c + 567a b )x
+--R     + 
+--R                                           +-----------+
+--R               2 4        2 3     4 2  +-+ |          2  +-+
+--R         (- 64a c  + 32a b c  - 4b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                             5 10          4 2 9          3 4 8         2 6 7
+--R                    - 262144a c   + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 6       10 5
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               7 12            6 2 11            5 4 10
+--R                      58720256a c   - 83886080a b c   + 50855936a b c
+--R                    + 
+--R                                 4 6 9           3 8 8          2 10 7
+--R                      - 17039360a b c  + 3440640a b c  - 425984a b  c
+--R                    + 
+--R                              12 6        14 5
+--R                      30720a b  c  - 1024b  c
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                         6   6          5 3 5          4 5 4          3 7 3
+--R                  903168a b c  - 993024a b c  + 449856a b c  - 108432a b c
+--R                + 
+--R                        2 9 2          11       13
+--R                  14868a b c  - 1116a b  c + 36b
+--R             *
+--R                ROOT
+--R                                    5 10          4 2 9          3 4 8
+--R                           - 262144a c   + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 7          8 6       10 5
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     6 4          5 2 3          4 4 2         3 6        2 8
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c + 567a b )x
+--R     + 
+--R                                         +-----------+
+--R             2 4        2 3     4 2  +-+ |          2  +-+
+--R         (64a c  - 32a b c  + 4b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                             5 10          4 2 9          3 4 8         2 6 7
+--R                    - 262144a c   + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 6       10 5
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 7 12            6 2 11            5 4 10
+--R                      - 58720256a c   + 83886080a b c   - 50855936a b c
+--R                    + 
+--R                               4 6 9           3 8 8          2 10 7
+--R                      17039360a b c  - 3440640a b c  + 425984a b  c
+--R                    + 
+--R                                12 6        14 5
+--R                      - 30720a b  c  + 1024b  c
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                           6   6          5 3 5          4 5 4          3 7 3
+--R                  - 903168a b c  + 993024a b c  - 449856a b c  + 108432a b c
+--R                + 
+--R                          2 9 2          11       13
+--R                  - 14868a b c  + 1116a b  c - 36b
+--R             *
+--R                ROOT
+--R                                    5 10          4 2 9          3 4 8
+--R                           - 262144a c   + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 7          8 6       10 5
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     6 4          5 2 3          4 4 2         3 6        2 8
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c + 567a b )x
+--R     + 
+--R                                           +-----------+
+--R               2 4        2 3     4 2  +-+ |          2  +-+
+--R         (- 64a c  + 32a b c  - 4b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           5 10          4 2 9          3 4 8         2 6 7
+--R                    262144a c   - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 6       10 5
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                 7 12            6 2 11            5 4 10
+--R                      - 58720256a c   + 83886080a b c   - 50855936a b c
+--R                    + 
+--R                               4 6 9           3 8 8          2 10 7
+--R                      17039360a b c  - 3440640a b c  + 425984a b  c
+--R                    + 
+--R                                12 6        14 5
+--R                      - 30720a b  c  + 1024b  c
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                         6   6          5 3 5          4 5 4          3 7 3
+--R                  903168a b c  - 993024a b c  + 449856a b c  - 108432a b c
+--R                + 
+--R                        2 9 2          11       13
+--R                  14868a b c  - 1116a b  c + 36b
+--R             *
+--R                ROOT
+--R                                  5 10          4 2 9          3 4 8
+--R                           262144a c   - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 7          8 6       10 5
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     6 4          5 2 3          4 4 2         3 6        2 8
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c + 567a b )x
+--R     + 
+--R                                     +-----------+
+--R                2 2        2      4  |          2        2   2        3      5
+--R         ((- 84a c  + 27a b c - 3b )\|- 4a c + b   + 132a b c  - 33a b c + 3b )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                     +-----------+
+--R                2 2        2      4  |          2        2   2        3      5
+--R         ((- 84a c  + 27a b c - 3b )\|- 4a c + b   - 132a b c  + 33a b c - 3b )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                          +--------------------+
+--R                                        +-----------+     |   +-----------+
+--R            2 4        2 3     4 2  +-+ |          2  +-+ |   |          2
+--R       (128a c  - 64a b c  + 8b c )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1074
+
+--S 1075 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1075
+
+)clear all
+
+--S 1076 of 1353
+t0:=x^9/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      9
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1076
+
+--S 1077 of 1353
+r0:=1/4*x^6*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-3/2*a*x^2*_
+   (2*a+b*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))-6*a^2*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R               2 2 8      2     6         3       2 2  4      3   2      4
+--R         (- 24a c x  - 48a b c x  + (- 48a c - 24a b )x  - 48a b x  - 24a )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                        3  8         2        2  6      2   4      3 2
+--R         ((- 10a b c + b )x  + (- 20a c - 4a b )x  - 18a b x  - 12a x )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1077
+
+--S 1078 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               2 4 8      2   3 6       3 3      2 2 2  4      3   2 2      4 2
+--R           (12a c x  + 24a b c x  + (24a c  + 12a b c )x  + 24a b c x  + 12a c )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                   2 3        2 2     4   6      2   2       3     5  4
+--R             (- 20a c  + 16a b c  - 2b c)x  + (2a b c  + 8a b c - b )x
+--R           + 
+--R                   3 2      2 2        4  2      3       2 3
+--R             (- 12a c  + 20a b c - 2a b )x  + 10a b c - a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 6        2 5     4 4  8        2   5        3 4     5 3  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 5        4 3     6 2  4        3   4      2 3 3       5 2  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 4      3 2 3     2 4 2
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R               2 4 8      2   3 6       3 3      2 2 2  4      3   2 2      4 2
+--R           (24a c x  + 48a b c x  + (48a c  + 24a b c )x  + 48a b c x  + 24a c )
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                   2 3        2 2     4   6      2   2       3     5  4
+--R             (- 20a c  + 16a b c  - 2b c)x  + (2a b c  + 8a b c - b )x
+--R           + 
+--R                   3 2      2 2        4  2      3       2 3
+--R             (- 12a c  + 20a b c - 2a b )x  + 10a b c - a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 6        2 5     4 4  8        2   5        3 4     5 3  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 5        4 3     6 2  4        3   4      2 3 3       5 2  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 4      3 2 3     2 4 2
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1078
+
+--S 1079 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2
+--R         12a c
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                          2                         +-----------+
+--R          2 2         2c x  + b                  3  |          2
+--R       24a c atanh(--------------) + (10a b c - b )\|- 4a c + b
+--R                    +-----------+
+--R                    |          2
+--R                   \|- 4a c + b
+--R  /
+--R                                 +-----------+
+--R         2 4        2 3     4 2  |          2
+--R     (64a c  - 32a b c  + 4b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1079
+
+--S 1080 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1080
+
+--S 1081 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              +---------+             2
+--R          2 2 |        2          2c x  + b
+--R       24a c \|4a c - b  atanh(--------------)
+--R                                +-----------+
+--R                                |          2
+--R                               \|- 4a c + b
+--R     + 
+--R                                            +---------+
+--R              +-----------+          2      |        2
+--R          2 2 |          2      (2c x  + b)\|4a c - b
+--R       24a c \|- 4a c + b  atan(-----------------------)
+--R                                               2
+--R                                       4a c - b
+--R     + 
+--R                      +-----------+ +---------+
+--R                   3  |          2  |        2
+--R       (10a b c - b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                                 +-----------+ +---------+
+--R         2 4        2 3     4 2  |          2  |        2
+--R     (64a c  - 32a b c  + 4b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1081
+
+--S 1082 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1082
+
+)clear all
+
+--S 1083 of 1353
+t0:=x^8/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      8
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1083
+
+--S 1084 of 1353
+r0:=-1/8*(b^2+20*a*c)*x/(c*(b^2-4*a*c)^2)+1/4*x^5*(2*a+b*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4)^2)+1/8*x^3*(12*a*b+(b^2+20*a*c)*x^2)/((b^2-4*a*c)^2*_
+   (a+b*x^2+c*x^4))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b^3-16*a*b*c+(-b^4+18*a*b^2*c+40*a^2*c^2)/sqrt(b^2-4*a*c))/(c^(3/2)*_
+   (b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/8*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^3-16*a*b*c+(b^4-18*a*b^2*c-_
+   40*a^2*c^2)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)^2*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                         3    3 2  8           2 2     4   6
+--R               (- 16a b c  + b c )x  + (- 32a b c  + 2b c)x
+--R             + 
+--R                     2   2        3     5  4         2 2        4  2      3
+--R               (- 32a b c  - 14a b c + b )x  + (- 32a b c + 2a b )x  - 16a b c
+--R             + 
+--R                2 3
+--R               a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 4        2 3    4 2  8       2   3        3 2     5   6
+--R           (40a c  + 18a b c  - b c )x  + (80a b c  + 36a b c  - 2b c)x
+--R         + 
+--R               3 3      2 2 2        4     6  4       3   2      2 3        5  2
+--R           (80a c  + 76a b c  + 16a b c - b )x  + (80a b c  + 36a b c - 2a b )x
+--R         + 
+--R              4 2      3 2     2 4
+--R           40a c  + 18a b c - a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                         3    3 2  8           2 2     4   6
+--R               (- 16a b c  + b c )x  + (- 32a b c  + 2b c)x
+--R             + 
+--R                     2   2        3     5  4         2 2        4  2      3
+--R               (- 32a b c  - 14a b c + b )x  + (- 32a b c + 2a b )x  - 16a b c
+--R             + 
+--R                2 3
+--R               a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 4        2 3    4 2  8         2   3        3 2     5   6
+--R           (- 40a c  - 18a b c  + b c )x  + (- 80a b c  - 36a b c  + 2b c)x
+--R         + 
+--R                 3 3      2 2 2        4     6  4
+--R           (- 80a c  - 76a b c  - 16a b c + b )x
+--R         + 
+--R                 3   2      2 3        5  2      4 2      3 2     2 4
+--R           (- 80a b c  - 36a b c + 2a b )x  - 40a c  - 18a b c + a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                     2    3   7         2 2       2     4  5
+--R           (- 16a b c  + b c)x  + (- 36a c  - 5a b c - b )x
+--R         + 
+--R                 2          3  3         3     2 2
+--R           (- 28a b c - 2a b )x  + (- 20a c - a b )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 5        2 4     4 3  8        2   4         3 3      5 2  6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R       + 
+--R              3 4        4 2     6   4        3   3       2 3 2        5   2
+--R         (256a c  - 48a b c  + 8b c)x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R             4 3      3 2 2     2 4
+--R         128a c  - 64a b c  + 8a b c
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1084
+
+--S 1085 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 5        2 4     4 3  8        2   4        3 3     5 2  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 4        4 2     6   4        3   3      2 3 2       5   2
+--R           (128a c  - 24a b c  + 4b c)x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R              4 3      3 2 2     2 4
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R         ROOT
+--R                           5 8          4 2 7          3 4 6         2 6 5
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 4       10 3
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                               6   9            5 3 8            4 5 7
+--R                      54525952a b c  - 69206016a b c  + 35389440a b c
+--R                    + 
+--R                              3 7 6           2 9 5           11 4        13 3
+--R                    - 9175040a b c  + 1228800a b c  - 73728a b  c  + 1024b  c
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         5 5         4 2 4         3 4 3        2 6 2        8
+--R                  128000a c  - 94720a b c  + 22784a b c  - 1568a b c  - 68a b c
+--R                + 
+--R                    10
+--R                  4b
+--R             *
+--R                ROOT
+--R                                  5 8          4 2 7          3 4 6
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 5          8 4       10 3
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     4 3         3 2 2        2 4         6
+--R              (10000a c  + 15000a b c  - 1491a b c + 35a b )x
+--R     + 
+--R                 2 5        2 4     4 3  8          2   4        3 3     5 2  6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c )x
+--R         + 
+--R                  3 4        4 2     6   4          3   3      2 3 2       5   2
+--R           (- 128a c  + 24a b c  - 4b c)x  + (- 128a b c  + 64a b c  - 8a b c)x
+--R         + 
+--R                4 3      3 2 2     2 4
+--R           - 64a c  + 32a b c  - 4a b c
+--R      *
+--R         ROOT
+--R                             5 8          4 2 7          3 4 6         2 6 5
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 4       10 3
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                               6   9            5 3 8            4 5 7
+--R                      54525952a b c  - 69206016a b c  + 35389440a b c
+--R                    + 
+--R                              3 7 6           2 9 5           11 4        13 3
+--R                    - 9175040a b c  + 1228800a b c  - 73728a b  c  + 1024b  c
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                           5 5         4 2 4         3 4 3        2 6 2
+--R                  - 128000a c  + 94720a b c  - 22784a b c  + 1568a b c
+--R                + 
+--R                       8      10
+--R                  68a b c - 4b
+--R             *
+--R                ROOT
+--R                                    5 8          4 2 7          3 4 6
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 5          8 4       10 3
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     4 3         3 2 2        2 4         6
+--R              (10000a c  + 15000a b c  - 1491a b c + 35a b )x
+--R     + 
+--R               2 5        2 4     4 3  8        2   4        3 3     5 2  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 4        4 2     6   4        3   3      2 3 2       5   2
+--R           (128a c  - 24a b c  + 4b c)x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R              4 3      3 2 2     2 4
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R         ROOT
+--R                             5 8          4 2 7          3 4 6         2 6 5
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 4       10 3
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                 6   9            5 3 8            4 5 7
+--R                      - 54525952a b c  + 69206016a b c  - 35389440a b c
+--R                    + 
+--R                              3 7 6           2 9 5           11 4        13 3
+--R                      9175040a b c  - 1228800a b c  + 73728a b  c  - 1024b  c
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         5 5         4 2 4         3 4 3        2 6 2        8
+--R                  128000a c  - 94720a b c  + 22784a b c  - 1568a b c  - 68a b c
+--R                + 
+--R                    10
+--R                  4b
+--R             *
+--R                ROOT
+--R                                    5 8          4 2 7          3 4 6
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 5          8 4       10 3
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     4 3         3 2 2        2 4         6
+--R              (10000a c  + 15000a b c  - 1491a b c + 35a b )x
+--R     + 
+--R                 2 5        2 4     4 3  8          2   4        3 3     5 2  6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c )x
+--R         + 
+--R                  3 4        4 2     6   4          3   3      2 3 2       5   2
+--R           (- 128a c  + 24a b c  - 4b c)x  + (- 128a b c  + 64a b c  - 8a b c)x
+--R         + 
+--R                4 3      3 2 2     2 4
+--R           - 64a c  + 32a b c  - 4a b c
+--R      *
+--R         ROOT
+--R                           5 8          4 2 7          3 4 6         2 6 5
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 4       10 3
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                 6   9            5 3 8            4 5 7
+--R                      - 54525952a b c  + 69206016a b c  - 35389440a b c
+--R                    + 
+--R                              3 7 6           2 9 5           11 4        13 3
+--R                      9175040a b c  - 1228800a b c  + 73728a b  c  - 1024b  c
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                           5 5         4 2 4         3 4 3        2 6 2
+--R                  - 128000a c  + 94720a b c  - 22784a b c  + 1568a b c
+--R                + 
+--R                       8      10
+--R                  68a b c - 4b
+--R             *
+--R                ROOT
+--R                                  5 8          4 2 7          3 4 6
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 5          8 4       10 3
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     4 3         3 2 2        2 4         6
+--R              (10000a c  + 15000a b c  - 1491a b c + 35a b )x
+--R     + 
+--R                 2    3   7         2 2       2     4  5         2          3  3
+--R       (- 16a b c  + b c)x  + (- 36a c  - 5a b c - b )x  + (- 28a b c - 2a b )x
+--R     + 
+--R             3     2 2
+--R       (- 20a c - a b )x
+--R  /
+--R            2 5        2 4     4 3  8        2   4         3 3      5 2  6
+--R       (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R     + 
+--R            3 4        4 2     6   4        3   3       2 3 2        5   2
+--R       (256a c  - 48a b c  + 8b c)x  + (256a b c  - 128a b c  + 16a b c)x
+--R     + 
+--R           4 3      3 2 2     2 4
+--R       128a c  - 64a b c  + 8a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1085
+
+--S 1086 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +--------------------+
+--R                                        +-----------+     |   +-----------+
+--R             2 3        2 2     4   +-+ |          2  +-+ |   |          2
+--R         (64a c  - 32a b c  + 4b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           5 8          4 2 7          3 4 6         2 6 5
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 4       10 3
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                               6   9            5 3 8            4 5 7
+--R                      54525952a b c  - 69206016a b c  + 35389440a b c
+--R                    + 
+--R                              3 7 6           2 9 5           11 4        13 3
+--R                    - 9175040a b c  + 1228800a b c  - 73728a b  c  + 1024b  c
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         5 5         4 2 4         3 4 3        2 6 2        8
+--R                  128000a c  - 94720a b c  + 22784a b c  - 1568a b c  - 68a b c
+--R                + 
+--R                    10
+--R                  4b
+--R             *
+--R                ROOT
+--R                                  5 8          4 2 7          3 4 6
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 5          8 4       10 3
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     4 3         3 2 2        2 4         6
+--R              (10000a c  + 15000a b c  - 1491a b c + 35a b )x
+--R     + 
+--R                                          +-----------+
+--R               2 3        2 2     4   +-+ |          2  +-+
+--R         (- 64a c  + 32a b c  - 4b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                             5 8          4 2 7          3 4 6         2 6 5
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 4       10 3
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               6   9            5 3 8            4 5 7
+--R                      54525952a b c  - 69206016a b c  + 35389440a b c
+--R                    + 
+--R                              3 7 6           2 9 5           11 4        13 3
+--R                    - 9175040a b c  + 1228800a b c  - 73728a b  c  + 1024b  c
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                           5 5         4 2 4         3 4 3        2 6 2
+--R                  - 128000a c  + 94720a b c  - 22784a b c  + 1568a b c
+--R                + 
+--R                       8      10
+--R                  68a b c - 4b
+--R             *
+--R                ROOT
+--R                                    5 8          4 2 7          3 4 6
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 5          8 4       10 3
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     4 3         3 2 2        2 4         6
+--R              (10000a c  + 15000a b c  - 1491a b c + 35a b )x
+--R     + 
+--R                                        +-----------+
+--R             2 3        2 2     4   +-+ |          2  +-+
+--R         (64a c  - 32a b c  + 4b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                             5 8          4 2 7          3 4 6         2 6 5
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 4       10 3
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 6   9            5 3 8            4 5 7
+--R                      - 54525952a b c  + 69206016a b c  - 35389440a b c
+--R                    + 
+--R                              3 7 6           2 9 5           11 4        13 3
+--R                      9175040a b c  - 1228800a b c  + 73728a b  c  - 1024b  c
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         5 5         4 2 4         3 4 3        2 6 2        8
+--R                  128000a c  - 94720a b c  + 22784a b c  - 1568a b c  - 68a b c
+--R                + 
+--R                    10
+--R                  4b
+--R             *
+--R                ROOT
+--R                                    5 8          4 2 7          3 4 6
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 5          8 4       10 3
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     4 3         3 2 2        2 4         6
+--R              (10000a c  + 15000a b c  - 1491a b c + 35a b )x
+--R     + 
+--R                                          +-----------+
+--R               2 3        2 2     4   +-+ |          2  +-+
+--R         (- 64a c  + 32a b c  - 4b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           5 8          4 2 7          3 4 6         2 6 5
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 4       10 3
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                 6   9            5 3 8            4 5 7
+--R                      - 54525952a b c  + 69206016a b c  - 35389440a b c
+--R                    + 
+--R                              3 7 6           2 9 5           11 4        13 3
+--R                      9175040a b c  - 1228800a b c  + 73728a b  c  - 1024b  c
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                           5 5         4 2 4         3 4 3        2 6 2
+--R                  - 128000a c  + 94720a b c  - 22784a b c  + 1568a b c
+--R                + 
+--R                       8      10
+--R                  68a b c - 4b
+--R             *
+--R                ROOT
+--R                                  5 8          4 2 7          3 4 6
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 5          8 4       10 3
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                     4 3         3 2 2        2 4         6
+--R              (10000a c  + 15000a b c  - 1491a b c + 35a b )x
+--R     + 
+--R                         +-----------+
+--R                      3  |          2       2 2        2     4
+--R         ((16a b c - b )\|- 4a c + b   - 40a c  - 18a b c + b )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                         +-----------+
+--R                      3  |          2       2 2        2     4
+--R         ((16a b c - b )\|- 4a c + b   + 40a c  + 18a b c - b )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                         +--------------------+
+--R                                       +-----------+     |   +-----------+
+--R            2 3        2 2     4   +-+ |          2  +-+ |   |          2
+--R       (128a c  - 64a b c  + 8b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1086
+
+--S 1087 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1087
+
+)clear all
+
+--S 1088 of 1353
+t0:=x^7/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      7
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1088
+
+--S 1089 of 1353
+r0:=-1/4*x^6*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+3/4*b*x^2*_
+   (2*a+b*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+3*a*b*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                 2 8        2   6       2           3  4      2 2 2      3
+--R         (12a b c x  + 24a b c x  + (24a b c + 12a b )x  + 24a b x  + 12a b)
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                                 +-----------+
+--R             2    2   8                3  6       2 4     2   2  |          2
+--R       ((8a c  + b c)x  + (10a b c + 2b )x  + 9a b x  + 6a b x )\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1089
+
+--S 1090 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     3 8        2 2 6       2   2       3   4      2 2   2
+--R               6a b c x  + 12a b c x  + (12a b c  + 6a b c)x  + 12a b c x
+--R             + 
+--R                 3
+--R               6a b c
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                     2 6         2 2      2     4  4         2          3  2
+--R             - 6a b c x  + (- 16a c  - a b c - b )x  + (- 10a b c - 2a b )x
+--R           + 
+--R                 3     2 2
+--R             - 8a c - a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 5        2 4     4 3  8        2   4        3 3     5 2  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 4        4 2     6   4        3   3      2 3 2       5   2
+--R           (128a c  - 24a b c  + 4b c)x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R              4 3      3 2 2     2 4
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                      3 8        2 2 6         2   2        3   4      2 2   2
+--R             - 12a b c x  - 24a b c x  + (- 24a b c  - 12a b c)x  - 24a b c x
+--R           + 
+--R                  3
+--R             - 12a b c
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                     2 6         2 2      2     4  4         2          3  2
+--R             - 6a b c x  + (- 16a c  - a b c - b )x  + (- 10a b c - 2a b )x
+--R           + 
+--R                 3     2 2
+--R             - 8a c - a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 5        2 4     4 3  8        2   4        3 3     5 2  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 4        4 2     6   4        3   3      2 3 2       5   2
+--R           (128a c  - 24a b c  + 4b c)x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R              4 3      3 2 2     2 4
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1090
+
+--S 1091 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         6a b c
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                              2                        +-----------+
+--R                          2c x  + b                 2  |          2
+--R       - 12a b c atanh(--------------) + (- 8a c - b )\|- 4a c + b
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R  /
+--R                                +-----------+
+--R         2 3        2 2     4   |          2
+--R     (64a c  - 32a b c  + 4b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1091
+
+--S 1092 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1092
+
+--S 1093 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 +---------+             2
+--R                 |        2          2c x  + b
+--R       - 12a b c\|4a c - b  atanh(--------------)
+--R                                   +-----------+
+--R                                   |          2
+--R                                  \|- 4a c + b
+--R     + 
+--R                                               +---------+
+--R                 +-----------+          2      |        2
+--R                 |          2      (2c x  + b)\|4a c - b
+--R       - 12a b c\|- 4a c + b  atan(-----------------------)
+--R                                                  2
+--R                                          4a c - b
+--R     + 
+--R                     +-----------+ +---------+
+--R                  2  |          2  |        2
+--R       (- 8a c - b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                                +-----------+ +---------+
+--R         2 3        2 2     4   |          2  |        2
+--R     (64a c  - 32a b c  + 4b c)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1093
+
+--S 1094 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1094
+
+)clear all
+
+--S 1095 of 1353
+t0:=x^6/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      6
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1095
+
+--S 1096 of 1353
+r0:=1/4*x^3*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+3/8*x*(4*a*b+_
+   (b^2+4*a*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+3/8*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b^2+4*a*c-b*(b^2+12*a*c)/sqrt(b^2-_
+   4*a*c))/((b^2-4*a*c)^2*sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^2+4*a*c+_
+   b*(b^2+12*a*c)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^2*sqrt(2)*sqrt(c)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     3     2 2  8           2     3   6
+--R               (12a c  + 3b c )x  + (24a b c  + 6b c)x
+--R             + 
+--R                   2 2        2      4  4       2          3  2      3      2 2
+--R               (24a c  + 18a b c + 3b )x  + (24a b c + 6a b )x  + 12a c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     3     3 2  8           2 2     4   6
+--R           (- 36a b c  - 3b c )x  + (- 72a b c  - 6b c)x
+--R         + 
+--R                 2   2        3      5  4         2 2        4  2      3
+--R           (- 72a b c  - 42a b c - 3b )x  + (- 72a b c - 6a b )x  - 36a b c
+--R         + 
+--R               2 3
+--R           - 3a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                     3     2 2  8           2     3   6
+--R               (12a c  + 3b c )x  + (24a b c  + 6b c)x
+--R             + 
+--R                   2 2        2      4  4       2          3  2      3      2 2
+--R               (24a c  + 18a b c + 3b )x  + (24a b c + 6a b )x  + 12a c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3     3 2  8         2 2     4   6
+--R           (36a b c  + 3b c )x  + (72a b c  + 6b c)x
+--R         + 
+--R               2   2        3      5  4       2 2        4  2      3        2 3
+--R           (72a b c  + 42a b c + 3b )x  + (72a b c + 6a b )x  + 36a b c + 3a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                2     2   7                3  5        2         2  3      2
+--R         ((12a c  + 3b c)x  + (16a b c + 5b )x  + (- 4a c + 19a b )x  + 12a b x)
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 4        2 3     4 2  8        2   3         3 2      5   6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R       + 
+--R              3 3        4      6  4        3   2       2 3         5  2
+--R         (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             4 2      3 2      2 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1096
+
+--S 1097 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                            5 6           4 2 5           3 4 4          2 6 3
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                            8 2        10
+--R                    46080a b c  - 2304b  c
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     5 7            4 2 6            3 4 5
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       2 6 4             8 3         10 2
+--R                            - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       5 6          4 2 5         3 4 4         2 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 2       10
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                              6 7           5 2 6           4 4 5
+--R                      8388608a c  - 4194304a b c  - 2621440a b c
+--R                    + 
+--R                              3 6 4          2 8 3            10 2        12
+--R                      2621440a b c  - 819200a b c  + 114688a b  c  - 6144b  c
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       5 7            4 2 6            3 4 5
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         2 6 4             8 3         10 2
+--R                              - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         3   3       2 3 2         5       7
+--R                  - 1024a b c  + 768a b c  - 192a b c + 16b
+--R             *
+--R                ROOT
+--R                                   5 6           4 2 5           3 4 4
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    2 6 3           8 2        10
+--R                           - 368640a b c  + 46080a b c  - 2304b  c
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            5 7            4 2 6
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            3 4 5            2 6 4
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                             8 3         10 2
+--R                                   1310720a b c  - 65536b  c
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              5 6          4 2 5         3 4 4         2 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 2       10
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                  2 2         2       4
+--R              (48a c  + 120a b c + 15b )x
+--R     + 
+--R                 2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c)x
+--R         + 
+--R                  3 3        4      6  4          3   2      2 3        5  2
+--R           (- 128a c  + 24a b c - 4b )x  + (- 128a b c  + 64a b c - 8a b )x
+--R         + 
+--R                4 2      3 2      2 4
+--R           - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                              5 6           4 2 5           3 4 4          2 6 3
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                              8 2        10
+--R                    - 46080a b c  + 2304b  c
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     5 7            4 2 6            3 4 5
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       2 6 4             8 3         10 2
+--R                            - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       5 6          4 2 5         3 4 4         2 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 2       10
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                              6 7           5 2 6           4 4 5
+--R                      8388608a c  - 4194304a b c  - 2621440a b c
+--R                    + 
+--R                              3 6 4          2 8 3            10 2        12
+--R                      2621440a b c  - 819200a b c  + 114688a b  c  - 6144b  c
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       5 7            4 2 6            3 4 5
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         2 6 4             8 3         10 2
+--R                              - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                       3   3       2 3 2         5       7
+--R                  1024a b c  - 768a b c  + 192a b c - 16b
+--R             *
+--R                ROOT
+--R                                     5 6           4 2 5           3 4 4
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  2 6 3           8 2        10
+--R                           368640a b c  - 46080a b c  + 2304b  c
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            5 7            4 2 6
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            3 4 5            2 6 4
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                             8 3         10 2
+--R                                   1310720a b c  - 65536b  c
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              5 6          4 2 5         3 4 4         2 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 2       10
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                  2 2         2       4
+--R              (48a c  + 120a b c + 15b )x
+--R     + 
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                              5 6           4 2 5           3 4 4          2 6 3
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                              8 2        10
+--R                    - 46080a b c  + 2304b  c
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     5 7            4 2 6            3 4 5
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       2 6 4             8 3         10 2
+--R                            - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       5 6          4 2 5         3 4 4         2 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 2       10
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                6 7           5 2 6           4 4 5
+--R                      - 8388608a c  + 4194304a b c  + 2621440a b c
+--R                    + 
+--R                                3 6 4          2 8 3            10 2        12
+--R                      - 2621440a b c  + 819200a b c  - 114688a b  c  + 6144b  c
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       5 7            4 2 6            3 4 5
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         2 6 4             8 3         10 2
+--R                              - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         3   3       2 3 2         5       7
+--R                  - 1024a b c  + 768a b c  - 192a b c + 16b
+--R             *
+--R                ROOT
+--R                                     5 6           4 2 5           3 4 4
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  2 6 3           8 2        10
+--R                           368640a b c  - 46080a b c  + 2304b  c
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            5 7            4 2 6
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            3 4 5            2 6 4
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                             8 3         10 2
+--R                                   1310720a b c  - 65536b  c
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              5 6          4 2 5         3 4 4         2 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 2       10
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                  2 2         2       4
+--R              (48a c  + 120a b c + 15b )x
+--R     + 
+--R                 2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c)x
+--R         + 
+--R                  3 3        4      6  4          3   2      2 3        5  2
+--R           (- 128a c  + 24a b c - 4b )x  + (- 128a b c  + 64a b c - 8a b )x
+--R         + 
+--R                4 2      3 2      2 4
+--R           - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                            5 6           4 2 5           3 4 4          2 6 3
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                            8 2        10
+--R                    46080a b c  - 2304b  c
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     5 7            4 2 6            3 4 5
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       2 6 4             8 3         10 2
+--R                            - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       5 6          4 2 5         3 4 4         2 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 2       10
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                6 7           5 2 6           4 4 5
+--R                      - 8388608a c  + 4194304a b c  + 2621440a b c
+--R                    + 
+--R                                3 6 4          2 8 3            10 2        12
+--R                      - 2621440a b c  + 819200a b c  - 114688a b  c  + 6144b  c
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       5 7            4 2 6            3 4 5
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         2 6 4             8 3         10 2
+--R                              - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                       3   3       2 3 2         5       7
+--R                  1024a b c  - 768a b c  + 192a b c - 16b
+--R             *
+--R                ROOT
+--R                                   5 6           4 2 5           3 4 4
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    2 6 3           8 2        10
+--R                           - 368640a b c  + 46080a b c  - 2304b  c
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            5 7            4 2 6
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            3 4 5            2 6 4
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                             8 3         10 2
+--R                                   1310720a b c  - 65536b  c
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              5 6          4 2 5         3 4 4         2 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 2       10
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                  2 2         2       4
+--R              (48a c  + 120a b c + 15b )x
+--R     + 
+--R             2     2   7                3  5        2         2  3      2
+--R       (12a c  + 3b c)x  + (16a b c + 5b )x  + (- 4a c + 19a b )x  + 12a b x
+--R  /
+--R            2 4        2 3     4 2  8        2   3         3 2      5   6
+--R       (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R     + 
+--R            3 3        4      6  4        3   2       2 3         5  2       4 2
+--R       (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x  + 128a c
+--R     + 
+--R            3 2      2 4
+--R       - 64a b c + 8a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1097
+
+--S 1098 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                        +--------------------+
+--R                                      +-----------+     |   +-----------+
+--R             2 2        2      4  +-+ |          2  +-+ |   |          2
+--R         (64a c  - 32a b c + 4b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                            5 6           4 2 5           3 4 4          2 6 3
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                            8 2        10
+--R                    46080a b c  - 2304b  c
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     5 7            4 2 6            3 4 5
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       2 6 4             8 3         10 2
+--R                            - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       5 6          4 2 5         3 4 4         2 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 2       10
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                              6 7           5 2 6           4 4 5
+--R                      8388608a c  - 4194304a b c  - 2621440a b c
+--R                    + 
+--R                              3 6 4          2 8 3            10 2        12
+--R                      2621440a b c  - 819200a b c  + 114688a b  c  - 6144b  c
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       5 7            4 2 6            3 4 5
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         2 6 4             8 3         10 2
+--R                              - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         3   3       2 3 2         5       7
+--R                  - 1024a b c  + 768a b c  - 192a b c + 16b
+--R             *
+--R                ROOT
+--R                                   5 6           4 2 5           3 4 4
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    2 6 3           8 2        10
+--R                           - 368640a b c  + 46080a b c  - 2304b  c
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            5 7            4 2 6
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            3 4 5            2 6 4
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                             8 3         10 2
+--R                                   1310720a b c  - 65536b  c
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              5 6          4 2 5         3 4 4         2 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 2       10
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                  2 2         2       4
+--R              (48a c  + 120a b c + 15b )x
+--R     + 
+--R                                        +-----------+
+--R               2 2        2      4  +-+ |          2  +-+
+--R         (- 64a c  + 32a b c - 4b )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                              5 6           4 2 5           3 4 4          2 6 3
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                              8 2        10
+--R                    - 46080a b c  + 2304b  c
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     5 7            4 2 6            3 4 5
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       2 6 4             8 3         10 2
+--R                            - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       5 6          4 2 5         3 4 4         2 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 2       10
+--R                2560a b c  - 128b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              6 7           5 2 6           4 4 5
+--R                      8388608a c  - 4194304a b c  - 2621440a b c
+--R                    + 
+--R                              3 6 4          2 8 3            10 2        12
+--R                      2621440a b c  - 819200a b c  + 114688a b  c  - 6144b  c
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       5 7            4 2 6            3 4 5
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         2 6 4             8 3         10 2
+--R                              - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                       3   3       2 3 2         5       7
+--R                  1024a b c  - 768a b c  + 192a b c - 16b
+--R             *
+--R                ROOT
+--R                                     5 6           4 2 5           3 4 4
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  2 6 3           8 2        10
+--R                           368640a b c  - 46080a b c  + 2304b  c
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            5 7            4 2 6
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            3 4 5            2 6 4
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                             8 3         10 2
+--R                                   1310720a b c  - 65536b  c
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              5 6          4 2 5         3 4 4         2 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 2       10
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                  2 2         2       4
+--R              (48a c  + 120a b c + 15b )x
+--R     + 
+--R                                      +-----------+
+--R             2 2        2      4  +-+ |          2  +-+
+--R         (64a c  - 32a b c + 4b )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                              5 6           4 2 5           3 4 4          2 6 3
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                              8 2        10
+--R                    - 46080a b c  + 2304b  c
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     5 7            4 2 6            3 4 5
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       2 6 4             8 3         10 2
+--R                            - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       5 6          4 2 5         3 4 4         2 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 2       10
+--R                2560a b c  - 128b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                6 7           5 2 6           4 4 5
+--R                      - 8388608a c  + 4194304a b c  + 2621440a b c
+--R                    + 
+--R                                3 6 4          2 8 3            10 2        12
+--R                      - 2621440a b c  + 819200a b c  - 114688a b  c  + 6144b  c
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       5 7            4 2 6            3 4 5
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         2 6 4             8 3         10 2
+--R                              - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         3   3       2 3 2         5       7
+--R                  - 1024a b c  + 768a b c  - 192a b c + 16b
+--R             *
+--R                ROOT
+--R                                     5 6           4 2 5           3 4 4
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  2 6 3           8 2        10
+--R                           368640a b c  - 46080a b c  + 2304b  c
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            5 7            4 2 6
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            3 4 5            2 6 4
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                             8 3         10 2
+--R                                   1310720a b c  - 65536b  c
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              5 6          4 2 5         3 4 4         2 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 2       10
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                  2 2         2       4
+--R              (48a c  + 120a b c + 15b )x
+--R     + 
+--R                                                          +--------------------+
+--R                                        +-----------+     |   +-----------+
+--R               2 2        2      4  +-+ |          2  +-+ |   |          2
+--R         (- 64a c  + 32a b c - 4b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                            5 6           4 2 5           3 4 4          2 6 3
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                            8 2        10
+--R                    46080a b c  - 2304b  c
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     5 7            4 2 6            3 4 5
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       2 6 4             8 3         10 2
+--R                            - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       5 6          4 2 5         3 4 4         2 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 2       10
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                6 7           5 2 6           4 4 5
+--R                      - 8388608a c  + 4194304a b c  + 2621440a b c
+--R                    + 
+--R                                3 6 4          2 8 3            10 2        12
+--R                      - 2621440a b c  + 819200a b c  - 114688a b  c  + 6144b  c
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       5 7            4 2 6            3 4 5
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         2 6 4             8 3         10 2
+--R                              - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                       3   3       2 3 2         5       7
+--R                  1024a b c  - 768a b c  + 192a b c - 16b
+--R             *
+--R                ROOT
+--R                                   5 6           4 2 5           3 4 4
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    2 6 3           8 2        10
+--R                           - 368640a b c  + 46080a b c  - 2304b  c
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            5 7            4 2 6
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            3 4 5            2 6 4
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                             8 3         10 2
+--R                                   1310720a b c  - 65536b  c
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              5 6          4 2 5         3 4 4         2 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 2       10
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                  2 2         2       4
+--R              (48a c  + 120a b c + 15b )x
+--R     + 
+--R                                                         +------------------+
+--R                          +-----------+                  | +-----------+
+--R                       2  |          2                3  | |          2
+--R         ((- 12a c - 3b )\|- 4a c + b   + 36a b c + 3b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                         +--------------------+
+--R                          +-----------+                  |   +-----------+
+--R                       2  |          2                3  |   |          2
+--R         ((- 12a c - 3b )\|- 4a c + b   - 36a b c - 3b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                                       +--------------------+
+--R                                     +-----------+     |   +-----------+
+--R            2 2        2      4  +-+ |          2  +-+ |   |          2
+--R       (128a c  - 64a b c + 8b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1098
+
+--S 1099 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1099
+
+)clear all
+
+--S 1100 of 1353
+t0:=x^5/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      5
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1100
+
+--S 1101 of 1353
+r0:=1/4*x^6*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-_
+   1/4*(b^2+2*a*c)*x^2*(2*a+b*x^2)/(a*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))-_
+   (b^2+2*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                  3     2 2  8             2     3   6
+--R           (- 8a c  - 4b c )x  + (- 16a b c  - 8b c)x
+--R         + 
+--R                 2 2        2      4  4         2          3  2     3      2 2
+--R           (- 16a c  - 16a b c - 4b )x  + (- 16a b c - 8a b )x  - 8a c - 4a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2 8        2      2   6                 3  4
+--R             - 6b c x  + (4a c  - 10b c)x  + (- 6a b c - 3b )x
+--R           + 
+--R                  2        2  2
+--R             (- 4a c - 2a b )x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1101
+
+--S 1102 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3     2 2  8          2     3   6      2 2       2      4  4
+--R             (4a c  + 2b c )x  + (8a b c  + 4b c)x  + (8a c  + 8a b c + 2b )x
+--R           + 
+--R                2          3  2     3      2 2
+--R             (8a b c + 4a b )x  + 4a c + 2a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                 2     2   6               3  4        2         2  2     2
+--R           ((4a c  + 2b c)x  + (6a b c + 3b )x  + (- 4a c + 10a b )x  + 6a b)
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                  3     2 2  8           2     3   6
+--R             (8a c  + 4b c )x  + (16a b c  + 8b c)x
+--R           + 
+--R                 2 2        2      4  4       2          3  2     3      2 2
+--R             (16a c  + 16a b c + 4b )x  + (16a b c + 8a b )x  + 8a c + 4a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                 2     2   6               3  4        2         2  2     2
+--R           ((4a c  + 2b c)x  + (6a b c + 3b )x  + (- 4a c + 10a b )x  + 6a b)
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1102
+
+--S 1103 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c + b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                2             +-----------+
+--R                 2          2c x  + b         |          2
+--R       (4a c + 2b )atanh(--------------) + 3b\|- 4a c + b
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R  /
+--R                              +-----------+
+--R         2 2        2      4  |          2
+--R     (32a c  - 16a b c + 2b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1103
+
+--S 1104 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1104
+
+--S 1105 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    +---------+             2
+--R                 2  |        2          2c x  + b
+--R       (4a c + 2b )\|4a c - b  atanh(--------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                    +-----------+          2      |        2
+--R                 2  |          2      (2c x  + b)\|4a c - b
+--R       (4a c + 2b )\|- 4a c + b  atan(-----------------------)
+--R                                                     2
+--R                                             4a c - b
+--R     + 
+--R          +-----------+ +---------+
+--R          |          2  |        2
+--R       3b\|- 4a c + b  \|4a c - b
+--R  /
+--R                              +-----------+ +---------+
+--R         2 2        2      4  |          2  |        2
+--R     (32a c  - 16a b c + 2b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1105
+
+--S 1106 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1106
+
+)clear all
+
+--S 1107 of 1353
+t0:=x^4/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      4
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1107
+
+--S 1108 of 1353
+r0:=1/4*x*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-1/8*x*(7*b^2-4*a*c+_
+   12*b*c*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+3/4*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2+4*a*c-2*b*sqrt(b^2-_
+   4*a*c))/((b^2-4*a*c)^(5/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   3/4*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2+_
+   4*a*c+2*b*sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     2 8      2   6                   3  4        2 2      2
+--R             (- 12b c x  - 24b c x  + (- 24a b c - 12b )x  - 24a b x  - 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8           2      3   6
+--R           (24a c  + 18b c )x  + (48a b c  + 36b c)x
+--R         + 
+--R               2 2        2       4  4       2           3  2      3       2 2
+--R           (48a c  + 60a b c + 18b )x  + (48a b c + 36a b )x  + 24a c + 18a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     2 8      2   6                   3  4        2 2      2
+--R             (- 12b c x  - 24b c x  + (- 24a b c - 12b )x  - 24a b x  - 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8             2      3   6
+--R           (- 24a c  - 18b c )x  + (- 48a b c  - 36b c)x
+--R         + 
+--R               2 2        2       4  4         2           3  2      3       2 2
+--R         (- 48a c  - 60a b c - 18b )x  + (- 48a b c - 36a b )x  - 24a c - 18a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 7        2      2   5                  3  3
+--R           - 12b c x  + (4a c  - 19b c)x  + (- 16a b c - 5b )x
+--R         + 
+--R                 2        2
+--R           (- 12a c - 3a b )x
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 4        2 3     4 2  8        2   3         3 2      5   6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R       + 
+--R              3 3        4      6  4        3   2       2 3         5  2
+--R         (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             4 2      3 2      2 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1108
+
+--S 1109 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                            6 5           5 2 4           4 4 3          3 6 2
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                          2 8           10
+--R                    46080a b c - 2304a b
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     7 5            6 2 4            5 4 3
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       4 6 2           3 8          2 10
+--R                            - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       6 5          5 2 4         4 4 3         3 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8          10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                       4 4       3 2 3        6      8
+--R                  1024a c  - 512a b c  + 32a b c - 4b
+--R             *
+--R                ROOT
+--R                                   6 5           5 2 4           4 4 3
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    3 6 2         2 8           10
+--R                           - 368640a b c  + 46080a b c - 2304a b
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            7 5            6 2 4
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            5 4 3            4 6 2
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                           3 8          2 10
+--R                                   1310720a b c - 65536a b
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              6 5          5 2 4         4 4 3         3 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8          10
+--R                       2560a b c - 128a b
+--R            + 
+--R                  2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)x
+--R     + 
+--R                 2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c)x
+--R         + 
+--R                  3 3        4      6  4          3   2      2 3        5  2
+--R           (- 128a c  + 24a b c - 4b )x  + (- 128a b c  + 64a b c - 8a b )x
+--R         + 
+--R                4 2      3 2      2 4
+--R           - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                              6 5           5 2 4           4 4 3          3 6 2
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                            2 8           10
+--R                    - 46080a b c + 2304a b
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     7 5            6 2 4            5 4 3
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       4 6 2           3 8          2 10
+--R                            - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       6 5          5 2 4         4 4 3         3 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8          10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                         4 4       3 2 3        6      8
+--R                  - 1024a c  + 512a b c  - 32a b c + 4b
+--R             *
+--R                ROOT
+--R                                     6 5           5 2 4           4 4 3
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  3 6 2         2 8           10
+--R                           368640a b c  - 46080a b c + 2304a b
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            7 5            6 2 4
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            5 4 3            4 6 2
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                           3 8          2 10
+--R                                   1310720a b c - 65536a b
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              6 5          5 2 4         4 4 3         3 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8          10
+--R                       2560a b c - 128a b
+--R            + 
+--R                  2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)x
+--R     + 
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                              6 5           5 2 4           4 4 3          3 6 2
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                            2 8           10
+--R                    - 46080a b c + 2304a b
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     7 5            6 2 4            5 4 3
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       4 6 2           3 8          2 10
+--R                            - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       6 5          5 2 4         4 4 3         3 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8          10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                       4 4       3 2 3        6      8
+--R                  1024a c  - 512a b c  + 32a b c - 4b
+--R             *
+--R                ROOT
+--R                                     6 5           5 2 4           4 4 3
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  3 6 2         2 8           10
+--R                           368640a b c  - 46080a b c + 2304a b
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            7 5            6 2 4
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            5 4 3            4 6 2
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                           3 8          2 10
+--R                                   1310720a b c - 65536a b
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              6 5          5 2 4         4 4 3         3 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8          10
+--R                       2560a b c - 128a b
+--R            + 
+--R                  2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)x
+--R     + 
+--R                 2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c)x
+--R         + 
+--R                  3 3        4      6  4          3   2      2 3        5  2
+--R           (- 128a c  + 24a b c - 4b )x  + (- 128a b c  + 64a b c - 8a b )x
+--R         + 
+--R                4 2      3 2      2 4
+--R           - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                            6 5           5 2 4           4 4 3          3 6 2
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                          2 8           10
+--R                    46080a b c - 2304a b
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     7 5            6 2 4            5 4 3
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       4 6 2           3 8          2 10
+--R                            - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       6 5          5 2 4         4 4 3         3 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8          10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                         4 4       3 2 3        6      8
+--R                  - 1024a c  + 512a b c  - 32a b c + 4b
+--R             *
+--R                ROOT
+--R                                   6 5           5 2 4           4 4 3
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    3 6 2         2 8           10
+--R                           - 368640a b c  + 46080a b c - 2304a b
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            7 5            6 2 4
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            5 4 3            4 6 2
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                           3 8          2 10
+--R                                   1310720a b c - 65536a b
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              6 5          5 2 4         4 4 3         3 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8          10
+--R                       2560a b c - 128a b
+--R            + 
+--R                  2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)x
+--R     + 
+--R            2 7        2      2   5                  3  3         2        2
+--R     - 12b c x  + (4a c  - 19b c)x  + (- 16a b c - 5b )x  + (- 12a c - 3a b )x
+--R  /
+--R            2 4        2 3     4 2  8        2   3         3 2      5   6
+--R       (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R     + 
+--R            3 3        4      6  4        3   2       2 3         5  2       4 2
+--R       (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x  + 128a c
+--R     + 
+--R            3 2      2 4
+--R       - 64a b c + 8a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1109
+
+--S 1110 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +--------------------+
+--R                                      +-----------+ |   +-----------+
+--R             2 2        2      4  +-+ |          2  |   |          2
+--R         (32a c  - 16a b c + 2b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                            6 5           5 2 4           4 4 3          3 6 2
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                          2 8           10
+--R                    46080a b c - 2304a b
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     7 5            6 2 4            5 4 3
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       4 6 2           3 8          2 10
+--R                            - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       6 5          5 2 4         4 4 3         3 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8          10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                       4 4       3 2 3        6      8
+--R                  1024a c  - 512a b c  + 32a b c - 4b
+--R             *
+--R                ROOT
+--R                                   6 5           5 2 4           4 4 3
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    3 6 2         2 8           10
+--R                           - 368640a b c  + 46080a b c - 2304a b
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            7 5            6 2 4
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            5 4 3            4 6 2
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                           3 8          2 10
+--R                                   1310720a b c - 65536a b
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              6 5          5 2 4         4 4 3         3 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8          10
+--R                       2560a b c - 128a b
+--R            + 
+--R                  2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)x
+--R     + 
+--R                                        +-----------+
+--R               2 2        2      4  +-+ |          2
+--R         (- 32a c  + 16a b c - 2b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                              6 5           5 2 4           4 4 3          3 6 2
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                            2 8           10
+--R                    - 46080a b c + 2304a b
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     7 5            6 2 4            5 4 3
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       4 6 2           3 8          2 10
+--R                            - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       6 5          5 2 4         4 4 3         3 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8          10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                         4 4       3 2 3        6      8
+--R                  - 1024a c  + 512a b c  - 32a b c + 4b
+--R             *
+--R                ROOT
+--R                                     6 5           5 2 4           4 4 3
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  3 6 2         2 8           10
+--R                           368640a b c  - 46080a b c + 2304a b
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            7 5            6 2 4
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            5 4 3            4 6 2
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                           3 8          2 10
+--R                                   1310720a b c - 65536a b
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              6 5          5 2 4         4 4 3         3 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8          10
+--R                       2560a b c - 128a b
+--R            + 
+--R                  2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)x
+--R     + 
+--R                                      +-----------+
+--R             2 2        2      4  +-+ |          2
+--R         (32a c  - 16a b c + 2b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                              6 5           5 2 4           4 4 3          3 6 2
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                            2 8           10
+--R                    - 46080a b c + 2304a b
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     7 5            6 2 4            5 4 3
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       4 6 2           3 8          2 10
+--R                            - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       6 5          5 2 4         4 4 3         3 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8          10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                       4 4       3 2 3        6      8
+--R                  1024a c  - 512a b c  + 32a b c - 4b
+--R             *
+--R                ROOT
+--R                                     6 5           5 2 4           4 4 3
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  3 6 2         2 8           10
+--R                           368640a b c  - 46080a b c + 2304a b
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            7 5            6 2 4
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            5 4 3            4 6 2
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                           3 8          2 10
+--R                                   1310720a b c - 65536a b
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              6 5          5 2 4         4 4 3         3 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8          10
+--R                       2560a b c - 128a b
+--R            + 
+--R                  2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)x
+--R     + 
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R               2 2        2      4  +-+ |          2  |   |          2
+--R         (- 32a c  + 16a b c - 2b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                            6 5           5 2 4           4 4 3          3 6 2
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                          2 8           10
+--R                    46080a b c - 2304a b
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                     7 5            6 2 4            5 4 3
+--R                            67108864a c  - 83886080a b c  + 41943040a b c
+--R                          + 
+--R                                       4 6 2           3 8          2 10
+--R                            - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                       6 5          5 2 4         4 4 3         3 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8          10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                         4 4       3 2 3        6      8
+--R                  - 1024a c  + 512a b c  - 32a b c + 4b
+--R             *
+--R                ROOT
+--R                                   6 5           5 2 4           4 4 3
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    3 6 2         2 8           10
+--R                           - 368640a b c  + 46080a b c - 2304a b
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                            7 5            6 2 4
+--R                                   67108864a c  - 83886080a b c
+--R                                 + 
+--R                                            5 4 3            4 6 2
+--R                                   41943040a b c  - 10485760a b c
+--R                                 + 
+--R                                           3 8          2 10
+--R                                   1310720a b c - 65536a b
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                              6 5          5 2 4         4 4 3         3 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8          10
+--R                       2560a b c - 128a b
+--R            + 
+--R                  2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)x
+--R     + 
+--R                                              +------------------+
+--R             +-----------+                    | +-----------+
+--R             |          2              2  +-+ | |          2
+--R         (6b\|- 4a c + b   - 12a c - 9b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                              +--------------------+
+--R             +-----------+                    |   +-----------+
+--R             |          2              2  +-+ |   |          2
+--R         (6b\|- 4a c + b   + 12a c + 9b )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                                  +--------------------+
+--R                                    +-----------+ |   +-----------+
+--R           2 2        2      4  +-+ |          2  |   |          2
+--R       (64a c  - 32a b c + 4b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1110
+
+--S 1111 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1111
+
+)clear all
+
+--S 1112 of 1353
+t0:=x^3/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1112
+
+--S 1113 of 1353
+r0:=1/4*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-3/4*b*(b+2*c*x^2)/_
+   ((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+3*b*c*atanh((b+2*c*x^2)/sqrt(b^2-_
+   4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R               3 8      2 2 6           2      3   4        2   2      2
+--R         (12b c x  + 24b c x  + (24a b c  + 12b c)x  + 24a b c x  + 12a b c)
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                                 +-----------+
+--R              2 6     2   4                  3  2     2       2  |          2
+--R       (- 6b c x  - 9b c x  + (- 10a b c - 2b )x  - 8a c - a b )\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1113
+
+--S 1114 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                3 8      2 2 6           2     3   4        2   2     2
+--R           (6b c x  + 12b c x  + (12a b c  + 6b c)x  + 12a b c x  + 6a b c)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                                                 +-----------+
+--R              2 6     2   4                  3  2     2       2  |          2
+--R       (- 6b c x  - 9b c x  + (- 10a b c - 2b )x  - 8a c - a b )\|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                      3 8      2 2 6             2      3   4        2   2
+--R               - 12b c x  - 24b c x  + (- 24a b c  - 12b c)x  - 24a b c x
+--R             + 
+--R                    2
+--R               - 12a b c
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                                                                   +---------+
+--R                2 6     2   4                  3  2     2       2  |        2
+--R         (- 6b c x  - 9b c x  + (- 10a b c - 2b )x  - 8a c - a b )\|4a c - b
+--R    /
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1114
+
+--S 1115 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         3b c
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                           2
+--R                       2c x  + b
+--R       - 6b c atanh(--------------)
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R  /
+--R                              +-----------+
+--R         2 2        2      4  |          2
+--R     (32a c  - 16a b c + 2b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1115
+
+--S 1116 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1116
+
+--S 1117 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              +---------+             2
+--R              |        2          2c x  + b
+--R       - 3b c\|4a c - b  atanh(--------------)
+--R                                +-----------+
+--R                                |          2
+--R                               \|- 4a c + b
+--R     + 
+--R                                            +---------+
+--R              +-----------+          2      |        2
+--R              |          2      (2c x  + b)\|4a c - b
+--R       - 3b c\|- 4a c + b  atan(-----------------------)
+--R                                               2
+--R                                       4a c - b
+--R  /
+--R                            +-----------+ +---------+
+--R         2 2       2     4  |          2  |        2
+--R     (16a c  - 8a b c + b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1117
+
+--S 1118 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1118
+
+)clear all
+
+--S 1119 of 1353
+t0:=x^2/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      2
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1119
+
+--S 1120 of 1353
+r0:=-1/4*x*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+1/8*x*(b*(b^2+8*a*c)+_
+   c*(b^2+20*a*c)*x^2)/(a*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))+1/8*atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b^2+20*a*c+b*(b^2-_
+   52*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (b^2+20*a*c-b*(b^2-52*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     3    2 2  8           2     3   6
+--R               (20a c  + b c )x  + (40a b c  + 2b c)x
+--R             + 
+--R                   2 2        2     4  4       2          3  2      3     2 2
+--R               (40a c  + 22a b c + b )x  + (40a b c + 2a b )x  + 20a c + a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     3    3 2  8            2 2     4   6
+--R           (- 52a b c  + b c )x  + (- 104a b c  + 2b c)x
+--R         + 
+--R                  2   2        3     5  4          2 2        4  2      3
+--R           (- 104a b c  - 50a b c + b )x  + (- 104a b c + 2a b )x  - 52a b c
+--R         + 
+--R            2 3
+--R           a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     3    2 2  8           2     3   6
+--R               (20a c  + b c )x  + (40a b c  + 2b c)x
+--R             + 
+--R                   2 2        2     4  4       2          3  2      3     2 2
+--R               (40a c  + 22a b c + b )x  + (40a b c + 2a b )x  + 20a c + a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3    3 2  8          2 2     4   6
+--R           (52a b c  - b c )x  + (104a b c  - 2b c)x
+--R         + 
+--R                2   2        3     5  4        2 2        4  2      3       2 3
+--R           (104a b c  + 50a b c - b )x  + (104a b c - 2a b )x  + 52a b c - a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 3    2 2  7           2     3   5       2 2       2     4  3
+--R           (20a c  + b c )x  + (28a b c  + 2b c)x  + (36a c  + 5a b c + b )x
+--R         + 
+--R               2         3
+--R           (16a b c - a b )x
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              3 4      2 2 3       4 2  8        3   3       2 3 2        5   6
+--R         (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R              4 3      2 4        6  4        4   2       3 3       2 5  2
+--R         (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             5 2      4 2      3 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1120
+
+--S 1121 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 4      2 2 3       4 2  8        3   3      2 3 2       5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                4 3      2 4        6  4        4   2      3 3      2 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              5 2      4 2      3 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                  - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                + 
+--R                          9      11
+--R                  - 212a b c + 4b
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )x
+--R     + 
+--R                 3 4      2 2 3       4 2  8
+--R           (- 64a c  + 32a b c  - 4a b c )x
+--R         + 
+--R                  3   3      2 3 2       5   6          4 3      2 4        6  4
+--R           (- 128a b c  + 64a b c  - 8a b c)x  + (- 128a c  + 24a b c - 4a b )x
+--R         + 
+--R                  4   2      3 3      2 5  2      5 2      4 2      3 4
+--R           (- 128a b c  + 64a b c - 8a b )x  - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                + 
+--R                        9      11
+--R                  212a b c - 4b
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )x
+--R     + 
+--R               3 4      2 2 3       4 2  8        3   3      2 3 2       5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                4 3      2 4        6  4        4   2      3 3      2 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              5 2      4 2      3 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                  - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                + 
+--R                          9      11
+--R                  - 212a b c + 4b
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )x
+--R     + 
+--R                 3 4      2 2 3       4 2  8
+--R           (- 64a c  + 32a b c  - 4a b c )x
+--R         + 
+--R                  3   3      2 3 2       5   6          4 3      2 4        6  4
+--R           (- 128a b c  + 64a b c  - 8a b c)x  + (- 128a c  + 24a b c - 4a b )x
+--R         + 
+--R                  4   2      3 3      2 5  2      5 2      4 2      3 4
+--R           (- 128a b c  + 64a b c - 8a b )x  - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                + 
+--R                        9      11
+--R                  212a b c - 4b
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )x
+--R     + 
+--R             3    2 2  7           2     3   5       2 2       2     4  3
+--R       (20a c  + b c )x  + (28a b c  + 2b c)x  + (36a c  + 5a b c + b )x
+--R     + 
+--R           2         3
+--R       (16a b c - a b )x
+--R  /
+--R            3 4      2 2 3       4 2  8        3   3       2 3 2        5   6
+--R       (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R     + 
+--R            4 3      2 4        6  4        4   2       3 3       2 5  2
+--R       (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R     + 
+--R           5 2      4 2      3 4
+--R       128a c  - 64a b c + 8a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1121
+
+--S 1122 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R             3 2      2 2        4  +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                  - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                + 
+--R                          9      11
+--R                  - 212a b c + 4b
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )x
+--R     + 
+--R                                          +-----------+
+--R               3 2      2 2        4  +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                + 
+--R                        9      11
+--R                  212a b c - 4b
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )x
+--R     + 
+--R                                        +-----------+
+--R             3 2      2 2        4  +-+ |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                  - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                + 
+--R                          9      11
+--R                  - 212a b c + 4b
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )x
+--R     + 
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R               3 2      2 2        4  +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                + 
+--R                        9      11
+--R                  212a b c - 4b
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )x
+--R     + 
+--R                                                           +------------------+
+--R                         +-----------+                     | +-----------+
+--R                      2  |          2               3  +-+ | |          2
+--R         ((- 20a c - b )\|- 4a c + b   + 52a b c - b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                         +-----------+
+--R                      2  |          2               3  +-+
+--R         ((- 20a c - b )\|- 4a c + b   - 52a b c + b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R            3 2      2 2        4  +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1122
+
+--S 1123 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1123
+
+)clear all
+
+--S 1124 of 1353
+t0:=x/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1124
+
+--S 1125 of 1353
+r0:=1/4*(-b-2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+3/2*c*(b+2*c*x^2)/_
+   ((b^2-4*a*c)^2*(a+b*x^2+c*x^4))-6*c^2*atanh((b+2*c*x^2)/sqrt(b^2-_
+   4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R               4 8        3 6           3      2 2  4          2 2      2 2
+--R         (- 24c x  - 48b c x  + (- 48a c  - 24b c )x  - 48a b c x  - 24a c )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                              +-----------+
+--R           3 6        2 4         2     2   2              3  |          2
+--R       (12c x  + 18b c x  + (20a c  + 4b c)x  + 10a b c - b )\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1125
+
+--S 1126 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               4 8        3 6         3      2 2  4          2 2      2 2
+--R           (12c x  + 24b c x  + (24a c  + 12b c )x  + 24a b c x  + 12a c )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                                                +-----------+
+--R             3 6        2 4         2     2   2              3  |          2
+--R         (12c x  + 18b c x  + (20a c  + 4b c)x  + 10a b c - b )\|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R               4 8        3 6         3      2 2  4          2 2      2 2
+--R           (24c x  + 48b c x  + (48a c  + 24b c )x  + 48a b c x  + 24a c )
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                                                                +---------+
+--R             3 6        2 4         2     2   2              3  |        2
+--R         (12c x  + 18b c x  + (20a c  + 4b c)x  + 10a b c - b )\|4a c - b
+--R    /
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1126
+
+--S 1127 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           2
+--R         3c
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                       2
+--R         2         2c x  + b
+--R       6c atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R  /
+--R                            +-----------+
+--R         2 2       2     4  |          2
+--R     (16a c  - 8a b c + b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1127
+
+--S 1128 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1128
+
+--S 1129 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             2
+--R         2 |        2          2c x  + b
+--R       6c \|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          2      |        2
+--R         2 |          2      (2c x  + b)\|4a c - b
+--R       6c \|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R                            +-----------+ +---------+
+--R         2 2       2     4  |          2  |        2
+--R     (16a c  - 8a b c + b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1129
+
+--S 1130 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1130
+
+)clear all
+
+--S 1131 of 1353
+t0:=1/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1131
+
+--S 1132 of 1353
+r0:=1/4*x*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/8*x*((b^2-7*a*c)*(3*b^2-4*a*c)+3*b*c*(b^2-8*a*c)*x^2)/(a^2*(b^2-_
+   4*a*c)^2*(a+b*x^2+c*x^4))+3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(b^3-8*a*b*c+(b^4-10*a*b^2*c+56*a^2*c^2)/_
+   sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b^3-_
+   8*a*b*c+(-b^4+10*a*b^2*c-56*a^2*c^2)/sqrt(b^2-4*a*c))/(a^2*(b^2-_
+   4*a*c)^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )x  + (- 48a b c  + 6b c)x
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )x  + (- 48a b c + 6a b )x  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (168a c  - 30a b c  + 3b c )x  + (336a b c  - 60a b c  + 6b c)x
+--R         + 
+--R                3 3       2 2 2        4      6  4
+--R           (336a c  + 108a b c  - 24a b c + 3b )x
+--R         + 
+--R                3   2      2 3        5  2       4 2      3 2      2 4
+--R           (336a b c  - 60a b c + 6a b )x  + 168a c  - 30a b c + 3a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )x  + (- 48a b c  + 6b c)x
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )x  + (- 48a b c + 6a b )x  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 168a c  + 30a b c  - 3b c )x  + (- 336a b c  + 60a b c  - 6b c)x
+--R         + 
+--R                  3 3       2 2 2        4      6  4
+--R           (- 336a c  - 108a b c  + 24a b c - 3b )x
+--R         + 
+--R                  3   2      2 3        5  2       4 2      3 2      2 4
+--R           (- 336a b c  + 60a b c - 6a b )x  - 168a c  + 30a b c - 3a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                     3     3 2  7       2 3        2 2     4   5
+--R           (- 24a b c  + 3b c )x  + (28a c  - 49a b c  + 6b c)x
+--R         + 
+--R                2   2        3      5  3       3 2      2 2        4
+--R           (- 4a b c  - 20a b c + 3b )x  + (44a c  - 37a b c + 5a b )x
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              4 4      3 2 3     2 4 2  8        4   3       3 3 2      2 5   6
+--R         (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R              5 3      3 4      2 6  4        5   2       4 3       3 5  2
+--R         (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             6 2      5 2      4 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1132
+
+--S 1133 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 4      3 2 3     2 4 2  8        4   3      3 3 2     2 5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                5 3      3 4      2 6  4        5   2      4 3      3 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              6 2      5 2      4 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                          7 7           6 2 6           5 4 5          4 6 4
+--R                  3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                + 
+--R                         3 8 3         2 10 2          12       14
+--R                  139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )x
+--R     + 
+--R                 4 4      3 2 3     2 4 2  8
+--R           (- 64a c  + 32a b c  - 4a b c )x
+--R         + 
+--R                  4   3      3 3 2     2 5   6          5 3      3 4      2 6  4
+--R           (- 128a b c  + 64a b c  - 8a b c)x  + (- 128a c  + 24a b c - 4a b )x
+--R         + 
+--R                  5   2      4 3      3 5  2      6 2      5 2      4 4
+--R           (- 128a b c  + 64a b c - 8a b )x  - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            7 7           6 2 6           5 4 5          4 6 4
+--R                  - 3161088a c  + 4096512a b c  - 2292480a b c  + 723168a b c
+--R                + 
+--R                           3 8 3         2 10 2          12       14
+--R                  - 139860a b c  + 16704a b  c  - 1152a b  c + 36b
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )x
+--R     + 
+--R               4 4      3 2 3     2 4 2  8        4   3      3 3 2     2 5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                5 3      3 4      2 6  4        5   2      4 3      3 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              6 2      5 2      4 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                          7 7           6 2 6           5 4 5          4 6 4
+--R                  3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                + 
+--R                         3 8 3         2 10 2          12       14
+--R                  139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )x
+--R     + 
+--R                 4 4      3 2 3     2 4 2  8
+--R           (- 64a c  + 32a b c  - 4a b c )x
+--R         + 
+--R                  4   3      3 3 2     2 5   6          5 3      3 4      2 6  4
+--R           (- 128a b c  + 64a b c  - 8a b c)x  + (- 128a c  + 24a b c - 4a b )x
+--R         + 
+--R                  5   2      4 3      3 5  2      6 2      5 2      4 4
+--R           (- 128a b c  + 64a b c - 8a b )x  - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            7 7           6 2 6           5 4 5          4 6 4
+--R                  - 3161088a c  + 4096512a b c  - 2292480a b c  + 723168a b c
+--R                + 
+--R                           3 8 3         2 10 2          12       14
+--R                  - 139860a b c  + 16704a b  c  - 1152a b  c + 36b
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )x
+--R     + 
+--R                 3     3 2  7       2 3        2 2     4   5
+--R       (- 24a b c  + 3b c )x  + (28a c  - 49a b c  + 6b c)x
+--R     + 
+--R            2   2        3      5  3       3 2      2 2        4
+--R       (- 4a b c  - 20a b c + 3b )x  + (44a c  - 37a b c + 5a b )x
+--R  /
+--R            4 4      3 2 3     2 4 2  8        4   3       3 3 2      2 5   6
+--R       (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R     + 
+--R            5 3      3 4      2 6  4        5   2       4 3       3 5  2
+--R       (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R     + 
+--R           6 2      5 2      4 4
+--R       128a c  - 64a b c + 8a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1133
+
+--S 1134 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R             4 2      3 2      2 4  +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                          7 7           6 2 6           5 4 5          4 6 4
+--R                  3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                + 
+--R                         3 8 3         2 10 2          12       14
+--R                  139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )x
+--R     + 
+--R                                          +-----------+
+--R               4 2      3 2      2 4  +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            7 7           6 2 6           5 4 5          4 6 4
+--R                  - 3161088a c  + 4096512a b c  - 2292480a b c  + 723168a b c
+--R                + 
+--R                           3 8 3         2 10 2          12       14
+--R                  - 139860a b c  + 16704a b  c  - 1152a b  c + 36b
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )x
+--R     + 
+--R                                        +-----------+
+--R             4 2      3 2      2 4  +-+ |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                          7 7           6 2 6           5 4 5          4 6 4
+--R                  3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                + 
+--R                         3 8 3         2 10 2          12       14
+--R                  139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )x
+--R     + 
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R               4 2      3 2      2 4  +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            7 7           6 2 6           5 4 5          4 6 4
+--R                  - 3161088a c  + 4096512a b c  - 2292480a b c  + 723168a b c
+--R                + 
+--R                           3 8 3         2 10 2          12       14
+--R                  - 139860a b c  + 16704a b  c  - 1152a b  c + 36b
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )x
+--R     + 
+--R                          +-----------+
+--R                       3  |          2        2 2        2      4  +-+
+--R         ((24a b c - 3b )\|- 4a c + b   - 168a c  + 30a b c - 3b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                       3  |          2        2 2        2      4  +-+
+--R         ((24a b c - 3b )\|- 4a c + b   + 168a c  - 30a b c + 3b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R            4 2      3 2      2 4  +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1134
+
+--S 1135 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1135
+
+)clear all
+
+--S 1136 of 1353
+t0:=1/(x*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 13       2 11        2     2   9              3  7      2        2  5
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   3    3
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1136
+
+--S 1137 of 1353
+r0:=1/4*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/4*(2*b^4-15*a*b^2*c+16*a^2*c^2+2*b*c*(b^2-7*a*c)*x^2)/(a^2*(b^2-_
+   4*a*c)^2*(a+b*x^2+c*x^4))+1/2*b*(b^4-10*a*b^2*c+30*a^2*c^2)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(5/2))+_
+   log(x)/a^3-1/4*log(a+b*x^2+c*x^4)/a^3
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  8        2 2 3        4 2     6   6
+--R           (60a b c  - 20a b c  + 2b c )x  + (120a b c  - 40a b c  + 4b c)x
+--R         + 
+--R                3   3      2 3 2        5      7  4
+--R           (120a b c  + 20a b c  - 16a b c + 2b )x
+--R         + 
+--R                3 2 2      2 4        6  2      4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )x  + 60a b c  - 20a b c + 2a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2 4       2 3    4 2  8         2   3        3 2     5   6
+--R               (- 16a c  + 8a b c  - b c )x  + (- 32a b c  + 16a b c  - 2b c)x
+--R             + 
+--R                     3 3       4     6  4         3   2      2 3        5  2
+--R               (- 32a c  + 6a b c - b )x  + (- 32a b c  + 16a b c - 2a b )x
+--R             + 
+--R                    4 2     3 2     2 4
+--R               - 16a c  + 8a b c - a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             log(x)
+--R         + 
+--R                 2   3       3 2  6       3 3      2 2 2       4   4
+--R           (- 14a b c  + 2a b c )x  + (16a c  - 29a b c  + 4a b c)x
+--R         + 
+--R                3   2      2 3        5  2      4 2      3 2      2 4
+--R           (- 2a b c  - 12a b c + 2a b )x  + 24a c  - 21a b c + 3a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R         (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R       + 
+--R              6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R         (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R       + 
+--R            7 2      6 2      5 4
+--R         64a c  - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1137
+
+--S 1138 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   4        3 3    5 2  8       2 2 3        4 2     6   6
+--R             (30a b c  - 10a b c  + b c )x  + (60a b c  - 20a b c  + 2b c)x
+--R           + 
+--R                 3   3      2 3 2       5     7  4
+--R             (60a b c  + 10a b c  - 8a b c + b )x
+--R           + 
+--R                 3 2 2      2 4        6  2      4   2      3 3     2 5
+--R             (60a b c  - 20a b c + 2a b )x  + 30a b c  - 10a b c + a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                       2 4       2 3    4 2  8
+--R                 (- 16a c  + 8a b c  - b c )x
+--R               + 
+--R                       2   3        3 2     5   6         3 3       4     6  4
+--R                 (- 32a b c  + 16a b c  - 2b c)x  + (- 32a c  + 6a b c - b )x
+--R               + 
+--R                       3   2      2 3        5  2      4 2     3 2     2 4
+--R                 (- 32a b c  + 16a b c - 2a b )x  - 16a c  + 8a b c - a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                     2 4        2 3     4 2  8        2   3        3 2     5   6
+--R                 (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R               + 
+--R                      3 3        4      6  4        3   2      2 3        5  2
+--R                 (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R               + 
+--R                    4 2      3 2      2 4
+--R                 64a c  - 32a b c + 4a b
+--R            *
+--R               log(x)
+--R           + 
+--R                   2   3       3 2  6       3 3      2 2 2       4   4
+--R             (- 14a b c  + 2a b c )x  + (16a c  - 29a b c  + 4a b c)x
+--R           + 
+--R                  3   2      2 3        5  2      4 2      3 2      2 4
+--R             (- 2a b c  - 12a b c + 2a b )x  + 24a c  - 21a b c + 3a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              7 2      6 2      5 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2   4        3 3     5 2  8
+--R             (- 60a b c  + 20a b c  - 2b c )x
+--R           + 
+--R                    2 2 3        4 2     6   6
+--R             (- 120a b c  + 40a b c  - 4b c)x
+--R           + 
+--R                    3   3      2 3 2        5      7  4
+--R             (- 120a b c  - 20a b c  + 16a b c - 2b )x
+--R           + 
+--R                    3 2 2      2 4        6  2      4   2      3 3      2 5
+--R             (- 120a b c  + 40a b c - 4a b )x  - 60a b c  + 20a b c - 2a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2 4       2 3    4 2  8
+--R                 (- 16a c  + 8a b c  - b c )x
+--R               + 
+--R                       2   3        3 2     5   6         3 3       4     6  4
+--R                 (- 32a b c  + 16a b c  - 2b c)x  + (- 32a c  + 6a b c - b )x
+--R               + 
+--R                       3   2      2 3        5  2      4 2     3 2     2 4
+--R                 (- 32a b c  + 16a b c - 2a b )x  - 16a c  + 8a b c - a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                     2 4        2 3     4 2  8        2   3        3 2     5   6
+--R                 (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R               + 
+--R                      3 3        4      6  4        3   2      2 3        5  2
+--R                 (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R               + 
+--R                    4 2      3 2      2 4
+--R                 64a c  - 32a b c + 4a b
+--R            *
+--R               log(x)
+--R           + 
+--R                   2   3       3 2  6       3 3      2 2 2       4   4
+--R             (- 14a b c  + 2a b c )x  + (16a c  - 29a b c  + 4a b c)x
+--R           + 
+--R                  3   2      2 3        5  2      4 2      3 2      2 4
+--R             (- 2a b c  - 12a b c + 2a b )x  + 24a c  - 21a b c + 3a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              7 2      6 2      5 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1138
+
+--S 1139 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2   2        3     5
+--R         (30a b c  - 10a b c + b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                                2
+--R             2   2        3      5          2c x  + b
+--R       (- 60a b c  + 20a b c - 2b )atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R  /
+--R                                +-----------+
+--R         5 2      4 2      3 4  |          2
+--R     (64a c  - 32a b c + 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1139
+
+--S 1140 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1140
+
+--S 1141 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                   +---------+             2
+--R             2   2        3     5  |        2          2c x  + b
+--R       (- 30a b c  + 10a b c - b )\|4a c - b  atanh(--------------)
+--R                                                     +-----------+
+--R                                                     |          2
+--R                                                    \|- 4a c + b
+--R     + 
+--R                                                                 +---------+
+--R                                   +-----------+          2      |        2
+--R             2   2        3     5  |          2      (2c x  + b)\|4a c - b
+--R       (- 30a b c  + 10a b c - b )\|- 4a c + b  atan(-----------------------)
+--R                                                                    2
+--R                                                            4a c - b
+--R  /
+--R                                +-----------+ +---------+
+--R         5 2      4 2      3 4  |          2  |        2
+--R     (32a c  - 16a b c + 2a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1141
+
+--S 1142 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1142
+
+)clear all
+
+--S 1143 of 1353
+t0:=1/(x^2*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 14       2 12        2     2   10              3  8      2        2  6
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   4    3 2
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1143
+
+--S 1144 of 1353
+r0:=-3/8*(5*b^2-12*a*c)*(b^2-5*a*c)/(a^3*(b^2-4*a*c)^2*x)+_
+   1/4*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x*(a+b*x^2+c*x^4)^2)+_
+   1/8*(5*b^4-35*a*b^2*c+36*a^2*c^2+b*c*(5*b^2-32*a*c)*x^2)/(a^2*_
+   (b^2-4*a*c)^2*x*(a+b*x^2+c*x^4))-3/8*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*((5*b^2-12*a*c)*(b^2-5*a*c)+_
+   b*(5*b^4-47*a*b^2*c+124*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^2*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-3/8*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*((5*b^2-12*a*c)*(b^2-5*a*c)+_
+   (-5*b^5+47*a*b^3*c-124*a^2*b*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^2*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )x
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)x
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )x
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )x
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2   4         3 3      5 2  9
+--R           (- 372a b c  + 141a b c  - 15b c )x
+--R         + 
+--R                  2 2 3         4 2      6   7
+--R           (- 744a b c  + 282a b c  - 30b c)x
+--R         + 
+--R                  3   3      2 3 2         5       7  5
+--R           (- 744a b c  - 90a b c  + 111a b c - 15b )x
+--R         + 
+--R                  3 2 2       2 4         6  3
+--R           (- 744a b c  + 282a b c - 30a b )x
+--R         + 
+--R                  4   2       3 3       2 5
+--R           (- 372a b c  + 141a b c - 15a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )x
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)x
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )x
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )x
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2   4         3 3      5 2  9
+--R           (372a b c  - 141a b c  + 15b c )x
+--R         + 
+--R                2 2 3         4 2      6   7
+--R           (744a b c  - 282a b c  + 30b c)x
+--R         + 
+--R                3   3      2 3 2         5       7  5
+--R           (744a b c  + 90a b c  - 111a b c + 15b )x
+--R         + 
+--R                3 2 2       2 4         6  3        4   2       3 3       2 5
+--R           (744a b c  - 282a b c + 30a b )x  + (372a b c  - 141a b c + 15a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 4         2 3      4 2  8
+--R           (- 180a c  + 111a b c  - 15b c )x
+--R         + 
+--R                  2   3         3 2      5   6
+--R           (- 392a b c  + 227a b c  - 30b c)x
+--R         + 
+--R                  3 3      2 2 2        4       6  4
+--R           (- 324a c  - 25a b c  + 91a b c - 15b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 364a b c  + 194a b c - 25a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              5 4      4 2 3     3 4 2  9        5   3       4 3 2      3 5   7
+--R         (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R              6 3      4 4      3 6  5        6   2       5 3       4 5  3
+--R         (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R              7 2      6 2      5 4
+--R         (128a c  - 64a b c + 8a b )x
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1144
+
+--S 1145 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 5 4      4 2 3     3 4 2  9
+--R           (- 64a c  + 32a b c  - 4a b c )x
+--R         + 
+--R                  5   3      4 3 2     3 5   7          6 3      4 4      3 6  5
+--R           (- 128a b c  + 64a b c  - 8a b c)x  + (- 128a c  + 24a b c - 4a b )x
+--R         + 
+--R                  6   2      5 3      4 5  3         7 2      6 2      5 4
+--R           (- 128a b c  + 64a b c - 8a b )x  + (- 64a c  + 32a b c - 4a b )x
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                  19 5            18 2 4            17 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    16 6 2           15 8          14 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                       12 5          11 2 4         10 4 3         9 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R              + 
+--R                     8 8        7 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                           8   8             7 3 7             6 5 6
+--R                  47692800a b c  - 204648192a b c  + 257282496a b c
+--R                + 
+--R                              5 7 5            4 9 4            3 11 3
+--R                  - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                + 
+--R                          2 13 2            15         17
+--R                  1776960a b  c  - 135900a b  c + 4500b
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                         19 5            18 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         17 4 3            16 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        15 8          14 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                              12 5          11 2 4         10 4 3         9 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                     + 
+--R                            8 8        7 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                x
+--R     + 
+--R               5 4      4 2 3     3 4 2  9        5   3      4 3 2     3 5   7
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                6 3      4 4      3 6  5        6   2      5 3      4 5  3
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R               7 2      6 2      5 4
+--R           (64a c  - 32a b c + 4a b )x
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                  19 5            18 2 4            17 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    16 6 2           15 8          14 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                       12 5          11 2 4         10 4 3         9 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R              + 
+--R                     8 8        7 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                             8   8             7 3 7             6 5 6
+--R                  - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                + 
+--R                            5 7 5            4 9 4            3 11 3
+--R                  160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                + 
+--R                            2 13 2            15         17
+--R                  - 1776960a b  c  + 135900a b  c - 4500b
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                         19 5            18 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         17 4 3            16 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        15 8          14 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                              12 5          11 2 4         10 4 3         9 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                     + 
+--R                            8 8        7 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                x
+--R     + 
+--R                 5 4      4 2 3     3 4 2  9
+--R           (- 64a c  + 32a b c  - 4a b c )x
+--R         + 
+--R                  5   3      4 3 2     3 5   7          6 3      4 4      3 6  5
+--R           (- 128a b c  + 64a b c  - 8a b c)x  + (- 128a c  + 24a b c - 4a b )x
+--R         + 
+--R                  6   2      5 3      4 5  3         7 2      6 2      5 4
+--R           (- 128a b c  + 64a b c - 8a b )x  + (- 64a c  + 32a b c - 4a b )x
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                  19 5            18 2 4            17 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    16 6 2           15 8          14 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                       12 5          11 2 4         10 4 3         9 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R              + 
+--R                     8 8        7 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                           8   8             7 3 7             6 5 6
+--R                  47692800a b c  - 204648192a b c  + 257282496a b c
+--R                + 
+--R                              5 7 5            4 9 4            3 11 3
+--R                  - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                + 
+--R                          2 13 2            15         17
+--R                  1776960a b  c  - 135900a b  c + 4500b
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                         19 5            18 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         17 4 3            16 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        15 8          14 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                              12 5          11 2 4         10 4 3         9 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                     + 
+--R                            8 8        7 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                x
+--R     + 
+--R               5 4      4 2 3     3 4 2  9        5   3      4 3 2     3 5   7
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                6 3      4 4      3 6  5        6   2      5 3      4 5  3
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R               7 2      6 2      5 4
+--R           (64a c  - 32a b c + 4a b )x
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                  19 5            18 2 4            17 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    16 6 2           15 8          14 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                       12 5          11 2 4         10 4 3         9 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R              + 
+--R                     8 8        7 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                             8   8             7 3 7             6 5 6
+--R                  - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                + 
+--R                            5 7 5            4 9 4            3 11 3
+--R                  160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                + 
+--R                            2 13 2            15         17
+--R                  - 1776960a b  c  + 135900a b  c - 4500b
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                         19 5            18 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         17 4 3            16 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        15 8          14 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                              12 5          11 2 4         10 4 3         9 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                     + 
+--R                            8 8        7 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                x
+--R     + 
+--R              2 4         2 3      4 2  8          2   3         3 2      5   6
+--R       (- 180a c  + 111a b c  - 15b c )x  + (- 392a b c  + 227a b c  - 30b c)x
+--R     + 
+--R              3 3      2 2 2        4       6  4
+--R       (- 324a c  - 25a b c  + 91a b c - 15b )x
+--R     + 
+--R              3   2       2 3         5  2       4 2      3 2      2 4
+--R       (- 364a b c  + 194a b c - 25a b )x  - 128a c  + 64a b c - 8a b
+--R  /
+--R            5 4      4 2 3     3 4 2  9        5   3       4 3 2      3 5   7
+--R       (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R     + 
+--R            6 3      4 4      3 6  5        6   2       5 3       4 5  3
+--R       (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R     + 
+--R            7 2      6 2      5 4
+--R       (128a c  - 64a b c + 8a b )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1145
+
+--S 1146 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R               5 2      4 2      3 4  +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                  19 5            18 2 4            17 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    16 6 2           15 8          14 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                       12 5          11 2 4         10 4 3         9 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R              + 
+--R                     8 8        7 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                           8   8             7 3 7             6 5 6
+--R                  47692800a b c  - 204648192a b c  + 257282496a b c
+--R                + 
+--R                              5 7 5            4 9 4            3 11 3
+--R                  - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                + 
+--R                          2 13 2            15         17
+--R                  1776960a b  c  - 135900a b  c + 4500b
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                         19 5            18 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         17 4 3            16 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        15 8          14 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                              12 5          11 2 4         10 4 3         9 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                     + 
+--R                            8 8        7 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                x
+--R     + 
+--R                                        +-----------+
+--R             5 2      4 2      3 4  +-+ |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                  19 5            18 2 4            17 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    16 6 2           15 8          14 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                       12 5          11 2 4         10 4 3         9 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R              + 
+--R                     8 8        7 10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                             8   8             7 3 7             6 5 6
+--R                  - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                + 
+--R                            5 7 5            4 9 4            3 11 3
+--R                  160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                + 
+--R                            2 13 2            15         17
+--R                  - 1776960a b  c  + 135900a b  c - 4500b
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                         19 5            18 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         17 4 3            16 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        15 8          14 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                              12 5          11 2 4         10 4 3         9 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                     + 
+--R                            8 8        7 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                x
+--R     + 
+--R                                          +-----------+
+--R               5 2      4 2      3 4  +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                  19 5            18 2 4            17 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    16 6 2           15 8          14 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                       12 5          11 2 4         10 4 3         9 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R              + 
+--R                     8 8        7 10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                           8   8             7 3 7             6 5 6
+--R                  47692800a b c  - 204648192a b c  + 257282496a b c
+--R                + 
+--R                              5 7 5            4 9 4            3 11 3
+--R                  - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                + 
+--R                          2 13 2            15         17
+--R                  1776960a b  c  - 135900a b  c + 4500b
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                         19 5            18 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         17 4 3            16 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        15 8          14 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                              12 5          11 2 4         10 4 3         9 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                     + 
+--R                            8 8        7 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                x
+--R     + 
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R             5 2      4 2      3 4  +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                  19 5            18 2 4            17 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    16 6 2           15 8          14 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                       12 5          11 2 4         10 4 3         9 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R              + 
+--R                     8 8        7 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                             8   8             7 3 7             6 5 6
+--R                  - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                + 
+--R                            5 7 5            4 9 4            3 11 3
+--R                  160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                + 
+--R                            2 13 2            15         17
+--R                  - 1776960a b  c  + 135900a b  c - 4500b
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                         19 5            18 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         17 4 3            16 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        15 8          14 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                              12 5          11 2 4         10 4 3         9 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                     + 
+--R                            8 8        7 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                x
+--R     + 
+--R                                         +-----------+
+--R                  2 2         2       4  |          2        2   2         3
+--R             (180a c  - 111a b c + 15b )\|- 4a c + b   + 372a b c  - 141a b c
+--R           + 
+--R                5
+--R             15b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +-----------+
+--R                  2 2         2       4  |          2        2   2         3
+--R             (180a c  - 111a b c + 15b )\|- 4a c + b   - 372a b c  + 141a b c
+--R           + 
+--R                  5
+--R             - 15b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R            5 2      4 2      3 4  +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1146
+
+--S 1147 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1147
+
+)clear all
+
+--S 1148 of 1353
+t0:=1/(x^3*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 15       2 13        2     2   11              3  9      2        2  7
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   5    3 3
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1148
+
+--S 1149 of 1353
+r0:=-3/2*(b^4-7*a*b^2*c+10*a^2*c^2)/(a^3*(b^2-4*a*c)^2*x^2)+_
+   1/4*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^2*(a+b*x^2+c*x^4)^2)+_
+   1/4*(3*b^4-20*a*b^2*c+20*a^2*c^2+3*b*c*(b^2-6*a*c)*x^2)/(a^2*(b^2-_
+   4*a*c)^2*x^2*(a+b*x^2+c*x^4))-3/2*(b^6-10*a*b^4*c+30*a^2*b^2*c^2-_
+   20*a^3*c^3)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(5/2))-_
+   3*b*log(x)/a^4+3/4*b*log(a+b*x^2+c*x^4)/a^4
+--R 
+--R
+--R   (2)
+--R                3 5       2 2 4        4 3     6 2  10
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )x
+--R         + 
+--R                3   4       2 3 3         5 2      7   8
+--R           (240a b c  - 360a b c  + 120a b c  - 12b c)x
+--R         + 
+--R                4 4       3 2 3      2 4 2        6      8  6
+--R           (240a c  - 240a b c  - 60a b c  + 48a b c - 6b )x
+--R         + 
+--R                4   3       3 3 2       2 5         7  4
+--R           (240a b c  - 360a b c  + 120a b c - 12a b )x
+--R         + 
+--R                5 3       4 2 2      3 4      2 6  2
+--R           (120a c  - 180a b c  + 60a b c - 6a b )x
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2   4        3 3     5 2  10       2 2 3        4 2     6   8
+--R               (48a b c  - 24a b c  + 3b c )x   + (96a b c  - 48a b c  + 6b c)x
+--R             + 
+--R                   3   3        5      7  6       3 2 2      2 4        6  4
+--R               (96a b c  - 18a b c + 3b )x  + (96a b c  - 48a b c + 6a b )x
+--R             + 
+--R                   4   2      3 3      2 5  2
+--R               (48a b c  - 24a b c + 3a b )x
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                      2   4        3 3      5 2  10
+--R               (- 192a b c  + 96a b c  - 12b c )x
+--R             + 
+--R                      2 2 3         4 2      6   8
+--R               (- 384a b c  + 192a b c  - 24b c)x
+--R             + 
+--R                      3   3        5       7  6
+--R               (- 384a b c  + 72a b c - 12b )x
+--R             + 
+--R                      3 2 2       2 4         6  4
+--R               (- 384a b c  + 192a b c - 24a b )x
+--R             + 
+--R                      4   2      3 3       2 5  2
+--R               (- 192a b c  + 96a b c - 12a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R                 3 4      2 2 3       4 2  8
+--R           (- 60a c  + 42a b c  - 6a b c )x
+--R         + 
+--R                  3   3      2 3 2        5   6
+--R           (- 138a b c  + 87a b c  - 12a b c)x
+--R         + 
+--R                  4 3      3 2 2      2 4        6  4
+--R           (- 100a c  - 14a b c  + 36a b c - 6a b )x
+--R         + 
+--R                  4   2      3 3      2 5  2      5 2      4 2      3 4
+--R           (- 122a b c  + 68a b c - 9a b )x  - 32a c  + 16a b c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             6 4      5 2 3     4 4 2  10        6   3      5 3 2     4 5   8
+--R         (64a c  - 32a b c  + 4a b c )x   + (128a b c  - 64a b c  + 8a b c)x
+--R       + 
+--R              7 3      5 4      4 6  6        7   2      6 3      5 5  4
+--R         (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R       + 
+--R             8 2      7 2      6 4  2
+--R         (64a c  - 32a b c + 4a b )x
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1149
+
+--S 1150 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3 5      2 2 4        4 3     6 2  10
+--R             (60a c  - 90a b c  + 30a b c  - 3b c )x
+--R           + 
+--R                  3   4       2 3 3        5 2     7   8
+--R             (120a b c  - 180a b c  + 60a b c  - 6b c)x
+--R           + 
+--R                  4 4       3 2 3      2 4 2        6      8  6
+--R             (120a c  - 120a b c  - 30a b c  + 24a b c - 3b )x
+--R           + 
+--R                  4   3       3 3 2      2 5        7  4
+--R             (120a b c  - 180a b c  + 60a b c - 6a b )x
+--R           + 
+--R                 5 3      4 2 2      3 4      2 6  2
+--R             (60a c  - 90a b c  + 30a b c - 3a b )x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                     2   4        3 3     5 2  10
+--R                 (48a b c  - 24a b c  + 3b c )x
+--R               + 
+--R                     2 2 3        4 2     6   8       3   3        5      7  6
+--R                 (96a b c  - 48a b c  + 6b c)x  + (96a b c  - 18a b c + 3b )x
+--R               + 
+--R                   3 2 2      2 4        6  4       4   2      3 3      2 5  2
+--R               (96a b c  - 48a b c + 6a b )x  + (48a b c  - 24a b c + 3a b )x
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                        2   4        3 3      5 2  10
+--R                 (- 192a b c  + 96a b c  - 12b c )x
+--R               + 
+--R                        2 2 3         4 2      6   8
+--R                 (- 384a b c  + 192a b c  - 24b c)x
+--R               + 
+--R                        3   3        5       7  6
+--R                 (- 384a b c  + 72a b c - 12b )x
+--R               + 
+--R                        3 2 2       2 4         6  4
+--R                 (- 384a b c  + 192a b c - 24a b )x
+--R               + 
+--R                        4   2      3 3       2 5  2
+--R                 (- 192a b c  + 96a b c - 12a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                   3 4      2 2 3       4 2  8
+--R             (- 60a c  + 42a b c  - 6a b c )x
+--R           + 
+--R                    3   3      2 3 2        5   6
+--R             (- 138a b c  + 87a b c  - 12a b c)x
+--R           + 
+--R                    4 3      3 2 2      2 4        6  4
+--R             (- 100a c  - 14a b c  + 36a b c - 6a b )x
+--R           + 
+--R                    4   2      3 3      2 5  2      5 2      4 2      3 4
+--R             (- 122a b c  + 68a b c - 9a b )x  - 32a c  + 16a b c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               6 4      5 2 3     4 4 2  10        6   3      5 3 2     4 5   8
+--R           (64a c  - 32a b c  + 4a b c )x   + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                7 3      5 4      4 6  6        7   2      6 3      5 5  4
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R               8 2      7 2      6 4  2
+--R           (64a c  - 32a b c + 4a b )x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    3 5       2 2 4        4 3     6 2  10
+--R             (- 120a c  + 180a b c  - 60a b c  + 6b c )x
+--R           + 
+--R                    3   4       2 3 3         5 2      7   8
+--R             (- 240a b c  + 360a b c  - 120a b c  + 12b c)x
+--R           + 
+--R                    4 4       3 2 3      2 4 2        6      8  6
+--R             (- 240a c  + 240a b c  + 60a b c  - 48a b c + 6b )x
+--R           + 
+--R                    4   3       3 3 2       2 5         7  4
+--R             (- 240a b c  + 360a b c  - 120a b c + 12a b )x
+--R           + 
+--R                    5 3       4 2 2      3 4      2 6  2
+--R             (- 120a c  + 180a b c  - 60a b c + 6a b )x
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                     2   4        3 3     5 2  10
+--R                 (48a b c  - 24a b c  + 3b c )x
+--R               + 
+--R                     2 2 3        4 2     6   8       3   3        5      7  6
+--R                 (96a b c  - 48a b c  + 6b c)x  + (96a b c  - 18a b c + 3b )x
+--R               + 
+--R                   3 2 2      2 4        6  4       4   2      3 3      2 5  2
+--R               (96a b c  - 48a b c + 6a b )x  + (48a b c  - 24a b c + 3a b )x
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                        2   4        3 3      5 2  10
+--R                 (- 192a b c  + 96a b c  - 12b c )x
+--R               + 
+--R                        2 2 3         4 2      6   8
+--R                 (- 384a b c  + 192a b c  - 24b c)x
+--R               + 
+--R                        3   3        5       7  6
+--R                 (- 384a b c  + 72a b c - 12b )x
+--R               + 
+--R                        3 2 2       2 4         6  4
+--R                 (- 384a b c  + 192a b c - 24a b )x
+--R               + 
+--R                        4   2      3 3       2 5  2
+--R                 (- 192a b c  + 96a b c - 12a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                   3 4      2 2 3       4 2  8
+--R             (- 60a c  + 42a b c  - 6a b c )x
+--R           + 
+--R                    3   3      2 3 2        5   6
+--R             (- 138a b c  + 87a b c  - 12a b c)x
+--R           + 
+--R                    4 3      3 2 2      2 4        6  4
+--R             (- 100a c  - 14a b c  + 36a b c - 6a b )x
+--R           + 
+--R                    4   2      3 3      2 5  2      5 2      4 2      3 4
+--R             (- 122a b c  + 68a b c - 9a b )x  - 32a c  + 16a b c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               6 4      5 2 3     4 4 2  10        6   3      5 3 2     4 5   8
+--R           (64a c  - 32a b c  + 4a b c )x   + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                7 3      5 4      4 6  6        7   2      6 3      5 5  4
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R               8 2      7 2      6 4  2
+--R           (64a c  - 32a b c + 4a b )x
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1150
+
+--S 1151 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             3 3      2 2 2        4      6
+--R         (60a c  - 90a b c  + 30a b c - 3b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                                           2
+--R              3 3       2 2 2        4      6          2c x  + b
+--R       (- 120a c  + 180a b c  - 60a b c + 6b )atanh(--------------)
+--R                                                     +-----------+
+--R                                                     |          2
+--R                                                    \|- 4a c + b
+--R  /
+--R                                +-----------+
+--R         6 2      5 2      4 4  |          2
+--R     (64a c  - 32a b c + 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1151
+
+--S 1152 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1152
+
+--S 1153 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                             +---------+             2
+--R             3 3      2 2 2        4      6  |        2          2c x  + b
+--R       (- 60a c  + 90a b c  - 30a b c + 3b )\|4a c - b  atanh(--------------)
+--R                                                               +-----------+
+--R                                                               |          2
+--R                                                              \|- 4a c + b
+--R     + 
+--R                                               +-----------+
+--R               3 3      2 2 2        4      6  |          2
+--R         (- 60a c  + 90a b c  - 30a b c + 3b )\|- 4a c + b
+--R      *
+--R                          +---------+
+--R                   2      |        2
+--R              (2c x  + b)\|4a c - b
+--R         atan(-----------------------)
+--R                             2
+--R                     4a c - b
+--R  /
+--R                                +-----------+ +---------+
+--R         6 2      5 2      4 4  |          2  |        2
+--R     (32a c  - 16a b c + 2a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1153
+
+--S 1154 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1154
+
+)clear all
+
+--S 1155 of 1353
+t0:=1/(x^4*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 16       2 14        2     2   12              3  10
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x
+--R     + 
+--R          2        2  8     2   6    3 4
+--R       (3a c + 3a b )x  + 3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1155
+
+--S 1156 of 1353
+r0:=1/24*(-35*b^4+235*a*b^2*c-308*a^2*c^2)/(a^3*(b^2-4*a*c)^2*x^3)+_
+   1/8*b*(35*b^4-270*a*b^2*c+508*a^2*c^2)/(a^4*(b^2-4*a*c)^2*x)+_
+   1/4*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^3*(a+b*x^2+c*x^4)^2)+_
+   1/8*(7*b^4-45*a*b^2*c+44*a^2*c^2+b*c*(7*b^2-40*a*c)*x^2)/(a^2*(b^2-_
+   4*a*c)^2*x^3*(a+b*x^2+c*x^4))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(35*b^5-270*a*b^3*c+508*a^2*b*c^2+(35*b^6-_
+   340*a*b^4*c+978*a^2*b^2*c^2-616*a^3*c^3)/sqrt(b^2-4*a*c))/(a^4*_
+   (b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/8*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(35*b^5-270*a*b^3*c+_
+   508*a^2*b*c^2+(-35*b^6+340*a*b^4*c-978*a^2*b^2*c^2+616*a^3*c^3)/_
+   sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )x
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)x
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )x
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )x
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3 5        2 2 4          4 3       6 2  11
+--R           (- 1848a c  + 2934a b c  - 1020a b c  + 105b c )x
+--R         + 
+--R                   3   4        2 3 3          5 2       7   9
+--R           (- 3696a b c  + 5868a b c  - 2040a b c  + 210b c)x
+--R         + 
+--R                   4 4        3 2 3       2 4 2         6        8  7
+--R           (- 3696a c  + 4020a b c  + 894a b c  - 810a b c + 105b )x
+--R         + 
+--R                   4   3        3 3 2        2 5          7  5
+--R           (- 3696a b c  + 5868a b c  - 2040a b c + 210a b )x
+--R         + 
+--R                   5 3        4 2 2        3 4        2 6  3
+--R           (- 1848a c  + 2934a b c  - 1020a b c + 105a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )x
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)x
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )x
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )x
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3 5        2 2 4          4 3       6 2  11
+--R           (1848a c  - 2934a b c  + 1020a b c  - 105b c )x
+--R         + 
+--R                 3   4        2 3 3          5 2       7   9
+--R           (3696a b c  - 5868a b c  + 2040a b c  - 210b c)x
+--R         + 
+--R                 4 4        3 2 3       2 4 2         6        8  7
+--R           (3696a c  - 4020a b c  - 894a b c  + 810a b c - 105b )x
+--R         + 
+--R                 4   3        3 3 2        2 5          7  5
+--R           (3696a b c  - 5868a b c  + 2040a b c - 210a b )x
+--R         + 
+--R                 5 3        4 2 2        3 4        2 6  3
+--R           (1848a c  - 2934a b c  + 1020a b c - 105a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 2   4         3 3       5 2  10
+--R           (1524a b c  - 810a b c  + 105b c )x
+--R         + 
+--R                  3 4        2 2 3          4 2       6   8
+--R           (- 308a c  + 3283a b c  - 1655a b c  + 210b c)x
+--R         + 
+--R                 3   3       2 3 2         5        7  6
+--R           (2312a b c  + 395a b c  - 670a b c + 105b )x
+--R         + 
+--R                  4 3        3 2 2        2 4          6  4
+--R           (- 484a c  + 2955a b c  - 1413a b c + 175a b )x
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (896a b c  - 448a b c + 56a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              6 4       5 2 3      4 4 2  11
+--R         (384a c  - 192a b c  + 24a b c )x
+--R       + 
+--R              6   3       5 3 2      4 5   9        7 3       5 4       4 6  7
+--R         (768a b c  - 384a b c  + 48a b c)x  + (768a c  - 144a b c + 24a b )x
+--R       + 
+--R              7   2       6 3       5 5  5        8 2       7 2       6 4  3
+--R         (768a b c  - 384a b c + 48a b )x  + (384a c  - 192a b c + 24a b )x
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1156
+
+--S 1157 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  6 4      5 2 3      4 4 2  11
+--R           (- 192a c  + 96a b c  - 12a b c )x
+--R         + 
+--R                  6   3       5 3 2      4 5   9
+--R           (- 384a b c  + 192a b c  - 24a b c)x
+--R         + 
+--R                  7 3      5 4       4 6  7
+--R           (- 384a c  + 72a b c - 12a b )x
+--R         + 
+--R                7   2       6 3       5 5  5          8 2      7 2       6 4  3
+--R         (- 384a b c  + 192a b c - 24a b )x  + (- 192a c  + 96a b c - 12a b )x
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                  23 5            22 2 4            21 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    20 6 2           19 8          18 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                       14 5          13 2 4         12 4 3         11 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R              + 
+--R                     10 8        9 10
+--R                2560a  b c - 128a b
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            10 10              9 2 9               8 4 8
+--R                  467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                + 
+--R                                7 6 7               6 8 6              5 10 5
+--R                  - 21970145504a b c  + 17711314348a b c  - 8747324300a b  c
+--R                + 
+--R                             4 12 4             3 14 3            2 16 2
+--R                  2769618280a b  c  - 566790200a b  c  + 72753100a b  c
+--R                + 
+--R                              18           20
+--R                  - 5341000a b  c + 171500b
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                         23 5            22 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         21 4 3            20 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        19 8          18 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                              14 5          13 2 4         12 4 3         11 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                     + 
+--R                            10 8        9 10
+--R                       2560a  b c - 128a b
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                x
+--R     + 
+--R                6 4      5 2 3      4 4 2  11
+--R           (192a c  - 96a b c  + 12a b c )x
+--R         + 
+--R                6   3       5 3 2      4 5   9        7 3      5 4       4 6  7
+--R           (384a b c  - 192a b c  + 24a b c)x  + (384a c  - 72a b c + 12a b )x
+--R         + 
+--R                7   2       6 3       5 5  5        8 2      7 2       6 4  3
+--R           (384a b c  - 192a b c + 24a b )x  + (192a c  - 96a b c + 12a b )x
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                  23 5            22 2 4            21 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    20 6 2           19 8          18 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                       14 5          13 2 4         12 4 3         11 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R              + 
+--R                     10 8        9 10
+--R                2560a  b c - 128a b
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                              10 10              9 2 9               8 4 8
+--R                  - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                + 
+--R                              7 6 7               6 8 6              5 10 5
+--R                  21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                + 
+--R                               4 12 4             3 14 3            2 16 2
+--R                  - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                + 
+--R                            18           20
+--R                  5341000a b  c - 171500b
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                         23 5            22 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         21 4 3            20 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        19 8          18 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                              14 5          13 2 4         12 4 3         11 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                     + 
+--R                            10 8        9 10
+--R                       2560a  b c - 128a b
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                x
+--R     + 
+--R                  6 4      5 2 3      4 4 2  11
+--R           (- 192a c  + 96a b c  - 12a b c )x
+--R         + 
+--R                  6   3       5 3 2      4 5   9
+--R           (- 384a b c  + 192a b c  - 24a b c)x
+--R         + 
+--R                  7 3      5 4       4 6  7
+--R           (- 384a c  + 72a b c - 12a b )x
+--R         + 
+--R                7   2       6 3       5 5  5          8 2      7 2       6 4  3
+--R         (- 384a b c  + 192a b c - 24a b )x  + (- 192a c  + 96a b c - 12a b )x
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                  23 5            22 2 4            21 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    20 6 2           19 8          18 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                       14 5          13 2 4         12 4 3         11 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R              + 
+--R                     10 8        9 10
+--R                2560a  b c - 128a b
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            10 10              9 2 9               8 4 8
+--R                  467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                + 
+--R                                7 6 7               6 8 6              5 10 5
+--R                  - 21970145504a b c  + 17711314348a b c  - 8747324300a b  c
+--R                + 
+--R                             4 12 4             3 14 3            2 16 2
+--R                  2769618280a b  c  - 566790200a b  c  + 72753100a b  c
+--R                + 
+--R                              18           20
+--R                  - 5341000a b  c + 171500b
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                         23 5            22 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         21 4 3            20 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        19 8          18 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                              14 5          13 2 4         12 4 3         11 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                     + 
+--R                            10 8        9 10
+--R                       2560a  b c - 128a b
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                x
+--R     + 
+--R                6 4      5 2 3      4 4 2  11
+--R           (192a c  - 96a b c  + 12a b c )x
+--R         + 
+--R                6   3       5 3 2      4 5   9        7 3      5 4       4 6  7
+--R           (384a b c  - 192a b c  + 24a b c)x  + (384a c  - 72a b c + 12a b )x
+--R         + 
+--R                7   2       6 3       5 5  5        8 2      7 2       6 4  3
+--R           (384a b c  - 192a b c + 24a b )x  + (192a c  - 96a b c + 12a b )x
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                  23 5            22 2 4            21 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    20 6 2           19 8          18 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                       14 5          13 2 4         12 4 3         11 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R              + 
+--R                     10 8        9 10
+--R                2560a  b c - 128a b
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                              10 10              9 2 9               8 4 8
+--R                  - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                + 
+--R                              7 6 7               6 8 6              5 10 5
+--R                  21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                + 
+--R                               4 12 4             3 14 3            2 16 2
+--R                  - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                + 
+--R                            18           20
+--R                  5341000a b  c - 171500b
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                         23 5            22 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         21 4 3            20 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        19 8          18 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                              14 5          13 2 4         12 4 3         11 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                     + 
+--R                            10 8        9 10
+--R                       2560a  b c - 128a b
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                x
+--R     + 
+--R             2   4         3 3       5 2  10
+--R       (1524a b c  - 810a b c  + 105b c )x
+--R     + 
+--R              3 4        2 2 3          4 2       6   8
+--R       (- 308a c  + 3283a b c  - 1655a b c  + 210b c)x
+--R     + 
+--R             3   3       2 3 2         5        7  6
+--R       (2312a b c  + 395a b c  - 670a b c + 105b )x
+--R     + 
+--R              4 3        3 2 2        2 4          6  4
+--R       (- 484a c  + 2955a b c  - 1413a b c + 175a b )x
+--R     + 
+--R            4   2       3 3       2 5  2       5 2      4 2      3 4
+--R       (896a b c  - 448a b c + 56a b )x  - 128a c  + 64a b c - 8a b
+--R  /
+--R            6 4       5 2 3      4 4 2  11        6   3       5 3 2      4 5   9
+--R       (384a c  - 192a b c  + 24a b c )x   + (768a b c  - 384a b c  + 48a b c)x
+--R     + 
+--R            7 3       5 4       4 6  7        7   2       6 3       5 5  5
+--R       (768a c  - 144a b c + 24a b )x  + (768a b c  - 384a b c + 48a b )x
+--R     + 
+--R            8 2       7 2       6 4  3
+--R       (384a c  - 192a b c + 24a b )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1157
+
+--S 1158 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R               6 2      5 2      4 4  +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                  23 5            22 2 4            21 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    20 6 2           19 8          18 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                       14 5          13 2 4         12 4 3         11 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R              + 
+--R                     10 8        9 10
+--R                2560a  b c - 128a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            10 10              9 2 9               8 4 8
+--R                  467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                + 
+--R                                7 6 7               6 8 6              5 10 5
+--R                  - 21970145504a b c  + 17711314348a b c  - 8747324300a b  c
+--R                + 
+--R                             4 12 4             3 14 3            2 16 2
+--R                  2769618280a b  c  - 566790200a b  c  + 72753100a b  c
+--R                + 
+--R                              18           20
+--R                  - 5341000a b  c + 171500b
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                         23 5            22 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         21 4 3            20 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        19 8          18 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                              14 5          13 2 4         12 4 3         11 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                     + 
+--R                            10 8        9 10
+--R                       2560a  b c - 128a b
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                x
+--R     + 
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R             6 2      5 2      4 4  +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                  23 5            22 2 4            21 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    20 6 2           19 8          18 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                       14 5          13 2 4         12 4 3         11 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R              + 
+--R                     10 8        9 10
+--R                2560a  b c - 128a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                              10 10              9 2 9               8 4 8
+--R                  - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                + 
+--R                              7 6 7               6 8 6              5 10 5
+--R                  21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                + 
+--R                               4 12 4             3 14 3            2 16 2
+--R                  - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                + 
+--R                            18           20
+--R                  5341000a b  c - 171500b
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                         23 5            22 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         21 4 3            20 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        19 8          18 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                              14 5          13 2 4         12 4 3         11 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                     + 
+--R                            10 8        9 10
+--R                       2560a  b c - 128a b
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                x
+--R     + 
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R               6 2      5 2      4 4  +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                  23 5            22 2 4            21 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    20 6 2           19 8          18 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                       14 5          13 2 4         12 4 3         11 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R              + 
+--R                     10 8        9 10
+--R                2560a  b c - 128a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            10 10              9 2 9               8 4 8
+--R                  467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                + 
+--R                                7 6 7               6 8 6              5 10 5
+--R                  - 21970145504a b c  + 17711314348a b c  - 8747324300a b  c
+--R                + 
+--R                             4 12 4             3 14 3            2 16 2
+--R                  2769618280a b  c  - 566790200a b  c  + 72753100a b  c
+--R                + 
+--R                              18           20
+--R                  - 5341000a b  c + 171500b
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                         23 5            22 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         21 4 3            20 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        19 8          18 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                              14 5          13 2 4         12 4 3         11 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                     + 
+--R                            10 8        9 10
+--R                       2560a  b c - 128a b
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                x
+--R     + 
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R             6 2      5 2      4 4  +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                  23 5            22 2 4            21 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    20 6 2           19 8          18 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                       14 5          13 2 4         12 4 3         11 6 2
+--R                131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R              + 
+--R                     10 8        9 10
+--R                2560a  b c - 128a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                              10 10              9 2 9               8 4 8
+--R                  - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                + 
+--R                              7 6 7               6 8 6              5 10 5
+--R                  21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                + 
+--R                               4 12 4             3 14 3            2 16 2
+--R                  - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                + 
+--R                            18           20
+--R                  5341000a b  c - 171500b
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                         23 5            22 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         21 4 3            20 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        19 8          18 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                              14 5          13 2 4         12 4 3         11 6 2
+--R                       131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                     + 
+--R                            10 8        9 10
+--R                       2560a  b c - 128a b
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                x
+--R     + 
+--R                                           +-----------+
+--R                  2   2         3       5  |          2        3 3       2 2 2
+--R           (- 508a b c  + 270a b c - 35b )\|- 4a c + b   + 616a c  - 978a b c
+--R         + 
+--R                 4       6
+--R           340a b c - 35b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                           +-----------+
+--R                  2   2         3       5  |          2        3 3       2 2 2
+--R           (- 508a b c  + 270a b c - 35b )\|- 4a c + b   - 616a c  + 978a b c
+--R         + 
+--R                   4       6
+--R           - 340a b c + 35b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R            6 2      5 2      4 4  +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1158
+
+--S 1159 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1159
+
+)clear all
+
+--S 1160 of 1353
+t0:=1/(a^2+b+2*a*x^2+x^4)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         4       2        2
+--R        x  + 2a x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1160
+
+--S 1161 of 1353
+r0:=1/2*atan(x/sqrt(a-sqrt(-b)))/(sqrt(-b)*sqrt(a-sqrt(-b)))-_
+   1/2*atan(x/sqrt(a+sqrt(-b)))/(sqrt(-b)*sqrt(a+sqrt(-b)))
+--R 
+--R
+--R   (2)
+--R    +----------+                         +------------+
+--R    | +---+                 x            |   +---+                x
+--R   \|\|- b  + a atan(---------------) - \|- \|- b  + a atan(-------------)
+--R                      +------------+                         +----------+
+--R                      |   +---+                              | +---+
+--R                     \|- \|- b  + a                         \|\|- b  + a
+--R   -----------------------------------------------------------------------
+--R                             +------------+ +----------+
+--R                       +---+ |   +---+      | +---+
+--R                     2\|- b \|- \|- b  + a \|\|- b  + a
+--R                                                    Type: Expression(Integer)
+--E 1161
+
+--S 1162 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-------------------------------------------+
+--R          |             +------------------------+
+--R          |   2     2   |             1
+--R          |(8b  + 8a b) |- ----------------------  + a
+--R          |             |     3       2 2      4
+--R          |            \|  64b  + 128a b  + 64a b
+--R          |-------------------------------------------
+--R          |                   2     2
+--R         \|                 4b  + 4a b
+--R      *
+--R         log
+--R                                  +------------------------+
+--R                       2      3   |             1
+--R                ((16a b  + 16a b) |- ----------------------  + 2b)
+--R                                  |     3       2 2      4
+--R                                 \|  64b  + 128a b  + 64a b
+--R             *
+--R                 +-------------------------------------------+
+--R                 |             +------------------------+
+--R                 |   2     2   |             1
+--R                 |(8b  + 8a b) |- ----------------------  + a
+--R                 |             |     3       2 2      4
+--R                 |            \|  64b  + 128a b  + 64a b
+--R                 |-------------------------------------------
+--R                 |                   2     2
+--R                \|                 4b  + 4a b
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +---------------------------------------------+
+--R             |               +------------------------+
+--R             |     2     2   |             1
+--R             |(- 8b  - 8a b) |- ----------------------  + a
+--R             |               |     3       2 2      4
+--R             |              \|  64b  + 128a b  + 64a b
+--R             |---------------------------------------------
+--R             |                    2     2
+--R            \|                  4b  + 4a b
+--R         *
+--R            log
+--R                                     +------------------------+
+--R                          2      3   |             1
+--R                   ((16a b  + 16a b) |- ----------------------  - 2b)
+--R                                     |     3       2 2      4
+--R                                    \|  64b  + 128a b  + 64a b
+--R                *
+--R                    +---------------------------------------------+
+--R                    |               +------------------------+
+--R                    |     2     2   |             1
+--R                    |(- 8b  - 8a b) |- ----------------------  + a
+--R                    |               |     3       2 2      4
+--R                    |              \|  64b  + 128a b  + 64a b
+--R                    |---------------------------------------------
+--R                    |                    2     2
+--R                   \|                  4b  + 4a b
+--R               + 
+--R                 x
+--R     + 
+--R          +---------------------------------------------+
+--R          |               +------------------------+
+--R          |     2     2   |             1
+--R          |(- 8b  - 8a b) |- ----------------------  + a
+--R          |               |     3       2 2      4
+--R          |              \|  64b  + 128a b  + 64a b
+--R          |---------------------------------------------
+--R          |                    2     2
+--R         \|                  4b  + 4a b
+--R      *
+--R         log
+--R                                    +------------------------+
+--R                         2      3   |             1
+--R                ((- 16a b  - 16a b) |- ----------------------  + 2b)
+--R                                    |     3       2 2      4
+--R                                   \|  64b  + 128a b  + 64a b
+--R             *
+--R                 +---------------------------------------------+
+--R                 |               +------------------------+
+--R                 |     2     2   |             1
+--R                 |(- 8b  - 8a b) |- ----------------------  + a
+--R                 |               |     3       2 2      4
+--R                 |              \|  64b  + 128a b  + 64a b
+--R                 |---------------------------------------------
+--R                 |                    2     2
+--R                \|                  4b  + 4a b
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +-------------------------------------------+
+--R             |             +------------------------+
+--R             |   2     2   |             1
+--R             |(8b  + 8a b) |- ----------------------  + a
+--R             |             |     3       2 2      4
+--R             |            \|  64b  + 128a b  + 64a b
+--R             |-------------------------------------------
+--R             |                   2     2
+--R            \|                 4b  + 4a b
+--R         *
+--R            log
+--R                                       +------------------------+
+--R                            2      3   |             1
+--R                   ((- 16a b  - 16a b) |- ----------------------  - 2b)
+--R                                       |     3       2 2      4
+--R                                      \|  64b  + 128a b  + 64a b
+--R                *
+--R                    +-------------------------------------------+
+--R                    |             +------------------------+
+--R                    |   2     2   |             1
+--R                    |(8b  + 8a b) |- ----------------------  + a
+--R                    |             |     3       2 2      4
+--R                    |            \|  64b  + 128a b  + 64a b
+--R                    |-------------------------------------------
+--R                    |                   2     2
+--R                   \|                 4b  + 4a b
+--R               + 
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1162
+
+--S 1163 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +------------+ +----------+
+--R          +---+ |   +---+      | +---+
+--R         \|- b \|- \|- b  + a \|\|- b  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |             +------------------------+
+--R          |   2     2   |             1
+--R          |(8b  + 8a b) |- ----------------------  + a
+--R          |             |     3       2 2      4
+--R          |            \|  64b  + 128a b  + 64a b
+--R          |-------------------------------------------
+--R          |                   2     2
+--R         \|                 4b  + 4a b
+--R      *
+--R         log
+--R                                  +------------------------+
+--R                       2      3   |             1
+--R                ((16a b  + 16a b) |- ----------------------  + 2b)
+--R                                  |     3       2 2      4
+--R                                 \|  64b  + 128a b  + 64a b
+--R             *
+--R                 +-------------------------------------------+
+--R                 |             +------------------------+
+--R                 |   2     2   |             1
+--R                 |(8b  + 8a b) |- ----------------------  + a
+--R                 |             |     3       2 2      4
+--R                 |            \|  64b  + 128a b  + 64a b
+--R                 |-------------------------------------------
+--R                 |                   2     2
+--R                \|                 4b  + 4a b
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                   +---------------------------------------------+
+--R                   |               +------------------------+
+--R                   |     2     2   |             1
+--R                   |(- 8b  - 8a b) |- ----------------------  + a
+--R                   |               |     3       2 2      4
+--R             +---+ |              \|  64b  + 128a b  + 64a b
+--R            \|- b  |---------------------------------------------
+--R                   |                    2     2
+--R                  \|                  4b  + 4a b
+--R         *
+--R             +------------+ +----------+
+--R             |   +---+      | +---+
+--R            \|- \|- b  + a \|\|- b  + a
+--R         *
+--R            log
+--R                                     +------------------------+
+--R                          2      3   |             1
+--R                   ((16a b  + 16a b) |- ----------------------  - 2b)
+--R                                     |     3       2 2      4
+--R                                    \|  64b  + 128a b  + 64a b
+--R                *
+--R                    +---------------------------------------------+
+--R                    |               +------------------------+
+--R                    |     2     2   |             1
+--R                    |(- 8b  - 8a b) |- ----------------------  + a
+--R                    |               |     3       2 2      4
+--R                    |              \|  64b  + 128a b  + 64a b
+--R                    |---------------------------------------------
+--R                    |                    2     2
+--R                   \|                  4b  + 4a b
+--R               + 
+--R                 x
+--R     + 
+--R                +---------------------------------------------+
+--R                |               +------------------------+
+--R                |     2     2   |             1
+--R                |(- 8b  - 8a b) |- ----------------------  + a
+--R                |               |     3       2 2      4        +------------+
+--R          +---+ |              \|  64b  + 128a b  + 64a b       |   +---+
+--R         \|- b  |--------------------------------------------- \|- \|- b  + a
+--R                |                    2     2
+--R               \|                  4b  + 4a b
+--R      *
+--R          +----------+
+--R          | +---+
+--R         \|\|- b  + a
+--R      *
+--R         log
+--R                                    +------------------------+
+--R                         2      3   |             1
+--R                ((- 16a b  - 16a b) |- ----------------------  + 2b)
+--R                                    |     3       2 2      4
+--R                                   \|  64b  + 128a b  + 64a b
+--R             *
+--R                 +---------------------------------------------+
+--R                 |               +------------------------+
+--R                 |     2     2   |             1
+--R                 |(- 8b  - 8a b) |- ----------------------  + a
+--R                 |               |     3       2 2      4
+--R                 |              \|  64b  + 128a b  + 64a b
+--R                 |---------------------------------------------
+--R                 |                    2     2
+--R                \|                  4b  + 4a b
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                   +------------+ +----------+
+--R             +---+ |   +---+      | +---+
+--R            \|- b \|- \|- b  + a \|\|- b  + a
+--R         *
+--R             +-------------------------------------------+
+--R             |             +------------------------+
+--R             |   2     2   |             1
+--R             |(8b  + 8a b) |- ----------------------  + a
+--R             |             |     3       2 2      4
+--R             |            \|  64b  + 128a b  + 64a b
+--R             |-------------------------------------------
+--R             |                   2     2
+--R            \|                 4b  + 4a b
+--R         *
+--R            log
+--R                                       +------------------------+
+--R                            2      3   |             1
+--R                   ((- 16a b  - 16a b) |- ----------------------  - 2b)
+--R                                       |     3       2 2      4
+--R                                      \|  64b  + 128a b  + 64a b
+--R                *
+--R                    +-------------------------------------------+
+--R                    |             +------------------------+
+--R                    |   2     2   |             1
+--R                    |(8b  + 8a b) |- ----------------------  + a
+--R                    |             |     3       2 2      4
+--R                    |            \|  64b  + 128a b  + 64a b
+--R                    |-------------------------------------------
+--R                    |                   2     2
+--R                   \|                 4b  + 4a b
+--R               + 
+--R                 x
+--R     + 
+--R        +----------+                         +------------+
+--R        | +---+                 x            |   +---+                x
+--R     - \|\|- b  + a atan(---------------) + \|- \|- b  + a atan(-------------)
+--R                          +------------+                         +----------+
+--R                          |   +---+                              | +---+
+--R                         \|- \|- b  + a                         \|\|- b  + a
+--R  /
+--R             +------------+ +----------+
+--R       +---+ |   +---+      | +---+
+--R     2\|- b \|- \|- b  + a \|\|- b  + a
+--R                                                    Type: Expression(Integer)
+--E 1163
+
+--S 1164 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1164
+
+)clear all
+
+--S 1165 of 1353
+t0:=1/(-1+a^2+2*a*x^2+x^4)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         4       2    2
+--R        x  + 2a x  + a  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1165
+
+--S 1166 of 1353
+r0:=-1/2*atanh(x/sqrt(1-a))/sqrt(1-a)-1/2*atan(x/sqrt(1+a))/sqrt(1+a)
+--R 
+--R
+--R           +-----+           x         +-------+         x
+--R        - \|a + 1 atanh(----------) - \|- a + 1 atan(--------)
+--R                         +-------+                    +-----+
+--R                        \|- a + 1                    \|a + 1
+--R   (2)  ------------------------------------------------------
+--R                            +-------+ +-----+
+--R                          2\|- a + 1 \|a + 1
+--R                                                    Type: Expression(Integer)
+--E 1166
+
+--S 1167 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         2          +-------+
+--R          +-------+    (x  - a + 1)\|- a + 1  + (2a - 2)x
+--R         \|- a - 1 log(----------------------------------)
+--R                                    2
+--R                                   x  + a - 1
+--R       + 
+--R                         2          +-------+
+--R          +-------+    (x  - a - 1)\|- a - 1  + (- 2a - 2)x
+--R         \|- a + 1 log(------------------------------------)
+--R                                     2
+--R                                    x  + a + 1
+--R    /
+--R         +-------+ +-------+
+--R       4\|- a - 1 \|- a + 1
+--R     ,
+--R
+--R                       2          +-------+
+--R          +-----+    (x  - a - 1)\|- a - 1  + (- 2a - 2)x
+--R         \|a - 1 log(------------------------------------)
+--R                                   2
+--R                                  x  + a + 1
+--R       + 
+--R                           +-----+
+--R           +-------+     x\|a - 1
+--R         2\|- a - 1 atan(---------)
+--R                           a - 1
+--R    /
+--R         +-------+ +-----+
+--R       4\|- a - 1 \|a - 1
+--R     ,
+--R                  2          +-------+                                  +-----+
+--R     +-----+    (x  - a + 1)\|- a + 1  + (2a - 2)x      +-------+     x\|a + 1
+--R    \|a + 1 log(----------------------------------) - 2\|- a + 1 atan(---------)
+--R                             2                                          a + 1
+--R                            x  + a - 1
+--R    ----------------------------------------------------------------------------
+--R                                   +-------+ +-----+
+--R                                 4\|- a + 1 \|a + 1
+--R     ,
+--R                     +-----+                   +-----+
+--R       +-----+     x\|a + 1      +-----+     x\|a - 1
+--R    - \|a - 1 atan(---------) + \|a + 1 atan(---------)
+--R                     a + 1                     a - 1
+--R    ---------------------------------------------------]
+--R                       +-----+ +-----+
+--R                     2\|a - 1 \|a + 1
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1167
+
+--S 1168 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                               2          +-------+
+--R        +-------+ +-----+    (x  - a + 1)\|- a + 1  + (2a - 2)x
+--R       \|- a - 1 \|a + 1 log(----------------------------------)
+--R                                          2
+--R                                         x  + a - 1
+--R     + 
+--R                               2          +-------+
+--R        +-------+ +-----+    (x  - a - 1)\|- a - 1  + (- 2a - 2)x
+--R       \|- a + 1 \|a + 1 log(------------------------------------)
+--R                                           2
+--R                                          x  + a + 1
+--R     + 
+--R       +-------+ +-----+           x          +-------+ +-------+         x
+--R     2\|- a - 1 \|a + 1 atanh(----------) + 2\|- a - 1 \|- a + 1 atan(--------)
+--R                               +-------+                               +-----+
+--R                              \|- a + 1                               \|a + 1
+--R  /
+--R       +-------+ +-------+ +-----+
+--R     4\|- a - 1 \|- a + 1 \|a + 1
+--R                                                    Type: Expression(Integer)
+--E 1168
+
+--S 1169 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1169
+
+--S 1170 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                       2          +-------+
+--R        +-------+ +-----+ +-----+    (x  - a - 1)\|- a - 1  + (- 2a - 2)x
+--R       \|- a + 1 \|a - 1 \|a + 1 log(------------------------------------)
+--R                                                   2
+--R                                                  x  + a + 1
+--R     + 
+--R         +-------+ +-----+ +-----+           x
+--R       2\|- a - 1 \|a - 1 \|a + 1 atanh(----------)
+--R                                         +-------+
+--R                                        \|- a + 1
+--R     + 
+--R                                           +-----+
+--R         +-------+ +-------+ +-----+     x\|a - 1
+--R       2\|- a - 1 \|- a + 1 \|a + 1 atan(---------)
+--R                                           a - 1
+--R     + 
+--R         +-------+ +-------+ +-----+         x
+--R       2\|- a - 1 \|- a + 1 \|a - 1 atan(--------)
+--R                                          +-----+
+--R                                         \|a + 1
+--R  /
+--R       +-------+ +-------+ +-----+ +-----+
+--R     4\|- a - 1 \|- a + 1 \|a - 1 \|a + 1
+--R                                                    Type: Expression(Integer)
+--E 1170
+
+--S 1171 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1171
+
+)clear all
+
+--S 1172 of 1353
+t0:=1/(1+a^2+2*a*x^2+x^4)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         4       2    2
+--R        x  + 2a x  + a  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1172
+
+--S 1173 of 1353
+r0:=-1/2*atan((x*sqrt(2)+sqrt(-a-sqrt(1+a^2)))/sqrt(a-sqrt(1+a^2)))/_
+   (sqrt(2)*sqrt(1+a^2)*sqrt(a-sqrt(1+a^2)))+1/2*atan((-2*x+sqrt(2)*_
+   sqrt(-a-sqrt(1+a^2)))/(sqrt(2)*sqrt(a-sqrt(1+a^2))))/(sqrt(2)*_
+   sqrt(1+a^2)*sqrt(a-sqrt(1+a^2)))-1/2*atan((-x*sqrt(2)+sqrt(-a+_
+   sqrt(1+a^2)))/sqrt(a+sqrt(1+a^2)))/(sqrt(2)*sqrt(1+a^2)*sqrt(a+_
+   sqrt(1+a^2)))+1/2*atan((x*sqrt(2)+sqrt(-a+sqrt(1+a^2)))/sqrt(a+_
+   sqrt(1+a^2)))/(sqrt(2)*sqrt(1+a^2)*sqrt(a+sqrt(1+a^2)))
+--R 
+--R
+--R   (2)
+--R                               +---------------+
+--R          +-------------+      |   +------+
+--R          | +------+           |   | 2               +-+
+--R          | | 2               \|- \|a  + 1  - a  + x\|2
+--R       - \|\|a  + 1  + a atan(--------------------------)
+--R                                   +---------------+
+--R                                   |   +------+
+--R                                   |   | 2
+--R                                  \|- \|a  + 1  + a
+--R     + 
+--R                                 +---------------+
+--R        +-------------+          |   +------+
+--R        | +------+           +-+ |   | 2
+--R        | | 2               \|2 \|- \|a  + 1  - a  - 2x
+--R       \|\|a  + 1  + a atan(---------------------------)
+--R                                    +---------------+
+--R                                    |   +------+
+--R                                +-+ |   | 2
+--R                               \|2 \|- \|a  + 1  + a
+--R     + 
+--R                               +-------------+
+--R        +---------------+      | +------+
+--R        |   +------+           | | 2               +-+
+--R        |   | 2               \|\|a  + 1  - a  + x\|2
+--R       \|- \|a  + 1  + a atan(------------------------)
+--R                                   +-------------+
+--R                                   | +------+
+--R                                   | | 2
+--R                                  \|\|a  + 1  + a
+--R     + 
+--R                                 +-------------+
+--R          +---------------+      | +------+
+--R          |   +------+           | | 2               +-+
+--R          |   | 2               \|\|a  + 1  - a  - x\|2
+--R       - \|- \|a  + 1  + a atan(------------------------)
+--R                                     +-------------+
+--R                                     | +------+
+--R                                     | | 2
+--R                                    \|\|a  + 1  + a
+--R  /
+--R                    +---------------+ +-------------+
+--R           +------+ |   +------+      | +------+
+--R       +-+ | 2      |   | 2           | | 2
+--R     2\|2 \|a  + 1 \|- \|a  + 1  + a \|\|a  + 1  + a
+--R                                                    Type: Expression(Integer)
+--E 1173
+
+--S 1174 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                                           +-----------------+
+--R                                    2      |        1
+--R                                 (8a  + 8) |-----------------
+--R                                           |   4       2
+--R                                          \|64a  + 128a  + 64
+--R             +---------+    atan(-----------------------------)
+--R             |    1                            a
+--R             |--------- cos(-----------------------------------)
+--R            4|   2                           2
+--R            \|16a  + 16
+--R         *
+--R            log
+--R                                                           +-----------------+  2
+--R                                                    2      |        1
+--R                                                 (8a  + 8) |-----------------
+--R                                                           |   4       2
+--R                                                          \|64a  + 128a  + 64
+--R                            +---------+2    atan(-----------------------------)
+--R                    2       |    1                             a
+--R                 (4a  + 4)  |---------  sin(-----------------------------------)
+--R                           4|   2                            2
+--R                           \|16a  + 16
+--R               + 
+--R                                 +-----------------+  +---------+
+--R                       3         |        1           |    1
+--R                   (32a  + 32a)x |-----------------   |---------
+--R                                 |   4       2       4|   2
+--R                                \|64a  + 128a  + 64  \|16a  + 16
+--R                *
+--R                                      +-----------------+
+--R                               2      |        1
+--R                            (8a  + 8) |-----------------
+--R                                      |   4       2
+--R                                     \|64a  + 128a  + 64
+--R                       atan(-----------------------------)
+--R                                          a
+--R                   sin(-----------------------------------)
+--R                                        2
+--R               + 
+--R                                                           +-----------------+  2
+--R                                                    2      |        1
+--R                                                 (8a  + 8) |-----------------
+--R                                                           |   4       2
+--R                                                          \|64a  + 128a  + 64
+--R                            +---------+2    atan(-----------------------------)
+--R                    2       |    1                             a
+--R                 (4a  + 4)  |---------  cos(-----------------------------------)
+--R                           4|   2                            2
+--R                           \|16a  + 16
+--R               + 
+--R                                                     +-----------------+
+--R                                              2      |        1
+--R                                           (8a  + 8) |-----------------
+--R                                                     |   4       2
+--R                                                    \|64a  + 128a  + 64
+--R                       +---------+    atan(-----------------------------)
+--R                       |    1                            a                   2
+--R                 - 4x  |--------- cos(----------------------------------- + x
+--R                      4|   2                           2
+--R                      \|16a  + 16
+--R     + 
+--R                                        +-----------------+
+--R                                 2      |        1
+--R                              (8a  + 8) |-----------------
+--R                                        |   4       2
+--R                                       \|64a  + 128a  + 64
+--R          +---------+    atan(-----------------------------)
+--R          |    1                            a
+--R          |--------- cos(-----------------------------------)
+--R         4|   2                           2
+--R         \|16a  + 16
+--R      *
+--R         log
+--R                                                        +-----------------+  2
+--R                                                 2      |        1
+--R                                              (8a  + 8) |-----------------
+--R                                                        |   4       2
+--R                                                       \|64a  + 128a  + 64
+--R                         +---------+2    atan(-----------------------------)
+--R                 2       |    1                             a
+--R              (4a  + 4)  |---------  sin(-----------------------------------)
+--R                        4|   2                            2
+--R                        \|16a  + 16
+--R            + 
+--R                                +-----------------+  +---------+
+--R                      3         |        1           |    1
+--R                (- 32a  - 32a)x |-----------------   |---------
+--R                                |   4       2       4|   2
+--R                               \|64a  + 128a  + 64  \|16a  + 16
+--R             *
+--R                                   +-----------------+
+--R                            2      |        1
+--R                         (8a  + 8) |-----------------
+--R                                   |   4       2
+--R                                  \|64a  + 128a  + 64
+--R                    atan(-----------------------------)
+--R                                       a
+--R                sin(-----------------------------------)
+--R                                     2
+--R            + 
+--R                                                        +-----------------+  2
+--R                                                 2      |        1
+--R                                              (8a  + 8) |-----------------
+--R                                                        |   4       2
+--R                                                       \|64a  + 128a  + 64
+--R                         +---------+2    atan(-----------------------------)
+--R                 2       |    1                             a
+--R              (4a  + 4)  |---------  cos(-----------------------------------)
+--R                        4|   2                            2
+--R                        \|16a  + 16
+--R            + 
+--R                                                +-----------------+
+--R                                         2      |        1
+--R                                      (8a  + 8) |-----------------
+--R                                                |   4       2
+--R                                               \|64a  + 128a  + 64
+--R                  +---------+    atan(-----------------------------)
+--R                  |    1                            a                   2
+--R              4x  |--------- cos(----------------------------------- + x
+--R                 4|   2                           2
+--R                 \|16a  + 16
+--R     + 
+--R                                          +-----------------+
+--R                                   2      |        1
+--R                                (8a  + 8) |-----------------
+--R                                          |   4       2
+--R                                         \|64a  + 128a  + 64
+--R            +---------+    atan(-----------------------------)
+--R            |    1                            a
+--R         2  |--------- sin(-----------------------------------)
+--R           4|   2                           2
+--R           \|16a  + 16
+--R      *
+--R         atan
+--R                                                 +-----------------+
+--R                                          2      |        1
+--R                                       (8a  + 8) |-----------------
+--R                                                 |   4       2
+--R                                                \|64a  + 128a  + 64
+--R                   +---------+    atan(-----------------------------)
+--R                   |    1                            a
+--R                2  |--------- sin(-----------------------------------)
+--R                  4|   2                           2
+--R                  \|16a  + 16
+--R              + 
+--R                               +-----------------+  +---------+
+--R                      3        |        1           |    1
+--R                  (16a  + 16a) |-----------------   |---------
+--R                               |   4       2       4|   2
+--R                              \|64a  + 128a  + 64  \|16a  + 16
+--R               *
+--R                                     +-----------------+
+--R                              2      |        1
+--R                           (8a  + 8) |-----------------
+--R                                     |   4       2
+--R                                    \|64a  + 128a  + 64
+--R                      atan(-----------------------------)
+--R                                         a
+--R                  cos(-----------------------------------)
+--R                                       2
+--R           /
+--R                               +-----------------+  +---------+
+--R                      3        |        1           |    1
+--R                  (16a  + 16a) |-----------------   |---------
+--R                               |   4       2       4|   2
+--R                              \|64a  + 128a  + 64  \|16a  + 16
+--R               *
+--R                                     +-----------------+
+--R                              2      |        1
+--R                           (8a  + 8) |-----------------
+--R                                     |   4       2
+--R                                    \|64a  + 128a  + 64
+--R                      atan(-----------------------------)
+--R                                         a
+--R                  sin(-----------------------------------)
+--R                                       2
+--R              + 
+--R                                                   +-----------------+
+--R                                            2      |        1
+--R                                         (8a  + 8) |-----------------
+--R                                                   |   4       2
+--R                                                  \|64a  + 128a  + 64
+--R                     +---------+    atan(-----------------------------)
+--R                     |    1                            a
+--R                - 2  |--------- cos(----------------------------------- - x
+--R                    4|   2                           2
+--R                    \|16a  + 16
+--R     + 
+--R       -
+--R                                             +-----------------+
+--R                                      2      |        1
+--R                                   (8a  + 8) |-----------------
+--R                                             |   4       2
+--R                                            \|64a  + 128a  + 64
+--R               +---------+    atan(-----------------------------)
+--R               |    1                            a
+--R            2  |--------- sin(-----------------------------------)
+--R              4|   2                           2
+--R              \|16a  + 16
+--R         *
+--R            atan
+--R                                                    +-----------------+
+--R                                             2      |        1
+--R                                          (8a  + 8) |-----------------
+--R                                                    |   4       2
+--R                                                   \|64a  + 128a  + 64
+--R                      +---------+    atan(-----------------------------)
+--R                      |    1                            a
+--R                   2  |--------- sin(-----------------------------------)
+--R                     4|   2                           2
+--R                     \|16a  + 16
+--R                 + 
+--R                                  +-----------------+  +---------+
+--R                         3        |        1           |    1
+--R                     (16a  + 16a) |-----------------   |---------
+--R                                  |   4       2       4|   2
+--R                                 \|64a  + 128a  + 64  \|16a  + 16
+--R                  *
+--R                                        +-----------------+
+--R                                 2      |        1
+--R                              (8a  + 8) |-----------------
+--R                                        |   4       2
+--R                                       \|64a  + 128a  + 64
+--R                         atan(-----------------------------)
+--R                                            a
+--R                     cos(-----------------------------------)
+--R                                          2
+--R              /
+--R                                  +-----------------+  +---------+
+--R                         3        |        1           |    1
+--R                     (16a  + 16a) |-----------------   |---------
+--R                                  |   4       2       4|   2
+--R                                 \|64a  + 128a  + 64  \|16a  + 16
+--R                  *
+--R                                        +-----------------+
+--R                                 2      |        1
+--R                              (8a  + 8) |-----------------
+--R                                        |   4       2
+--R                                       \|64a  + 128a  + 64
+--R                         atan(-----------------------------)
+--R                                            a
+--R                     sin(-----------------------------------)
+--R                                          2
+--R                 + 
+--R                                                      +-----------------+
+--R                                               2      |        1
+--R                                            (8a  + 8) |-----------------
+--R                                                      |   4       2
+--R                                                     \|64a  + 128a  + 64
+--R                        +---------+    atan(-----------------------------)
+--R                        |    1                            a
+--R                   - 2  |--------- cos(----------------------------------- + x
+--R                       4|   2                           2
+--R                       \|16a  + 16
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1174
+
+--S 1175 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                       +---------------+ +-------------+
+--R                  +---------+ +------+ |   +------+      | +------+
+--R             +-+  |    1      | 2      |   | 2           | | 2
+--R            \|2   |--------- \|a  + 1 \|- \|a  + 1  + a \|\|a  + 1  + a
+--R                 4|   2
+--R                 \|16a  + 16
+--R         *
+--R                               +-----------------+
+--R                        2      |        1
+--R                     (8a  + 8) |-----------------
+--R                               |   4       2
+--R                              \|64a  + 128a  + 64
+--R                atan(-----------------------------)
+--R                                   a
+--R            cos(-----------------------------------)
+--R                                 2
+--R         *
+--R            log
+--R                                                           +-----------------+  2
+--R                                                    2      |        1
+--R                                                 (8a  + 8) |-----------------
+--R                                                           |   4       2
+--R                                                          \|64a  + 128a  + 64
+--R                            +---------+2    atan(-----------------------------)
+--R                    2       |    1                             a
+--R                 (4a  + 4)  |---------  sin(-----------------------------------)
+--R                           4|   2                            2
+--R                           \|16a  + 16
+--R               + 
+--R                                 +-----------------+  +---------+
+--R                       3         |        1           |    1
+--R                   (32a  + 32a)x |-----------------   |---------
+--R                                 |   4       2       4|   2
+--R                                \|64a  + 128a  + 64  \|16a  + 16
+--R                *
+--R                                      +-----------------+
+--R                               2      |        1
+--R                            (8a  + 8) |-----------------
+--R                                      |   4       2
+--R                                     \|64a  + 128a  + 64
+--R                       atan(-----------------------------)
+--R                                          a
+--R                   sin(-----------------------------------)
+--R                                        2
+--R               + 
+--R                                                           +-----------------+  2
+--R                                                    2      |        1
+--R                                                 (8a  + 8) |-----------------
+--R                                                           |   4       2
+--R                                                          \|64a  + 128a  + 64
+--R                            +---------+2    atan(-----------------------------)
+--R                    2       |    1                             a
+--R                 (4a  + 4)  |---------  cos(-----------------------------------)
+--R                           4|   2                            2
+--R                           \|16a  + 16
+--R               + 
+--R                                                     +-----------------+
+--R                                              2      |        1
+--R                                           (8a  + 8) |-----------------
+--R                                                     |   4       2
+--R                                                    \|64a  + 128a  + 64
+--R                       +---------+    atan(-----------------------------)
+--R                       |    1                            a                   2
+--R                 - 4x  |--------- cos(----------------------------------- + x
+--R                      4|   2                           2
+--R                      \|16a  + 16
+--R     + 
+--R                                    +---------------+ +-------------+
+--R               +---------+ +------+ |   +------+      | +------+
+--R          +-+  |    1      | 2      |   | 2           | | 2
+--R         \|2   |--------- \|a  + 1 \|- \|a  + 1  + a \|\|a  + 1  + a
+--R              4|   2
+--R              \|16a  + 16
+--R      *
+--R                            +-----------------+
+--R                     2      |        1
+--R                  (8a  + 8) |-----------------
+--R                            |   4       2
+--R                           \|64a  + 128a  + 64
+--R             atan(-----------------------------)
+--R                                a
+--R         cos(-----------------------------------)
+--R                              2
+--R      *
+--R         log
+--R                                                        +-----------------+  2
+--R                                                 2      |        1
+--R                                              (8a  + 8) |-----------------
+--R                                                        |   4       2
+--R                                                       \|64a  + 128a  + 64
+--R                         +---------+2    atan(-----------------------------)
+--R                 2       |    1                             a
+--R              (4a  + 4)  |---------  sin(-----------------------------------)
+--R                        4|   2                            2
+--R                        \|16a  + 16
+--R            + 
+--R                                +-----------------+  +---------+
+--R                      3         |        1           |    1
+--R                (- 32a  - 32a)x |-----------------   |---------
+--R                                |   4       2       4|   2
+--R                               \|64a  + 128a  + 64  \|16a  + 16
+--R             *
+--R                                   +-----------------+
+--R                            2      |        1
+--R                         (8a  + 8) |-----------------
+--R                                   |   4       2
+--R                                  \|64a  + 128a  + 64
+--R                    atan(-----------------------------)
+--R                                       a
+--R                sin(-----------------------------------)
+--R                                     2
+--R            + 
+--R                                                        +-----------------+  2
+--R                                                 2      |        1
+--R                                              (8a  + 8) |-----------------
+--R                                                        |   4       2
+--R                                                       \|64a  + 128a  + 64
+--R                         +---------+2    atan(-----------------------------)
+--R                 2       |    1                             a
+--R              (4a  + 4)  |---------  cos(-----------------------------------)
+--R                        4|   2                            2
+--R                        \|16a  + 16
+--R            + 
+--R                                                +-----------------+
+--R                                         2      |        1
+--R                                      (8a  + 8) |-----------------
+--R                                                |   4       2
+--R                                               \|64a  + 128a  + 64
+--R                  +---------+    atan(-----------------------------)
+--R                  |    1                            a                   2
+--R              4x  |--------- cos(----------------------------------- + x
+--R                 4|   2                           2
+--R                 \|16a  + 16
+--R     + 
+--R                                     +---------------+ +-------------+
+--R                +---------+ +------+ |   +------+      | +------+
+--R           +-+  |    1      | 2      |   | 2           | | 2
+--R         2\|2   |--------- \|a  + 1 \|- \|a  + 1  + a \|\|a  + 1  + a
+--R               4|   2
+--R               \|16a  + 16
+--R      *
+--R                            +-----------------+
+--R                     2      |        1
+--R                  (8a  + 8) |-----------------
+--R                            |   4       2
+--R                           \|64a  + 128a  + 64
+--R             atan(-----------------------------)
+--R                                a
+--R         sin(-----------------------------------)
+--R                              2
+--R      *
+--R         atan
+--R                                                 +-----------------+
+--R                                          2      |        1
+--R                                       (8a  + 8) |-----------------
+--R                                                 |   4       2
+--R                                                \|64a  + 128a  + 64
+--R                   +---------+    atan(-----------------------------)
+--R                   |    1                            a
+--R                2  |--------- sin(-----------------------------------)
+--R                  4|   2                           2
+--R                  \|16a  + 16
+--R              + 
+--R                               +-----------------+  +---------+
+--R                      3        |        1           |    1
+--R                  (16a  + 16a) |-----------------   |---------
+--R                               |   4       2       4|   2
+--R                              \|64a  + 128a  + 64  \|16a  + 16
+--R               *
+--R                                     +-----------------+
+--R                              2      |        1
+--R                           (8a  + 8) |-----------------
+--R                                     |   4       2
+--R                                    \|64a  + 128a  + 64
+--R                      atan(-----------------------------)
+--R                                         a
+--R                  cos(-----------------------------------)
+--R                                       2
+--R           /
+--R                               +-----------------+  +---------+
+--R                      3        |        1           |    1
+--R                  (16a  + 16a) |-----------------   |---------
+--R                               |   4       2       4|   2
+--R                              \|64a  + 128a  + 64  \|16a  + 16
+--R               *
+--R                                     +-----------------+
+--R                              2      |        1
+--R                           (8a  + 8) |-----------------
+--R                                     |   4       2
+--R                                    \|64a  + 128a  + 64
+--R                      atan(-----------------------------)
+--R                                         a
+--R                  sin(-----------------------------------)
+--R                                       2
+--R              + 
+--R                                                   +-----------------+
+--R                                            2      |        1
+--R                                         (8a  + 8) |-----------------
+--R                                                   |   4       2
+--R                                                  \|64a  + 128a  + 64
+--R                     +---------+    atan(-----------------------------)
+--R                     |    1                            a
+--R                - 2  |--------- cos(----------------------------------- - x
+--R                    4|   2                           2
+--R                    \|16a  + 16
+--R     + 
+--R       -
+--R                                        +---------------+ +-------------+
+--R                   +---------+ +------+ |   +------+      | +------+
+--R              +-+  |    1      | 2      |   | 2           | | 2
+--R            2\|2   |--------- \|a  + 1 \|- \|a  + 1  + a \|\|a  + 1  + a
+--R                  4|   2
+--R                  \|16a  + 16
+--R         *
+--R                               +-----------------+
+--R                        2      |        1
+--R                     (8a  + 8) |-----------------
+--R                               |   4       2
+--R                              \|64a  + 128a  + 64
+--R                atan(-----------------------------)
+--R                                   a
+--R            sin(-----------------------------------)
+--R                                 2
+--R         *
+--R            atan
+--R                                                    +-----------------+
+--R                                             2      |        1
+--R                                          (8a  + 8) |-----------------
+--R                                                    |   4       2
+--R                                                   \|64a  + 128a  + 64
+--R                      +---------+    atan(-----------------------------)
+--R                      |    1                            a
+--R                   2  |--------- sin(-----------------------------------)
+--R                     4|   2                           2
+--R                     \|16a  + 16
+--R                 + 
+--R                                  +-----------------+  +---------+
+--R                         3        |        1           |    1
+--R                     (16a  + 16a) |-----------------   |---------
+--R                                  |   4       2       4|   2
+--R                                 \|64a  + 128a  + 64  \|16a  + 16
+--R                  *
+--R                                        +-----------------+
+--R                                 2      |        1
+--R                              (8a  + 8) |-----------------
+--R                                        |   4       2
+--R                                       \|64a  + 128a  + 64
+--R                         atan(-----------------------------)
+--R                                            a
+--R                     cos(-----------------------------------)
+--R                                          2
+--R              /
+--R                                  +-----------------+  +---------+
+--R                         3        |        1           |    1
+--R                     (16a  + 16a) |-----------------   |---------
+--R                                  |   4       2       4|   2
+--R                                 \|64a  + 128a  + 64  \|16a  + 16
+--R                  *
+--R                                        +-----------------+
+--R                                 2      |        1
+--R                              (8a  + 8) |-----------------
+--R                                        |   4       2
+--R                                       \|64a  + 128a  + 64
+--R                         atan(-----------------------------)
+--R                                            a
+--R                     sin(-----------------------------------)
+--R                                          2
+--R                 + 
+--R                                                      +-----------------+
+--R                                               2      |        1
+--R                                            (8a  + 8) |-----------------
+--R                                                      |   4       2
+--R                                                     \|64a  + 128a  + 64
+--R                        +---------+    atan(-----------------------------)
+--R                        |    1                            a
+--R                   - 2  |--------- cos(----------------------------------- + x
+--R                       4|   2                           2
+--R                       \|16a  + 16
+--R     + 
+--R                             +---------------+
+--R        +-------------+      |   +------+
+--R        | +------+           |   | 2               +-+
+--R        | | 2               \|- \|a  + 1  - a  + x\|2
+--R       \|\|a  + 1  + a atan(--------------------------)
+--R                                 +---------------+
+--R                                 |   +------+
+--R                                 |   | 2
+--R                                \|- \|a  + 1  + a
+--R     + 
+--R                                   +---------------+
+--R          +-------------+          |   +------+
+--R          | +------+           +-+ |   | 2
+--R          | | 2               \|2 \|- \|a  + 1  - a  - 2x
+--R       - \|\|a  + 1  + a atan(---------------------------)
+--R                                      +---------------+
+--R                                      |   +------+
+--R                                  +-+ |   | 2
+--R                                 \|2 \|- \|a  + 1  + a
+--R     + 
+--R                                 +-------------+
+--R          +---------------+      | +------+
+--R          |   +------+           | | 2               +-+
+--R          |   | 2               \|\|a  + 1  - a  + x\|2
+--R       - \|- \|a  + 1  + a atan(------------------------)
+--R                                     +-------------+
+--R                                     | +------+
+--R                                     | | 2
+--R                                    \|\|a  + 1  + a
+--R     + 
+--R                               +-------------+
+--R        +---------------+      | +------+
+--R        |   +------+           | | 2               +-+
+--R        |   | 2               \|\|a  + 1  - a  - x\|2
+--R       \|- \|a  + 1  + a atan(------------------------)
+--R                                   +-------------+
+--R                                   | +------+
+--R                                   | | 2
+--R                                  \|\|a  + 1  + a
+--R  /
+--R                    +---------------+ +-------------+
+--R           +------+ |   +------+      | +------+
+--R       +-+ | 2      |   | 2           | | 2
+--R     2\|2 \|a  + 1 \|- \|a  + 1  + a \|\|a  + 1  + a
+--R                                                    Type: Expression(Integer)
+--E 1175
+
+--S 1176 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                        9        7        5       3        10
+--R                   (512a  + 1568a  + 1680a  + 704a  + 80a)x
+--R                 + 
+--R                         10        8        6        4       2  8
+--R                   (1024a   + 3136a  + 3360a  + 1408a  + 160a )x
+--R                 + 
+--R                         11        9       7        5        3         6
+--R                   (1024a   + 2112a  + 224a  - 1952a  - 1248a  - 160a)x
+--R                 + 
+--R                         12        10         8         6        4       2  4
+--R                   (1024a   + 8256a   + 19040a  + 18208a  + 7200a  + 800a )x
+--R                 + 
+--R                      13       11        9        7        5        3         2
+--R                 (512a   + 544a   - 2992a  - 7360a  - 6368a  - 2272a  - 240a)x
+--R              *
+--R                  +-----------------+
+--R                  |        1
+--R                  |-----------------
+--R                  |   4       2
+--R                 \|64a  + 128a  + 64
+--R             + 
+--R                     7       5      3        10
+--R               (- 64a  - 132a  - 78a  - 10a)x
+--R             + 
+--R                      8       6       4      2  8
+--R               (- 128a  - 264a  - 156a  - 20a )x
+--R             + 
+--R                      9       7       5      3  6
+--R               (- 256a  - 528a  - 312a  - 40a )x
+--R             + 
+--R                    10       8       6       4      2  4
+--R               (128a   - 120a  - 636a  - 448a  - 60a )x
+--R             + 
+--R                      11       9       7      5      3        2
+--R               (- 192a   - 524a  - 434a  - 54a  + 58a  + 10a)x
+--R          *
+--R              +---------+2
+--R              |    1
+--R              |---------
+--R             4|   2
+--R             \|16a  + 16
+--R         + 
+--R                    9       7        5       3  8
+--R               (256a  - 368a  - 1056a  - 432a )x
+--R             + 
+--R                    10       8        6       4  6
+--R               (512a   - 736a  - 2112a  - 864a )x
+--R             + 
+--R                    11        9        7       5       3  4
+--R               (256a   - 2160a  - 2576a  + 560a  + 720a )x
+--R          *
+--R              +-----------------+
+--R              |        1
+--R              |-----------------
+--R              |   4       2
+--R             \|64a  + 128a  + 64
+--R         + 
+--R                 7      5      3  8         8       6       4      2  6
+--R           (- 32a  + 78a  + 54a )x  + (- 32a  + 238a  + 176a  + 18a )x
+--R         + 
+--R                 9       7       5       3  4
+--R           (- 96a  + 138a  - 116a  - 126a )x
+--R         + 
+--R               10       8       6      4      2  2
+--R           (32a   + 114a  + 150a  + 86a  + 18a )x
+--R      *
+--R            3
+--R         %ER
+--R     + 
+--R                          8        6        4       2  10
+--R                   (- 640a  - 1792a  - 1664a  - 512a )x
+--R                 + 
+--R                           9        7        5        3  8
+--R                   (- 1280a  - 3584a  - 3328a  - 1024a )x
+--R                 + 
+--R                           10        8       6        4        2  6
+--R                   (- 1280a   - 2304a  + 256a  + 2304a  + 1024a )x
+--R                 + 
+--R                           11        9         7         5        3  4
+--R                   (- 1280a   - 9984a  - 21248a  - 17664a  - 5120a )x
+--R                 + 
+--R                          12       10        8        6        4        2  2
+--R                   (- 640a   - 512a   + 3840a  + 8192a  + 6016a  + 1536a )x
+--R              *
+--R                  +-----------------+
+--R                  |        1
+--R                  |-----------------
+--R                  |   4       2
+--R                 \|64a  + 128a  + 64
+--R             + 
+--R                   6       4      2  10        7       5       3  8
+--R               (80a  + 144a  + 64a )x   + (160a  + 288a  + 128a )x
+--R             + 
+--R                    8       6       4  6          9       7       5       3  4
+--R               (320a  + 576a  + 256a )x  + (- 160a  + 192a  + 736a  + 384a )x
+--R             + 
+--R                    10       8       6      4      2  2
+--R               (240a   + 592a  + 400a  - 16a  - 64a )x
+--R          *
+--R              +---------+2
+--R              |    1
+--R              |---------
+--R             4|   2
+--R             \|16a  + 16
+--R         + 
+--R                      8       6        4       2  8
+--R               (- 320a  + 544a  + 1152a  + 288a )x
+--R             + 
+--R                      9        7        5       3  6
+--R               (- 640a  + 1088a  + 2304a  + 576a )x
+--R             + 
+--R                      10        8        6        4       2  4
+--R               (- 320a   + 2784a  + 2464a  - 1120a  - 480a )x
+--R          *
+--R              +-----------------+
+--R              |        1
+--R              |-----------------
+--R              |   4       2
+--R             \|64a  + 128a  + 64
+--R         + 
+--R               6       4      2  8       7       5       3        6
+--R           (40a  - 108a  - 36a )x  + (40a  - 308a  - 136a  - 12a)x
+--R         + 
+--R                8       6       4      2  4
+--R           (120a  - 204a  + 208a  + 84a )x
+--R         + 
+--R                 9       7       5      3        2
+--R           (- 40a  - 132a  - 156a  - 76a  - 12a)x
+--R      *
+--R            2
+--R         %ER
+--R     + 
+--R                          9        7        5       3        10
+--R                   (- 512a  - 1440a  - 1360a  - 448a  - 16a)x
+--R                 + 
+--R                           10        8        6       4      2  8
+--R                   (- 1024a   - 2880a  - 2720a  - 896a  - 32a )x
+--R                 + 
+--R                           11        9       7        5       3        6
+--R                   (- 1024a   - 1856a  + 160a  + 1824a  + 864a  + 32a)x
+--R                 + 
+--R                           12        10         8         6        4       2  4
+--R                   (- 1024a   - 8000a   - 17120a  - 14496a  - 4512a  - 160a )x
+--R                 + 
+--R                        13       11        9        7        5        3        2
+--R                 (- 512a   - 416a   + 3056a  + 6592a  + 4960a  + 1376a  + 48a)x
+--R              *
+--R                  +-----------------+
+--R                  |        1
+--R                  |-----------------
+--R                  |   4       2
+--R                 \|64a  + 128a  + 64
+--R             + 
+--R                   7       5      3       10        8       6       4     2  8
+--R               (64a  + 116a  + 54a  + 2a)x   + (128a  + 232a  + 108a  + 4a )x
+--R             + 
+--R                    9       7       5     3  6
+--R               (256a  + 464a  + 216a  + 8a )x
+--R             + 
+--R                      10       8       6       4      2  4
+--R               (- 128a   + 152a  + 588a  + 320a  + 12a )x
+--R             + 
+--R                    11       9       7     5      3       2
+--R               (192a   + 476a  + 330a  - 2a  - 50a  - 2a)x
+--R          *
+--R              +---------+2
+--R              |    1
+--R              |---------
+--R             4|   2
+--R             \|16a  + 16
+--R         + 
+--R                      9       7       5       3  8
+--R               (- 256a  + 432a  + 928a  + 240a )x
+--R             + 
+--R                      10       8        6       4  6
+--R               (- 512a   + 864a  + 1856a  + 480a )x
+--R             + 
+--R                      11        9        7       5       3  4
+--R               (- 256a   + 2224a  + 2000a  - 880a  - 400a )x
+--R          *
+--R              +-----------------+
+--R              |        1
+--R              |-----------------
+--R              |   4       2
+--R             \|64a  + 128a  + 64
+--R         + 
+--R               7      5      3  8       8       6       4      2  6
+--R           (32a  - 86a  - 30a )x  + (32a  - 246a  - 112a  - 10a )x
+--R         + 
+--R               9       7       5      3  4
+--R           (96a  - 162a  + 164a  + 70a )x
+--R         + 
+--R                 10       8       6      4      2  2
+--R           (- 32a   - 106a  - 126a  - 62a  - 10a )x
+--R      *
+--R         %ER
+--R     + 
+--R                    8       6       4      2  10
+--R               (128a  + 352a  + 320a  + 96a )x
+--R             + 
+--R                    9       7       5       3  8
+--R               (256a  + 704a  + 640a  + 192a )x
+--R             + 
+--R                    10       8      6       4       2  6
+--R               (256a   + 448a  - 64a  - 448a  - 192a )x
+--R             + 
+--R                    11        9        7        5       3  4
+--R               (256a   + 1984a  + 4160a  + 3392a  + 960a )x
+--R             + 
+--R                    12      10       8        6        4       2  2
+--R               (128a   + 96a   - 768a  - 1600a  - 1152a  - 288a )x
+--R          *
+--R              +-----------------+
+--R              |        1
+--R              |-----------------
+--R              |   4       2
+--R             \|64a  + 128a  + 64
+--R         + 
+--R                 6      4      2  10         7      5      3  8
+--R           (- 16a  - 28a  - 12a )x   + (- 32a  - 56a  - 24a )x
+--R         + 
+--R                 8       6      4  6       9      7       5      3  4
+--R           (- 64a  - 112a  - 48a )x  + (32a  - 40a  - 144a  - 72a )x
+--R         + 
+--R                 10       8      6     4      2  2
+--R           (- 48a   - 116a  - 76a  + 4a  + 12a )x
+--R      *
+--R          +---------+2
+--R          |    1
+--R          |---------
+--R         4|   2
+--R         \|16a  + 16
+--R     + 
+--R               8       6       4      2  8        9       7       5      3  6
+--R           (64a  - 112a  - 224a  - 48a )x  + (128a  - 224a  - 448a  - 96a )x
+--R         + 
+--R               10       8       6       4      2  4
+--R           (64a   - 560a  - 464a  + 240a  + 80a )x
+--R      *
+--R          +-----------------+
+--R          |        1
+--R          |-----------------
+--R          |   4       2
+--R         \|64a  + 128a  + 64
+--R     + 
+--R            6      4     2  8        7      5      3       6
+--R       (- 8a  + 22a  + 6a )x  + (- 8a  + 62a  + 24a  + 2a)x
+--R     + 
+--R             8      6      4      2  4      9      7      5      3       2
+--R       (- 24a  + 42a  - 44a  - 14a )x  + (8a  + 26a  + 30a  + 14a  + 2a)x
+--R  /
+--R                         9         7         5        3         10
+--R                   (4096a  + 12544a  + 13440a  + 5632a  + 640a)x
+--R                 + 
+--R                         10         8         6         4        2  8
+--R                   (8192a   + 25088a  + 26880a  + 11264a  + 1280a )x
+--R                 + 
+--R                         11         9         7         5         3          6
+--R                   (8192a   + 33280a  + 51968a  + 38144a  + 12544a  + 1280a)x
+--R                 + 
+--R                         12         10         8         6         4        2  4
+--R                   (8192a   + 33280a   + 51968a  + 38144a  + 12544a  + 1280a )x
+--R                 + 
+--R                            13         11         9         7         5        3
+--R                       4096a   + 20736a   + 42624a  + 45056a  + 25344a  + 6912a
+--R                     + 
+--R                       640a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-----------------+
+--R                  |        1
+--R                  |-----------------
+--R                  |   4       2
+--R                 \|64a  + 128a  + 64
+--R             + 
+--R                    9       7       5       3        10
+--R               (256a  + 272a  - 216a  - 272a  - 40a)x
+--R             + 
+--R                    10       8       6       4      2  8
+--R               (512a   + 544a  - 432a  - 544a  - 80a )x
+--R             + 
+--R                    11        9       7       5       3        6
+--R               (512a   + 1056a  + 112a  - 976a  - 624a  - 80a)x
+--R             + 
+--R                    12        10       8       6       4      2  4
+--R               (512a   + 1056a   + 112a  - 976a  - 624a  - 80a )x
+--R             + 
+--R                    13       11       9       7       5       3        2
+--R               (256a   + 784a   + 584a  - 432a  - 800a  - 352a  - 40a)x
+--R          *
+--R              +---------+2
+--R              |    1
+--R              |---------
+--R             4|   2
+--R             \|16a  + 16
+--R         + 
+--R                     9        7        5        3  8
+--R               (2048a  + 1152a  - 2048a  - 1152a )x
+--R             + 
+--R                     10        8        6        4  6
+--R               (4096a   + 2304a  - 4096a  - 2304a )x
+--R             + 
+--R                     11        9       7        5        3  4
+--R               (2048a   + 3200a  - 896a  - 3200a  - 1152a )x
+--R          *
+--R              +-----------------+
+--R              |        1
+--R              |-----------------
+--R              |   4       2
+--R             \|64a  + 128a  + 64
+--R         + 
+--R               7      5      3       12       8      6      4      2  10
+--R           (16a  + 41a  + 34a  + 9a)x   + (32a  + 82a  + 68a  + 18a )x
+--R         + 
+--R                9      7       5       3        8
+--R           (112a  + 79a  + 473a  + 309a  + 27a)x
+--R         + 
+--R                10      8       6       4      2  6
+--R           (192a   + 44a  + 796a  + 532a  + 36a )x
+--R         + 
+--R                11       9       7       5       3        4
+--R           (112a   + 191a  + 552a  + 782a  + 336a  + 27a)x
+--R         + 
+--R               12       10       8       6       4      2  2      13      11
+--R           (32a   + 146a   + 264a  + 236a  + 104a  + 18a )x  + 16a   + 89a
+--R         + 
+--R               9       7       5      3
+--R           205a  + 250a  + 170a  + 61a  + 9a
+--R      *
+--R            3
+--R         %ER
+--R     + 
+--R                           8         6         4        2  10
+--R                   (- 5120a  - 14336a  - 13312a  - 4096a )x
+--R                 + 
+--R                            9         7         5        3  8
+--R                   (- 10240a  - 28672a  - 26624a  - 8192a )x
+--R                 + 
+--R                            10         8         6         4        2  6
+--R                   (- 10240a   - 38912a  - 55296a  - 34816a  - 8192a )x
+--R                 + 
+--R                            11         9         7         5        3  4
+--R                   (- 10240a   - 38912a  - 55296a  - 34816a  - 8192a )x
+--R                 + 
+--R                         12         10         8         6         4        2  2
+--R                 (- 5120a   - 24576a   - 47104a  - 45056a  - 21504a  - 4096a )x
+--R              *
+--R                  +-----------------+
+--R                  |        1
+--R                  |-----------------
+--R                  |   4       2
+--R                 \|64a  + 128a  + 64
+--R             + 
+--R                      8       6       4       2  10
+--R               (- 320a  - 256a  + 320a  + 256a )x
+--R             + 
+--R                      9       7       5       3  8
+--R               (- 640a  - 512a  + 640a  + 512a )x
+--R             + 
+--R                      10        8       6        4       2  6
+--R               (- 640a   - 1152a  + 128a  + 1152a  + 512a )x
+--R             + 
+--R                      11        9       7        5       3  4
+--R               (- 640a   - 1152a  + 128a  + 1152a  + 512a )x
+--R             + 
+--R                      12       10       8       6       4       2  2
+--R               (- 320a   - 896a   - 512a  + 640a  + 832a  + 256a )x
+--R          *
+--R              +---------+2
+--R              |    1
+--R              |---------
+--R             4|   2
+--R             \|16a  + 16
+--R         + 
+--R                       8       6        4       2  8
+--R               (- 2560a  - 768a  + 2560a  + 768a )x
+--R             + 
+--R                       9        7        5        3  6
+--R               (- 5120a  - 1536a  + 5120a  + 1536a )x
+--R             + 
+--R                       10        8        6        4       2  4
+--R               (- 2560a   - 3328a  + 1792a  + 3328a  + 768a )x
+--R          *
+--R              +-----------------+
+--R              |        1
+--R              |-----------------
+--R              |   4       2
+--R             \|64a  + 128a  + 64
+--R         + 
+--R                 6      4      2      12         7      5      3        10
+--R           (- 20a  - 46a  - 32a  - 6)x   + (- 40a  - 92a  - 64a  - 12a)x
+--R         + 
+--R                  8      6       4       2       8
+--R           (- 140a  - 62a  - 586a  - 234a  - 18)x
+--R         + 
+--R                  9     7        5       3        6
+--R           (- 240a  + 8a  - 1016a  - 392a  - 24a)x
+--R         + 
+--R                  10       8       6       4       2       4
+--R           (- 140a   - 202a  - 648a  - 820a  - 252a  - 18)x
+--R         + 
+--R                 11       9       7       5      3        2      12       10
+--R           (- 40a   - 172a  - 288a  - 232a  - 88a  - 12a)x  - 20a   - 106a
+--R         + 
+--R                 8       6       4      2
+--R           - 230a  - 260a  - 160a  - 50a  - 6
+--R      *
+--R            2
+--R         %ER
+--R     + 
+--R                           9         7         5        3         10
+--R                   (- 4096a  - 11520a  - 10880a  - 3584a  - 128a)x
+--R                 + 
+--R                           10         8         6        4       2  8
+--R                   (- 8192a   - 23040a  - 21760a  - 7168a  - 256a )x
+--R                 + 
+--R                           11         9         7         5        3         6
+--R                   (- 8192a   - 31232a  - 44800a  - 28928a  - 7424a  - 256a)x
+--R                 + 
+--R                           12         10         8         6        4       2  4
+--R                   (- 8192a   - 31232a   - 44800a  - 28928a  - 7424a  - 256a )x
+--R                 + 
+--R                              13         11         9         7         5
+--R                       - 4096a   - 19712a   - 38016a  - 36864a  - 18176a
+--R                     + 
+--R                              3
+--R                       - 3840a  - 128a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-----------------+
+--R                  |        1
+--R                  |-----------------
+--R                  |   4       2
+--R                 \|64a  + 128a  + 64
+--R             + 
+--R                      9       7       5       3       10
+--R               (- 256a  - 208a  + 248a  + 208a  + 8a)x
+--R             + 
+--R                      10       8       6       4      2  8
+--R               (- 512a   - 416a  + 496a  + 416a  + 16a )x
+--R             + 
+--R                      11       9      7       5       3        6
+--R               (- 512a   - 928a  + 80a  + 912a  + 432a  + 16a)x
+--R             + 
+--R                      12       10      8       6       4      2  4
+--R               (- 512a   - 928a   + 80a  + 912a  + 432a  + 16a )x
+--R             + 
+--R                      13       11       9       7       5       3       2
+--R               (- 256a   - 720a   - 424a  + 496a  + 672a  + 224a  + 8a)x
+--R          *
+--R              +---------+2
+--R              |    1
+--R              |---------
+--R             4|   2
+--R             \|16a  + 16
+--R         + 
+--R                       9       7        5       3  8
+--R               (- 2048a  - 640a  + 2048a  + 640a )x
+--R             + 
+--R                       10        8        6        4  6
+--R               (- 4096a   - 1280a  + 4096a  + 1280a )x
+--R             + 
+--R                       11        9        7        5       3  4
+--R               (- 2048a   - 2688a  + 1408a  + 2688a  + 640a )x
+--R          *
+--R              +-----------------+
+--R              |        1
+--R              |-----------------
+--R              |   4       2
+--R             \|64a  + 128a  + 64
+--R         + 
+--R                 7      5      3       12         8      6      4      2  10
+--R           (- 16a  - 37a  - 26a  - 5a)x   + (- 32a  - 74a  - 52a  - 10a )x
+--R         + 
+--R                  9      7       5       3        8
+--R           (- 112a  - 51a  - 469a  - 193a  - 15a)x
+--R         + 
+--R                  10     8       6       4      2  6
+--R           (- 192a   + 4a  - 812a  - 324a  - 20a )x
+--R         + 
+--R                  11       9       7       5       3        4
+--R           (- 112a   - 163a  - 520a  - 662a  - 208a  - 15a)x
+--R         + 
+--R                 12       10       8       6      4      2  2      13      11
+--R           (- 32a   - 138a   - 232a  - 188a  - 72a  - 10a )x  - 16a   - 85a
+--R         + 
+--R                 9       7       5      3
+--R           - 185a  - 210a  - 130a  - 41a  - 5a
+--R      *
+--R         %ER
+--R     + 
+--R                     8        6        4       2  10
+--R               (1024a  + 2816a  + 2560a  + 768a )x
+--R             + 
+--R                     9        7        5        3  8
+--R               (2048a  + 5632a  + 5120a  + 1536a )x
+--R             + 
+--R                     10        8         6        4        2  6
+--R               (2048a   + 7680a  + 10752a  + 6656a  + 1536a )x
+--R             + 
+--R                     11        9         7        5        3  4
+--R               (2048a   + 7680a  + 10752a  + 6656a  + 1536a )x
+--R             + 
+--R                     12        10        8        6        4       2  2
+--R               (1024a   + 4864a   + 9216a  + 8704a  + 4096a  + 768a )x
+--R          *
+--R              +-----------------+
+--R              |        1
+--R              |-----------------
+--R              |   4       2
+--R             \|64a  + 128a  + 64
+--R         + 
+--R               8      6      4      2  10        9      7       5      3  8
+--R           (64a  + 48a  - 64a  - 48a )x   + (128a  + 96a  - 128a  - 96a )x
+--R         + 
+--R                10       8      6       4      2  6
+--R           (128a   + 224a  - 32a  - 224a  - 96a )x
+--R         + 
+--R                11       9      7       5      3  4
+--R           (128a   + 224a  - 32a  - 224a  - 96a )x
+--R         + 
+--R               12       10      8       6       4      2  2
+--R           (64a   + 176a   + 96a  - 128a  - 160a  - 48a )x
+--R      *
+--R          +---------+2
+--R          |    1
+--R          |---------
+--R         4|   2
+--R         \|16a  + 16
+--R     + 
+--R                8       6       4       2  8
+--R           (512a  + 128a  - 512a  - 128a )x
+--R         + 
+--R                 9       7        5       3  6
+--R           (1024a  + 256a  - 1024a  - 256a )x
+--R         + 
+--R                10       8       6       4       2  4
+--R           (512a   + 640a  - 384a  - 640a  - 128a )x
+--R      *
+--R          +-----------------+
+--R          |        1
+--R          |-----------------
+--R          |   4       2
+--R         \|64a  + 128a  + 64
+--R     + 
+--R          6     4     2      12      7      5      3       10
+--R       (4a  + 9a  + 6a  + 1)x   + (8a  + 18a  + 12a  + 2a)x
+--R     + 
+--R           8      6       4      2      8       9     7       5      3       6
+--R       (28a  + 11a  + 117a  + 41a  + 3)x  + (48a  - 4a  + 204a  + 68a  + 4a)x
+--R     + 
+--R           10      8       6       4      2      4
+--R       (28a   + 39a  + 128a  + 158a  + 44a  + 3)x
+--R     + 
+--R          11      9      7      5      3       2     12      10      8      6
+--R       (8a   + 34a  + 56a  + 44a  + 16a  + 2a)x  + 4a   + 21a   + 45a  + 50a
+--R     + 
+--R          4     2
+--R       30a  + 9a  + 1
+--R                                                    Type: Expression(Integer)
+--E 1176
+
+)clear all
+
+--S 1177 of 1353
+t0:=1/(4-5*x^2+x^4)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1177
+
+--S 1178 of 1353
+r0:=-1/6*atanh(1/2*x)+1/3*atanh(x)
+--R 
+--R
+--R                          x
+--R        2atanh(x) - atanh(-)
+--R                          2
+--R   (2)  --------------------
+--R                  6
+--R                                                    Type: Expression(Integer)
+--E 1178
+
+--S 1179 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - log(x + 2) + 2log(x + 1) - 2log(x - 1) + log(x - 2)
+--R   (3)  -----------------------------------------------------
+--R                                  12
+--R                                         Type: Union(Expression(Integer),...)
+--E 1179
+
+--S 1180 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                              x
+--R   - log(x + 2) + 2log(x + 1) - 2log(x - 1) + log(x - 2) - 4atanh(x) + 2atanh(-)
+--R                                                                              2
+--R   -----------------------------------------------------------------------------
+--R                                         12
+--R                                                    Type: Expression(Integer)
+--E 1180
+
+--S 1181 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1181
+
+)clear all
+
+--S 1182 of 1353
+t0:=1/(3+4*x^2+x^4)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1182
+
+--S 1183 of 1353
+r0:=1/2*atan(x)-1/2*atan(x/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                 +-+
+--R               x\|3      +-+
+--R        - atan(-----) + \|3 atan(x)
+--R                 3
+--R   (2)  ---------------------------
+--R                     +-+
+--R                   2\|3
+--R                                                    Type: Expression(Integer)
+--E 1183
+
+--S 1184 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-+
+--R               x\|3      +-+
+--R        - atan(-----) + \|3 atan(x)
+--R                 3
+--R   (3)  ---------------------------
+--R                     +-+
+--R                   2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1184
+
+--S 1185 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1185
+
+--S 1186 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1186
+
+)clear all
+
+--S 1187 of 1353
+t0:=1/(9+5*x^2+x^4)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 5x  + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1187
+
+--S 1188 of 1353
+r0:=-1/12*log(3-x+x^2)+1/12*log(3+x+x^2)-1/6*atan((1-2*x)/sqrt(11))/_
+   sqrt(11)+1/6*atan((1+2*x)/sqrt(11))/sqrt(11)
+--R 
+--R
+--R   (2)
+--R                                                                    +--+
+--R        +--+     2             +--+     2                  (2x + 1)\|11
+--R       \|11 log(x  + x + 3) - \|11 log(x  - x + 3) + 2atan(-------------)
+--R                                                                 11
+--R     + 
+--R                      +--+
+--R             (2x - 1)\|11
+--R       2atan(-------------)
+--R                   11
+--R  /
+--R        +--+
+--R     12\|11
+--R                                                    Type: Expression(Integer)
+--E 1188
+
+--S 1189 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                    +--+
+--R        +--+     2             +--+     2                  (2x + 1)\|11
+--R       \|11 log(x  + x + 3) - \|11 log(x  - x + 3) + 2atan(-------------)
+--R                                                                 11
+--R     + 
+--R                      +--+
+--R             (2x - 1)\|11
+--R       2atan(-------------)
+--R                   11
+--R  /
+--R        +--+
+--R     12\|11
+--R                                         Type: Union(Expression(Integer),...)
+--E 1189
+
+--S 1190 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1190
+
+--S 1191 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1191
+
+)clear all
+
+--S 1192 of 1353
+t0:=1/(1-x^2+x^4)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         4    2
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1192
+
+--S 1193 of 1353
+r0:=-1/2*atan(-2*x+sqrt(3))+1/2*atan(2*x+sqrt(3))-1/4*log(1+x^2-_
+   x*sqrt(3))/sqrt(3)+1/4*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R             +-+    2                +-+    2          +-+      +-+
+--R       log(x\|3  + x  + 1) - log(- x\|3  + x  + 1) + 2\|3 atan(\|3  + 2x)
+--R     + 
+--R           +-+      +-+
+--R       - 2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1193
+
+--S 1194 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                       3
+--R                atan(----)
+--R                      +-+
+--R                     \|3
+--R            cos(----------)
+--R                     2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3                  \|3               \|3
+--R                 sin(----------)  + x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                   3
+--R                            atan(----)
+--R                                  +-+
+--R                     +-+         \|3       2
+--R                 - x\|3 cos(----------) + x
+--R                                 2
+--R     + 
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         cos(----------)
+--R                  2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                              3
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            2
+--R     + 
+--R                                              3                 3
+--R                                       atan(----)        atan(----)
+--R                   3                         +-+               +-+
+--R            atan(----)          +-+         \|3               \|3
+--R                  +-+          \|3 sin(----------) + cos(----------)
+--R                 \|3                        2                 2
+--R       2sin(----------)atan(------------------------------------------)
+--R                 2                     3                     3
+--R                                atan(----)            atan(----)
+--R                                      +-+                   +-+
+--R                                     \|3       +-+         \|3
+--R                            sin(----------) - \|3 cos(----------) - 2x
+--R                                     2                     2
+--R     + 
+--R                                                3                 3
+--R                                         atan(----)        atan(----)
+--R                     3                         +-+               +-+
+--R              atan(----)          +-+         \|3               \|3
+--R                    +-+          \|3 sin(----------) + cos(----------)
+--R                   \|3                        2                 2
+--R       - 2sin(----------)atan(------------------------------------------)
+--R                   2                     3                     3
+--R                                  atan(----)            atan(----)
+--R                                        +-+                   +-+
+--R                                       \|3       +-+         \|3
+--R                              sin(----------) - \|3 cos(----------) + 2x
+--R                                       2                     2
+--R  /
+--R       +-+
+--R     2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1194
+
+--S 1195 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3                  \|3               \|3
+--R                 sin(----------)  + x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                   3
+--R                            atan(----)
+--R                                  +-+
+--R                     +-+         \|3       2
+--R                 - x\|3 cos(----------) + x
+--R                                 2
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                              3
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            2
+--R     + 
+--R                                              3                 3
+--R                                       atan(----)        atan(----)
+--R                   3                         +-+               +-+
+--R            atan(----)          +-+         \|3               \|3
+--R                  +-+          \|3 sin(----------) + cos(----------)
+--R                 \|3                        2                 2
+--R       4sin(----------)atan(------------------------------------------)
+--R                 2                     3                     3
+--R                                atan(----)            atan(----)
+--R                                      +-+                   +-+
+--R                                     \|3       +-+         \|3
+--R                            sin(----------) - \|3 cos(----------) - 2x
+--R                                     2                     2
+--R     + 
+--R                                                3                 3
+--R                                         atan(----)        atan(----)
+--R                     3                         +-+               +-+
+--R              atan(----)          +-+         \|3               \|3
+--R                    +-+          \|3 sin(----------) + cos(----------)
+--R                   \|3                        2                 2
+--R       - 4sin(----------)atan(------------------------------------------)
+--R                   2                     3                     3
+--R                                  atan(----)            atan(----)
+--R                                        +-+                   +-+
+--R                                       \|3       +-+         \|3
+--R                              sin(----------) - \|3 cos(----------) + 2x
+--R                                       2                     2
+--R     + 
+--R               +-+    2                +-+    2          +-+      +-+
+--R       - log(x\|3  + x  + 1) + log(- x\|3  + x  + 1) - 2\|3 atan(\|3  + 2x)
+--R     + 
+--R         +-+      +-+
+--R       2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1195
+
+--S 1196 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                             3   8
+--R                      atan(----)
+--R                            +-+
+--R          4     2          \|3
+--R       (3x  - 3x )sin(----------)
+--R                           2
+--R     + 
+--R                                3   2                        3   6
+--R                         atan(----)                   atan(----)
+--R                               +-+                          +-+
+--R            4      2          \|3         6     4          \|3
+--R       ((12x  - 12x )cos(----------)  + 6x  - 6x )sin(----------)
+--R                              2                            2
+--R     + 
+--R                                       3              3   5
+--R                                atan(----)     atan(----)
+--R                                      +-+            +-+
+--R          6     4     2  +-+         \|3            \|3
+--R       (8x  - 8x  - 4x )\|3 cos(----------)sin(----------)
+--R                                     2              2
+--R     + 
+--R                                   3   4                         3   2
+--R                            atan(----)                    atan(----)
+--R                                  +-+                           +-+
+--R               4      2          \|3          6     4          \|3         8
+--R           (18x  - 18x )cos(----------)  + (6x  - 6x )cos(----------)  + 6x
+--R                                 2                             2
+--R         + 
+--R               6     4
+--R           - 6x  - 3x
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                             3   3
+--R                                      atan(----)
+--R                                            +-+
+--R               6      4     2  +-+         \|3
+--R           (16x  - 16x  - 8x )\|3 cos(----------)
+--R                                           2
+--R         + 
+--R                                           3
+--R                                    atan(----)
+--R                                          +-+
+--R              8     6     4  +-+         \|3
+--R           (8x  - 8x  - 4x )\|3 cos(----------)
+--R                                         2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                   3   6                           3   4
+--R                            atan(----)                      atan(----)
+--R                                  +-+                             +-+
+--R               4      2          \|3            6     4          \|3
+--R           (12x  - 12x )cos(----------)  + (- 6x  + 6x )cos(----------)
+--R                                 2                               2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               8      6      4          \|3         10     8     6
+--R           (12x  - 12x  - 30x )cos(----------)  + 3x   - 3x  - 3x
+--R                                        2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                           3   5
+--R                                    atan(----)
+--R                                          +-+
+--R              6     4     2  +-+         \|3
+--R           (8x  - 8x  - 4x )\|3 cos(----------)
+--R                                         2
+--R         + 
+--R                                             3   3
+--R                                      atan(----)
+--R                                            +-+
+--R                8     6     4  +-+         \|3
+--R           (- 8x  + 8x  + 4x )\|3 cos(----------)
+--R                                           2
+--R         + 
+--R                                             3
+--R                                      atan(----)
+--R                                            +-+
+--R              10     8      6  +-+         \|3
+--R           (2x   - 2x  - 10x )\|3 cos(----------)
+--R                                           2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                             3   8                           3   6
+--R                      atan(----)                      atan(----)
+--R                            +-+                             +-+
+--R          4     2          \|3            6     4          \|3
+--R       (3x  - 3x )cos(----------)  + (- 6x  + 6x )cos(----------)
+--R                           2                               2
+--R     + 
+--R                                   3   4                                  3   2
+--R                            atan(----)                             atan(----)
+--R                                  +-+                                    +-+
+--R          8     6     4          \|3            10     8     6          \|3
+--R       (6x  - 6x  - 3x )cos(----------)  + (- 3x   + 3x  + 3x )cos(----------)
+--R                                 2                                      2
+--R     + 
+--R           8
+--R       - 3x
+--R  /
+--R                                 3   8
+--R                          atan(----)
+--R                                +-+
+--R          4     2              \|3
+--R       (3x  - 3x  + 3)sin(----------)
+--R                               2
+--R     + 
+--R                                     3   2                              3   6
+--R                              atan(----)                         atan(----)
+--R                                    +-+                                +-+
+--R            4      2               \|3         6     4     2          \|3
+--R       ((12x  - 12x  + 12)cos(----------)  + 6x  - 6x  + 6x )sin(----------)
+--R                                   2                                  2
+--R     + 
+--R                                          3              3   5
+--R                                   atan(----)     atan(----)
+--R                                         +-+            +-+
+--R           6      4      2  +-+         \|3            \|3
+--R       (12x  - 12x  + 12x )\|3 cos(----------)sin(----------)
+--R                                        2              2
+--R     + 
+--R                                        3   4
+--R                                 atan(----)
+--R                                       +-+
+--R               4      2               \|3
+--R           (18x  - 18x  + 18)cos(----------)
+--R                                      2
+--R         + 
+--R                                       3   2
+--R                                atan(----)
+--R                                      +-+
+--R              6     4     2          \|3         8     6     4
+--R           (6x  - 6x  + 6x )cos(----------)  + 9x  - 9x  + 9x
+--R                                     2
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   3
+--R                                       atan(----)
+--R                                             +-+
+--R               6      4      2  +-+         \|3
+--R           (24x  - 24x  + 24x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                              3
+--R                                       atan(----)
+--R                                             +-+
+--R               8      6      4  +-+         \|3
+--R           (12x  - 12x  + 12x )\|3 cos(----------)
+--R                                            2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                        3   6
+--R                                 atan(----)
+--R                                       +-+
+--R               4      2               \|3
+--R           (12x  - 12x  + 12)cos(----------)
+--R                                      2
+--R         + 
+--R                                         3   4
+--R                                  atan(----)
+--R                                        +-+
+--R                6     4     2          \|3
+--R           (- 6x  + 6x  - 6x )cos(----------)
+--R                                       2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               8      6      4          \|3         10     8     6
+--R           (42x  - 42x  + 42x )cos(----------)  + 6x   - 6x  + 6x
+--R                                        2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   5
+--R                                       atan(----)
+--R                                             +-+
+--R               6      4      2  +-+         \|3
+--R           (12x  - 12x  + 12x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                                3   3
+--R                                         atan(----)
+--R                                               +-+
+--R                 8      6      4  +-+         \|3
+--R           (- 12x  + 12x  - 12x )\|3 cos(----------)
+--R                                              2
+--R         + 
+--R                                               3
+--R                                        atan(----)
+--R                                              +-+
+--R               10      8      6  +-+         \|3
+--R           (12x   - 12x  + 12x )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                 3   8                                 3   6
+--R                          atan(----)                            atan(----)
+--R                                +-+                                   +-+
+--R          4     2              \|3            6     4     2          \|3
+--R       (3x  - 3x  + 3)cos(----------)  + (- 6x  + 6x  - 6x )cos(----------)
+--R                               2                                     2
+--R     + 
+--R                                   3   4                                  3   2
+--R                            atan(----)                             atan(----)
+--R                                  +-+                                    +-+
+--R          8     6     4          \|3            10     8     6          \|3
+--R       (9x  - 9x  + 9x )cos(----------)  + (- 6x   + 6x  - 6x )cos(----------)
+--R                                 2                                      2
+--R     + 
+--R         12     10     8
+--R       3x   - 3x   + 3x
+--R                                                    Type: Expression(Integer)
+--E 1196
+
+)clear all
+
+--S 1197 of 1353
+t0:=1/(2+2*x^2+x^4)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1197
+
+--S 1198 of 1353
+r0:=-1/8*log(x^2+sqrt(2)-x*sqrt(2*(-1+sqrt(2))))/sqrt(-1+sqrt(2))+_
+   1/8*log(x^2+sqrt(2)+x*sqrt(2*(-1+sqrt(2))))/sqrt(-1+sqrt(2))-_
+   1/4*atan((-2*x+sqrt(2*(-1+sqrt(2))))/sqrt(2*(1+sqrt(2))))*_
+   sqrt(-1+sqrt(2))+1/4*atan((2*x+sqrt(2*(-1+sqrt(2))))/sqrt(2*(1+_
+   sqrt(2))))*sqrt(-1+sqrt(2))
+--R 
+--R
+--R   (2)
+--R             +---------+                        +---------+
+--R             |  +-+         +-+    2            |  +-+         +-+    2
+--R       log(x\|2\|2  - 2  + \|2  + x ) - log(- x\|2\|2  - 2  + \|2  + x )
+--R     + 
+--R                                   +---------+                +---------+
+--R                          +-+      |  +-+           +-+       |  +-+
+--R          +-+          ((\|2  - 1)\|2\|2  - 2  + 2x\|2  - 2x)\|2\|2  + 2
+--R       (2\|2  - 2)atan(--------------------------------------------------)
+--R                                                2
+--R     + 
+--R                                     +---------+                +---------+
+--R                            +-+      |  +-+           +-+       |  +-+
+--R            +-+          ((\|2  - 1)\|2\|2  - 2  - 2x\|2  + 2x)\|2\|2  + 2
+--R       (- 2\|2  + 2)atan(--------------------------------------------------)
+--R                                                  2
+--R  /
+--R       +--------+
+--R       | +-+
+--R     8\|\|2  - 1
+--R                                                    Type: Expression(Integer)
+--E 1198
+
+--S 1199 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            4+-+    %pi
+--R            \|2 cos(---)
+--R                     8
+--R         *
+--R            log
+--R                 4+-+2    %pi 2     +-+4+-+    %pi    4+-+2    %pi 2
+--R                 \|2  sin(---)  + x\|2 \|2 sin(---) + \|2  cos(---)
+--R                           8                    8               8
+--R               + 
+--R                     +-+4+-+    %pi     2
+--R                 - x\|2 \|2 cos(---) + x
+--R                                 8
+--R     + 
+--R         4+-+    %pi
+--R         \|2 cos(---)
+--R                  8
+--R      *
+--R         log
+--R              4+-+2    %pi 2     +-+4+-+    %pi    4+-+2    %pi 2
+--R              \|2  sin(---)  - x\|2 \|2 sin(---) + \|2  cos(---)
+--R                        8                    8               8
+--R            + 
+--R                +-+4+-+    %pi     2
+--R              x\|2 \|2 cos(---) + x
+--R                            8
+--R     + 
+--R                             4+-+    %pi    4+-+    %pi
+--R                             \|2 sin(---) + \|2 cos(---)
+--R        4+-+    %pi                   8              8
+--R       2\|2 sin(---)atan(-----------------------------------)
+--R                 8       4+-+    %pi    4+-+    %pi      +-+
+--R                         \|2 sin(---) - \|2 cos(---) - x\|2
+--R                                  8              8
+--R     + 
+--R                               4+-+    %pi    4+-+    %pi
+--R                               \|2 sin(---) + \|2 cos(---)
+--R          4+-+    %pi                   8              8
+--R       - 2\|2 sin(---)atan(-----------------------------------)
+--R                   8       4+-+    %pi    4+-+    %pi      +-+
+--R                           \|2 sin(---) - \|2 cos(---) + x\|2
+--R                                    8              8
+--R  /
+--R       +-+
+--R     4\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1199
+
+--S 1200 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +---------+
+--R          +-+      |  +-+         +-+    2
+--R       - \|2 log(x\|2\|2  - 2  + \|2  + x )
+--R     + 
+--R       -
+--R                          +--------+
+--R             4+-+    %pi  | +-+
+--R            2\|2 cos(---)\|\|2  - 1
+--R                      8
+--R         *
+--R            log
+--R                 4+-+2    %pi 2     +-+4+-+    %pi    4+-+2    %pi 2
+--R                 \|2  sin(---)  + x\|2 \|2 sin(---) + \|2  cos(---)
+--R                           8                    8               8
+--R               + 
+--R                     +-+4+-+    %pi     2
+--R                 - x\|2 \|2 cos(---) + x
+--R                                 8
+--R     + 
+--R                       +--------+
+--R          4+-+    %pi  | +-+
+--R         2\|2 cos(---)\|\|2  - 1
+--R                   8
+--R      *
+--R         log
+--R              4+-+2    %pi 2     +-+4+-+    %pi    4+-+2    %pi 2
+--R              \|2  sin(---)  - x\|2 \|2 sin(---) + \|2  cos(---)
+--R                        8                    8               8
+--R            + 
+--R                +-+4+-+    %pi     2
+--R              x\|2 \|2 cos(---) + x
+--R                            8
+--R     + 
+--R                   +---------+
+--R        +-+        |  +-+         +-+    2
+--R       \|2 log(- x\|2\|2  - 2  + \|2  + x )
+--R     + 
+--R                                   +---------+                +---------+
+--R                          +-+      |  +-+           +-+       |  +-+
+--R          +-+          ((\|2  - 1)\|2\|2  - 2  + 2x\|2  - 2x)\|2\|2  + 2
+--R       (2\|2  - 4)atan(--------------------------------------------------)
+--R                                                2
+--R     + 
+--R                                     +---------+                +---------+
+--R                            +-+      |  +-+           +-+       |  +-+
+--R            +-+          ((\|2  - 1)\|2\|2  - 2  - 2x\|2  + 2x)\|2\|2  + 2
+--R       (- 2\|2  + 4)atan(--------------------------------------------------)
+--R                                                  2
+--R     + 
+--R                                        4+-+    %pi    4+-+    %pi
+--R                     +--------+         \|2 sin(---) + \|2 cos(---)
+--R        4+-+    %pi  | +-+                       8              8
+--R       4\|2 sin(---)\|\|2  - 1 atan(-----------------------------------)
+--R                 8                  4+-+    %pi    4+-+    %pi      +-+
+--R                                    \|2 sin(---) - \|2 cos(---) - x\|2
+--R                                             8              8
+--R     + 
+--R                                          4+-+    %pi    4+-+    %pi
+--R                       +--------+         \|2 sin(---) + \|2 cos(---)
+--R          4+-+    %pi  | +-+                       8              8
+--R       - 4\|2 sin(---)\|\|2  - 1 atan(-----------------------------------)
+--R                   8                  4+-+    %pi    4+-+    %pi      +-+
+--R                                      \|2 sin(---) - \|2 cos(---) + x\|2
+--R                                               8              8
+--R  /
+--R           +--------+
+--R       +-+ | +-+
+--R     8\|2 \|\|2  - 1
+--R                                                    Type: Expression(Integer)
+--E 1200
+
+--S 1201 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                  2      4+-+2      2          %pi 8
+--R           ((- 20x  + 28)\|2   + 28x  - 40)sin(---)
+--R                                                8
+--R         + 
+--R                  2       4+-+2       2           %pi 2    %pi 6
+--R           ((- 80x  + 112)\|2   + 112x  - 160)cos(---) sin(---)
+--R                                                   8        8
+--R         + 
+--R                 4       2 4+-+2       4       2     %pi     %pi 5
+--R           ((112x  - 160x )\|2   - 160x  + 224x )cos(---)sin(---)
+--R                                                      8       8
+--R         + 
+--R                       2       4+-+2       2           %pi 4
+--R               ((- 120x  + 168)\|2   + 168x  - 240)cos(---)
+--R                                                        8
+--R             + 
+--R                     6      4 4+-+2      6      4
+--R               (- 20x  + 28x )\|2   + 28x  - 40x
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  8
+--R         + 
+--R                 4       2 4+-+2       4       2     %pi 3    %pi 3
+--R           ((224x  - 320x )\|2   - 320x  + 448x )cos(---) sin(---)
+--R                                                      8        8
+--R         + 
+--R                      2       4+-+2       2           %pi 6
+--R               ((- 80x  + 112)\|2   + 112x  - 160)cos(---)
+--R                                                       8
+--R             + 
+--R                       6       4 4+-+2       6       4     %pi 2
+--R               ((- 200x  + 280x )\|2   + 280x  - 400x )cos(---)
+--R                                                            8
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  8
+--R         + 
+--R                     4       2 4+-+2       4       2     %pi 5
+--R               ((112x  - 160x )\|2   - 160x  + 224x )cos(---)
+--R                                                          8
+--R             + 
+--R                    8      6 4+-+2      8       6     %pi
+--R               ((56x  - 80x )\|2   - 80x  + 112x )cos(---)
+--R                                                       8
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  8
+--R         + 
+--R                  2      4+-+2      2          %pi 8
+--R           ((- 20x  + 28)\|2   + 28x  - 40)cos(---)
+--R                                                8
+--R         + 
+--R                  6      4 4+-+2      6      4     %pi 4        10     8 4+-+2
+--R           ((- 20x  + 28x )\|2   + 28x  - 40x )cos(---)  + (- 5x   + 7x )\|2
+--R                                                    8
+--R         + 
+--R             10      8
+--R           7x   - 10x
+--R      *
+--R          +---------+ +----------+
+--R          |4+-+2      | 4+-+2
+--R         \|\|2   - 1 \|2\|2   + 2
+--R     + 
+--R                 2      4+-+2      2          %pi 8
+--R           ((- 8x  - 12)\|2   + 12x  + 16)sin(---)
+--R                                               8
+--R         + 
+--R                  2      4+-+2      2          %pi 2    %pi 6
+--R           ((- 32x  - 48)\|2   + 48x  + 64)cos(---) sin(---)
+--R                                                8        8
+--R         + 
+--R                4      2 4+-+2      4      2     %pi     %pi 5
+--R           ((48x  + 64x )\|2   - 64x  - 96x )cos(---)sin(---)
+--R                                                  8       8
+--R         + 
+--R                      2      4+-+2      2          %pi 4        6      4 4+-+2
+--R               ((- 48x  - 72)\|2   + 72x  + 96)cos(---)  + (- 8x  - 12x )\|2
+--R                                                    8
+--R             + 
+--R                  6      4
+--R               12x  + 16x
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  8
+--R         + 
+--R                4       2 4+-+2       4       2     %pi 3    %pi 3
+--R           ((96x  + 128x )\|2   - 128x  - 192x )cos(---) sin(---)
+--R                                                     8        8
+--R         + 
+--R                      2      4+-+2      2          %pi 6
+--R               ((- 32x  - 48)\|2   + 48x  + 64)cos(---)
+--R                                                    8
+--R             + 
+--R                      6       4 4+-+2       6       4     %pi 2
+--R               ((- 80x  - 120x )\|2   + 120x  + 160x )cos(---)
+--R                                                           8
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  8
+--R         + 
+--R                    4      2 4+-+2      4      2     %pi 5
+--R               ((48x  + 64x )\|2   - 64x  - 96x )cos(---)
+--R                                                      8
+--R             + 
+--R                    8      6 4+-+2      8      6     %pi
+--R               ((24x  + 32x )\|2   - 32x  - 48x )cos(---)
+--R                                                      8
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  8
+--R         + 
+--R                 2      4+-+2      2          %pi 8
+--R           ((- 8x  - 12)\|2   + 12x  + 16)cos(---)
+--R                                               8
+--R         + 
+--R                 6      4 4+-+2      6      4     %pi 4        10     8 4+-+2
+--R           ((- 8x  - 12x )\|2   + 12x  + 16x )cos(---)  + (- 2x   - 3x )\|2
+--R                                                   8
+--R         + 
+--R             10     8
+--R           3x   + 4x
+--R      *
+--R          +---------+ +----------+
+--R          |4+-+2      | 4+-+2
+--R         \|\|2   - 1 \|2\|2   - 2
+--R     + 
+--R            4      2      4+-+2      4       2           %pi 8
+--R       ((40x  + 80x  + 80)\|2   - 56x  - 112x  - 112)sin(---)
+--R                                                          8
+--R     + 
+--R                 4       2       4+-+2       4       2           %pi 2
+--R           ((160x  + 320x  + 320)\|2   - 224x  - 448x  - 448)cos(---)
+--R                                                                  8
+--R         + 
+--R                 6      4      2 4+-+2      6      4      2
+--R           (- 28x  - 56x  - 56x )\|2   + 40x  + 80x  + 80x
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              8
+--R     + 
+--R               6       4       2 4+-+2       6       4       2     %pi     %pi 5
+--R       ((- 168x  - 336x  - 336x )\|2   + 240x  + 480x  + 480x )cos(---)sin(---)
+--R                                                                    8       8
+--R     + 
+--R                 4       2       4+-+2       4       2           %pi 4
+--R           ((240x  + 480x  + 480)\|2   - 336x  - 672x  - 672)cos(---)
+--R                                                                  8
+--R         + 
+--R                  6      4      2 4+-+2      6      4      2     %pi 2
+--R           ((- 28x  - 56x  - 56x )\|2   + 40x  + 80x  + 80x )cos(---)
+--R                                                                  8
+--R         + 
+--R               8      6      4 4+-+2      8      6      4
+--R           (20x  + 40x  + 40x )\|2   - 28x  - 56x  - 56x
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              8
+--R     + 
+--R                   6       4       2 4+-+2       6       4       2     %pi 3
+--R           ((- 336x  - 672x  - 672x )\|2   + 480x  + 960x  + 960x )cos(---)
+--R                                                                        8
+--R         + 
+--R                8       6       4 4+-+2       8       6       4     %pi
+--R           ((80x  + 160x  + 160x )\|2   - 112x  - 224x  - 224x )cos(---)
+--R                                                                     8
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              8
+--R     + 
+--R                 4       2       4+-+2       4       2           %pi 6
+--R           ((160x  + 320x  + 320)\|2   - 224x  - 448x  - 448)cos(---)
+--R                                                                  8
+--R         + 
+--R                6      4      2 4+-+2      6      4      2     %pi 4
+--R           ((28x  + 56x  + 56x )\|2   - 40x  - 80x  - 80x )cos(---)
+--R                                                                8
+--R         + 
+--R                 8       6       4 4+-+2       8       6       4     %pi 2
+--R           ((200x  + 400x  + 400x )\|2   - 280x  - 560x  - 560x )cos(---)
+--R                                                                      8
+--R         + 
+--R                 10      8      6 4+-+2      10      8      6
+--R           (- 14x   - 28x  - 28x )\|2   + 20x   + 40x  + 40x
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              8
+--R     + 
+--R                   6       4       2 4+-+2       6       4       2     %pi 5
+--R           ((- 168x  - 336x  - 336x )\|2   + 240x  + 480x  + 480x )cos(---)
+--R                                                                        8
+--R         + 
+--R                  8       6       4 4+-+2       8       6       4     %pi 3
+--R           ((- 80x  - 160x  - 160x )\|2   + 112x  + 224x  + 224x )cos(---)
+--R                                                                       8
+--R         + 
+--R                  10      8      6 4+-+2      10      8      6     %pi
+--R           ((- 28x   - 56x  - 56x )\|2   + 40x   + 80x  + 80x )cos(---)
+--R                                                                    8
+--R      *
+--R             %pi
+--R         sin(---)
+--R              8
+--R     + 
+--R            4      2      4+-+2      4       2           %pi 8
+--R       ((40x  + 80x  + 80)\|2   - 56x  - 112x  - 112)cos(---)
+--R                                                          8
+--R     + 
+--R            6      4      2 4+-+2      6      4      2     %pi 6
+--R       ((28x  + 56x  + 56x )\|2   - 40x  - 80x  - 80x )cos(---)
+--R                                                            8
+--R     + 
+--R            8      6      4 4+-+2      8      6      4     %pi 4
+--R       ((20x  + 40x  + 40x )\|2   - 28x  - 56x  - 56x )cos(---)
+--R                                                            8
+--R     + 
+--R            10      8      6 4+-+2      10      8      6     %pi 2
+--R       ((14x   + 28x  + 28x )\|2   - 20x   - 40x  - 40x )cos(---)
+--R                                                              8
+--R  /
+--R            4       2       4+-+2       4       2           %pi 8
+--R       ((80x  + 160x  + 160)\|2   - 112x  - 224x  - 224)sin(---)
+--R                                                             8
+--R     + 
+--R             4       2       4+-+2       4       2           %pi 2    %pi 6
+--R       ((320x  + 640x  + 640)\|2   - 448x  - 896x  - 896)cos(---) sin(---)
+--R                                                              8        8
+--R     + 
+--R                 6       4       2 4+-+2       6        4        2     %pi
+--R         ((- 448x  - 896x  - 896x )\|2   + 640x  + 1280x  + 1280x )cos(---)
+--R                                                                        8
+--R      *
+--R             %pi 5
+--R         sin(---)
+--R              8
+--R     + 
+--R                 4       2       4+-+2       4        2            %pi 4
+--R           ((480x  + 960x  + 960)\|2   - 672x  - 1344x  - 1344)cos(---)
+--R                                                                    8
+--R         + 
+--R               8       6       4 4+-+2       8       6       4
+--R           (80x  + 160x  + 160x )\|2   - 112x  - 224x  - 224x
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              8
+--R     + 
+--R                 6        4        2 4+-+2        6        4        2     %pi 3
+--R         ((- 896x  - 1792x  - 1792x )\|2   + 1280x  + 2560x  + 2560x )cos(---)
+--R                                                                           8
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              8
+--R     + 
+--R                 4       2       4+-+2       4       2           %pi 6
+--R           ((320x  + 640x  + 640)\|2   - 448x  - 896x  - 896)cos(---)
+--R                                                                  8
+--R         + 
+--R                 8        6        4 4+-+2        8        6        4     %pi 2
+--R           ((800x  + 1600x  + 1600x )\|2   - 1120x  - 2240x  - 2240x )cos(---)
+--R                                                                           8
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              8
+--R     + 
+--R                   6       4       2 4+-+2       6        4        2     %pi 5
+--R           ((- 448x  - 896x  - 896x )\|2   + 640x  + 1280x  + 1280x )cos(---)
+--R                                                                          8
+--R         + 
+--R                   10       8       6 4+-+2       10       8       6     %pi
+--R           ((- 224x   - 448x  - 448x )\|2   + 320x   + 640x  + 640x )cos(---)
+--R                                                                          8
+--R      *
+--R             %pi
+--R         sin(---)
+--R              8
+--R     + 
+--R            4       2       4+-+2       4       2           %pi 8
+--R       ((80x  + 160x  + 160)\|2   - 112x  - 224x  - 224)cos(---)
+--R                                                             8
+--R     + 
+--R            8       6       4 4+-+2       8       6       4     %pi 4
+--R       ((80x  + 160x  + 160x )\|2   - 112x  - 224x  - 224x )cos(---)
+--R                                                                 8
+--R     + 
+--R           12      10      8 4+-+2      12      10      8
+--R       (20x   + 40x   + 40x )\|2   - 28x   - 56x   - 56x
+--R                                                    Type: Expression(Integer)
+--E 1201
+
+)clear all
+
+--S 1202 of 1353
+t0:=x/(1+x^2+x^4)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1202
+
+--S 1203 of 1353
+r0:=atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                2      +-+
+--R             (2x  + 1)\|3
+--R        atan(-------------)
+--R                   3
+--R   (2)  -------------------
+--R                 +-+
+--R                \|3
+--R                                                    Type: Expression(Integer)
+--E 1203
+
+--S 1204 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2      +-+
+--R             (2x  + 1)\|3
+--R        atan(-------------)
+--R                   3
+--R   (3)  -------------------
+--R                 +-+
+--R                \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1204
+
+--S 1205 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1205
+
+--S 1206 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1206
+
+)clear all
+
+--S 1207 of 1353
+t0:=x/(10+2*x^2+x^4)
+--R 
+--R
+--R              x
+--R   (1)  -------------
+--R         4     2
+--R        x  + 2x  + 10
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1207
+
+--S 1208 of 1353
+r0:=1/6*atan(1/3+1/3*x^2)
+--R 
+--R
+--R              2
+--R             x  + 1
+--R        atan(------)
+--R                3
+--R   (2)  ------------
+--R              6
+--R                                                    Type: Expression(Integer)
+--E 1208
+
+--S 1209 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R             x  + 1
+--R        atan(------)
+--R                3
+--R   (3)  ------------
+--R              6
+--R                                         Type: Union(Expression(Integer),...)
+--E 1209
+
+--S 1210 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1210
+
+--S 1211 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1211
+
+)clear all
+
+--S 1212 of 1353
+t0:=x^2/(20+9*x^2+x^4)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  -------------
+--R         4     2
+--R        x  + 9x  + 20
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1212
+
+--S 1213 of 1353
+r0:=-2*atan(1/2*x)+atan(x/sqrt(5))*sqrt(5)
+--R 
+--R
+--R                   +-+
+--R         +-+     x\|5           x
+--R   (2)  \|5 atan(-----) - 2atan(-)
+--R                   5            2
+--R                                                    Type: Expression(Integer)
+--E 1213
+
+--S 1214 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    +-+
+--R           +-+     \|5           x
+--R   (3)  - \|5 atan(----) - 2atan(-)
+--R                     x           2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1214
+
+--S 1215 of 1353
+m0:=a0-r0
+--R 
+--R
+--R                     +-+              +-+
+--R           +-+     x\|5      +-+     \|5
+--R   (4)  - \|5 atan(-----) - \|5 atan(----)
+--R                     5                 x
+--R                                                    Type: Expression(Integer)
+--E 1215
+
+--S 1216 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1216
+
+)clear all
+
+--S 1217 of 1353
+t0:=x^2/(1-x^2+x^4)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         4    2
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1217
+
+--S 1218 of 1353
+r0:=-1/2*atan(-2*x+sqrt(3))+1/2*atan(2*x+sqrt(3))+1/4*log(1+x^2-_
+   x*sqrt(3))/sqrt(3)-1/4*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R               +-+    2                +-+    2          +-+      +-+
+--R       - log(x\|3  + x  + 1) + log(- x\|3  + x  + 1) + 2\|3 atan(\|3  + 2x)
+--R     + 
+--R           +-+      +-+
+--R       - 2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1218
+
+--S 1219 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         cos(----------)
+--R                  2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R       -
+--R                       3
+--R                atan(----)
+--R                      +-+
+--R                     \|3
+--R            cos(----------)
+--R                     2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3                   \|3               \|3        2
+--R            log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                                           3
+--R                                    atan(----)
+--R                     3                    +-+
+--R              atan(----)                 \|3
+--R                    +-+         cos(----------)
+--R                   \|3                   2
+--R       - 2sin(----------)atan(-------------------)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------) - x
+--R                                       2
+--R     + 
+--R                                         3
+--R                                  atan(----)
+--R                   3                    +-+
+--R            atan(----)                 \|3
+--R                  +-+         cos(----------)
+--R                 \|3                   2
+--R       2sin(----------)atan(-------------------)
+--R                 2                     3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------) + x
+--R                                     2
+--R  /
+--R       +-+
+--R     2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1219
+
+--S 1220 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3                   \|3               \|3        2
+--R            log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                                           3
+--R                                    atan(----)
+--R                     3                    +-+
+--R              atan(----)                 \|3
+--R                    +-+         cos(----------)
+--R                   \|3                   2
+--R       - 4sin(----------)atan(-------------------)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------) - x
+--R                                       2
+--R     + 
+--R                                         3
+--R                                  atan(----)
+--R                   3                    +-+
+--R            atan(----)                 \|3
+--R                  +-+         cos(----------)
+--R                 \|3                   2                 +-+    2
+--R       4sin(----------)atan(-------------------) + log(x\|3  + x  + 1)
+--R                 2                     3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------) + x
+--R                                     2
+--R     + 
+--R                 +-+    2          +-+      +-+           +-+      +-+
+--R       - log(- x\|3  + x  + 1) - 2\|3 atan(\|3  + 2x) + 2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1220
+
+--S 1221 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                       3   4                    3   2                  3   2
+--R                atan(----)               atan(----)             atan(----)
+--R                      +-+                      +-+                    +-+
+--R           2         \|3            2         \|3         4          \|3
+--R       - 3x sin(----------)  + (- 6x cos(----------)  + 6x )sin(----------)
+--R                     2                        2                      2
+--R     + 
+--R                                         3              3
+--R                                  atan(----)     atan(----)
+--R                                        +-+            +-+
+--R            6     4     2  +-+         \|3            \|3
+--R       (- 4x  + 4x  - 4x )\|3 cos(----------)sin(----------)
+--R                                       2              2
+--R     + 
+--R                       3   4                 3   2
+--R                atan(----)            atan(----)
+--R                      +-+                   +-+
+--R           2         \|3         4         \|3         6
+--R       - 3x cos(----------)  - 6x cos(----------)  - 3x
+--R                     2                     2
+--R  /
+--R                                 3   4
+--R                          atan(----)
+--R                                +-+
+--R          4     2              \|3
+--R       (3x  - 3x  + 3)sin(----------)
+--R                               2
+--R     + 
+--R                                  3   2                              3   2
+--R                           atan(----)                         atan(----)
+--R                                 +-+                                +-+
+--R           4     2              \|3         6     4     2          \|3
+--R       ((6x  - 6x  + 6)cos(----------)  - 6x  + 6x  - 6x )sin(----------)
+--R                                2                                  2
+--R     + 
+--R                                 3   4                               3   2
+--R                          atan(----)                          atan(----)
+--R                                +-+                                 +-+
+--R          4     2              \|3          6     4     2          \|3         8
+--R       (3x  - 3x  + 3)cos(----------)  + (6x  - 6x  + 6x )cos(----------)  + 3x
+--R                               2                                   2
+--R     + 
+--R           6     4
+--R       - 3x  + 3x
+--R                                                    Type: Expression(Integer)
+--E 1221
+
+)clear all
+
+--S 1222 of 1353
+t0:=x^2/(2-2*x^2+x^4)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         4     2
+--R        x  - 2x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1222
+
+--S 1223 of 1353
+r0:=-1/2*atan((-2*x+sqrt(2*(1+sqrt(2))))/sqrt(2*(-1+sqrt(2))))*_
+   sqrt(1/2*(1+sqrt(2)))+1/2*atan((2*x+sqrt(2*(1+sqrt(2))))/sqrt(2*_
+   (-1+sqrt(2))))*sqrt(1/2*(1+sqrt(2)))+1/4*log(x^2+sqrt(2)-x*sqrt(2*_
+   (1+sqrt(2))))/sqrt(2*(1+sqrt(2)))-1/4*log(x^2+sqrt(2)+x*sqrt(2*_
+   (1+sqrt(2))))/sqrt(2*(1+sqrt(2)))
+--R 
+--R
+--R   (2)
+--R                   +---------+
+--R          +-+      |  +-+         +-+    2
+--R       - \|2 log(x\|2\|2  + 2  + \|2  + x )
+--R     + 
+--R                   +---------+
+--R        +-+        |  +-+         +-+    2
+--R       \|2 log(- x\|2\|2  + 2  + \|2  + x )
+--R     + 
+--R           +--------+ +---------+
+--R           | +-+      |  +-+
+--R         2\|\|2  + 1 \|2\|2  + 2
+--R      *
+--R                         +---------+ +---------+                 +---------+
+--R                +-+      |  +-+      |  +-+            +-+       |  +-+
+--R              (\|2  + 1)\|2\|2  - 2 \|2\|2  + 2  + (2x\|2  + 2x)\|2\|2  - 2
+--R         atan(--------------------------------------------------------------)
+--R                                             2
+--R     + 
+--R       -
+--R              +--------+ +---------+
+--R              | +-+      |  +-+
+--R            2\|\|2  + 1 \|2\|2  + 2
+--R         *
+--R                          +---------+ +---------+                   +---------+
+--R                 +-+      |  +-+      |  +-+              +-+       |  +-+
+--R               (\|2  + 1)\|2\|2  - 2 \|2\|2  + 2  + (- 2x\|2  - 2x)\|2\|2  - 2
+--R          atan(----------------------------------------------------------------)
+--R                                               2
+--R  /
+--R           +---------+
+--R       +-+ |  +-+
+--R     4\|2 \|2\|2  + 2
+--R                                                    Type: Expression(Integer)
+--E 1223
+
+--S 1224 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       4+-+    %pi     4+-+2    %pi 2     4+-+    %pi    4+-+2    %pi 2    2
+--R       \|2 cos(---)log(\|2  sin(---)  + 2x\|2 sin(---) + \|2  cos(---)  + x )
+--R                8                8                 8               8
+--R     + 
+--R         4+-+    %pi     4+-+2    %pi 2     4+-+    %pi    4+-+2    %pi 2    2
+--R       - \|2 cos(---)log(\|2  sin(---)  - 2x\|2 sin(---) + \|2  cos(---)  + x )
+--R                  8                8                 8               8
+--R     + 
+--R                           4+-+    %pi                           4+-+    %pi
+--R                           \|2 cos(---)                          \|2 cos(---)
+--R        4+-+    %pi                 8         4+-+    %pi                 8
+--R     - 2\|2 sin(---)atan(----------------) + 2\|2 sin(---)atan(----------------)
+--R                 8       4+-+    %pi                   8       4+-+    %pi
+--R                         \|2 sin(---) - x                      \|2 sin(---) + x
+--R                                  8                                     8
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1224
+
+--S 1225 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 +---------+
+--R        +-+      |  +-+         +-+    2
+--R       \|2 log(x\|2\|2  + 2  + \|2  + x )
+--R     + 
+--R                          +---------+
+--R          +-+4+-+    %pi  |  +-+
+--R         \|2 \|2 cos(---)\|2\|2  + 2
+--R                      8
+--R      *
+--R             4+-+2    %pi 2     4+-+    %pi    4+-+2    %pi 2    2
+--R         log(\|2  sin(---)  + 2x\|2 sin(---) + \|2  cos(---)  + x )
+--R                       8                 8               8
+--R     + 
+--R       -
+--R                             +---------+
+--R             +-+4+-+    %pi  |  +-+
+--R            \|2 \|2 cos(---)\|2\|2  + 2
+--R                         8
+--R         *
+--R                4+-+2    %pi 2     4+-+    %pi    4+-+2    %pi 2    2
+--R            log(\|2  sin(---)  - 2x\|2 sin(---) + \|2  cos(---)  + x )
+--R                          8                 8               8
+--R     + 
+--R                     +---------+
+--R          +-+        |  +-+         +-+    2
+--R       - \|2 log(- x\|2\|2  + 2  + \|2  + x )
+--R     + 
+--R       -
+--R              +--------+ +---------+
+--R              | +-+      |  +-+
+--R            2\|\|2  + 1 \|2\|2  + 2
+--R         *
+--R                          +---------+ +---------+                 +---------+
+--R                 +-+      |  +-+      |  +-+            +-+       |  +-+
+--R               (\|2  + 1)\|2\|2  - 2 \|2\|2  + 2  + (2x\|2  + 2x)\|2\|2  - 2
+--R          atan(--------------------------------------------------------------)
+--R                                              2
+--R     + 
+--R           +--------+ +---------+
+--R           | +-+      |  +-+
+--R         2\|\|2  + 1 \|2\|2  + 2
+--R      *
+--R                         +---------+ +---------+                   +---------+
+--R                +-+      |  +-+      |  +-+              +-+       |  +-+
+--R              (\|2  + 1)\|2\|2  - 2 \|2\|2  + 2  + (- 2x\|2  - 2x)\|2\|2  - 2
+--R         atan(----------------------------------------------------------------)
+--R                                              2
+--R     + 
+--R                                             4+-+    %pi
+--R                           +---------+       \|2 cos(---)
+--R           +-+4+-+    %pi  |  +-+                     8
+--R       - 2\|2 \|2 sin(---)\|2\|2  + 2 atan(----------------)
+--R                       8                   4+-+    %pi
+--R                                           \|2 sin(---) - x
+--R                                                    8
+--R     + 
+--R                                           4+-+    %pi
+--R                         +---------+       \|2 cos(---)
+--R         +-+4+-+    %pi  |  +-+                     8
+--R       2\|2 \|2 sin(---)\|2\|2  + 2 atan(----------------)
+--R                     8                   4+-+    %pi
+--R                                         \|2 sin(---) + x
+--R                                                  8
+--R  /
+--R           +---------+
+--R       +-+ |  +-+
+--R     4\|2 \|2\|2  + 2
+--R                                                    Type: Expression(Integer)
+--E 1225
+
+--S 1226 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                  2      4+-+2      2          %pi 8
+--R           ((- 28x  - 40)\|2   - 40x  - 56)sin(---)
+--R                                                8
+--R         + 
+--R                       2       4+-+2       2           %pi 2
+--R               ((- 112x  - 160)\|2   - 160x  - 224)cos(---)
+--R                                                        8
+--R             + 
+--R                   4       2 4+-+2       4       2
+--R               (80x  + 112x )\|2   + 112x  + 160x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  8
+--R         + 
+--R                       2       4+-+2       2           %pi 4
+--R               ((- 168x  - 240)\|2   - 240x  - 336)cos(---)
+--R                                                        8
+--R             + 
+--R                    4       2 4+-+2       4       2     %pi 2
+--R               ((80x  + 112x )\|2   + 112x  + 160x )cos(---)
+--R                                                         8
+--R             + 
+--R                     6       4 4+-+2       6       4
+--R               (- 84x  - 120x )\|2   - 120x  - 168x
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  8
+--R         + 
+--R                       2       4+-+2       2           %pi 6
+--R               ((- 112x  - 160)\|2   - 160x  - 224)cos(---)
+--R                                                        8
+--R             + 
+--R                      4       2 4+-+2       4       2     %pi 4
+--R               ((- 80x  - 112x )\|2   - 112x  - 160x )cos(---)
+--R                                                           8
+--R             + 
+--R                    6      4 4+-+2      6       4     %pi 2       8      6 4+-+2
+--R               ((56x  + 80x )\|2   + 80x  + 112x )cos(---)  + (40x  + 56x )\|2
+--R                                                       8
+--R             + 
+--R                  8      6
+--R               56x  + 80x
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  8
+--R         + 
+--R                  2      4+-+2      2          %pi 8
+--R           ((- 28x  - 40)\|2   - 40x  - 56)cos(---)
+--R                                                8
+--R         + 
+--R                  4       2 4+-+2       4       2     %pi 6
+--R           ((- 80x  - 112x )\|2   - 112x  - 160x )cos(---)
+--R                                                       8
+--R         + 
+--R                  6       4 4+-+2       6       4     %pi 4
+--R           ((- 84x  - 120x )\|2   - 120x  - 168x )cos(---)
+--R                                                       8
+--R         + 
+--R                  8      6 4+-+2      8      6     %pi 2        10      8 4+-+2
+--R           ((- 40x  - 56x )\|2   - 56x  - 80x )cos(---)  + (- 7x   - 10x )\|2
+--R                                                    8
+--R         + 
+--R                10      8
+--R           - 10x   - 14x
+--R      *
+--R          +---------+ +----------+
+--R          |4+-+2      | 4+-+2
+--R         \|\|2   + 1 \|2\|2   - 2
+--R     + 
+--R              2      4+-+2      2          %pi 8
+--R       ((- 40x  + 56)\|2   - 56x  + 80)sin(---)
+--R                                            8
+--R     + 
+--R                   2       4+-+2       2           %pi 2        4       2 4+-+2
+--R           ((- 160x  + 224)\|2   - 224x  + 320)cos(---)  + (112x  - 160x )\|2
+--R                                                    8
+--R         + 
+--R               4       2
+--R           160x  - 224x
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              8
+--R     + 
+--R               6       4       2 4+-+2       6       4       2     %pi     %pi 5
+--R       ((- 112x  + 224x  - 224x )\|2   - 160x  + 320x  - 320x )cos(---)sin(---)
+--R                                                                    8       8
+--R     + 
+--R                   2       4+-+2       2           %pi 4
+--R           ((- 240x  + 336)\|2   - 336x  + 480)cos(---)
+--R                                                    8
+--R         + 
+--R                 4       2 4+-+2       4       2     %pi 2
+--R           ((112x  - 160x )\|2   + 160x  - 224x )cos(---)
+--R                                                      8
+--R         + 
+--R                  6       4 4+-+2       6       4
+--R           (- 120x  + 168x )\|2   - 168x  + 240x
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              8
+--R     + 
+--R                   6       4       2 4+-+2       6       4       2     %pi 3
+--R           ((- 224x  + 448x  - 448x )\|2   - 320x  + 640x  - 640x )cos(---)
+--R                                                                        8
+--R         + 
+--R                 8       6       4 4+-+2       8       6       4     %pi
+--R           ((160x  - 320x  + 320x )\|2   + 224x  - 448x  + 448x )cos(---)
+--R                                                                      8
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              8
+--R     + 
+--R                   2       4+-+2       2           %pi 6
+--R           ((- 160x  + 224)\|2   - 224x  + 320)cos(---)
+--R                                                    8
+--R         + 
+--R                   4       2 4+-+2       4       2     %pi 4
+--R           ((- 112x  + 160x )\|2   - 160x  + 224x )cos(---)
+--R                                                        8
+--R         + 
+--R                6       4 4+-+2       6       4     %pi 2       8      6 4+-+2
+--R           ((80x  - 112x )\|2   + 112x  - 160x )cos(---)  + (56x  - 80x )\|2
+--R                                                     8
+--R         + 
+--R              8       6
+--R           80x  - 112x
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              8
+--R     + 
+--R                   6       4       2 4+-+2       6       4       2     %pi 5
+--R           ((- 112x  + 224x  - 224x )\|2   - 160x  + 320x  - 320x )cos(---)
+--R                                                                        8
+--R         + 
+--R                   8       6       4 4+-+2       8       6       4     %pi 3
+--R           ((- 160x  + 320x  - 320x )\|2   - 224x  + 448x  - 448x )cos(---)
+--R                                                                        8
+--R         + 
+--R                  10       8       6 4+-+2      10       8       6     %pi
+--R           ((- 56x   + 112x  - 112x )\|2   - 80x   + 160x  - 160x )cos(---)
+--R                                                                        8
+--R      *
+--R             %pi
+--R         sin(---)
+--R              8
+--R     + 
+--R              2      4+-+2      2          %pi 8
+--R       ((- 40x  + 56)\|2   - 56x  + 80)cos(---)
+--R                                            8
+--R     + 
+--R               4       2 4+-+2       4       2     %pi 6
+--R       ((- 112x  + 160x )\|2   - 160x  + 224x )cos(---)
+--R                                                    8
+--R     + 
+--R               6       4 4+-+2       6       4     %pi 4
+--R       ((- 120x  + 168x )\|2   - 168x  + 240x )cos(---)
+--R                                                    8
+--R     + 
+--R              8      6 4+-+2      8       6     %pi 2         10      8 4+-+2
+--R       ((- 56x  + 80x )\|2   - 80x  + 112x )cos(---)  + (- 10x   + 14x )\|2
+--R                                                 8
+--R     + 
+--R            10      8
+--R       - 14x   + 20x
+--R  /
+--R            4       2       4+-+2       4       2           %pi 8
+--R       ((80x  - 160x  + 160)\|2   + 112x  - 224x  + 224)sin(---)
+--R                                                             8
+--R     + 
+--R                 4       2       4+-+2       4       2           %pi 2
+--R           ((320x  - 640x  + 640)\|2   + 448x  - 896x  + 896)cos(---)
+--R                                                                  8
+--R         + 
+--R                  6       4       2 4+-+2       6       4       2
+--R           (- 224x  + 448x  - 448x )\|2   - 320x  + 640x  - 640x
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              8
+--R     + 
+--R                 4       2       4+-+2       4        2            %pi 4
+--R           ((480x  - 960x  + 960)\|2   + 672x  - 1344x  + 1344)cos(---)
+--R                                                                    8
+--R         + 
+--R                   6       4       2 4+-+2       6       4       2     %pi 2
+--R           ((- 224x  + 448x  - 448x )\|2   - 320x  + 640x  - 640x )cos(---)
+--R                                                                        8
+--R         + 
+--R                8       6       4 4+-+2       8       6       4
+--R           (240x  - 480x  + 480x )\|2   + 336x  - 672x  + 672x
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              8
+--R     + 
+--R                 4       2       4+-+2       4       2           %pi 6
+--R           ((320x  - 640x  + 640)\|2   + 448x  - 896x  + 896)cos(---)
+--R                                                                  8
+--R         + 
+--R                 6       4       2 4+-+2       6       4       2     %pi 4
+--R           ((224x  - 448x  + 448x )\|2   + 320x  - 640x  + 640x )cos(---)
+--R                                                                      8
+--R         + 
+--R                   8       6       4 4+-+2       8       6       4     %pi 2
+--R           ((- 160x  + 320x  - 320x )\|2   - 224x  + 448x  - 448x )cos(---)
+--R                                                                        8
+--R         + 
+--R                  10       8       6 4+-+2       10       8       6
+--R           (- 112x   + 224x  - 224x )\|2   - 160x   + 320x  - 320x
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              8
+--R     + 
+--R            4       2       4+-+2       4       2           %pi 8
+--R       ((80x  - 160x  + 160)\|2   + 112x  - 224x  + 224)cos(---)
+--R                                                             8
+--R     + 
+--R             6       4       2 4+-+2       6       4       2     %pi 6
+--R       ((224x  - 448x  + 448x )\|2   + 320x  - 640x  + 640x )cos(---)
+--R                                                                  8
+--R     + 
+--R             8       6       4 4+-+2       8       6       4     %pi 4
+--R       ((240x  - 480x  + 480x )\|2   + 336x  - 672x  + 672x )cos(---)
+--R                                                                  8
+--R     + 
+--R             10       8       6 4+-+2       10       8       6     %pi 2
+--R       ((112x   - 224x  + 224x )\|2   + 160x   - 320x  + 320x )cos(---)
+--R                                                                    8
+--R     + 
+--R           12      10      8 4+-+2      12      10      8
+--R       (20x   - 40x   + 40x )\|2   + 28x   - 56x   + 56x
+--R                                                    Type: Expression(Integer)
+--E 1226
+
+)clear all
+
+--S 1227 of 1353
+t0:=x^7*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +---------------+
+--R         7 |   4      2
+--R   (1)  x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1227
+
+--S 1228 of 1353
+r0:=1/480*(35*b^2-8*a*c)*(a+b*x^2+c*x^4)^(3/2)/c^3+1/10*x^4*(a+b*x^2+_
+   c*x^4)^(3/2)/c-1/80*(4*a+7*b*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^2+_
+   1/512*b*(7*b^2-12*a*c)*(b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/c^(9/2)-1/256*b*(7*b^2-12*a*c)*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^4
+--R 
+--R
+--R   (2)
+--R                                                      2
+--R            2   2         3        5              2c x  + b
+--R       (720a b c  - 600a b c + 105b )atanh(-----------------------)
+--R                                                 +---------------+
+--R                                             +-+ |   4      2
+--R                                           2\|c \|c x  + b x  + a
+--R     + 
+--R               4 8        3 6          3       2 2  4              2       3   2
+--R           768c x  + 96b c x  + (256a c  - 112b c )x  + (- 464a b c  + 140b c)x
+--R         + 
+--R                 2 2         2        4
+--R           - 512a c  + 920a b c - 210b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R          4 +-+
+--R     7680c \|c
+--R                                                    Type: Expression(Integer)
+--E 1228
+
+--S 1229 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             4   4         3 3 3         2 5 2          7
+--R                       23040a b c  + 38400a b c  - 37440a b c  + 2400a b c
+--R                     + 
+--R                            9
+--R                       1050b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                         4 2 3          3 4 2         2 6            8  6
+--R                 (276480a b c  - 115200a b c  - 55680a b c + 16800a b )x
+--R               + 
+--R                         5   3          4 3 2          3 5          2 7  4
+--R                 (276480a b c  + 253440a b c  - 362880a b c + 70560a b )x
+--R               + 
+--R                         5 2 2          4 4           3 6  2          6   2
+--R                 (737280a b c  - 614400a b c + 107520a b )x  + 368640a b c
+--R               + 
+--R                          5 3          4 5
+--R                 - 307200a b c + 53760a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                      4 2 4         3 4 3         2 6 2          8        10  10
+--R             (- 57600a b c  + 19200a b c  + 14880a b c  - 3600a b c - 105b  )x
+--R           + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                 - 115200a b c  - 192000a b c  + 187200a b c  - 12000a b c
+--R               + 
+--R                          9
+--R                 - 5250a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                       5 2 3          4 4 2          3 6          2 8  6
+--R             (- 691200a b c  + 288000a b c  + 139200a b c - 42000a b )x
+--R           + 
+--R                       6   3          5 3 2          4 5           3 7  4
+--R             (- 460800a b c  - 422400a b c  + 604800a b c - 117600a b )x
+--R           + 
+--R                       6 2 2          5 4           4 6  2          7   2
+--R             (- 921600a b c  + 768000a b c - 134400a b )x  - 368640a b c
+--R           + 
+--R                    6 3          5 5
+--R             307200a b c - 53760a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                      2   6           3 5       5 4  18
+--R             (- 61440a b c  - 30720a b c  - 768b c )x
+--R           + 
+--R                       3 6          2 2 5           4 4      6 3  16
+--R             (- 122880a c  - 314880a b c  - 42240a b c  - 96b c )x
+--R           + 
+--R                       3   5          2 3 4         5 3       7 2  14
+--R             (- 773120a b c  - 346880a b c  - 576a b c  + 112b c )x
+--R           + 
+--R                       4 5          3 2 4       2 4 3         6 2       8   12
+--R             (- 532480a c  - 999680a b c  + 960a b c  + 464a b c  - 140b c)x
+--R           + 
+--R                        4   4        3 3 3        2 5 2         7        9  10
+--R             (- 1175040a b c  + 7680a b c  - 7488a b c  + 480a b c + 210b )x
+--R           + 
+--R                            5 4          4 2 3         3 4 2         2 6
+--R                   - 491520a c  + 153600a b c  - 70400a b c  - 25600a b c
+--R                 + 
+--R                          8
+--R                   8400a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                     5   3          4 3 2          3 5          2 7  6
+--R             (215040a b c  + 166400a b c  - 256640a b c + 50400a b )x
+--R           + 
+--R                     5 2 2          4 4          3 6  4
+--R             (645120a b c  - 537600a b c + 94080a b )x
+--R           + 
+--R                     6   2          5 3          4 5  2
+--R             (368640a b c  - 307200a b c + 53760a b )x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                    2 7           2 6        4 5  20
+--R             (24576a c  + 61440a b c  + 7680b c )x
+--R           + 
+--R                     2   6            3 5        5 4  18
+--R             (322560a b c  + 192000a b c  + 8640b c )x
+--R           + 
+--R                     3 6          2 2 5            4 4       6 3  16
+--R             (327680a c  + 929280a b c  + 147200a b c  - 160b c )x
+--R           + 
+--R                      3   5          2 3 4          5 3       7 2  14
+--R             (1507840a b c  + 730240a b c  - 1440a b c  + 280b c )x
+--R           + 
+--R                     4 5           3 2 4        2 4 3          6 2       8   12
+--R             (778240a c  + 1514240a b c  + 4800a b c  + 2320a b c  - 700b c)x
+--R           + 
+--R                      4   4         3 3 3         2 5 2          7         9  10
+--R             (1359360a b c  - 87040a b c  + 95808a b c  - 9920a b c - 1890b )x
+--R           + 
+--R                          5 4          4 2 3          3 4 2         2 6
+--R                   491520a c  - 491520a b c  + 236800a b c  + 72320a b c
+--R                 + 
+--R                             8
+--R                   - 25200a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                       5   3          4 3 2          3 5          2 7  6
+--R             (- 399360a b c  - 289280a b c  + 460160a b c - 90720a b )x
+--R           + 
+--R                       5 2 2          4 4           3 6  4
+--R             (- 829440a b c  + 691200a b c - 120960a b )x
+--R           + 
+--R                       6   2          5 3          4 5  2
+--R             (- 368640a b c  + 307200a b c - 53760a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                     2 6            2 5         4 4  8
+--R             (245760a c  + 614400a b c  + 76800b c )x
+--R           + 
+--R                      2   5             3 4  6            3 5           2 2 4  4
+--R             (2949120a b c  + 1228800a b c )x  + (2949120a c  + 5160960a b c )x
+--R           + 
+--R                     3   4 2           4 4
+--R             7864320a b c x  + 3932160a c
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                       2   6            3 5        5 4  10
+--R             (- 614400a b c  - 307200a b c  - 7680b c )x
+--R           + 
+--R                        3 6           2 2 5            4 4  8
+--R             (- 1228800a c  - 3072000a b c  - 384000a b c )x
+--R           + 
+--R                        3   5           2 3 4  6
+--R             (- 7372800a b c  - 3072000a b c )x
+--R           + 
+--R                        4 5           3 2 4  4           4   4 2           5 4
+--R             (- 4915200a c  - 8601600a b c )x  - 9830400a b c x  - 3932160a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                             4   4         3 3 3         2 5 2          7
+--R                       23040a b c  + 38400a b c  - 37440a b c  + 2400a b c
+--R                     + 
+--R                            9
+--R                       1050b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                         4 2 3          3 4 2         2 6            8  6
+--R                 (276480a b c  - 115200a b c  - 55680a b c + 16800a b )x
+--R               + 
+--R                         5   3          4 3 2          3 5          2 7  4
+--R                 (276480a b c  + 253440a b c  - 362880a b c + 70560a b )x
+--R               + 
+--R                         5 2 2          4 4           3 6  2          6   2
+--R                 (737280a b c  - 614400a b c + 107520a b )x  + 368640a b c
+--R               + 
+--R                          5 3          4 5
+--R                 - 307200a b c + 53760a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                      4 2 4         3 4 3         2 6 2          8        10  10
+--R             (- 57600a b c  + 19200a b c  + 14880a b c  - 3600a b c - 105b  )x
+--R           + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                 - 115200a b c  - 192000a b c  + 187200a b c  - 12000a b c
+--R               + 
+--R                          9
+--R                 - 5250a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                       5 2 3          4 4 2          3 6          2 8  6
+--R             (- 691200a b c  + 288000a b c  + 139200a b c - 42000a b )x
+--R           + 
+--R                       6   3          5 3 2          4 5           3 7  4
+--R             (- 460800a b c  - 422400a b c  + 604800a b c - 117600a b )x
+--R           + 
+--R                       6 2 2          5 4           4 6  2          7   2
+--R             (- 921600a b c  + 768000a b c - 134400a b )x  - 368640a b c
+--R           + 
+--R                    6 3          5 5
+--R             307200a b c - 53760a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                      2   6           3 5       5 4  18
+--R             (- 30720a b c  - 15360a b c  - 384b c )x
+--R           + 
+--R                      3 6          2 2 5           4 4      6 3  16
+--R             (- 61440a c  - 157440a b c  - 21120a b c  - 48b c )x
+--R           + 
+--R                       3   5          2 3 4         5 3      7 2  14
+--R             (- 386560a b c  - 173440a b c  - 288a b c  + 56b c )x
+--R           + 
+--R                       4 5          3 2 4       2 4 3         6 2      8   12
+--R             (- 266240a c  - 499840a b c  + 480a b c  + 232a b c  - 70b c)x
+--R           + 
+--R                       4   4        3 3 3        2 5 2         7        9  10
+--R             (- 587520a b c  + 3840a b c  - 3744a b c  + 240a b c + 105b )x
+--R           + 
+--R                            5 4         4 2 3         3 4 2         2 6
+--R                   - 245760a c  + 76800a b c  - 35200a b c  - 12800a b c
+--R                 + 
+--R                          8
+--R                   4200a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                     5   3         4 3 2          3 5          2 7  6
+--R             (107520a b c  + 83200a b c  - 128320a b c + 25200a b )x
+--R           + 
+--R                     5 2 2          4 4          3 6  4
+--R             (322560a b c  - 268800a b c + 47040a b )x
+--R           + 
+--R                     6   2          5 3          4 5  2
+--R             (184320a b c  - 153600a b c + 26880a b )x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                    2 7           2 6        4 5  20
+--R             (12288a c  + 30720a b c  + 3840b c )x
+--R           + 
+--R                     2   6           3 5        5 4  18
+--R             (161280a b c  + 96000a b c  + 4320b c )x
+--R           + 
+--R                     3 6          2 2 5           4 4      6 3  16
+--R             (163840a c  + 464640a b c  + 73600a b c  - 80b c )x
+--R           + 
+--R                     3   5          2 3 4         5 3       7 2  14
+--R             (753920a b c  + 365120a b c  - 720a b c  + 140b c )x
+--R           + 
+--R                     4 5          3 2 4        2 4 3          6 2       8   12
+--R             (389120a c  + 757120a b c  + 2400a b c  + 1160a b c  - 350b c)x
+--R           + 
+--R                     4   4         3 3 3         2 5 2          7        9  10
+--R             (679680a b c  - 43520a b c  + 47904a b c  - 4960a b c - 945b )x
+--R           + 
+--R                          5 4          4 2 3          3 4 2         2 6
+--R                   245760a c  - 245760a b c  + 118400a b c  + 36160a b c
+--R                 + 
+--R                             8
+--R                   - 12600a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                       5   3          4 3 2          3 5          2 7  6
+--R             (- 199680a b c  - 144640a b c  + 230080a b c - 45360a b )x
+--R           + 
+--R                       5 2 2          4 4          3 6  4
+--R             (- 414720a b c  + 345600a b c - 60480a b )x
+--R           + 
+--R                       6   2          5 3          4 5  2
+--R             (- 184320a b c  + 153600a b c - 26880a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                     2 6            2 5         4 4  8
+--R             (122880a c  + 307200a b c  + 38400b c )x
+--R           + 
+--R                      2   5            3 4  6            3 5           2 2 4  4
+--R             (1474560a b c  + 614400a b c )x  + (1474560a c  + 2580480a b c )x
+--R           + 
+--R                     3   4 2           4 4
+--R             3932160a b c x  + 1966080a c
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                       2   6            3 5        5 4  10
+--R             (- 307200a b c  - 153600a b c  - 3840b c )x
+--R           + 
+--R                       3 6           2 2 5            4 4  8
+--R             (- 614400a c  - 1536000a b c  - 192000a b c )x
+--R           + 
+--R                        3   5           2 3 4  6
+--R             (- 3686400a b c  - 1536000a b c )x
+--R           + 
+--R                        4 5           3 2 4  4           4   4 2           5 4
+--R             (- 2457600a c  - 4300800a b c )x  - 4915200a b c x  - 1966080a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1229
+
+--S 1230 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      4   4         3 3 3         2 5 2          7         9  8
+--R               (23040a b c  + 38400a b c  - 37440a b c  + 2400a b c + 1050b )x
+--R             + 
+--R                       4 2 3          3 4 2         2 6            8  6
+--R               (276480a b c  - 115200a b c  - 55680a b c + 16800a b )x
+--R             + 
+--R                       5   3          4 3 2          3 5          2 7  4
+--R               (276480a b c  + 253440a b c  - 362880a b c + 70560a b )x
+--R             + 
+--R                       5 2 2          4 4           3 6  2          6   2
+--R               (737280a b c  - 614400a b c + 107520a b )x  + 368640a b c
+--R             + 
+--R                        5 3          4 5
+--R               - 307200a b c + 53760a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                    4 2 4         3 4 3         2 6 2          8        10  10
+--R           (- 57600a b c  + 19200a b c  + 14880a b c  - 3600a b c - 105b  )x
+--R         + 
+--R                        5   4          4 3 3          3 5 2         2 7
+--R               - 115200a b c  - 192000a b c  + 187200a b c  - 12000a b c
+--R             + 
+--R                        9
+--R               - 5250a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                     5 2 3          4 4 2          3 6          2 8  6
+--R           (- 691200a b c  + 288000a b c  + 139200a b c - 42000a b )x
+--R         + 
+--R                     6   3          5 3 2          4 5           3 7  4
+--R           (- 460800a b c  - 422400a b c  + 604800a b c - 117600a b )x
+--R         + 
+--R                     6 2 2          5 4           4 6  2          7   2
+--R           (- 921600a b c  + 768000a b c - 134400a b )x  - 368640a b c
+--R         + 
+--R                  6 3          5 5
+--R           307200a b c - 53760a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                             4   4         3 3 3         2 5 2          7
+--R                     - 23040a b c  - 38400a b c  + 37440a b c  - 2400a b c
+--R                   + 
+--R                            9
+--R                     - 1050b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                         4 2 3          3 4 2         2 6            8  6
+--R               (- 276480a b c  + 115200a b c  + 55680a b c - 16800a b )x
+--R             + 
+--R                         5   3          4 3 2          3 5          2 7  4
+--R               (- 276480a b c  - 253440a b c  + 362880a b c - 70560a b )x
+--R             + 
+--R                         5 2 2          4 4           3 6  2          6   2
+--R               (- 737280a b c  + 614400a b c - 107520a b )x  - 368640a b c
+--R             + 
+--R                      5 3          4 5
+--R               307200a b c - 53760a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                  4 2 4         3 4 3         2 6 2          8        10  10
+--R           (57600a b c  - 19200a b c  - 14880a b c  + 3600a b c + 105b  )x
+--R         + 
+--R                        5   4          4 3 3          3 5 2         2 7
+--R                 115200a b c  + 192000a b c  - 187200a b c  + 12000a b c
+--R               + 
+--R                        9
+--R                 5250a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                   5 2 3          4 4 2          3 6          2 8  6
+--R           (691200a b c  - 288000a b c  - 139200a b c + 42000a b )x
+--R         + 
+--R                   6   3          5 3 2          4 5           3 7  4
+--R           (460800a b c  + 422400a b c  - 604800a b c + 117600a b )x
+--R         + 
+--R                   6 2 2          5 4           4 6  2          7   2
+--R           (921600a b c  - 768000a b c + 134400a b )x  + 368640a b c
+--R         + 
+--R                    6 3          5 5
+--R           - 307200a b c + 53760a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                    5 4         4 2 3         3 4 2        2 6           8  8
+--R           (- 16384a c  - 11520a b c  + 61760a b c  - 7600a b c - 2100a b )x
+--R         + 
+--R                     5   3          4 3 2         3 5          2 7  6
+--R           (- 196608a b c  + 271360a b c  + 66560a b c - 33600a b )x
+--R         + 
+--R                     6 3        5 2 2          4 4           3 6  4
+--R           (- 196608a c  + 9216a b c  + 537600a b c - 141120a b )x
+--R         + 
+--R                     6   2          5 3           4 5  2          7 2
+--R           (- 524288a b c  + 942080a b c - 215040a b )x  - 262144a c
+--R         + 
+--R                  6 2           5 4
+--R           471040a b c - 107520a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                  4   4         3 3 3         2 5 2          7        9  10
+--R           (40960a b c  - 53120a b c  - 19488a b c  + 7480a b c + 210b )x
+--R         + 
+--R                  5 4         4 2 3          3 4 2         2 6            8  8
+--R           (81920a c  + 57600a b c  - 308800a b c  + 38000a b c + 10500a b )x
+--R         + 
+--R                   5   3          4 3 2          3 5          2 7  6
+--R           (491520a b c  - 678400a b c  - 166400a b c + 84000a b )x
+--R         + 
+--R                   6 3         5 2 2          4 4           3 6  4
+--R           (327680a c  - 15360a b c  - 896000a b c + 235200a b )x
+--R         + 
+--R                   6   2           5 3           4 5  2          7 2
+--R           (655360a b c  - 1177600a b c + 268800a b )x  + 262144a c
+--R         + 
+--R                    6 2           5 4
+--R           - 471040a b c + 107520a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                   2 6            2 5         4 4  8
+--R           (245760a c  + 614400a b c  + 76800b c )x
+--R         + 
+--R                    2   5             3 4  6            3 5           2 2 4  4
+--R           (2949120a b c  + 1228800a b c )x  + (2949120a c  + 5160960a b c )x
+--R         + 
+--R                   3   4 2           4 4
+--R           7864320a b c x  + 3932160a c
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                     2   6            3 5        5 4  10
+--R           (- 614400a b c  - 307200a b c  - 7680b c )x
+--R         + 
+--R                      3 6           2 2 5            4 4  8
+--R           (- 1228800a c  - 3072000a b c  - 384000a b c )x
+--R         + 
+--R                      3   5           2 3 4  6
+--R           (- 7372800a b c  - 3072000a b c )x
+--R         + 
+--R                      4 5           3 2 4  4           4   4 2           5 4
+--R           (- 4915200a c  - 8601600a b c )x  - 9830400a b c x  - 3932160a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 1230
+
+--S 1231 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1231
+
+--S 1232 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             4   4         3 3 3         2 5 2          7
+--R                     - 23040a b c  - 38400a b c  + 37440a b c  - 2400a b c
+--R                   + 
+--R                            9
+--R                     - 1050b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                         4 2 3          3 4 2         2 6            8  6
+--R               (- 276480a b c  + 115200a b c  + 55680a b c - 16800a b )x
+--R             + 
+--R                         5   3          4 3 2          3 5          2 7  4
+--R               (- 276480a b c  - 253440a b c  + 362880a b c - 70560a b )x
+--R             + 
+--R                         5 2 2          4 4           3 6  2          6   2
+--R               (- 737280a b c  + 614400a b c - 107520a b )x  - 368640a b c
+--R             + 
+--R                      5 3          4 5
+--R               307200a b c - 53760a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                      4 2 4         3 4 3         2 6 2          8        10  10
+--R               (57600a b c  - 19200a b c  - 14880a b c  + 3600a b c + 105b  )x
+--R             + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                   115200a b c  + 192000a b c  - 187200a b c  + 12000a b c
+--R                 + 
+--R                          9
+--R                   5250a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                       5 2 3          4 4 2          3 6          2 8  6
+--R               (691200a b c  - 288000a b c  - 139200a b c + 42000a b )x
+--R             + 
+--R                       6   3          5 3 2          4 5           3 7  4
+--R               (460800a b c  + 422400a b c  - 604800a b c + 117600a b )x
+--R             + 
+--R                       6 2 2          5 4           4 6  2          7   2
+--R               (921600a b c  - 768000a b c + 134400a b )x  + 368640a b c
+--R             + 
+--R                        6 3          5 5
+--R               - 307200a b c + 53760a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                      4   4         3 3 3         2 5 2          7         9  8
+--R               (46080a b c  + 76800a b c  - 74880a b c  + 4800a b c + 2100b )x
+--R             + 
+--R                       4 2 3          3 4 2          2 6            8  6
+--R               (552960a b c  - 230400a b c  - 111360a b c + 33600a b )x
+--R             + 
+--R                       5   3          4 3 2          3 5           2 7  4
+--R               (552960a b c  + 506880a b c  - 725760a b c + 141120a b )x
+--R             + 
+--R                        5 2 2           4 4           3 6  2          6   2
+--R               (1474560a b c  - 1228800a b c + 215040a b )x  + 737280a b c
+--R             + 
+--R                        5 3           4 5
+--R               - 614400a b c + 107520a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                              4 2 4         3 4 3         2 6 2          8
+--R                     - 115200a b c  + 38400a b c  + 29760a b c  - 7200a b c
+--R                   + 
+--R                           10
+--R                     - 210b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            5   4          4 3 3          3 5 2         2 7
+--R                   - 230400a b c  - 384000a b c  + 374400a b c  - 24000a b c
+--R                 + 
+--R                             9
+--R                   - 10500a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          5 2 3          4 4 2          3 6          2 8  6
+--R               (- 1382400a b c  + 576000a b c  + 278400a b c - 84000a b )x
+--R             + 
+--R                         6   3          5 3 2           4 5           3 7  4
+--R               (- 921600a b c  - 844800a b c  + 1209600a b c - 235200a b )x
+--R             + 
+--R                          6 2 2           5 4           4 6  2          7   2
+--R               (- 1843200a b c  + 1536000a b c - 268800a b )x  - 737280a b c
+--R             + 
+--R                      6 3           5 5
+--R               614400a b c - 107520a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                    5 4         4 2 3         3 4 2        2 6           8  8
+--R           (- 16384a c  - 11520a b c  + 61760a b c  - 7600a b c - 2100a b )x
+--R         + 
+--R                     5   3          4 3 2         3 5          2 7  6
+--R           (- 196608a b c  + 271360a b c  + 66560a b c - 33600a b )x
+--R         + 
+--R                     6 3        5 2 2          4 4           3 6  4
+--R           (- 196608a c  + 9216a b c  + 537600a b c - 141120a b )x
+--R         + 
+--R                     6   2          5 3           4 5  2          7 2
+--R           (- 524288a b c  + 942080a b c - 215040a b )x  - 262144a c
+--R         + 
+--R                  6 2           5 4
+--R           471040a b c - 107520a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                  4   4         3 3 3         2 5 2          7        9  10
+--R           (40960a b c  - 53120a b c  - 19488a b c  + 7480a b c + 210b )x
+--R         + 
+--R                  5 4         4 2 3          3 4 2         2 6            8  8
+--R           (81920a c  + 57600a b c  - 308800a b c  + 38000a b c + 10500a b )x
+--R         + 
+--R                   5   3          4 3 2          3 5          2 7  6
+--R           (491520a b c  - 678400a b c  - 166400a b c + 84000a b )x
+--R         + 
+--R                   6 3         5 2 2          4 4           3 6  4
+--R           (327680a c  - 15360a b c  - 896000a b c + 235200a b )x
+--R         + 
+--R                   6   2           5 3           4 5  2          7 2
+--R           (655360a b c  - 1177600a b c + 268800a b )x  + 262144a c
+--R         + 
+--R                    6 2           5 4
+--R           - 471040a b c + 107520a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                   2 6            2 5         4 4  8
+--R           (245760a c  + 614400a b c  + 76800b c )x
+--R         + 
+--R                    2   5             3 4  6            3 5           2 2 4  4
+--R           (2949120a b c  + 1228800a b c )x  + (2949120a c  + 5160960a b c )x
+--R         + 
+--R                   3   4 2           4 4
+--R           7864320a b c x  + 3932160a c
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                     2   6            3 5        5 4  10
+--R           (- 614400a b c  - 307200a b c  - 7680b c )x
+--R         + 
+--R                      3 6           2 2 5            4 4  8
+--R           (- 1228800a c  - 3072000a b c  - 384000a b c )x
+--R         + 
+--R                      3   5           2 3 4  6
+--R           (- 7372800a b c  - 3072000a b c )x
+--R         + 
+--R                      4 5           3 2 4  4           4   4 2           5 4
+--R           (- 4915200a c  - 8601600a b c )x  - 9830400a b c x  - 3932160a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 1232
+
+--S 1233 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1233
+
+)clear all
+
+--S 1234 of 1353
+t0:=x^5*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +---------------+
+--R         5 |   4      2
+--R   (1)  x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1234
+
+--S 1235 of 1353
+r0:=-5/48*b*(a+b*x^2+c*x^4)^(3/2)/c^2+1/8*x^2*(a+b*x^2+c*x^4)^(3/2)/c-_
+   1/256*(b^2-4*a*c)*(5*b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/c^(7/2)+1/128*(5*b^2-4*a*c)*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R                                                   2
+--R             2 2        2       4              2c x  + b
+--R       (- 48a c  + 72a b c - 15b )atanh(-----------------------)
+--R                                              +---------------+
+--R                                          +-+ |   4      2
+--R                                        2\|c \|c x  + b x  + a
+--R     + 
+--R             3 6        2 4         2      2   2                 3  +-+
+--R         (96c x  + 16b c x  + (48a c  - 20b c)x  - 104a b c + 30b )\|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R  /
+--R         3 +-+
+--R     768c \|c
+--R                                                    Type: Expression(Integer)
+--E 1235
+
+--S 1236 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       3   3        2 3 2        5        7  6
+--R                 (1536a b c  - 1920a b c  - 96a b c + 120b )x
+--R               + 
+--R                       4 3       3 2 2        2 4           6  4
+--R                 (3072a c  - 768a b c  - 4800a b c + 1200a b )x
+--R               + 
+--R                       4   2         3 3         2 5  2        5 2        4 2
+--R                 (9216a b c  - 13824a b c + 2880a b )x  + 6144a c  - 9216a b c
+--R               + 
+--R                      3 4
+--R                 1920a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                    4 4        2 4 2         6       8  8
+--R             (- 768a c  + 1440a b c  - 288a b c - 15b )x
+--R           + 
+--R                     4   3        3 3 2       2 5          7  6
+--R             (- 6144a b c  + 7680a b c  + 384a b c - 480a b )x
+--R           + 
+--R                     5 3        4 2 2        3 4         2 6  4
+--R             (- 6144a c  + 1536a b c  + 9600a b c - 2400a b )x
+--R           + 
+--R                      5   2         4 3         3 5  2        6 2        5 2
+--R             (- 12288a b c  + 18432a b c - 3840a b )x  - 6144a c  + 9216a b c
+--R           + 
+--R                    4 4
+--R             - 1920a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                     2 5          2 4      4 3  14
+--R             (- 1536a c  - 2304a b c  - 96b c )x
+--R           + 
+--R                      2   4          3 3      5 2  12
+--R             (- 12544a b c  - 3456a b c  - 16b c )x
+--R           + 
+--R                      3 4         2 2 3        4 2      6   10
+--R             (- 13056a c  - 18240a b c  - 80a b c  + 20b c)x
+--R           + 
+--R                      3   3       2 3 2        5       7  8
+--R             (- 31104a b c  + 480a b c  + 24a b c - 30b )x
+--R           + 
+--R                      4 3       3 2 2        2 4          6  6
+--R             (- 18432a c  + 768a b c  + 2816a b c - 720a b )x
+--R           + 
+--R                     4   2         3 3         2 5  4
+--R             (- 7680a b c  + 11520a b c - 2400a b )x
+--R           + 
+--R                     5 2        4 2         3 4  2
+--R             (- 6144a c  + 9216a b c - 1920a b )x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                       5       3 4  16         2 5           2 4       4 3  14
+--R             (3072a b c  + 768b c )x   + (6144a c  + 11264a b c  + 896b c )x
+--R           + 
+--R                    2   4          3 3      5 2  12
+--R             (30208a b c  + 9984a b c  - 32b c )x
+--R           + 
+--R                    3 4         2 2 3         4 2      6   10
+--R             (21504a c  + 31488a b c  - 320a b c  + 80b c)x
+--R           + 
+--R                    3   3        2 3 2         5        7  8
+--R             (42624a b c  - 4896a b c  + 152a b c + 210b )x
+--R           + 
+--R                    4 3        3 2 2        2 4           6  6
+--R             (21504a c  - 2304a b c  - 6464a b c + 1680a b )x
+--R           + 
+--R                    4   2         3 3         2 5  4
+--R             (10752a b c  - 16128a b c + 3360a b )x
+--R           + 
+--R                   5 2        4 2         3 4  2
+--R             (6144a c  - 9216a b c + 1920a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                        4        3 3  6          2 4           2 3  4
+--R             (24576a b c  + 6144b c )x  + (49152a c  + 61440a b c )x
+--R           + 
+--R                    2   3 2         3 3
+--R             147456a b c x  + 98304a c
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                      2 5           2 4       4 3  8
+--R             (- 12288a c  - 18432a b c  - 768b c )x
+--R           + 
+--R                      2   4           3 3  6            3 4          2 2 3  4
+--R             (- 98304a b c  - 24576a b c )x  + (- 98304a c  - 122880a b c )x
+--R           + 
+--R                      3   3 2         4 3
+--R             - 196608a b c x  - 98304a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                         3   3        2 3 2        5        7  6
+--R                 (- 1536a b c  + 1920a b c  + 96a b c - 120b )x
+--R               + 
+--R                         4 3       3 2 2        2 4           6  4
+--R                 (- 3072a c  + 768a b c  + 4800a b c - 1200a b )x
+--R               + 
+--R                         4   2         3 3         2 5  2        5 2        4 2
+--R                 (- 9216a b c  + 13824a b c - 2880a b )x  - 6144a c  + 9216a b c
+--R               + 
+--R                        3 4
+--R                 - 1920a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                  4 4        2 4 2         6       8  8
+--R             (768a c  - 1440a b c  + 288a b c + 15b )x
+--R           + 
+--R                   4   3        3 3 2       2 5          7  6
+--R             (6144a b c  - 7680a b c  - 384a b c + 480a b )x
+--R           + 
+--R                   5 3        4 2 2        3 4         2 6  4
+--R             (6144a c  - 1536a b c  - 9600a b c + 2400a b )x
+--R           + 
+--R                    5   2         4 3         3 5  2        6 2        5 2
+--R             (12288a b c  - 18432a b c + 3840a b )x  + 6144a c  - 9216a b c
+--R           + 
+--R                  4 4
+--R             1920a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                    2 5          2 4      4 3  14
+--R             (- 768a c  - 1152a b c  - 48b c )x
+--R           + 
+--R                     2   4          3 3     5 2  12
+--R             (- 6272a b c  - 1728a b c  - 8b c )x
+--R           + 
+--R                     3 4        2 2 3        4 2      6   10
+--R             (- 6528a c  - 9120a b c  - 40a b c  + 10b c)x
+--R           + 
+--R                      3   3       2 3 2        5       7  8
+--R             (- 15552a b c  + 240a b c  + 12a b c - 15b )x
+--R           + 
+--R                     4 3       3 2 2        2 4          6  6
+--R             (- 9216a c  + 384a b c  + 1408a b c - 360a b )x
+--R           + 
+--R                     4   2        3 3         2 5  4
+--R             (- 3840a b c  + 5760a b c - 1200a b )x
+--R           + 
+--R                     5 2        4 2        3 4  2
+--R             (- 3072a c  + 4608a b c - 960a b )x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                       5       3 4  16         2 5          2 4       4 3  14
+--R             (1536a b c  + 384b c )x   + (3072a c  + 5632a b c  + 448b c )x
+--R           + 
+--R                    2   4          3 3      5 2  12
+--R             (15104a b c  + 4992a b c  - 16b c )x
+--R           + 
+--R                    3 4         2 2 3         4 2      6   10
+--R             (10752a c  + 15744a b c  - 160a b c  + 40b c)x
+--R           + 
+--R                    3   3        2 3 2        5        7  8
+--R             (21312a b c  - 2448a b c  + 76a b c + 105b )x
+--R           + 
+--R                    4 3        3 2 2        2 4          6  6
+--R             (10752a c  - 1152a b c  - 3232a b c + 840a b )x
+--R           + 
+--R                   4   2        3 3         2 5  4
+--R             (5376a b c  - 8064a b c + 1680a b )x
+--R           + 
+--R                   5 2        4 2        3 4  2
+--R             (3072a c  - 4608a b c + 960a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                        4        3 3  6          2 4           2 3  4
+--R             (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R           + 
+--R                   2   3 2         3 3
+--R             73728a b c x  + 49152a c
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                     2 5          2 4       4 3  8
+--R             (- 6144a c  - 9216a b c  - 384b c )x
+--R           + 
+--R                      2   4           3 3  6            3 4         2 2 3  4
+--R             (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R           + 
+--R                     3   3 2         4 3
+--R             - 98304a b c x  - 49152a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1236
+
+--S 1237 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     3   3        2 3 2        5        7  6
+--R               (1536a b c  - 1920a b c  - 96a b c + 120b )x
+--R             + 
+--R                     4 3       3 2 2        2 4           6  4
+--R               (3072a c  - 768a b c  - 4800a b c + 1200a b )x
+--R             + 
+--R                     4   2         3 3         2 5  2        5 2        4 2
+--R               (9216a b c  - 13824a b c + 2880a b )x  + 6144a c  - 9216a b c
+--R             + 
+--R                    3 4
+--R               1920a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                  4 4        2 4 2         6       8  8
+--R           (- 768a c  + 1440a b c  - 288a b c - 15b )x
+--R         + 
+--R                   4   3        3 3 2       2 5          7  6
+--R           (- 6144a b c  + 7680a b c  + 384a b c - 480a b )x
+--R         + 
+--R                   5 3        4 2 2        3 4         2 6  4
+--R           (- 6144a c  + 1536a b c  + 9600a b c - 2400a b )x
+--R         + 
+--R                    5   2         4 3         3 5  2        6 2        5 2
+--R           (- 12288a b c  + 18432a b c - 3840a b )x  - 6144a c  + 9216a b c
+--R         + 
+--R                  4 4
+--R           - 1920a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                     3   3        2 3 2        5        7  6
+--R               (1536a b c  - 1920a b c  - 96a b c + 120b )x
+--R             + 
+--R                     4 3       3 2 2        2 4           6  4
+--R               (3072a c  - 768a b c  - 4800a b c + 1200a b )x
+--R             + 
+--R                     4   2         3 3         2 5  2        5 2        4 2
+--R               (9216a b c  - 13824a b c + 2880a b )x  + 6144a c  - 9216a b c
+--R             + 
+--R                    3 4
+--R               1920a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                  4 4        2 4 2         6       8  8
+--R           (- 768a c  + 1440a b c  - 288a b c - 15b )x
+--R         + 
+--R                   4   3        3 3 2       2 5          7  6
+--R           (- 6144a b c  + 7680a b c  + 384a b c - 480a b )x
+--R         + 
+--R                   5 3        4 2 2        3 4         2 6  4
+--R           (- 6144a c  + 1536a b c  + 9600a b c - 2400a b )x
+--R         + 
+--R                    5   2         4 3         3 5  2        6 2        5 2
+--R           (- 12288a b c  + 18432a b c - 3840a b )x  - 6144a c  + 9216a b c
+--R         + 
+--R                  4 4
+--R           - 1920a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                   3 2 2       2 4          6  6
+--R           (- 3328a b c  + 128a b c + 240a b )x
+--R         + 
+--R                   4   2        3 3         2 5  4            4 2         3 4  2
+--R           (- 6656a b c  - 6400a b c + 2400a b )x  + (- 19968a b c + 5760a b )x
+--R         + 
+--R                   5           4 3
+--R           - 13312a b c + 3840a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                 3   3        2 3 2         5       7  8
+--R           (1664a b c  + 2016a b c  - 616a b c - 30b )x
+--R         + 
+--R                  3 2 2       2 4          6  6
+--R           (13312a b c  - 512a b c - 960a b )x
+--R         + 
+--R                  4   2         3 3         2 5  4          4 2         3 4  2
+--R           (13312a b c  + 12800a b c - 4800a b )x  + (26624a b c - 7680a b )x
+--R         + 
+--R                 5           4 3
+--R           13312a b c - 3840a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                      4        3 3  6          2 4           2 3  4
+--R           (24576a b c  + 6144b c )x  + (49152a c  + 61440a b c )x
+--R         + 
+--R                  2   3 2         3 3
+--R           147456a b c x  + 98304a c
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                    2 5           2 4       4 3  8
+--R           (- 12288a c  - 18432a b c  - 768b c )x
+--R         + 
+--R                    2   4           3 3  6            3 4          2 2 3  4
+--R           (- 98304a b c  - 24576a b c )x  + (- 98304a c  - 122880a b c )x
+--R         + 
+--R                    3   3 2         4 3
+--R           - 196608a b c x  - 98304a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 1237
+
+--S 1238 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1238
+
+--S 1239 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     3   3        2 3 2        5        7  6
+--R               (1536a b c  - 1920a b c  - 96a b c + 120b )x
+--R             + 
+--R                     4 3       3 2 2        2 4           6  4
+--R               (3072a c  - 768a b c  - 4800a b c + 1200a b )x
+--R             + 
+--R                     4   2         3 3         2 5  2        5 2        4 2
+--R               (9216a b c  - 13824a b c + 2880a b )x  + 6144a c  - 9216a b c
+--R             + 
+--R                    3 4
+--R               1920a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                      4 4        2 4 2         6       8  8
+--R               (- 768a c  + 1440a b c  - 288a b c - 15b )x
+--R             + 
+--R                       4   3        3 3 2       2 5          7  6
+--R               (- 6144a b c  + 7680a b c  + 384a b c - 480a b )x
+--R             + 
+--R                       5 3        4 2 2        3 4         2 6  4
+--R               (- 6144a c  + 1536a b c  + 9600a b c - 2400a b )x
+--R             + 
+--R                        5   2         4 3         3 5  2        6 2        5 2
+--R               (- 12288a b c  + 18432a b c - 3840a b )x  - 6144a c  + 9216a b c
+--R             + 
+--R                      4 4
+--R               - 1920a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                       3   3        2 3 2         5        7  6
+--R               (- 3072a b c  + 3840a b c  + 192a b c - 240b )x
+--R             + 
+--R                       4 3        3 2 2        2 4           6  4
+--R               (- 6144a c  + 1536a b c  + 9600a b c - 2400a b )x
+--R             + 
+--R                        4   2         3 3         2 5  2         5 2
+--R               (- 18432a b c  + 27648a b c - 5760a b )x  - 12288a c
+--R             + 
+--R                     4 2         3 4
+--R               18432a b c - 3840a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                     4 4        2 4 2         6       8  8
+--R               (1536a c  - 2880a b c  + 576a b c + 30b )x
+--R             + 
+--R                      4   3         3 3 2       2 5          7  6
+--R               (12288a b c  - 15360a b c  - 768a b c + 960a b )x
+--R             + 
+--R                      5 3        4 2 2         3 4         2 6  4
+--R               (12288a c  - 3072a b c  - 19200a b c + 4800a b )x
+--R             + 
+--R                      5   2         4 3         3 5  2         6 2         5 2
+--R               (24576a b c  - 36864a b c + 7680a b )x  + 12288a c  - 18432a b c
+--R             + 
+--R                    4 4
+--R               3840a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                   3 2 2       2 4          6  6
+--R           (- 3328a b c  + 128a b c + 240a b )x
+--R         + 
+--R                   4   2        3 3         2 5  4            4 2         3 4  2
+--R           (- 6656a b c  - 6400a b c + 2400a b )x  + (- 19968a b c + 5760a b )x
+--R         + 
+--R                   5           4 3
+--R           - 13312a b c + 3840a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                 3   3        2 3 2         5       7  8
+--R           (1664a b c  + 2016a b c  - 616a b c - 30b )x
+--R         + 
+--R                  3 2 2       2 4          6  6
+--R           (13312a b c  - 512a b c - 960a b )x
+--R         + 
+--R                  4   2         3 3         2 5  4          4 2         3 4  2
+--R           (13312a b c  + 12800a b c - 4800a b )x  + (26624a b c - 7680a b )x
+--R         + 
+--R                 5           4 3
+--R           13312a b c - 3840a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                      4        3 3  6          2 4           2 3  4
+--R           (24576a b c  + 6144b c )x  + (49152a c  + 61440a b c )x
+--R         + 
+--R                  2   3 2         3 3
+--R           147456a b c x  + 98304a c
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                    2 5           2 4       4 3  8
+--R           (- 12288a c  - 18432a b c  - 768b c )x
+--R         + 
+--R                    2   4           3 3  6            3 4          2 2 3  4
+--R           (- 98304a b c  - 24576a b c )x  + (- 98304a c  - 122880a b c )x
+--R         + 
+--R                    3   3 2         4 3
+--R           - 196608a b c x  - 98304a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 1239
+
+--S 1240 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1240
+
+)clear all
+
+--S 1241 of 1353
+t0:=x^3*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +---------------+
+--R         3 |   4      2
+--R   (1)  x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1241
+
+--S 1242 of 1353
+r0:=1/6*(a+b*x^2+c*x^4)^(3/2)/c+1/32*b*(b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/_
+   (sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(5/2)-1/16*b*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                                         2
+--R                      3              2c x  + b
+--R       (- 12a b c + 3b )atanh(-----------------------)
+--R                                    +---------------+
+--R                                +-+ |   4      2
+--R                              2\|c \|c x  + b x  + a
+--R     + 
+--R                                            +---------------+
+--R           2 4         2             2  +-+ |   4      2
+--R       (16c x  + 4b c x  + 16a c - 6b )\|c \|c x  + b x  + a
+--R  /
+--R        2 +-+
+--R     96c \|c
+--R                                                    Type: Expression(Integer)
+--E 1242
+
+--S 1243 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     2   2        3       5  4        2 2         4  2
+--R                 (96a b c  + 48a b c - 18b )x  + (384a b c - 96a b )x
+--R               + 
+--R                     3         2 3
+--R                 384a b c - 96a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                    2 2 2        4      6  6
+--R             (- 144a b c  + 24a b c + 3b )x
+--R           + 
+--R                    3   2       2 3         5  4          3 2        2 4  2
+--R             (- 288a b c  - 144a b c + 54a b )x  + (- 576a b c + 144a b )x
+--R           + 
+--R                   4         3 3
+--R             - 384a b c + 96a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                        3      3 2  10          2 3         2 2     4   8
+--R             (- 192a b c  - 16b c )x   + (- 384a c  - 336a b c  - 4b c)x
+--R           + 
+--R                     2   2        3      5  6
+--R             (- 1056a b c  - 16a b c + 6b )x
+--R           + 
+--R                    3 2       2 2         4  4          3         2 3  2
+--R             (- 768a c  - 288a b c + 72a b )x  + (- 384a b c + 96a b )x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                    4      2 3  12            3       3 2  10
+--R             (128a c  + 96b c )x   + (672a b c  + 120b c )x
+--R           + 
+--R                  2 3         2 2      4   8         2   2        3       5  6
+--R             (768a c  + 816a b c  - 12b c)x  + (1632a b c  + 64a b c - 30b )x
+--R           + 
+--R                  3 2       2 2          4  4        3         2 3  2
+--R             (768a c  + 480a b c - 120a b )x  + (384a b c - 96a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                   3       2 2  4            2 2        2 2  +-+ +-+
+--R           ((768a c  + 576b c )x  + 3072a b c x  + 3072a c )\|a \|c
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                         3      3 2  6           2 3          2 2  4
+--R             (- 1152a b c  - 96b c )x  + (- 2304a c  - 1728a b c )x
+--R           + 
+--R                    2   2 2        3 2
+--R             - 4608a b c x  - 3072a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                       2   2        3       5  4          2 2         4  2
+--R                 (- 96a b c  - 48a b c + 18b )x  + (- 384a b c + 96a b )x
+--R               + 
+--R                       3         2 3
+--R                 - 384a b c + 96a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                  2 2 2        4      6  6        3   2       2 3         5  4
+--R             (144a b c  - 24a b c - 3b )x  + (288a b c  + 144a b c - 54a b )x
+--R           + 
+--R                  3 2        2 4  2       4         3 3
+--R             (576a b c - 144a b )x  + 384a b c - 96a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                       3     3 2  10          2 3         2 2     4   8
+--R             (- 96a b c  - 8b c )x   + (- 192a c  - 168a b c  - 2b c)x
+--R           + 
+--R                    2   2       3      5  6          3 2       2 2         4  4
+--R             (- 528a b c  - 8a b c + 3b )x  + (- 384a c  - 144a b c + 36a b )x
+--R           + 
+--R                    3         2 3  2
+--R             (- 192a b c + 48a b )x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                   4      2 3  12            3      3 2  10
+--R             (64a c  + 48b c )x   + (336a b c  + 60b c )x
+--R           + 
+--R                  2 3         2 2     4   8        2   2        3       5  6
+--R             (384a c  + 408a b c  - 6b c)x  + (816a b c  + 32a b c - 15b )x
+--R           + 
+--R                  3 2       2 2         4  4        3         2 3  2
+--R             (384a c  + 240a b c - 60a b )x  + (192a b c - 48a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                   3       2 2  4            2 2        2 2  +---+ +-+
+--R           ((384a c  + 288b c )x  + 1536a b c x  + 1536a c )\|- c \|a
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                        3      3 2  6           2 3         2 2  4
+--R             (- 576a b c  - 48b c )x  + (- 1152a c  - 864a b c )x
+--R           + 
+--R                    2   2 2        3 2
+--R             - 2304a b c x  - 1536a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1243
+
+--S 1244 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                   2   2        3       5  4        2 2         4  2       3
+--R               (96a b c  + 48a b c - 18b )x  + (384a b c - 96a b )x  + 384a b c
+--R             + 
+--R                    2 3
+--R               - 96a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                  2 2 2        4      6  6          3   2       2 3         5  4
+--R           (- 144a b c  + 24a b c + 3b )x  + (- 288a b c  - 144a b c + 54a b )x
+--R         + 
+--R                  3 2        2 4  2       4         3 3
+--R           (- 576a b c + 144a b )x  - 384a b c + 96a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                   2   2        3       5  4        2 2         4  2       3
+--R               (96a b c  + 48a b c - 18b )x  + (384a b c - 96a b )x  + 384a b c
+--R             + 
+--R                    2 3
+--R               - 96a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                  2 2 2        4      6  6          3   2       2 3         5  4
+--R           (- 144a b c  + 24a b c + 3b )x  + (- 288a b c  - 144a b c + 54a b )x
+--R         + 
+--R                  3 2        2 4  2       4         3 3
+--R           (- 576a b c + 144a b )x  - 384a b c + 96a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                3 2      2 2         4  4        3          2 3  2       4
+--R           (128a c  + 48a b c - 36a b )x  + (512a b c - 192a b )x  + 512a c
+--R         + 
+--R                 3 2
+--R           - 192a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                  2   2        3      5  6          3 2       2 2          4  4
+--R           (- 192a b c  + 56a b c + 6b )x  + (- 384a c  - 144a b c + 108a b )x
+--R         + 
+--R                  3          2 3  2       4        3 2
+--R           (- 768a b c + 288a b )x  - 512a c + 192a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                 3       2 2  4            2 2        2 2  +-+ +-+
+--R         ((768a c  + 576b c )x  + 3072a b c x  + 3072a c )\|a \|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                       3      3 2  6           2 3          2 2  4
+--R           (- 1152a b c  - 96b c )x  + (- 2304a c  - 1728a b c )x
+--R         + 
+--R                  2   2 2        3 2
+--R           - 4608a b c x  - 3072a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 1244
+
+--S 1245 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1245
+
+--S 1246 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                   2   2        3       5  4        2 2         4  2       3
+--R               (96a b c  + 48a b c - 18b )x  + (384a b c - 96a b )x  + 384a b c
+--R             + 
+--R                    2 3
+--R               - 96a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                      2 2 2        4      6  6
+--R               (- 144a b c  + 24a b c + 3b )x
+--R             + 
+--R                      3   2       2 3         5  4          3 2        2 4  2
+--R               (- 288a b c  - 144a b c + 54a b )x  + (- 576a b c + 144a b )x
+--R             + 
+--R                     4         3 3
+--R               - 384a b c + 96a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                      2   2        3       5  4          2 2          4  2
+--R               (- 192a b c  - 96a b c + 36b )x  + (- 768a b c + 192a b )x
+--R             + 
+--R                     3          2 3
+--R               - 768a b c + 192a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                    2 2 2        4      6  6
+--R               (288a b c  - 48a b c - 6b )x
+--R             + 
+--R                    3   2       2 3          5  4         3 2        2 4  2
+--R               (576a b c  + 288a b c - 108a b )x  + (1152a b c - 288a b )x
+--R             + 
+--R                   4          3 3
+--R               768a b c - 192a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                3 2      2 2         4  4        3          2 3  2       4
+--R           (128a c  + 48a b c - 36a b )x  + (512a b c - 192a b )x  + 512a c
+--R         + 
+--R                 3 2
+--R           - 192a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                  2   2        3      5  6          3 2       2 2          4  4
+--R           (- 192a b c  + 56a b c + 6b )x  + (- 384a c  - 144a b c + 108a b )x
+--R         + 
+--R                  3          2 3  2       4        3 2
+--R           (- 768a b c + 288a b )x  - 512a c + 192a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                 3       2 2  4            2 2        2 2  +---+ +-+ +-+
+--R         ((768a c  + 576b c )x  + 3072a b c x  + 3072a c )\|- c \|a \|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                       3      3 2  6           2 3          2 2  4
+--R           (- 1152a b c  - 96b c )x  + (- 2304a c  - 1728a b c )x
+--R         + 
+--R                  2   2 2        3 2
+--R           - 4608a b c x  - 3072a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 1246
+
+--S 1247 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1247
+
+)clear all
+
+--S 1248 of 1353
+t0:=x*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R          +---------------+
+--R          |   4      2
+--R   (1)  x\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1248
+
+--S 1249 of 1353
+r0:=-1/16*(b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/c^(3/2)+1/8*(b+2*c*x^2)*sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                   2
+--R                2              2c x  + b
+--R       (4a c - b )atanh(-----------------------)
+--R                              +---------------+
+--R                          +-+ |   4      2
+--R                        2\|c \|c x  + b x  + a
+--R     + 
+--R                        +---------------+
+--R            2       +-+ |   4      2
+--R       (4c x  + 2b)\|c \|c x  + b x  + a
+--R  /
+--R         +-+
+--R     16c\|c
+--R                                                    Type: Expression(Integer)
+--E 1249
+
+--S 1250 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                     +---------------+
+--R                           3  2      2        2  +-+ |   4      2
+--R             ((16a b c - 4b )x  + 32a c - 8a b )\|a \|c x  + b x  + a
+--R           + 
+--R                   2 2    4  4         2          3  2      3      2 2
+--R             (- 16a c  + b )x  + (- 32a b c + 8a b )x  - 32a c + 8a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                    2     2   6                  3  4         2        2  2  +-+
+--R           ((- 16a c  - 4b c)x  + (- 40a b c - 2b )x  + (- 32a c - 8a b )x )\|c
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                    2 8         2      2   6                3  4
+--R               16b c x  + (32a c  + 24b c)x  + (56a b c + 6b )x
+--R             + 
+--R                   2        2  2
+--R               (32a c + 8a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                                     +---------------+
+--R                 2           +-+ +-+ |   4      2
+--R         (64b c x  + 128a c)\|a \|c \|c x  + b x  + a
+--R       + 
+--R                  2      2   4             2       2   +-+
+--R         ((- 64a c  - 16b c)x  - 128a b c x  - 128a c)\|c
+--R     ,
+--R
+--R                                                     +---------------+
+--R                           3  2      2        2  +-+ |   4      2
+--R             ((16a b c - 4b )x  + 32a c - 8a b )\|a \|c x  + b x  + a
+--R           + 
+--R                   2 2    4  4         2          3  2      3      2 2
+--R             (- 16a c  + b )x  + (- 32a b c + 8a b )x  - 32a c + 8a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                   2     2   6                 3  4         2        2  2  +---+
+--R           ((- 8a c  - 2b c)x  + (- 20a b c - b )x  + (- 16a c - 4a b )x )\|- c
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                   2 8         2      2   6                3  4
+--R               8b c x  + (16a c  + 12b c)x  + (28a b c + 3b )x
+--R             + 
+--R                   2        2  2
+--R               (16a c + 4a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                      +---------------+
+--R                 2          +---+ +-+ |   4      2
+--R         (32b c x  + 64a c)\|- c \|a \|c x  + b x  + a
+--R       + 
+--R                  2     2   4            2      2   +---+
+--R         ((- 32a c  - 8b c)x  - 64a b c x  - 64a c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1250
+
+--S 1251 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                   +---------------+
+--R                         3  2      2        2  +-+ |   4      2
+--R           ((16a b c - 4b )x  + 32a c - 8a b )\|a \|c x  + b x  + a
+--R         + 
+--R                 2 2    4  4         2          3  2      3      2 2
+--R           (- 16a c  + b )x  + (- 32a b c + 8a b )x  - 32a c + 8a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                                                     +---------------+
+--R                           3  2      2        2  +-+ |   4      2
+--R           ((- 16a b c + 4b )x  - 32a c + 8a b )\|a \|c x  + b x  + a
+--R         + 
+--R               2 2    4  4       2          3  2      3      2 2
+--R           (16a c  - b )x  + (32a b c - 8a b )x  + 32a c - 8a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                             +---------------+
+--R            2 2      2   +-+ |   4      2
+--R       (8a b x  + 16a b)\|c \|c x  + b x  + a
+--R     + 
+--R                      3  4        2 2      2   +-+ +-+
+--R       ((- 8a b c - 2b )x  - 16a b x  - 16a b)\|a \|c
+--R  /
+--R                                   +---------------+
+--R               2           +-+ +-+ |   4      2
+--R       (64b c x  + 128a c)\|a \|c \|c x  + b x  + a
+--R     + 
+--R                2      2   4             2       2   +-+
+--R       ((- 64a c  - 16b c)x  - 128a b c x  - 128a c)\|c
+--R                                                    Type: Expression(Integer)
+--E 1251
+
+--S 1252 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1252
+
+--S 1253 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                           +---------------+
+--R                           3  2      2        2  +---+ +-+ |   4      2
+--R           ((- 16a b c + 4b )x  - 32a c + 8a b )\|- c \|a \|c x  + b x  + a
+--R         + 
+--R                2 2    4  4       2          3  2      3      2 2  +---+
+--R           ((16a c  - b )x  + (32a b c - 8a b )x  + 32a c - 8a b )\|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                                                        +---------------+
+--R                         3  2      2         2  +-+ +-+ |   4      2
+--R           ((32a b c - 8b )x  + 64a c - 16a b )\|a \|c \|c x  + b x  + a
+--R         + 
+--R                  2 2     4  4         2           3  2      3       2 2  +-+
+--R           ((- 32a c  + 2b )x  + (- 64a b c + 16a b )x  - 64a c + 16a b )\|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                                   +---------------+
+--R            2 2      2   +---+ +-+ |   4      2
+--R       (8a b x  + 16a b)\|- c \|c \|c x  + b x  + a
+--R     + 
+--R                      3  4        2 2      2   +---+ +-+ +-+
+--R       ((- 8a b c - 2b )x  - 16a b x  - 16a b)\|- c \|a \|c
+--R  /
+--R                                         +---------------+
+--R               2           +---+ +-+ +-+ |   4      2
+--R       (64b c x  + 128a c)\|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                2      2   4             2       2   +---+ +-+
+--R       ((- 64a c  - 16b c)x  - 128a b c x  - 128a c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 1253
+
+--S 1254 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1254
+
+)clear all
+
+--S 1255 of 1353
+t0:=sqrt(a+b*x^2+c*x^4)/x
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 1255
+
+--S 1256 of 1353
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))*sqrt(a)+_
+   1/4*b*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/sqrt(c)+_
+   1/2*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (2)
+--R                                  2
+--R           +-+ +-+             b x  + 2a
+--R       - 2\|a \|c atanh(-----------------------)
+--R                              +---------------+
+--R                          +-+ |   4      2
+--R                        2\|a \|c x  + b x  + a
+--R     + 
+--R                          2                     +---------------+
+--R                      2c x  + b             +-+ |   4      2
+--R       b atanh(-----------------------) + 2\|c \|c x  + b x  + a
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R  /
+--R       +-+
+--R     4\|c
+--R                                                    Type: Expression(Integer)
+--E 1256
+
+--S 1257 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   +---------------+
+--R               +-+ |   4      2               2       +-+ +-+
+--R           (4a\|c \|c x  + b x  + a  + (- 2b x  - 4a)\|a \|c )
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                   +---------------+
+--R               +-+ |   4      2         2 2
+--R           (2b\|a \|c x  + b x  + a  - b x  - 2a b)
+--R        *
+--R           log
+--R                            4         2     2  +-+            4         2  +-+
+--R                    ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                           6              2  4         2     2  +-+ +-+
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c
+--R                + 
+--R                      2 6           4     2   2
+--R                  4a c x  + 6a b c x  + 8a c x
+--R             /
+--R                                  +---------------+
+--R                         2     2  |   4      2
+--R                  (4a b x  + 8a )\|c x  + b x  + a
+--R                + 
+--R                              2  4         2     2  +-+
+--R                  ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R       + 
+--R                     +---------------+
+--R               2 +-+ |   4      2             4       2  +-+ +-+
+--R         - 2b x \|c \|c x  + b x  + a  + (4c x  + 2b x )\|a \|c
+--R    /
+--R                 +---------------+
+--R         +-+ +-+ |   4      2               2       +-+
+--R       8\|a \|c \|c x  + b x  + a  + (- 4b x  - 8a)\|c
+--R     ,
+--R
+--R                     +---------------+
+--R               +---+ |   4      2              2       +---+ +-+
+--R           (2a\|- c \|c x  + b x  + a  + (- b x  - 2a)\|- c \|a )
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                   +---------------+
+--R               +-+ |   4      2         2 2
+--R           (2b\|a \|c x  + b x  + a  - b x  - 2a b)
+--R        *
+--R                           +---------------+
+--R                 +---+ +-+ |   4      2          +---+
+--R                \|- c \|a \|c x  + b x  + a  - a\|- c
+--R           atan(--------------------------------------)
+--R                                  2 +-+
+--R                               c x \|a
+--R       + 
+--R                      +---------------+
+--R              2 +---+ |   4      2             4      2  +---+ +-+
+--R         - b x \|- c \|c x  + b x  + a  + (2c x  + b x )\|- c \|a
+--R    /
+--R                   +---------------+
+--R         +---+ +-+ |   4      2               2       +---+
+--R       4\|- c \|a \|c x  + b x  + a  + (- 2b x  - 4a)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1257
+
+--S 1258 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 +---------------+
+--R             +-+ |   4      2               2       +-+ +-+
+--R         (4a\|c \|c x  + b x  + a  + (- 2b x  - 4a)\|a \|c )
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                 +---------------+
+--R             +-+ |   4      2         2 2
+--R         (2b\|a \|c x  + b x  + a  - b x  - 2a b)
+--R      *
+--R         log
+--R                          4         2     2  +-+            4         2  +-+
+--R                  ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R               *
+--R                   +---------------+
+--R                   |   4      2
+--R                  \|c x  + b x  + a
+--R              + 
+--R                         6              2  4         2     2  +-+ +-+       2 6
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c  + 4a c x
+--R              + 
+--R                        4     2   2
+--R                6a b c x  + 8a c x
+--R           /
+--R                                +---------------+
+--R                       2     2  |   4      2
+--R                (4a b x  + 8a )\|c x  + b x  + a
+--R              + 
+--R                            2  4         2     2  +-+
+--R                ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R     + 
+--R                 +---------------+
+--R             +-+ |   4      2               2       +-+ +-+
+--R         (4a\|c \|c x  + b x  + a  + (- 2b x  - 4a)\|a \|c )
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                 +---------------+                                2
+--R             +-+ |   4      2         2 2                     2c x  + b
+--R       (- 2b\|a \|c x  + b x  + a  + b x  + 2a b)atanh(-----------------------)
+--R                                                             +---------------+
+--R                                                         +-+ |   4      2
+--R                                                       2\|c \|c x  + b x  + a
+--R     + 
+--R              +---------------+
+--R          +-+ |   4      2               2       +-+ +-+
+--R       4a\|c \|c x  + b x  + a  + (- 2b x  - 4a)\|a \|c
+--R  /
+--R               +---------------+
+--R       +-+ +-+ |   4      2               2       +-+
+--R     8\|a \|c \|c x  + b x  + a  + (- 4b x  - 8a)\|c
+--R                                                    Type: Expression(Integer)
+--E 1258
+
+--S 1259 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1259
+
+--S 1260 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------------+
+--R             +---+ +-+ |   4      2               2       +---+ +-+ +-+
+--R         (4a\|- c \|c \|c x  + b x  + a  + (- 2b x  - 4a)\|- c \|a \|c )
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                       +---------------+
+--R             +---+ +-+ |   4      2               2       +---+ +-+ +-+
+--R         (4a\|- c \|c \|c x  + b x  + a  + (- 2b x  - 4a)\|- c \|a \|c )
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                         +---------------+
+--R               +---+ +-+ |   4      2          2 2         +---+
+--R         (- 2b\|- c \|a \|c x  + b x  + a  + (b x  + 2a b)\|- c )
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                     +---------------+
+--R             +-+ +-+ |   4      2             2 2         +-+
+--R         (4b\|a \|c \|c x  + b x  + a  + (- 2b x  - 4a b)\|c )
+--R      *
+--R                         +---------------+
+--R               +---+ +-+ |   4      2          +---+
+--R              \|- c \|a \|c x  + b x  + a  - a\|- c
+--R         atan(--------------------------------------)
+--R                                2 +-+
+--R                             c x \|a
+--R     + 
+--R                    +---------------+
+--R          +---+ +-+ |   4      2               2       +---+ +-+ +-+
+--R       4a\|- c \|c \|c x  + b x  + a  + (- 2b x  - 4a)\|- c \|a \|c
+--R  /
+--R                     +---------------+
+--R       +---+ +-+ +-+ |   4      2               2       +---+ +-+
+--R     8\|- c \|a \|c \|c x  + b x  + a  + (- 4b x  - 8a)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 1260
+
+--S 1261 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1261
+
+)clear all
+
+--S 1262 of 1353
+t0:=sqrt(a+b*x^2+c*x^4)/x^3
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1262
+
+--S 1263 of 1353
+r0:=-1/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)+_
+   1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))*sqrt(c)-_
+   1/2*sqrt(a+b*x^2+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                             2
+--R            2             b x  + 2a
+--R       - b x atanh(-----------------------)
+--R                         +---------------+
+--R                     +-+ |   4      2
+--R                   2\|a \|c x  + b x  + a
+--R     + 
+--R                                   2                     +---------------+
+--R         2 +-+ +-+             2c x  + b             +-+ |   4      2
+--R       2x \|a \|c atanh(-----------------------) - 2\|a \|c x  + b x  + a
+--R                              +---------------+
+--R                          +-+ |   4      2
+--R                        2\|c \|c x  + b x  + a
+--R  /
+--R       2 +-+
+--R     4x \|a
+--R                                                    Type: Expression(Integer)
+--E 1263
+
+--S 1264 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      +---------------+
+--R                2 +-+ |   4      2          2 4         2
+--R           (4b x \|a \|c x  + b x  + a  - 2b x  - 4a b x )
+--R        *
+--R                  +---------------+
+--R                  |   4      2              2       +-+
+--R               2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R           log(----------------------------------------)
+--R                                     2
+--R                                 2a x
+--R       + 
+--R                      +---------------+
+--R                2 +-+ |   4      2               4       2  +-+ +-+
+--R           (8a x \|c \|c x  + b x  + a  + (- 4b x  - 8a x )\|a \|c )
+--R        *
+--R           log
+--R                                      +---------------+
+--R                       2 +-+     +-+  |   4      2          2 +-+ +-+       4
+--R                  (- 2x \|c  + 2\|a )\|c x  + b x  + a  + 2x \|a \|c  - 2c x
+--R                + 
+--R                       2
+--R                  - b x  - 2a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                          +---------------+
+--R              2       +-+ |   4      2                   2  4         2     2
+--R         (2b x  + 8a)\|a \|c x  + b x  + a  + (- 8a c + b )x  - 6a b x  - 8a
+--R    /
+--R              +---------------+
+--R            2 |   4      2               4        2  +-+
+--R       16a x \|c x  + b x  + a  + (- 8b x  - 16a x )\|a
+--R     ,
+--R
+--R                      +---------------+
+--R                2 +-+ |   4      2          2 4         2
+--R           (4b x \|a \|c x  + b x  + a  - 2b x  - 4a b x )
+--R        *
+--R                  +---------------+
+--R                  |   4      2              2       +-+
+--R               2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R           log(----------------------------------------)
+--R                                     2
+--R                                 2a x
+--R       + 
+--R                         +---------------+
+--R                 2 +---+ |   4      2               4        2  +---+ +-+
+--R           (16a x \|- c \|c x  + b x  + a  + (- 8b x  - 16a x )\|- c \|a )
+--R        *
+--R                 +---------------+
+--R                 |   4      2         +-+
+--R                \|c x  + b x  + a  - \|a
+--R           atan(-------------------------)
+--R                          2 +---+
+--R                         x \|- c
+--R       + 
+--R                          +---------------+
+--R              2       +-+ |   4      2                   2  4         2     2
+--R         (2b x  + 8a)\|a \|c x  + b x  + a  + (- 8a c + b )x  - 6a b x  - 8a
+--R    /
+--R              +---------------+
+--R            2 |   4      2               4        2  +-+
+--R       16a x \|c x  + b x  + a  + (- 8b x  - 16a x )\|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1264
+
+--S 1265 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               +---------------+
+--R               |   4      2             2 2         +-+
+--R         (4a b\|c x  + b x  + a  + (- 2b x  - 4a b)\|a )
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                     +---------------+
+--R             +-+ +-+ |   4      2                 2     2  +-+
+--R         (8a\|a \|c \|c x  + b x  + a  + (- 4a b x  - 8a )\|c )
+--R      *
+--R         log
+--R                                    +---------------+
+--R                     2 +-+     +-+  |   4      2          2 +-+ +-+       4
+--R                (- 2x \|c  + 2\|a )\|c x  + b x  + a  + 2x \|a \|c  - 2c x
+--R              + 
+--R                     2
+--R                - b x  - 2a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R               +---------------+
+--R               |   4      2             2 2         +-+
+--R         (4a b\|c x  + b x  + a  + (- 2b x  - 4a b)\|a )
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                       +---------------+
+--R               +-+ +-+ |   4      2               2     2  +-+
+--R         (- 8a\|a \|c \|c x  + b x  + a  + (4a b x  + 8a )\|c )
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R              +---------------+
+--R              |   4      2          2 2         +-+
+--R       - 2a b\|c x  + b x  + a  + (b x  + 2a b)\|a
+--R  /
+--R             +---------------+
+--R         +-+ |   4      2              2      2
+--R     16a\|a \|c x  + b x  + a  - 8a b x  - 16a
+--R                                                    Type: Expression(Integer)
+--E 1265
+
+--S 1266 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1266
+
+--S 1267 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               +---------------+
+--R               |   4      2             2 2         +-+
+--R         (4a b\|c x  + b x  + a  + (- 2b x  - 4a b)\|a )
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R               +---------------+
+--R               |   4      2             2 2         +-+
+--R         (4a b\|c x  + b x  + a  + (- 2b x  - 4a b)\|a )
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                       +---------------+
+--R               +-+ +-+ |   4      2               2     2  +-+
+--R         (- 8a\|a \|c \|c x  + b x  + a  + (4a b x  + 8a )\|c )
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                        +---------------+
+--R              +---+ +-+ |   4      2                 2      2  +---+
+--R         (16a\|- c \|a \|c x  + b x  + a  + (- 8a b x  - 16a )\|- c )
+--R      *
+--R               +---------------+
+--R               |   4      2         +-+
+--R              \|c x  + b x  + a  - \|a
+--R         atan(-------------------------)
+--R                        2 +---+
+--R                       x \|- c
+--R     + 
+--R              +---------------+
+--R              |   4      2          2 2         +-+
+--R       - 2a b\|c x  + b x  + a  + (b x  + 2a b)\|a
+--R  /
+--R             +---------------+
+--R         +-+ |   4      2              2      2
+--R     16a\|a \|c x  + b x  + a  - 8a b x  - 16a
+--R                                                    Type: Expression(Integer)
+--E 1267
+
+--S 1268 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1268
+
+)clear all
+
+--S 1269 of 1353
+t0:=sqrt(a+b*x^2+c*x^4)/x^5
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 5
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1269
+
+--S 1270 of 1353
+r0:=1/16*(b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+_
+   c*x^4)))/a^(3/2)-1/4*sqrt(a+b*x^2+c*x^4)/x^4-1/8*b*sqrt(a+b*x^2+_
+   c*x^4)/(a*x^2)
+--R 
+--R
+--R   (2)
+--R                                      2
+--R                  2  4             b x  + 2a
+--R       (- 4a c + b )x atanh(-----------------------)
+--R                                  +---------------+
+--R                              +-+ |   4      2
+--R                            2\|a \|c x  + b x  + a
+--R     + 
+--R                          +---------------+
+--R              2       +-+ |   4      2
+--R       (- 2b x  - 4a)\|a \|c x  + b x  + a
+--R  /
+--R          4 +-+
+--R     16a x \|a
+--R                                                    Type: Expression(Integer)
+--E 1270
+
+--S 1271 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                        +---------------+
+--R                2           3  6        3       2 2  4  |   4      2
+--R           ((64a b c - 16a b )x  + (128a c - 32a b )x )\|c x  + b x  + a
+--R         + 
+--R                     2 2     4  8          2           3  6
+--R               (- 64a c  + 4b )x  + (- 128a b c + 32a b )x
+--R             + 
+--R                      3       2 2  4
+--R               (- 128a c + 32a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R              2          3  6       3       2 2  4       3   2       4
+--R         ((32a b c + 4a b )x  + (64a c + 72a b )x  + 192a b x  + 128a )
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                   2     4  8          2           3  6          3        2 2  4
+--R           (- 28a b c + b )x  + (- 128a b c - 24a b )x  + (- 128a c - 152a b )x
+--R         + 
+--R                 3   2       4
+--R           - 256a b x  - 128a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                 +---------------+
+--R            2   6       3 4  +-+ |   4      2               3       2 2  8
+--R       (256a b x  + 512a x )\|a \|c x  + b x  + a  + (- 256a c - 64a b )x
+--R     + 
+--R             3   6       4 4
+--R       - 512a b x  - 512a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1271
+
+--S 1272 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              +---------------+
+--R                          +-+ |   4      2           2
+--R                  2     2\|a \|c x  + b x  + a  - b x  - 2a
+--R       (16a c - 4b )log(-----------------------------------)
+--R                                        2 +-+
+--R                                      2x \|a
+--R     + 
+--R                                    2
+--R                  2              b x  + 2a            2
+--R       (16a c - 4b )atanh(-----------------------) - b
+--R                                +---------------+
+--R                            +-+ |   4      2
+--R                          2\|a \|c x  + b x  + a
+--R  /
+--R         +-+
+--R     64a\|a
+--R                                                    Type: Expression(Integer)
+--E 1272
+
+--S 1273 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1273
+
+)clear all
+
+--S 1274 of 1353
+t0:=sqrt(a+b*x^2+c*x^4)/x^7
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 7
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1274
+
+--S 1275 of 1353
+r0:=-1/32*b*(b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+_
+   c*x^4)))/a^(5/2)-1/6*sqrt(a+b*x^2+c*x^4)/x^6-1/24*b*sqrt(a+b*x^2+_
+   c*x^4)/(a*x^4)+1/48*(3*b^2-8*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*x^2)
+--R 
+--R
+--R   (2)
+--R                                        2
+--R                    3  6             b x  + 2a
+--R       (12a b c - 3b )x atanh(-----------------------)
+--R                                    +---------------+
+--R                                +-+ |   4      2
+--R                              2\|a \|c x  + b x  + a
+--R     + 
+--R                                                +---------------+
+--R                     2  4         2      2  +-+ |   4      2
+--R       ((- 16a c + 6b )x  - 4a b x  - 16a )\|a \|c x  + b x  + a
+--R  /
+--R        2 6 +-+
+--R     96a x \|a
+--R                                                    Type: Expression(Integer)
+--E 1275
+
+--S 1276 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      2   2         3       5  10           2 2          4  8
+--R               (- 384a b c  - 192a b c + 72b )x   + (- 1536a b c + 384a b )x
+--R             + 
+--R                       3          2 3  6
+--R               (- 1536a b c + 384a b )x
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                2 2 2        4       6  12
+--R           (576a b c  - 96a b c - 12b )x
+--R         + 
+--R                 3   2       2 3          5  10         3 2        2 4  8
+--R           (1152a b c  + 576a b c - 216a b )x   + (2304a b c - 576a b )x
+--R         + 
+--R                 4          3 3  6
+--R           (1536a b c - 384a b )x
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                2   2         3      5  10         3 2       2 2          4  8
+--R           (672a b c  - 256a b c + 6b )x   + (1536a c  + 384a b c - 256a b )x
+--R         + 
+--R               3          2 3  6         4         3 2  4        4   2        5
+--R         (3840a b c - 640a b )x  + (3584a c + 1152a b )x  + 3584a b x  + 2048a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R              3 3      2 2 2        4      6  12
+--R       (- 512a c  - 48a b c  + 96a b c - 5b )x
+--R     + 
+--R               3   2       2 3         5  10
+--R       (- 2400a b c  + 576a b c + 54a b )x
+--R     + 
+--R               4 2        3 2        2 4  8           4          3 3  6
+--R       (- 3072a c  - 1920a b c + 576a b )x  + (- 6912a b c + 384a b )x
+--R     + 
+--R               5         4 2  4        5   2        6
+--R       (- 4608a c - 2688a b )x  - 4608a b x  - 2048a
+--R  /
+--R                                                           +---------------+
+--R              4         3 2  10         4   8         5 6  |   4      2
+--R       ((3072a c + 2304a b )x   + 12288a b x  + 12288a x )\|c x  + b x  + a
+--R     + 
+--R                   3          2 3  12           4         3 2  10         4   8
+--R           (- 4608a b c - 384a b )x   + (- 9216a c - 6912a b )x   - 18432a b x
+--R         + 
+--R                   5 6
+--R           - 12288a x
+--R      *
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1276
+
+--S 1277 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      3   2       2 3         5  4           3 2        2 4  2
+--R               (- 384a b c  - 192a b c + 72a b )x  + (- 1536a b c + 384a b )x
+--R             + 
+--R                      4          3 3
+--R               - 1536a b c + 384a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                    2 2 2        4       6  6
+--R               (576a b c  - 96a b c - 12b )x
+--R             + 
+--R                     3   2       2 3          5  4         3 2        2 4  2
+--R               (1152a b c  + 576a b c - 216a b )x  + (2304a b c - 576a b )x
+--R             + 
+--R                    4          3 3
+--R               1536a b c - 384a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                      3   2       2 3         5  4           3 2        2 4  2
+--R               (- 384a b c  - 192a b c + 72a b )x  + (- 1536a b c + 384a b )x
+--R             + 
+--R                      4          3 3
+--R               - 1536a b c + 384a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                    2 2 2        4       6  6
+--R               (576a b c  - 96a b c - 12b )x
+--R             + 
+--R                     3   2       2 3          5  4         3 2        2 4  2
+--R               (1152a b c  + 576a b c - 216a b )x  + (2304a b c - 576a b )x
+--R             + 
+--R                    4          3 3
+--R               1536a b c - 384a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                 3   2      2 3         5  4          3 2        2 4  2
+--R           (- 96a b c  - 32a b c + 30a b )x  + (- 384a b c + 160a b )x
+--R         + 
+--R                 4          3 3
+--R           - 384a b c + 160a b
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                2 2 2        4      6  6        3   2      2 3         5  4
+--R           (144a b c  - 48a b c - 5b )x  + (288a b c  + 96a b c - 90a b )x
+--R         + 
+--R                3 2        2 4  2       4          3 3
+--R           (576a b c - 240a b )x  + 384a b c - 160a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                            +---------------+
+--R              4         3 2  4         4   2         5  +-+ |   4      2
+--R       ((3072a c + 2304a b )x  + 12288a b x  + 12288a )\|a \|c x  + b x  + a
+--R     + 
+--R               4          3 3  6           5         4 2  4         5   2
+--R       (- 4608a b c - 384a b )x  + (- 9216a c - 6912a b )x  - 18432a b x
+--R     + 
+--R               6
+--R       - 12288a
+--R                                                    Type: Expression(Integer)
+--E 1277
+
+--S 1278 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1278
+
+)clear all
+
+--S 1279 of 1353
+t0:=sqrt(a+b*x^2+c*x^4)/x^9
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 9
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1279
+
+--S 1280 of 1353
+r0:=1/256*(b^2-4*a*c)*(5*b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*_
+   sqrt(a+b*x^2+c*x^4)))/a^(7/2)-1/8*sqrt(a+b*x^2+c*x^4)/x^8-1/48*b*_
+   sqrt(a+b*x^2+c*x^4)/(a*x^6)+1/192*(5*b^2-12*a*c)*sqrt(a+b*x^2+c*x^4)/_
+   (a^2*x^4)-1/384*b*(15*b^2-52*a*c)*sqrt(a+b*x^2+c*x^4)/(a^3*x^2)
+--R 
+--R
+--R   (2)
+--R                                                  2
+--R           2 2        2       4  8             b x  + 2a
+--R       (48a c  - 72a b c + 15b )x atanh(-----------------------)
+--R                                              +---------------+
+--R                                          +-+ |   4      2
+--R                                        2\|a \|c x  + b x  + a
+--R     + 
+--R                         3  6         2         2  4      2   2      3  +-+
+--R         ((104a b c - 30b )x  + (- 48a c + 20a b )x  - 16a b x  - 96a )\|a
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R  /
+--R         3 8 +-+
+--R     768a x \|a
+--R                                                    Type: Expression(Integer)
+--E 1280
+
+--S 1281 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        4   3         3 3 2       2 5          7  14
+--R               (- 12288a b c  + 15360a b c  + 768a b c - 960a b )x
+--R             + 
+--R                        5 3        4 2 2         3 4         2 6  12
+--R               (- 24576a c  + 6144a b c  + 38400a b c - 9600a b )x
+--R             + 
+--R                        5   2          4 3          3 5  10
+--R               (- 73728a b c  + 110592a b c - 23040a b )x
+--R             + 
+--R                        6 2         5 2          4 4  8
+--R               (- 49152a c  + 73728a b c - 15360a b )x
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                     4 4         2 4 2          6        8  16
+--R               (6144a c  - 11520a b c  + 2304a b c + 120b )x
+--R             + 
+--R                      4   3         3 3 2        2 5           7  14
+--R               (49152a b c  - 61440a b c  - 3072a b c + 3840a b )x
+--R             + 
+--R                      5 3         4 2 2         3 4          2 6  12
+--R               (49152a c  - 12288a b c  - 76800a b c + 19200a b )x
+--R             + 
+--R                      5   2          4 3          3 5  10
+--R               (98304a b c  - 147456a b c + 30720a b )x
+--R             + 
+--R                      6 2         5 2          4 4  8
+--R               (49152a c  - 73728a b c + 15360a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                    4   3        3 3 2        2 5          7  14
+--R           (- 13312a b c  - 9984a b c  + 4576a b c - 232a b )x
+--R         + 
+--R                 5 3         4 2 2         3 4         2 6  12
+--R           (6144a c  - 87552a b c  + 12224a b c + 2800a b )x
+--R         + 
+--R                    5   2         4 3          3 5  10
+--R           (- 55296a b c  - 70656a b c + 22080a b )x
+--R         + 
+--R                  6 2          5 2          4 4  8           6            5 3  6
+--R           (61440a c  - 112640a b c + 33152a b )x  + (106496a b c + 34816a b )x
+--R         + 
+--R                   7           6 2  4          7   2         8
+--R           (147456a c + 135168a b )x  + 212992a b x  + 98304a
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                  3 2 3        2 4 2         6       8  16
+--R           (23552a b c  - 4688a b c  - 696a b c + 59b )x
+--R         + 
+--R                  4   3         3 3 2         2 5         7  14
+--R           (40960a b c  + 55296a b c  - 17536a b c - 32a b )x
+--R         + 
+--R                    5 3          4 2 2        3 4          2 6  12
+--R           (- 24576a c  + 178176a b c  - 5248a b c - 10400a b )x
+--R         + 
+--R                  5   2          4 3          3 5  10
+--R           (16384a b c  + 122880a b c - 37120a b )x
+--R         + 
+--R                     6 2         5 2          4 4  8
+--R           (- 122880a c  + 45056a b c - 43136a b )x
+--R         + 
+--R                     6            5 3  6             7           6 2  4
+--R           (- 262144a b c - 81920a b )x  + (- 196608a c - 229376a b )x
+--R         + 
+--R                    7   2         8
+--R           - 262144a b x  - 98304a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                   5            4 3  14           6           5 2  12
+--R           (196608a b c + 49152a b )x   + (393216a c + 491520a b )x
+--R         + 
+--R                   6   10          7 8
+--R           1179648a b x   + 786432a x
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R                6 2          5 2         4 4  16
+--R       (- 98304a c  - 147456a b c - 6144a b )x
+--R     + 
+--R                 6             5 3  14             7           6 2  12
+--R       (- 786432a b c - 196608a b )x   + (- 786432a c - 983040a b )x
+--R     + 
+--R                 7   10          8 8
+--R       - 1572864a b x   - 786432a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1281
+
+--S 1282 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +---------------+
+--R                                           +-+ |   4      2           2
+--R              2 2         2        4     2\|a \|c x  + b x  + a  - b x  - 2a
+--R       (- 384a c  + 576a b c - 120b )log(-----------------------------------)
+--R                                                         2 +-+
+--R                                                       2x \|a
+--R     + 
+--R                                                     2
+--R              2 2         2        4              b x  + 2a                 2
+--R       (- 384a c  + 576a b c - 120b )atanh(-----------------------) + 192a b c
+--R                                                 +---------------+
+--R                                             +-+ |   4      2
+--R                                           2\|a \|c x  + b x  + a
+--R     + 
+--R            4
+--R       - 59b
+--R  /
+--R          3 +-+
+--R     6144a \|a
+--R                                                    Type: Expression(Integer)
+--E 1282
+
+--S 1283 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1283
+
+)clear all
+
+--S 1284 of 1353
+t0:=sqrt(a+b*x^2+c*x^4)/x^11
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 11
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1284
+
+--S 1285 of 1353
+r0:=-1/512*b*(7*b^2-12*a*c)*(b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*_
+   sqrt(a+b*x^2+c*x^4)))/a^(9/2)-1/10*sqrt(a+b*x^2+c*x^4)/x^10-1/80*b*_
+   sqrt(a+b*x^2+c*x^4)/(a*x^8)+1/480*(7*b^2-16*a*c)*sqrt(a+b*x^2+c*x^4)/_
+   (a^2*x^6)-1/1920*b*(35*b^2-116*a*c)*sqrt(a+b*x^2+c*x^4)/(a^3*x^4)+_
+   1/3840*(105*b^4-460*a*b^2*c+256*a^2*c^2)*sqrt(a+b*x^2+c*x^4)/(a^4*x^2)
+--R 
+--R
+--R   (2)
+--R                                                          2
+--R              2   2         3        5  10             b x  + 2a
+--R       (- 720a b c  + 600a b c - 105b )x  atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|a \|c x  + b x  + a
+--R     + 
+--R                2 2         2        4  8        2            3  6
+--R           (512a c  - 920a b c + 210b )x  + (464a b c - 140a b )x
+--R         + 
+--R                  3        2 2  4      3   2       4
+--R           (- 256a c + 112a b )x  - 96a b x  - 768a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R  /
+--R          4 10 +-+
+--R     7680a x  \|a
+--R                                                    Type: Expression(Integer)
+--E 1285
+
+--S 1286 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          4   4          3 3 3          2 5 2           7
+--R                   184320a b c  + 307200a b c  - 299520a b c  + 19200a b c
+--R                 + 
+--R                        9
+--R                   8400b
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                        4 2 3          3 4 2          2 6             8  16
+--R               (2211840a b c  - 921600a b c  - 445440a b c + 134400a b )x
+--R             + 
+--R                        5   3           4 3 2           3 5           2 7  14
+--R               (2211840a b c  + 2027520a b c  - 2903040a b c + 564480a b )x
+--R             + 
+--R                        5 2 2           4 4           3 6  12
+--R               (5898240a b c  - 4915200a b c + 860160a b )x
+--R             + 
+--R                        6   2           5 3           4 5  10
+--R               (2949120a b c  - 2457600a b c + 430080a b )x
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                          4 2 4          3 4 3          2 6 2           8
+--R                 - 460800a b c  + 153600a b c  + 119040a b c  - 28800a b c
+--R               + 
+--R                       10
+--R                 - 840b
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                        5   4           4 3 3           3 5 2         2 7
+--R               - 921600a b c  - 1536000a b c  + 1497600a b c  - 96000a b c
+--R             + 
+--R                         9
+--R               - 42000a b
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                      5 2 3           4 4 2           3 6           2 8  16
+--R           (- 5529600a b c  + 2304000a b c  + 1113600a b c - 336000a b )x
+--R         + 
+--R                      6   3           5 3 2           4 5           3 7  14
+--R           (- 3686400a b c  - 3379200a b c  + 4838400a b c - 940800a b )x
+--R         + 
+--R                      6 2 2           5 4            4 6  12
+--R           (- 7372800a b c  + 6144000a b c - 1075200a b )x
+--R         + 
+--R                      7   2           6 3           5 5  10
+--R           (- 2949120a b c  + 2457600a b c - 430080a b )x
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                       4   4          3 3 3         2 5 2           7         9
+--R             (- 296960a b c  + 441600a b c  + 29472a b c  - 42720a b c + 2810b )
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                        5 4          4 2 3           3 4 2          2 6
+--R               - 655360a c  - 389120a b c  + 1843200a b c  - 391296a b c
+--R             + 
+--R                         8
+--R               - 11040a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                      5   3           4 3 2          3 5           2 7  14
+--R           (- 3993600a b c  + 4055040a b c  + 468864a b c - 315168a b )x
+--R         + 
+--R                      6 3           5 2 2           4 4            3 6  12
+--R           (- 2293760a c  - 1720320a b c  + 4608000a b c - 1017856a b )x
+--R         + 
+--R                      6   2           5 3           4 5  10
+--R           (- 4546560a b c  + 5529600a b c - 979968a b )x
+--R         + 
+--R                   7 2           6 2           5 4  8
+--R           (196608a c  + 3932160a b c + 184320a b )x
+--R         + 
+--R                    7              6 3  6            8            7 2  4
+--R           (7110656a b c + 2744320a b )x  + (4980736a c + 7405568a b )x
+--R         + 
+--R                   8   2           9
+--R           8257536a b x  + 3145728a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R                  5 5         4 2 4          3 4 3         2 6 2         8
+--R           131072a c  + 15360a b c  - 382080a b c  + 99120a b c  + 720a b c
+--R         + 
+--R                 10
+--R           - 449b
+--R      *
+--R          20
+--R         x
+--R     + 
+--R                  5   4           4 3 3          3 5 2          2 7           9
+--R         (1669120a b c  - 1900800a b c  - 446880a b c  + 232800a b c - 5650a b )
+--R      *
+--R          18
+--R         x
+--R     + 
+--R                  6 4           5 2 3           4 4 2          3 6          2 8
+--R         (1638400a c  + 2078720a b c  - 5068800a b c  + 755520a b c + 94800a b )
+--R      *
+--R          16
+--R         x
+--R     + 
+--R                6   3           5 3 2           4 5           3 7  14
+--R       (7393280a b c  - 6082560a b c  - 1749120a b c + 713440a b )x
+--R     + 
+--R                7 3           6 2 2           5 4            4 6  12
+--R       (2621440a c  + 3010560a b c  - 7065600a b c + 1487360a b )x
+--R     + 
+--R                7   2           6 3            5 5  10
+--R       (2580480a b c  - 7495680a b c + 1004544a b )x
+--R     + 
+--R                  8 2           7 2            6 4  8
+--R       (- 2293760a c  - 9093120a b c - 1024000a b )x
+--R     + 
+--R                   8              7 3  6              9             8 2  4
+--R       (- 12943360a b c - 5611520a b )x  + (- 6553600a c - 11141120a b )x
+--R     + 
+--R                 9   2           10
+--R       - 9830400a b x  - 3145728a
+--R  /
+--R                    7 2           6 2           5 4  18
+--R           (1966080a c  + 4915200a b c + 614400a b )x
+--R         + 
+--R                     7              6 3  16             8             7 2  14
+--R           (23592960a b c + 9830400a b )x   + (23592960a c + 41287680a b )x
+--R         + 
+--R                    8   12            9 10
+--R           62914560a b x   + 31457280a x
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                      6   2           5 3          4 5  20
+--R           (- 4915200a b c  - 2457600a b c - 61440a b )x
+--R         + 
+--R                      7 2            6 2            5 4  18
+--R           (- 9830400a c  - 24576000a b c - 3072000a b )x
+--R         + 
+--R                       7               6 3  16
+--R           (- 58982400a b c - 24576000a b )x
+--R         + 
+--R                       8             7 2  14            8   12            9 10
+--R           (- 39321600a c - 68812800a b )x   - 78643200a b x   - 31457280a x
+--R      *
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1286
+
+--S 1287 of 1353
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                   184320a b c  + 307200a b c  - 299520a b c  + 19200a b c
+--R                 + 
+--R                          9
+--R                   8400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                        5 2 3          4 4 2          3 6           2 8  6
+--R               (2211840a b c  - 921600a b c  - 445440a b c + 134400a b )x
+--R             + 
+--R                        6   3           5 3 2           4 5           3 7  4
+--R               (2211840a b c  + 2027520a b c  - 2903040a b c + 564480a b )x
+--R             + 
+--R                        6 2 2           5 4           4 6  2           7   2
+--R               (5898240a b c  - 4915200a b c + 860160a b )x  + 2949120a b c
+--R             + 
+--R                         6 3           5 5
+--R               - 2457600a b c + 430080a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                            4 2 4          3 4 3          2 6 2           8
+--R                   - 460800a b c  + 153600a b c  + 119040a b c  - 28800a b c
+--R                 + 
+--R                         10
+--R                   - 840b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            5   4           4 3 3           3 5 2         2 7
+--R                   - 921600a b c  - 1536000a b c  + 1497600a b c  - 96000a b c
+--R                 + 
+--R                             9
+--R                   - 42000a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          5 2 3           4 4 2           3 6           2 8  6
+--R               (- 5529600a b c  + 2304000a b c  + 1113600a b c - 336000a b )x
+--R             + 
+--R                          6   3           5 3 2           4 5           3 7  4
+--R               (- 3686400a b c  - 3379200a b c  + 4838400a b c - 940800a b )x
+--R             + 
+--R                          6 2 2           5 4            4 6  2           7   2
+--R               (- 7372800a b c  + 6144000a b c - 1075200a b )x  - 2949120a b c
+--R             + 
+--R                       6 3           5 5
+--R               2457600a b c - 430080a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                   184320a b c  + 307200a b c  - 299520a b c  + 19200a b c
+--R                 + 
+--R                          9
+--R                   8400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                        5 2 3          4 4 2          3 6           2 8  6
+--R               (2211840a b c  - 921600a b c  - 445440a b c + 134400a b )x
+--R             + 
+--R                        6   3           5 3 2           4 5           3 7  4
+--R               (2211840a b c  + 2027520a b c  - 2903040a b c + 564480a b )x
+--R             + 
+--R                        6 2 2           5 4           4 6  2           7   2
+--R               (5898240a b c  - 4915200a b c + 860160a b )x  + 2949120a b c
+--R             + 
+--R                         6 3           5 5
+--R               - 2457600a b c + 430080a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                            4 2 4          3 4 3          2 6 2           8
+--R                   - 460800a b c  + 153600a b c  + 119040a b c  - 28800a b c
+--R                 + 
+--R                         10
+--R                   - 840b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            5   4           4 3 3           3 5 2         2 7
+--R                   - 921600a b c  - 1536000a b c  + 1497600a b c  - 96000a b c
+--R                 + 
+--R                             9
+--R                   - 42000a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          5 2 3           4 4 2           3 6           2 8  6
+--R               (- 5529600a b c  + 2304000a b c  + 1113600a b c - 336000a b )x
+--R             + 
+--R                          6   3           5 3 2           4 5           3 7  4
+--R               (- 3686400a b c  - 3379200a b c  + 4838400a b c - 940800a b )x
+--R             + 
+--R                          6 2 2           5 4            4 6  2           7   2
+--R               (- 7372800a b c  + 6144000a b c - 1075200a b )x  - 2949120a b c
+--R             + 
+--R                       6 3           5 5
+--R               2457600a b c - 430080a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                  5   4         4 3 3          3 5 2         2 7           9  8
+--R           (30720a b c  + 16640a b c  - 126432a b c  + 17120a b c + 4490a b )x
+--R         + 
+--R                   5 2 3          4 4 2          3 6          2 8  6
+--R           (368640a b c  - 568320a b c  - 128384a b c + 71840a b )x
+--R         + 
+--R                   6   3         5 3 2           4 5           3 7  4
+--R           (368640a b c  - 76800a b c  - 1090944a b c + 301728a b )x
+--R         + 
+--R                   6 2 2           5 4           4 6  2          7   2
+--R           (983040a b c  - 1925120a b c + 459776a b )x  + 491520a b c
+--R         + 
+--R                    6 3           5 5
+--R           - 962560a b c + 229888a b
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                    4 2 4          3 4 3         2 6 2           8        10  10
+--R           (- 76800a b c  + 112000a b c  + 38320a b c  - 16080a b c - 449b  )x
+--R         + 
+--R                        5   4         4 3 3          3 5 2         2 7
+--R               - 153600a b c  - 83200a b c  + 632160a b c  - 85600a b c
+--R             + 
+--R                         9
+--R               - 22450a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                     5 2 3           4 4 2          3 6           2 8  6
+--R           (- 921600a b c  + 1420800a b c  + 320960a b c - 179600a b )x
+--R         + 
+--R                     6   3          5 3 2           4 5           3 7  4
+--R           (- 614400a b c  + 128000a b c  + 1818240a b c - 502880a b )x
+--R         + 
+--R                      6 2 2           5 4           4 6  2          7   2
+--R           (- 1228800a b c  + 2406400a b c - 574720a b )x  - 491520a b c
+--R         + 
+--R                  6 3           5 5
+--R           962560a b c - 229888a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                    7 2           6 2           5 4  8
+--R           (1966080a c  + 4915200a b c + 614400a b )x
+--R         + 
+--R                     7              6 3  6             8             7 2  4
+--R           (23592960a b c + 9830400a b )x  + (23592960a c + 41287680a b )x
+--R         + 
+--R                    8   2            9
+--R           62914560a b x  + 31457280a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R                  7   2           6 3          5 5  10
+--R       (- 4915200a b c  - 2457600a b c - 61440a b )x
+--R     + 
+--R                  8 2            7 2            6 4  8
+--R       (- 9830400a c  - 24576000a b c - 3072000a b )x
+--R     + 
+--R                   8               7 3  6               9             8 2  4
+--R       (- 58982400a b c - 24576000a b )x  + (- 39321600a c - 68812800a b )x
+--R     + 
+--R                  9   2            10
+--R       - 78643200a b x  - 31457280a
+--R                                                    Type: Expression(Integer)
+--E 1287
+
+--S 1288 of 1353
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1288
+
+)clear all
+
+--S 1289 of 1353
+t0:=x^4*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +---------------+
+--R         4 |   4      2
+--R   (1)  x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1289
+
+--S 1290 of 1353
+--r0a:=-2/105*(2*b^2-5*a*c)*x*sqrt(a+b*x^2+c*x^4)/c^2+1/35*x^3*(b+5*c*x^2)*sqrt(a+b*x^2+c*x^4)/c+1/210*b*(8*b^2-29*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/210*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(8*b^4-37*a*b^2*c+20*a^2*c^2+b*(8*b^2-29*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1290
+
+--S 1291 of 1353
+--a0:=integrate(t0,x)
+--E 1291
+
+--S 1292 of 1353
+--m0:=a0-r0
+--E 1292
+
+--S 1293 of 1353
+--d0:=normalize(D(m0,x))
+--E 1293
+
+)clear all
+
+--S 1294 of 1353
+t0:=x^2*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +---------------+
+--R         2 |   4      2
+--R   (1)  x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1294
+
+--S 1295 of 1353
+--r0:=1/15*x*(b+3*c*x^2)*sqrt(a+b*x^2+c*x^4)/c-1/15*(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))+1/15*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1295
+
+--S 1296 of 1353
+--a0:=integrate(t0,x)
+--E 1296
+
+--S 1297 of 1353
+--m0:=a0-r0
+--E 1297
+
+--S 1298 of 1353
+--d0:=normalize(D(m0,x))
+--E 1298
+
+)clear all
+
+--S 1299 of 1353
+t0:=sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R   (1)  \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1299
+
+--S 1300 of 1353
+--r0:=1/3*x*sqrt(a+b*x^2+c*x^4)+1/6*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/6*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1300
+
+--S 1301 of 1353
+--a0:=integrate(t0,x)
+--E 1301
+
+--S 1302 of 1353
+--m0:=a0-r0
+--E 1302
+
+--S 1303 of 1353
+--d0:=normalize(D(m0,x))
+--E 1303
+
+)clear all
+
+--S 1304 of 1353
+t0:=sqrt(a+b*x^2+c*x^4)/x^2
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1304
+
+--S 1305 of 1353
+--r0:=-sqrt(a+b*x^2+c*x^4)/x-elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(b^2-4*a*c)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))+elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 1305
+
+--S 1306 of 1353
+--a0:=integrate(t0,x)
+--E 1306
+
+--S 1307 of 1353
+--m0:=a0-r0
+--E 1307
+
+--S 1308 of 1353
+--d0:=normalize(D(m0,x))
+--E 1308
+
+)clear all
+
+--S 1309 of 1353
+t0:=sqrt(a+b*x^2+c*x^4)/x^4
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 4
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1309
+
+--S 1310 of 1353
+--r0:=-1/3*sqrt(a+b*x^2+c*x^4)/x^3-1/3*b*sqrt(a+b*x^2+c*x^4)/(a*x)+1/6*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))-1/6*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 1310
+
+--S 1311 of 1353
+--a0:=integrate(t0,x)
+--E 1311
+
+--S 1312 of 1353
+--m0:=a0-r0
+--E 1312
+
+--S 1313 of 1353
+--d0:=normalize(D(m0,x))
+--E 1313
+
+)clear all
+
+--S 1314 of 1353
+t0:=sqrt(a+b*x^2+c*x^4)/x^6
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 6
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1314
+
+--S 1315 of 1353
+--r0:=-1/5*sqrt(a+b*x^2+c*x^4)/x^5-1/15*b*sqrt(a+b*x^2+c*x^4)/(a*x^3)+2/15*(b^2-3*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*x)-1/15*(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))+1/15*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 1315
+
+--S 1316 of 1353
+--a0:=integrate(t0,x)
+--E 1316
+
+--S 1317 of 1353
+--m0:=a0-r0
+--E 1317
+
+--S 1318 of 1353
+--d0:=normalize(D(m0,x))
+--E 1318
+
+)clear all
+
+--S 1319 of 1353
+t0:=x^7*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                              +---------------+
+--R            11      9      7  |   4      2
+--R   (1)  (c x   + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1319
+
+--S 1320 of 1353
+r0:=-1/256*b*(3*b^2-4*a*c)*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^4+1/1680*_
+   (63*b^2-8*a*c)*(a+b*x^2+c*x^4)^(5/2)/c^3+1/14*x^4*(a+b*x^2+c*x^4)^(5/2)/c-_
+   1/168*(4*a+9*b*x^2)*(a+b*x^2+c*x^4)^(5/2)/c^2-3/4096*b*(b^2-4*a*c)^2*_
+   (3*b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/_
+   c^(11/2)+3/2048*b*(b^2-4*a*c)*(3*b^2-4*a*c)*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^5
+--R 
+--R
+--R   (2)
+--R               3   3        2 3 2          5        7
+--R         (6720a b c  - 8400a b c  + 2940a b c - 315b )
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                 6 12           5 10            5       2 4  8
+--R           10240c x   + 12800b c x   + (16384a c  + 256b c )x
+--R         + 
+--R                     4       3 3  6         2 4          2 3       4 2  4
+--R           (1408a b c  - 288b c )x  + (2048a c  - 1984a b c  + 336b c )x
+--R         + 
+--R                   2   3          3 2       5   2        3 3         2 2 2
+--R           (- 4672a b c  + 2912a b c  - 420b c)x  - 4096a c  + 10976a b c
+--R         + 
+--R                    4        6
+--R           - 5040a b c + 630b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R            5 +-+
+--R     143360c \|c
+--R                                                    Type: Expression(Integer)
+--E 1320
+
+--S 1321 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            6   6           5 3 5           4 5 4          3 7 3
+--R                     860160a b c  + 3440640a b c  - 3386880a b c  - 322560a b c
+--R                   + 
+--R                            2 9 2           11         13
+--R                     493920a b c  - 47040a b  c - 4410b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                              6 2 5           5 4 4            4 6 3
+--R                     20643840a b c  - 1720320a b c  - 18063360a b c
+--R                   + 
+--R                             3 8 2          2 10             12
+--R                     5806080a b c  + 188160a b  c - 141120a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              7   5            6 3 4            5 5 3
+--R                     20643840a b c  + 67092480a b c  - 79994880a b c
+--R                   + 
+--R                             4 7 2           3 9            2 11
+--R                     5806080a b c  + 7499520a b c - 1270080a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                               7 2 4            6 4 3            5 6 2
+--R                     137625600a b c  - 68812800a b c  - 68812800a b c
+--R                   + 
+--R                              4 8            3 10
+--R                     38707200a b c - 4838400a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                              8   4             7 3 3             6 5 2
+--R                     68812800a b c  + 103219200a b c  - 206438400a b c
+--R                   + 
+--R                              5 7            4 9
+--R                     79564800a b c - 8870400a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                               8 2 3             7 4 2            6 6
+--R                     165150720a b c  - 206438400a b c  + 72253440a b c
+--R                   + 
+--R                               5 8
+--R                     - 7741440a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                          9   3            8 3 2            7 5            6 7
+--R                 55050240a b c  - 68812800a b c  + 24084480a b c - 2580480a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                           6 2 6           4 6 4          3 8 3         2 10 2
+--R                 - 3010560a b c  + 2822400a b c  - 806400a b c  - 62160a b  c
+--R               + 
+--R                         12        14
+--R                 23520a b  c + 315b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                           7   6            6 3 5            5 5 4
+--R                 - 6021120a b c  - 24084480a b c  + 23708160a b c
+--R               + 
+--R                         4 7 3           3 9 2          2 11            13
+--R                 2257920a b c  - 3457440a b c  + 329280a b  c + 30870a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            7 2 5           6 4 4            5 6 3
+--R                 - 72253440a b c  + 6021120a b c  + 63221760a b c
+--R               + 
+--R                            4 8 2          3 10           2 12
+--R                 - 20321280a b c  - 658560a b  c + 493920a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            8   5             7 3 4             6 5 3
+--R                 - 48168960a b c  - 156549120a b c  + 186654720a b c
+--R               + 
+--R                            5 7 2            4 9            3 11
+--R                 - 13547520a b c  - 17498880a b c + 2963520a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             8 2 4             7 4 3             6 6 2
+--R                 - 240844800a b c  + 120422400a b c  + 120422400a b c
+--R               + 
+--R                            5 8            4 10
+--R                 - 67737600a b c + 8467200a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            9   4             8 3 3             7 5 2
+--R                 - 96337920a b c  - 144506880a b c  + 289013760a b c
+--R               + 
+--R                             6 7             5 9
+--R                 - 111390720a b c + 12418560a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                               9 2 3             8 4 2            7 6
+--R                   - 192675840a b c  + 240844800a b c  - 84295680a b c
+--R                 + 
+--R                           6 8
+--R                   9031680a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        10   3            9 3 2            8 5            7 7
+--R             - 55050240a  b c  + 68812800a b c  - 24084480a b c + 2580480a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                        3   9           2 3 8            5 7         7 6  26
+--R             (- 4587520a b c  - 5734400a b c  - 860160a b c  - 10240b c )x
+--R           + 
+--R                           4 9            3 2 8            2 4 7             6 6
+--R                 - 9175040a c  - 53903360a b c  - 27238400a b c  - 2078720a b c
+--R               + 
+--R                         8 5
+--R                 - 12800b c
+--R            *
+--R                24
+--R               x
+--R           + 
+--R                             4   8             3 3 7            2 5 6
+--R                 - 128909312a b c  - 197951488a b c  - 42663936a b c
+--R               + 
+--R                             7 5       9 4
+--R                 - 1292288a b c  - 256b c
+--R            *
+--R                22
+--R               x
+--R           + 
+--R                            5 8             4 2 7             3 4 6
+--R                 - 88080384a c  - 545857536a b c  - 290877440a b c
+--R               + 
+--R                            2 6 5          8 4       10 3
+--R                 - 22134784a b c  - 2304a b c  + 288b  c
+--R            *
+--R                20
+--R               x
+--R           + 
+--R                             5   7             4 3 6             3 5 5
+--R                 - 637091840a b c  - 903024640a b c  - 149940224a b c
+--R               + 
+--R                      2 7 4          9 3       11 2
+--R                 1536a b c  + 1984a b c  - 336b  c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                             6 7              5 2 6             4 4 5
+--R                 - 266076160a c  - 1413672960a b c  - 514698240a b c
+--R               + 
+--R                       3 6 4         2 8 3         10 2       12
+--R                 53760a b c  - 17280a b c  - 560a b  c  + 420b  c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                              6   6             5 3 5          4 5 4
+--R                 - 1090396160a b c  - 985169920a b c  - 483840a b c
+--R               + 
+--R                         3 7 3         2 9 2          11        13
+--R                 - 46080a b c  + 70560a b c  - 6720a b  c - 630b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                             7 6              6 2 5           5 4 4
+--R                 - 330301440a c  - 1060577280a b c  - 1505280a b c
+--R               + 
+--R                           4 6 3           3 8 2         2 10            12
+--R                 - 7375872a b c  + 2546432a b c  + 23520a b  c - 52920a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                             7   5            6 3 4            5 5 3
+--R                 - 603258880a b c  + 39567360a b c  - 49373184a b c
+--R               + 
+--R                         4 7 2           3 9           2 11
+--R                 5146624a b c  + 3951360a b c - 705600a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                             8 5             7 2 4            6 4 3
+--R                 - 146800640a c  + 103219200a b c  - 56770560a b c
+--R               + 
+--R                            5 6 2            4 8            3 10
+--R                 - 45158400a b c  + 26772480a b c - 3386880a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          8   4            7 3 3             6 5 2
+--R                 59637760a b c  + 80281600a b c  - 167444480a b c
+--R               + 
+--R                          5 7            4 9
+--R                 64942080a b c - 7257600a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                        8 2 3             7 4 2            6 6            5 8  4
+--R             (151388160a b c  - 189235200a b c  + 66232320a b c - 7096320a b )x
+--R           + 
+--R                       9   3            8 3 2            7 5            6 7  2
+--R             (55050240a b c  - 68812800a b c  + 24084480a b c - 2580480a b )x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                      3 10           2 2 9             4 8          6 7  28
+--R             (1310720a c   + 6881280a b c  + 2867200a b c  + 143360b c )x
+--R           + 
+--R                       3   9            2 3 8              5 7          7 6  26
+--R             (34406400a b c  + 52183040a b c  + 11038720a b c  + 322560b c )x
+--R           + 
+--R                          4 9             3 2 8             2 4 7
+--R                 34865152a c  + 231899136a b c  + 140091392a b c
+--R               + 
+--R                            6 6          8 5
+--R                 14350336a b c  + 182784b c
+--R            *
+--R                24
+--R               x
+--R           + 
+--R                           4   8             3 3 7             2 5 6
+--R                 366198784a b c  + 631873536a b c  + 160161792a b c
+--R               + 
+--R                           7 5       9 4
+--R                 6268416a b c  - 448b c
+--R            *
+--R                22
+--R               x
+--R           + 
+--R                           5 8              4 2 7             3 4 6
+--R                 189005824a c  + 1274699776a b c  + 756224000a b c
+--R               + 
+--R                          2 6 5          8 4       10 3
+--R                 66433024a b c  - 5376a b c  + 672b  c
+--R            *
+--R                20
+--R               x
+--R           + 
+--R                            5   7              4 3 6             3 5 5
+--R                 1183293440a b c  + 1812285440a b c  + 330781696a b c
+--R               + 
+--R                      2 7 4          9 3        11 2
+--R                 5376a b c  + 6944a b c  - 1176b  c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                           6 7              5 2 6             4 4 5
+--R                 412876800a c  + 2325442560a b c  + 906644480a b c
+--R               + 
+--R                        3 6 4          2 8 3          10 2        12
+--R                 376320a b c  - 120960a b c  - 3920a b  c  + 2940b  c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                            6   6              5 3 5            4 5 4
+--R                 1524490240a b c  + 1442918400a b c  + 10547712a b c
+--R               + 
+--R                        3 7 3           2 9 2            11         13
+--R                 114176a b c  - 1240288a b c  + 146160a b  c + 8190b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                           7 6              6 2 5           5 4 4
+--R                 403701760a c  + 1315758080a b c  + 8816640a b c
+--R               + 
+--R                          4 6 3            3 8 2         2 10             12
+--R                 33567744a b c  - 12018944a b c  + 23520a b  c + 229320a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           7   5             6 3 4             5 5 3
+--R                 653721600a b c  - 104939520a b c  + 132808704a b c
+--R               + 
+--R                            4 7 2            3 9            2 11
+--R                 - 15110144a b c  - 10080000a b c + 1834560a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           8 5             7 2 4             6 4 3
+--R                 146800640a c  - 194969600a b c  + 109527040a b c
+--R               + 
+--R                          5 6 2            4 8            3 10
+--R                 82432000a b c  - 49566720a b c + 6289920a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            8   4             7 3 3             6 5 2
+--R                 - 87162880a b c  - 114688000a b c  + 241418240a b c
+--R               + 
+--R                            5 7             4 9
+--R                 - 93757440a b c + 10483200a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                               8 2 3             7 4 2            6 6
+--R                   - 178913280a b c  + 223641600a b c  - 78274560a b c
+--R                 + 
+--R                           5 8
+--R                   8386560a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       9   3            8 3 2            7 5            6 7  2
+--R           (- 55050240a b c  + 68812800a b c  - 24084480a b c + 2580480a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                       3 8            2 2 7              4 6           6 5  12
+--R             (18350080a c  + 96337920a b c  + 40140800a b c  + 2007040b c )x
+--R           + 
+--R                        3   7             2 3 6              5 5  10
+--R             (440401920a b c  + 513802240a b c  + 64225280a b c )x
+--R           + 
+--R                        4 7              3 2 6             2 4 5  8
+--R             (440401920a c  + 1981808640a b c  + 578027520a b c )x
+--R           + 
+--R                         4   6              3 3 5  6
+--R             (2936012800a b c  + 2202009600a b c )x
+--R           + 
+--R                         5 6              4 2 5  4              5   5 2
+--R             (1468006400a c  + 4037017600a b c )x  + 3523215360a b c x
+--R           + 
+--R                        6 5
+--R             1174405120a c
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                           3   8            2 3 7              5 6          7 5
+--R               (- 64225280a b c  - 80281600a b c  - 12042240a b c  - 143360b c )
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                             4 8             3 2 7             2 4 6
+--R                 - 128450560a c  - 674365440a b c  - 280985600a b c
+--R               + 
+--R                              6 5
+--R                 - 14049280a b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           4   7              3 3 6             2 5 5  10
+--R             (- 1541406720a b c  - 1798307840a b c  - 224788480a b c )x
+--R           + 
+--R                           5 7              4 2 6              3 4 5  8
+--R             (- 1027604480a c  - 4624220160a b c  - 1348730880a b c )x
+--R           + 
+--R                           5   6              4 3 5  6
+--R             (- 5138022400a b c  - 3853516800a b c )x
+--R           + 
+--R                           6 6              5 2 5  4              6   5 2
+--R             (- 2055208960a c  - 5651824640a b c )x  - 4110417920a b c x
+--R           + 
+--R                          7 5
+--R             - 1174405120a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                            6   6           5 3 5           4 5 4          3 7 3
+--R                     860160a b c  + 3440640a b c  - 3386880a b c  - 322560a b c
+--R                   + 
+--R                            2 9 2           11         13
+--R                     493920a b c  - 47040a b  c - 4410b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                              6 2 5           5 4 4            4 6 3
+--R                     20643840a b c  - 1720320a b c  - 18063360a b c
+--R                   + 
+--R                             3 8 2          2 10             12
+--R                     5806080a b c  + 188160a b  c - 141120a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              7   5            6 3 4            5 5 3
+--R                     20643840a b c  + 67092480a b c  - 79994880a b c
+--R                   + 
+--R                             4 7 2           3 9            2 11
+--R                     5806080a b c  + 7499520a b c - 1270080a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                               7 2 4            6 4 3            5 6 2
+--R                     137625600a b c  - 68812800a b c  - 68812800a b c
+--R                   + 
+--R                              4 8            3 10
+--R                     38707200a b c - 4838400a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                              8   4             7 3 3             6 5 2
+--R                     68812800a b c  + 103219200a b c  - 206438400a b c
+--R                   + 
+--R                              5 7            4 9
+--R                     79564800a b c - 8870400a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                               8 2 3             7 4 2            6 6
+--R                     165150720a b c  - 206438400a b c  + 72253440a b c
+--R                   + 
+--R                               5 8
+--R                     - 7741440a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                          9   3            8 3 2            7 5            6 7
+--R                 55050240a b c  - 68812800a b c  + 24084480a b c - 2580480a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                           6 2 6           4 6 4          3 8 3         2 10 2
+--R                 - 3010560a b c  + 2822400a b c  - 806400a b c  - 62160a b  c
+--R               + 
+--R                         12        14
+--R                 23520a b  c + 315b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                           7   6            6 3 5            5 5 4
+--R                 - 6021120a b c  - 24084480a b c  + 23708160a b c
+--R               + 
+--R                         4 7 3           3 9 2          2 11            13
+--R                 2257920a b c  - 3457440a b c  + 329280a b  c + 30870a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            7 2 5           6 4 4            5 6 3
+--R                 - 72253440a b c  + 6021120a b c  + 63221760a b c
+--R               + 
+--R                            4 8 2          3 10           2 12
+--R                 - 20321280a b c  - 658560a b  c + 493920a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            8   5             7 3 4             6 5 3
+--R                 - 48168960a b c  - 156549120a b c  + 186654720a b c
+--R               + 
+--R                            5 7 2            4 9            3 11
+--R                 - 13547520a b c  - 17498880a b c + 2963520a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             8 2 4             7 4 3             6 6 2
+--R                 - 240844800a b c  + 120422400a b c  + 120422400a b c
+--R               + 
+--R                            5 8            4 10
+--R                 - 67737600a b c + 8467200a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            9   4             8 3 3             7 5 2
+--R                 - 96337920a b c  - 144506880a b c  + 289013760a b c
+--R               + 
+--R                             6 7             5 9
+--R                 - 111390720a b c + 12418560a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                               9 2 3             8 4 2            7 6
+--R                   - 192675840a b c  + 240844800a b c  - 84295680a b c
+--R                 + 
+--R                           6 8
+--R                   9031680a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        10   3            9 3 2            8 5            7 7
+--R             - 55050240a  b c  + 68812800a b c  - 24084480a b c + 2580480a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                        3   9           2 3 8            5 7        7 6  26
+--R             (- 2293760a b c  - 2867200a b c  - 430080a b c  - 5120b c )x
+--R           + 
+--R                           4 9            3 2 8            2 4 7             6 6
+--R                 - 4587520a c  - 26951680a b c  - 13619200a b c  - 1039360a b c
+--R               + 
+--R                        8 5
+--R                 - 6400b c
+--R            *
+--R                24
+--R               x
+--R           + 
+--R                            4   8            3 3 7            2 5 6
+--R                 - 64454656a b c  - 98975744a b c  - 21331968a b c
+--R               + 
+--R                            7 5       9 4
+--R                 - 646144a b c  - 128b c
+--R            *
+--R                22
+--R               x
+--R           + 
+--R                            5 8             4 2 7             3 4 6
+--R                 - 44040192a c  - 272928768a b c  - 145438720a b c
+--R               + 
+--R                            2 6 5          8 4       10 3
+--R                 - 11067392a b c  - 1152a b c  + 144b  c
+--R            *
+--R                20
+--R               x
+--R           + 
+--R                             5   7             4 3 6            3 5 5
+--R                 - 318545920a b c  - 451512320a b c  - 74970112a b c
+--R               + 
+--R                     2 7 4         9 3       11 2
+--R                 768a b c  + 992a b c  - 168b  c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                             6 7             5 2 6             4 4 5
+--R                 - 133038080a c  - 706836480a b c  - 257349120a b c
+--R               + 
+--R                       3 6 4        2 8 3         10 2       12
+--R                 26880a b c  - 8640a b c  - 280a b  c  + 210b  c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                             6   6             5 3 5          4 5 4
+--R                 - 545198080a b c  - 492584960a b c  - 241920a b c
+--R               + 
+--R                         3 7 3         2 9 2          11        13
+--R                 - 23040a b c  + 35280a b c  - 3360a b  c - 315b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                             7 6             6 2 5          5 4 4
+--R                 - 165150720a c  - 530288640a b c  - 752640a b c
+--R               + 
+--R                           4 6 3           3 8 2         2 10            12
+--R                 - 3687936a b c  + 1273216a b c  + 11760a b  c - 26460a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                             7   5            6 3 4            5 5 3
+--R                 - 301629440a b c  + 19783680a b c  - 24686592a b c
+--R               + 
+--R                         4 7 2           3 9           2 11
+--R                 2573312a b c  + 1975680a b c - 352800a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            8 5            7 2 4            6 4 3
+--R                 - 73400320a c  + 51609600a b c  - 28385280a b c
+--R               + 
+--R                            5 6 2            4 8            3 10
+--R                 - 22579200a b c  + 13386240a b c - 1693440a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          8   4            7 3 3            6 5 2
+--R                 29818880a b c  + 40140800a b c  - 83722240a b c
+--R               + 
+--R                          5 7            4 9
+--R                 32471040a b c - 3628800a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                       8 2 3            7 4 2            6 6            5 8  4
+--R             (75694080a b c  - 94617600a b c  + 33116160a b c - 3548160a b )x
+--R           + 
+--R                       9   3            8 3 2            7 5            6 7  2
+--R             (27525120a b c  - 34406400a b c  + 12042240a b c - 1290240a b )x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                     3 10           2 2 9             4 8         6 7  28
+--R             (655360a c   + 3440640a b c  + 1433600a b c  + 71680b c )x
+--R           + 
+--R                       3   9            2 3 8             5 7          7 6  26
+--R             (17203200a b c  + 26091520a b c  + 5519360a b c  + 161280b c )x
+--R           + 
+--R                          4 9             3 2 8            2 4 7             6 6
+--R                 17432576a c  + 115949568a b c  + 70045696a b c  + 7175168a b c
+--R               + 
+--R                       8 5
+--R                 91392b c
+--R            *
+--R                24
+--R               x
+--R           + 
+--R                           4   8             3 3 7            2 5 6
+--R                 183099392a b c  + 315936768a b c  + 80080896a b c
+--R               + 
+--R                           7 5       9 4
+--R                 3134208a b c  - 224b c
+--R            *
+--R                22
+--R               x
+--R           + 
+--R                          5 8             4 2 7             3 4 6
+--R                 94502912a c  + 637349888a b c  + 378112000a b c
+--R               + 
+--R                          2 6 5          8 4       10 3
+--R                 33216512a b c  - 2688a b c  + 336b  c
+--R            *
+--R                20
+--R               x
+--R           + 
+--R                           5   7             4 3 6             3 5 5
+--R                 591646720a b c  + 906142720a b c  + 165390848a b c
+--R               + 
+--R                      2 7 4          9 3       11 2
+--R                 2688a b c  + 3472a b c  - 588b  c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                           6 7              5 2 6             4 4 5
+--R                 206438400a c  + 1162721280a b c  + 453322240a b c
+--R               + 
+--R                        3 6 4         2 8 3          10 2        12
+--R                 188160a b c  - 60480a b c  - 1960a b  c  + 1470b  c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                           6   6             5 3 5           4 5 4         3 7 3
+--R                 762245120a b c  + 721459200a b c  + 5273856a b c  + 57088a b c
+--R               + 
+--R                          2 9 2           11         13
+--R                 - 620144a b c  + 73080a b  c + 4095b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                           7 6             6 2 5           5 4 4
+--R                 201850880a c  + 657879040a b c  + 4408320a b c
+--R               + 
+--R                          4 6 3           3 8 2         2 10             12
+--R                 16783872a b c  - 6009472a b c  + 11760a b  c + 114660a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           7   5            6 3 4            5 5 3
+--R                 326860800a b c  - 52469760a b c  + 66404352a b c
+--R               + 
+--R                           4 7 2           3 9           2 11
+--R                 - 7555072a b c  - 5040000a b c + 917280a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          8 5            7 2 4            6 4 3            5 6 2
+--R                 73400320a c  - 97484800a b c  + 54763520a b c  + 41216000a b c
+--R               + 
+--R                            4 8            3 10
+--R                 - 24783360a b c + 3144960a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            8   4            7 3 3             6 5 2
+--R                 - 43581440a b c  - 57344000a b c  + 120709120a b c
+--R               + 
+--R                            5 7            4 9
+--R                 - 46878720a b c + 5241600a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                              8 2 3             7 4 2            6 6
+--R                   - 89456640a b c  + 111820800a b c  - 39137280a b c
+--R                 + 
+--R                           5 8
+--R                   4193280a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       9   3            8 3 2            7 5            6 7  2
+--R           (- 27525120a b c  + 34406400a b c  - 12042240a b c + 1290240a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                      3 8            2 2 7              4 6           6 5  12
+--R             (9175040a c  + 48168960a b c  + 20070400a b c  + 1003520b c )x
+--R           + 
+--R                        3   7             2 3 6              5 5  10
+--R             (220200960a b c  + 256901120a b c  + 32112640a b c )x
+--R           + 
+--R                        4 7             3 2 6             2 4 5  8
+--R             (220200960a c  + 990904320a b c  + 289013760a b c )x
+--R           + 
+--R                         4   6              3 3 5  6
+--R             (1468006400a b c  + 1101004800a b c )x
+--R           + 
+--R                        5 6              4 2 5  4              5   5 2
+--R             (734003200a c  + 2018508800a b c )x  + 1761607680a b c x
+--R           + 
+--R                       6 5
+--R             587202560a c
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                         3   8            2 3 7             5 6         7 5  14
+--R             (- 32112640a b c  - 40140800a b c  - 6021120a b c  - 71680b c )x
+--R           + 
+--R                            4 8             3 2 7             2 4 6
+--R                 - 64225280a c  - 337182720a b c  - 140492800a b c
+--R               + 
+--R                             6 5
+--R                 - 7024640a b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          4   7             3 3 6             2 5 5  10
+--R             (- 770703360a b c  - 899153920a b c  - 112394240a b c )x
+--R           + 
+--R                          5 7              4 2 6             3 4 5  8
+--R             (- 513802240a c  - 2312110080a b c  - 674365440a b c )x
+--R           + 
+--R                           5   6              4 3 5  6
+--R             (- 2569011200a b c  - 1926758400a b c )x
+--R           + 
+--R                           6 6              5 2 5  4              6   5 2
+--R             (- 1027604480a c  - 2825912320a b c )x  - 2055208960a b c x
+--R           + 
+--R                         7 5
+--R             - 587202560a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1321
+
+--S 1322 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          6   6           5 3 5           4 5 4          3 7 3
+--R                   860160a b c  + 3440640a b c  - 3386880a b c  - 322560a b c
+--R                 + 
+--R                          2 9 2           11         13
+--R                   493920a b c  - 47040a b  c - 4410b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                            6 2 5           5 4 4            4 6 3
+--R                   20643840a b c  - 1720320a b c  - 18063360a b c
+--R                 + 
+--R                           3 8 2          2 10             12
+--R                   5806080a b c  + 188160a b  c - 141120a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            7   5            6 3 4            5 5 3
+--R                   20643840a b c  + 67092480a b c  - 79994880a b c
+--R                 + 
+--R                           4 7 2           3 9            2 11
+--R                   5806080a b c  + 7499520a b c - 1270080a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             7 2 4            6 4 3            5 6 2
+--R                   137625600a b c  - 68812800a b c  - 68812800a b c
+--R                 + 
+--R                            4 8            3 10
+--R                   38707200a b c - 4838400a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            8   4             7 3 3             6 5 2
+--R                   68812800a b c  + 103219200a b c  - 206438400a b c
+--R                 + 
+--R                            5 7            4 9
+--R                   79564800a b c - 8870400a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               8 2 3             7 4 2            6 6
+--R                     165150720a b c  - 206438400a b c  + 72253440a b c
+--R                   + 
+--R                               5 8
+--R                     - 7741440a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        9   3            8 3 2            7 5            6 7
+--R               55050240a b c  - 68812800a b c  + 24084480a b c - 2580480a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                         6 2 6           4 6 4          3 8 3         2 10 2
+--R               - 3010560a b c  + 2822400a b c  - 806400a b c  - 62160a b  c
+--R             + 
+--R                       12        14
+--R               23520a b  c + 315b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                         7   6            6 3 5            5 5 4           4 7 3
+--R               - 6021120a b c  - 24084480a b c  + 23708160a b c  + 2257920a b c
+--R             + 
+--R                         3 9 2          2 11            13
+--R               - 3457440a b c  + 329280a b  c + 30870a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          7 2 5           6 4 4            5 6 3
+--R               - 72253440a b c  + 6021120a b c  + 63221760a b c
+--R             + 
+--R                          4 8 2          3 10           2 12
+--R               - 20321280a b c  - 658560a b  c + 493920a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          8   5             7 3 4             6 5 3
+--R               - 48168960a b c  - 156549120a b c  + 186654720a b c
+--R             + 
+--R                          5 7 2            4 9            3 11
+--R               - 13547520a b c  - 17498880a b c + 2963520a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                           8 2 4             7 4 3             6 6 2
+--R               - 240844800a b c  + 120422400a b c  + 120422400a b c
+--R             + 
+--R                          5 8            4 10
+--R               - 67737600a b c + 8467200a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          9   4             8 3 3             7 5 2
+--R               - 96337920a b c  - 144506880a b c  + 289013760a b c
+--R             + 
+--R                           6 7             5 9
+--R               - 111390720a b c + 12418560a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        9 2 3             8 4 2            7 6            6 8  2
+--R           (- 192675840a b c  + 240844800a b c  - 84295680a b c + 9031680a b )x
+--R         + 
+--R                      10   3            9 3 2            8 5            7 7
+--R           - 55050240a  b c  + 68812800a b c  - 24084480a b c + 2580480a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                            6   6           5 3 5           4 5 4          3 7 3
+--R                   - 860160a b c  - 3440640a b c  + 3386880a b c  + 322560a b c
+--R                 + 
+--R                            2 9 2           11         13
+--R                   - 493920a b c  + 47040a b  c + 4410b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                              6 2 5           5 4 4            4 6 3
+--R                   - 20643840a b c  + 1720320a b c  + 18063360a b c
+--R                 + 
+--R                             3 8 2          2 10             12
+--R                   - 5806080a b c  - 188160a b  c + 141120a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              7   5            6 3 4            5 5 3
+--R                   - 20643840a b c  - 67092480a b c  + 79994880a b c
+--R                 + 
+--R                             4 7 2           3 9            2 11
+--R                   - 5806080a b c  - 7499520a b c + 1270080a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               7 2 4            6 4 3            5 6 2
+--R                   - 137625600a b c  + 68812800a b c  + 68812800a b c
+--R                 + 
+--R                              4 8            3 10
+--R                   - 38707200a b c + 4838400a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              8   4             7 3 3             6 5 2
+--R                   - 68812800a b c  - 103219200a b c  + 206438400a b c
+--R                 + 
+--R                              5 7            4 9
+--R                   - 79564800a b c + 8870400a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               8 2 3             7 4 2            6 6
+--R                   - 165150720a b c  + 206438400a b c  - 72253440a b c
+--R                 + 
+--R                           5 8
+--R                   7741440a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          9   3            8 3 2            7 5            6 7
+--R               - 55050240a b c  + 68812800a b c  - 24084480a b c + 2580480a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                       6 2 6           4 6 4          3 8 3         2 10 2
+--R               3010560a b c  - 2822400a b c  + 806400a b c  + 62160a b  c
+--R             + 
+--R                         12        14
+--R               - 23520a b  c - 315b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                       7   6            6 3 5            5 5 4           4 7 3
+--R               6021120a b c  + 24084480a b c  - 23708160a b c  - 2257920a b c
+--R             + 
+--R                       3 9 2          2 11            13
+--R               3457440a b c  - 329280a b  c - 30870a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        7 2 5           6 4 4            5 6 3            4 8 2
+--R               72253440a b c  - 6021120a b c  - 63221760a b c  + 20321280a b c
+--R             + 
+--R                      3 10           2 12
+--R               658560a b  c - 493920a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        8   5             7 3 4             6 5 3
+--R               48168960a b c  + 156549120a b c  - 186654720a b c
+--R             + 
+--R                        5 7 2            4 9            3 11
+--R               13547520a b c  + 17498880a b c - 2963520a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         8 2 4             7 4 3             6 6 2
+--R               240844800a b c  - 120422400a b c  - 120422400a b c
+--R             + 
+--R                        5 8            4 10
+--R               67737600a b c - 8467200a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        9   4             8 3 3             7 5 2
+--R               96337920a b c  + 144506880a b c  - 289013760a b c
+--R             + 
+--R                         6 7             5 9
+--R               111390720a b c - 12418560a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      9 2 3             8 4 2            7 6            6 8  2
+--R           (192675840a b c  - 240844800a b c  + 84295680a b c - 9031680a b )x
+--R         + 
+--R                    10   3            9 3 2            8 5            7 7
+--R           55050240a  b c  - 68812800a b c  + 24084480a b c - 2580480a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                        7 6           6 2 5           5 4 4          4 6 3
+--R               - 524288a c  - 1347584a b c  + 5583872a b c  - 290304a b c
+--R             + 
+--R                        3 8 2          2 10           12
+--R               - 834176a b c  + 105840a b  c + 8820a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          7   5            6 3 4            5 5 3
+--R               - 12582912a b c  + 19038208a b c  + 22020096a b c
+--R             + 
+--R                          4 7 2          2 11
+--R               - 11210752a b c  + 282240a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          8 5            7 2 4             6 4 3
+--R               - 12582912a c  - 22904832a b c  + 119734272a b c
+--R             + 
+--R                          5 6 2            4 8            3 10
+--R               - 23482368a b c  - 11612160a b c + 2540160a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                          8   4             7 3 3            6 5 2
+--R               - 83886080a b c  + 161873920a b c  + 65372160a b c
+--R             + 
+--R                          5 7            4 9
+--R               - 64512000a b c + 9676800a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          9 4           8 2 3             7 4 2             6 6
+--R               - 41943040a c  - 2949120a b c  + 257474560a b c  - 135475200a b c
+--R             + 
+--R                        5 8
+--R               17740800a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                             9   3             8 3 2             7 5
+--R                 - 100663296a b c  + 269746176a b c  - 123863040a b c
+--R               + 
+--R                          6 7
+--R                 15482880a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      10 3            9 2 2            8 4            7 6
+--R           - 33554432a  c  + 89915392a b c  - 41287680a b c + 5160960a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                       6   6           5 3 5           4 5 4           3 7 3
+--R               1835008a b c  - 2623488a b c  - 3544576a b c  + 1622272a b c
+--R             + 
+--R                     2 9 2           11        13
+--R               59584a b c  - 47880a b  c - 630b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                       7 6           6 2 5            5 4 4           4 6 3
+--R               3670016a c  + 9433088a b c  - 39087104a b c  + 2032128a b c
+--R             + 
+--R                       3 8 2          2 10            12
+--R               5839232a b c  - 740880a b  c - 61740a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        7   5            6 3 4            5 5 3            4 7 2
+--R               44040192a b c  - 66633728a b c  - 77070336a b c  + 39237632a b c
+--R             + 
+--R                        2 11
+--R               - 987840a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        8 5            7 2 4             6 4 3            5 6 2
+--R               29360128a c  + 53444608a b c  - 279379968a b c  + 54792192a b c
+--R             + 
+--R                        4 8            3 10
+--R               27095040a b c - 5927040a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         8   4             7 3 3             6 5 2
+--R               146800640a b c  - 283279360a b c  - 114401280a b c
+--R             + 
+--R                         5 7             4 9
+--R               112896000a b c - 16934400a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        9 4           8 2 3             7 4 2             6 6
+--R               58720256a c  + 4128768a b c  - 360464384a b c  + 189665280a b c
+--R             + 
+--R                          5 8
+--R               - 24837120a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      9   3             8 3 2             7 5             6 7  2
+--R           (117440512a b c  - 314703872a b c  + 144506880a b c - 18063360a b )x
+--R         + 
+--R                    10 3            9 2 2            8 4            7 6
+--R           33554432a  c  - 89915392a b c  + 41287680a b c - 5160960a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                     3 8            2 2 7              4 6           6 5  12
+--R           (18350080a c  + 96337920a b c  + 40140800a b c  + 2007040b c )x
+--R         + 
+--R                      3   7             2 3 6              5 5  10
+--R           (440401920a b c  + 513802240a b c  + 64225280a b c )x
+--R         + 
+--R                      4 7              3 2 6             2 4 5  8
+--R           (440401920a c  + 1981808640a b c  + 578027520a b c )x
+--R         + 
+--R                       4   6              3 3 5  6
+--R           (2936012800a b c  + 2202009600a b c )x
+--R         + 
+--R                       5 6              4 2 5  4              5   5 2
+--R           (1468006400a c  + 4037017600a b c )x  + 3523215360a b c x
+--R         + 
+--R                      6 5
+--R           1174405120a c
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                       3   8            2 3 7              5 6          7 5  14
+--R           (- 64225280a b c  - 80281600a b c  - 12042240a b c  - 143360b c )x
+--R         + 
+--R                           4 8             3 2 7             2 4 6
+--R               - 128450560a c  - 674365440a b c  - 280985600a b c
+--R             + 
+--R                            6 5
+--R               - 14049280a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         4   7              3 3 6             2 5 5  10
+--R           (- 1541406720a b c  - 1798307840a b c  - 224788480a b c )x
+--R         + 
+--R                         5 7              4 2 6              3 4 5  8
+--R           (- 1027604480a c  - 4624220160a b c  - 1348730880a b c )x
+--R         + 
+--R                         5   6              4 3 5  6
+--R           (- 5138022400a b c  - 3853516800a b c )x
+--R         + 
+--R                         6 6              5 2 5  4              6   5 2
+--R           (- 2055208960a c  - 5651824640a b c )x  - 4110417920a b c x
+--R         + 
+--R                        7 5
+--R           - 1174405120a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 1322
+
+--S 1323 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1323
+
+--S 1324 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                            6   6           5 3 5           4 5 4          3 7 3
+--R                   - 860160a b c  - 3440640a b c  + 3386880a b c  + 322560a b c
+--R                 + 
+--R                            2 9 2           11         13
+--R                   - 493920a b c  + 47040a b  c + 4410b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                              6 2 5           5 4 4            4 6 3
+--R                   - 20643840a b c  + 1720320a b c  + 18063360a b c
+--R                 + 
+--R                             3 8 2          2 10             12
+--R                   - 5806080a b c  - 188160a b  c + 141120a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              7   5            6 3 4            5 5 3
+--R                   - 20643840a b c  - 67092480a b c  + 79994880a b c
+--R                 + 
+--R                             4 7 2           3 9            2 11
+--R                   - 5806080a b c  - 7499520a b c + 1270080a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               7 2 4            6 4 3            5 6 2
+--R                   - 137625600a b c  + 68812800a b c  + 68812800a b c
+--R                 + 
+--R                              4 8            3 10
+--R                   - 38707200a b c + 4838400a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              8   4             7 3 3             6 5 2
+--R                   - 68812800a b c  - 103219200a b c  + 206438400a b c
+--R                 + 
+--R                              5 7            4 9
+--R                   - 79564800a b c + 8870400a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               8 2 3             7 4 2            6 6
+--R                   - 165150720a b c  + 206438400a b c  - 72253440a b c
+--R                 + 
+--R                           5 8
+--R                   7741440a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          9   3            8 3 2            7 5            6 7
+--R               - 55050240a b c  + 68812800a b c  - 24084480a b c + 2580480a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                           6 2 6           4 6 4          3 8 3         2 10 2
+--R                   3010560a b c  - 2822400a b c  + 806400a b c  + 62160a b  c
+--R                 + 
+--R                             12        14
+--R                   - 23520a b  c - 315b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                           7   6            6 3 5            5 5 4
+--R                   6021120a b c  + 24084480a b c  - 23708160a b c
+--R                 + 
+--R                             4 7 3           3 9 2          2 11            13
+--R                   - 2257920a b c  + 3457440a b c  - 329280a b  c - 30870a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                            7 2 5           6 4 4            5 6 3
+--R                   72253440a b c  - 6021120a b c  - 63221760a b c
+--R                 + 
+--R                            4 8 2          3 10           2 12
+--R                   20321280a b c  + 658560a b  c - 493920a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            8   5             7 3 4             6 5 3
+--R                   48168960a b c  + 156549120a b c  - 186654720a b c
+--R                 + 
+--R                            5 7 2            4 9            3 11
+--R                   13547520a b c  + 17498880a b c - 2963520a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             8 2 4             7 4 3             6 6 2
+--R                   240844800a b c  - 120422400a b c  - 120422400a b c
+--R                 + 
+--R                            5 8            4 10
+--R                   67737600a b c - 8467200a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            9   4             8 3 3             7 5 2
+--R                   96337920a b c  + 144506880a b c  - 289013760a b c
+--R                 + 
+--R                             6 7             5 9
+--R                   111390720a b c - 12418560a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               9 2 3             8 4 2            7 6
+--R                     192675840a b c  - 240844800a b c  + 84295680a b c
+--R                   + 
+--R                               6 8
+--R                     - 9031680a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        10   3            9 3 2            8 5            7 7
+--R               55050240a  b c  - 68812800a b c  + 24084480a b c - 2580480a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                           6   6           5 3 5           4 5 4          3 7 3
+--R                   1720320a b c  + 6881280a b c  - 6773760a b c  - 645120a b c
+--R                 + 
+--R                          2 9 2           11         13
+--R                   987840a b c  - 94080a b  c - 8820b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                            6 2 5           5 4 4            4 6 3
+--R                   41287680a b c  - 3440640a b c  - 36126720a b c
+--R                 + 
+--R                            3 8 2          2 10             12
+--R                   11612160a b c  + 376320a b  c - 282240a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            7   5             6 3 4             5 5 3
+--R                   41287680a b c  + 134184960a b c  - 159989760a b c
+--R                 + 
+--R                            4 7 2            3 9            2 11
+--R                   11612160a b c  + 14999040a b c - 2540160a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             7 2 4             6 4 3             5 6 2
+--R                   275251200a b c  - 137625600a b c  - 137625600a b c
+--R                 + 
+--R                            4 8            3 10
+--R                   77414400a b c - 9676800a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             8   4             7 3 3             6 5 2
+--R                   137625600a b c  + 206438400a b c  - 412876800a b c
+--R                 + 
+--R                             5 7             4 9
+--R                   159129600a b c - 17740800a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             8 2 3             7 4 2             6 6
+--R                   330301440a b c  - 412876800a b c  + 144506880a b c
+--R                 + 
+--R                              5 8
+--R                   - 15482880a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         9   3             8 3 2            7 5            6 7
+--R               110100480a b c  - 137625600a b c  + 48168960a b c - 5160960a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                             6 2 6           4 6 4           3 8 3
+--R                   - 6021120a b c  + 5644800a b c  - 1612800a b c
+--R                 + 
+--R                            2 10 2           12        14
+--R                   - 124320a b  c  + 47040a b  c + 630b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                              7   6            6 3 5            5 5 4
+--R                   - 12042240a b c  - 48168960a b c  + 47416320a b c
+--R                 + 
+--R                           4 7 3           3 9 2          2 11            13
+--R                   4515840a b c  - 6914880a b c  + 658560a b  c + 61740a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                               7 2 5            6 4 4             5 6 3
+--R                   - 144506880a b c  + 12042240a b c  + 126443520a b c
+--R                 + 
+--R                              4 8 2           3 10           2 12
+--R                   - 40642560a b c  - 1317120a b  c + 987840a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              8   5             7 3 4             6 5 3
+--R                   - 96337920a b c  - 313098240a b c  + 373309440a b c
+--R                 + 
+--R                              5 7 2            4 9            3 11
+--R                   - 27095040a b c  - 34997760a b c + 5927040a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               8 2 4             7 4 3             6 6 2
+--R                   - 481689600a b c  + 240844800a b c  + 240844800a b c
+--R                 + 
+--R                               5 8             4 10
+--R                   - 135475200a b c + 16934400a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                               9   4             8 3 3             7 5 2
+--R                   - 192675840a b c  - 289013760a b c  + 578027520a b c
+--R                 + 
+--R                               6 7             5 9
+--R                   - 222781440a b c + 24837120a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               9 2 3             8 4 2             7 6
+--R                   - 385351680a b c  + 481689600a b c  - 168591360a b c
+--R                 + 
+--R                            6 8
+--R                   18063360a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         10   3             9 3 2            8 5            7 7
+--R             - 110100480a  b c  + 137625600a b c  - 48168960a b c + 5160960a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                        7 6           6 2 5           5 4 4          4 6 3
+--R               - 524288a c  - 1347584a b c  + 5583872a b c  - 290304a b c
+--R             + 
+--R                        3 8 2          2 10           12
+--R               - 834176a b c  + 105840a b  c + 8820a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          7   5            6 3 4            5 5 3
+--R               - 12582912a b c  + 19038208a b c  + 22020096a b c
+--R             + 
+--R                          4 7 2          2 11
+--R               - 11210752a b c  + 282240a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          8 5            7 2 4             6 4 3
+--R               - 12582912a c  - 22904832a b c  + 119734272a b c
+--R             + 
+--R                          5 6 2            4 8            3 10
+--R               - 23482368a b c  - 11612160a b c + 2540160a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                          8   4             7 3 3            6 5 2
+--R               - 83886080a b c  + 161873920a b c  + 65372160a b c
+--R             + 
+--R                          5 7            4 9
+--R               - 64512000a b c + 9676800a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          9 4           8 2 3             7 4 2             6 6
+--R               - 41943040a c  - 2949120a b c  + 257474560a b c  - 135475200a b c
+--R             + 
+--R                        5 8
+--R               17740800a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                             9   3             8 3 2             7 5
+--R                 - 100663296a b c  + 269746176a b c  - 123863040a b c
+--R               + 
+--R                          6 7
+--R                 15482880a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      10 3            9 2 2            8 4            7 6
+--R           - 33554432a  c  + 89915392a b c  - 41287680a b c + 5160960a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                       6   6           5 3 5           4 5 4           3 7 3
+--R               1835008a b c  - 2623488a b c  - 3544576a b c  + 1622272a b c
+--R             + 
+--R                     2 9 2           11        13
+--R               59584a b c  - 47880a b  c - 630b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                       7 6           6 2 5            5 4 4           4 6 3
+--R               3670016a c  + 9433088a b c  - 39087104a b c  + 2032128a b c
+--R             + 
+--R                       3 8 2          2 10            12
+--R               5839232a b c  - 740880a b  c - 61740a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        7   5            6 3 4            5 5 3            4 7 2
+--R               44040192a b c  - 66633728a b c  - 77070336a b c  + 39237632a b c
+--R             + 
+--R                        2 11
+--R               - 987840a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        8 5            7 2 4             6 4 3            5 6 2
+--R               29360128a c  + 53444608a b c  - 279379968a b c  + 54792192a b c
+--R             + 
+--R                        4 8            3 10
+--R               27095040a b c - 5927040a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         8   4             7 3 3             6 5 2
+--R               146800640a b c  - 283279360a b c  - 114401280a b c
+--R             + 
+--R                         5 7             4 9
+--R               112896000a b c - 16934400a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        9 4           8 2 3             7 4 2             6 6
+--R               58720256a c  + 4128768a b c  - 360464384a b c  + 189665280a b c
+--R             + 
+--R                          5 8
+--R               - 24837120a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      9   3             8 3 2             7 5             6 7  2
+--R           (117440512a b c  - 314703872a b c  + 144506880a b c - 18063360a b )x
+--R         + 
+--R                    10 3            9 2 2            8 4            7 6
+--R           33554432a  c  - 89915392a b c  + 41287680a b c - 5160960a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                     3 8            2 2 7              4 6           6 5  12
+--R           (18350080a c  + 96337920a b c  + 40140800a b c  + 2007040b c )x
+--R         + 
+--R                      3   7             2 3 6              5 5  10
+--R           (440401920a b c  + 513802240a b c  + 64225280a b c )x
+--R         + 
+--R                      4 7              3 2 6             2 4 5  8
+--R           (440401920a c  + 1981808640a b c  + 578027520a b c )x
+--R         + 
+--R                       4   6              3 3 5  6
+--R           (2936012800a b c  + 2202009600a b c )x
+--R         + 
+--R                       5 6              4 2 5  4              5   5 2
+--R           (1468006400a c  + 4037017600a b c )x  + 3523215360a b c x
+--R         + 
+--R                      6 5
+--R           1174405120a c
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                       3   8            2 3 7              5 6          7 5  14
+--R           (- 64225280a b c  - 80281600a b c  - 12042240a b c  - 143360b c )x
+--R         + 
+--R                           4 8             3 2 7             2 4 6
+--R               - 128450560a c  - 674365440a b c  - 280985600a b c
+--R             + 
+--R                            6 5
+--R               - 14049280a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         4   7              3 3 6             2 5 5  10
+--R           (- 1541406720a b c  - 1798307840a b c  - 224788480a b c )x
+--R         + 
+--R                         5 7              4 2 6              3 4 5  8
+--R           (- 1027604480a c  - 4624220160a b c  - 1348730880a b c )x
+--R         + 
+--R                         5   6              4 3 5  6
+--R           (- 5138022400a b c  - 3853516800a b c )x
+--R         + 
+--R                         6 6              5 2 5  4              6   5 2
+--R           (- 2055208960a c  - 5651824640a b c )x  - 4110417920a b c x
+--R         + 
+--R                        7 5
+--R           - 1174405120a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 1324
+
+--S 1325 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1325
+
+)clear all
+
+--S 1326 of 1353
+t0:=x^5*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                             +---------------+
+--R            9      7      5  |   4      2
+--R   (1)  (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1326
+
+--S 1327 of 1353
+r0:=1/384*(7*b^2-4*a*c)*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^3-7/120*b*_
+   (a+b*x^2+c*x^4)^(5/2)/c^2+1/12*x^2*(a+b*x^2+c*x^4)^(5/2)/c+1/2048*_
+   (b^2-4*a*c)^2*(7*b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/c^(9/2)-1/1024*(b^2-4*a*c)*(7*b^2-4*a*c)*_
+   (b+2*c*x^2)*sqrt(a+b*x^2+c*x^4)/c^4
+--R 
+--R
+--R   (2)
+--R                                                                   2
+--R              3 3        2 2 2         4        6              2c x  + b
+--R       (- 960a c  + 2160a b c  - 900a b c + 105b )atanh(-----------------------)
+--R                                                              +---------------+
+--R                                                          +-+ |   4      2
+--R                                                        2\|c \|c x  + b x  + a
+--R     + 
+--R                5 10          4 8           4      2 3  6
+--R           2560c x   + 3328b c x  + (4480a c  + 96b c )x
+--R         + 
+--R                    3       3 2  4        2 3         2 2       4   2
+--R           (576a b c  - 112b c )x  + (960a c  - 864a b c  + 140b c)x
+--R         + 
+--R                  2   2          3        5
+--R           - 2592a b c  + 1520a b c - 210b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R           4 +-+
+--R     30720c \|c
+--R                                                    Type: Expression(Integer)
+--E 1327
+
+--S 1328 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     184320a b c  - 261120a b c  - 161280a b c  + 97920a b c
+--R                   + 
+--R                              9         11
+--R                     - 6000a b c - 1260b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                            6 5          5 2 4           4 4 3          3 6 2
+--R                     368640a c  + 460800a b c  - 2288640a b c  + 564480a b c
+--R                   + 
+--R                            2 8            10
+--R                     110880a b c - 29400a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                             6   4           5 3 3           4 5 2
+--R                     2949120a b c  - 4915200a b c  - 1105920a b c
+--R                   + 
+--R                             3 7           2 9
+--R                     1290240a b c - 188160a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                          7 4           5 4 2           4 6           3 8  4
+--R                 (1966080a c  - 8110080a b c  + 3932160a b c - 483840a b )x
+--R               + 
+--R                          7   3            6 3 2           5 5           4 7  2
+--R                 (4915200a b c  - 11059200a b c  + 4608000a b c - 537600a b )x
+--R               + 
+--R                         8 3           7 2 2           6 4           5 6
+--R                 1966080a c  - 4423680a b c  + 1843200a b c - 215040a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                         6 6         5 2 5          4 4 4         3 6 3
+--R                 - 61440a c  - 92160a b c  + 403200a b c  - 80640a b c
+--R               + 
+--R                         2 8 2          10        12
+--R                 - 26640a b c  + 5400a b  c + 105b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           6   5           5 3 4          4 5 3          3 7 2
+--R                 - 1105920a b c  + 1566720a b c  + 967680a b c  - 587520a b c
+--R               + 
+--R                       2 9           11
+--R                 36000a b c + 7560a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           7 5           6 2 4           5 4 3           4 6 2
+--R                 - 1105920a c  - 1382400a b c  + 6865920a b c  - 1693440a b c
+--R               + 
+--R                          3 8          2 10
+--R                 - 332640a b c + 88200a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                           7   4           6 3 3           5 5 2           4 7
+--R                 - 5898240a b c  + 9830400a b c  + 2211840a b c  - 2580480a b c
+--R               + 
+--R                        3 9
+--R                 376320a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                        8 4            6 4 2           5 6           4 8  4
+--R             (- 2949120a c  + 12165120a b c  - 5898240a b c + 725760a b )x
+--R           + 
+--R                        8   3            7 3 2           6 5           5 7  2
+--R             (- 5898240a b c  + 13271040a b c  - 5529600a b c + 645120a b )x
+--R           + 
+--R                       9 3           8 2 2           7 4           6 6
+--R             - 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                       3 8          2 2 7            4 6        6 5  22
+--R             (- 163840a c  - 614400a b c  - 153600a b c  - 2560b c )x
+--R           + 
+--R                        3   7           2 3 6            5 5        7 4  20
+--R             (- 3162112a b c  - 3256320a b c  - 384000a b c  - 3328b c )x
+--R           + 
+--R                           4 7            3 2 6           2 4 5            6 4
+--R                 - 3235840a c  - 15237120a b c  - 5637120a b c  - 249856a b c
+--R               + 
+--R                      8 3
+--R                 - 96b c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                            4   6            3 3 5           2 5 4         7 3
+--R                 - 24760320a b c  - 27136000a b c  - 3217920a b c  - 768a b c
+--R               + 
+--R                     9 2
+--R                 112b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                            5 6            4 2 5            3 4 4        2 6 3
+--R                 - 13086720a c  - 57154560a b c  - 16360960a b c  + 2688a b c
+--R               + 
+--R                       8 2       10
+--R                 528a b c  - 140b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                            5   5            4 3 4         3 5 3         2 7 2
+--R                 - 55080960a b c  - 41244160a b c  + 26880a b c  - 16320a b c
+--R               + 
+--R                        9        11
+--R                 1000a b c + 210b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            6 5            5 2 4           4 4 3          3 6 2
+--R                 - 20111360a c  - 55633920a b c  + 1090560a b c  - 296192a b c
+--R               + 
+--R                         2 8            10
+--R                 - 40800a b c + 12600a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            6   4           5 3 3          4 5 2          3 7
+--R                 - 40017920a b c  + 3440640a b c  + 537600a b c  - 788480a b c
+--R               + 
+--R                        2 9
+--R                 117600a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            7 4          6 2 3           5 4 2           4 6
+--R                 - 12124160a c  + 245760a b c  + 6205440a b c  - 3046400a b c
+--R               + 
+--R                        3 8
+--R                 376320a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                        7   3           6 3 2           5 5           4 7  4
+--R             (- 4423680a b c  + 9953280a b c  - 4147200a b c + 483840a b )x
+--R           + 
+--R                        8 3           7 2 2           6 4           5 6  2
+--R             (- 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b )x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                     2   8            3 7         5 6  24
+--R             (491520a b c  + 409600a b c  + 30720b c )x
+--R           + 
+--R                     3 8           2 2 7             4 6         6 5  22
+--R             (983040a c  + 4571136a b c  + 1658880a b c  + 70656b c )x
+--R           + 
+--R                       3   7            2 3 6             5 5         7 4  20
+--R             (11476992a b c  + 14284800a b c  + 2280960a b c  + 41088b c )x
+--R           + 
+--R                         4 7            3 2 6            2 4 5             6 4
+--R                 7946240a c  + 42270720a b c  + 18462720a b c  + 1056768a b c
+--R               + 
+--R                       8 3
+--R                 - 192b c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                          4   6            3 3 5           2 5 4          7 3
+--R                 51056640a b c  + 62361600a b c  + 8501760a b c  - 2304a b c
+--R               + 
+--R                     9 2
+--R                 336b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                          5 6             4 2 5            3 4 4         2 6 3
+--R                 21749760a c  + 102389760a b c  + 31964160a b c  + 16128a b c
+--R               + 
+--R                        8 2       10
+--R                 3168a b c  - 840b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                          5   5            4 3 4          3 5 3          2 7 2
+--R                 81930240a b c  + 64094720a b c  - 341760a b c  + 254016a b c
+--R               + 
+--R                           9         11
+--R                 - 22200a b c - 2310b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          6 5            5 2 4           4 4 3           3 6 2
+--R                 25927680a c  + 73820160a b c  - 4254720a b c  + 1212672a b c
+--R               + 
+--R                        2 8            10
+--R                 133920a b c - 46200a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          6   4           5 3 3           4 5 2           3 7
+--R                 47800320a b c  - 7864320a b c  - 1059840a b c  + 1720320a b c
+--R               + 
+--R                          2 9
+--R                 - 258720a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          7 4          6 2 3           5 4 2           4 6
+--R                 13107200a c  - 491520a b c  - 9707520a b c  + 4782080a b c
+--R               + 
+--R                          3 8
+--R                 - 591360a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                      7   3            6 3 2           5 5           4 7  4
+--R             (5406720a b c  - 12165120a b c  + 5068800a b c - 591360a b )x
+--R           + 
+--R                      8 3           7 2 2           6 4           5 6  2
+--R             (1966080a c  - 4423680a b c  + 1843200a b c - 215040a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                      2   6             3 5          5 4  10
+--R             (5898240a b c  + 4915200a b c  + 368640b c )x
+--R           + 
+--R                       3 6            2 2 5             4 4  8
+--R             (11796480a c  + 41287680a b c  + 8601600a b c )x
+--R           + 
+--R                       3   5            2 3 4  6
+--R             (94371840a b c  + 55050240a b c )x
+--R           + 
+--R                     4 5             3 2 4  4             4   4 2            5 4
+--R           (62914560a c  + 141557760a b c )x  + 157286400a b c x  + 62914560a c
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                        3 7           2 2 6             4 5         6 4  12
+--R             (- 1966080a c  - 7372800a b c  - 1843200a b c  - 30720b c )x
+--R           + 
+--R                         3   6            2 3 5             5 4  10
+--R             (- 35389440a b c  - 29491200a b c  - 2211840a b c )x
+--R           + 
+--R                         4 6             3 2 5            2 4 4  8
+--R             (- 35389440a c  - 123863040a b c  - 25804800a b c )x
+--R           + 
+--R                          4   5             3 3 4  6
+--R             (- 188743680a b c  - 110100480a b c )x
+--R           + 
+--R                         5 5             4 2 4  4             5   4 2
+--R             (- 94371840a c  - 212336640a b c )x  - 188743680a b c x
+--R           + 
+--R                        6 4
+--R             - 62914560a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                     - 184320a b c  + 261120a b c  + 161280a b c  - 97920a b c
+--R                   + 
+--R                            9         11
+--R                     6000a b c + 1260b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              6 5          5 2 4           4 4 3          3 6 2
+--R                     - 368640a c  - 460800a b c  + 2288640a b c  - 564480a b c
+--R                   + 
+--R                              2 8            10
+--R                     - 110880a b c + 29400a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                               6   4           5 3 3           4 5 2
+--R                     - 2949120a b c  + 4915200a b c  + 1105920a b c
+--R                   + 
+--R                               3 7           2 9
+--R                     - 1290240a b c + 188160a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                            7 4           5 4 2           4 6           3 8  4
+--R                 (- 1966080a c  + 8110080a b c  - 3932160a b c + 483840a b )x
+--R               + 
+--R                                 7   3            6 3 2           5 5
+--R                       - 4915200a b c  + 11059200a b c  - 4608000a b c
+--R                     + 
+--R                              4 7
+--R                       537600a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                           8 3           7 2 2           6 4           5 6
+--R                 - 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                       6 6         5 2 5          4 4 4         3 6 3
+--R                 61440a c  + 92160a b c  - 403200a b c  + 80640a b c
+--R               + 
+--R                       2 8 2          10        12
+--R                 26640a b c  - 5400a b  c - 105b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                         6   5           5 3 4          4 5 3          3 7 2
+--R                 1105920a b c  - 1566720a b c  - 967680a b c  + 587520a b c
+--R               + 
+--R                         2 9           11
+--R                 - 36000a b c - 7560a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                         7 5           6 2 4           5 4 3           4 6 2
+--R                 1105920a c  + 1382400a b c  - 6865920a b c  + 1693440a b c
+--R               + 
+--R                        3 8          2 10
+--R                 332640a b c - 88200a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                         7   4           6 3 3           5 5 2           4 7
+--R                 5898240a b c  - 9830400a b c  - 2211840a b c  + 2580480a b c
+--R               + 
+--R                          3 9
+--R                 - 376320a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                      8 4            6 4 2           5 6           4 8  4
+--R             (2949120a c  - 12165120a b c  + 5898240a b c - 725760a b )x
+--R           + 
+--R                      8   3            7 3 2           6 5           5 7  2
+--R             (5898240a b c  - 13271040a b c  + 5529600a b c - 645120a b )x
+--R           + 
+--R                     9 3           8 2 2           7 4           6 6
+--R             1966080a c  - 4423680a b c  + 1843200a b c - 215040a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                      3 8          2 2 7           4 6        6 5  22
+--R             (- 81920a c  - 307200a b c  - 76800a b c  - 1280b c )x
+--R           + 
+--R                        3   7           2 3 6            5 5        7 4  20
+--R             (- 1581056a b c  - 1628160a b c  - 192000a b c  - 1664b c )x
+--R           + 
+--R                           4 7           3 2 6           2 4 5            6 4
+--R                 - 1617920a c  - 7618560a b c  - 2818560a b c  - 124928a b c
+--R               + 
+--R                      8 3
+--R                 - 48b c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                            4   6            3 3 5           2 5 4         7 3
+--R                 - 12380160a b c  - 13568000a b c  - 1608960a b c  - 384a b c
+--R               + 
+--R                    9 2
+--R                 56b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                           5 6            4 2 5           3 4 4        2 6 3
+--R                 - 6543360a c  - 28577280a b c  - 8180480a b c  + 1344a b c
+--R               + 
+--R                       8 2      10
+--R                 264a b c  - 70b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                            5   5            4 3 4         3 5 3        2 7 2
+--R                 - 27540480a b c  - 20622080a b c  + 13440a b c  - 8160a b c
+--R               + 
+--R                       9        11
+--R                 500a b c + 105b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            6 5            5 2 4          4 4 3          3 6 2
+--R                 - 10055680a c  - 27816960a b c  + 545280a b c  - 148096a b c
+--R               + 
+--R                         2 8           10
+--R                 - 20400a b c + 6300a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            6   4           5 3 3          4 5 2          3 7
+--R                 - 20008960a b c  + 1720320a b c  + 268800a b c  - 394240a b c
+--R               + 
+--R                       2 9
+--R                 58800a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                           7 4          6 2 3           5 4 2           4 6
+--R                 - 6062080a c  + 122880a b c  + 3102720a b c  - 1523200a b c
+--R               + 
+--R                        3 8
+--R                 188160a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                        7   3           6 3 2           5 5           4 7  4
+--R             (- 2211840a b c  + 4976640a b c  - 2073600a b c + 241920a b )x
+--R           + 
+--R                       8 3           7 2 2          6 4           5 6  2
+--R             (- 983040a c  + 2211840a b c  - 921600a b c + 107520a b )x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                     2   8            3 7         5 6  24
+--R             (245760a b c  + 204800a b c  + 15360b c )x
+--R           + 
+--R                     3 8           2 2 7            4 6         6 5  22
+--R             (491520a c  + 2285568a b c  + 829440a b c  + 35328b c )x
+--R           + 
+--R                      3   7           2 3 6             5 5         7 4  20
+--R             (5738496a b c  + 7142400a b c  + 1140480a b c  + 20544b c )x
+--R           + 
+--R                         4 7            3 2 6           2 4 5            6 4
+--R                 3973120a c  + 21135360a b c  + 9231360a b c  + 528384a b c
+--R               + 
+--R                      8 3
+--R                 - 96b c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                          4   6            3 3 5           2 5 4          7 3
+--R                 25528320a b c  + 31180800a b c  + 4250880a b c  - 1152a b c
+--R               + 
+--R                     9 2
+--R                 168b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                          5 6            4 2 5            3 4 4        2 6 3
+--R                 10874880a c  + 51194880a b c  + 15982080a b c  + 8064a b c
+--R               + 
+--R                        8 2       10
+--R                 1584a b c  - 420b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                          5   5            4 3 4          3 5 3          2 7 2
+--R                 40965120a b c  + 32047360a b c  - 170880a b c  + 127008a b c
+--R               + 
+--R                           9         11
+--R                 - 11100a b c - 1155b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          6 5            5 2 4           4 4 3          3 6 2
+--R                 12963840a c  + 36910080a b c  - 2127360a b c  + 606336a b c
+--R               + 
+--R                       2 8            10
+--R                 66960a b c - 23100a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          6   4           5 3 3          4 5 2          3 7
+--R                 23900160a b c  - 3932160a b c  - 529920a b c  + 860160a b c
+--R               + 
+--R                          2 9
+--R                 - 129360a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                         7 4          6 2 3           5 4 2           4 6
+--R                 6553600a c  - 245760a b c  - 4853760a b c  + 2391040a b c
+--R               + 
+--R                          3 8
+--R                 - 295680a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                      7   3           6 3 2           5 5           4 7  4
+--R             (2703360a b c  - 6082560a b c  + 2534400a b c - 295680a b )x
+--R           + 
+--R                     8 3           7 2 2          6 4           5 6  2
+--R             (983040a c  - 2211840a b c  + 921600a b c - 107520a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                      2   6             3 5          5 4  10
+--R             (2949120a b c  + 2457600a b c  + 184320b c )x
+--R           + 
+--R                      3 6            2 2 5             4 4  8
+--R             (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R           + 
+--R                       3   5            2 3 4  6
+--R             (47185920a b c  + 27525120a b c )x
+--R           + 
+--R                     4 5            3 2 4  4            4   4 2            5 4
+--R           (31457280a c  + 70778880a b c )x  + 78643200a b c x  + 31457280a c
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                       3 7           2 2 6            4 5         6 4  12
+--R             (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R           + 
+--R                         3   6            2 3 5             5 4  10
+--R             (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R           + 
+--R                         4 6            3 2 5            2 4 4  8
+--R             (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R           + 
+--R                         4   5            3 3 4  6
+--R             (- 94371840a b c  - 55050240a b c )x
+--R           + 
+--R                         5 5             4 2 4  4            5   4 2
+--R             (- 47185920a c  - 106168320a b c )x  - 94371840a b c x
+--R           + 
+--R                        6 4
+--R             - 31457280a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1328
+
+--S 1329 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          5   5          4 3 4          3 5 3         2 7 2
+--R                   184320a b c  - 261120a b c  - 161280a b c  + 97920a b c
+--R                 + 
+--R                            9         11
+--R                   - 6000a b c - 1260b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                          6 5          5 2 4           4 4 3          3 6 2
+--R                   368640a c  + 460800a b c  - 2288640a b c  + 564480a b c
+--R                 + 
+--R                          2 8            10
+--R                   110880a b c - 29400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           6   4           5 3 3           4 5 2           3 7
+--R                   2949120a b c  - 4915200a b c  - 1105920a b c  + 1290240a b c
+--R                 + 
+--R                            2 9
+--R                   - 188160a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                        7 4           5 4 2           4 6           3 8  4
+--R               (1966080a c  - 8110080a b c  + 3932160a b c - 483840a b )x
+--R             + 
+--R                        7   3            6 3 2           5 5           4 7  2
+--R               (4915200a b c  - 11059200a b c  + 4608000a b c - 537600a b )x
+--R             + 
+--R                       8 3           7 2 2           6 4           5 6
+--R               1966080a c  - 4423680a b c  + 1843200a b c - 215040a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                       6 6         5 2 5          4 4 4         3 6 3
+--R               - 61440a c  - 92160a b c  + 403200a b c  - 80640a b c
+--R             + 
+--R                       2 8 2          10        12
+--R               - 26640a b c  + 5400a b  c + 105b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         6   5           5 3 4          4 5 3          3 7 2
+--R               - 1105920a b c  + 1566720a b c  + 967680a b c  - 587520a b c
+--R             + 
+--R                     2 9           11
+--R               36000a b c + 7560a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         7 5           6 2 4           5 4 3           4 6 2
+--R               - 1105920a c  - 1382400a b c  + 6865920a b c  - 1693440a b c
+--R             + 
+--R                        3 8          2 10
+--R               - 332640a b c + 88200a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         7   4           6 3 3           5 5 2           4 7
+--R               - 5898240a b c  + 9830400a b c  + 2211840a b c  - 2580480a b c
+--R             + 
+--R                      3 9
+--R               376320a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      8 4            6 4 2           5 6           4 8  4
+--R           (- 2949120a c  + 12165120a b c  - 5898240a b c + 725760a b )x
+--R         + 
+--R                      8   3            7 3 2           6 5           5 7  2
+--R           (- 5898240a b c  + 13271040a b c  - 5529600a b c + 645120a b )x
+--R         + 
+--R                     9 3           8 2 2           7 4           6 6
+--R           - 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                          5   5          4 3 4          3 5 3         2 7 2
+--R                   184320a b c  - 261120a b c  - 161280a b c  + 97920a b c
+--R                 + 
+--R                            9         11
+--R                   - 6000a b c - 1260b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                          6 5          5 2 4           4 4 3          3 6 2
+--R                   368640a c  + 460800a b c  - 2288640a b c  + 564480a b c
+--R                 + 
+--R                          2 8            10
+--R                   110880a b c - 29400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           6   4           5 3 3           4 5 2           3 7
+--R                   2949120a b c  - 4915200a b c  - 1105920a b c  + 1290240a b c
+--R                 + 
+--R                            2 9
+--R                   - 188160a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                        7 4           5 4 2           4 6           3 8  4
+--R               (1966080a c  - 8110080a b c  + 3932160a b c - 483840a b )x
+--R             + 
+--R                        7   3            6 3 2           5 5           4 7  2
+--R               (4915200a b c  - 11059200a b c  + 4608000a b c - 537600a b )x
+--R             + 
+--R                       8 3           7 2 2           6 4           5 6
+--R               1966080a c  - 4423680a b c  + 1843200a b c - 215040a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                       6 6         5 2 5          4 4 4         3 6 3
+--R               - 61440a c  - 92160a b c  + 403200a b c  - 80640a b c
+--R             + 
+--R                       2 8 2          10        12
+--R               - 26640a b c  + 5400a b  c + 105b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         6   5           5 3 4          4 5 3          3 7 2
+--R               - 1105920a b c  + 1566720a b c  + 967680a b c  - 587520a b c
+--R             + 
+--R                     2 9           11
+--R               36000a b c + 7560a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         7 5           6 2 4           5 4 3           4 6 2
+--R               - 1105920a c  - 1382400a b c  + 6865920a b c  - 1693440a b c
+--R             + 
+--R                        3 8          2 10
+--R               - 332640a b c + 88200a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         7   4           6 3 3           5 5 2           4 7
+--R               - 5898240a b c  + 9830400a b c  + 2211840a b c  - 2580480a b c
+--R             + 
+--R                      3 9
+--R               376320a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      8 4            6 4 2           5 6           4 8  4
+--R           (- 2949120a c  + 12165120a b c  - 5898240a b c + 725760a b )x
+--R         + 
+--R                      8   3            7 3 2           6 5           5 7  2
+--R           (- 5898240a b c  + 13271040a b c  - 5529600a b c + 645120a b )x
+--R         + 
+--R                     9 3           8 2 2           7 4           6 6
+--R           - 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                        5 2 4          4 4 3          3 6 2         2 8
+--R               - 497664a b c  - 122880a b c  + 171776a b c  - 15360a b c
+--R             + 
+--R                        10
+--R               - 2520a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        6   4           5 3 3           4 5 2          3 7
+--R               - 995328a b c  - 2899968a b c  + 1236480a b c  + 143360a b c
+--R             + 
+--R                       2 9
+--R               - 58800a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      6 2 3         5 4 2           4 6           3 8  6
+--R           (- 7962624a b c  + 24576a b c  + 2078720a b c - 376320a b )x
+--R         + 
+--R                      7   3           6 3 2           5 5           4 7  4
+--R           (- 5308416a b c  - 8830976a b c  + 6574080a b c - 967680a b )x
+--R         + 
+--R                       7 2 2           6 4            5 6  2           8   2
+--R           (- 13271040a b c  + 7782400a b c - 1075200a b )x  - 5308416a b c
+--R         + 
+--R                   7 3           6 5
+--R           3112960a b c - 430080a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                      5   5          4 3 4          3 5 3         2 7 2
+--R               165888a b c  + 524800a b c  - 195840a b c  - 38208a b c
+--R             + 
+--R                       9        11
+--R               11080a b c + 210b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                       5 2 4          4 4 3           3 6 2         2 8
+--R               2985984a b c  + 737280a b c  - 1030656a b c  + 92160a b c
+--R             + 
+--R                       10
+--R               15120a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                       6   4           5 3 3           4 5 2          3 7
+--R               2985984a b c  + 8699904a b c  - 3709440a b c  - 430080a b c
+--R             + 
+--R                      2 9
+--R               176400a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                     6 2 3         5 4 2           4 6           3 8  6
+--R           (15925248a b c  - 49152a b c  - 4157440a b c + 752640a b )x
+--R         + 
+--R                    7   3            6 3 2           5 5            4 7  4
+--R           (7962624a b c  + 13246464a b c  - 9861120a b c + 1451520a b )x
+--R         + 
+--R                     7 2 2           6 4            5 6  2           8   2
+--R           (15925248a b c  - 9338880a b c + 1290240a b )x  + 5308416a b c
+--R         + 
+--R                     7 3           6 5
+--R           - 3112960a b c + 430080a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                    2   6             3 5          5 4  10
+--R           (5898240a b c  + 4915200a b c  + 368640b c )x
+--R         + 
+--R                     3 6            2 2 5             4 4  8
+--R           (11796480a c  + 41287680a b c  + 8601600a b c )x
+--R         + 
+--R                     3   5            2 3 4  6
+--R           (94371840a b c  + 55050240a b c )x
+--R         + 
+--R                   4 5             3 2 4  4             4   4 2            5 4
+--R         (62914560a c  + 141557760a b c )x  + 157286400a b c x  + 62914560a c
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                      3 7           2 2 6             4 5         6 4  12
+--R           (- 1966080a c  - 7372800a b c  - 1843200a b c  - 30720b c )x
+--R         + 
+--R                       3   6            2 3 5             5 4  10
+--R           (- 35389440a b c  - 29491200a b c  - 2211840a b c )x
+--R         + 
+--R                       4 6             3 2 5            2 4 4  8
+--R           (- 35389440a c  - 123863040a b c  - 25804800a b c )x
+--R         + 
+--R                        4   5             3 3 4  6
+--R           (- 188743680a b c  - 110100480a b c )x
+--R         + 
+--R                     5 5             4 2 4  4             5   4 2            6 4
+--R         (- 94371840a c  - 212336640a b c )x  - 188743680a b c x  - 62914560a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 1329
+
+--S 1330 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1330
+
+--S 1331 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          5   5          4 3 4          3 5 3         2 7 2
+--R                   184320a b c  - 261120a b c  - 161280a b c  + 97920a b c
+--R                 + 
+--R                            9         11
+--R                   - 6000a b c - 1260b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                          6 5          5 2 4           4 4 3          3 6 2
+--R                   368640a c  + 460800a b c  - 2288640a b c  + 564480a b c
+--R                 + 
+--R                          2 8            10
+--R                   110880a b c - 29400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           6   4           5 3 3           4 5 2           3 7
+--R                   2949120a b c  - 4915200a b c  - 1105920a b c  + 1290240a b c
+--R                 + 
+--R                            2 9
+--R                   - 188160a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                        7 4           5 4 2           4 6           3 8  4
+--R               (1966080a c  - 8110080a b c  + 3932160a b c - 483840a b )x
+--R             + 
+--R                        7   3            6 3 2           5 5           4 7  2
+--R               (4915200a b c  - 11059200a b c  + 4608000a b c - 537600a b )x
+--R             + 
+--R                       8 3           7 2 2           6 4           5 6
+--R               1966080a c  - 4423680a b c  + 1843200a b c - 215040a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                           6 6         5 2 5          4 4 4         3 6 3
+--R                   - 61440a c  - 92160a b c  + 403200a b c  - 80640a b c
+--R                 + 
+--R                           2 8 2          10        12
+--R                   - 26640a b c  + 5400a b  c + 105b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             6   5           5 3 4          4 5 3          3 7 2
+--R                   - 1105920a b c  + 1566720a b c  + 967680a b c  - 587520a b c
+--R                 + 
+--R                         2 9           11
+--R                   36000a b c + 7560a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             7 5           6 2 4           5 4 3           4 6 2
+--R                   - 1105920a c  - 1382400a b c  + 6865920a b c  - 1693440a b c
+--R                 + 
+--R                            3 8          2 10
+--R                   - 332640a b c + 88200a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             7   4           6 3 3           5 5 2
+--R                   - 5898240a b c  + 9830400a b c  + 2211840a b c
+--R                 + 
+--R                             4 7           3 9
+--R                   - 2580480a b c + 376320a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          8 4            6 4 2           5 6           4 8  4
+--R               (- 2949120a c  + 12165120a b c  - 5898240a b c + 725760a b )x
+--R             + 
+--R                          8   3            7 3 2           6 5           5 7  2
+--R               (- 5898240a b c  + 13271040a b c  - 5529600a b c + 645120a b )x
+--R             + 
+--R                         9 3           8 2 2           7 4           6 6
+--R               - 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                            5   5          4 3 4          3 5 3          2 7 2
+--R                   - 368640a b c  + 522240a b c  + 322560a b c  - 195840a b c
+--R                 + 
+--R                           9         11
+--R                   12000a b c + 2520b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            6 5          5 2 4           4 4 3           3 6 2
+--R                   - 737280a c  - 921600a b c  + 4577280a b c  - 1128960a b c
+--R                 + 
+--R                            2 8            10
+--R                   - 221760a b c + 58800a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             6   4           5 3 3           4 5 2
+--R                   - 5898240a b c  + 9830400a b c  + 2211840a b c
+--R                 + 
+--R                             3 7           2 9
+--R                   - 2580480a b c + 376320a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          7 4            5 4 2           4 6           3 8  4
+--R               (- 3932160a c  + 16220160a b c  - 7864320a b c + 967680a b )x
+--R             + 
+--R                          7   3            6 3 2           5 5            4 7  2
+--R               (- 9830400a b c  + 22118400a b c  - 9216000a b c + 1075200a b )x
+--R             + 
+--R                         8 3           7 2 2           6 4           5 6
+--R               - 3932160a c  + 8847360a b c  - 3686400a b c + 430080a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                          6 6          5 2 5          4 4 4          3 6 3
+--R                   122880a c  + 184320a b c  - 806400a b c  + 161280a b c
+--R                 + 
+--R                         2 8 2           10        12
+--R                   53280a b c  - 10800a b  c - 210b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                           6   5           5 3 4           4 5 3           3 7 2
+--R                   2211840a b c  - 3133440a b c  - 1935360a b c  + 1175040a b c
+--R                 + 
+--R                           2 9            11
+--R                   - 72000a b c - 15120a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                           7 5           6 2 4            5 4 3           4 6 2
+--R                   2211840a c  + 2764800a b c  - 13731840a b c  + 3386880a b c
+--R                 + 
+--R                          3 8           2 10
+--R                   665280a b c - 176400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            7   4            6 3 3           5 5 2
+--R                   11796480a b c  - 19660800a b c  - 4423680a b c
+--R                 + 
+--R                           4 7           3 9
+--R                   5160960a b c - 752640a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                        8 4            6 4 2            5 6            4 8  4
+--R               (5898240a c  - 24330240a b c  + 11796480a b c - 1451520a b )x
+--R             + 
+--R                         8   3            7 3 2            6 5            5 7  2
+--R               (11796480a b c  - 26542080a b c  + 11059200a b c - 1290240a b )x
+--R             + 
+--R                       9 3           8 2 2           7 4           6 6
+--R               3932160a c  - 8847360a b c  + 3686400a b c - 430080a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                        5 2 4          4 4 3          3 6 2         2 8
+--R               - 497664a b c  - 122880a b c  + 171776a b c  - 15360a b c
+--R             + 
+--R                        10
+--R               - 2520a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        6   4           5 3 3           4 5 2          3 7
+--R               - 995328a b c  - 2899968a b c  + 1236480a b c  + 143360a b c
+--R             + 
+--R                       2 9
+--R               - 58800a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      6 2 3         5 4 2           4 6           3 8  6
+--R           (- 7962624a b c  + 24576a b c  + 2078720a b c - 376320a b )x
+--R         + 
+--R                      7   3           6 3 2           5 5           4 7  4
+--R           (- 5308416a b c  - 8830976a b c  + 6574080a b c - 967680a b )x
+--R         + 
+--R                       7 2 2           6 4            5 6  2           8   2
+--R           (- 13271040a b c  + 7782400a b c - 1075200a b )x  - 5308416a b c
+--R         + 
+--R                   7 3           6 5
+--R           3112960a b c - 430080a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                      5   5          4 3 4          3 5 3         2 7 2
+--R               165888a b c  + 524800a b c  - 195840a b c  - 38208a b c
+--R             + 
+--R                       9        11
+--R               11080a b c + 210b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                       5 2 4          4 4 3           3 6 2         2 8
+--R               2985984a b c  + 737280a b c  - 1030656a b c  + 92160a b c
+--R             + 
+--R                       10
+--R               15120a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                       6   4           5 3 3           4 5 2          3 7
+--R               2985984a b c  + 8699904a b c  - 3709440a b c  - 430080a b c
+--R             + 
+--R                      2 9
+--R               176400a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                     6 2 3         5 4 2           4 6           3 8  6
+--R           (15925248a b c  - 49152a b c  - 4157440a b c + 752640a b )x
+--R         + 
+--R                    7   3            6 3 2           5 5            4 7  4
+--R           (7962624a b c  + 13246464a b c  - 9861120a b c + 1451520a b )x
+--R         + 
+--R                     7 2 2           6 4            5 6  2           8   2
+--R           (15925248a b c  - 9338880a b c + 1290240a b )x  + 5308416a b c
+--R         + 
+--R                     7 3           6 5
+--R           - 3112960a b c + 430080a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                    2   6             3 5          5 4  10
+--R           (5898240a b c  + 4915200a b c  + 368640b c )x
+--R         + 
+--R                     3 6            2 2 5             4 4  8
+--R           (11796480a c  + 41287680a b c  + 8601600a b c )x
+--R         + 
+--R                     3   5            2 3 4  6
+--R           (94371840a b c  + 55050240a b c )x
+--R         + 
+--R                   4 5             3 2 4  4             4   4 2            5 4
+--R         (62914560a c  + 141557760a b c )x  + 157286400a b c x  + 62914560a c
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                      3 7           2 2 6             4 5         6 4  12
+--R           (- 1966080a c  - 7372800a b c  - 1843200a b c  - 30720b c )x
+--R         + 
+--R                       3   6            2 3 5             5 4  10
+--R           (- 35389440a b c  - 29491200a b c  - 2211840a b c )x
+--R         + 
+--R                       4 6             3 2 5            2 4 4  8
+--R           (- 35389440a c  - 123863040a b c  - 25804800a b c )x
+--R         + 
+--R                        4   5             3 3 4  6
+--R           (- 188743680a b c  - 110100480a b c )x
+--R         + 
+--R                     5 5             4 2 4  4             5   4 2            6 4
+--R         (- 94371840a c  - 212336640a b c )x  - 188743680a b c x  - 62914560a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 1331
+
+--S 1332 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1332
+
+)clear all
+
+--S 1333 of 1353
+t0:=x^3*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                             +---------------+
+--R            7      5      3  |   4      2
+--R   (1)  (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1333
+
+--S 1334 of 1353
+r0:=-1/32*b*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^2+1/10*(a+b*x^2+_
+   c*x^4)^(5/2)/c-3/512*b*(b^2-4*a*c)^2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/c^(7/2)+3/256*b*(b^2-4*a*c)*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R                                                       2
+--R              2   2         3       5              2c x  + b
+--R       (- 240a b c  + 120a b c - 15b )atanh(-----------------------)
+--R                                                  +---------------+
+--R                                              +-+ |   4      2
+--R                                            2\|c \|c x  + b x  + a
+--R     + 
+--R               4 8         3 6          3      2 2  4            2      3   2
+--R           256c x  + 352b c x  + (512a c  + 16b c )x  + (112a b c  - 20b c)x
+--R         + 
+--R               2 2         2       4
+--R           256a c  - 200a b c + 30b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R          3 +-+
+--R     2560c \|c
+--R                                                    Type: Expression(Integer)
+--E 1334
+
+--S 1335 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       4   4         3 3 3        2 5 2       9  8
+--R                 (7680a b c  + 15360a b c  - 6720a b c  + 150b )x
+--R               + 
+--R                        4 2 3        3 4 2         2 6           8  6
+--R                 (92160a b c  - 7680a b c  - 13440a b c + 2400a b )x
+--R               + 
+--R                        5   3          4 3 2         3 5          2 7  4
+--R                 (92160a b c  + 115200a b c  - 74880a b c + 10080a b )x
+--R               + 
+--R                         5 2 2          4 4          3 6  2          6   2
+--R                 (245760a b c  - 122880a b c + 15360a b )x  + 122880a b c
+--R               + 
+--R                         5 3         4 5
+--R                 - 61440a b c + 7680a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                      4 2 4        2 6 2         8       10  10
+--R             (- 19200a b c  + 3360a b c  - 480a b c - 15b  )x
+--R           + 
+--R                      5   4         4 3 3         3 5 2         9  8
+--R             (- 38400a b c  - 76800a b c  + 33600a b c  - 750a b )x
+--R           + 
+--R                       5 2 3         4 4 2         3 6         2 8  6
+--R             (- 230400a b c  + 19200a b c  + 33600a b c - 6000a b )x
+--R           + 
+--R                       6   3          5 3 2          4 5          3 7  4
+--R             (- 153600a b c  - 192000a b c  + 124800a b c - 16800a b )x
+--R           + 
+--R                       6 2 2          5 4          4 6  2          7   2
+--R             (- 307200a b c  + 153600a b c - 19200a b )x  - 122880a b c
+--R           + 
+--R                   6 3         5 5
+--R             61440a b c - 7680a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                      2   6           3 5       5 4  18
+--R             (- 20480a b c  - 10240a b c  - 256b c )x
+--R           + 
+--R                      3 6          2 2 5           4 4       6 3  16
+--R             (- 40960a c  - 130560a b c  - 26880a b c  - 352b c )x
+--R           + 
+--R                       3   5          2 3 4           5 3      7 2  14
+--R             (- 343040a b c  - 264960a b c  - 18752a b c  - 16b c )x
+--R           + 
+--R                       4 5          3 2 4          2 4 3         6 2      8   12
+--R             (- 245760a c  - 840960a b c  - 175680a b c  - 112a b c  + 20b c)x
+--R           + 
+--R                        4   4          3 3 3        2 5 2      9  10
+--R             (- 1082880a b c  - 650240a b c  + 1344a b c  - 30b )x
+--R           + 
+--R                            5 4           4 2 3        3 4 2        2 6
+--R                   - 491520a c  - 1198080a b c  + 6400a b c  + 6400a b c
+--R                 + 
+--R                            8
+--R                   - 1200a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                        5   3         4 3 2         3 5         2 7  6
+--R             (- 1054720a b c  - 79360a b c  + 53120a b c - 7200a b )x
+--R           + 
+--R                       6 3          5 2 2          4 4          3 6  4
+--R             (- 327680a c  - 215040a b c  + 107520a b c - 13440a b )x
+--R           + 
+--R                       6   2         5 3         4 5  2
+--R             (- 122880a b c  + 61440a b c - 7680a b )x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                   2 7           2 6        4 5  20
+--R             (8192a c  + 20480a b c  + 2560b c )x
+--R           + 
+--R                     2   6           3 5        5 4  18
+--R             (117760a b c  + 89600a b c  + 6080b c )x
+--R           + 
+--R                     3 6          2 2 5            4 4        6 3  16
+--R             (122880a c  + 478720a b c  + 134400a b c  + 3680b c )x
+--R           + 
+--R                     3   5          2 3 4           5 3      7 2  14
+--R             (821760a b c  + 750720a b c  + 68320a b c  - 40b c )x
+--R           + 
+--R                     4 5           3 2 4          2 4 3         6 2       8   12
+--R             (450560a c  + 1713920a b c  + 404160a b c  - 560a b c  + 100b c)x
+--R           + 
+--R                      4   4           3 3 3         2 5 2         7        9  10
+--R             (1758720a b c  + 1154560a b c  - 17984a b c  + 800a b c + 270b )x
+--R           + 
+--R                          5 4           4 2 3         3 4 2         2 6
+--R                   655360a c  + 1761280a b c  - 24320a b c  - 18560a b c
+--R                 + 
+--R                          8
+--R                   3600a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                      5   3          4 3 2         3 5          2 7  6
+--R             (1280000a b c  + 140800a b c  - 95360a b c + 12960a b )x
+--R           + 
+--R                     6 3          5 2 2          4 4          3 6  4
+--R             (327680a c  + 276480a b c  - 138240a b c + 17280a b )x
+--R           + 
+--R                     6   2         5 3         4 5  2
+--R             (122880a b c  - 61440a b c + 7680a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                    2 5            2 4         4 3  8
+--R             (81920a c  + 204800a b c  + 25600b c )x
+--R           + 
+--R                     2   4            3 3  6           3 4           2 2 3  4
+--R             (983040a b c  + 409600a b c )x  + (983040a c  + 1720320a b c )x
+--R           + 
+--R                     3   3 2           4 3
+--R             2621440a b c x  + 1310720a c
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                       2   5            3 4        5 3  10
+--R             (- 204800a b c  - 102400a b c  - 2560b c )x
+--R           + 
+--R                       3 5           2 2 4            4 3  8
+--R             (- 409600a c  - 1024000a b c  - 128000a b c )x
+--R           + 
+--R                        3   4           2 3 3  6
+--R             (- 2457600a b c  - 1024000a b c )x
+--R           + 
+--R                        4 4           3 2 3  4           4   3 2           5 3
+--R             (- 1638400a c  - 2867200a b c )x  - 3276800a b c x  - 1310720a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                         4   4         3 3 3        2 5 2       9  8
+--R                 (- 7680a b c  - 15360a b c  + 6720a b c  - 150b )x
+--R               + 
+--R                          4 2 3        3 4 2         2 6           8  6
+--R                 (- 92160a b c  + 7680a b c  + 13440a b c - 2400a b )x
+--R               + 
+--R                          5   3          4 3 2         3 5          2 7  4
+--R                 (- 92160a b c  - 115200a b c  + 74880a b c - 10080a b )x
+--R               + 
+--R                           5 2 2          4 4          3 6  2          6   2
+--R                 (- 245760a b c  + 122880a b c - 15360a b )x  - 122880a b c
+--R               + 
+--R                       5 3         4 5
+--R                 61440a b c - 7680a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                    4 2 4        2 6 2         8       10  10
+--R             (19200a b c  - 3360a b c  + 480a b c + 15b  )x
+--R           + 
+--R                    5   4         4 3 3         3 5 2         9  8
+--R             (38400a b c  + 76800a b c  - 33600a b c  + 750a b )x
+--R           + 
+--R                     5 2 3         4 4 2         3 6         2 8  6
+--R             (230400a b c  - 19200a b c  - 33600a b c + 6000a b )x
+--R           + 
+--R                     6   3          5 3 2          4 5          3 7  4
+--R             (153600a b c  + 192000a b c  - 124800a b c + 16800a b )x
+--R           + 
+--R                     6 2 2          5 4          4 6  2          7   2
+--R             (307200a b c  - 153600a b c + 19200a b )x  + 122880a b c
+--R           + 
+--R                     6 3         5 5
+--R             - 61440a b c + 7680a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                      2   6          3 5       5 4  18
+--R             (- 10240a b c  - 5120a b c  - 128b c )x
+--R           + 
+--R                      3 6         2 2 5           4 4       6 3  16
+--R             (- 20480a c  - 65280a b c  - 13440a b c  - 176b c )x
+--R           + 
+--R                       3   5          2 3 4          5 3     7 2  14
+--R             (- 171520a b c  - 132480a b c  - 9376a b c  - 8b c )x
+--R           + 
+--R                       4 5          3 2 4         2 4 3        6 2      8   12
+--R             (- 122880a c  - 420480a b c  - 87840a b c  - 56a b c  + 10b c)x
+--R           + 
+--R                       4   4          3 3 3       2 5 2      9  10
+--R             (- 541440a b c  - 325120a b c  + 672a b c  - 15b )x
+--R           + 
+--R                       5 4          4 2 3        3 4 2        2 6          8  8
+--R             (- 245760a c  - 599040a b c  + 3200a b c  + 3200a b c - 600a b )x
+--R           + 
+--R                       5   3         4 3 2         3 5         2 7  6
+--R             (- 527360a b c  - 39680a b c  + 26560a b c - 3600a b )x
+--R           + 
+--R                       6 3          5 2 2         4 4         3 6  4
+--R             (- 163840a c  - 107520a b c  + 53760a b c - 6720a b )x
+--R           + 
+--R                      6   2         5 3         4 5  2
+--R             (- 61440a b c  + 30720a b c - 3840a b )x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                   2 7           2 6        4 5  20
+--R             (4096a c  + 10240a b c  + 1280b c )x
+--R           + 
+--R                    2   6           3 5        5 4  18
+--R             (58880a b c  + 44800a b c  + 3040b c )x
+--R           + 
+--R                    3 6          2 2 5           4 4        6 3  16
+--R             (61440a c  + 239360a b c  + 67200a b c  + 1840b c )x
+--R           + 
+--R                     3   5          2 3 4           5 3      7 2  14
+--R             (410880a b c  + 375360a b c  + 34160a b c  - 20b c )x
+--R           + 
+--R                     4 5          3 2 4          2 4 3         6 2      8   12
+--R             (225280a c  + 856960a b c  + 202080a b c  - 280a b c  + 50b c)x
+--R           + 
+--R                     4   4          3 3 3        2 5 2         7        9  10
+--R             (879360a b c  + 577280a b c  - 8992a b c  + 400a b c + 135b )x
+--R           + 
+--R                     5 4          4 2 3         3 4 2        2 6           8  8
+--R             (327680a c  + 880640a b c  - 12160a b c  - 9280a b c + 1800a b )x
+--R           + 
+--R                     5   3         4 3 2         3 5         2 7  6
+--R             (640000a b c  + 70400a b c  - 47680a b c + 6480a b )x
+--R           + 
+--R                     6 3          5 2 2         4 4         3 6  4
+--R             (163840a c  + 138240a b c  - 69120a b c + 8640a b )x
+--R           + 
+--R                    6   2         5 3         4 5  2
+--R             (61440a b c  - 30720a b c + 3840a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                    2 5            2 4         4 3  8
+--R             (40960a c  + 102400a b c  + 12800b c )x
+--R           + 
+--R                     2   4            3 3  6           3 4          2 2 3  4
+--R             (491520a b c  + 204800a b c )x  + (491520a c  + 860160a b c )x
+--R           + 
+--R                     3   3 2          4 3
+--R             1310720a b c x  + 655360a c
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                       2   5           3 4        5 3  10
+--R             (- 102400a b c  - 51200a b c  - 1280b c )x
+--R           + 
+--R                       3 5          2 2 4           4 3  8
+--R             (- 204800a c  - 512000a b c  - 64000a b c )x
+--R           + 
+--R                        3   4          2 3 3  6
+--R             (- 1228800a b c  - 512000a b c )x
+--R           + 
+--R                       4 4           3 2 3  4           4   3 2          5 3
+--R             (- 819200a c  - 1433600a b c )x  - 1638400a b c x  - 655360a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1335
+
+--S 1336 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     4   4         3 3 3        2 5 2       9  8
+--R               (7680a b c  + 15360a b c  - 6720a b c  + 150b )x
+--R             + 
+--R                      4 2 3        3 4 2         2 6           8  6
+--R               (92160a b c  - 7680a b c  - 13440a b c + 2400a b )x
+--R             + 
+--R                      5   3          4 3 2         3 5          2 7  4
+--R               (92160a b c  + 115200a b c  - 74880a b c + 10080a b )x
+--R             + 
+--R                       5 2 2          4 4          3 6  2          6   2
+--R               (245760a b c  - 122880a b c + 15360a b )x  + 122880a b c
+--R             + 
+--R                       5 3         4 5
+--R               - 61440a b c + 7680a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                    4 2 4        2 6 2         8       10  10
+--R           (- 19200a b c  + 3360a b c  - 480a b c - 15b  )x
+--R         + 
+--R                    5   4         4 3 3         3 5 2         9  8
+--R           (- 38400a b c  - 76800a b c  + 33600a b c  - 750a b )x
+--R         + 
+--R                     5 2 3         4 4 2         3 6         2 8  6
+--R           (- 230400a b c  + 19200a b c  + 33600a b c - 6000a b )x
+--R         + 
+--R                     6   3          5 3 2          4 5          3 7  4
+--R           (- 153600a b c  - 192000a b c  + 124800a b c - 16800a b )x
+--R         + 
+--R                     6 2 2          5 4          4 6  2          7   2
+--R           (- 307200a b c  + 153600a b c - 19200a b )x  - 122880a b c
+--R         + 
+--R                 6 3         5 5
+--R           61440a b c - 7680a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                     4   4         3 3 3        2 5 2       9  8
+--R               (7680a b c  + 15360a b c  - 6720a b c  + 150b )x
+--R             + 
+--R                      4 2 3        3 4 2         2 6           8  6
+--R               (92160a b c  - 7680a b c  - 13440a b c + 2400a b )x
+--R             + 
+--R                      5   3          4 3 2         3 5          2 7  4
+--R               (92160a b c  + 115200a b c  - 74880a b c + 10080a b )x
+--R             + 
+--R                       5 2 2          4 4          3 6  2          6   2
+--R               (245760a b c  - 122880a b c + 15360a b )x  + 122880a b c
+--R             + 
+--R                       5 3         4 5
+--R               - 61440a b c + 7680a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                    4 2 4        2 6 2         8       10  10
+--R           (- 19200a b c  + 3360a b c  - 480a b c - 15b  )x
+--R         + 
+--R                    5   4         4 3 3         3 5 2         9  8
+--R           (- 38400a b c  - 76800a b c  + 33600a b c  - 750a b )x
+--R         + 
+--R                     5 2 3         4 4 2         3 6         2 8  6
+--R           (- 230400a b c  + 19200a b c  + 33600a b c - 6000a b )x
+--R         + 
+--R                     6   3          5 3 2          4 5          3 7  4
+--R           (- 153600a b c  - 192000a b c  + 124800a b c - 16800a b )x
+--R         + 
+--R                     6 2 2          5 4          4 6  2          7   2
+--R           (- 307200a b c  + 153600a b c - 19200a b )x  - 122880a b c
+--R         + 
+--R                 6 3         5 5
+--R           61440a b c - 7680a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                 5 4         4 2 3         3 4 2       2 6          8  8
+--R           (8192a c  + 14080a b c  - 12480a b c  + 400a b c + 300a b )x
+--R         + 
+--R                  5   3         4 3 2         3 5         2 7  6
+--R           (98304a b c  - 35840a b c  - 20480a b c + 4800a b )x
+--R         + 
+--R                  6 3         5 2 2          4 4          3 6  4
+--R           (98304a c  + 95232a b c  - 122880a b c + 20160a b )x
+--R         + 
+--R                   6   2          5 3          4 5  2          7 2          6 2
+--R           (262144a b c  - 204800a b c + 30720a b )x  + 131072a c  - 102400a b c
+--R         + 
+--R                 5 4
+--R           15360a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                    4   4        3 3 3        2 5 2          7       9  10
+--R           (- 20480a b c  + 5760a b c  + 5344a b c  - 1000a b c - 30b )x
+--R         + 
+--R                    5 4         4 2 3         3 4 2        2 6           8  8
+--R           (- 40960a c  - 70400a b c  + 62400a b c  - 2000a b c - 1500a b )x
+--R         + 
+--R                     5   3         4 3 2         3 5          2 7  6
+--R           (- 245760a b c  + 89600a b c  + 51200a b c - 12000a b )x
+--R         + 
+--R                     6 3          5 2 2          4 4          3 6  4
+--R           (- 163840a c  - 158720a b c  + 204800a b c - 33600a b )x
+--R         + 
+--R                     6   2          5 3          4 5  2          7 2
+--R           (- 327680a b c  + 256000a b c - 38400a b )x  - 131072a c
+--R         + 
+--R                  6 2          5 4
+--R           102400a b c - 15360a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                  2 5            2 4         4 3  8
+--R           (81920a c  + 204800a b c  + 25600b c )x
+--R         + 
+--R                   2   4            3 3  6           3 4           2 2 3  4
+--R           (983040a b c  + 409600a b c )x  + (983040a c  + 1720320a b c )x
+--R         + 
+--R                   3   3 2           4 3
+--R           2621440a b c x  + 1310720a c
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                     2   5            3 4        5 3  10
+--R           (- 204800a b c  - 102400a b c  - 2560b c )x
+--R         + 
+--R                     3 5           2 2 4            4 3  8
+--R           (- 409600a c  - 1024000a b c  - 128000a b c )x
+--R         + 
+--R                      3   4           2 3 3  6
+--R           (- 2457600a b c  - 1024000a b c )x
+--R         + 
+--R                      4 4           3 2 3  4           4   3 2           5 3
+--R           (- 1638400a c  - 2867200a b c )x  - 3276800a b c x  - 1310720a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 1336
+
+--S 1337 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1337
+
+--S 1338 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     4   4         3 3 3        2 5 2       9  8
+--R               (7680a b c  + 15360a b c  - 6720a b c  + 150b )x
+--R             + 
+--R                      4 2 3        3 4 2         2 6           8  6
+--R               (92160a b c  - 7680a b c  - 13440a b c + 2400a b )x
+--R             + 
+--R                      5   3          4 3 2         3 5          2 7  4
+--R               (92160a b c  + 115200a b c  - 74880a b c + 10080a b )x
+--R             + 
+--R                       5 2 2          4 4          3 6  2          6   2
+--R               (245760a b c  - 122880a b c + 15360a b )x  + 122880a b c
+--R             + 
+--R                       5 3         4 5
+--R               - 61440a b c + 7680a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                        4 2 4        2 6 2         8       10  10
+--R               (- 19200a b c  + 3360a b c  - 480a b c - 15b  )x
+--R             + 
+--R                        5   4         4 3 3         3 5 2         9  8
+--R               (- 38400a b c  - 76800a b c  + 33600a b c  - 750a b )x
+--R             + 
+--R                         5 2 3         4 4 2         3 6         2 8  6
+--R               (- 230400a b c  + 19200a b c  + 33600a b c - 6000a b )x
+--R             + 
+--R                         6   3          5 3 2          4 5          3 7  4
+--R               (- 153600a b c  - 192000a b c  + 124800a b c - 16800a b )x
+--R             + 
+--R                         6 2 2          5 4          4 6  2          7   2
+--R               (- 307200a b c  + 153600a b c - 19200a b )x  - 122880a b c
+--R             + 
+--R                     6 3         5 5
+--R               61440a b c - 7680a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                        4   4         3 3 3         2 5 2       9  8
+--R               (- 15360a b c  - 30720a b c  + 13440a b c  - 300b )x
+--R             + 
+--R                         4 2 3         3 4 2         2 6           8  6
+--R               (- 184320a b c  + 15360a b c  + 26880a b c - 4800a b )x
+--R             + 
+--R                         5   3          4 3 2          3 5          2 7  4
+--R               (- 184320a b c  - 230400a b c  + 149760a b c - 20160a b )x
+--R             + 
+--R                         5 2 2          4 4          3 6  2          6   2
+--R               (- 491520a b c  + 245760a b c - 30720a b )x  - 245760a b c
+--R             + 
+--R                      5 3          4 5
+--R               122880a b c - 15360a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                      4 2 4        2 6 2         8       10  10
+--R               (38400a b c  - 6720a b c  + 960a b c + 30b  )x
+--R             + 
+--R                      5   4          4 3 3         3 5 2          9  8
+--R               (76800a b c  + 153600a b c  - 67200a b c  + 1500a b )x
+--R             + 
+--R                       5 2 3         4 4 2         3 6          2 8  6
+--R               (460800a b c  - 38400a b c  - 67200a b c + 12000a b )x
+--R             + 
+--R                       6   3          5 3 2          4 5          3 7  4
+--R               (307200a b c  + 384000a b c  - 249600a b c + 33600a b )x
+--R             + 
+--R                       6 2 2          5 4          4 6  2          7   2
+--R               (614400a b c  - 307200a b c + 38400a b )x  + 245760a b c
+--R             + 
+--R                        6 3          5 5
+--R               - 122880a b c + 15360a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                 5 4         4 2 3         3 4 2       2 6          8  8
+--R           (8192a c  + 14080a b c  - 12480a b c  + 400a b c + 300a b )x
+--R         + 
+--R                  5   3         4 3 2         3 5         2 7  6
+--R           (98304a b c  - 35840a b c  - 20480a b c + 4800a b )x
+--R         + 
+--R                  6 3         5 2 2          4 4          3 6  4
+--R           (98304a c  + 95232a b c  - 122880a b c + 20160a b )x
+--R         + 
+--R                   6   2          5 3          4 5  2          7 2          6 2
+--R           (262144a b c  - 204800a b c + 30720a b )x  + 131072a c  - 102400a b c
+--R         + 
+--R                 5 4
+--R           15360a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                    4   4        3 3 3        2 5 2          7       9  10
+--R           (- 20480a b c  + 5760a b c  + 5344a b c  - 1000a b c - 30b )x
+--R         + 
+--R                    5 4         4 2 3         3 4 2        2 6           8  8
+--R           (- 40960a c  - 70400a b c  + 62400a b c  - 2000a b c - 1500a b )x
+--R         + 
+--R                     5   3         4 3 2         3 5          2 7  6
+--R           (- 245760a b c  + 89600a b c  + 51200a b c - 12000a b )x
+--R         + 
+--R                     6 3          5 2 2          4 4          3 6  4
+--R           (- 163840a c  - 158720a b c  + 204800a b c - 33600a b )x
+--R         + 
+--R                     6   2          5 3          4 5  2          7 2
+--R           (- 327680a b c  + 256000a b c - 38400a b )x  - 131072a c
+--R         + 
+--R                  6 2          5 4
+--R           102400a b c - 15360a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                  2 5            2 4         4 3  8
+--R           (81920a c  + 204800a b c  + 25600b c )x
+--R         + 
+--R                   2   4            3 3  6           3 4           2 2 3  4
+--R           (983040a b c  + 409600a b c )x  + (983040a c  + 1720320a b c )x
+--R         + 
+--R                   3   3 2           4 3
+--R           2621440a b c x  + 1310720a c
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                     2   5            3 4        5 3  10
+--R           (- 204800a b c  - 102400a b c  - 2560b c )x
+--R         + 
+--R                     3 5           2 2 4            4 3  8
+--R           (- 409600a c  - 1024000a b c  - 128000a b c )x
+--R         + 
+--R                      3   4           2 3 3  6
+--R           (- 2457600a b c  - 1024000a b c )x
+--R         + 
+--R                      4 4           3 2 3  4           4   3 2           5 3
+--R           (- 1638400a c  - 2867200a b c )x  - 3276800a b c x  - 1310720a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 1338
+
+--S 1339 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1339
+
+)clear all
+
+--S 1340 of 1353
+t0:=x*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                            +---------------+
+--R            5      3        |   4      2
+--R   (1)  (c x  + b x  + a x)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1340
+
+--S 1341 of 1353
+r0:=1/16*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c+3/256*(b^2-4*a*c)^2*_
+   atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(5/2)-3/128*_
+   (b^2-4*a*c)*(b+2*c*x^2)*sqrt(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                                                2
+--R           2 2        2      4              2c x  + b
+--R       (48a c  - 24a b c + 3b )atanh(-----------------------)
+--R                                           +---------------+
+--R                                       +-+ |   4      2
+--R                                     2\|c \|c x  + b x  + a
+--R     + 
+--R             3 6        2 4         2     2   2               3  +-+
+--R         (32c x  + 48b c x  + (80a c  + 4b c)x  + 40a b c - 6b )\|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R  /
+--R         2 +-+
+--R     256c \|c
+--R                                                    Type: Expression(Integer)
+--E 1341
+
+--S 1342 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       3   3       2 3 2        5       7  6
+--R                 (1536a b c  - 384a b c  - 96a b c + 24b )x
+--R               + 
+--R                       4 3        3 2 2        2 4          6  4
+--R                 (3072a c  + 2304a b c  - 1728a b c + 240a b )x
+--R               + 
+--R                       4   2        3 3        2 5  2        5 2        4 2
+--R                 (9216a b c  - 4608a b c + 576a b )x  + 6144a c  - 3072a b c
+--R               + 
+--R                     3 4
+--R                 384a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                    4 4       3 2 3       2 4 2        6      8  8
+--R             (- 768a c  - 768a b c  + 480a b c  - 48a b c - 3b )x
+--R           + 
+--R                     4   3        3 3 2       2 5         7  6
+--R             (- 6144a b c  + 1536a b c  + 384a b c - 96a b )x
+--R           + 
+--R                     5 3        4 2 2        3 4        2 6  4
+--R             (- 6144a c  - 4608a b c  + 3456a b c - 480a b )x
+--R           + 
+--R                      5   2        4 3        3 5  2        6 2        5 2
+--R             (- 12288a b c  + 6144a b c - 768a b )x  - 6144a c  + 3072a b c
+--R           + 
+--R                   4 4
+--R             - 384a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                    2 5         2 4      4 3  14
+--R             (- 512a c  - 768a b c  - 32b c )x
+--R           + 
+--R                     2   4          3 3      5 2  12
+--R             (- 4864a b c  - 2176a b c  - 48b c )x
+--R           + 
+--R                     3 4         2 2 3          4 2     6   10
+--R             (- 5376a c  - 13248a b c  - 1712a b c  - 4b c)x
+--R           + 
+--R                      3   3         2 3 2        5      7  8
+--R             (- 25216a b c  - 11616a b c  - 24a b c + 6b )x
+--R           + 
+--R                      4 3         3 2 2        2 4          6  6
+--R             (- 14336a c  - 29440a b c  - 1024a b c + 144a b )x
+--R           + 
+--R                      4   2        3 3        2 5  4
+--R             (- 29184a b c  - 3840a b c + 480a b )x
+--R           + 
+--R                      5 2        4 2        3 4  2
+--R             (- 10240a c  - 3072a b c + 384a b )x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                       5       3 4  16         2 5          2 4       4 3  14
+--R             (1024a b c  + 256b c )x   + (2048a c  + 5120a b c  + 640b c )x
+--R           + 
+--R                    2   4          3 3       5 2  12
+--R             (14848a b c  + 8960a b c  + 416b c )x
+--R           + 
+--R                    3 4         2 2 3          4 2      6   10
+--R             (11264a c  + 33024a b c  + 5440a b c  - 16b c)x
+--R           + 
+--R                    3   3         2 3 2         5       7  8
+--R             (44416a b c  + 24480a b c  + 104a b c - 42b )x
+--R           + 
+--R                    4 3         3 2 2        2 4          6  6
+--R             (19456a c  + 44288a b c  + 2368a b c - 336a b )x
+--R           + 
+--R                    4   2        3 3        2 5  4
+--R             (34304a b c  + 5376a b c - 672a b )x
+--R           + 
+--R                    5 2        4 2        3 4  2
+--R             (10240a c  + 3072a b c - 384a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                       3        3 2  6          2 3           2 2  4
+--R             (8192a b c  + 2048b c )x  + (16384a c  + 20480a b c )x
+--R           + 
+--R                   2   2 2         3 2
+--R             49152a b c x  + 32768a c
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                     2 4          2 3       4 2  8
+--R             (- 4096a c  - 6144a b c  - 256b c )x
+--R           + 
+--R                      2   3          3 2  6            3 3         2 2 2  4
+--R             (- 32768a b c  - 8192a b c )x  + (- 32768a c  - 40960a b c )x
+--R           + 
+--R                     3   2 2         4 2
+--R             - 65536a b c x  - 32768a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                       3   3       2 3 2        5       7  6
+--R                 (1536a b c  - 384a b c  - 96a b c + 24b )x
+--R               + 
+--R                       4 3        3 2 2        2 4          6  4
+--R                 (3072a c  + 2304a b c  - 1728a b c + 240a b )x
+--R               + 
+--R                       4   2        3 3        2 5  2        5 2        4 2
+--R                 (9216a b c  - 4608a b c + 576a b )x  + 6144a c  - 3072a b c
+--R               + 
+--R                     3 4
+--R                 384a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                    4 4       3 2 3       2 4 2        6      8  8
+--R             (- 768a c  - 768a b c  + 480a b c  - 48a b c - 3b )x
+--R           + 
+--R                     4   3        3 3 2       2 5         7  6
+--R             (- 6144a b c  + 1536a b c  + 384a b c - 96a b )x
+--R           + 
+--R                     5 3        4 2 2        3 4        2 6  4
+--R             (- 6144a c  - 4608a b c  + 3456a b c - 480a b )x
+--R           + 
+--R                      5   2        4 3        3 5  2        6 2        5 2
+--R             (- 12288a b c  + 6144a b c - 768a b )x  - 6144a c  + 3072a b c
+--R           + 
+--R                   4 4
+--R             - 384a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                    2 5         2 4      4 3  14
+--R             (- 256a c  - 384a b c  - 16b c )x
+--R           + 
+--R                     2   4          3 3      5 2  12
+--R             (- 2432a b c  - 1088a b c  - 24b c )x
+--R           + 
+--R                     3 4        2 2 3         4 2     6   10
+--R             (- 2688a c  - 6624a b c  - 856a b c  - 2b c)x
+--R           + 
+--R                      3   3        2 3 2        5      7  8
+--R             (- 12608a b c  - 5808a b c  - 12a b c + 3b )x
+--R           + 
+--R                     4 3         3 2 2       2 4         6  6
+--R             (- 7168a c  - 14720a b c  - 512a b c + 72a b )x
+--R           + 
+--R                      4   2        3 3        2 5  4
+--R             (- 14592a b c  - 1920a b c + 240a b )x
+--R           + 
+--R                     5 2        4 2        3 4  2
+--R             (- 5120a c  - 1536a b c + 192a b )x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                      5       3 4  16         2 5          2 4       4 3  14
+--R             (512a b c  + 128b c )x   + (1024a c  + 2560a b c  + 320b c )x
+--R           + 
+--R                   2   4          3 3       5 2  12
+--R             (7424a b c  + 4480a b c  + 208b c )x
+--R           + 
+--R                   3 4         2 2 3          4 2     6   10
+--R             (5632a c  + 16512a b c  + 2720a b c  - 8b c)x
+--R           + 
+--R                    3   3         2 3 2        5       7  8
+--R             (22208a b c  + 12240a b c  + 52a b c - 21b )x
+--R           + 
+--R                   4 3         3 2 2        2 4          6  6
+--R             (9728a c  + 22144a b c  + 1184a b c - 168a b )x
+--R           + 
+--R                    4   2        3 3        2 5  4
+--R             (17152a b c  + 2688a b c - 336a b )x
+--R           + 
+--R                   5 2        4 2        3 4  2
+--R             (5120a c  + 1536a b c - 192a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                       3        3 2  6         2 3           2 2  4
+--R             (4096a b c  + 1024b c )x  + (8192a c  + 10240a b c )x
+--R           + 
+--R                   2   2 2         3 2
+--R             24576a b c x  + 16384a c
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                     2 4          2 3       4 2  8
+--R             (- 2048a c  - 3072a b c  - 128b c )x
+--R           + 
+--R                      2   3          3 2  6            3 3         2 2 2  4
+--R             (- 16384a b c  - 4096a b c )x  + (- 16384a c  - 20480a b c )x
+--R           + 
+--R                     3   2 2         4 2
+--R             - 32768a b c x  - 16384a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1342
+
+--S 1343 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     3   3       2 3 2        5       7  6
+--R               (1536a b c  - 384a b c  - 96a b c + 24b )x
+--R             + 
+--R                     4 3        3 2 2        2 4          6  4
+--R               (3072a c  + 2304a b c  - 1728a b c + 240a b )x
+--R             + 
+--R                     4   2        3 3        2 5  2        5 2        4 2
+--R               (9216a b c  - 4608a b c + 576a b )x  + 6144a c  - 3072a b c
+--R             + 
+--R                   3 4
+--R               384a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                  4 4       3 2 3       2 4 2        6      8  8
+--R           (- 768a c  - 768a b c  + 480a b c  - 48a b c - 3b )x
+--R         + 
+--R                   4   3        3 3 2       2 5         7  6
+--R           (- 6144a b c  + 1536a b c  + 384a b c - 96a b )x
+--R         + 
+--R                   5 3        4 2 2        3 4        2 6  4
+--R           (- 6144a c  - 4608a b c  + 3456a b c - 480a b )x
+--R         + 
+--R                    5   2        4 3        3 5  2        6 2        5 2
+--R           (- 12288a b c  + 6144a b c - 768a b )x  - 6144a c  + 3072a b c
+--R         + 
+--R                 4 4
+--R           - 384a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                       3   3       2 3 2        5       7  6
+--R               (- 1536a b c  + 384a b c  + 96a b c - 24b )x
+--R             + 
+--R                       4 3        3 2 2        2 4          6  4
+--R               (- 3072a c  - 2304a b c  + 1728a b c - 240a b )x
+--R             + 
+--R                       4   2        3 3        2 5  2        5 2        4 2
+--R               (- 9216a b c  + 4608a b c - 576a b )x  - 6144a c  + 3072a b c
+--R             + 
+--R                     3 4
+--R               - 384a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                4 4       3 2 3       2 4 2        6      8  8
+--R           (768a c  + 768a b c  - 480a b c  + 48a b c + 3b )x
+--R         + 
+--R                 4   3        3 3 2       2 5         7  6
+--R           (6144a b c  - 1536a b c  - 384a b c + 96a b )x
+--R         + 
+--R                 5 3        4 2 2        3 4        2 6  4
+--R           (6144a c  + 4608a b c  - 3456a b c + 480a b )x
+--R         + 
+--R                5   2        4 3        3 5  2        6 2        5 2        4 4
+--R         (12288a b c  - 6144a b c + 768a b )x  + 6144a c  - 3072a b c + 384a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                 3 2 2       2 4         6  6
+--R           (1280a b c  + 128a b c - 48a b )x
+--R         + 
+--R                 4   2        3 3        2 5  4         4 2         3 4  2
+--R           (2560a b c  + 2816a b c - 480a b )x  + (7680a b c - 1152a b )x
+--R         + 
+--R                5          4 3
+--R           5120a b c - 768a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                  3   3       2 3 2         5      7  8
+--R           (- 640a b c  - 864a b c  + 104a b c + 6b )x
+--R         + 
+--R                   3 2 2       2 4          6  6
+--R           (- 5120a b c  - 512a b c + 192a b )x
+--R         + 
+--R                   4   2        3 3        2 5  4            4 2         3 4  2
+--R           (- 5120a b c  - 5632a b c + 960a b )x  + (- 10240a b c + 1536a b )x
+--R         + 
+--R                  5          4 3
+--R           - 5120a b c + 768a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                     3        3 2  6          2 3           2 2  4
+--R           (8192a b c  + 2048b c )x  + (16384a c  + 20480a b c )x
+--R         + 
+--R                 2   2 2         3 2
+--R           49152a b c x  + 32768a c
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                   2 4          2 3       4 2  8
+--R           (- 4096a c  - 6144a b c  - 256b c )x
+--R         + 
+--R                    2   3          3 2  6            3 3         2 2 2  4
+--R           (- 32768a b c  - 8192a b c )x  + (- 32768a c  - 40960a b c )x
+--R         + 
+--R                   3   2 2         4 2
+--R           - 65536a b c x  - 32768a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 1343
+
+--S 1344 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1344
+
+--S 1345 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       3   3       2 3 2        5       7  6
+--R               (- 1536a b c  + 384a b c  + 96a b c - 24b )x
+--R             + 
+--R                       4 3        3 2 2        2 4          6  4
+--R               (- 3072a c  - 2304a b c  + 1728a b c - 240a b )x
+--R             + 
+--R                       4   2        3 3        2 5  2        5 2        4 2
+--R               (- 9216a b c  + 4608a b c - 576a b )x  - 6144a c  + 3072a b c
+--R             + 
+--R                     3 4
+--R               - 384a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                    4 4       3 2 3       2 4 2        6      8  8
+--R               (768a c  + 768a b c  - 480a b c  + 48a b c + 3b )x
+--R             + 
+--R                     4   3        3 3 2       2 5         7  6
+--R               (6144a b c  - 1536a b c  - 384a b c + 96a b )x
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6  4
+--R               (6144a c  + 4608a b c  - 3456a b c + 480a b )x
+--R             + 
+--R                      5   2        4 3        3 5  2        6 2        5 2
+--R               (12288a b c  - 6144a b c + 768a b )x  + 6144a c  - 3072a b c
+--R             + 
+--R                   4 4
+--R               384a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                     3   3       2 3 2         5       7  6
+--R               (3072a b c  - 768a b c  - 192a b c + 48b )x
+--R             + 
+--R                     4 3        3 2 2        2 4          6  4
+--R               (6144a c  + 4608a b c  - 3456a b c + 480a b )x
+--R             + 
+--R                      4   2        3 3         2 5  2         5 2        4 2
+--R               (18432a b c  - 9216a b c + 1152a b )x  + 12288a c  - 6144a b c
+--R             + 
+--R                   3 4
+--R               768a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                       4 4        3 2 3       2 4 2        6      8  8
+--R               (- 1536a c  - 1536a b c  + 960a b c  - 96a b c - 6b )x
+--R             + 
+--R                        4   3        3 3 2       2 5          7  6
+--R               (- 12288a b c  + 3072a b c  + 768a b c - 192a b )x
+--R             + 
+--R                        5 3        4 2 2        3 4        2 6  4
+--R               (- 12288a c  - 9216a b c  + 6912a b c - 960a b )x
+--R             + 
+--R                        5   2         4 3         3 5  2         6 2        5 2
+--R               (- 24576a b c  + 12288a b c - 1536a b )x  - 12288a c  + 6144a b c
+--R             + 
+--R                     4 4
+--R               - 768a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                 3 2 2       2 4         6  6
+--R           (1280a b c  + 128a b c - 48a b )x
+--R         + 
+--R                 4   2        3 3        2 5  4         4 2         3 4  2
+--R           (2560a b c  + 2816a b c - 480a b )x  + (7680a b c - 1152a b )x
+--R         + 
+--R                5          4 3
+--R           5120a b c - 768a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                  3   3       2 3 2         5      7  8
+--R           (- 640a b c  - 864a b c  + 104a b c + 6b )x
+--R         + 
+--R                   3 2 2       2 4          6  6
+--R           (- 5120a b c  - 512a b c + 192a b )x
+--R         + 
+--R                   4   2        3 3        2 5  4            4 2         3 4  2
+--R           (- 5120a b c  - 5632a b c + 960a b )x  + (- 10240a b c + 1536a b )x
+--R         + 
+--R                  5          4 3
+--R           - 5120a b c + 768a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                     3        3 2  6          2 3           2 2  4
+--R           (8192a b c  + 2048b c )x  + (16384a c  + 20480a b c )x
+--R         + 
+--R                 2   2 2         3 2
+--R           49152a b c x  + 32768a c
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                   2 4          2 3       4 2  8
+--R           (- 4096a c  - 6144a b c  - 256b c )x
+--R         + 
+--R                    2   3          3 2  6            3 3         2 2 2  4
+--R           (- 32768a b c  - 8192a b c )x  + (- 32768a c  - 40960a b c )x
+--R         + 
+--R                   3   2 2         4 2
+--R           - 65536a b c x  - 32768a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 1345
+
+--S 1346 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1346
+
+)clear all
+
+--S 1347 of 1353
+t0:=(a+b*x^2+c*x^4)^(3/2)/x
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 1347
+
+--S 1348 of 1353
+r0:=1/6*(a+b*x^2+c*x^4)^(3/2)-1/2*a^(3/2)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*_
+   sqrt(a+b*x^2+c*x^4)))-1/32*b*(b^2-12*a*c)*atanh(1/2*(b+2*c*x^2)/_
+   (sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(3/2)+1/16*(b^2+8*a*c+2*b*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                      2
+--R               +-+ +-+             b x  + 2a
+--R       - 48a c\|a \|c atanh(-----------------------)
+--R                                  +---------------+
+--R                              +-+ |   4      2
+--R                            2\|a \|c x  + b x  + a
+--R     + 
+--R                                       2
+--R                    3              2c x  + b
+--R       (36a b c - 3b )atanh(-----------------------)
+--R                                  +---------------+
+--R                              +-+ |   4      2
+--R                            2\|c \|c x  + b x  + a
+--R     + 
+--R                                             +---------------+
+--R           2 4          2             2  +-+ |   4      2
+--R       (16c x  + 28b c x  + 64a c + 6b )\|c \|c x  + b x  + a
+--R  /
+--R         +-+
+--R     96c\|c
+--R                                                    Type: Expression(Integer)
+--E 1348
+
+--S 1349 of 1353
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     3 2       2 2   4        3     2        4   +-+
+--R               ((384a c  + 288a b c)x  + 1536a b c x  + 1536a c)\|c
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                        2   2        3   6           3 2       2 2   4
+--R                 (- 576a b c  - 48a b c)x  + (- 1152a c  - 864a b c)x
+--R               + 
+--R                        3     2        4
+--R                 - 2304a b c x  - 1536a c
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                      2   2         3       5  4         2 2         4  2
+--R                 (288a b c  + 192a b c - 18b )x  + (1152a b c - 96a b )x
+--R               + 
+--R                      3         2 3
+--R                 1152a b c - 96a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                    2 2 2     6  6          3   2       2 3         5  4
+--R             (- 432a b c  + 3b )x  + (- 864a b c  - 576a b c + 54a b )x
+--R           + 
+--R                     3 2        2 4  2        4         3 3
+--R             (- 1728a b c + 144a b )x  - 1152a b c + 96a b
+--R        *
+--R           log
+--R                            4         2     2  +-+            4         2  +-+
+--R                    ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                           6              2  4         2     2  +-+ +-+
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c
+--R                + 
+--R                      2 6           4     2   2
+--R                  4a c x  + 6a b c x  + 8a c x
+--R             /
+--R                                  +---------------+
+--R                         2     2  |   4      2
+--R                  (4a b x  + 8a )\|c x  + b x  + a
+--R                + 
+--R                              2  4         2     2  +-+
+--R                  ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R       + 
+--R                        3      3 2  10          2 3         2 2      4   8
+--R             (- 192a b c  - 16b c )x   + (- 384a c  - 624a b c  - 28b c)x
+--R           + 
+--R                     2   2         3      5  6
+--R             (- 2208a b c  - 640a b c - 6b )x
+--R           + 
+--R                     3 2        2 2         4  4           3         2 3  2
+--R             (- 1536a c  - 2208a b c - 72a b )x  + (- 1920a b c - 96a b )x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                    4      2 3  12            3       3 2  10
+--R             (128a c  + 96b c )x   + (864a b c  + 264b c )x
+--R           + 
+--R                   2 3          2 2       4   8
+--R             (1152a c  + 2160a b c  + 204b c)x
+--R           + 
+--R                   2   2          3       5  6
+--R             (3936a b c  + 1552a b c + 30b )x
+--R           + 
+--R                   3 2        2 2          4  4         3         2 3  2
+--R             (1536a c  + 3168a b c + 120a b )x  + (1920a b c + 96a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                   2       2   4              2        2   +-+ +-+
+--R           ((768a c  + 576b c)x  + 3072a b c x  + 3072a c)\|a \|c
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                         2      3   6           2 2          2   4
+--R             (- 1152a b c  - 96b c)x  + (- 2304a c  - 1728a b c)x
+--R           + 
+--R                    2     2        3
+--R             - 4608a b c x  - 3072a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                     3 2       2 2   4       3     2       4   +---+
+--R               ((192a c  + 144a b c)x  + 768a b c x  + 768a c)\|- c
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                        2   2        3   6          3 2       2 2   4
+--R                 (- 288a b c  - 24a b c)x  + (- 576a c  - 432a b c)x
+--R               + 
+--R                        3     2       4
+--R                 - 1152a b c x  - 768a c
+--R            *
+--R                +---+ +-+
+--R               \|- c \|a
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                      2   2         3       5  4         2 2         4  2
+--R                 (288a b c  + 192a b c - 18b )x  + (1152a b c - 96a b )x
+--R               + 
+--R                      3         2 3
+--R                 1152a b c - 96a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                    2 2 2     6  6          3   2       2 3         5  4
+--R             (- 432a b c  + 3b )x  + (- 864a b c  - 576a b c + 54a b )x
+--R           + 
+--R                     3 2        2 4  2        4         3 3
+--R             (- 1728a b c + 144a b )x  - 1152a b c + 96a b
+--R        *
+--R                           +---------------+
+--R                 +---+ +-+ |   4      2          +---+
+--R                \|- c \|a \|c x  + b x  + a  - a\|- c
+--R           atan(--------------------------------------)
+--R                                  2 +-+
+--R                               c x \|a
+--R       + 
+--R                       3     3 2  10          2 3         2 2      4   8
+--R             (- 96a b c  - 8b c )x   + (- 192a c  - 312a b c  - 14b c)x
+--R           + 
+--R                     2   2         3      5  6
+--R             (- 1104a b c  - 320a b c - 3b )x
+--R           + 
+--R                    3 2        2 2         4  4          3         2 3  2
+--R             (- 768a c  - 1104a b c - 36a b )x  + (- 960a b c - 48a b )x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                   4      2 3  12            3       3 2  10
+--R             (64a c  + 48b c )x   + (432a b c  + 132b c )x
+--R           + 
+--R                  2 3          2 2       4   8
+--R             (576a c  + 1080a b c  + 102b c)x
+--R           + 
+--R                   2   2         3       5  6        3 2        2 2         4  4
+--R             (1968a b c  + 776a b c + 15b )x  + (768a c  + 1584a b c + 60a b )x
+--R           + 
+--R                  3         2 3  2
+--R             (960a b c + 48a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                   2       2   4              2        2   +---+ +-+
+--R           ((384a c  + 288b c)x  + 1536a b c x  + 1536a c)\|- c \|a
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                        2      3   6           2 2         2   4        2     2
+--R             (- 576a b c  - 48b c)x  + (- 1152a c  - 864a b c)x  - 2304a b c x
+--R           + 
+--R                    3
+--R             - 1536a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1349
+
+--S 1350 of 1353
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                   3 2       2 2   4        3     2        4   +-+
+--R             ((384a c  + 288a b c)x  + 1536a b c x  + 1536a c)\|c
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                      2   2        3   6           3 2       2 2   4
+--R               (- 576a b c  - 48a b c)x  + (- 1152a c  - 864a b c)x
+--R             + 
+--R                      3     2        4
+--R               - 2304a b c x  - 1536a c
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                    2   2         3       5  4         2 2         4  2
+--R               (288a b c  + 192a b c - 18b )x  + (1152a b c - 96a b )x
+--R             + 
+--R                    3         2 3
+--R               1152a b c - 96a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                  2 2 2     6  6          3   2       2 3         5  4
+--R           (- 432a b c  + 3b )x  + (- 864a b c  - 576a b c + 54a b )x
+--R         + 
+--R                   3 2        2 4  2        4         3 3
+--R           (- 1728a b c + 144a b )x  - 1152a b c + 96a b
+--R      *
+--R         log
+--R                          4         2     2  +-+            4         2  +-+
+--R                  ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R               *
+--R                   +---------------+
+--R                   |   4      2
+--R                  \|c x  + b x  + a
+--R              + 
+--R                         6              2  4         2     2  +-+ +-+       2 6
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c  + 4a c x
+--R              + 
+--R                        4     2   2
+--R                6a b c x  + 8a c x
+--R           /
+--R                                +---------------+
+--R                       2     2  |   4      2
+--R                (4a b x  + 8a )\|c x  + b x  + a
+--R              + 
+--R                            2  4         2     2  +-+
+--R                ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R     + 
+--R                   3 2       2 2   4        3     2        4   +-+
+--R             ((384a c  + 288a b c)x  + 1536a b c x  + 1536a c)\|c
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                      2   2        3   6           3 2       2 2   4
+--R               (- 576a b c  - 48a b c)x  + (- 1152a c  - 864a b c)x
+--R             + 
+--R                      3     2        4
+--R               - 2304a b c x  - 1536a c
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                      2   2         3       5  4           2 2         4  2
+--R               (- 288a b c  - 192a b c + 18b )x  + (- 1152a b c + 96a b )x
+--R             + 
+--R                      3         2 3
+--R               - 1152a b c + 96a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                2 2 2     6  6        3   2       2 3         5  4
+--R           (432a b c  - 3b )x  + (864a b c  + 576a b c - 54a b )x
+--R         + 
+--R                 3 2        2 4  2        4         3 3
+--R           (1728a b c - 144a b )x  + 1152a b c - 96a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                3 2       2 2         4  4         3          2 3  2        4
+--R           (512a c  + 432a b c + 36a b )x  + (2048a b c + 192a b )x  + 2048a c
+--R         + 
+--R               3 2
+--R           192a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                  2   2         3      5  6
+--R           (- 768a b c  - 136a b c - 6b )x
+--R         + 
+--R                   3 2        2 2          4  4           3          2 3  2
+--R           (- 1536a c  - 1296a b c - 108a b )x  + (- 3072a b c - 288a b )x
+--R         + 
+--R                  4        3 2
+--R           - 2048a c - 192a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                                                               +---------------+
+--R               2       2   4              2        2   +-+ +-+ |   4      2
+--R       ((768a c  + 576b c)x  + 3072a b c x  + 3072a c)\|a \|c \|c x  + b x  + a
+--R     + 
+--R                       2      3   6           2 2          2   4        2     2
+--R           (- 1152a b c  - 96b c)x  + (- 2304a c  - 1728a b c)x  - 4608a b c x
+--R         + 
+--R                  3
+--R           - 3072a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 1350
+
+--S 1351 of 1353
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1351
+
+--S 1352 of 1353
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                   3 2       2 2   4        3     2        4   +---+ +-+
+--R             ((384a c  + 288a b c)x  + 1536a b c x  + 1536a c)\|- c \|c
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                      2   2        3   6           3 2       2 2   4
+--R               (- 576a b c  - 48a b c)x  + (- 1152a c  - 864a b c)x
+--R             + 
+--R                      3     2        4
+--R               - 2304a b c x  - 1536a c
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                   3 2       2 2   4        3     2        4   +---+ +-+
+--R             ((384a c  + 288a b c)x  + 1536a b c x  + 1536a c)\|- c \|c
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                      2   2        3   6           3 2       2 2   4
+--R               (- 576a b c  - 48a b c)x  + (- 1152a c  - 864a b c)x
+--R             + 
+--R                      3     2        4
+--R               - 2304a b c x  - 1536a c
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                      2   2         3       5  4           2 2         4  2
+--R               (- 288a b c  - 192a b c + 18b )x  + (- 1152a b c + 96a b )x
+--R             + 
+--R                      3         2 3
+--R               - 1152a b c + 96a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                    2 2 2     6  6        3   2       2 3         5  4
+--R               (432a b c  - 3b )x  + (864a b c  + 576a b c - 54a b )x
+--R             + 
+--R                     3 2        2 4  2        4         3 3
+--R               (1728a b c - 144a b )x  + 1152a b c - 96a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                    2   2         3       5  4         2 2          4  2
+--R               (576a b c  + 384a b c - 36b )x  + (2304a b c - 192a b )x
+--R             + 
+--R                    3          2 3
+--R               2304a b c - 192a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                      2 2 2     6  6           3   2        2 3          5  4
+--R               (- 864a b c  + 6b )x  + (- 1728a b c  - 1152a b c + 108a b )x
+--R             + 
+--R                       3 2        2 4  2        4          3 3
+--R               (- 3456a b c + 288a b )x  - 2304a b c + 192a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                         +---------------+
+--R               +---+ +-+ |   4      2          +---+
+--R              \|- c \|a \|c x  + b x  + a  - a\|- c
+--R         atan(--------------------------------------)
+--R                                2 +-+
+--R                             c x \|a
+--R     + 
+--R                3 2       2 2         4  4         3          2 3  2        4
+--R           (512a c  + 432a b c + 36a b )x  + (2048a b c + 192a b )x  + 2048a c
+--R         + 
+--R               3 2
+--R           192a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                  2   2         3      5  6
+--R           (- 768a b c  - 136a b c - 6b )x
+--R         + 
+--R                   3 2        2 2          4  4           3          2 3  2
+--R           (- 1536a c  - 1296a b c - 108a b )x  + (- 3072a b c - 288a b )x
+--R         + 
+--R                  4        3 2
+--R           - 2048a c - 192a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                 2       2   4              2        2   +---+ +-+ +-+
+--R         ((768a c  + 576b c)x  + 3072a b c x  + 3072a c)\|- c \|a \|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                       2      3   6           2 2          2   4        2     2
+--R           (- 1152a b c  - 96b c)x  + (- 2304a c  - 1728a b c)x  - 4608a b c x
+--R         + 
+--R                  3
+--R           - 3072a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 1352
+
+--S 1353 of 1353
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1353
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich14c.input.pamphlet b/src/input/rich14c.input.pamphlet
new file mode 100644
index 0000000..bdbcc95
--- /dev/null
+++ b/src/input/rich14c.input.pamphlet
@@ -0,0 +1,151866 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich14c.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a+b x^2+c x^4)^p|
+
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich14c.output
+)spool rich14c.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^3
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          3
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1057
+r0:=-1/2*(a+b*x^2+c*x^4)^(3/2)/x^2-3/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*_
+   sqrt(a+b*x^2+c*x^4)))*sqrt(a)+3/16*(b^2+4*a*c)*atanh(1/2*(b+2*c*x^2)/_
+   (sqrt(c)*sqrt(a+b*x^2+c*x^4)))/sqrt(c)+3/8*(3*b+2*c*x^2)*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (2)
+--R                                       2
+--R              2 +-+ +-+             b x  + 2a
+--R       - 12b x \|a \|c atanh(-----------------------)
+--R                                   +---------------+
+--R                               +-+ |   4      2
+--R                             2\|a \|c x  + b x  + a
+--R     + 
+--R                                       2
+--R                  2  2             2c x  + b
+--R       (12a c + 3b )x atanh(-----------------------)
+--R                                  +---------------+
+--R                              +-+ |   4      2
+--R                            2\|c \|c x  + b x  + a
+--R     + 
+--R                                 +---------------+
+--R            4        2       +-+ |   4      2
+--R       (4c x  + 10b x  - 8a)\|c \|c x  + b x  + a
+--R  /
+--R        2 +-+
+--R     16x \|c
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2           3  6       2 2 4       3   2  +-+ +-+
+--R               ((96a b c + 72a b )x  + 384a b x  + 384a b x )\|a \|c
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                        2 2         4  8          3          2 3  6       3 2 4
+--R                 (- 144a b c - 12a b )x  + (- 288a b c - 216a b )x  - 576a b x
+--R               + 
+--R                       4   2
+--R                 - 384a b x
+--R            *
+--R                +-+
+--R               \|c
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                     3 2      2 2         4  6        3         2 3  4
+--R                 (96a c  + 96a b c + 18a b )x  + (384a b c + 96a b )x
+--R               + 
+--R                      4       3 2  2
+--R                 (384a c + 96a b )x
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                        2   2        3      5  8
+--R                 (- 144a b c  - 48a b c - 3b )x
+--R               + 
+--R                        3 2       2 2         4  6          3          2 3  4
+--R                 (- 288a c  - 288a b c - 54a b )x  + (- 576a b c - 144a b )x
+--R               + 
+--R                        4       3 2  2
+--R                 (- 384a c - 96a b )x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R           log
+--R                            4         2     2  +-+            4         2  +-+
+--R                    ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                           6              2  4         2     2  +-+ +-+
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c
+--R                + 
+--R                      2 6           4     2   2
+--R                  4a c x  + 6a b c x  + 8a c x
+--R             /
+--R                                  +---------------+
+--R                         2     2  |   4      2
+--R                  (4a b x  + 8a )\|c x  + b x  + a
+--R                + 
+--R                              2  4         2     2  +-+
+--R                  ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R       + 
+--R                       2     3   10         2 2         2       4  8
+--R             (- 48a b c  - 4b c)x   + (- 96a c  - 192a b c - 10b )x
+--R           + 
+--R                    2            3  6       3       2 2  4       3   2       4
+--R             (- 272a b c - 124a b )x  + (64a c - 80a b )x  + 320a b x  + 256a
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                 2 3        2 2  12        2   2        3   10
+--R             (32a c  + 24a b c )x   + (240a b c  + 84a b c)x
+--R           + 
+--R                 3 2       2 2         4  8        3          2 3  6
+--R             (96a c  + 408a b c + 52a b )x  + (144a b c + 188a b )x
+--R           + 
+--R                    4       3 2  4       4   2       5
+--R             (- 192a c - 48a b )x  - 448a b x  - 256a
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                                                         +---------------+
+--R               2         2  6       2   4       3 2  +-+ |   4      2
+--R         ((128a c + 96a b )x  + 512a b x  + 512a x )\|c \|c x  + b x  + a
+--R       + 
+--R                                3  8          2          2  6       2   4
+--R               (- 192a b c - 16b )x  + (- 384a c - 288a b )x  - 768a b x
+--R             + 
+--R                     3 2
+--R               - 512a x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R     ,
+--R
+--R                    2           3  6       2 2 4       3   2  +---+ +-+
+--R               ((48a b c + 36a b )x  + 192a b x  + 192a b x )\|- c \|a
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                       2 2        4  8          3          2 3  6       3 2 4
+--R                 (- 72a b c - 6a b )x  + (- 144a b c - 108a b )x  - 288a b x
+--R               + 
+--R                       4   2
+--R                 - 192a b x
+--R            *
+--R                +---+
+--R               \|- c
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                     3 2      2 2         4  6        3         2 3  4
+--R                 (96a c  + 96a b c + 18a b )x  + (384a b c + 96a b )x
+--R               + 
+--R                      4       3 2  2
+--R                 (384a c + 96a b )x
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                        2   2        3      5  8
+--R                 (- 144a b c  - 48a b c - 3b )x
+--R               + 
+--R                        3 2       2 2         4  6          3          2 3  4
+--R                 (- 288a c  - 288a b c - 54a b )x  + (- 576a b c - 144a b )x
+--R               + 
+--R                        4       3 2  2
+--R                 (- 384a c - 96a b )x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                           +---------------+
+--R                 +---+ +-+ |   4      2          +---+
+--R                \|- c \|a \|c x  + b x  + a  - a\|- c
+--R           atan(--------------------------------------)
+--R                                  2 +-+
+--R                               c x \|a
+--R       + 
+--R                       2     3   10         2 2        2      4  8
+--R             (- 24a b c  - 2b c)x   + (- 48a c  - 96a b c - 5b )x
+--R           + 
+--R                    2           3  6       3       2 2  4       3   2       4
+--R             (- 136a b c - 62a b )x  + (32a c - 40a b )x  + 160a b x  + 128a
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                 2 3        2 2  12        2   2        3   10
+--R             (16a c  + 12a b c )x   + (120a b c  + 42a b c)x
+--R           + 
+--R                 3 2       2 2         4  8       3         2 3  6
+--R             (48a c  + 204a b c + 26a b )x  + (72a b c + 94a b )x
+--R           + 
+--R                   4       3 2  4       4   2       5
+--R             (- 96a c - 24a b )x  - 224a b x  - 128a
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                                                          +---------------+
+--R              2         2  6       2   4       3 2  +---+ |   4      2
+--R         ((64a c + 48a b )x  + 256a b x  + 256a x )\|- c \|c x  + b x  + a
+--R       + 
+--R                           3  8          2          2  6       2   4       3 2
+--R           ((- 96a b c - 8b )x  + (- 192a c - 144a b )x  - 384a b x  - 256a x )
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 3
+
+--S 4 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                               +---------------+
+--R                2           3  4       2 2 2       3   +-+ +-+ |   4      2
+--R           ((96a b c + 72a b )x  + 384a b x  + 384a b)\|a \|c \|c x  + b x  + a
+--R         + 
+--R                      2 2         4  6          3          2 3  4       3 2 2
+--R               (- 144a b c - 12a b )x  + (- 288a b c - 216a b )x  - 576a b x
+--R             + 
+--R                     4
+--R               - 384a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                   3 2      2 2         4  4        3         2 3  2       4
+--R               (96a c  + 96a b c + 18a b )x  + (384a b c + 96a b )x  + 384a c
+--R             + 
+--R                  3 2
+--R               96a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                      2   2        3      5  6
+--R               (- 144a b c  - 48a b c - 3b )x
+--R             + 
+--R                      3 2       2 2         4  4          3          2 3  2
+--R               (- 288a c  - 288a b c - 54a b )x  + (- 576a b c - 144a b )x
+--R             + 
+--R                     4       3 2
+--R               - 384a c - 96a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         log
+--R                          4         2     2  +-+            4         2  +-+
+--R                  ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R               *
+--R                   +---------------+
+--R                   |   4      2
+--R                  \|c x  + b x  + a
+--R              + 
+--R                         6              2  4         2     2  +-+ +-+       2 6
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c  + 4a c x
+--R              + 
+--R                        4     2   2
+--R                6a b c x  + 8a c x
+--R           /
+--R                                +---------------+
+--R                       2     2  |   4      2
+--R                (4a b x  + 8a )\|c x  + b x  + a
+--R              + 
+--R                            2  4         2     2  +-+
+--R                ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R     + 
+--R                                                               +---------------+
+--R                2           3  4       2 2 2       3   +-+ +-+ |   4      2
+--R           ((96a b c + 72a b )x  + 384a b x  + 384a b)\|a \|c \|c x  + b x  + a
+--R         + 
+--R                      2 2         4  6          3          2 3  4       3 2 2
+--R               (- 144a b c - 12a b )x  + (- 288a b c - 216a b )x  - 576a b x
+--R             + 
+--R                     4
+--R               - 384a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                     3 2      2 2         4  4          3         2 3  2
+--R               (- 96a c  - 96a b c - 18a b )x  + (- 384a b c - 96a b )x
+--R             + 
+--R                     4       3 2
+--R               - 384a c - 96a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                    2   2        3      5  6        3 2       2 2         4  4
+--R               (144a b c  + 48a b c + 3b )x  + (288a c  + 288a b c + 54a b )x
+--R             + 
+--R                    3          2 3  2       4       3 2
+--R               (576a b c + 144a b )x  + 384a c + 96a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                                                           +---------------+
+--R            2           3  4       2 2 2       3   +-+ +-+ |   4      2
+--R       ((64a b c + 48a b )x  + 256a b x  + 256a b)\|a \|c \|c x  + b x  + a
+--R     + 
+--R            2 2        4  6          3          2 3  4       3 2 2       4   +-+
+--R     ((- 96a b c - 8a b )x  + (- 192a b c - 144a b )x  - 384a b x  - 256a b)\|c
+--R  /
+--R                                                     +---------------+
+--R             2         2  4       2   2       3  +-+ |   4      2
+--R       ((128a c + 96a b )x  + 512a b x  + 512a )\|c \|c x  + b x  + a
+--R     + 
+--R                           3  6          2          2  4       2   2       3
+--R         ((- 192a b c - 16b )x  + (- 384a c - 288a b )x  - 768a b x  - 512a )
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                  2           3  4       2 2 2       3   +---+ +-+ +-+
+--R             ((96a b c + 72a b )x  + 384a b x  + 384a b)\|- c \|a \|c
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                      2 2         4  6          3          2 3  4       3 2 2
+--R               (- 144a b c - 12a b )x  + (- 288a b c - 216a b )x  - 576a b x
+--R             + 
+--R                     4
+--R               - 384a b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                  2           3  4       2 2 2       3   +---+ +-+ +-+
+--R             ((96a b c + 72a b )x  + 384a b x  + 384a b)\|- c \|a \|c
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                      2 2         4  6          3          2 3  4       3 2 2
+--R               (- 144a b c - 12a b )x  + (- 288a b c - 216a b )x  - 576a b x
+--R             + 
+--R                     4
+--R               - 384a b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                     3 2      2 2         4  4          3         2 3  2
+--R               (- 96a c  - 96a b c - 18a b )x  + (- 384a b c - 96a b )x
+--R             + 
+--R                     4       3 2
+--R               - 384a c - 96a b
+--R          *
+--R                    +---------------+
+--R              +---+ |   4      2
+--R             \|- c \|c x  + b x  + a
+--R         + 
+--R                    2   2        3      5  6        3 2       2 2         4  4
+--R               (144a b c  + 48a b c + 3b )x  + (288a c  + 288a b c + 54a b )x
+--R             + 
+--R                    3          2 3  2       4       3 2
+--R               (576a b c + 144a b )x  + 384a c + 96a b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                    3 2       2 2         4  4        3          2 3  2       4
+--R               (192a c  + 192a b c + 36a b )x  + (768a b c + 192a b )x  + 768a c
+--R             + 
+--R                   3 2
+--R               192a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|c \|c x  + b x  + a
+--R         + 
+--R                      2   2        3      5  6
+--R               (- 288a b c  - 96a b c - 6b )x
+--R             + 
+--R                      3 2       2 2          4  4           3          2 3  2
+--R               (- 576a c  - 576a b c - 108a b )x  + (- 1152a b c - 288a b )x
+--R             + 
+--R                     4        3 2
+--R               - 768a c - 192a b
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                         +---------------+
+--R               +---+ +-+ |   4      2          +---+
+--R              \|- c \|a \|c x  + b x  + a  - a\|- c
+--R         atan(--------------------------------------)
+--R                                2 +-+
+--R                             c x \|a
+--R     + 
+--R              2           3  4       2 2 2       3   +---+ +-+ +-+
+--R         ((64a b c + 48a b )x  + 256a b x  + 256a b)\|- c \|a \|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                2 2        4  6          3          2 3  4       3 2 2       4
+--R         ((- 96a b c - 8a b )x  + (- 192a b c - 144a b )x  - 384a b x  - 256a b)
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                                                           +---------------+
+--R             2         2  4       2   2       3  +---+ +-+ |   4      2
+--R       ((128a c + 96a b )x  + 512a b x  + 512a )\|- c \|c \|c x  + b x  + a
+--R     + 
+--R                           3  6          2          2  4       2   2       3
+--R         ((- 192a b c - 16b )x  + (- 384a c - 288a b )x  - 768a b x  - 512a )
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 7
+
+)clear all
+
+--S 8 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^5
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          5
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 1057
+r0:=-1/4*(a+b*x^2+c*x^4)^(3/2)/x^4-3/16*(b^2+4*a*c)*atanh(1/2*(2*a+b*x^2)/_
+   (sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)+3/4*b*atanh(1/2*(b+2*c*x^2)/_
+   (sqrt(c)*sqrt(a+b*x^2+c*x^4)))*sqrt(c)-3/8*(b-2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                                        2
+--R                    2  4             b x  + 2a
+--R       (- 12a c - 3b )x atanh(-----------------------)
+--R                                    +---------------+
+--R                                +-+ |   4      2
+--R                              2\|a \|c x  + b x  + a
+--R     + 
+--R                                      2
+--R            4 +-+ +-+             2c x  + b
+--R       12b x \|a \|c atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|c \|c x  + b x  + a
+--R     + 
+--R                                 +---------------+
+--R            4        2       +-+ |   4      2
+--R       (8c x  - 10b x  - 4a)\|a \|c x  + b x  + a
+--R  /
+--R        4 +-+
+--R     16x \|a
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3 2       2 2         4  8         3          2 3  6
+--R                 (384a c  + 384a b c + 72a b )x  + (1536a b c + 384a b )x
+--R               + 
+--R                       4        3 2  4
+--R                 (1536a c + 384a b )x
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                        2   2         3       5  10
+--R                 (- 576a b c  - 192a b c - 12b )x
+--R               + 
+--R                         3 2        2 2          4  8
+--R                 (- 1152a c  - 1152a b c - 216a b )x
+--R               + 
+--R                         3          2 3  6           4        3 2  4
+--R                 (- 2304a b c - 576a b )x  + (- 1536a c - 384a b )x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                     2            3  8        2 2 6        3   4  +-+ +-+
+--R               ((384a b c + 288a b )x  + 1536a b x  + 1536a b x )\|a \|c
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                        2 2         4  10           3          2 3  8
+--R                 (- 576a b c - 48a b )x   + (- 1152a b c - 864a b )x
+--R               + 
+--R                        3 2 6        4   4
+--R                 - 2304a b x  - 1536a b x
+--R            *
+--R                +-+
+--R               \|c
+--R        *
+--R           log
+--R                            4       2  +-+ +-+         4         2     2
+--R                    ((- 2b x  - 8a x )\|a \|c  + 4a c x  + 4a b x  + 8a )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                         6         4     2 2  +-+
+--R                  (4a c x  + 6a b x  + 8a x )\|c
+--R                + 
+--R                           6              2  4         2     2  +-+
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a
+--R             /
+--R                                  +---------------+
+--R                         2     2  |   4      2
+--R                  (4a b x  + 8a )\|c x  + b x  + a
+--R                + 
+--R                              2  4         2     2  +-+
+--R                  ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R       + 
+--R                    2   2        3   10          3 2      2 2         4  8
+--R             (- 384a b c  - 32a b c)x   + (- 512a c  + 24a b c - 14a b )x
+--R           + 
+--R                3          2 3  6        4         3 2  4        4   2       5
+--R           (640a b c + 448a b )x  + (384a c + 1920a b )x  + 2048a b x  + 512a
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                  2 3         2 2  12        2   2        3      5  10
+--R             (256a c  + 192a b c )x   + (576a b c  + 28a b c + 9b )x
+--R           + 
+--R                  3 2       2 2         4  8           3           2 3  6
+--R             (384a c  - 840a b c - 78a b )x  + (- 1728a b c - 1184a b )x
+--R           + 
+--R                    4         3 2  4        4   2       5
+--R             (- 640a c - 2880a b )x  - 2304a b x  - 512a
+--R        *
+--R            +-+
+--R           \|a
+--R    /
+--R                                                            +---------------+
+--R               2          2  8        2   6        3 4  +-+ |   4      2
+--R         ((512a c + 384a b )x  + 2048a b x  + 2048a x )\|a \|c x  + b x  + a
+--R       + 
+--R                2           3  10           3         2 2  8        3   6
+--R         (- 768a b c - 64a b )x   + (- 1536a c - 1152a b )x  - 3072a b x
+--R       + 
+--R                4 4
+--R         - 2048a x
+--R     ,
+--R
+--R                      3 2       2 2         4  8         3          2 3  6
+--R                 (384a c  + 384a b c + 72a b )x  + (1536a b c + 384a b )x
+--R               + 
+--R                       4        3 2  4
+--R                 (1536a c + 384a b )x
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                        2   2         3       5  10
+--R                 (- 576a b c  - 192a b c - 12b )x
+--R               + 
+--R                         3 2        2 2          4  8
+--R                 (- 1152a c  - 1152a b c - 216a b )x
+--R               + 
+--R                         3          2 3  6           4        3 2  4
+--R                 (- 2304a b c - 576a b )x  + (- 1536a c - 384a b )x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                     2            3  8        2 2 6        3   4  +---+ +-+
+--R               ((768a b c + 576a b )x  + 3072a b x  + 3072a b x )\|- c \|a
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                         2 2         4  10           3           2 3  8
+--R                 (- 1152a b c - 96a b )x   + (- 2304a b c - 1728a b )x
+--R               + 
+--R                        3 2 6        4   4
+--R                 - 4608a b x  - 3072a b x
+--R            *
+--R                +---+
+--R               \|- c
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R                \|a \|c x  + b x  + a  - a
+--R           atan(--------------------------)
+--R                        2 +---+ +-+
+--R                       x \|- c \|a
+--R       + 
+--R                    2   2        3   10          3 2      2 2         4  8
+--R             (- 384a b c  - 32a b c)x   + (- 512a c  + 24a b c - 14a b )x
+--R           + 
+--R                3          2 3  6        4         3 2  4        4   2       5
+--R           (640a b c + 448a b )x  + (384a c + 1920a b )x  + 2048a b x  + 512a
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                  2 3         2 2  12        2   2        3      5  10
+--R             (256a c  + 192a b c )x   + (576a b c  + 28a b c + 9b )x
+--R           + 
+--R                  3 2       2 2         4  8           3           2 3  6
+--R             (384a c  - 840a b c - 78a b )x  + (- 1728a b c - 1184a b )x
+--R           + 
+--R                    4         3 2  4        4   2       5
+--R             (- 640a c - 2880a b )x  - 2304a b x  - 512a
+--R        *
+--R            +-+
+--R           \|a
+--R    /
+--R                                                            +---------------+
+--R               2          2  8        2   6        3 4  +-+ |   4      2
+--R         ((512a c + 384a b )x  + 2048a b x  + 2048a x )\|a \|c x  + b x  + a
+--R       + 
+--R                2           3  10           3         2 2  8        3   6
+--R         (- 768a b c - 64a b )x   + (- 1536a c - 1152a b )x  - 3072a b x
+--R       + 
+--R                4 4
+--R         - 2048a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 10
+
+--S 11 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                               +---------------+
+--R                           +-+ |   4      2           2
+--R                   2     2\|a \|c x  + b x  + a  - b x  - 2a
+--R       (48a c + 12b )log(-----------------------------------)
+--R                                         2 +-+
+--R                                       2x \|a
+--R     + 
+--R             +-+ +-+
+--R         48b\|a \|c
+--R      *
+--R         log
+--R                          4       2  +-+ +-+         4         2     2
+--R                  ((- 2b x  - 8a x )\|a \|c  + 4a c x  + 4a b x  + 8a )
+--R               *
+--R                   +---------------+
+--R                   |   4      2
+--R                  \|c x  + b x  + a
+--R              + 
+--R                       6         4     2 2  +-+
+--R                (4a c x  + 6a b x  + 8a x )\|c
+--R              + 
+--R                         6              2  4         2     2  +-+
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a
+--R           /
+--R                                +---------------+
+--R                       2     2  |   4      2
+--R                (4a b x  + 8a )\|c x  + b x  + a
+--R              + 
+--R                            2  4         2     2  +-+
+--R                ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R     + 
+--R                                     2
+--R                   2              b x  + 2a
+--R       (48a c + 12b )atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|a \|c x  + b x  + a
+--R     + 
+--R                                     2
+--R             +-+ +-+             2c x  + b                     2
+--R       - 48b\|a \|c atanh(-----------------------) + 32a c - 9b
+--R                                +---------------+
+--R                            +-+ |   4      2
+--R                          2\|c \|c x  + b x  + a
+--R  /
+--R        +-+
+--R     64\|a
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                               +---------------+
+--R                           +-+ |   4      2           2
+--R                   2     2\|a \|c x  + b x  + a  - b x  - 2a
+--R       (48a c + 12b )log(-----------------------------------)
+--R                                         2 +-+
+--R                                       2x \|a
+--R     + 
+--R                                     2
+--R                   2              b x  + 2a
+--R       (48a c + 12b )atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|a \|c x  + b x  + a
+--R     + 
+--R                                     2
+--R             +-+ +-+             2c x  + b
+--R       - 48b\|a \|c atanh(-----------------------)
+--R                                +---------------+
+--R                            +-+ |   4      2
+--R                          2\|c \|c x  + b x  + a
+--R     + 
+--R                              +---------------+
+--R                          +-+ |   4      2
+--R           +---+ +-+     \|a \|c x  + b x  + a  - a              2
+--R       96b\|- c \|a atan(--------------------------) + 32a c - 9b
+--R                                 2 +---+ +-+
+--R                                x \|- c \|a
+--R  /
+--R        +-+
+--R     64\|a
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 14
+
+)clear all
+
+--S 15 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^7
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          7
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 15
+
+--S 16 of 1057
+r0:=-1/6*(a+b*x^2+c*x^4)^(3/2)/x^6-1/8*b*(a+b*x^2+c*x^4)^(3/2)/(a*x^4)+_
+   1/32*b*(b^2-12*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+_
+   c*x^4)))/a^(3/2)+1/2*c^(3/2)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))+1/16*(b^2-8*a*c+2*b*c*x^2)*sqrt(a+b*x^2+c*x^4)/(a*x^2)
+--R 
+--R
+--R   (2)
+--R                                          2
+--R                      3  6             b x  + 2a
+--R       (- 36a b c + 3b )x atanh(-----------------------)
+--R                                      +---------------+
+--R                                  +-+ |   4      2
+--R                                2\|a \|c x  + b x  + a
+--R     + 
+--R                                        2
+--R              6 +-+ +-+             2c x  + b
+--R       48a c x \|a \|c atanh(-----------------------)
+--R                                   +---------------+
+--R                               +-+ |   4      2
+--R                             2\|c \|c x  + b x  + a
+--R     + 
+--R                                                 +---------------+
+--R                     2  4          2      2  +-+ |   4      2
+--R       ((- 64a c - 6b )x  - 28a b x  - 16a )\|a \|c x  + b x  + a
+--R  /
+--R          6 +-+
+--R     96a x \|a
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       2   2         3       5  10         2 2          4  8
+--R                 (1152a b c  + 768a b c - 72b )x   + (4608a b c - 384a b )x
+--R               + 
+--R                       3          2 3  6
+--R                 (4608a b c - 384a b )x
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                     2 2 2      6  12           3   2        2 3          5  10
+--R             (- 1728a b c  + 12b )x   + (- 3456a b c  - 2304a b c + 216a b )x
+--R           + 
+--R                     3 2        2 4  8           4          3 3  6
+--R             (- 6912a b c + 576a b )x  + (- 4608a b c + 384a b )x
+--R        *
+--R                  +---------------+
+--R                  |   4      2              2       +-+
+--R               2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R           log(----------------------------------------)
+--R                                     2
+--R                                 2a x
+--R       + 
+--R                      3 2        2 2   10        3     8        4   6  +-+
+--R               ((1536a c  + 1152a b c)x   + 6144a b c x  + 6144a c x )\|c
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                         2   2         3   12           3 2        2 2   10
+--R                 (- 2304a b c  - 192a b c)x   + (- 4608a c  - 3456a b c)x
+--R               + 
+--R                        3     8        4   6
+--R                 - 9216a b c x  - 6144a c x
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R        *
+--R           log
+--R                                      +---------------+
+--R                       2 +-+     +-+  |   4      2          2 +-+ +-+       4
+--R                  (- 2x \|c  + 2\|a )\|c x  + b x  + a  + 2x \|a \|c  - 2c x
+--R                + 
+--R                       2
+--R                  - b x  - 2a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                   2   2         3       5  10
+--R             (2592a b c  + 176a b c + 18b )x
+--R           + 
+--R                   3 2        2 2          4  8          3           2 3  6
+--R             (6144a c  + 4608a b c + 512a b )x  + (13824a b c + 3200a b )x
+--R           + 
+--R                   4         3 2  4        4   2        5
+--R             (9728a c + 7296a b )x  + 6656a b x  + 2048a
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|a \|c x  + b x  + a
+--R       + 
+--R                 3 3        2 2 2        4     6  12
+--R         (- 2048a c  - 1008a b c  - 72a b c + b )x
+--R       + 
+--R                 3   2        2 3          5  10
+--R         (- 9696a b c  - 2064a b c - 126a b )x
+--R       + 
+--R                  4 2         3 2         2 4  8            4           3 3  6
+--R         (- 10752a c  - 12672a b c - 1536a b )x  + (- 21504a b c - 6144a b )x
+--R       + 
+--R                  5          4 2  4        5   2        6
+--R         (- 10752a c - 10368a b )x  - 7680a b x  - 2048a
+--R    /
+--R                                                             +---------------+
+--R                3         2 2  10         3   8         4 6  |   4      2
+--R         ((3072a c + 2304a b )x   + 12288a b x  + 12288a x )\|c x  + b x  + a
+--R       + 
+--R                     2            3  12           3         2 2  10
+--R             (- 4608a b c - 384a b )x   + (- 9216a c - 6912a b )x
+--R           + 
+--R                     3   8         4 6
+--R             - 18432a b x  - 12288a x
+--R        *
+--R            +-+
+--R           \|a
+--R     ,
+--R
+--R                       2   2         3       5  10         2 2          4  8
+--R                 (1152a b c  + 768a b c - 72b )x   + (4608a b c - 384a b )x
+--R               + 
+--R                       3          2 3  6
+--R                 (4608a b c - 384a b )x
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                     2 2 2      6  12           3   2        2 3          5  10
+--R             (- 1728a b c  + 12b )x   + (- 3456a b c  - 2304a b c + 216a b )x
+--R           + 
+--R                     3 2        2 4  8           4          3 3  6
+--R             (- 6912a b c + 576a b )x  + (- 4608a b c + 384a b )x
+--R        *
+--R                  +---------------+
+--R                  |   4      2              2       +-+
+--R               2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R           log(----------------------------------------)
+--R                                     2
+--R                                 2a x
+--R       + 
+--R                      3 2        2 2   10         3     8         4   6  +---+
+--R               ((3072a c  + 2304a b c)x   + 12288a b c x  + 12288a c x )\|- c
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                         2   2         3   12           3 2        2 2   10
+--R                 (- 4608a b c  - 384a b c)x   + (- 9216a c  - 6912a b c)x
+--R               + 
+--R                         3     8         4   6
+--R                 - 18432a b c x  - 12288a c x
+--R            *
+--R                +---+ +-+
+--R               \|- c \|a
+--R        *
+--R                 +---------------+
+--R                 |   4      2         +-+
+--R                \|c x  + b x  + a  - \|a
+--R           atan(-------------------------)
+--R                          2 +---+
+--R                         x \|- c
+--R       + 
+--R                   2   2         3       5  10
+--R             (2592a b c  + 176a b c + 18b )x
+--R           + 
+--R                   3 2        2 2          4  8          3           2 3  6
+--R             (6144a c  + 4608a b c + 512a b )x  + (13824a b c + 3200a b )x
+--R           + 
+--R                   4         3 2  4        4   2        5
+--R             (9728a c + 7296a b )x  + 6656a b x  + 2048a
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|a \|c x  + b x  + a
+--R       + 
+--R                 3 3        2 2 2        4     6  12
+--R         (- 2048a c  - 1008a b c  - 72a b c + b )x
+--R       + 
+--R                 3   2        2 3          5  10
+--R         (- 9696a b c  - 2064a b c - 126a b )x
+--R       + 
+--R                  4 2         3 2         2 4  8            4           3 3  6
+--R         (- 10752a c  - 12672a b c - 1536a b )x  + (- 21504a b c - 6144a b )x
+--R       + 
+--R                  5          4 2  4        5   2        6
+--R         (- 10752a c - 10368a b )x  - 7680a b x  - 2048a
+--R    /
+--R                                                             +---------------+
+--R                3         2 2  10         3   8         4 6  |   4      2
+--R         ((3072a c + 2304a b )x   + 12288a b x  + 12288a x )\|c x  + b x  + a
+--R       + 
+--R                     2            3  12           3         2 2  10
+--R             (- 4608a b c - 384a b )x   + (- 9216a c - 6912a b )x
+--R           + 
+--R                     3   8         4 6
+--R             - 18432a b x  - 12288a x
+--R        *
+--R            +-+
+--R           \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 17
+
+--S 18 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     3   2       2 3         5  4         3 2        2 4  2
+--R               (1152a b c  + 768a b c - 72a b )x  + (4608a b c - 384a b )x
+--R             + 
+--R                    4          3 3
+--R               4608a b c - 384a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       2 2 2      6  6           3   2        2 3          5  4
+--R               (- 1728a b c  + 12b )x  + (- 3456a b c  - 2304a b c + 216a b )x
+--R             + 
+--R                       3 2        2 4  2        4          3 3
+--R               (- 6912a b c + 576a b )x  - 4608a b c + 384a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                    3 2        2 2   4        3     2        4   +-+ +-+
+--R             ((1536a c  + 1152a b c)x  + 6144a b c x  + 6144a c)\|a \|c
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       3   2       2 3   6           4 2        3 2   4
+--R               (- 2304a b c  - 192a b c)x  + (- 4608a c  - 3456a b c)x
+--R             + 
+--R                      4     2        5
+--R               - 9216a b c x  - 6144a c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R         log
+--R                                    +---------------+
+--R                     2 +-+     +-+  |   4      2          2 +-+ +-+       4
+--R                (- 2x \|c  + 2\|a )\|c x  + b x  + a  + 2x \|a \|c  - 2c x
+--R              + 
+--R                     2
+--R                - b x  - 2a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                     3   2       2 3         5  4         3 2        2 4  2
+--R               (1152a b c  + 768a b c - 72a b )x  + (4608a b c - 384a b )x
+--R             + 
+--R                    4          3 3
+--R               4608a b c - 384a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       2 2 2      6  6           3   2        2 3          5  4
+--R               (- 1728a b c  + 12b )x  + (- 3456a b c  - 2304a b c + 216a b )x
+--R             + 
+--R                       3 2        2 4  2        4          3 3
+--R               (- 6912a b c + 576a b )x  - 4608a b c + 384a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                      3 2        2 2   4        3     2        4   +-+ +-+
+--R             ((- 1536a c  - 1152a b c)x  - 6144a b c x  - 6144a c)\|a \|c
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                     3   2       2 3   6         4 2        3 2   4
+--R               (2304a b c  + 192a b c)x  + (4608a c  + 3456a b c)x
+--R             + 
+--R                    4     2        5
+--R               9216a b c x  + 6144a c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                  3   2       2 3        5  4           3 2       2 4  2
+--R           (- 480a b c  - 368a b c - 6a b )x  + (- 1920a b c - 32a b )x
+--R         + 
+--R                  4         3 3
+--R           - 1920a b c - 32a b
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                2 2 2        4     6  6         3   2        2 3         5  4
+--R           (720a b c  + 72a b c + b )x  + (1440a b c  + 1104a b c + 18a b )x
+--R         + 
+--R                 3 2       2 4  2        4         3 3
+--R           (2880a b c + 48a b )x  + 1920a b c + 32a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                            +---------------+
+--R              3         2 2  4         3   2         4  +-+ |   4      2
+--R       ((3072a c + 2304a b )x  + 12288a b x  + 12288a )\|a \|c x  + b x  + a
+--R     + 
+--R               3          2 3  6           4         3 2  4         4   2
+--R       (- 4608a b c - 384a b )x  + (- 9216a c - 6912a b )x  - 18432a b x
+--R     + 
+--R               5
+--R       - 12288a
+--R                                                    Type: Expression(Integer)
+--E 18
+
+--S 19 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     3   2       2 3         5  4         3 2        2 4  2
+--R               (1152a b c  + 768a b c - 72a b )x  + (4608a b c - 384a b )x
+--R             + 
+--R                    4          3 3
+--R               4608a b c - 384a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       2 2 2      6  6           3   2        2 3          5  4
+--R               (- 1728a b c  + 12b )x  + (- 3456a b c  - 2304a b c + 216a b )x
+--R             + 
+--R                       3 2        2 4  2        4          3 3
+--R               (- 6912a b c + 576a b )x  - 4608a b c + 384a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                     3   2       2 3         5  4         3 2        2 4  2
+--R               (1152a b c  + 768a b c - 72a b )x  + (4608a b c - 384a b )x
+--R             + 
+--R                    4          3 3
+--R               4608a b c - 384a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       2 2 2      6  6           3   2        2 3          5  4
+--R               (- 1728a b c  + 12b )x  + (- 3456a b c  - 2304a b c + 216a b )x
+--R             + 
+--R                       3 2        2 4  2        4          3 3
+--R               (- 6912a b c + 576a b )x  - 4608a b c + 384a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                      3 2        2 2   4        3     2        4   +-+ +-+
+--R             ((- 1536a c  - 1152a b c)x  - 6144a b c x  - 6144a c)\|a \|c
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                     3   2       2 3   6         4 2        3 2   4
+--R               (2304a b c  + 192a b c)x  + (4608a c  + 3456a b c)x
+--R             + 
+--R                    4     2        5
+--R               9216a b c x  + 6144a c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                    3 2        2 2   4         3     2         4   +---+ +-+
+--R             ((3072a c  + 2304a b c)x  + 12288a b c x  + 12288a c)\|- c \|a
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       3   2       2 3   6           4 2        3 2   4
+--R               (- 4608a b c  - 384a b c)x  + (- 9216a c  - 6912a b c)x
+--R             + 
+--R                       4     2         5
+--R               - 18432a b c x  - 12288a c
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R               +---------------+
+--R               |   4      2         +-+
+--R              \|c x  + b x  + a  - \|a
+--R         atan(-------------------------)
+--R                        2 +---+
+--R                       x \|- c
+--R     + 
+--R                  3   2       2 3        5  4           3 2       2 4  2
+--R           (- 480a b c  - 368a b c - 6a b )x  + (- 1920a b c - 32a b )x
+--R         + 
+--R                  4         3 3
+--R           - 1920a b c - 32a b
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                2 2 2        4     6  6         3   2        2 3         5  4
+--R           (720a b c  + 72a b c + b )x  + (1440a b c  + 1104a b c + 18a b )x
+--R         + 
+--R                 3 2       2 4  2        4         3 3
+--R           (2880a b c + 48a b )x  + 1920a b c + 32a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                            +---------------+
+--R              3         2 2  4         3   2         4  +-+ |   4      2
+--R       ((3072a c + 2304a b )x  + 12288a b x  + 12288a )\|a \|c x  + b x  + a
+--R     + 
+--R               3          2 3  6           4         3 2  4         4   2
+--R       (- 4608a b c - 384a b )x  + (- 9216a c - 6912a b )x  - 18432a b x
+--R     + 
+--R               5
+--R       - 12288a
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^9
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          9
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 1057
+r0:=-1/8*(a+b*x^2+c*x^4)^(3/2)/x^8-3/256*(b^2-4*a*c)^2*atanh(1/2*_
+   (2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(5/2)-1/64*(b^2-12*a*c)*_
+   sqrt(a+b*x^2+c*x^4)/(a*x^4)+1/128*b*(3*b^2-20*a*c)*sqrt(a+b*x^2+c*x^4)/_
+   (a^2*x^2)-1/16*(b+6*c*x^2)*sqrt(a+b*x^2+c*x^4)/x^6
+--R 
+--R
+--R   (2)
+--R                                                   2
+--R             2 2        2      4  8             b x  + 2a
+--R       (- 48a c  + 24a b c - 3b )x atanh(-----------------------)
+--R                                               +---------------+
+--R                                           +-+ |   4      2
+--R                                         2\|a \|c x  + b x  + a
+--R     + 
+--R                         3  6         2        2  4      2   2      3  +-+
+--R         ((- 40a b c + 6b )x  + (- 80a c - 4a b )x  - 48a b x  - 32a )\|a
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R  /
+--R         2 8 +-+
+--R     256a x \|a
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      4   3        3 3 2       2 5          7  14
+--R               (12288a b c  - 3072a b c  - 768a b c + 192a b )x
+--R             + 
+--R                      5 3         4 2 2         3 4         2 6  12
+--R               (24576a c  + 18432a b c  - 13824a b c + 1920a b )x
+--R             + 
+--R                      5   2         4 3         3 5  10
+--R               (73728a b c  - 36864a b c + 4608a b )x
+--R             + 
+--R                      6 2         5 2         4 4  8
+--R               (49152a c  - 24576a b c + 3072a b )x
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       4 4        3 2 3        2 4 2         6       8  16
+--R               (- 6144a c  - 6144a b c  + 3840a b c  - 384a b c - 24b )x
+--R             + 
+--R                        4   3         3 3 2        2 5          7  14
+--R               (- 49152a b c  + 12288a b c  + 3072a b c - 768a b )x
+--R             + 
+--R                        5 3         4 2 2         3 4         2 6  12
+--R               (- 49152a c  - 36864a b c  + 27648a b c - 3840a b )x
+--R             + 
+--R                        5   2         4 3         3 5  10
+--R               (- 98304a b c  + 49152a b c - 6144a b )x
+--R             + 
+--R                        6 2         5 2         4 4  8
+--R               (- 49152a c  + 24576a b c - 3072a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                 4   3        3 3 2       2 5        7  14
+--R           (5120a b c  + 5888a b c  - 864a b c + 8a b )x
+--R         + 
+--R                  5 3         4 2 2        3 4        2 6  12
+--R           (10240a c  + 54784a b c  + 3392a b c - 944a b )x
+--R         + 
+--R                   5   2         4 3         3 5  10
+--R           (129024a b c  + 72704a b c - 4928a b )x
+--R         + 
+--R                  6 2          5 2         4 4  8           6            5 3  6
+--R           (86016a c  + 239616a b c + 6272a b )x  + (286720a b c + 71680a b )x
+--R         + 
+--R                   7           6 2  4          7   2         8
+--R           (114688a c + 143360a b )x  + 114688a b x  + 32768a
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                   3 2 3       2 4 2         6      8  16
+--R           (- 9728a b c  - 368a b c  + 248a b c - 7b )x
+--R         + 
+--R                    4   3         3 3 2        2 5          7  14
+--R           (- 40960a b c  - 34816a b c  + 2688a b c + 160a b )x
+--R         + 
+--R                    5 3          4 2 2         3 4         2 6  12
+--R           (- 40960a c  - 174080a b c  - 21888a b c + 2848a b )x
+--R         + 
+--R                     5   2          4 3         3 5  10
+--R           (- 278528a b c  - 180224a b c + 5376a b )x
+--R         + 
+--R                     6 2          5 2          4 4  8
+--R           (- 139264a c  - 417792a b c - 30080a b )x
+--R         + 
+--R                     6             5 3  6             7           6 2  4
+--R           (- 393216a b c - 131072a b )x  + (- 131072a c - 196608a b )x
+--R         + 
+--R                    7   2         8
+--R           - 131072a b x  - 32768a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  4            3 3  14           5           4 2  12
+--R           (65536a b c + 16384a b )x   + (131072a c + 163840a b )x
+--R         + 
+--R                  5   10          6 8
+--R           393216a b x   + 262144a x
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R                5 2         4 2         3 4  16             5            4 3  14
+--R       (- 32768a c  - 49152a b c - 2048a b )x   + (- 262144a b c - 65536a b )x
+--R     + 
+--R                 6           5 2  12          6   10          7 8
+--R       (- 262144a c - 327680a b )x   - 524288a b x   - 262144a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 24
+
+--S 25 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +---------------+
+--R                                        +-+ |   4      2           2
+--R            2 2         2       4     2\|a \|c x  + b x  + a  - b x  - 2a
+--R       (384a c  - 192a b c + 24b )log(-----------------------------------)
+--R                                                      2 +-+
+--R                                                    2x \|a
+--R     + 
+--R                                                2
+--R          2 2         2       4              b x  + 2a                2      4
+--R     (384a c  - 192a b c + 24b )atanh(-----------------------) - 32a b c + 7b
+--R                                            +---------------+
+--R                                        +-+ |   4      2
+--R                                      2\|a \|c x  + b x  + a
+--R  /
+--R          2 +-+
+--R     2048a \|a
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 26
+
+)clear all
+
+--S 27 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^11
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                         11
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 1057
+r0:=-1/10*(a+b*x^2+c*x^4)^(3/2)/x^10+3/512*b*(b^2-4*a*c)^2*atanh(1/2*_
+   (2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(7/2)-1/160*(b^2-8*a*c)*_
+   sqrt(a+b*x^2+c*x^4)/(a*x^6)+1/640*b*(5*b^2-28*a*c)*sqrt(a+b*x^2+c*x^4)/_
+   (a^2*x^4)-1/1280*(15*b^4-100*a*b^2*c+128*a^2*c^2)*sqrt(a+b*x^2+c*x^4)/_
+   (a^3*x^2)-3/80*(b+4*c*x^2)*sqrt(a+b*x^2+c*x^4)/x^8
+--R 
+--R
+--R   (2)
+--R                                                       2
+--R            2   2         3       5  10             b x  + 2a
+--R       (240a b c  - 120a b c + 15b )x  atanh(-----------------------)
+--R                                                   +---------------+
+--R                                               +-+ |   4      2
+--R                                             2\|a \|c x  + b x  + a
+--R     + 
+--R                  2 2         2       4  8          2           3  6
+--R           (- 256a c  + 200a b c - 30b )x  + (- 112a b c + 20a b )x
+--R         + 
+--R                  3       2 2  4       3   2       4
+--R           (- 512a c - 16a b )x  - 352a b x  - 256a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R  /
+--R          3 10 +-+
+--R     2560a x  \|a
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        4   4          3 3 3         2 5 2        9  18
+--R               (- 61440a b c  - 122880a b c  + 53760a b c  - 1200b )x
+--R             + 
+--R                         4 2 3         3 4 2          2 6            8  16
+--R               (- 737280a b c  + 61440a b c  + 107520a b c - 19200a b )x
+--R             + 
+--R                         5   3          4 3 2          3 5          2 7  14
+--R               (- 737280a b c  - 921600a b c  + 599040a b c - 80640a b )x
+--R             + 
+--R                          5 2 2          4 4           3 6  12
+--R               (- 1966080a b c  + 983040a b c - 122880a b )x
+--R             + 
+--R                         6   2          5 3          4 5  10
+--R               (- 983040a b c  + 491520a b c - 61440a b )x
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                   4 2 4         2 6 2          8        10  20
+--R           (153600a b c  - 26880a b c  + 3840a b c + 120b  )x
+--R         + 
+--R                   5   4          4 3 3          3 5 2          9  18
+--R           (307200a b c  + 614400a b c  - 268800a b c  + 6000a b )x
+--R         + 
+--R                    5 2 3          4 4 2          3 6          2 8  16
+--R           (1843200a b c  - 153600a b c  - 268800a b c + 48000a b )x
+--R         + 
+--R                    6   3           5 3 2          4 5           3 7  14
+--R           (1228800a b c  + 1536000a b c  - 998400a b c + 134400a b )x
+--R         + 
+--R                    6 2 2           5 4           4 6  12
+--R           (2457600a b c  - 1228800a b c + 153600a b )x
+--R         + 
+--R                   7   2          6 3          5 5  10
+--R           (983040a b c  - 491520a b c + 61440a b )x
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                   4   4         3 3 3         2 5 2          7        9  18
+--R           (153600a b c  - 62720a b c  - 25056a b c  + 7040a b c - 230b )x
+--R         + 
+--R                   5 4          4 2 3          3 4 2         2 6           8  16
+--R           (327680a c  + 512000a b c  - 419840a b c  + 37248a b c + 4320a b )x
+--R         + 
+--R                    5   3          4 3 2          3 5          2 7  14
+--R           (2314240a b c  - 317440a b c  - 249472a b c + 56544a b )x
+--R         + 
+--R                    6 3           5 2 2          4 4           3 6  12
+--R           (1966080a c  + 3686400a b c  - 778240a b c + 165888a b )x
+--R         + 
+--R                    6   2           5 3           4 5  10
+--R           (7577600a b c  + 1966080a b c + 297984a b )x
+--R         + 
+--R                    7 2           6 2            5 4  8
+--R           (3997696a c  + 8519680a b c + 1290240a b )x
+--R         + 
+--R                    7              6 3  6            8            7 2  4
+--R           (9469952a b c + 4055040a b )x  + (3407872a c + 5963776a b )x
+--R         + 
+--R                   8   2           9
+--R           4063232a b x  + 1048576a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R                   5 5         4 2 4         3 4 3         2 6 2         8
+--R           - 65536a c  - 87040a b c  + 90240a b c  - 10320a b c  - 800a b c
+--R         + 
+--R              10
+--R           47b
+--R      *
+--R          20
+--R         x
+--R     + 
+--R                 5   4          4 3 3          3 5 2         2 7         9  18
+--R       (- 829440a b c  + 190720a b c  + 179040a b c  - 35200a b c - 50a b )x
+--R     + 
+--R                   6 4           5 2 3           4 4 2         3 6          2 8
+--R         (- 983040a c  - 2058240a b c  + 1029120a b c  - 39360a b c - 20400a b )
+--R      *
+--R          16
+--R         x
+--R     + 
+--R                  6   3          5 3 2          4 5           3 7  14
+--R       (- 5632000a b c  - 870400a b c  + 547200a b c - 121120a b )x
+--R     + 
+--R                  7 3           6 2 2          5 4           4 6  12
+--R       (- 3604480a c  - 9277440a b c  + 143360a b c - 263680a b )x
+--R     + 
+--R                   7   2           6 3           5 5  10
+--R       (- 13148160a b c  - 6389760a b c - 678912a b )x
+--R     + 
+--R                  8 2            7 2            6 4  8
+--R       (- 5570560a c  - 14991360a b c - 2785280a b )x
+--R     + 
+--R                   8              7 3  6              9            8 2  4
+--R       (- 12943360a b c - 6594560a b )x  + (- 3932160a c - 7864320a b )x
+--R     + 
+--R                 9   2           10
+--R       - 4587520a b x  - 1048576a
+--R  /
+--R                   6 2           5 2           4 4  18
+--R           (655360a c  + 1638400a b c + 204800a b )x
+--R         + 
+--R                    6              5 3  16            7             6 2  14
+--R           (7864320a b c + 3276800a b )x   + (7864320a c + 13762560a b )x
+--R         + 
+--R                    7   12            8 10
+--R           20971520a b x   + 10485760a x
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                      5   2          4 3          3 5  20
+--R           (- 1638400a b c  - 819200a b c - 20480a b )x
+--R         + 
+--R                      6 2           5 2            4 4  18
+--R           (- 3276800a c  - 8192000a b c - 1024000a b )x
+--R         + 
+--R                       6              5 3  16
+--R           (- 19660800a b c - 8192000a b )x
+--R         + 
+--R                       7             6 2  14            7   12            8 10
+--R           (- 13107200a c - 22937600a b )x   - 26214400a b x   - 10485760a x
+--R      *
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 29
+
+--S 30 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        5   4          4 3 3         3 5 2          9  8
+--R               (- 61440a b c  - 122880a b c  + 53760a b c  - 1200a b )x
+--R             + 
+--R                         5 2 3         4 4 2          3 6          2 8  6
+--R               (- 737280a b c  + 61440a b c  + 107520a b c - 19200a b )x
+--R             + 
+--R                         6   3          5 3 2          4 5          3 7  4
+--R               (- 737280a b c  - 921600a b c  + 599040a b c - 80640a b )x
+--R             + 
+--R                          6 2 2          5 4           4 6  2          7   2
+--R               (- 1966080a b c  + 983040a b c - 122880a b )x  - 983040a b c
+--R             + 
+--R                      6 3          5 5
+--R               491520a b c - 61440a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       4 2 4         2 6 2          8        10  10
+--R               (153600a b c  - 26880a b c  + 3840a b c + 120b  )x
+--R             + 
+--R                       5   4          4 3 3          3 5 2          9  8
+--R               (307200a b c  + 614400a b c  - 268800a b c  + 6000a b )x
+--R             + 
+--R                        5 2 3          4 4 2          3 6          2 8  6
+--R               (1843200a b c  - 153600a b c  - 268800a b c + 48000a b )x
+--R             + 
+--R                        6   3           5 3 2          4 5           3 7  4
+--R               (1228800a b c  + 1536000a b c  - 998400a b c + 134400a b )x
+--R             + 
+--R                        6 2 2           5 4           4 6  2          7   2
+--R               (2457600a b c  - 1228800a b c + 153600a b )x  + 983040a b c
+--R             + 
+--R                        6 3          5 5
+--R               - 491520a b c + 61440a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                        5   4          4 3 3         3 5 2          9  8
+--R               (- 61440a b c  - 122880a b c  + 53760a b c  - 1200a b )x
+--R             + 
+--R                         5 2 3         4 4 2          3 6          2 8  6
+--R               (- 737280a b c  + 61440a b c  + 107520a b c - 19200a b )x
+--R             + 
+--R                         6   3          5 3 2          4 5          3 7  4
+--R               (- 737280a b c  - 921600a b c  + 599040a b c - 80640a b )x
+--R             + 
+--R                          6 2 2          5 4           4 6  2          7   2
+--R               (- 1966080a b c  + 983040a b c - 122880a b )x  - 983040a b c
+--R             + 
+--R                      6 3          5 5
+--R               491520a b c - 61440a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       4 2 4         2 6 2          8        10  10
+--R               (153600a b c  - 26880a b c  + 3840a b c + 120b  )x
+--R             + 
+--R                       5   4          4 3 3          3 5 2          9  8
+--R               (307200a b c  + 614400a b c  - 268800a b c  + 6000a b )x
+--R             + 
+--R                        5 2 3          4 4 2          3 6          2 8  6
+--R               (1843200a b c  - 153600a b c  - 268800a b c + 48000a b )x
+--R             + 
+--R                        6   3           5 3 2          4 5           3 7  4
+--R               (1228800a b c  + 1536000a b c  - 998400a b c + 134400a b )x
+--R             + 
+--R                        6 2 2           5 4           4 6  2          7   2
+--R               (2457600a b c  - 1228800a b c + 153600a b )x  + 983040a b c
+--R             + 
+--R                        6 3          5 5
+--R               - 491520a b c + 61440a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                    5   4         4 3 3         3 5 2       2 7          9  8
+--R           (- 10240a b c  - 16640a b c  + 17696a b c  - 960a b c - 470a b )x
+--R         + 
+--R                     5 2 3         4 4 2         3 6         2 8  6
+--R           (- 122880a b c  + 56320a b c  + 26752a b c - 7520a b )x
+--R         + 
+--R                     6   3          5 3 2          4 5          3 7  4
+--R           (- 122880a b c  - 107520a b c  + 170112a b c - 31584a b )x
+--R         + 
+--R                     6 2 2          5 4          4 6  2          7   2
+--R           (- 327680a b c  + 286720a b c - 48128a b )x  - 163840a b c
+--R         + 
+--R                  6 3          5 5
+--R           143360a b c - 24064a b
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                  4 2 4        3 4 3        2 6 2          8       10  10
+--R           (25600a b c  - 9600a b c  - 7120a b c  + 1600a b c + 47b  )x
+--R         + 
+--R                  5   4         4 3 3         3 5 2        2 7           9  8
+--R           (51200a b c  + 83200a b c  - 88480a b c  + 4800a b c + 2350a b )x
+--R         + 
+--R                   5 2 3          4 4 2         3 6          2 8  6
+--R           (307200a b c  - 140800a b c  - 66880a b c + 18800a b )x
+--R         + 
+--R                   6   3          5 3 2          4 5          3 7  4
+--R           (204800a b c  + 179200a b c  - 283520a b c + 52640a b )x
+--R         + 
+--R                   6 2 2          5 4          4 6  2          7   2
+--R           (409600a b c  - 358400a b c + 60160a b )x  + 163840a b c
+--R         + 
+--R                    6 3          5 5
+--R           - 143360a b c + 24064a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                   6 2           5 2           4 4  8
+--R           (655360a c  + 1638400a b c + 204800a b )x
+--R         + 
+--R                    6              5 3  6            7             6 2  4
+--R           (7864320a b c + 3276800a b )x  + (7864320a c + 13762560a b )x
+--R         + 
+--R                    7   2            8
+--R           20971520a b x  + 10485760a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R                  6   2          5 3          4 5  10
+--R       (- 1638400a b c  - 819200a b c - 20480a b )x
+--R     + 
+--R                  7 2           6 2            5 4  8
+--R       (- 3276800a c  - 8192000a b c - 1024000a b )x
+--R     + 
+--R                   7              6 3  6               8             7 2  4
+--R       (- 19660800a b c - 8192000a b )x  + (- 13107200a c - 22937600a b )x
+--R     + 
+--R                  8   2            9
+--R       - 26214400a b x  - 10485760a
+--R                                                    Type: Expression(Integer)
+--E 30
+
+--S 31 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 31
+
+)clear all
+
+--S 32 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^13
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                         13
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 1057
+r0:=-1/12*(a+b*x^2+c*x^4)^(3/2)/x^12-1/2048*(b^2-4*a*c)^2*(7*b^2-4*a*c)*_
+   atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(9/2)-_
+   1/960*(3*b^2-20*a*c)*sqrt(a+b*x^2+c*x^4)/(a*x^8)+1/1920*b*(7*b^2-36*a*c)*_
+   sqrt(a+b*x^2+c*x^4)/(a^2*x^6)-1/7680*(35*b^4-216*a*b^2*c+240*a^2*c^2)*_
+   sqrt(a+b*x^2+c*x^4)/(a^3*x^4)+1/15360*b*(105*b^4-760*a*b^2*c+_
+   1296*a^2*c^2)*sqrt(a+b*x^2+c*x^4)/(a^4*x^2)-1/120*(3*b+10*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/x^10
+--R 
+--R
+--R   (2)
+--R              3 3        2 2 2         4        6  12
+--R         (960a c  - 2160a b c  + 900a b c - 105b )x
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                 2   2          3        5  10
+--R           (2592a b c  - 1520a b c + 210b )x
+--R         + 
+--R                  3 2       2 2          4  8          3          2 3  6
+--R           (- 960a c  + 864a b c - 140a b )x  + (- 576a b c + 112a b )x
+--R         + 
+--R                   4       3 2  4        4   2        5
+--R           (- 4480a c - 96a b )x  - 3328a b x  - 2560a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R  /
+--R           4 12 +-+
+--R     30720a x  \|a
+--R                                                    Type: Expression(Integer)
+--E 33
+
+--S 34 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                             6   5           5 3 4           4 5 3
+--R                   - 1474560a b c  + 2088960a b c  + 1290240a b c
+--R                 + 
+--R                            3 7 2         2 9            11
+--R                   - 783360a b c  + 48000a b c + 10080a b
+--R              *
+--R                  22
+--R                 x
+--R             + 
+--R                             7 5           6 2 4            5 4 3
+--R                   - 2949120a c  - 3686400a b c  + 18309120a b c
+--R                 + 
+--R                             4 6 2          3 8           2 10
+--R                   - 4515840a b c  - 887040a b c + 235200a b
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                              7   4            6 3 3           5 5 2
+--R                   - 23592960a b c  + 39321600a b c  + 8847360a b c
+--R                 + 
+--R                              4 7            3 9
+--R                   - 10321920a b c + 1505280a b
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                             8 4            6 4 2            5 6            4 8
+--R                 (- 15728640a c  + 64880640a b c  - 31457280a b c + 3870720a b )
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                8   3            7 3 2            6 5
+--R                     - 39321600a b c  + 88473600a b c  - 36864000a b c
+--R                   + 
+--R                             5 7
+--R                     4300800a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                         9 3            8 2 2            7 4            6 6  12
+--R             (- 15728640a c  + 35389440a b c  - 14745600a b c + 1720320a b )x
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                          6 6          5 2 5           4 4 4          3 6 3
+--R                   491520a c  + 737280a b c  - 3225600a b c  + 645120a b c
+--R                 + 
+--R                          2 8 2           10        12
+--R                   213120a b c  - 43200a b  c - 840b
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                           6   5            5 3 4           4 5 3
+--R                   8847360a b c  - 12533760a b c  - 7741440a b c
+--R                 + 
+--R                           3 7 2          2 9            11
+--R                   4700160a b c  - 288000a b c - 60480a b
+--R              *
+--R                  22
+--R                 x
+--R             + 
+--R                           7 5            6 2 4            5 4 3
+--R                   8847360a c  + 11059200a b c  - 54927360a b c
+--R                 + 
+--R                            4 6 2           3 8           2 10
+--R                   13547520a b c  + 2661120a b c - 705600a b
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                            7   4            6 3 3            5 5 2
+--R                   47185920a b c  - 78643200a b c  - 17694720a b c
+--R                 + 
+--R                            4 7            3 9
+--R                   20643840a b c - 3010560a b
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                         8 4            6 4 2            5 6            4 8  16
+--R               (23592960a c  - 97320960a b c  + 47185920a b c - 5806080a b )x
+--R             + 
+--R                              8   3             7 3 2            6 5
+--R                     47185920a b c  - 106168320a b c  + 44236800a b c
+--R                   + 
+--R                               5 7
+--R                     - 5160960a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                         9 3            8 2 2            7 4            6 6  12
+--R               (15728640a c  - 35389440a b c  + 14745600a b c - 1720320a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                         6   5           5 3 4           4 5 3         3 7 2
+--R               - 1327104a b c  - 3415040a b c  + 1724160a b c  + 14592a b c
+--R             + 
+--R                       2 9           11
+--R               - 58960a b c + 2868a b
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                      7 5            6 2 4           5 4 3           4 6 2
+--R               491520a c  - 20920320a b c  - 2531840a b c  + 5927424a b c
+--R             + 
+--R                        3 8          2 10
+--R               - 890016a b c - 13720a b
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                          7   4            6 3 3            5 5 2          4 7
+--R               - 14745600a b c  - 56606720a b c  + 24330240a b c  + 509952a b c
+--R             + 
+--R                        3 9
+--R               - 652288a b
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                        8 4            7 2 3          6 4 2            5 6
+--R               11141120a c  - 82083840a b c  - 491520a b c  + 20410368a b c
+--R             + 
+--R                         4 8
+--R               - 3397632a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                     8   3            7 3 2            6 5            5 7  14
+--R           (31784960a b c  - 40796160a b c  + 52961280a b c - 6328320a b )x
+--R         + 
+--R                     9 3             8 2 2            7 4            6 6  12
+--R           (66191360a c  + 122093568a b c  + 96092160a b c - 2433024a b )x
+--R         + 
+--R                      9   2             8 3             7 5  10
+--R           (293339136a b c  + 271712256a b c + 23838720a b )x
+--R         + 
+--R                      10 2             9 2              8 4  8
+--R           (149422080a  c  + 510394368a b c + 114720768a b )x
+--R         + 
+--R                      10                9 3  6
+--R           (437256192a  b c + 260308992a b )x
+--R         + 
+--R                      11              10 2  4             11   2            12
+--R           (136314880a  c + 306708480a  b )x  + 180355072a  b x  + 41943040a
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                       5 2 5          4 4 4           3 6 3          2 8 2
+--R               3720192a b c  + 168960a b c  - 1024064a b c  + 182640a b c
+--R             + 
+--R                     12
+--R               - 379b
+--R          *
+--R              24
+--R             x
+--R         + 
+--R                       6   5            5 3 4           4 5 3          3 7 2
+--R               6488064a b c  + 22579200a b c  - 9054720a b c  - 870912a b c
+--R             + 
+--R                      2 9           11
+--R               401760a b c - 7128a b
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                         7 5            6 2 4            5 4 3            4 6 2
+--R               - 2949120a c  + 60917760a b c  + 16750080a b c  - 20040192a b c
+--R             + 
+--R                       3 8           2 10
+--R               2226528a b c + 158760a b
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                        7   4             6 3 3            5 5 2           4 7
+--R               13762560a b c  + 119767040a b c  - 46202880a b c  - 4460544a b c
+--R             + 
+--R                       3 9
+--R               1806336a b
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                          8 4            7 2 3           6 4 2            5 6
+--R               - 32440320a c  + 70041600a b c  - 1474560a b c  - 39217152a b c
+--R             + 
+--R                       4 8
+--R               6064128a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                        8   3            7 3 2            6 5            5 7  14
+--R           (- 149815296a b c  - 56033280a b c  - 89210880a b c + 8159232a b )x
+--R         + 
+--R                        9 3             8 2 2             7 4            6 6  12
+--R           (- 126484480a c  - 407175168a b c  - 217497600a b c - 3506176a b )x
+--R         + 
+--R                        9   2             8 3             7 5  10
+--R           (- 537919488a b c  - 561512448a b c - 61931520a b )x
+--R         + 
+--R                        10 2             9 2              8 4  8
+--R           (- 212336640a  c  - 828112896a b c - 216170496a b )x
+--R         + 
+--R                        10                9 3  6
+--R           (- 585105408a  b c - 393740288a b )x
+--R         + 
+--R                      11              10 2  4             11   2            12
+--R         (- 157286400a  c - 391643136a  b )x  - 201326592a  b x  - 41943040a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                     7   2            6 3            5 5  22
+--R           (47185920a b c  + 39321600a b c + 2949120a b )x
+--R         + 
+--R                     8 2             7 2             6 4  20
+--R           (94371840a c  + 330301440a b c + 68812800a b )x
+--R         + 
+--R                      8                7 3  18
+--R           (754974720a b c + 440401920a b )x
+--R         + 
+--R                      9               8 2  16              9   14
+--R           (503316480a c + 1132462080a b )x   + 1258291200a b x
+--R         + 
+--R                     10 12
+--R           503316480a  x
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R                   8 3            7 2 2            6 4           5 6  24
+--R       (- 15728640a c  - 58982400a b c  - 14745600a b c - 245760a b )x
+--R     + 
+--R                    8   2             7 3             6 5  22
+--R       (- 283115520a b c  - 235929600a b c - 17694720a b )x
+--R     + 
+--R                    9 2             8 2              7 4  20
+--R       (- 283115520a c  - 990904320a b c - 206438400a b )x
+--R     + 
+--R                     9                8 3  18
+--R       (- 1509949440a b c - 880803840a b )x
+--R     + 
+--R                    10               9 2  16              10   14
+--R       (- 754974720a  c - 1698693120a b )x   - 1509949440a  b x
+--R     + 
+--R                   11 12
+--R       - 503316480a  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 34
+
+--S 35 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3 3         2 2 2          4        6
+--R         (- 7680a c  + 17280a b c  - 7200a b c + 840b )
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                 3 3         2 2 2          4        6
+--R         (- 7680a c  + 17280a b c  - 7200a b c + 840b )
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R            2 2 2          4        6
+--R       4080a b c  - 2580a b c + 379b
+--R  /
+--R            4 +-+
+--R     245760a \|a
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 1057
+t0:=x^4*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                             +---------------+
+--R            8      6      4  |   4      2
+--R   (1)  (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 1057
+--r0:=1/33*x^3*(b+3*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c+1/1155*(8*b^4-51*a*b^2*c+60*a^2*c^2)*x*sqrt(a+b*x^2+c*x^4)/c^3-1/385*x^3*(b*(2*b^2+a*c)+10*c*(b^2-3*a*c)*x^2)*sqrt(a+b*x^2+c*x^4)/c^2-2/1155*b*(2*b^2-9*a*c)*(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(2)*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(9/2)*sqrt(a+b*x^2+c*x^4))+1/1155*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*(4*b*(2*b^2-9*a*c)*(b^2-3*a*c)-a*c*(8*b^4-51*a*b^2*c+60*a^2*c^2)/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(9/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 38
+
+--S 39 of 1057
+--a0:=integrate(t0,x)
+--E 39
+
+--S 40 of 1057
+--m0:=a0-r0
+--E 40
+
+--S 41 of 1057
+--d0:=D(m0,x)
+--E 41
+
+)clear all
+
+--S 42 of 1057
+t0:=x^2*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                             +---------------+
+--R            6      4      2  |   4      2
+--R   (1)  (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 1057
+--r0:=1/63*x*(3*b+7*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c-1/315*x*(b*(4*b^2-9*a*c)+6*c*(2*b^2-7*a*c)*x^2)*sqrt(a+b*x^2+c*x^4)/c^2+1/630*(8*b^4-57*a*b^2*c+84*a^2*c^2)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/630*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*(8*b^4-57*a*b^2*c+84*a^2*c^2-8*a*b*c*(b^2-6*a*c)/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 43
+
+--S 44 of 1057
+--a0:=integrate(t0,x)
+--E 44
+
+--S 45 of 1057
+--m0:=a0-r0
+--E 45
+
+--S 46 of 1057
+--d0:=D(m0,x)
+--E 46
+
+)clear all
+
+--S 47 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R   (1)  (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 1057
+--r0:=1/7*x*(a+b*x^2+c*x^4)^(3/2)+1/35*x*(b^2+10*a*c+3*b*c*x^2)*sqrt(a+b*x^2+c*x^4)/c-1/35*b*(b^2-8*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))+1/35*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^4-9*a*b^2*c+20*a^2*c^2+b*(b^2-8*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 48
+
+--S 49 of 1057
+--a0:=integrate(t0,x)
+--E 49
+
+--S 50 of 1057
+--m0:=a0-r0
+--E 50
+
+--S 51 of 1057
+--d0:=D(m0,x)
+--E 51
+
+)clear all
+
+--S 52 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^2
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          2
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 1057
+--r0:=-(a+b*x^2+c*x^4)^(3/2)/x+1/5*x*(7*b+6*c*x^2)*sqrt(a+b*x^2+c*x^4)+1/10*(b^2+12*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/10*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2+12*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 53
+
+--S 54 of 1057
+--a0:=integrate(t0,x)
+--E 54
+
+--S 55 of 1057
+--m0:=a0-r0
+--E 55
+
+--S 56 of 1057
+--d0:=D(m0,x)
+--E 56
+
+)clear all
+
+--S 57 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^4
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          4
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 57
+
+--S 58 of 1057
+--r0:=-1/3*(a+b*x^2+c*x^4)^(3/2)/x^3-1/3*(3*b-2*c*x^2)*sqrt(a+b*x^2+c*x^4)/x+2/3*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(2)*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(c)*sqrt(a+b*x^2+c*x^4))-1/3*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-4*a*c+4*b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 58
+
+--S 59 of 1057
+--a0:=integrate(t0,x)
+--E 59
+
+--S 60 of 1057
+--m0:=a0-r0
+--E 60
+
+--S 61 of 1057
+--d0:=D(m0,x)
+--E 61
+
+)clear all
+
+--S 62 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^6
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          6
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 1057
+--r0:=-1/5*(a+b*x^2+c*x^4)^(3/2)/x^5-1/5*(b^2+12*a*c)*sqrt(a+b*x^2+c*x^4)/(a*x)-1/5*(b-6*c*x^2)*sqrt(a+b*x^2+c*x^4)/x^3+1/10*(b^2+12*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))-1/10*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2+12*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 63
+
+--S 64 of 1057
+--a0:=integrate(t0,x)
+--E 64
+
+--S 65 of 1057
+--m0:=a0-r0
+--E 65
+
+--S 66 of 1057
+--d0:=D(m0,x)
+--E 66
+
+)clear all
+
+--S 67 of 1057
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^8
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          8
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 1057
+--r0:=-1/7*(a+b*x^2+c*x^4)^(3/2)/x^7-1/35*(b^2-20*a*c)*sqrt(a+b*x^2+c*x^4)/(a*x^3)+2/35*b*(b^2-8*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*x)-3/35*(b+10*c*x^2)*sqrt(a+b*x^2+c*x^4)/x^5-1/35*b*(b^2-8*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))+1/35*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^4-9*a*b^2*c+20*a^2*c^2+b*(b^2-8*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 68
+
+--S 69 of 1057
+--a0:=integrate(t0,x)
+--E 69
+
+--S 70 of 1057
+--m0:=a0-r0
+--E 70
+
+--S 71 of 1057
+--d0:=D(m0,x)
+--E 71
+
+)clear all
+
+--S 72 of 1057
+t0:=sqrt(3-2*x^2-x^4)
+--R 
+--R
+--R         +--------------+
+--R         |   4     2
+--R   (1)  \|- x  - 2x  + 3
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 1057
+--r0:=-2*elliptic_e(asin(x),-1/3)/sqrt(3)+4*elliptic_f(asin(x),-1/3)/sqrt(3)+1/3*x*sqrt(3-2*x^2-x^4)
+--E 73
+
+--S 74 of 1057
+--a0:=integrate(t0,x)
+--E 74
+
+--S 75 of 1057
+--m0:=a0-r0
+--E 75
+
+--S 76 of 1057
+--d0:=D(m0,x)
+--E 76
+
+)clear all
+
+--S 77 of 1057
+t0:=x^7/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 7
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 1057
+r0:=-1/32*b*(5*b^2-12*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+_
+   c*x^4)))/c^(7/2)+1/48*(15*b^2-8*a*c)*sqrt(a+b*x^2+c*x^4)/c^3+_
+   1/6*x^4*sqrt(a+b*x^2+c*x^4)/c-1/24*(4*a+5*b*x^2)*sqrt(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                                        2
+--R                     3              2c x  + b
+--R       (36a b c - 15b )atanh(-----------------------)
+--R                                   +---------------+
+--R                               +-+ |   4      2
+--R                             2\|c \|c x  + b x  + a
+--R     + 
+--R                                              +---------------+
+--R           2 4          2              2  +-+ |   4      2
+--R       (16c x  - 20b c x  - 32a c + 30b )\|c \|c x  + b x  + a
+--R  /
+--R        3 +-+
+--R     96c \|c
+--R                                                    Type: Expression(Integer)
+--E 78
+
+--S 79 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3   2      2 3         5  4         3 2        2 4  2
+--R                 (288a b c  + 96a b c - 90a b )x  + (1152a b c - 480a b )x
+--R               + 
+--R                      4          3 3
+--R                 1152a b c - 480a b
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                        2 2 2         4       6  6
+--R                 (- 432a b c  + 144a b c + 15b )x
+--R               + 
+--R                        3   2       2 3          5  4
+--R                 (- 864a b c  - 288a b c + 270a b )x
+--R               + 
+--R                         3 2        2 4  2        4          3 3
+--R                 (- 1728a b c + 720a b )x  - 1152a b c + 480a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                        3      3 2  10          2 3        2 2      4   8
+--R             (- 192a b c  - 16b c )x   + (- 384a c  - 48a b c  + 20b c)x
+--R           + 
+--R                 2   2        3       5  6        2 2          4  4
+--R             (96a b c  + 32a b c - 30b )x  + (864a b c - 360a b )x
+--R           + 
+--R                   3          2 3  2
+--R             (1152a b c - 480a b )x
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                  2 4        2 3  12        2   3        3 2  10
+--R             (128a c  + 96a b c )x   + (480a b c  - 24a b c )x
+--R           + 
+--R                  3 3       2 2 2        4   8
+--R             (384a c  - 144a b c  + 60a b c)x
+--R           + 
+--R                    3   2      2 3          5  6           3 2        2 4  4
+--R             (- 672a b c  - 80a b c + 150a b )x  + (- 1440a b c + 600a b )x
+--R           + 
+--R                     4          3 3  2
+--R             (- 1152a b c + 480a b )x
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                 2 4         2 3  4        2   3 2        3 3  +-+
+--R           ((768a c  + 576a b c )x  + 3072a b c x  + 3072a c )\|c
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                         4      3 3  6           2 4          2 3  4
+--R             (- 1152a b c  - 96b c )x  + (- 2304a c  - 1728a b c )x
+--R           + 
+--R                    2   3 2        3 3
+--R             - 4608a b c x  - 3072a c
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R     ,
+--R
+--R                      3   2      2 3         5  4         3 2        2 4  2
+--R                 (288a b c  + 96a b c - 90a b )x  + (1152a b c - 480a b )x
+--R               + 
+--R                      4          3 3
+--R                 1152a b c - 480a b
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                        2 2 2         4       6  6
+--R                 (- 432a b c  + 144a b c + 15b )x
+--R               + 
+--R                        3   2       2 3          5  4
+--R                 (- 864a b c  - 288a b c + 270a b )x
+--R               + 
+--R                         3 2        2 4  2        4          3 3
+--R                 (- 1728a b c + 720a b )x  - 1152a b c + 480a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                       3     3 2  10          2 3        2 2      4   8
+--R             (- 96a b c  - 8b c )x   + (- 192a c  - 24a b c  + 10b c)x
+--R           + 
+--R                 2   2        3       5  6        2 2          4  4
+--R             (48a b c  + 16a b c - 15b )x  + (432a b c - 180a b )x
+--R           + 
+--R                  3          2 3  2
+--R             (576a b c - 240a b )x
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                 2 4        2 3  12        2   3        3 2  10
+--R             (64a c  + 48a b c )x   + (240a b c  - 12a b c )x
+--R           + 
+--R                  3 3      2 2 2        4   8
+--R             (192a c  - 72a b c  + 30a b c)x
+--R           + 
+--R                    3   2      2 3         5  6          3 2        2 4  4
+--R             (- 336a b c  - 40a b c + 75a b )x  + (- 720a b c + 300a b )x
+--R           + 
+--R                    4          3 3  2
+--R             (- 576a b c + 240a b )x
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                 2 4         2 3  4        2   3 2        3 3  +---+
+--R           ((384a c  + 288a b c )x  + 1536a b c x  + 1536a c )\|- c
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                        4      3 3  6           2 4         2 3  4
+--R             (- 576a b c  - 48b c )x  + (- 1152a c  - 864a b c )x
+--R           + 
+--R                    2   3 2        3 3
+--R             - 2304a b c x  - 1536a c
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 79
+
+--S 80 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3   2      2 3         5  4         3 2        2 4  2
+--R               (288a b c  + 96a b c - 90a b )x  + (1152a b c - 480a b )x
+--R             + 
+--R                    4          3 3
+--R               1152a b c - 480a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                      2 2 2         4       6  6
+--R               (- 432a b c  + 144a b c + 15b )x
+--R             + 
+--R                      3   2       2 3          5  4           3 2        2 4  2
+--R               (- 864a b c  - 288a b c + 270a b )x  + (- 1728a b c + 720a b )x
+--R             + 
+--R                      4          3 3
+--R               - 1152a b c + 480a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                      3   2      2 3         5  4           3 2        2 4  2
+--R               (- 288a b c  - 96a b c + 90a b )x  + (- 1152a b c + 480a b )x
+--R             + 
+--R                      4          3 3
+--R               - 1152a b c + 480a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                    2 2 2         4       6  6
+--R               (432a b c  - 144a b c - 15b )x
+--R             + 
+--R                    3   2       2 3          5  4         3 2        2 4  2
+--R               (864a b c  + 288a b c - 270a b )x  + (1728a b c - 720a b )x
+--R             + 
+--R                    4          3 3
+--R               1152a b c - 480a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                  3 2      2 2          4  4           3          2 3  2
+--R           (- 256a c  + 48a b c + 180a b )x  + (- 1024a b c + 960a b )x
+--R         + 
+--R                  4        3 2
+--R           - 1024a c + 960a b
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                3   2       2 3         5  6        4 2       3 2        2 4  4
+--R           (384a b c  - 328a b c - 30a b )x  + (768a c  - 144a b c - 540a b )x
+--R         + 
+--R                 4           3 3  2        5        4 2
+--R           (1536a b c - 1440a b )x  + 1024a c - 960a b
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                                               +---------------+
+--R             2 4         2 3  4        2   3 2        3 3  +-+ |   4      2
+--R       ((768a c  + 576a b c )x  + 3072a b c x  + 3072a c )\|c \|c x  + b x  + a
+--R     + 
+--R                       4      3 3  6           2 4          2 3  4
+--R           (- 1152a b c  - 96b c )x  + (- 2304a c  - 1728a b c )x
+--R         + 
+--R                  2   3 2        3 3
+--R           - 4608a b c x  - 3072a c
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      3   2      2 3         5  4           3 2        2 4  2
+--R               (- 288a b c  - 96a b c + 90a b )x  + (- 1152a b c + 480a b )x
+--R             + 
+--R                      4          3 3
+--R               - 1152a b c + 480a b
+--R          *
+--R                    +---------------+
+--R              +---+ |   4      2
+--R             \|- c \|c x  + b x  + a
+--R         + 
+--R                    2 2 2         4       6  6
+--R               (432a b c  - 144a b c - 15b )x
+--R             + 
+--R                    3   2       2 3          5  4         3 2        2 4  2
+--R               (864a b c  + 288a b c - 270a b )x  + (1728a b c - 720a b )x
+--R             + 
+--R                    4          3 3
+--R               1152a b c - 480a b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                    3   2       2 3          5  4         3 2        2 4  2
+--R               (576a b c  + 192a b c - 180a b )x  + (2304a b c - 960a b )x
+--R             + 
+--R                    4          3 3
+--R               2304a b c - 960a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|c \|c x  + b x  + a
+--R         + 
+--R                      2 2 2         4       6  6
+--R               (- 864a b c  + 288a b c + 30b )x
+--R             + 
+--R                       3   2       2 3          5  4
+--R               (- 1728a b c  - 576a b c + 540a b )x
+--R             + 
+--R                       3 2         2 4  2        4          3 3
+--R               (- 3456a b c + 1440a b )x  - 2304a b c + 960a b
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                  3 2      2 2          4  4           3          2 3  2
+--R           (- 256a c  + 48a b c + 180a b )x  + (- 1024a b c + 960a b )x
+--R         + 
+--R                  4        3 2
+--R           - 1024a c + 960a b
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                3   2       2 3         5  6        4 2       3 2        2 4  4
+--R           (384a b c  - 328a b c - 30a b )x  + (768a c  - 144a b c - 540a b )x
+--R         + 
+--R                 4           3 3  2        5        4 2
+--R           (1536a b c - 1440a b )x  + 1024a c - 960a b
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R               2 4         2 3  4        2   3 2        3 3  +---+ +-+
+--R         ((768a c  + 576a b c )x  + 3072a b c x  + 3072a c )\|- c \|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                       4      3 3  6           2 4          2 3  4
+--R           (- 1152a b c  - 96b c )x  + (- 2304a c  - 1728a b c )x
+--R         + 
+--R                  2   3 2        3 3
+--R           - 4608a b c x  - 3072a c
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 83
+
+)clear all
+
+--S 84 of 1057
+t0:=x^5/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 5
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 1057
+r0:=1/16*(3*b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+_
+   c*x^4)))/c^(5/2)-3/8*b*sqrt(a+b*x^2+c*x^4)/c^2+1/4*x^2*sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                      2
+--R                   2              2c x  + b
+--R       (- 4a c + 3b )atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|c \|c x  + b x  + a
+--R     + 
+--R                        +---------------+
+--R            2       +-+ |   4      2
+--R       (4c x  - 6b)\|c \|c x  + b x  + a
+--R  /
+--R        2 +-+
+--R     16c \|c
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                       +---------------+
+--R                            3  2      2         2  +-+ |   4      2
+--R             ((16a b c - 12b )x  + 32a c - 24a b )\|a \|c x  + b x  + a
+--R           + 
+--R                 2 2       2      4  4         2           3  2      3       2 2
+--R           (- 16a c  + 8a b c + 3b )x  + (- 32a b c + 24a b )x  - 32a c + 24a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                    2     2   6                 3  4         2         2  2  +-+
+--R           ((- 16a c  - 4b c)x  + (- 8a b c + 6b )x  + (- 32a c + 24a b )x )\|c
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                  2 8         2     2   6                 3  4
+--R             16b c x  + (32a c  - 8b c)x  + (24a b c - 18b )x
+--R           + 
+--R                 2         2  2
+--R             (32a c - 24a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                                      +---------------+
+--R               2 2         2  +-+ +-+ |   4      2
+--R         (64b c x  + 128a c )\|a \|c \|c x  + b x  + a
+--R       + 
+--R                  3      2 2  4           2 2       2 2  +-+
+--R         ((- 64a c  - 16b c )x  - 128a b c x  - 128a c )\|c
+--R     ,
+--R
+--R                                                         +---------------+
+--R                              3  2      2         2  +-+ |   4      2
+--R             ((- 16a b c + 12b )x  - 32a c + 24a b )\|a \|c x  + b x  + a
+--R           + 
+--R                 2 2       2      4  4       2           3  2      3       2 2
+--R             (16a c  - 8a b c - 3b )x  + (32a b c - 24a b )x  + 32a c - 24a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                   2     2   6                 3  4         2         2  2
+--R           ((- 8a c  - 2b c)x  + (- 4a b c + 3b )x  + (- 16a c + 12a b )x )
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                   2 8         2     2   6                3  4
+--R               8b c x  + (16a c  - 4b c)x  + (12a b c - 9b )x
+--R             + 
+--R                   2         2  2
+--R               (16a c - 12a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                       +---------------+
+--R               2 2        2  +---+ +-+ |   4      2
+--R         (32b c x  + 64a c )\|- c \|a \|c x  + b x  + a
+--R       + 
+--R                  3     2 2  4          2 2      2 2  +---+
+--R         ((- 32a c  - 8b c )x  - 64a b c x  - 64a c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 86
+
+--S 87 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                     +---------------+
+--R                          3  2      2         2  +-+ |   4      2
+--R           ((16a b c - 12b )x  + 32a c - 24a b )\|a \|c x  + b x  + a
+--R         + 
+--R               2 2       2      4  4         2           3  2      3       2 2
+--R         (- 16a c  + 8a b c + 3b )x  + (- 32a b c + 24a b )x  - 32a c + 24a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                                                     +---------------+
+--R                          3  2      2         2  +-+ |   4      2
+--R           ((16a b c - 12b )x  + 32a c - 24a b )\|a \|c x  + b x  + a
+--R         + 
+--R               2 2       2      4  4         2           3  2      3       2 2
+--R         (- 16a c  + 8a b c + 3b )x  + (- 32a b c + 24a b )x  - 32a c + 24a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                                +---------------+
+--R               2 2      2   +-+ |   4      2
+--R       (- 24a b x  - 48a b)\|c \|c x  + b x  + a
+--R     + 
+--R                     3  4        2 2      2   +-+ +-+
+--R       ((24a b c + 6b )x  + 48a b x  + 48a b)\|a \|c
+--R  /
+--R                                    +---------------+
+--R             2 2         2  +-+ +-+ |   4      2
+--R       (64b c x  + 128a c )\|a \|c \|c x  + b x  + a
+--R     + 
+--R                3      2 2  4           2 2       2 2  +-+
+--R       ((- 64a c  - 16b c )x  - 128a b c x  - 128a c )\|c
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                           +---------------+
+--R                          3  2      2         2  +---+ +-+ |   4      2
+--R           ((16a b c - 12b )x  + 32a c - 24a b )\|- c \|a \|c x  + b x  + a
+--R         + 
+--R                     2 2       2      4  4         2           3  2      3
+--R               (- 16a c  + 8a b c + 3b )x  + (- 32a b c + 24a b )x  - 32a c
+--R             + 
+--R                  2 2
+--R               24a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                                                           +---------------+
+--R                            3  2      2         2  +-+ +-+ |   4      2
+--R           ((- 32a b c + 24b )x  - 64a c + 48a b )\|a \|c \|c x  + b x  + a
+--R         + 
+--R                     2 2        2      4  4       2           3  2      3
+--R                 (32a c  - 16a b c - 6b )x  + (64a b c - 48a b )x  + 64a c
+--R               + 
+--R                      2 2
+--R                 - 48a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                                      +---------------+
+--R               2 2      2   +---+ +-+ |   4      2
+--R       (- 24a b x  - 48a b)\|- c \|c \|c x  + b x  + a
+--R     + 
+--R                     3  4        2 2      2   +---+ +-+ +-+
+--R       ((24a b c + 6b )x  + 48a b x  + 48a b)\|- c \|a \|c
+--R  /
+--R                                          +---------------+
+--R             2 2         2  +---+ +-+ +-+ |   4      2
+--R       (64b c x  + 128a c )\|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                3      2 2  4           2 2       2 2  +---+ +-+
+--R       ((- 64a c  - 16b c )x  - 128a b c x  - 128a c )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 1057
+t0:=x^3/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1057
+r0:=-1/4*b*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(3/2)+_
+   1/2*sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R                             2                     +---------------+
+--R                         2c x  + b             +-+ |   4      2
+--R        - b atanh(-----------------------) + 2\|c \|c x  + b x  + a
+--R                        +---------------+
+--R                    +-+ |   4      2
+--R                  2\|c \|c x  + b x  + a
+--R   (2)  ------------------------------------------------------------
+--R                                      +-+
+--R                                   4c\|c
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   +---------------+
+--R               +-+ |   4      2         2 2
+--R           (2b\|a \|c x  + b x  + a  - b x  - 2a b)
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                     +---------------+
+--R               2 +-+ |   4      2             4       2  +-+ +-+
+--R         - 2b x \|c \|c x  + b x  + a  + (4c x  + 2b x )\|a \|c
+--R    /
+--R                  +---------------+
+--R          +-+ +-+ |   4      2                 2         +-+
+--R       8c\|a \|c \|c x  + b x  + a  + (- 4b c x  - 8a c)\|c
+--R     ,
+--R
+--R                     +---------------+
+--R                 +-+ |   4      2         2 2
+--R           (- 2b\|a \|c x  + b x  + a  + b x  + 2a b)
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                      +---------------+
+--R              2 +---+ |   4      2             4      2  +---+ +-+
+--R         - b x \|- c \|c x  + b x  + a  + (2c x  + b x )\|- c \|a
+--R    /
+--R                    +---------------+
+--R          +---+ +-+ |   4      2                 2         +---+
+--R       4c\|- c \|a \|c x  + b x  + a  + (- 2b c x  - 4a c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 93
+
+--S 94 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 +---------------+
+--R             +-+ |   4      2         2 2
+--R         (2b\|a \|c x  + b x  + a  - b x  - 2a b)
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R               +---------------+                                2
+--R           +-+ |   4      2         2 2                     2c x  + b
+--R       (2b\|a \|c x  + b x  + a  - b x  - 2a b)atanh(-----------------------)
+--R                                                           +---------------+
+--R                                                       +-+ |   4      2
+--R                                                     2\|c \|c x  + b x  + a
+--R     + 
+--R              +---------------+
+--R          +-+ |   4      2               2       +-+ +-+
+--R       4a\|c \|c x  + b x  + a  + (- 2b x  - 4a)\|a \|c
+--R  /
+--R                +---------------+
+--R        +-+ +-+ |   4      2                 2         +-+
+--R     8c\|a \|c \|c x  + b x  + a  + (- 4b c x  - 8a c)\|c
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------------+
+--R             +---+ +-+ |   4      2            2 2         +---+
+--R         (2b\|- c \|a \|c x  + b x  + a  + (- b x  - 2a b)\|- c )
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                       +---------------+
+--R               +-+ +-+ |   4      2           2 2         +-+
+--R         (- 4b\|a \|c \|c x  + b x  + a  + (2b x  + 4a b)\|c )
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                    +---------------+
+--R          +---+ +-+ |   4      2               2       +---+ +-+ +-+
+--R       4a\|- c \|c \|c x  + b x  + a  + (- 2b x  - 4a)\|- c \|a \|c
+--R  /
+--R                      +---------------+
+--R        +---+ +-+ +-+ |   4      2                 2         +---+ +-+
+--R     8c\|- c \|a \|c \|c x  + b x  + a  + (- 4b c x  - 8a c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 97
+
+)clear all
+
+--S 98 of 1057
+t0:=x/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 1057
+r0:=1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/sqrt(c)
+--R 
+--R
+--R                         2
+--R                     2c x  + b
+--R        atanh(-----------------------)
+--R                    +---------------+
+--R                +-+ |   4      2
+--R              2\|c \|c x  + b x  + a
+--R   (2)  ------------------------------
+--R                       +-+
+--R                     2\|c
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                  +---------------+
+--R                 +-+ +-+       2  |   4      2               4      2       +-+
+--R              (2\|a \|c  - 2c x )\|c x  + b x  + a  + (- 2c x  - b x  - 2a)\|c
+--R            + 
+--R                  2 +-+
+--R              2c x \|a
+--R         /
+--R                  +---------------+
+--R              +-+ |   4      2           2
+--R            2\|a \|c x  + b x  + a  - b x  - 2a
+--R    /
+--R         +-+
+--R       2\|c
+--R     ,
+--R                +---------------+
+--R          +---+ |   4      2         +---+ +-+
+--R         \|- c \|c x  + b x  + a  - \|- c \|a
+--R    atan(-------------------------------------)
+--R                             2
+--R                          c x
+--R    -------------------------------------------]
+--R                        +---+
+--R                       \|- c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 100
+
+--S 101 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                  +---------------+
+--R                 +-+ +-+       2  |   4      2               4      2       +-+
+--R              (2\|a \|c  - 2c x )\|c x  + b x  + a  + (- 2c x  - b x  - 2a)\|c
+--R            + 
+--R                  2 +-+
+--R              2c x \|a
+--R         /
+--R                  +---------------+
+--R              +-+ |   4      2           2
+--R            2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                          2
+--R                      2c x  + b
+--R       - atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R  /
+--R       +-+
+--R     2\|c
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                2
+--R          +---+             2c x  + b
+--R       - \|- c atanh(-----------------------)
+--R                           +---------------+
+--R                       +-+ |   4      2
+--R                     2\|c \|c x  + b x  + a
+--R     + 
+--R                        +---------------+
+--R                  +---+ |   4      2         +---+ +-+
+--R         +-+     \|- c \|c x  + b x  + a  - \|- c \|a
+--R       2\|c atan(-------------------------------------)
+--R                                     2
+--R                                  c x
+--R  /
+--R       +---+ +-+
+--R     2\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 104
+
+)clear all
+
+--S 105 of 1057
+t0:=1/(x*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R          +---------------+
+--R          |   4      2
+--R        x\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 105
+
+--S 106 of 1057
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)
+--R 
+--R
+--R                          2
+--R                       b x  + 2a
+--R          atanh(-----------------------)
+--R                      +---------------+
+--R                  +-+ |   4      2
+--R                2\|a \|c x  + b x  + a
+--R   (2)  - ------------------------------
+--R                         +-+
+--R                       2\|a
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +---------------+
+--R              +-+ |   4      2           2
+--R            2\|a \|c x  + b x  + a  - b x  - 2a
+--R        log(-----------------------------------)
+--R                              2
+--R                             x
+--R   (3)  ----------------------------------------
+--R                            +-+
+--R                          2\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 107
+
+--S 108 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             +---------------+
+--R         +-+ |   4      2           2                         2
+--R       2\|a \|c x  + b x  + a  - b x  - 2a                 b x  + 2a
+--R   log(-----------------------------------) + atanh(-----------------------)
+--R                         2                                +---------------+
+--R                        x                             +-+ |   4      2
+--R                                                    2\|a \|c x  + b x  + a
+--R   -------------------------------------------------------------------------
+--R                                       +-+
+--R                                     2\|a
+--R                                                    Type: Expression(Integer)
+--E 108
+
+--S 109 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 109
+
+)clear all
+
+--S 110 of 1057
+t0:=1/(x^3*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         3 |   4      2
+--R        x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 1057
+r0:=1/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(3/2)-_
+   1/2*sqrt(a+b*x^2+c*x^4)/(a*x^2)
+--R 
+--R
+--R                            2                      +---------------+
+--R           2             b x  + 2a             +-+ |   4      2
+--R        b x atanh(-----------------------) - 2\|a \|c x  + b x  + a
+--R                        +---------------+
+--R                    +-+ |   4      2
+--R                  2\|a \|c x  + b x  + a
+--R   (2)  ------------------------------------------------------------
+--R                                      2 +-+
+--R                                  4a x \|a
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +---------------+
+--R                2 +-+ |   4      2          2 4         2
+--R         (- 4b x \|a \|c x  + b x  + a  + 2b x  + 4a b x )
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                        +---------------+
+--R            2       +-+ |   4      2                   2  4         2     2
+--R       (2b x  + 8a)\|a \|c x  + b x  + a  + (- 8a c + b )x  - 6a b x  - 8a
+--R  /
+--R            +---------------+
+--R        2 2 |   4      2                 4      2 2  +-+
+--R     16a x \|c x  + b x  + a  + (- 8a b x  - 16a x )\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 112
+
+--S 113 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 +---------------+
+--R                 |   4      2           2 2         +-+
+--R         (- 4a b\|c x  + b x  + a  + (2b x  + 4a b)\|a )
+--R      *
+--R                +---------------+
+--R                |   4      2              2       +-+
+--R             2a\|c x  + b x  + a  + (- b x  - 2a)\|a
+--R         log(----------------------------------------)
+--R                                   2
+--R                               2a x
+--R     + 
+--R                 +---------------+
+--R                 |   4      2           2 2         +-+
+--R         (- 4a b\|c x  + b x  + a  + (2b x  + 4a b)\|a )
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R              +---------------+
+--R              |   4      2          2 2         +-+
+--R       - 2a b\|c x  + b x  + a  + (b x  + 2a b)\|a
+--R  /
+--R              +---------------+
+--R        2 +-+ |   4      2          2   2      3
+--R     16a \|a \|c x  + b x  + a  - 8a b x  - 16a
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 1057
+t0:=1/(x^5*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         5 |   4      2
+--R        x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 1057
+r0:=-1/16*(3*b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+_
+   c*x^4)))/a^(5/2)-1/4*sqrt(a+b*x^2+c*x^4)/(a*x^4)+3/8*b*sqrt(a+b*x^2+_
+   c*x^4)/(a^2*x^2)
+--R 
+--R
+--R   (2)
+--R                                     2
+--R                 2  4             b x  + 2a
+--R       (4a c - 3b )x atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|a \|c x  + b x  + a
+--R     + 
+--R                        +---------------+
+--R            2       +-+ |   4      2
+--R       (6b x  - 4a)\|a \|c x  + b x  + a
+--R  /
+--R        2 4 +-+
+--R     16a x \|a
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                            +---------------+
+--R                  2           3  6          3       2 2  4  |   4      2
+--R           ((- 64a b c + 48a b )x  + (- 128a c + 96a b )x )\|c x  + b x  + a
+--R         + 
+--R                   2 2        2       4  8        2           3  6
+--R               (64a c  - 32a b c - 12b )x  + (128a b c - 96a b )x
+--R             + 
+--R                    3       2 2  4
+--R               (128a c - 96a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                2          3  6       3        2 2  4      3   2       4
+--R         ((- 96a b c + 4a b )x  + (64a c - 120a b )x  - 64a b x  + 128a )
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                 2      4  8        2           3  6          3        2 2  4
+--R           (68a b c - 7b )x  + (128a b c + 40a b )x  + (- 128a c + 168a b )x
+--R         + 
+--R                 4
+--R           - 128a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                 +---------------+
+--R            3   6       4 4  +-+ |   4      2               4       3 2  8
+--R       (256a b x  + 512a x )\|a \|c x  + b x  + a  + (- 256a c - 64a b )x
+--R     + 
+--R             4   6       5 4
+--R       - 512a b x  - 512a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 117
+
+--S 118 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +---------------+
+--R                             +-+ |   4      2           2
+--R                     2     2\|a \|c x  + b x  + a  - b x  - 2a
+--R       (- 16a c + 12b )log(-----------------------------------)
+--R                                           2 +-+
+--R                                         2x \|a
+--R     + 
+--R                                       2
+--R                     2              b x  + 2a             2
+--R       (- 16a c + 12b )atanh(-----------------------) + 7b
+--R                                   +---------------+
+--R                               +-+ |   4      2
+--R                             2\|a \|c x  + b x  + a
+--R  /
+--R        2 +-+
+--R     64a \|a
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 119
+
+)clear all
+
+--S 120 of 1057
+t0:=1/(x^7*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         7 |   4      2
+--R        x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 120
+
+--S 121 of 1057
+r0:=1/32*b*(5*b^2-12*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+_
+   c*x^4)))/a^(7/2)-1/6*sqrt(a+b*x^2+c*x^4)/(a*x^6)+5/24*b*sqrt(a+b*x^2+_
+   c*x^4)/(a^2*x^4)-1/48*(15*b^2-16*a*c)*sqrt(a+b*x^2+c*x^4)/(a^3*x^2)
+--R 
+--R
+--R   (2)
+--R                                           2
+--R                       3  6             b x  + 2a
+--R       (- 36a b c + 15b )x atanh(-----------------------)
+--R                                       +---------------+
+--R                                   +-+ |   4      2
+--R                                 2\|a \|c x  + b x  + a
+--R     + 
+--R                                                +---------------+
+--R                    2  4          2      2  +-+ |   4      2
+--R       ((32a c - 30b )x  + 20a b x  - 16a )\|a \|c x  + b x  + a
+--R  /
+--R        3 6 +-+
+--R     96a x \|a
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     2   2         3        5  10         2 2           4  8
+--R               (1152a b c  + 384a b c - 360b )x   + (4608a b c - 1920a b )x
+--R             + 
+--R                     3           2 3  6
+--R               (4608a b c - 1920a b )x
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                   2 2 2         4       6  12
+--R           (- 1728a b c  + 576a b c + 60b )x
+--R         + 
+--R                   3   2        2 3           5  10           3 2         2 4  8
+--R           (- 3456a b c  - 1152a b c + 1080a b )x   + (- 6912a b c + 2880a b )x
+--R         + 
+--R                   4           3 3  6
+--R           (- 4608a b c + 1920a b )x
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                   2   2          3        5  10
+--R           (- 1248a b c  + 1232a b c - 102b )x
+--R         + 
+--R                   3 2       2 2          4  8           3           2 3  6
+--R           (- 3072a c  + 768a b c + 896a b )x  + (- 6144a b c + 3200a b )x
+--R         + 
+--R                   4         3 2  4       4   2        5
+--R           (- 2560a c + 1152a b )x  + 512a b x  + 2048a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R             3 3       2 2 2         4       6  12
+--R       (1024a c  - 624a b c  - 312a b c + 37b )x
+--R     + 
+--R             3   2        2 3         5  10
+--R       (4896a b c  - 3312a b c - 54a b )x
+--R     + 
+--R             4 2        3 2         2 4  8         4           3 3  6
+--R       (4608a c  + 1152a b c - 2304a b )x  + (7680a b c - 3840a b )x
+--R     + 
+--R             5         4 2  4        5   2        6
+--R       (1536a c - 1152a b )x  - 1536a b x  - 2048a
+--R  /
+--R                                                           +---------------+
+--R              5         4 2  10         5   8         6 6  |   4      2
+--R       ((3072a c + 2304a b )x   + 12288a b x  + 12288a x )\|c x  + b x  + a
+--R     + 
+--R                   4          3 3  12           5         4 2  10         5   8
+--R           (- 4608a b c - 384a b )x   + (- 9216a c - 6912a b )x   - 18432a b x
+--R         + 
+--R                   6 6
+--R           - 12288a x
+--R      *
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 122
+
+--S 123 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     3   2       2 3          5  4         3 2         2 4  2
+--R               (1152a b c  + 384a b c - 360a b )x  + (4608a b c - 1920a b )x
+--R             + 
+--R                    4           3 3
+--R               4608a b c - 1920a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       2 2 2         4       6  6
+--R               (- 1728a b c  + 576a b c + 60b )x
+--R             + 
+--R                       3   2        2 3           5  4
+--R               (- 3456a b c  - 1152a b c + 1080a b )x
+--R             + 
+--R                       3 2         2 4  2        4           3 3
+--R               (- 6912a b c + 2880a b )x  - 4608a b c + 1920a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                     3   2       2 3          5  4         3 2         2 4  2
+--R               (1152a b c  + 384a b c - 360a b )x  + (4608a b c - 1920a b )x
+--R             + 
+--R                    4           3 3
+--R               4608a b c - 1920a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                       2 2 2         4       6  6
+--R               (- 1728a b c  + 576a b c + 60b )x
+--R             + 
+--R                       3   2        2 3           5  4
+--R               (- 3456a b c  - 1152a b c + 1080a b )x
+--R             + 
+--R                       3 2         2 4  2        4           3 3
+--R               (- 6912a b c + 2880a b )x  - 4608a b c + 1920a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                3   2      2 3          5  4         3 2         2 4  2
+--R           (288a b c  - 80a b c - 222a b )x  + (1152a b c - 1184a b )x
+--R         + 
+--R                4           3 3
+--R           1152a b c - 1184a b
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                  2 2 2         4       6  6
+--R           (- 432a b c  + 408a b c + 37b )x
+--R         + 
+--R                  3   2       2 3          5  4           3 2         2 4  2
+--R           (- 864a b c  + 240a b c + 666a b )x  + (- 1728a b c + 1776a b )x
+--R         + 
+--R                  4           3 3
+--R           - 1152a b c + 1184a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                            +---------------+
+--R              5         4 2  4         5   2         6  +-+ |   4      2
+--R       ((3072a c + 2304a b )x  + 12288a b x  + 12288a )\|a \|c x  + b x  + a
+--R     + 
+--R               5          4 3  6           6         5 2  4         6   2
+--R       (- 4608a b c - 384a b )x  + (- 9216a c - 6912a b )x  - 18432a b x
+--R     + 
+--R               7
+--R       - 12288a
+--R                                                    Type: Expression(Integer)
+--E 123
+
+--S 124 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 124
+
+)clear all
+
+--S 125 of 1057
+t0:=x^4/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 4
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 1057
+--r0:=1/3*x*sqrt(a+b*x^2+c*x^4)/c-1/3*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))+1/3*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 126
+
+--S 127 of 1057
+--a0:=integrate(t0,x)
+--E 127
+
+--S 128 of 1057
+--m0:=a0-r0
+--E 128
+
+--S 129 of 1057
+--d0:=D(m0,x)
+--E 129
+
+)clear all
+
+--S 130 of 1057
+t0:=x^2/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 1057
+--r0:=1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(-b+sqrt(b^2-4*a*c))^(3/2)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/2*elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*(b-sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/((-c)^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 131
+
+--S 132 of 1057
+--a0:=integrate(t0,x)
+--E 132
+
+--S 133 of 1057
+--m0:=a0-r0
+--E 133
+
+--S 134 of 1057
+--d0:=D(m0,x)
+--E 134
+
+)clear all
+
+--S 135 of 1057
+t0:=1/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 135
+
+--S 136 of 1057
+--r0:=elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 136
+
+--S 137 of 1057
+--a0:=integrate(t0,x)
+--E 137
+
+--S 138 of 1057
+--m0:=a0-r0
+--E 138
+
+--S 139 of 1057
+--d0:=D(m0,x)
+--E 139
+
+)clear all
+
+--S 140 of 1057
+t0:=1/(x^2*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         2 |   4      2
+--R        x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 1057
+--r0:=-sqrt(a+b*x^2+c*x^4)/(a*x)+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(-b+sqrt(b^2-4*a*c))^(3/2)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))+1/2*elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*(b-sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(-c)*sqrt(a+b*x^2+c*x^4))
+--E 141
+
+--S 142 of 1057
+--a0:=integrate(t0,x)
+--E 142
+
+--S 143 of 1057
+--m0:=a0-r0
+--E 143
+
+--S 144 of 1057
+--d0:=D(m0,x)
+--E 144
+
+)clear all
+
+--S 145 of 1057
+t0:=1/(x^4*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         4 |   4      2
+--R        x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 1057
+--r0:=-1/3*sqrt(a+b*x^2+c*x^4)/(a*x^3)+2/3*b*sqrt(a+b*x^2+c*x^4)/(a^2*x)-1/3*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))+1/3*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 146
+
+--S 147 of 1057
+--a0:=integrate(t0,x)
+--E 147
+
+--S 148 of 1057
+--m0:=a0-r0
+--E 148
+
+--S 149 of 1057
+--d0:=D(m0,x)
+--E 149
+
+)clear all
+
+--S 150 of 1057
+t0:=x^9/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          9
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 150
+
+--S 151 of 1057
+r0:=3/16*(5*b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+_
+   c*x^4)))/c^(7/2)+x^6*(2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-_
+   1/8*b*(15*b^2-44*a*c)*sqrt(a+b*x^2+c*x^4)/(c^3*(b^2-4*a*c))-b*x^4*_
+   sqrt(a+b*x^2+c*x^4)/(c*(b^2-4*a*c))+1/4*(4*a*b+(5*b^2-12*a*c)*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/(c^2*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                     +---------------+
+--R               2 2        2       4  |   4      2
+--R         (- 48a c  + 72a b c - 15b )\|c x  + b x  + a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                 3     2 2  6             2      3   4
+--R           (16a c  - 4b c )x  + (- 40a b c  + 10b c)x
+--R         + 
+--R               2 2         2       4  2       2           3
+--R           (48a c  - 124a b c + 30b )x  - 104a b c + 30a b
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                           +---------------+
+--R           4      2 3  +-+ |   4      2
+--R     (64a c  - 16b c )\|c \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      2   2         3       5  6
+--R                 (144a b c  - 168a b c - 15b )x
+--R               + 
+--R                      3 2       2 2          4  4        3          2 3  2
+--R                 (288a c  - 144a b c - 270a b )x  + (576a b c - 720a b )x
+--R               + 
+--R                     4        3 2
+--R                 384a c - 480a b
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                       2 3        2 2      4   8
+--R                 (- 96a c  + 48a b c  + 90b c)x
+--R               + 
+--R                        2   2         3       5  6
+--R                 (- 480a b c  + 528a b c + 90b )x
+--R               + 
+--R                        3 2       2 2          4  4          3          2 3  2
+--R                 (- 480a c  + 144a b c + 570a b )x  + (- 768a b c + 960a b )x
+--R               + 
+--R                       4        3 2
+--R                 - 384a c + 480a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                     3      2 2  10             2      3   8
+--R             (- 32a c  - 24b c )x   + (- 48a b c  + 60b c)x
+--R           + 
+--R                    2 2         2        4  6          2            3  4
+--R             (- 224a c  + 160a b c + 150b )x  + (- 480a b c + 600a b )x
+--R           + 
+--R                    3        2 2  2
+--R             (- 384a c + 480a b )x
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                     3     3 2  12       2 3        2 2      4   10
+--R             (48a b c  + 4b c )x   + (96a c  - 48a b c  - 10b c)x
+--R           + 
+--R                  2   2         3       5  8        3 2       2 2          4  6
+--R             (304a b c  - 356a b c - 30b )x  + (416a c  - 208a b c - 390a b )x
+--R           + 
+--R                  3          2 3  4        4        3 2  2
+--R             (672a b c - 840a b )x  + (384a c - 480a b )x
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                      4      3 3  6        2 4         2 3  4       2   3 2
+--R             (192a b c  + 16b c )x  + (384a c  + 288a b c )x  + 768a b c x
+--R           + 
+--R                 3 3
+--R             512a c
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                      5      2 4  8              4      3 3  6
+--R             (- 128a c  - 96b c )x  + (- 640a b c  - 96b c )x
+--R           + 
+--R                    2 4         2 3  4        2   3 2       3 3
+--R             (- 640a c  - 608a b c )x  - 1024a b c x  - 512a c
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R     ,
+--R
+--R                        2   2         3       5  6
+--R                 (- 144a b c  + 168a b c + 15b )x
+--R               + 
+--R                        3 2       2 2          4  4          3          2 3  2
+--R                 (- 288a c  + 144a b c + 270a b )x  + (- 576a b c + 720a b )x
+--R               + 
+--R                       4        3 2
+--R                 - 384a c + 480a b
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                     2 3        2 2      4   8        2   2         3       5  6
+--R                 (96a c  - 48a b c  - 90b c)x  + (480a b c  - 528a b c - 90b )x
+--R               + 
+--R                      3 2       2 2          4  4        3          2 3  2
+--R                 (480a c  - 144a b c - 570a b )x  + (768a b c - 960a b )x
+--R               + 
+--R                     4        3 2
+--R                 384a c - 480a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                     3      2 2  10             2      3   8
+--R             (- 16a c  - 12b c )x   + (- 24a b c  + 30b c)x
+--R           + 
+--R                    2 2        2       4  6          2            3  4
+--R             (- 112a c  + 80a b c + 75b )x  + (- 240a b c + 300a b )x
+--R           + 
+--R                    3        2 2  2
+--R             (- 192a c + 240a b )x
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                     3     3 2  12       2 3        2 2     4   10
+--R             (24a b c  + 2b c )x   + (48a c  - 24a b c  - 5b c)x
+--R           + 
+--R                  2   2         3       5  8        3 2       2 2          4  6
+--R             (152a b c  - 178a b c - 15b )x  + (208a c  - 104a b c - 195a b )x
+--R           + 
+--R                  3          2 3  4        4        3 2  2
+--R             (336a b c - 420a b )x  + (192a c - 240a b )x
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                     4     3 3  6        2 4         2 3  4       2   3 2
+--R             (96a b c  + 8b c )x  + (192a c  + 144a b c )x  + 384a b c x
+--R           + 
+--R                 3 3
+--R             256a c
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                     5      2 4  8              4      3 3  6
+--R             (- 64a c  - 48b c )x  + (- 320a b c  - 48b c )x
+--R           + 
+--R                    2 4         2 3  4       2   3 2       3 3
+--R             (- 320a c  - 304a b c )x  - 512a b c x  - 256a c
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 152
+
+--S 153 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3 3       2 2 2         4       6  4
+--R               (384a c  - 288a b c  - 312a b c + 90b )x
+--R             + 
+--R                     3   2        2 3          5  2        4 2        3 2
+--R               (1536a b c  - 2304a b c + 480a b )x  + 1536a c  - 2304a b c
+--R             + 
+--R                   2 4
+--R               480a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                  3   3       2 3 2         5       7  6
+--R           (- 576a b c  + 816a b c  - 108a b c - 15b )x
+--R         + 
+--R                   4 3       3 2 2       2 4          6  4
+--R           (- 1152a c  + 864a b c  + 936a b c - 270a b )x
+--R         + 
+--R                 4   2        3 3        2 5  2        5 2        4 2        3 4
+--R         (- 2304a b c  + 3456a b c - 720a b )x  - 1536a c  + 2304a b c - 480a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                    3 3       2 2 2         4       6  4
+--R               (384a c  - 288a b c  - 312a b c + 90b )x
+--R             + 
+--R                     3   2        2 3          5  2        4 2        3 2
+--R               (1536a b c  - 2304a b c + 480a b )x  + 1536a c  - 2304a b c
+--R             + 
+--R                   2 4
+--R               480a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                  3   3       2 3 2         5       7  6
+--R           (- 576a b c  + 816a b c  - 108a b c - 15b )x
+--R         + 
+--R                   4 3       3 2 2       2 4          6  4
+--R           (- 1152a c  + 864a b c  + 936a b c - 270a b )x
+--R         + 
+--R                 4   2        3 3        2 5  2        5 2        4 2        3 4
+--R         (- 2304a b c  + 3456a b c - 720a b )x  - 1536a c  + 2304a b c - 480a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                  3   2       2 3          5  4           3 2        2 4  2
+--R           (- 832a b c  - 384a b c + 180a b )x  + (- 3328a b c + 960a b )x
+--R         + 
+--R                  4          3 3
+--R           - 3328a b c + 960a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                 2 2 2         4       6  6
+--R           (1248a b c  - 256a b c - 30b )x
+--R         + 
+--R                 3   2        2 3          5  4         3 2         2 4  2
+--R           (2496a b c  + 1152a b c - 540a b )x  + (4992a b c - 1440a b )x
+--R         + 
+--R                4          3 3
+--R           3328a b c - 960a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                2 5         2 4      4 3  4         2   4         3 3  2
+--R           (512a c  + 256a b c  - 96b c )x  + (2048a b c  - 512a b c )x
+--R         + 
+--R                3 4       2 2 3
+--R           2048a c  - 512a b c
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                  2   5         3 4      5 3  6
+--R           (- 768a b c  + 128a b c  + 16b c )x
+--R         + 
+--R                   3 5       2 2 4         4 3  4           3   4       2 3 3  2
+--R           (- 1536a c  - 768a b c  + 288a b c )x  + (- 3072a b c  + 768a b c )x
+--R         + 
+--R                  4 4       3 2 3
+--R           - 2048a c  + 512a b c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 153
+
+--S 154 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    3 3       2 2 2         4       6  4
+--R               (384a c  - 288a b c  - 312a b c + 90b )x
+--R             + 
+--R                     3   2        2 3          5  2        4 2        3 2
+--R               (1536a b c  - 2304a b c + 480a b )x  + 1536a c  - 2304a b c
+--R             + 
+--R                   2 4
+--R               480a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                      3   3       2 3 2         5       7  6
+--R               (- 576a b c  + 816a b c  - 108a b c - 15b )x
+--R             + 
+--R                       4 3       3 2 2       2 4          6  4
+--R               (- 1152a c  + 864a b c  + 936a b c - 270a b )x
+--R             + 
+--R                       4   2        3 3        2 5  2        5 2        4 2
+--R               (- 2304a b c  + 3456a b c - 720a b )x  - 1536a c  + 2304a b c
+--R             + 
+--R                     3 4
+--R               - 480a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                      3 3       2 2 2         4        6  4
+--R               (- 768a c  + 576a b c  + 624a b c - 180b )x
+--R             + 
+--R                       3   2        2 3          5  2        4 2        3 2
+--R               (- 3072a b c  + 4608a b c - 960a b )x  - 3072a c  + 4608a b c
+--R             + 
+--R                     2 4
+--R               - 960a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                     3   3        2 3 2         5       7  6
+--R               (1152a b c  - 1632a b c  + 216a b c + 30b )x
+--R             + 
+--R                     4 3        3 2 2        2 4          6  4
+--R               (2304a c  - 1728a b c  - 1872a b c + 540a b )x
+--R             + 
+--R                     4   2        3 3         2 5  2        5 2        4 2
+--R               (4608a b c  - 6912a b c + 1440a b )x  + 3072a c  - 4608a b c
+--R             + 
+--R                   3 4
+--R               960a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                  3   2       2 3          5  4           3 2        2 4  2
+--R           (- 832a b c  - 384a b c + 180a b )x  + (- 3328a b c + 960a b )x
+--R         + 
+--R                  4          3 3
+--R           - 3328a b c + 960a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                 2 2 2         4       6  6
+--R           (1248a b c  - 256a b c - 30b )x
+--R         + 
+--R                 3   2        2 3          5  4         3 2         2 4  2
+--R           (2496a b c  + 1152a b c - 540a b )x  + (4992a b c - 1440a b )x
+--R         + 
+--R                4          3 3
+--R           3328a b c - 960a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                2 5         2 4      4 3  4         2   4         3 3  2
+--R           (512a c  + 256a b c  - 96b c )x  + (2048a b c  - 512a b c )x
+--R         + 
+--R                3 4       2 2 3
+--R           2048a c  - 512a b c
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                  2   5         3 4      5 3  6
+--R           (- 768a b c  + 128a b c  + 16b c )x
+--R         + 
+--R                   3 5       2 2 4         4 3  4           3   4       2 3 3  2
+--R           (- 1536a c  - 768a b c  + 288a b c )x  + (- 3072a b c  + 768a b c )x
+--R         + 
+--R                  4 4       3 2 3
+--R           - 2048a c  + 512a b c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 1057
+t0:=x^7/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          7
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 1057
+r0:=-3/4*b*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(5/2)+_
+   x^4*(2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))+1/2*(3*b^2-4*a*c)*_
+   sqrt(a+b*x^2+c*x^4)/(c^2*(b^2-4*a*c))-(2*a+b*x^2)*sqrt(a+b*x^2+c*x^4)/_
+   (c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                         +---------------+                 2
+--R                      3  |   4      2                  2c x  + b
+--R       (- 12a b c + 3b )\|c x  + b x  + a atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|c \|c x  + b x  + a
+--R     + 
+--R             2     2   4                3  2      2        2  +-+
+--R       ((8a c  - 2b c)x  + (20a b c - 6b )x  + 16a c - 6a b )\|c
+--R  /
+--R                          +---------------+
+--R           3     2 2  +-+ |   4      2
+--R     (16a c  - 4b c )\|c \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                    +---------------+
+--R                           3  4        2 2      2   |   4      2
+--R             ((12a b c + 3b )x  + 24a b x  + 24a b)\|c x  + b x  + a
+--R           + 
+--R                   2   6                   3  4        2 2      2   +-+
+--R             (- 12b c x  + (- 24a b c - 12b )x  - 36a b x  - 24a b)\|a
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                                                 +---------------+
+--R                  6      2 4          2  +-+ +-+ |   4      2
+--R         (- 8b c x  - 18b x  - 24a b x )\|a \|c \|c x  + b x  + a
+--R       + 
+--R               2     2   8                3  6        2 4      2   2  +-+
+--R         ((8a c  + 2b c)x  + (20a b c + 6b )x  + 30a b x  + 24a b x )\|c
+--R    /
+--R                                                        +---------------+
+--R                3     2 2  4          2 2      2 2  +-+ |   4      2
+--R         ((16a c  + 4b c )x  + 32a b c x  + 32a c )\|c \|c x  + b x  + a
+--R       + 
+--R                 3 6           3      2 2  4          2 2      2 2  +-+ +-+
+--R         (- 16b c x  + (- 32a c  - 16b c )x  - 48a b c x  - 32a c )\|a \|c
+--R     ,
+--R
+--R                                                      +---------------+
+--R                             3  4        2 2      2   |   4      2
+--R             ((- 12a b c - 3b )x  - 24a b x  - 24a b)\|c x  + b x  + a
+--R           + 
+--R                 2   6                 3  4        2 2      2   +-+
+--R             (12b c x  + (24a b c + 12b )x  + 36a b x  + 24a b)\|a
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                                                  +---------------+
+--R                  6     2 4          2  +---+ +-+ |   4      2
+--R         (- 4b c x  - 9b x  - 12a b x )\|- c \|a \|c x  + b x  + a
+--R       + 
+--R               2    2   8                3  6        2 4      2   2  +---+
+--R         ((4a c  + b c)x  + (10a b c + 3b )x  + 15a b x  + 12a b x )\|- c
+--R    /
+--R                                                         +---------------+
+--R               3     2 2  4          2 2      2 2  +---+ |   4      2
+--R         ((8a c  + 2b c )x  + 16a b c x  + 16a c )\|- c \|c x  + b x  + a
+--R       + 
+--R                3 6           3     2 2  4          2 2      2 2  +---+ +-+
+--R         (- 8b c x  + (- 16a c  - 8b c )x  - 24a b c x  - 16a c )\|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 159
+
+--S 160 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                       +---------------+
+--R                  2       4  2      2           3  +-+ |   4      2
+--R           ((48a b c - 12b )x  + 96a b c - 24a b )\|a \|c x  + b x  + a
+--R         + 
+--R                 2   2     5  4         2 2         4  2      3         2 3
+--R           (- 48a b c  + 3b )x  + (- 96a b c + 24a b )x  - 96a b c + 24a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                                                       +---------------+
+--R                  2       4  2      2           3  +-+ |   4      2
+--R           ((48a b c - 12b )x  + 96a b c - 24a b )\|a \|c x  + b x  + a
+--R         + 
+--R                 2   2     5  4         2 2         4  2      3         2 3
+--R           (- 48a b c  + 3b )x  + (- 96a b c + 24a b )x  - 96a b c + 24a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                                                    +---------------+
+--R            2           3  2       3       2 2  +-+ |   4      2
+--R       ((64a b c - 24a b )x  + 128a c - 48a b )\|c \|c x  + b x  + a
+--R     + 
+--R                   2 2       2      4  4          2           3  2       3
+--R             (- 64a c  + 8a b c + 6b )x  + (- 128a b c + 48a b )x  - 128a c
+--R           + 
+--R                2 2
+--R             48a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                                                            +---------------+
+--R                3      3 2  2       2 3        2 2  +-+ +-+ |   4      2
+--R       ((64a b c  - 16b c )x  + 128a c  - 32a b c )\|a \|c \|c x  + b x  + a
+--R     + 
+--R                   2 4     4 2  4          2   3        3 2  2       3 3
+--R             (- 64a c  + 4b c )x  + (- 128a b c  + 32a b c )x  - 128a c
+--R           + 
+--R                2 2 2
+--R             32a b c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                             +---------------+
+--R                  2       4  2      2           3  +---+ +-+ |   4      2
+--R           ((48a b c - 12b )x  + 96a b c - 24a b )\|- c \|a \|c x  + b x  + a
+--R         + 
+--R                    2   2     5  4         2 2         4  2      3         2 3
+--R             ((- 48a b c  + 3b )x  + (- 96a b c + 24a b )x  - 96a b c + 24a b )
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                                                              +---------------+
+--R                    2       4  2       2           3  +-+ +-+ |   4      2
+--R           ((- 96a b c + 24b )x  - 192a b c + 48a b )\|a \|c \|c x  + b x  + a
+--R         + 
+--R                2   2     5  4        2 2         4  2       3         2 3  +-+
+--R           ((96a b c  - 6b )x  + (192a b c - 48a b )x  + 192a b c - 48a b )\|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                                                          +---------------+
+--R            2           3  2       3       2 2  +---+ +-+ |   4      2
+--R       ((64a b c - 24a b )x  + 128a c - 48a b )\|- c \|c \|c x  + b x  + a
+--R     + 
+--R                   2 2       2      4  4          2           3  2       3
+--R             (- 64a c  + 8a b c + 6b )x  + (- 128a b c + 48a b )x  - 128a c
+--R           + 
+--R                2 2
+--R             48a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                  3      3 2  2       2 3        2 2  +---+ +-+ +-+
+--R         ((64a b c  - 16b c )x  + 128a c  - 32a b c )\|- c \|a \|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                   2 4     4 2  4          2   3        3 2  2       3 3
+--R             (- 64a c  + 4b c )x  + (- 128a b c  + 32a b c )x  - 128a c
+--R           + 
+--R                2 2 2
+--R             32a b c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 163
+
+)clear all
+
+--S 164 of 1057
+t0:=x^5/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          5
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 1057
+r0:=1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(3/2)+x^2*_
+   (2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-b*sqrt(a+b*x^2+c*x^4)/_
+   (c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                   +---------------+                 2
+--R                2  |   4      2                  2c x  + b
+--R       (4a c - b )\|c x  + b x  + a atanh(-----------------------)
+--R                                                +---------------+
+--R                                            +-+ |   4      2
+--R                                          2\|c \|c x  + b x  + a
+--R     + 
+--R                    2  2         +-+
+--R       ((- 4a c + 2b )x  + 2a b)\|c
+--R  /
+--R                        +---------------+
+--R          2     2   +-+ |   4      2
+--R     (8a c  - 2b c)\|c \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 165
+
+--S 166 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            +---------------+
+--R                2       +-+ |   4      2              4         2     2
+--R           ((b x  + 2a)\|a \|c x  + b x  + a  - 2a c x  - 2a b x  - 2a )
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                   +---------------+
+--R             2 +-+ |   4      2               4       2  +-+ +-+
+--R         2a x \|c \|c x  + b x  + a  + (- 2b x  - 2a x )\|a \|c
+--R    /
+--R                                  +---------------+
+--R                2         +-+ +-+ |   4      2
+--R         (2b c x  + 4a c)\|a \|c \|c x  + b x  + a
+--R       + 
+--R                2 4           2     2   +-+
+--R         (- 4a c x  - 4a b c x  - 4a c)\|c
+--R     ,
+--R
+--R                            +---------------+
+--R                2       +-+ |   4      2              4         2     2
+--R           ((b x  + 2a)\|a \|c x  + b x  + a  - 2a c x  - 2a b x  - 2a )
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                    +---------------+
+--R            2 +---+ |   4      2              4      2  +---+ +-+
+--R         a x \|- c \|c x  + b x  + a  + (- b x  - a x )\|- c \|a
+--R    /
+--R                                   +---------------+
+--R               2         +---+ +-+ |   4      2
+--R         (b c x  + 2a c)\|- c \|a \|c x  + b x  + a
+--R       + 
+--R                2 4           2     2   +---+
+--R         (- 2a c x  - 2a b c x  - 2a c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 166
+
+--S 167 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          +---------------+
+--R              2        2  |   4      2
+--R           (8a c - 2a b )\|c x  + b x  + a
+--R         + 
+--R                         3  2     2        2  +-+
+--R           ((- 4a b c + b )x  - 8a c + 2a b )\|a
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                            +---------------+
+--R                2        2  |   4      2
+--R           (- 8a c + 2a b )\|c x  + b x  + a
+--R         + 
+--R                       3  2     2        2  +-+
+--R           ((4a b c - b )x  + 8a c - 2a b )\|a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                    +---------------+
+--R            +-+ +-+ |   4      2               2 2     2   +-+
+--R       4a b\|a \|c \|c x  + b x  + a  + (- 2a b x  - 4a b)\|c
+--R  /
+--R                             +---------------+
+--R           2 2       2   +-+ |   4      2
+--R       (16a c  - 4a b c)\|c \|c x  + b x  + a
+--R     + 
+--R                 2     3   2      2 2       2   +-+ +-+
+--R       ((- 8a b c  + 2b c)x  - 16a c  + 4a b c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+--S 169 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------------+
+--R                2        2  +---+ |   4      2
+--R           (- 8a c + 2a b )\|- c \|c x  + b x  + a
+--R         + 
+--R                       3  2     2        2  +---+ +-+
+--R           ((4a b c - b )x  + 8a c - 2a b )\|- c \|a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                               +---------------+
+--R               2        2  +-+ |   4      2
+--R           (16a c - 4a b )\|c \|c x  + b x  + a
+--R         + 
+--R                          3  2      2        2  +-+ +-+
+--R           ((- 8a b c + 2b )x  - 16a c + 4a b )\|a \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                          +---------------+
+--R            +---+ +-+ +-+ |   4      2               2 2     2   +---+ +-+
+--R       4a b\|- c \|a \|c \|c x  + b x  + a  + (- 2a b x  - 4a b)\|- c \|c
+--R  /
+--R                                   +---------------+
+--R           2 2       2   +---+ +-+ |   4      2
+--R       (16a c  - 4a b c)\|- c \|c \|c x  + b x  + a
+--R     + 
+--R                 2     3   2      2 2       2   +---+ +-+ +-+
+--R       ((- 8a b c  + 2b c)x  - 16a c  + 4a b c)\|- c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 170
+
+)clear all
+
+--S 171 of 1057
+t0:=x^3/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          3
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 1057
+r0:=(2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                      2
+--R                 - b x  - 2a
+--R   (2)  -----------------------------
+--R                    +---------------+
+--R                 2  |   4      2
+--R        (4a c - b )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                    4 +-+
+--R                                   x \|a
+--R   (3)  -----------------------------------------------------------
+--R                        +---------------+
+--R            2       +-+ |   4      2              4         2     2
+--R        (b x  + 2a)\|a \|c x  + b x  + a  - 2a c x  - 2a b x  - 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 173
+
+--S 174 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            +---------------+
+--R                        +-+ |   4      2              2     2
+--R                   - 4a\|a \|c x  + b x  + a  + 2a b x  + 4a
+--R   -------------------------------------------------------------------------
+--R                  +---------------+
+--R      2        2  |   4      2                      3  2     2        2  +-+
+--R   (8a c - 2a b )\|c x  + b x  + a  + ((- 4a b c + b )x  - 8a c + 2a b )\|a
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 175
+
+)clear all
+
+--S 176 of 1057
+t0:=x/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 1057
+r0:=(-b-2*c*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                      2
+--R                  2c x  + b
+--R   (2)  -----------------------------
+--R                    +---------------+
+--R                 2  |   4      2
+--R        (4a c - b )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           +---------------+
+--R                         2 |   4      2         2 +-+
+--R                      - x \|c x  + b x  + a  + x \|a
+--R   (3)  -----------------------------------------------------------
+--R                        +---------------+
+--R            2       +-+ |   4      2              4         2     2
+--R        (b x  + 2a)\|a \|c x  + b x  + a  - 2a c x  - 2a b x  - 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 178
+
+--S 179 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            +---------------+
+--R                        +-+ |   4      2         2 2
+--R                     2b\|a \|c x  + b x  + a  - b x  - 2a b
+--R   -------------------------------------------------------------------------
+--R                  +---------------+
+--R      2        2  |   4      2                      3  2     2        2  +-+
+--R   (8a c - 2a b )\|c x  + b x  + a  + ((- 4a b c + b )x  - 8a c + 2a b )\|a
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 1057
+t0:=1/(x*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R                            +---------------+
+--R            5      3        |   4      2
+--R        (c x  + b x  + a x)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1057
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(3/2)+_
+   (b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                     +---------------+                2
+--R                  2  |   4      2                  b x  + 2a
+--R       (- 4a c + b )\|c x  + b x  + a atanh(-----------------------)
+--R                                                  +---------------+
+--R                                              +-+ |   4      2
+--R                                            2\|a \|c x  + b x  + a
+--R     + 
+--R                2            2  +-+
+--R       (- 2b c x  + 4a c - 2b )\|a
+--R  /
+--R                        +---------------+
+--R        2        2  +-+ |   4      2
+--R     (8a c - 2a b )\|a \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +---------------+
+--R              2       |   4      2               4       2       +-+
+--R         ((b x  + 2a)\|c x  + b x  + a  + (- 2c x  - 2b x  - 2a)\|a )
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R             +---------------+
+--R           2 |   4      2               4       2  +-+
+--R       2b x \|c x  + b x  + a  + (- 2c x  - 2b x )\|a
+--R  /
+--R                         +---------------+
+--R            2     2  +-+ |   4      2          2   4     2   2     3
+--R     (2a b x  + 4a )\|a \|c x  + b x  + a  - 4a c x  - 4a b x  - 4a
+--R                                         Type: Union(Expression(Integer),...)
+--E 183
+
+--S 184 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +---------------+
+--R              2        2  |   4      2
+--R           (8a c - 2a b )\|c x  + b x  + a
+--R         + 
+--R                         3  2     2        2  +-+
+--R           ((- 4a b c + b )x  - 8a c + 2a b )\|a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                          +---------------+
+--R              2        2  |   4      2
+--R           (8a c - 2a b )\|c x  + b x  + a
+--R         + 
+--R                         3  2     2        2  +-+
+--R           ((- 4a b c + b )x  - 8a c + 2a b )\|a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                    +---------------+
+--R        2        2  |   4      2                       3  2     2        2  +-+
+--R     (8a c - 4a b )\|c x  + b x  + a  + ((- 4a b c + 2b )x  - 8a c + 4a b )\|a
+--R  /
+--R                           +---------------+
+--R           3      2 2  +-+ |   4      2             3        2 3  2      4
+--R       (16a c - 4a b )\|a \|c x  + b x  + a  + (- 8a b c + 2a b )x  - 16a c
+--R     + 
+--R         3 2
+--R       4a b
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 185
+
+)clear all
+
+--S 186 of 1057
+t0:=1/(x^3*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                           1
+--R   (1)  --------------------------------------
+--R                             +---------------+
+--R            7      5      3  |   4      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 1057
+r0:=3/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(5/2)+_
+   (b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^2*sqrt(a+b*x^2+c*x^4))-1/2*(3*b^2-_
+   8*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*(b^2-4*a*c)*x^2)
+--R 
+--R
+--R   (2)
+--R                         +---------------+                2
+--R                    3  2 |   4      2                  b x  + 2a
+--R       (12a b c - 3b )x \|c x  + b x  + a atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|a \|c x  + b x  + a
+--R     + 
+--R                2     2   4                  3  2     2        2  +-+
+--R       ((- 16a c  + 6b c)x  + (- 20a b c + 6b )x  - 8a c + 2a b )\|a
+--R  /
+--R                           +---------------+
+--R         3      2 2  2 +-+ |   4      2
+--R     (16a c - 4a b )x \|a \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                           +---------------+
+--R                           3  6        2 4      2   2  +-+ |   4      2
+--R           ((- 24a b c - 6b )x  - 48a b x  - 48a b x )\|a \|c x  + b x  + a
+--R         + 
+--R                2   8       2           3  6      2 2 4      3   2
+--R           24a b c x  + (48a b c + 24a b )x  + 72a b x  + 48a b x
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                      3  6       2         2  4      2   2      3  +-+
+--R         ((4a b c - 9b )x  + (64a c - 24a b )x  + 40a b x  + 32a )\|a
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R             2 2        2   8         2           3  6         3      2 2  4
+--R       (- 32a c  + 24a b c)x  + (- 48a b c + 24a b )x  + (- 80a c + 8a b )x
+--R     + 
+--R            3   2      4
+--R       - 56a b x  - 32a
+--R  /
+--R                                               +---------------+
+--R            4      3 2  6      4   4      5 2  |   4      2
+--R       ((32a c + 8a b )x  + 64a b x  + 64a x )\|c x  + b x  + a
+--R     + 
+--R             3     8         4       3 2  6      4   4      5 2  +-+
+--R       (- 32a b c x  + (- 64a c - 32a b )x  - 96a b x  - 64a x )\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 188
+
+--S 189 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  +---------------+
+--R                              +-+ |   4      2           2
+--R                      3     2\|a \|c x  + b x  + a  - b x  - 2a
+--R       (- 24a b c + 6b )log(-----------------------------------)
+--R                                            2 +-+
+--R                                          2x \|a
+--R     + 
+--R                                        2
+--R                      3              b x  + 2a                       3
+--R       (- 24a b c + 6b )atanh(-----------------------) - 28a b c + 9b
+--R                                    +---------------+
+--R                                +-+ |   4      2
+--R                              2\|a \|c x  + b x  + a
+--R  /
+--R         3      2 2  +-+
+--R     (32a c - 8a b )\|a
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 190
+
+)clear all
+
+--S 191 of 1057
+t0:=1/(x^5*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                           1
+--R   (1)  --------------------------------------
+--R                             +---------------+
+--R            9      7      5  |   4      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1057
+r0:=-3/16*(5*b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/_
+   a^(7/2)+(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^4*sqrt(a+b*x^2+c*x^4))-_
+   1/4*(5*b^2-12*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*(b^2-4*a*c)*x^4)+_
+   1/8*b*(15*b^2-52*a*c)*sqrt(a+b*x^2+c*x^4)/(a^3*(b^2-4*a*c)*x^2)
+--R 
+--R
+--R   (2)
+--R                                     +---------------+
+--R             2 2        2       4  4 |   4      2
+--R         (48a c  - 72a b c + 15b )x \|c x  + b x  + a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                    2      3   6         2 2         2       4  4
+--R           (104a b c  - 30b c)x  + (- 48a c  + 124a b c - 30b )x
+--R         + 
+--R               2           3  2      3      2 2
+--R           (40a b c - 10a b )x  - 16a c + 4a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                            +---------------+
+--R         4       3 2  4 +-+ |   4      2
+--R     (64a c - 16a b )x \|a \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      2   2         3       5  10
+--R               (- 576a b c  + 672a b c + 60b )x
+--R             + 
+--R                       3 2       2 2           4  8           3           2 3  6
+--R               (- 1152a c  + 576a b c + 1080a b )x  + (- 2304a b c + 2880a b )x
+--R             + 
+--R                       4         3 2  4
+--R               (- 1536a c + 1920a b )x
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                    2 3         2 2       4   12
+--R               (384a c  - 192a b c  - 360b c)x
+--R             + 
+--R                     2   2          3        5  10
+--R               (1920a b c  - 2112a b c - 360b )x
+--R             + 
+--R                     3 2       2 2           4  8         3           2 3  6
+--R               (1920a c  - 576a b c - 2280a b )x  + (3072a b c - 3840a b )x
+--R             + 
+--R                     4         3 2  4
+--R               (1536a c - 1920a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                   2   2         3       5  10
+--R           (- 1216a b c  + 228a b c + 79b )x
+--R         + 
+--R                  3 2        2 2          4  8           3          2 3  6
+--R           (- 384a c  - 2808a b c + 702a b )x  + (- 3648a b c - 288a b )x
+--R         + 
+--R                4         3 2  4       4   2       5
+--R           (640a c - 2496a b )x  - 768a b x  + 512a
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                2 3         2 2       4   12
+--R           (256a c  + 872a b c  - 354b c)x
+--R         + 
+--R                 2   2         3        5  10
+--R           (3200a b c  + 424a b c - 354b )x
+--R         + 
+--R                3 2        2 2          4  8         3           2 3  6
+--R           (128a c  + 5672a b c - 802a b )x  + (3840a b c + 1408a b )x
+--R         + 
+--R                  4         3 2  4       4   2       5
+--R           (- 896a c + 2944a b )x  + 512a b x  - 512a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  4         3 3  10         5         4 2  8        5   6
+--R             (768a b c + 64a b )x   + (1536a c + 1152a b )x  + 3072a b x
+--R           + 
+--R                  6 4
+--R             2048a x
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R              5 2       4 2   12           5          4 3  10
+--R       (- 512a c  - 384a b c)x   + (- 2560a b c - 384a b )x
+--R     + 
+--R               6         5 2  8        6   6        7 4
+--R       (- 2560a c - 2432a b )x  - 4096a b x  - 2048a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 193
+
+--S 194 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       4 3        3 2 2        2 4          6  4
+--R               (- 1536a c  + 1152a b c  + 1248a b c - 360a b )x
+--R             + 
+--R                       4   2        3 3         2 5  2        5 2        4 2
+--R               (- 6144a b c  + 9216a b c - 1920a b )x  - 6144a c  + 9216a b c
+--R             + 
+--R                      3 4
+--R               - 1920a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                     3   3        2 3 2         5       7  6
+--R               (2304a b c  - 3264a b c  + 432a b c + 60b )x
+--R             + 
+--R                     4 3        3 2 2        2 4           6  4
+--R               (4608a c  - 3456a b c  - 3744a b c + 1080a b )x
+--R             + 
+--R                     4   2         3 3         2 5  2        5 2        4 2
+--R               (9216a b c  - 13824a b c + 2880a b )x  + 6144a c  - 9216a b c
+--R             + 
+--R                    3 4
+--R               1920a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                       4 3        3 2 2        2 4          6  4
+--R               (- 1536a c  + 1152a b c  + 1248a b c - 360a b )x
+--R             + 
+--R                       4   2        3 3         2 5  2        5 2        4 2
+--R               (- 6144a b c  + 9216a b c - 1920a b )x  - 6144a c  + 9216a b c
+--R             + 
+--R                      3 4
+--R               - 1920a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                     3   3        2 3 2         5       7  6
+--R               (2304a b c  - 3264a b c  + 432a b c + 60b )x
+--R             + 
+--R                     4 3        3 2 2        2 4           6  4
+--R               (4608a c  - 3456a b c  - 3744a b c + 1080a b )x
+--R             + 
+--R                     4   2         3 3         2 5  2        5 2        4 2
+--R               (9216a b c  - 13824a b c + 2880a b )x  + 6144a c  - 9216a b c
+--R             + 
+--R                    3 4
+--R               1920a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                   4 3        3 2 2        2 4          6  4
+--R           (- 1024a c  + 1760a b c  + 1264a b c - 474a b )x
+--R         + 
+--R                   4   2         3 3         2 5  2        5 2         4 2
+--R           (- 4096a b c  + 10112a b c - 2528a b )x  - 4096a c  + 10112a b c
+--R         + 
+--R                  3 4
+--R           - 2528a b
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                 3   3        2 3 2         5       7  6
+--R           (1536a b c  - 3664a b c  + 632a b c + 79b )x
+--R         + 
+--R                 4 3        3 2 2        2 4           6  4
+--R           (3072a c  - 5280a b c  - 3792a b c + 1422a b )x
+--R         + 
+--R                 4   2         3 3         2 5  2        5 2         4 2
+--R           (6144a b c  - 15168a b c + 3792a b )x  + 4096a c  - 10112a b c
+--R         + 
+--R                3 4
+--R           2528a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 6 2        5 2        4 4  4         6           5 3  2
+--R           (2048a c  + 1024a b c - 384a b )x  + (8192a b c - 2048a b )x
+--R         + 
+--R                7         6 2
+--R           8192a c - 2048a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R               6   2       5 3       4 5  6
+--R       (- 3072a b c  + 512a b c + 64a b )x
+--R     + 
+--R               7 2        6 2         5 4  4            7           6 3  2
+--R       (- 6144a c  - 3072a b c + 1152a b )x  + (- 12288a b c + 3072a b )x
+--R     + 
+--R              8         7 2
+--R       - 8192a c + 2048a b
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 1057
+t0:=x^6/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          6
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1057
+--r0:=x^3*(2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-b*x*sqrt(a+b*x^2+c*x^4)/(c*(b^2-4*a*c))+(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*(b^2-4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*(b^2-4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 197
+
+--S 198 of 1057
+--a0:=integrate(t0,x)
+--E 198
+
+--S 199 of 1057
+--m0:=a0-r0
+--E 199
+
+--S 200 of 1057
+--d0:=D(m0,x)
+--E 200
+
+)clear all
+
+--S 201 of 1057
+t0:=x^4/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          4
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 1057
+--r0:=x*(2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-1/2*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 202
+
+--S 203 of 1057
+--a0:=integrate(t0,x)
+--E 203
+
+--S 204 of 1057
+--m0:=a0-r0
+--E 204
+
+--S 205 of 1057
+--d0:=D(m0,x)
+--E 205
+
+)clear all
+
+--S 206 of 1057
+t0:=x^2/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          2
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 1057
+--r0:=-x*(b+2*c*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))+elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/((b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 207
+
+--S 208 of 1057
+--a0:=integrate(t0,x)
+--E 208
+
+--S 209 of 1057
+--m0:=a0-r0
+--E 209
+
+--S 210 of 1057
+--d0:=D(m0,x)
+--E 210
+
+)clear all
+
+--S 211 of 1057
+t0:=1/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                         1
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 1057
+--r0:=x*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-1/2*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 212
+
+--S 213 of 1057
+--a0:=integrate(t0,x)
+--E 213
+
+--S 214 of 1057
+--m0:=a0-r0
+--E 214
+
+--S 215 of 1057
+--d0:=D(m0,x)
+--E 215
+
+)clear all
+
+--S 216 of 1057
+t0:=1/(x^2*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                           1
+--R   (1)  --------------------------------------
+--R                             +---------------+
+--R            6      4      2  |   4      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 1057
+--r0:=(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x*sqrt(a+b*x^2+c*x^4))-2*(b^2-3*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*(b^2-4*a*c)*x)+(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))-elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 217
+
+--S 218 of 1057
+--a0:=integrate(t0,x)
+--E 218
+
+--S 219 of 1057
+--m0:=a0-r0
+--E 219
+
+--S 220 of 1057
+--d0:=D(m0,x)
+--E 220
+
+)clear all
+
+--S 221 of 1057
+t0:=x^4/sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1057
+r0:=-2/3*b*sqrt(b*x^2+c*x^4)/(c^2*x)+1/3*x*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                    +-----------+
+--R            2       |   4      2
+--R        (c x  - 2b)\|c x  + b x
+--R   (2)  -------------------------
+--R                     2
+--R                   3c x
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +--------+
+--R                 4 |   2            6       4  +-+
+--R           - 3b x \|c x  + b  + (c x  + 3b x )\|b
+--R   (3)  ---------------------------------------------
+--R                          +--------+
+--R             2        +-+ |   2              2      2
+--R        (3c x  + 12b)\|b \|c x  + b  - 9b c x  - 12b
+--R                                         Type: Union(Expression(Integer),...)
+--E 223
+
+--S 224 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       +--------+
+--R              2 4         2     2  +-+ |   2            2 4     2   2     3
+--R         ((- c x  - 2b c x  + 8b )\|b \|c x  + b  + 3b c x  - 2b c x  - 8b )
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 +--------+
+--R             2 5 |   2          3 7       2 5  +-+
+--R       - 3b c x \|c x  + b  + (c x  + 3b c x )\|b
+--R  /
+--R                           +--------+
+--R        3 3        2   +-+ |   2            3 3      2 2
+--R     (3c x  + 12b c x)\|b \|c x  + b  - 9b c x  - 12b c x
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                             +--------+
+--R                2 7          5      2 3  +-+ |   2         3 9        2 7
+--R           (- 6c x  - 32b c x  - 32b x )\|b \|c x  + b  + c x  + 18b c x
+--R         + 
+--R              2   5      3 3
+--R           48b c x  + 32b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                +--------+
+--R           3 10        2 8      2   6      3 4  |   2
+--R       (- c x   - 18b c x  - 48b c x  - 32b x )\|c x  + b
+--R     + 
+--R          3 10        2 8      2   6      3 4  +-+
+--R       (6c x   + 38b c x  + 64b c x  + 32b x )\|b
+--R  /
+--R                                             +--------+
+--R           3 6        2 4      2   2      3  |   2
+--R         (c x  + 18b c x  + 48b c x  + 32b )\|c x  + b
+--R       + 
+--R              3 6        2 4      2   2      3  +-+
+--R         (- 6c x  - 38b c x  - 64b c x  - 32b )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 1057
+t0:=x^3/sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 1057
+r0:=-1/2*b*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)+1/2*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                       2 +-+             +-----------+
+--R                      x \|c          +-+ |   4      2
+--R        - b atanh(--------------) + \|c \|c x  + b x
+--R                   +-----------+
+--R                   |   4      2
+--R                  \|c x  + b x
+--R   (2)  ----------------------------------------------
+--R                               +-+
+--R                            2c\|c
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   +--------+
+--R               +-+ |   2             2     2
+--R           (2b\|b \|c x  + b  - b c x  - 2b )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                             +--------+
+--R               3         +-+ |   2             3         +-+ +-+
+--R         (- c x  - 2b x)\|c \|c x  + b  + (2c x  + 2b x)\|b \|c
+--R    /
+--R                  +--------+
+--R          +-+ +-+ |   2             2 2         +-+
+--R       4c\|b \|c \|c x  + b  + (- 2c x  - 4b c)\|c
+--R     ,
+--R
+--R                     +--------+
+--R                 +-+ |   2              2     2
+--R           (- 4b\|b \|c x  + b  + 2b c x  + 4b )
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                               +--------+
+--R               3         +---+ |   2             3         +---+ +-+
+--R         (- c x  - 2b x)\|- c \|c x  + b  + (2c x  + 2b x)\|- c \|b
+--R    /
+--R                    +--------+
+--R          +---+ +-+ |   2             2 2         +---+
+--R       4c\|- c \|b \|c x  + b  + (- 2c x  - 4b c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 228
+
+--S 229 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 +--------+
+--R             +-+ |   2             2     2
+--R         (2b\|b \|c x  + b  - b c x  - 2b )
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R               +--------+                           2 +-+
+--R           +-+ |   2             2     2           x \|c
+--R       (2b\|b \|c x  + b  - b c x  - 2b )atanh(--------------)
+--R                                                +-----------+
+--R                                                |   4      2
+--R                                               \|c x  + b x
+--R     + 
+--R                    +--------+                    +-----------+
+--R            +-+ +-+ |   2            2       +-+  |   4      2
+--R       (- 2\|b \|c \|c x  + b  + (c x  + 2b)\|c )\|c x  + b x
+--R     + 
+--R                           +--------+
+--R             3         +-+ |   2             3         +-+ +-+
+--R       (- c x  - 2b x)\|c \|c x  + b  + (2c x  + 2b x)\|b \|c
+--R  /
+--R                +--------+
+--R        +-+ +-+ |   2             2 2         +-+
+--R     4c\|b \|c \|c x  + b  + (- 2c x  - 4b c)\|c
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                    3 8        2 6       2   4      3 2  +-+ +-+    4 9
+--R               (- 7c x  - 56b c x  - 112b c x  - 64b x )\|b \|c  - c x
+--R             + 
+--R                      3 7      2 2 5      3   3
+--R               - 24b c x  - 80b c x  - 64b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R             4 10        3 8       2 2 6       3   4      4 2  +-+
+--R           (c x   + 25b c x  + 104b c x  + 144b c x  + 64b x )\|c
+--R         + 
+--R              4 9        3 7       2 2 5      3   3  +-+
+--R           (7c x  + 56b c x  + 112b c x  + 64b c x )\|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R               4 11        3 9       2 2 7       3   5      4 3  +-+
+--R           (- c x   - 25b c x  - 104b c x  - 144b c x  - 64b x )\|c
+--R         + 
+--R                4 10        3 8       2 2 6      3   4  +-+
+--R           (- 7c x   - 56b c x  - 112b c x  - 64b c x )\|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R          4 11        3 9       2 2 7       3   5      4 3  +-+ +-+    5 12
+--R       (7c x   + 63b c x  + 168b c x  + 176b c x  + 64b x )\|b \|c  + c x
+--R     + 
+--R            4 10       2 3 8       3 2 6      4   4
+--R       25b c x   + 104b c x  + 144b c x  + 64b c x
+--R  /
+--R               4 8        3 6       2 2 4       3   2      4  +-+
+--R             (c x  + 25b c x  + 104b c x  + 144b c x  + 64b )\|c
+--R           + 
+--R                4 7        3 5       2 2 3      3     +-+
+--R             (7c x  + 56b c x  + 112b c x  + 64b c x)\|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R              4 8        3 6       2 2 4       3   2      4  +-+ +-+    5 9
+--R         (- 7c x  - 63b c x  - 168b c x  - 176b c x  - 64b )\|b \|c  - c x
+--R       + 
+--R                4 7       2 3 5       3 2 3      4
+--R         - 25b c x  - 104b c x  - 144b c x  - 64b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +--------+                                     2 +-+
+--R           +---+ +-+ |   2                2     2  +---+           x \|c
+--R       (2b\|- c \|b \|c x  + b  + (- b c x  - 2b )\|- c )atanh(--------------)
+--R                                                                +-----------+
+--R                                                                |   4      2
+--R                                                               \|c x  + b x
+--R     + 
+--R                       +--------+
+--R               +-+ +-+ |   2               2     2  +-+
+--R         (- 4b\|b \|c \|c x  + b  + (2b c x  + 4b )\|c )
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                          +--------+                          +-----------+
+--R            +---+ +-+ +-+ |   2            2       +---+ +-+  |   4      2
+--R       (- 2\|- c \|b \|c \|c x  + b  + (c x  + 2b)\|- c \|c )\|c x  + b x
+--R     + 
+--R                                 +--------+
+--R             3         +---+ +-+ |   2             3         +---+ +-+ +-+
+--R       (- c x  - 2b x)\|- c \|c \|c x  + b  + (2c x  + 2b x)\|- c \|b \|c
+--R  /
+--R                      +--------+
+--R        +---+ +-+ +-+ |   2             2 2         +---+ +-+
+--R     4c\|- c \|b \|c \|c x  + b  + (- 2c x  - 4b c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                              +--------+                           +-----------+
+--R               4       2  +-+ |   2         2 6         4     2 2  |   4      2
+--R       ((- 4c x  - 8b x )\|b \|c x  + b  + c x  + 8b c x  + 8b x )\|c x  + b x
+--R     + 
+--R                                  +--------+
+--R           2 7         5     2 3  |   2           2 7          5     2 3  +-+
+--R       (- c x  - 8b c x  - 8b x )\|c x  + b  + (4c x  + 12b c x  + 8b x )\|b
+--R  /
+--R                               +--------+
+--R          2 4         2     2  |   2             2 4          2     2  +-+
+--R       ((c x  + 8b c x  + 8b )\|c x  + b  + (- 4c x  - 12b c x  - 8b )\|b )
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+)clear all
+
+--S 233 of 1057
+t0:=x^2/sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 1057
+r0:=sqrt(b*x^2+c*x^4)/(c*x)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (2)  --------------
+--R              c x
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2 +-+
+--R               x \|b
+--R   (3)  -------------------
+--R             +--------+
+--R         +-+ |   2
+--R        \|b \|c x  + b  - b
+--R                                         Type: Union(Expression(Integer),...)
+--E 235
+
+--S 236 of 1057
+m0:=a0-r0
+--R 
+--R
+--R                +--------+      +-----------+
+--R            +-+ |   2           |   4      2       3 +-+
+--R        (- \|b \|c x  + b  + b)\|c x  + b x   + c x \|b
+--R   (4)  ------------------------------------------------
+--R                           +--------+
+--R                       +-+ |   2
+--R                   c x\|b \|c x  + b  - b c x
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 +--------+                +-----------+
+--R             +-+ |   2           3         |   4      2
+--R       (- 2x\|b \|c x  + b  + c x  + 2b x)\|c x  + b x
+--R     + 
+--R                        +--------+
+--R             4       2  |   2             4       2  +-+
+--R       (- c x  - 2b x )\|c x  + b  + (2c x  + 2b x )\|b
+--R  /
+--R                  +--------+                       +-----------+
+--R          2       |   2               2       +-+  |   4      2
+--R     ((c x  + 2b)\|c x  + b  + (- 2c x  - 2b)\|b )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 1057
+t0:=x/sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 1057
+r0:=atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/sqrt(c)
+--R 
+--R
+--R                   2 +-+
+--R                  x \|c
+--R        atanh(--------------)
+--R               +-----------+
+--R               |   4      2
+--R              \|c x  + b x
+--R   (2)  ---------------------
+--R                  +-+
+--R                 \|c
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         +--------+
+--R          +-+ +-+        |   2              2      +-+       +-+
+--R        (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R    log(--------------------------------------------------------)
+--R                                +--------+
+--R                            +-+ |   2
+--R                           \|b \|c x  + b  - b
+--R   [-------------------------------------------------------------,
+--R                                  +-+
+--R                                 \|c
+--R                 +--------+
+--R           +---+ |   2         +---+ +-+
+--R          \|- c \|c x  + b  - \|- c \|b
+--R    2atan(------------------------------)
+--R                        c x
+--R    -------------------------------------]
+--R                     +---+
+--R                    \|- c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 240
+
+--S 241 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            +--------+
+--R             +-+ +-+        |   2              2      +-+       +-+
+--R           (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R       log(--------------------------------------------------------)
+--R                                   +--------+
+--R                               +-+ |   2
+--R                              \|b \|c x  + b  - b
+--R     + 
+--R                    2 +-+
+--R                   x \|c
+--R       - atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R  /
+--R      +-+
+--R     \|c
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                                    +--------+
+--R                   2       +-+ +-+    2 3           |   2
+--R           ((- 3c x  - 4b)\|b \|c  + c x  + 4b c x)\|c x  + b
+--R         + 
+--R             2 4         2     2  +-+        2 3           +-+
+--R           (c x  + 5b c x  + 4b )\|c  + (- 3c x  - 4b c x)\|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                               +--------+
+--R            2 5         3     2   +-+      2 4         2  +-+  |   2
+--R       ((- c x  - 5b c x  - 4b x)\|c  + (3c x  + 4b c x )\|b )\|c x  + b
+--R     + 
+--R          2 5         3     2   +-+ +-+    3 6       2 4     2   2
+--R       (3c x  + 7b c x  + 4b x)\|b \|c  - c x  - 5b c x  - 4b c x
+--R  /
+--R                                                               +--------+
+--R            2 4         2     2  +-+        2 3           +-+  |   2
+--R         ((c x  + 5b c x  + 4b )\|c  + (- 3c x  - 4b c x)\|b )\|c x  + b
+--R       + 
+--R              2 4         2     2  +-+ +-+    3 5       2 3     2
+--R         (- 3c x  - 7b c x  - 4b )\|b \|c  + c x  + 5b c x  + 4b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                    +--------+
+--R                      2 +-+                   +---+ |   2         +---+ +-+
+--R      +---+          x \|c           +-+     \|- c \|c x  + b  - \|- c \|b
+--R   - \|- c atanh(--------------) + 2\|c atan(------------------------------)
+--R                  +-----------+                            c x
+--R                  |   4      2
+--R                 \|c x  + b x
+--R   -------------------------------------------------------------------------
+--R                                    +---+ +-+
+--R                                   \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 243
+
+--S 244 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R         +-----------+     +--------+
+--R         |   4      2      |   2
+--R        \|c x  + b x   - x\|c x  + b
+--R   (7)  -----------------------------
+--R           +--------+ +-----------+
+--R           |   2      |   4      2
+--R          \|c x  + b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+)clear all
+
+--S 245 of 1057
+t0:=1/sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 1057
+r0:=-atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/sqrt(b)
+--R 
+--R
+--R                       +-+
+--R                     x\|b
+--R          atanh(--------------)
+--R                 +-----------+
+--R                 |   4      2
+--R                \|c x  + b x
+--R   (2)  - ---------------------
+--R                    +-+
+--R                   \|b
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------+
+--R                 |   2         +-+
+--R         +-+    \|c x  + b  - \|b
+--R        \|b log(------------------)
+--R                         x
+--R   (3)  ---------------------------
+--R                     b
+--R                                         Type: Union(Expression(Integer),...)
+--E 247
+
+--S 248 of 1057
+m0:=a0-r0
+--R 
+--R
+--R             +--------+
+--R             |   2         +-+                 +-+
+--R            \|c x  + b  - \|b                x\|b
+--R        log(------------------) + atanh(--------------)
+--R                     x                   +-----------+
+--R                                         |   4      2
+--R                                        \|c x  + b x
+--R   (4)  -----------------------------------------------
+--R                               +-+
+--R                              \|b
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R            +--------+         +-----------+         +--------+
+--R            |   2         +-+  |   4      2      +-+ |   2           3
+--R        (- \|c x  + b  + \|b )\|c x  + b x   - x\|b \|c x  + b  + c x  + b x
+--R   (5)  --------------------------------------------------------------------
+--R                           +--------+               +-----------+
+--R                       +-+ |   2           3        |   4      2
+--R                    (x\|b \|c x  + b  - c x  - b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 1057
+t0:=1/(x*sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          +-----------+
+--R          |   4      2
+--R        x\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 1057
+r0:=-sqrt(b*x^2+c*x^4)/(b*x^2)
+--R 
+--R
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R   (2)  - --------------
+--R                  2
+--R               b x
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +--------+
+--R         +-+ |   2           2
+--R        \|b \|c x  + b  - c x  - b
+--R   (3)  --------------------------
+--R             +--------+
+--R             |   2            +-+
+--R         b x\|c x  + b  - b x\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 252
+
+--S 253 of 1057
+m0:=a0-r0
+--R 
+--R
+--R          +--------+         +-----------+         +--------+
+--R          |   2         +-+  |   4      2      +-+ |   2           3
+--R        (\|c x  + b  - \|b )\|c x  + b x   + x\|b \|c x  + b  - c x  - b x
+--R   (4)  ------------------------------------------------------------------
+--R                                 +--------+
+--R                               2 |   2           2 +-+
+--R                            b x \|c x  + b  - b x \|b
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                +--------+              +-----------+
+--R            +-+ |   2           2       |   4      2
+--R       (- 2\|b \|c x  + b  + c x  + 2b)\|c x  + b x
+--R     + 
+--R                       +--------+
+--R             3         |   2             3         +-+
+--R       (- c x  - 2b x)\|c x  + b  + (2c x  + 2b x)\|b
+--R  /
+--R                     +--------+                          +-----------+
+--R          4       2  |   2               4       2  +-+  |   4      2
+--R     ((c x  + 2b x )\|c x  + b  + (- 2c x  - 2b x )\|b )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 254
+
+)clear all
+
+--S 255 of 1057
+t0:=1/(x^2*sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         2 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 255
+
+--S 256 of 1057
+r0:=1/2*c*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-_
+   1/2*sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R                         +-+             +-----------+
+--R           3           x\|b          +-+ |   4      2
+--R        c x atanh(--------------) - \|b \|c x  + b x
+--R                   +-----------+
+--R                   |   4      2
+--R                  \|c x  + b x
+--R   (2)  ----------------------------------------------
+--R                               3 +-+
+--R                           2b x \|b
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                         +--------+
+--R                  +--------+                             |   2         +-+
+--R                2 |   2          2 4         2  +-+     \|c x  + b  - \|b
+--R       (- 2b c x \|c x  + b  + (c x  + 2b c x )\|b )log(------------------)
+--R                                                                 x
+--R     + 
+--R                      +--------+
+--R             2     2  |   2                 2     2  +-+
+--R       (b c x  + 2b )\|c x  + b  + (- 2b c x  - 2b )\|b
+--R  /
+--R               +--------+
+--R       2 2 +-+ |   2          2   4     3 2
+--R     4b x \|b \|c x  + b  - 2b c x  - 4b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 257
+
+--S 258 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                     +--------+
+--R                    +--------+                       |   2         +-+
+--R              3 +-+ |   2         2 5         3     \|c x  + b  - \|b
+--R       (- 2c x \|b \|c x  + b  + c x  + 2b c x )log(------------------)
+--R                                                             x
+--R     + 
+--R                    +--------+                               +-+
+--R              3 +-+ |   2         2 5         3            x\|b
+--R       (- 2c x \|b \|c x  + b  + c x  + 2b c x )atanh(--------------)
+--R                                                       +-----------+
+--R                                                       |   4      2
+--R                                                      \|c x  + b x
+--R     + 
+--R           +--------+                      +-----------+
+--R           |   2              2       +-+  |   4      2
+--R       (2b\|c x  + b  + (- c x  - 2b)\|b )\|c x  + b x
+--R     + 
+--R                         +--------+
+--R           3         +-+ |   2              3     2
+--R       (c x  + 2b x)\|b \|c x  + b  - 2b c x  - 2b x
+--R  /
+--R           +--------+
+--R       2 3 |   2                 5     2 3  +-+
+--R     4b x \|c x  + b  + (- 2b c x  - 4b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 258
+
+--S 259 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                     +--------+
+--R              2 4          2      2  |   2           2 4          2      2  +-+
+--R         ((- c x  - 12b c x  - 16b )\|c x  + b  + (5c x  + 20b c x  + 16b )\|b )
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                        +--------+
+--R            2 5          3      2   +-+ |   2         3 7        2 5      2   3
+--R       (- 5c x  - 20b c x  - 16b x)\|b \|c x  + b  + c x  + 13b c x  + 28b c x
+--R     + 
+--R          3
+--R       16b x
+--R  /
+--R                                         +--------+
+--R            2 7          5      2 3  +-+ |   2         3 9        2 7      2   5
+--R         (5c x  + 20b c x  + 16b x )\|b \|c x  + b  - c x  - 13b c x  - 28b c x
+--R       + 
+--R              3 3
+--R         - 16b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 259
+
+)clear all
+
+--S 260 of 1057
+t0:=1/(x^3*sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         3 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 1057
+r0:=-1/3*sqrt(b*x^2+c*x^4)/(b*x^4)+2/3*c*sqrt(b*x^2+c*x^4)/(b^2*x^2)
+--R 
+--R
+--R                    +-----------+
+--R             2      |   4      2
+--R        (2c x  - b)\|c x  + b x
+--R   (2)  -------------------------
+--R                    2 4
+--R                  3b x
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 +--------+
+--R        2 4         2     2  +-+ |   2          3 6       2 4     2   2     3
+--R   (- 6c x  - 5b c x  + 4b )\|b \|c x  + b  + 2c x  + 9b c x  + 3b c x  - 4b
+--R   --------------------------------------------------------------------------
+--R                               +--------+
+--R               2   5      3 3  |   2             2   5      3 3  +-+
+--R            (3b c x  + 12b x )\|c x  + b  + (- 9b c x  - 12b x )\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 262
+
+--S 263 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    +--------+
+--R               2 4         2     2  |   2           2 4         2     2  +-+
+--R         ((- 2c x  - 7b c x  + 4b )\|c x  + b  + (6c x  + 5b c x  - 4b )\|b )
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                      +--------+
+--R            2 5         3     2   +-+ |   2          3 7       2 5     2   3
+--R       (- 6c x  - 5b c x  + 4b x)\|b \|c x  + b  + 2c x  + 9b c x  + 3b c x
+--R     + 
+--R           3
+--R       - 4b x
+--R  /
+--R                        +--------+
+--R        2   6      3 4  |   2             2   6      3 4  +-+
+--R     (3b c x  + 12b x )\|c x  + b  + (- 9b c x  - 12b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                           +--------+
+--R                2 4          2      2  +-+ |   2         3 6        2 4
+--R           (- 6c x  - 32b c x  - 32b )\|b \|c x  + b  + c x  + 18b c x
+--R         + 
+--R              2   2      3
+--R           48b c x  + 32b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                              +--------+
+--R           3 7        2 5      2   3      3   |   2
+--R       (- c x  - 18b c x  - 48b c x  - 32b x)\|c x  + b
+--R     + 
+--R          3 7        2 5      2   3      3   +-+
+--R       (6c x  + 38b c x  + 64b c x  + 32b x)\|b
+--R  /
+--R                                                +--------+
+--R           3 10        2 8      2   6      3 4  |   2
+--R         (c x   + 18b c x  + 48b c x  + 32b x )\|c x  + b
+--R       + 
+--R              3 10        2 8      2   6      3 4  +-+
+--R         (- 6c x   - 38b c x  - 64b c x  - 32b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 1057
+t0:=1/(x^4*sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         4 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 1057
+r0:=-3/8*c^2*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)-_
+   1/4*sqrt(b*x^2+c*x^4)/(b*x^5)+3/8*c*sqrt(b*x^2+c*x^4)/(b^2*x^3)
+--R 
+--R
+--R                            +-+                         +-----------+
+--R            2 5           x\|b              2       +-+ |   4      2
+--R        - 3c x atanh(--------------) + (3c x  - 2b)\|b \|c x  + b x
+--R                      +-----------+
+--R                      |   4      2
+--R                     \|c x  + b x
+--R   (2)  -------------------------------------------------------------
+--R                                    2 5 +-+
+--R                                  8b x \|b
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                   +--------+
+--R                   3 6      2 2 4  |   2
+--R             (12b c x  + 24b c x )\|c x  + b
+--R           + 
+--R                  4 8        3 6      2 2 4  +-+
+--R             (- 3c x  - 24b c x  - 24b c x )\|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                               +--------+
+--R              3 6      2 2 4     3   2      4  |   2
+--R       (- 3b c x  - 22b c x  - 8b c x  + 16b )\|c x  + b
+--R     + 
+--R             3 6      2 2 4      4  +-+
+--R       (12b c x  + 28b c x  - 16b )\|b
+--R  /
+--R                             +--------+
+--R         3   6      4 4  +-+ |   2          3 2 8      4   6      5 4
+--R     (32b c x  + 64b x )\|b \|c x  + b  - 8b c x  - 64b c x  - 64b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 267
+
+--S 268 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  +--------+
+--R              3 7        2 5  +-+ |   2          4 9        3 7      2 2 5
+--R         ((12c x  + 24b c x )\|b \|c x  + b  - 3c x  - 24b c x  - 24b c x )
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                  +--------+
+--R              3 7        2 5  +-+ |   2          4 9        3 7      2 2 5
+--R         ((12c x  + 24b c x )\|b \|c x  + b  - 3c x  - 24b c x  - 24b c x )
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                          +--------+
+--R                   2 4      2   2      3  |   2
+--R           (- 12b c x  - 16b c x  + 16b )\|c x  + b
+--R         + 
+--R              3 6        2 4     2   2      3  +-+
+--R           (3c x  + 22b c x  + 8b c x  - 16b )\|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                  +--------+
+--R            3 7        2 5     2   3      3   +-+ |   2             3 7
+--R       (- 3c x  - 22b c x  - 8b c x  + 16b x)\|b \|c x  + b  + 12b c x
+--R     + 
+--R          2 2 5      4
+--R       28b c x  - 16b x
+--R  /
+--R                         +--------+
+--R         3   7      4 5  |   2             2 2 9      3   7      4 5  +-+
+--R     (32b c x  + 64b x )\|c x  + b  + (- 8b c x  - 64b c x  - 64b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                               +--------+
+--R               4 8        3 6       2 2 4       3   2       4  |   2
+--R           (- c x  - 40b c x  - 240b c x  - 448b c x  - 256b )\|c x  + b
+--R         + 
+--R              4 8         3 6       2 2 4       3   2       4  +-+
+--R           (9c x  + 120b c x  + 432b c x  + 576b c x  + 256b )\|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                                  +--------+
+--R            4 9         3 7       2 2 5       3   3       4   +-+ |   2
+--R       (- 9c x  - 120b c x  - 432b c x  - 576b c x  - 256b x)\|b \|c x  + b
+--R     + 
+--R        5 11        4 9       2 3 7       3 2 5       4   3       5
+--R       c x   + 41b c x  + 280b c x  + 688b c x  + 704b c x  + 256b x
+--R  /
+--R                                                                     +--------+
+--R            4 13         3 11       2 2 9       3   7       4 5  +-+ |   2
+--R         (9c x   + 120b c x   + 432b c x  + 576b c x  + 256b x )\|b \|c x  + b
+--R       + 
+--R            5 15        4 13       2 3 11       3 2 9       4   7       5 5
+--R         - c x   - 41b c x   - 280b c x   - 688b c x  - 704b c x  - 256b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 269
+
+)clear all
+
+--S 270 of 1057
+t0:=x^4/sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 270
+
+--S 271 of 1057
+--r0:=1/3*x*sqrt(a+c*x^4)/c+1/3*a^(5/4)*elliptic_f(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/((-c)^(5/4)*sqrt(a+c*x^4))
+--E 271
+
+--S 272 of 1057
+--a0:=integrate(t0,x)
+--E 272
+
+--S 273 of 1057
+--m0:=a0-r0
+--E 273
+
+--S 274 of 1057
+--d0:=D(m0,x)
+--E 274
+
+)clear all
+
+--S 275 of 1057
+t0:=x^3/sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 1057
+r0:=1/2*sqrt(a+c*x^4)/c
+--R 
+--R
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R   (2)  -----------
+--R             2c
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R   (3)  -----------
+--R             2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 277
+
+--S 278 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 1057
+t0:=x^2/sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 1057
+--r0:=a^(3/4)*elliptic_e(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/((-c)^(3/4)*sqrt(a+c*x^4))-a^(3/4)*elliptic_f(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/((-c)^(3/4)*sqrt(a+c*x^4))
+--E 281
+
+--S 282 of 1057
+--a0:=integrate(t0,x)
+--E 282
+
+--S 283 of 1057
+--m0:=a0-r0
+--E 283
+
+--S 284 of 1057
+--d0:=D(m0,x)
+--E 284
+
+)clear all
+
+--S 285 of 1057
+t0:=x/sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 285
+
+--S 286 of 1057
+r0:=1/2*atanh(x^2*sqrt(c)/sqrt(a+c*x^4))/sqrt(c)
+--R 
+--R
+--R                  2 +-+
+--R                 x \|c
+--R        atanh(-----------)
+--R               +--------+
+--R               |   4
+--R              \|c x  + a
+--R   (2)  ------------------
+--R                 +-+
+--R               2\|c
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          +--------+
+--R          +-+ +-+      2  |   4              4      +-+      2 +-+
+--R        (\|a \|c  - c x )\|c x  + a  + (- c x  - a)\|c  + c x \|a
+--R    log(----------------------------------------------------------)
+--R                                 +--------+
+--R                             +-+ |   4
+--R                            \|a \|c x  + a  - a
+--R   [---------------------------------------------------------------,
+--R                                   +-+
+--R                                 2\|c
+--R                +--------+
+--R          +---+ |   4         +---+ +-+
+--R         \|- c \|c x  + a  - \|- c \|a
+--R    atan(------------------------------)
+--R                         2
+--R                      c x
+--R    ------------------------------------]
+--R                    +---+
+--R                   \|- c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 287
+
+--S 288 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             +--------+
+--R             +-+ +-+      2  |   4              4      +-+      2 +-+
+--R           (\|a \|c  - c x )\|c x  + a  + (- c x  - a)\|c  + c x \|a
+--R       log(----------------------------------------------------------)
+--R                                    +--------+
+--R                                +-+ |   4
+--R                               \|a \|c x  + a  - a
+--R     + 
+--R                   2 +-+
+--R                  x \|c
+--R       - atanh(-----------)
+--R                +--------+
+--R                |   4
+--R               \|c x  + a
+--R  /
+--R       +-+
+--R     2\|c
+--R                                                    Type: Expression(Integer)
+--E 288
+
+--S 289 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                      +--------+
+--R                          2 +-+                 +---+ |   4         +---+ +-+
+--R           +---+         x \|c         +-+     \|- c \|c x  + a  - \|- c \|a
+--R        - \|- c atanh(-----------) + 2\|c atan(------------------------------)
+--R                       +--------+                              2
+--R                       |   4                                c x
+--R                      \|c x  + a
+--R   (6)  ----------------------------------------------------------------------
+--R                                        +---+ +-+
+--R                                      2\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 1057
+t0:=1/sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 1057
+--r0:=a^(1/4)*elliptic_f(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/((-c)^(1/4)*sqrt(a+c*x^4))
+--E 293
+
+--S 294 of 1057
+--a0:=integrate(t0,x)
+--E 294
+
+--S 295 of 1057
+--m0:=a0-r0
+--E 295
+
+--S 296 of 1057
+--d0:=D(m0,x)
+--E 296
+
+)clear all
+
+--S 297 of 1057
+t0:=1/(x*sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R          +--------+
+--R          |   4
+--R        x\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 297
+
+--S 298 of 1057
+r0:=-1/2*atanh(sqrt(a+c*x^4)/sqrt(a))/sqrt(a)
+--R 
+--R
+--R                 +--------+
+--R                 |   4
+--R                \|c x  + a
+--R          atanh(-----------)
+--R                     +-+
+--R                    \|a
+--R   (2)  - ------------------
+--R                   +-+
+--R                 2\|a
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +--------+
+--R                  |   4            4       +-+                +--------+
+--R             - 2a\|c x  + a  + (c x  + 2a)\|a           +---+ |   4
+--R         log(---------------------------------)        \|- a \|c x  + a
+--R                              4                   atan(-----------------)
+--R                             x                                 a
+--R   (3)  [--------------------------------------,- -----------------------]
+--R                            +-+                             +---+
+--R                          4\|a                            2\|- a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 299
+
+--S 300 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R                 +--------+                              +--------+
+--R                 |   4            4       +-+            |   4
+--R            - 2a\|c x  + a  + (c x  + 2a)\|a            \|c x  + a
+--R        log(---------------------------------) + 2atanh(-----------)
+--R                             4                               +-+
+--R                            x                               \|a
+--R   (4)  ------------------------------------------------------------
+--R                                      +-+
+--R                                    4\|a
+--R                                                    Type: Expression(Integer)
+--E 300
+
+--S 301 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R                     +--------+                    +--------+
+--R                     |   4                   +---+ |   4
+--R         +---+      \|c x  + a      +-+     \|- a \|c x  + a
+--R        \|- a atanh(-----------) - \|a atan(-----------------)
+--R                         +-+                        a
+--R                        \|a
+--R   (6)  ------------------------------------------------------
+--R                                +---+ +-+
+--R                              2\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 1057
+t0:=1/(x^2*sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         2 |   4
+--R        x \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 1057
+--r0:=-sqrt(a+c*x^4)/(a*x)-(-c)^(1/4)*elliptic_e(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/(a^(1/4)*sqrt(a+c*x^4))+(-c)^(1/4)*elliptic_f(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/(a^(1/4)*sqrt(a+c*x^4))
+--E 305
+
+--S 306 of 1057
+--a0:=integrate(t0,x)
+--E 306
+
+--S 307 of 1057
+--m0:=a0-r0
+--E 307
+
+--S 308 of 1057
+--d0:=D(m0,x)
+--E 308
+
+)clear all
+
+--S 309 of 1057
+t0:=1/(x^3*sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         3 |   4
+--R        x \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 1057
+r0:=-1/2*sqrt(a+c*x^4)/(a*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   4
+--R          \|c x  + a
+--R   (2)  - -----------
+--R                 2
+--R             2a x
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +--------+
+--R          +-+ |   4           4
+--R         \|a \|c x  + a  - c x  - a
+--R   (3)  ----------------------------
+--R              +--------+
+--R            2 |   4            2 +-+
+--R        2a x \|c x  + a  - 2a x \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 311
+
+--S 312 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 313
+
+)clear all
+
+--S 314 of 1057
+t0:=1/(x^4*sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         4 |   4
+--R        x \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 1057
+--r0:=-1/3*sqrt(a+c*x^4)/(a*x^3)+1/3*(-c)^(3/4)*elliptic_f(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/(a^(3/4)*sqrt(a+c*x^4))
+--E 315
+
+--S 316 of 1057
+--a0:=integrate(t0,x)
+--E 316
+
+--S 317 of 1057
+--m0:=a0-r0
+--E 317
+
+--S 318 of 1057
+--d0:=D(m0,x)
+--E 318
+
+)clear all
+
+--S 319 of 1057
+t0:=x^4/sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 1057
+r0:=3/8*a^2*atanh(x*sqrt(b)/sqrt(a+b*x^2))/b^(5/2)-_
+   3/8*a*x*sqrt(a+b*x^2)/b^2+1/4*x^3*sqrt(a+b*x^2)/b
+--R 
+--R
+--R                      +-+                          +--------+
+--R          2         x\|b             3         +-+ |   2
+--R        3a atanh(-----------) + (2b x  - 3a x)\|b \|b x  + a
+--R                  +--------+
+--R                  |   2
+--R                 \|b x  + a
+--R   (2)  -----------------------------------------------------
+--R                                 2 +-+
+--R                               8b \|b
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                  +--------+
+--R                2   2      3  +-+ |   2          2 2 4      3   2      4
+--R           ((12a b x  + 24a )\|a \|b x  + a  - 3a b x  - 24a b x  - 24a )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|a \|b  - b x)\|b x  + a  + (- b x  - a)\|b  + b x\|a
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|a \|b x  + a  - a
+--R       + 
+--R                                                    +--------+
+--R              3 7        2 5     2   3      3   +-+ |   2
+--R         (- 2b x  - 13a b x  + 8a b x  + 24a x)\|b \|b x  + a
+--R       + 
+--R            3 7        2 5      2   3      3   +-+ +-+
+--R         (8b x  + 12a b x  - 20a b x  - 24a x)\|a \|b
+--R    /
+--R                                 +--------+
+--R           3 2        2  +-+ +-+ |   2             4 4        3 2      2 2  +-+
+--R       (32b x  + 64a b )\|a \|b \|b x  + a  + (- 8b x  - 64a b x  - 64a b )\|b
+--R     ,
+--R
+--R                                  +--------+
+--R                2   2      3  +-+ |   2          2 2 4      3   2      4
+--R           ((24a b x  + 48a )\|a \|b x  + a  - 6a b x  - 48a b x  - 48a )
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- b \|b x  + a  - \|- b \|a
+--R           atan(------------------------------)
+--R                              b x
+--R       + 
+--R                                                      +--------+
+--R              3 7        2 5     2   3      3   +---+ |   2
+--R         (- 2b x  - 13a b x  + 8a b x  + 24a x)\|- b \|b x  + a
+--R       + 
+--R            3 7        2 5      2   3      3   +---+ +-+
+--R         (8b x  + 12a b x  - 20a b x  - 24a x)\|- b \|a
+--R    /
+--R                                     +--------+
+--R             3 2        2  +---+ +-+ |   2
+--R         (32b x  + 64a b )\|- b \|a \|b x  + a
+--R       + 
+--R              4 4        3 2      2 2  +---+
+--R         (- 8b x  - 64a b x  - 64a b )\|- b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 321
+
+--S 322 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                               +--------+
+--R                +-+ +-+        |   2              2      +-+       +-+
+--R         2    (\|a \|b  - b x)\|b x  + a  + (- b x  - a)\|b  + b x\|a
+--R       3a log(--------------------------------------------------------)
+--R                                      +--------+
+--R                                  +-+ |   2
+--R                                 \|a \|b x  + a  - a
+--R     + 
+--R                       +-+
+--R           2         x\|b
+--R       - 3a atanh(-----------)
+--R                   +--------+
+--R                   |   2
+--R                  \|b x  + a
+--R  /
+--R       2 +-+
+--R     8b \|b
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                      +--------+
+--R                         +-+                    +---+ |   2         +---+ +-+
+--R       2 +---+         x\|b          2 +-+     \|- b \|b x  + a  - \|- b \|a
+--R   - 3a \|- b atanh(-----------) + 6a \|b atan(------------------------------)
+--R                     +--------+                              b x
+--R                     |   2
+--R                    \|b x  + a
+--R   ---------------------------------------------------------------------------
+--R                                    2 +---+ +-+
+--R                                  8b \|- b \|b
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 325
+
+)clear all
+
+--S 326 of 1057
+t0:=x^3/sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 1057
+r0:=-2/3*a*sqrt(a+b*x^2)/b^2+1/3*x^2*sqrt(a+b*x^2)/b
+--R 
+--R
+--R                    +--------+
+--R            2       |   2
+--R        (b x  - 2a)\|b x  + a
+--R   (2)  ----------------------
+--R                    2
+--R                  3b
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +--------+
+--R                 4 |   2            6       4  +-+
+--R           - 3a x \|b x  + a  + (b x  + 3a x )\|a
+--R   (3)  ---------------------------------------------
+--R                          +--------+
+--R             2        +-+ |   2              2      2
+--R        (3b x  + 12a)\|a \|b x  + a  - 9a b x  - 12a
+--R                                         Type: Union(Expression(Integer),...)
+--E 328
+
+--S 329 of 1057
+m0:=a0-r0
+--R 
+--R
+--R                          +--------+
+--R             2   2     3  |   2           2   2     3  +-+
+--R        (- 2a b x  - 8a )\|b x  + a  + (6a b x  + 8a )\|a
+--R   (4)  --------------------------------------------------
+--R                             +--------+
+--R           3 2        2  +-+ |   2            3 2      2 2
+--R        (3b x  + 12a b )\|a \|b x  + a  - 9a b x  - 12a b
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 1057
+t0:=x^2/sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 1057
+r0:=-1/2*a*atanh(x*sqrt(b)/sqrt(a+b*x^2))/b^(3/2)+1/2*x*sqrt(a+b*x^2)/b
+--R 
+--R
+--R                       +-+             +--------+
+--R                     x\|b          +-+ |   2
+--R        - a atanh(-----------) + x\|b \|b x  + a
+--R                   +--------+
+--R                   |   2
+--R                  \|b x  + a
+--R   (2)  -----------------------------------------
+--R                             +-+
+--R                          2b\|b
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   +--------+
+--R               +-+ |   2             2     2
+--R           (2a\|a \|b x  + a  - a b x  - 2a )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|a \|b  + b x)\|b x  + a  + (- b x  - a)\|b  - b x\|a
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|a \|b x  + a  - a
+--R       + 
+--R                             +--------+
+--R               3         +-+ |   2             3         +-+ +-+
+--R         (- b x  - 2a x)\|b \|b x  + a  + (2b x  + 2a x)\|a \|b
+--R    /
+--R                  +--------+
+--R          +-+ +-+ |   2             2 2         +-+
+--R       4b\|a \|b \|b x  + a  + (- 2b x  - 4a b)\|b
+--R     ,
+--R
+--R                     +--------+
+--R                 +-+ |   2              2     2
+--R           (- 4a\|a \|b x  + a  + 2a b x  + 4a )
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- b \|b x  + a  - \|- b \|a
+--R           atan(------------------------------)
+--R                              b x
+--R       + 
+--R                               +--------+
+--R               3         +---+ |   2             3         +---+ +-+
+--R         (- b x  - 2a x)\|- b \|b x  + a  + (2b x  + 2a x)\|- b \|a
+--R    /
+--R                    +--------+
+--R          +---+ +-+ |   2             2 2         +---+
+--R       4b\|- b \|a \|b x  + a  + (- 2b x  - 4a b)\|- b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 333
+
+--S 334 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|a \|b  + b x)\|b x  + a  + (- b x  - a)\|b  - b x\|a
+--R       a log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|a \|b x  + a  - a
+--R     + 
+--R                    +-+
+--R                  x\|b
+--R       a atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|b x  + a
+--R  /
+--R        +-+
+--R     2b\|b
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                      +--------+
+--R                          +-+                   +---+ |   2         +---+ +-+
+--R          +---+         x\|b           +-+     \|- b \|b x  + a  - \|- b \|a
+--R        a\|- b atanh(-----------) - 2a\|b atan(------------------------------)
+--R                      +--------+                             b x
+--R                      |   2
+--R                     \|b x  + a
+--R   (6)  ----------------------------------------------------------------------
+--R                                        +---+ +-+
+--R                                     2b\|- b \|b
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 337
+
+)clear all
+
+--S 338 of 1057
+t0:=x/sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 1057
+r0:=sqrt(a+b*x^2)/b
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R   (2)  -----------
+--R             b
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2 +-+
+--R               x \|a
+--R   (3)  -------------------
+--R             +--------+
+--R         +-+ |   2
+--R        \|a \|b x  + a  - a
+--R                                         Type: Union(Expression(Integer),...)
+--E 340
+
+--S 341 of 1057
+m0:=a0-r0
+--R 
+--R
+--R           +--------+
+--R           |   2          +-+
+--R         a\|b x  + a  - a\|a
+--R   (4)  ----------------------
+--R              +--------+
+--R          +-+ |   2
+--R        b\|a \|b x  + a  - a b
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 1057
+t0:=1/sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 1057
+r0:=atanh(x*sqrt(b)/sqrt(a+b*x^2))/sqrt(b)
+--R 
+--R
+--R                   +-+
+--R                 x\|b
+--R        atanh(-----------)
+--R               +--------+
+--R               |   2
+--R              \|b x  + a
+--R   (2)  ------------------
+--R                +-+
+--R               \|b
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         +--------+
+--R          +-+ +-+        |   2              2      +-+       +-+
+--R        (\|a \|b  - b x)\|b x  + a  + (- b x  - a)\|b  + b x\|a
+--R    log(--------------------------------------------------------)
+--R                                +--------+
+--R                            +-+ |   2
+--R                           \|a \|b x  + a  - a
+--R   [-------------------------------------------------------------,
+--R                                  +-+
+--R                                 \|b
+--R                 +--------+
+--R           +---+ |   2         +---+ +-+
+--R          \|- b \|b x  + a  - \|- b \|a
+--R    2atan(------------------------------)
+--R                        b x
+--R    -------------------------------------]
+--R                     +---+
+--R                    \|- b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 345
+
+--S 346 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            +--------+
+--R             +-+ +-+        |   2              2      +-+       +-+
+--R           (\|a \|b  - b x)\|b x  + a  + (- b x  - a)\|b  + b x\|a
+--R       log(--------------------------------------------------------)
+--R                                   +--------+
+--R                               +-+ |   2
+--R                              \|a \|b x  + a  - a
+--R     + 
+--R                    +-+
+--R                  x\|b
+--R       - atanh(-----------)
+--R                +--------+
+--R                |   2
+--R               \|b x  + a
+--R  /
+--R      +-+
+--R     \|b
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                      +--------+
+--R                           +-+                  +---+ |   2         +---+ +-+
+--R           +---+         x\|b          +-+     \|- b \|b x  + a  - \|- b \|a
+--R        - \|- b atanh(-----------) + 2\|b atan(------------------------------)
+--R                       +--------+                            b x
+--R                       |   2
+--R                      \|b x  + a
+--R   (6)  ----------------------------------------------------------------------
+--R                                       +---+ +-+
+--R                                      \|- b \|b
+--R                                                    Type: Expression(Integer)
+--E 348
+
+--S 349 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 349
+
+)clear all
+
+--S 350 of 1057
+t0:=1/(x*sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R          +--------+
+--R          |   2
+--R        x\|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 1057
+r0:=-atanh(sqrt(a+b*x^2)/sqrt(a))/sqrt(a)
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R                \|b x  + a
+--R          atanh(-----------)
+--R                     +-+
+--R                    \|a
+--R   (2)  - ------------------
+--R                  +-+
+--R                 \|a
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------+
+--R                 |   2         +-+
+--R         +-+    \|b x  + a  - \|a
+--R        \|a log(------------------)
+--R                         x
+--R   (3)  ---------------------------
+--R                     a
+--R                                         Type: Union(Expression(Integer),...)
+--E 352
+
+--S 353 of 1057
+m0:=a0-r0
+--R 
+--R
+--R             +--------+                  +--------+
+--R             |   2         +-+           |   2
+--R            \|b x  + a  - \|a           \|b x  + a
+--R        log(------------------) + atanh(-----------)
+--R                     x                       +-+
+--R                                            \|a
+--R   (4)  --------------------------------------------
+--R                             +-+
+--R                            \|a
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 1057
+t0:=1/(x^2*sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         2 |   2
+--R        x \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 1057
+r0:=-sqrt(a+b*x^2)/(a*x)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R          \|b x  + a
+--R   (2)  - -----------
+--R              a x
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +--------+
+--R         +-+ |   2           2
+--R        \|a \|b x  + a  - b x  - a
+--R   (3)  --------------------------
+--R             +--------+
+--R             |   2            +-+
+--R         a x\|b x  + a  - a x\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 357
+
+--S 358 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 359
+
+)clear all
+
+--S 360 of 1057
+t0:=1/(x^3*sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         3 |   2
+--R        x \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 360
+
+--S 361 of 1057
+r0:=1/2*b*atanh(sqrt(a+b*x^2)/sqrt(a))/a^(3/2)-1/2*sqrt(a+b*x^2)/(a*x^2)
+--R 
+--R
+--R                   +--------+
+--R                   |   2              +--------+
+--R           2      \|b x  + a      +-+ |   2
+--R        b x atanh(-----------) - \|a \|b x  + a
+--R                       +-+
+--R                      \|a
+--R   (2)  ----------------------------------------
+--R                            2 +-+
+--R                        2a x \|a
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                         +--------+
+--R                  +--------+                             |   2         +-+
+--R                2 |   2          2 4         2  +-+     \|b x  + a  - \|a
+--R       (- 2a b x \|b x  + a  + (b x  + 2a b x )\|a )log(------------------)
+--R                                                                 x
+--R     + 
+--R                      +--------+
+--R             2     2  |   2                 2     2  +-+
+--R       (a b x  + 2a )\|b x  + a  + (- 2a b x  - 2a )\|a
+--R  /
+--R               +--------+
+--R       2 2 +-+ |   2          2   4     3 2
+--R     4a x \|a \|b x  + a  - 2a b x  - 4a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 362
+
+--S 363 of 1057
+m0:=a0-r0
+--R 
+--R
+--R                 +--------+                    +--------+
+--R                 |   2         +-+             |   2
+--R                \|b x  + a  - \|a             \|b x  + a
+--R        - b log(------------------) - b atanh(-----------)
+--R                         x                         +-+
+--R                                                  \|a
+--R   (4)  --------------------------------------------------
+--R                                 +-+
+--R                              2a\|a
+--R                                                    Type: Expression(Integer)
+--E 363
+
+--S 364 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 364
+
+)clear all
+
+--S 365 of 1057
+t0:=1/(x^4*sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         4 |   2
+--R        x \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 1057
+r0:=-1/3*sqrt(a+b*x^2)/(a*x^3)+2/3*b*sqrt(a+b*x^2)/(a^2*x)
+--R 
+--R
+--R                    +--------+
+--R             2      |   2
+--R        (2b x  - a)\|b x  + a
+--R   (2)  ----------------------
+--R                   2 3
+--R                 3a x
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 +--------+
+--R        2 4         2     2  +-+ |   2          3 6       2 4     2   2     3
+--R   (- 6b x  - 5a b x  + 4a )\|a \|b x  + a  + 2b x  + 9a b x  + 3a b x  - 4a
+--R   --------------------------------------------------------------------------
+--R                               +--------+
+--R               2   5      3 3  |   2             2   5      3 3  +-+
+--R            (3a b x  + 12a x )\|b x  + a  + (- 9a b x  - 12a x )\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 367
+
+--S 368 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 1057
+t0:=x^4/sqrt(2+2*a-2*(1+a)+c*x^4)
+--R 
+--R
+--R            4
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 1057
+r0:=1/3*x^5/sqrt(c*x^4)
+--R 
+--R
+--R            5
+--R           x
+--R   (2)  --------
+--R          +----+
+--R          |   4
+--R        3\|c x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3
+--R          x
+--R   (3)  -----
+--R          +-+
+--R        3\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 372
+
+--S 373 of 1057
+m0:=a0-r0
+--R 
+--R
+--R           +----+
+--R         3 |   4     5 +-+
+--R        x \|c x   - x \|c
+--R   (4)  ------------------
+--R                 +----+
+--R             +-+ |   4
+--R           3\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R               +----+
+--R         2 +-+ |   4       4
+--R        x \|c \|c x   - c x
+--R   (5)  --------------------
+--R                +----+
+--R                |   4
+--R              c\|c x
+--R                                                    Type: Expression(Integer)
+--E 374
+
+)clear all
+
+--S 375 of 1057
+t0:=x^3/sqrt(2+2*a-2*(1+a)+c*x^4)
+--R 
+--R
+--R            3
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 375
+
+--S 376 of 1057
+r0:=1/2*x^4/sqrt(c*x^4)
+--R 
+--R
+--R            4
+--R           x
+--R   (2)  --------
+--R          +----+
+--R          |   4
+--R        2\|c x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R          x
+--R   (3)  -----
+--R          +-+
+--R        2\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 377
+
+--S 378 of 1057
+m0:=a0-r0
+--R 
+--R
+--R           +----+
+--R         2 |   4     4 +-+
+--R        x \|c x   - x \|c
+--R   (4)  ------------------
+--R                 +----+
+--R             +-+ |   4
+--R           2\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 378
+
+--S 379 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R              +----+
+--R          +-+ |   4       3
+--R        x\|c \|c x   - c x
+--R   (5)  -------------------
+--R                +----+
+--R                |   4
+--R              c\|c x
+--R                                                    Type: Expression(Integer)
+--E 379
+
+)clear all
+
+--S 380 of 1057
+t0:=x^2/sqrt(2+2*a-2*(1+a)+c*x^4)
+--R 
+--R
+--R            2
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 1057
+r0:=x^3/sqrt(c*x^4)
+--R 
+--R
+--R            3
+--R           x
+--R   (2)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R          x
+--R   (3)  ----
+--R         +-+
+--R        \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 382
+
+--S 383 of 1057
+m0:=a0-r0
+--R 
+--R
+--R          +----+
+--R          |   4     3 +-+
+--R        x\|c x   - x \|c
+--R   (4)  -----------------
+--R                +----+
+--R            +-+ |   4
+--R           \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R             +----+
+--R         +-+ |   4       2
+--R        \|c \|c x   - c x
+--R   (5)  ------------------
+--R               +----+
+--R               |   4
+--R             c\|c x
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 1057
+t0:=x/sqrt(2+2*a-2*(1+a)+c*x^4)
+--R 
+--R
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 1057
+r0:=x^2*log(x)/sqrt(c*x^4)
+--R 
+--R
+--R         2
+--R        x log(x)
+--R   (2)  --------
+--R          +----+
+--R          |   4
+--R         \|c x
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(x)
+--R   (3)  ------
+--R          +-+
+--R         \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 387
+
+--S 388 of 1057
+m0:=a0-r0
+--R 
+--R
+--R               +----+
+--R               |   4     2       +-+
+--R        log(x)\|c x   - x log(x)\|c
+--R   (4)  ----------------------------
+--R                      +----+
+--R                  +-+ |   4
+--R                 \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R             +----+
+--R         +-+ |   4       2
+--R        \|c \|c x   - c x
+--R   (5)  ------------------
+--R                +----+
+--R                |   4
+--R            c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 389
+
+)clear all
+
+--S 390 of 1057
+t0:=1/sqrt(2+2*a-2*(1+a)+c*x^4)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 390
+
+--S 391 of 1057
+r0:=-x/sqrt(c*x^4)
+--R 
+--R
+--R             x
+--R   (2)  - -------
+--R           +----+
+--R           |   4
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R            1
+--R   (3)  - -----
+--R            +-+
+--R          x\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 392
+
+--S 393 of 1057
+m0:=a0-r0
+--R 
+--R
+--R           +----+
+--R           |   4     2 +-+
+--R        - \|c x   + x \|c
+--R   (4)  ------------------
+--R                 +----+
+--R             +-+ |   4
+--R           x\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 393
+
+--S 394 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R             +----+
+--R         +-+ |   4       2
+--R        \|c \|c x   - c x
+--R   (5)  ------------------
+--R                 +----+
+--R               2 |   4
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 394
+
+)clear all
+
+--S 395 of 1057
+t0:=1/(x*sqrt(2+2*a-2*(1+a)+c*x^4))
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R          +----+
+--R          |   4
+--R        x\|c x
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 1057
+r0:=(-1/2)/sqrt(c*x^4)
+--R 
+--R
+--R              1
+--R   (2)  - --------
+--R            +----+
+--R            |   4
+--R          2\|c x
+--R                                                    Type: Expression(Integer)
+--E 396
+
+--S 397 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            2 +-+
+--R          2x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 397
+
+--S 398 of 1057
+m0:=a0-r0
+--R 
+--R
+--R           +----+
+--R           |   4     2 +-+
+--R        - \|c x   + x \|c
+--R   (4)  ------------------
+--R                  +----+
+--R            2 +-+ |   4
+--R          2x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R             +----+
+--R         +-+ |   4       2
+--R        \|c \|c x   - c x
+--R   (5)  ------------------
+--R                 +----+
+--R               3 |   4
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 1057
+t0:=1/(x^2*sqrt(2+2*a-2*(1+a)+c*x^4))
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R           +----+
+--R         2 |   4
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 1057
+r0:=(-1/3)/(x*sqrt(c*x^4))
+--R 
+--R
+--R              1
+--R   (2)  - ---------
+--R             +----+
+--R             |   4
+--R          3x\|c x
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            3 +-+
+--R          3x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 402
+
+--S 403 of 1057
+m0:=a0-r0
+--R 
+--R
+--R           +----+
+--R           |   4     2 +-+
+--R        - \|c x   + x \|c
+--R   (4)  ------------------
+--R                  +----+
+--R            3 +-+ |   4
+--R          3x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R             +----+
+--R         +-+ |   4       2
+--R        \|c \|c x   - c x
+--R   (5)  ------------------
+--R                 +----+
+--R               4 |   4
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 404
+
+)clear all
+
+--S 405 of 1057
+t0:=1/(x^3*sqrt(2+2*a-2*(1+a)+c*x^4))
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R           +----+
+--R         3 |   4
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 405
+
+--S 406 of 1057
+r0:=(-1/4)/(x^2*sqrt(c*x^4))
+--R 
+--R
+--R               1
+--R   (2)  - ----------
+--R              +----+
+--R            2 |   4
+--R          4x \|c x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            4 +-+
+--R          4x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 407
+
+--S 408 of 1057
+m0:=a0-r0
+--R 
+--R
+--R           +----+
+--R           |   4     2 +-+
+--R        - \|c x   + x \|c
+--R   (4)  ------------------
+--R                  +----+
+--R            4 +-+ |   4
+--R          4x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 408
+
+--S 409 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R             +----+
+--R         +-+ |   4       2
+--R        \|c \|c x   - c x
+--R   (5)  ------------------
+--R                 +----+
+--R               5 |   4
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 409
+
+)clear all
+
+--S 410 of 1057
+t0:=1/(x^4*sqrt(2+2*a-2*(1+a)+c*x^4))
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R           +----+
+--R         4 |   4
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 1057
+r0:=(-1/5)/(x^3*sqrt(c*x^4))
+--R 
+--R
+--R               1
+--R   (2)  - ----------
+--R              +----+
+--R            3 |   4
+--R          5x \|c x
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            5 +-+
+--R          5x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 412
+
+--S 413 of 1057
+m0:=a0-r0
+--R 
+--R
+--R           +----+
+--R           |   4     2 +-+
+--R        - \|c x   + x \|c
+--R   (4)  ------------------
+--R                  +----+
+--R            5 +-+ |   4
+--R          5x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R             +----+
+--R         +-+ |   4       2
+--R        \|c \|c x   - c x
+--R   (5)  ------------------
+--R                 +----+
+--R               6 |   4
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 1057
+t0:=x^4/sqrt(a+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R          4
+--R         x
+--R   (1)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 1057
+r0:=1/5*x^5/sqrt(a)
+--R 
+--R
+--R           5
+--R          x
+--R   (2)  -----
+--R          +-+
+--R        5\|a
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5
+--R          x
+--R   (3)  -----
+--R          +-+
+--R        5\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 417
+
+--S 418 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 419
+
+)clear all
+
+--S 420 of 1057
+t0:=x^3/sqrt(a+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R          3
+--R         x
+--R   (1)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 420
+
+--S 421 of 1057
+r0:=1/4*x^4/sqrt(a)
+--R 
+--R
+--R           4
+--R          x
+--R   (2)  -----
+--R          +-+
+--R        4\|a
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4
+--R          x
+--R   (3)  -----
+--R          +-+
+--R        4\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 422
+
+--S 423 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+--S 424 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 424
+
+)clear all
+
+--S 425 of 1057
+t0:=x^2/sqrt(a+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R          2
+--R         x
+--R   (1)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 1057
+r0:=1/3*x^3/sqrt(a)
+--R 
+--R
+--R           3
+--R          x
+--R   (2)  -----
+--R          +-+
+--R        3\|a
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3
+--R          x
+--R   (3)  -----
+--R          +-+
+--R        3\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 427
+
+--S 428 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 1057
+t0:=x/sqrt(a+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R          x
+--R   (1)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 1057
+r0:=1/2*x^2/sqrt(a)
+--R 
+--R
+--R           2
+--R          x
+--R   (2)  -----
+--R          +-+
+--R        2\|a
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R          x
+--R   (3)  -----
+--R          +-+
+--R        2\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 432
+
+--S 433 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 434
+
+)clear all
+
+--S 435 of 1057
+t0:=1/sqrt(a+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R          1
+--R   (1)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 435
+
+--S 436 of 1057
+r0:=x/sqrt(a)
+--R 
+--R
+--R          x
+--R   (2)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R          x
+--R   (3)  ----
+--R         +-+
+--R        \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 437
+
+--S 438 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+--S 439 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 439
+
+)clear all
+
+--S 440 of 1057
+t0:=1/(x*sqrt(a+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R          1
+--R   (1)  -----
+--R          +-+
+--R        x\|a
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 1057
+r0:=log(x)/sqrt(a)
+--R 
+--R
+--R        log(x)
+--R   (2)  ------
+--R          +-+
+--R         \|a
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(x)
+--R   (3)  ------
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 442
+
+--S 443 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 444
+
+)clear all
+
+--S 445 of 1057
+t0:=1/(x^2*sqrt(a+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         2 +-+
+--R        x \|a
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 1057
+r0:=(-1)/(x*sqrt(a))
+--R 
+--R
+--R            1
+--R   (2)  - -----
+--R            +-+
+--R          x\|a
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R            1
+--R   (3)  - -----
+--R            +-+
+--R          x\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 447
+
+--S 448 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 449
+
+)clear all
+
+--S 450 of 1057
+t0:=1/(x^3*sqrt(a+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         3 +-+
+--R        x \|a
+--R                                                    Type: Expression(Integer)
+--E 450
+
+--S 451 of 1057
+r0:=(-1/2)/(x^2*sqrt(a))
+--R 
+--R
+--R             1
+--R   (2)  - -------
+--R            2 +-+
+--R          2x \|a
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            2 +-+
+--R          2x \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 452
+
+--S 453 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+--S 454 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 454
+
+)clear all
+
+--S 455 of 1057
+t0:=1/(x^4*sqrt(a+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         4 +-+
+--R        x \|a
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 1057
+r0:=(-1/3)/(x^3*sqrt(a))
+--R 
+--R
+--R             1
+--R   (2)  - -------
+--R            3 +-+
+--R          3x \|a
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            3 +-+
+--R          3x \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 457
+
+--S 458 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 1057
+t0:=1/sqrt(3-2*x^2-x^4)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   4     2
+--R        \|- x  - 2x  + 3
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 1057
+--r0:=elliptic_f(asin(x),-1/3)/sqrt(3)
+--E 461
+
+--S 462 of 1057
+--a0:=integrate(t0,x)
+--E 462
+
+--S 463 of 1057
+--m0:=a0-r0
+--E 463
+
+--S 464 of 1057
+--d0:=D(m0,x)
+--E 464
+
+)clear all
+
+--S 465 of 1057
+t0:=x^(7/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R            7      5      3  +-+
+--R   (1)  (c x  + b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 1057
+r0:=2/9*a*x^(9/2)+2/13*b*x^(13/2)+2/17*c*x^(17/2)
+--R 
+--R
+--R               8         6         4  +-+
+--R        (234c x  + 306b x  + 442a x )\|x
+--R   (2)  ---------------------------------
+--R                       1989
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R               8         6         4  +-+
+--R        (234c x  + 306b x  + 442a x )\|x
+--R   (3)  ---------------------------------
+--R                       1989
+--R                                         Type: Union(Expression(Integer),...)
+--E 467
+
+--S 468 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+--S 469 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 469
+
+)clear all
+
+--S 470 of 1057
+t0:=x^(5/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R            6      4      2  +-+
+--R   (1)  (c x  + b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 1057
+r0:=2/7*a*x^(7/2)+2/11*b*x^(11/2)+2/15*c*x^(15/2)
+--R 
+--R
+--R               7         5         3  +-+
+--R        (154c x  + 210b x  + 330a x )\|x
+--R   (2)  ---------------------------------
+--R                       1155
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R               7         5         3  +-+
+--R        (154c x  + 210b x  + 330a x )\|x
+--R   (3)  ---------------------------------
+--R                       1155
+--R                                         Type: Union(Expression(Integer),...)
+--E 472
+
+--S 473 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 1057
+t0:=x^(3/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R            5      3        +-+
+--R   (1)  (c x  + b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 1057
+r0:=2/5*a*x^(5/2)+2/9*b*x^(9/2)+2/13*c*x^(13/2)
+--R 
+--R
+--R              6         4         2  +-+
+--R        (90c x  + 130b x  + 234a x )\|x
+--R   (2)  --------------------------------
+--R                       585
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R              6         4         2  +-+
+--R        (90c x  + 130b x  + 234a x )\|x
+--R   (3)  --------------------------------
+--R                       585
+--R                                         Type: Union(Expression(Integer),...)
+--E 477
+
+--S 478 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 479
+
+)clear all
+
+--S 480 of 1057
+t0:=x^(1/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R            4      2      +-+
+--R   (1)  (c x  + b x  + a)\|x
+--R                                                    Type: Expression(Integer)
+--E 480
+
+--S 481 of 1057
+r0:=2/3*a*x^(3/2)+2/7*b*x^(7/2)+2/11*c*x^(11/2)
+--R 
+--R
+--R              5        3           +-+
+--R        (42c x  + 66b x  + 154a x)\|x
+--R   (2)  ------------------------------
+--R                      231
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R              5        3           +-+
+--R        (42c x  + 66b x  + 154a x)\|x
+--R   (3)  ------------------------------
+--R                      231
+--R                                         Type: Union(Expression(Integer),...)
+--E 482
+
+--S 483 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 484
+
+)clear all
+
+--S 485 of 1057
+t0:=(a+b*x^2+c*x^4)/x^(1/2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R               +-+
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 1057
+r0:=2/5*b*x^(5/2)+2/9*c*x^(9/2)+2*a*sqrt(x)
+--R 
+--R
+--R              4        2        +-+
+--R        (10c x  + 18b x  + 90a)\|x
+--R   (2)  ---------------------------
+--R                     45
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4        2        +-+
+--R        (10c x  + 18b x  + 90a)\|x
+--R   (3)  ---------------------------
+--R                     45
+--R                                         Type: Union(Expression(Integer),...)
+--E 487
+
+--S 488 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 1057
+t0:=(a+b*x^2+c*x^4)/x^(3/2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R               +-+
+--R             x\|x
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 1057
+r0:=2/3*b*x^(3/2)+2/7*c*x^(7/2)-2*a/sqrt(x)
+--R 
+--R
+--R            4        2
+--R        6c x  + 14b x  - 42a
+--R   (2)  --------------------
+--R                  +-+
+--R               21\|x
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4        2
+--R        6c x  + 14b x  - 42a
+--R   (3)  --------------------
+--R                  +-+
+--R               21\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 492
+
+--S 493 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 494
+
+)clear all
+
+--S 495 of 1057
+t0:=(a+b*x^2+c*x^4)/x^(5/2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R              2 +-+
+--R             x \|x
+--R                                                    Type: Expression(Integer)
+--E 495
+
+--S 496 of 1057
+r0:=-2/3*a/x^(3/2)+2/5*c*x^(5/2)+2*b*sqrt(x)
+--R 
+--R
+--R            4        2
+--R        6c x  + 30b x  - 10a
+--R   (2)  --------------------
+--R                   +-+
+--R               15x\|x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4        2
+--R        6c x  + 30b x  - 10a
+--R   (3)  --------------------
+--R                   +-+
+--R               15x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 497
+
+--S 498 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 499
+
+)clear all
+
+--S 500 of 1057
+t0:=(a+b*x^2+c*x^4)/x^(7/2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R              3 +-+
+--R             x \|x
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 1057
+r0:=-2/5*a/x^(5/2)+2/3*c*x^(3/2)-2*b/sqrt(x)
+--R 
+--R
+--R             4        2
+--R        10c x  - 30b x  - 6a
+--R   (2)  --------------------
+--R                 2 +-+
+--R              15x \|x
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4        2
+--R        10c x  - 30b x  - 6a
+--R   (3)  --------------------
+--R                 2 +-+
+--R              15x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 502
+
+--S 503 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 1057
+t0:=x^(7/2)*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 11         9            2  7         5    2 3  +-+
+--R   (1)  (c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 1057
+r0:=2/9*a^2*x^(9/2)+4/13*a*b*x^(13/2)+2/17*(b^2+2*a*c)*x^(17/2)+_
+   4/21*b*c*x^(21/2)+2/25*c^2*x^(25/2)
+--R 
+--R
+--R   (2)
+--R               2 12             10                     2  8              6
+--R         27846c x   + 66300b c x   + (81900a c + 40950b )x  + 107100a b x
+--R       + 
+--R               2 4
+--R         77350a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     348075
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 12             10                     2  8              6
+--R         27846c x   + 66300b c x   + (81900a c + 40950b )x  + 107100a b x
+--R       + 
+--R               2 4
+--R         77350a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     348075
+--R                                         Type: Union(Expression(Integer),...)
+--E 507
+
+--S 508 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 509
+
+)clear all
+
+--S 510 of 1057
+t0:=x^(5/2)*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 10         8            2  6         4    2 2  +-+
+--R   (1)  (c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 510
+
+--S 511 of 1057
+r0:=2/7*a^2*x^(7/2)+4/11*a*b*x^(11/2)+2/15*(b^2+2*a*c)*x^(15/2)+_
+   4/19*b*c*x^(19/2)+2/23*c^2*x^(23/2)
+--R 
+--R
+--R   (2)
+--R               2 11              9                      2  7              5
+--R         43890c x   + 106260b c x  + (134596a c + 67298b )x  + 183540a b x
+--R       + 
+--R                2 3
+--R         144210a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     504735
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 11              9                      2  7              5
+--R         43890c x   + 106260b c x  + (134596a c + 67298b )x  + 183540a b x
+--R       + 
+--R                2 3
+--R         144210a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     504735
+--R                                         Type: Union(Expression(Integer),...)
+--E 512
+
+--S 513 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 513
+
+--S 514 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 514
+
+)clear all
+
+--S 515 of 1057
+t0:=x^(3/2)*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 9         7            2  5         3    2   +-+
+--R   (1)  (c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 1057
+r0:=2/5*a^2*x^(5/2)+4/9*a*b*x^(9/2)+2/13*(b^2+2*a*c)*x^(13/2)+_
+   4/17*b*c*x^(17/2)+2/21*c^2*x^(21/2)
+--R 
+--R
+--R   (2)
+--R              2 10             8                     2  6             4
+--R         6630c x   + 16380b c x  + (21420a c + 10710b )x  + 30940a b x
+--R       + 
+--R               2 2
+--R         27846a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     69615
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 10             8                     2  6             4
+--R         6630c x   + 16380b c x  + (21420a c + 10710b )x  + 30940a b x
+--R       + 
+--R               2 2
+--R         27846a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     69615
+--R                                         Type: Union(Expression(Integer),...)
+--E 517
+
+--S 518 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 519
+
+)clear all
+
+--S 520 of 1057
+t0:=x^(1/2)*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 8         6            2  4         2    2  +-+
+--R   (1)  (c x  + 2b c x  + (2a c + b )x  + 2a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 1057
+r0:=2/3*a^2*x^(3/2)+4/7*a*b*x^(7/2)+2/11*(b^2+2*a*c)*x^(11/2)+_
+   4/15*b*c*x^(15/2)+2/19*c^2*x^(19/2)
+--R 
+--R
+--R   (2)
+--R         2 9            7                   2  5             3         2   +-+
+--R   (2310c x  + 5852b c x  + (7980a c + 3990b )x  + 12540a b x  + 14630a x)\|x
+--R   ---------------------------------------------------------------------------
+--R                                      21945
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2 9            7                   2  5             3         2   +-+
+--R   (2310c x  + 5852b c x  + (7980a c + 3990b )x  + 12540a b x  + 14630a x)\|x
+--R   ---------------------------------------------------------------------------
+--R                                      21945
+--R                                         Type: Union(Expression(Integer),...)
+--E 522
+
+--S 523 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 524
+
+)clear all
+
+--S 525 of 1057
+t0:=(a+b*x^2+c*x^4)^2/x^(1/2)
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                              +-+
+--R                             \|x
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 1057
+r0:=4/5*a*b*x^(5/2)+2/9*(b^2+2*a*c)*x^(9/2)+4/13*b*c*x^(13/2)+_
+   2/17*c^2*x^(17/2)+2*a^2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R         2 8            6                   2  4            2         2  +-+
+--R   (1170c x  + 3060b c x  + (4420a c + 2210b )x  + 7956a b x  + 19890a )\|x
+--R   -------------------------------------------------------------------------
+--R                                      9945
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2 8            6                   2  4            2         2  +-+
+--R   (1170c x  + 3060b c x  + (4420a c + 2210b )x  + 7956a b x  + 19890a )\|x
+--R   -------------------------------------------------------------------------
+--R                                      9945
+--R                                         Type: Union(Expression(Integer),...)
+--E 527
+
+--S 528 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+--S 529 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 529
+
+)clear all
+
+--S 530 of 1057
+t0:=(a+b*x^2+c*x^4)^2/x^(3/2)
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                              +-+
+--R                            x\|x
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 1057
+r0:=4/3*a*b*x^(3/2)+2/7*(b^2+2*a*c)*x^(7/2)+4/11*b*c*x^(11/2)+_
+   2/15*c^2*x^(15/2)-2*a^2/sqrt(x)
+--R 
+--R
+--R            2 8           6                 2  4            2        2
+--R        154c x  + 420b c x  + (660a c + 330b )x  + 1540a b x  - 2310a
+--R   (2)  --------------------------------------------------------------
+--R                                        +-+
+--R                                   1155\|x
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 8           6                 2  4            2        2
+--R        154c x  + 420b c x  + (660a c + 330b )x  + 1540a b x  - 2310a
+--R   (3)  --------------------------------------------------------------
+--R                                        +-+
+--R                                   1155\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 532
+
+--S 533 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 534
+
+)clear all
+
+--S 535 of 1057
+t0:=(a+b*x^2+c*x^4)^2/x^(5/2)
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                             2 +-+
+--R                            x \|x
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 1057
+r0:=-2/3*a^2/x^(3/2)+2/5*(b^2+2*a*c)*x^(5/2)+4/9*b*c*x^(9/2)+_
+   2/13*c^2*x^(13/2)+4*a*b*sqrt(x)
+--R 
+--R
+--R           2 8           6                 2  4            2       2
+--R        90c x  + 260b c x  + (468a c + 234b )x  + 2340a b x  - 390a
+--R   (2)  ------------------------------------------------------------
+--R                                       +-+
+--R                                  585x\|x
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 8           6                 2  4            2       2
+--R        90c x  + 260b c x  + (468a c + 234b )x  + 2340a b x  - 390a
+--R   (3)  ------------------------------------------------------------
+--R                                       +-+
+--R                                  585x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 537
+
+--S 538 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 539
+
+)clear all
+
+--S 540 of 1057
+t0:=(a+b*x^2+c*x^4)^2/x^(7/2)
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                             3 +-+
+--R                            x \|x
+--R                                                    Type: Expression(Integer)
+--E 540
+
+--S 541 of 1057
+r0:=-2/5*a^2/x^(5/2)+2/3*(b^2+2*a*c)*x^(3/2)+4/7*b*c*x^(7/2)+_
+   2/11*c^2*x^(11/2)-4*a*b/sqrt(x)
+--R 
+--R
+--R            2 8           6                  2  4            2       2
+--R        210c x  + 660b c x  + (1540a c + 770b )x  - 4620a b x  - 462a
+--R   (2)  --------------------------------------------------------------
+--R                                       2 +-+
+--R                                  1155x \|x
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 8           6                  2  4            2       2
+--R        210c x  + 660b c x  + (1540a c + 770b )x  - 4620a b x  - 462a
+--R   (3)  --------------------------------------------------------------
+--R                                       2 +-+
+--R                                  1155x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 542
+
+--S 543 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 544
+
+)clear all
+
+--S 545 of 1057
+t0:=x^(7/2)*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3 15       2 13        2     2   11              3  9      2        2  7
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   5    3 3
+--R       3a b x  + a x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 1057
+r0:=2/9*a^3*x^(9/2)+6/13*a^2*b*x^(13/2)+6/17*a*(b^2+a*c)*x^(17/2)+_
+   2/21*b*(b^2+6*a*c)*x^(21/2)+6/25*c*(b^2+a*c)*x^(25/2)+_
+   6/29*b*c^2*x^(29/2)+2/33*c^3*x^(33/2)
+--R 
+--R
+--R   (2)
+--R                 3 16              2 14               2            2   12
+--R         6729450c x   + 22972950b c x   + (26648622a c  + 26648622b c)x
+--R       + 
+--R                                   3  10             2               2  8
+--R         (63449100a b c + 10574850b )x   + (39189150a c + 39189150a b )x
+--R       + 
+--R                  2   6            3 4
+--R         51247350a b x  + 24674650a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     111035925
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3 16              2 14               2            2   12
+--R         6729450c x   + 22972950b c x   + (26648622a c  + 26648622b c)x
+--R       + 
+--R                                   3  10             2               2  8
+--R         (63449100a b c + 10574850b )x   + (39189150a c + 39189150a b )x
+--R       + 
+--R                  2   6            3 4
+--R         51247350a b x  + 24674650a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     111035925
+--R                                         Type: Union(Expression(Integer),...)
+--E 547
+
+--S 548 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 549
+
+)clear all
+
+--S 550 of 1057
+t0:=x^(5/2)*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3 14       2 12        2     2   10              3  8      2        2  6
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   4    3 2
+--R       3a b x  + a x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 1057
+r0:=2/7*a^3*x^(7/2)+6/11*a^2*b*x^(11/2)+2/5*a*(b^2+a*c)*x^(15/2)+_
+   2/19*b*(b^2+6*a*c)*x^(19/2)+6/23*c*(b^2+a*c)*x^(23/2)+_
+   2/9*b*c^2*x^(27/2)+2/31*c^3*x^(31/2)
+--R 
+--R
+--R   (2)
+--R                 3 15              2 13               2            2   11
+--R         3028410c x   + 10431190b c x   + (12245310a c  + 12245310b c)x
+--R       + 
+--R                                  3  9             2               2  7
+--R         (29646540a b c + 4941090b )x  + (18776142a c + 18776142a b )x
+--R       + 
+--R                  2   5            3 3
+--R         25603830a b x  + 13411530a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     46940355
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3 15              2 13               2            2   11
+--R         3028410c x   + 10431190b c x   + (12245310a c  + 12245310b c)x
+--R       + 
+--R                                  3  9             2               2  7
+--R         (29646540a b c + 4941090b )x  + (18776142a c + 18776142a b )x
+--R       + 
+--R                  2   5            3 3
+--R         25603830a b x  + 13411530a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     46940355
+--R                                         Type: Union(Expression(Integer),...)
+--E 552
+
+--S 553 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 554
+
+)clear all
+
+--S 555 of 1057
+t0:=x^(3/2)*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3 13       2 11        2     2   9              3  7      2        2  5
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   3    3
+--R       3a b x  + a x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 555
+
+--S 556 of 1057
+r0:=2/5*a^3*x^(5/2)+2/3*a^2*b*x^(9/2)+6/13*a*(b^2+a*c)*x^(13/2)+_
+   2/17*b*(b^2+6*a*c)*x^(17/2)+2/7*c*(b^2+a*c)*x^(21/2)+_
+   6/25*b*c^2*x^(25/2)+2/29*c^3*x^(29/2)
+--R 
+--R
+--R   (2)
+--R                3 14            2 12             2          2   10
+--R         232050c x   + 807534b c x   + (961350a c  + 961350b c)x
+--R       + 
+--R                                3  8            2              2  6
+--R         (2375100a b c + 395850b )x  + (1552950a c + 1552950a b )x
+--R       + 
+--R                 2   4           3 2
+--R         2243150a b x  + 1345890a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     3364725
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 14            2 12             2          2   10
+--R         232050c x   + 807534b c x   + (961350a c  + 961350b c)x
+--R       + 
+--R                                3  8            2              2  6
+--R         (2375100a b c + 395850b )x  + (1552950a c + 1552950a b )x
+--R       + 
+--R                 2   4           3 2
+--R         2243150a b x  + 1345890a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     3364725
+--R                                         Type: Union(Expression(Integer),...)
+--E 557
+
+--S 558 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 559
+
+)clear all
+
+--S 560 of 1057
+t0:=x^(1/2)*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 1057
+r0:=2/3*a^3*x^(3/2)+6/7*a^2*b*x^(7/2)+6/11*a*(b^2+a*c)*x^(11/2)+_
+   2/15*b*(b^2+6*a*c)*x^(15/2)+6/19*c*(b^2+a*c)*x^(19/2)+_
+   6/23*b*c^2*x^(23/2)+2/27*c^3*x^(27/2)
+--R 
+--R
+--R   (2)
+--R                3 13             2 11              2           2   9
+--R         336490c x   + 1185030b c x   + (1434510a c  + 1434510b c)x
+--R       + 
+--R                                3  7            2              2  5
+--R         (3634092a b c + 605682b )x  + (2477790a c + 2477790a b )x
+--R       + 
+--R                 2   3           3
+--R         3893670a b x  + 3028410a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     4542615
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 13             2 11              2           2   9
+--R         336490c x   + 1185030b c x   + (1434510a c  + 1434510b c)x
+--R       + 
+--R                                3  7            2              2  5
+--R         (3634092a b c + 605682b )x  + (2477790a c + 2477790a b )x
+--R       + 
+--R                 2   3           3
+--R         3893670a b x  + 3028410a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     4542615
+--R                                         Type: Union(Expression(Integer),...)
+--E 562
+
+--S 563 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 1057
+t0:=(a+b*x^2+c*x^4)^3/x^(1/2)
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 1057
+r0:=6/5*a^2*b*x^(5/2)+2/3*a*(b^2+a*c)*x^(9/2)+2/13*b*(b^2+6*a*c)*x^(13/2)+_
+   6/17*c*(b^2+a*c)*x^(17/2)+2/7*b*c^2*x^(21/2)+2/25*c^3*x^(25/2)+2*a^3*sqrt(x)
+--R 
+--R
+--R   (2)
+--R              3 12           2 10            2         2   8
+--R         9282c x   + 33150b c x   + (40950a c  + 40950b c)x
+--R       + 
+--R                              3  6          2            2  4          2   2
+--R         (107100a b c + 17850b )x  + (77350a c + 77350a b )x  + 139230a b x
+--R       + 
+--R                3
+--R         232050a
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     116025
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 12           2 10            2         2   8
+--R         9282c x   + 33150b c x   + (40950a c  + 40950b c)x
+--R       + 
+--R                              3  6          2            2  4          2   2
+--R         (107100a b c + 17850b )x  + (77350a c + 77350a b )x  + 139230a b x
+--R       + 
+--R                3
+--R         232050a
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     116025
+--R                                         Type: Union(Expression(Integer),...)
+--E 567
+
+--S 568 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 569
+
+)clear all
+
+--S 570 of 1057
+t0:=(a+b*x^2+c*x^4)^3/x^(3/2)
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R       +-+
+--R     x\|x
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 1057
+r0:=2*a^2*b*x^(3/2)+6/7*a*(b^2+a*c)*x^(7/2)+2/11*b*(b^2+6*a*c)*x^(11/2)+_
+   2/5*c*(b^2+a*c)*x^(15/2)+6/19*b*c^2*x^(19/2)+2/23*c^3*x^(23/2)-2*a^3/sqrt(x)
+--R 
+--R
+--R   (2)
+--R             3 12           2 10            2         2   8
+--R       14630c x   + 53130b c x   + (67298a c  + 67298b c)x
+--R     + 
+--R                            3  6           2             2  4          2   2
+--R       (183540a b c + 30590b )x  + (144210a c + 144210a b )x  + 336490a b x
+--R     + 
+--R                3
+--R       - 336490a
+--R  /
+--R            +-+
+--R     168245\|x
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3 12           2 10            2         2   8
+--R       14630c x   + 53130b c x   + (67298a c  + 67298b c)x
+--R     + 
+--R                            3  6           2             2  4          2   2
+--R       (183540a b c + 30590b )x  + (144210a c + 144210a b )x  + 336490a b x
+--R     + 
+--R                3
+--R       - 336490a
+--R  /
+--R            +-+
+--R     168245\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 572
+
+--S 573 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 574
+
+)clear all
+
+--S 575 of 1057
+t0:=(a+b*x^2+c*x^4)^3/x^(5/2)
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      2 +-+
+--R     x \|x
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 1057
+r0:=-2/3*a^3/x^(3/2)+6/5*a*(b^2+a*c)*x^(5/2)+2/9*b*(b^2+6*a*c)*x^(9/2)+_
+   6/13*c*(b^2+a*c)*x^(13/2)+6/17*b*c^2*x^(17/2)+2/21*c^3*x^(21/2)+_
+   6*a^2*b*sqrt(x)
+--R 
+--R
+--R   (2)
+--R            3 12           2 10            2         2   8
+--R       6630c x   + 24570b c x   + (32130a c  + 32130b c)x
+--R     + 
+--R                           3  6          2            2  4          2   2
+--R       (92820a b c + 15470b )x  + (83538a c + 83538a b )x  + 417690a b x
+--R     + 
+--R               3
+--R       - 46410a
+--R  /
+--R            +-+
+--R     69615x\|x
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 12           2 10            2         2   8
+--R       6630c x   + 24570b c x   + (32130a c  + 32130b c)x
+--R     + 
+--R                           3  6          2            2  4          2   2
+--R       (92820a b c + 15470b )x  + (83538a c + 83538a b )x  + 417690a b x
+--R     + 
+--R               3
+--R       - 46410a
+--R  /
+--R            +-+
+--R     69615x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 577
+
+--S 578 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 579
+
+)clear all
+
+--S 580 of 1057
+t0:=(a+b*x^2+c*x^4)^3/x^(7/2)
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      3 +-+
+--R     x \|x
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 1057
+r0:=-2/5*a^3/x^(5/2)+2*a*(b^2+a*c)*x^(3/2)+2/7*b*(b^2+6*a*c)*x^(7/2)+_
+   6/11*c*(b^2+a*c)*x^(11/2)+2/5*b*c^2*x^(15/2)+2/19*c^3*x^(19/2)-_
+   6*a^2*b/sqrt(x)
+--R 
+--R
+--R   (2)
+--R           3 12          2 10           2        2   8                      3  6
+--R       770c x   + 2926b c x   + (3990a c  + 3990b c)x  + (12540a b c + 2090b )x
+--R     + 
+--R              2            2  4         2   2        3
+--R       (14630a c + 14630a b )x  - 43890a b x  - 2926a
+--R  /
+--R          2 +-+
+--R     7315x \|x
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 12          2 10           2        2   8                      3  6
+--R       770c x   + 2926b c x   + (3990a c  + 3990b c)x  + (12540a b c + 2090b )x
+--R     + 
+--R              2            2  4         2   2        3
+--R       (14630a c + 14630a b )x  - 43890a b x  - 2926a
+--R  /
+--R          2 +-+
+--R     7315x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 582
+
+--S 583 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 584
+
+)clear all
+
+--S 585 of 1057
+t0:=x^(9/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R              4 +-+
+--R             x \|x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 585
+
+--S 586 of 1057
+r0:=2/3*x^(3/2)/c-atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   c^(7/4)*(-b+sqrt(b^2-4*a*c))^(1/4))+atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*c^(7/4)*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R             +-----------+               | +-----------+
+--R             |          2             2 4| |          2
+--R         (3b\|- 4a c + b   - 6a c + 3b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                         +--------------------+
+--R             +-----------+               |   +-----------+
+--R             |          2             2 4|   |          2
+--R         (3b\|- 4a c + b   + 6a c - 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                           +------------------+
+--R               +-----------+               | +-----------+
+--R               |          2             2 4| |          2
+--R         (- 3b\|- 4a c + b   + 6a c - 3b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+
+--R               +-----------+               |   +-----------+
+--R               |          2             2 4|   |          2
+--R         (- 3b\|- 4a c + b   - 6a c + 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                                     +--------------------+ +------------------+
+--R              +-----------+          |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4+-+3 +-+4|   |          2      4| |          2
+--R     2x \|2  \|- 4a c + b  \|c  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                                  +--------------------+ +------------------+
+--R              +-----------+       |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R     3c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            2 9         2 8      4 7
+--R                       (256a c  - 128a b c  + 16b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       2 9        2 8     4 7
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                           5   12        4 3 11        3 5 10        2 7 9
+--R                      5120a b c   - 8960a b c   + 5824a b c   - 1808a b c
+--R                    + 
+--R                            9 8      11 7
+--R                      272a b c  - 16b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               3 17         2 2 16          4 15       6 14
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                     7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                  16a c  - 152a b c  + 457a b c  - 553a b c  + 328a b c
+--R                + 
+--R                        2 10 2        12     14
+--R                  - 102a b  c  + 16a b  c - b
+--R             *
+--R                ROOT
+--R                              2 9         2 8      4 7
+--R                         (256a c  - 128a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                    3 17         2 2 16          4 15       6 14
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                         2 9        2 8     4 7
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   2 9         2 8      4 7
+--R                              (256a c  - 128a b c  + 16b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           3 17         2 2 16          4 15
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 14
+--R                                     - 256b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              2 9        2 8     4 7
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                8 3     7 2 2     6 4     5 6  +-+
+--R              (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R       -
+--R            3c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 2 9         2 8      4 7
+--R                          (- 256a c  + 128a b c  - 16b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                       3 17         2 2 16          4 15
+--R                                 16384a c   - 12288a b c   + 3072a b c
+--R                               + 
+--R                                       6 14
+--R                                 - 256b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          2 9        2 8     4 7
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                              5   12        4 3 11        3 5 10        2 7 9
+--R                         5120a b c   - 8960a b c   + 5824a b c   - 1808a b c
+--R                       + 
+--R                               9 8      11 7
+--R                         272a b c  - 16b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                          7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                     - 16a c  + 152a b c  - 457a b c  + 553a b c  - 328a b c
+--R                   + 
+--R                         2 10 2        12     14
+--R                     102a b  c  - 16a b  c + b
+--R                *
+--R                   ROOT
+--R                                   2 9         2 8      4 7
+--R                            (- 256a c  + 128a b c  - 16b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                         3 17         2 2 16          4 15
+--R                                   16384a c   - 12288a b c   + 3072a b c
+--R                                 + 
+--R                                         6 14
+--R                                   - 256b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                            2 9        2 8     4 7
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        2 9         2 8      4 7
+--R                                 (- 256a c  + 128a b c  - 16b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              3 17         2 2 16          4 15
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 14
+--R                                        - 256b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 2 9        2 8     4 7
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                   8 3     7 2 2     6 4     5 6  +-+
+--R                 (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R         3c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              2 9         2 8      4 7
+--R                       (- 256a c  + 128a b c  - 16b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       2 9        2 8     4 7
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                             5   12        4 3 11        3 5 10        2 7 9
+--R                      - 5120a b c   + 8960a b c   - 5824a b c   + 1808a b c
+--R                    + 
+--R                              9 8      11 7
+--R                      - 272a b c  + 16b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               3 17         2 2 16          4 15       6 14
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                     7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                  16a c  - 152a b c  + 457a b c  - 553a b c  + 328a b c
+--R                + 
+--R                        2 10 2        12     14
+--R                  - 102a b  c  + 16a b  c - b
+--R             *
+--R                ROOT
+--R                                2 9         2 8      4 7
+--R                         (- 256a c  + 128a b c  - 16b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                    3 17         2 2 16          4 15       6 14
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                         2 9        2 8     4 7
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     2 9         2 8      4 7
+--R                              (- 256a c  + 128a b c  - 16b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           3 17         2 2 16          4 15
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 14
+--R                                     - 256b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              2 9        2 8     4 7
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                8 3     7 2 2     6 4     5 6  +-+
+--R              (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R       -
+--R            3c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               2 9         2 8      4 7
+--R                          (256a c  - 128a b c  + 16b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                       3 17         2 2 16          4 15
+--R                                 16384a c   - 12288a b c   + 3072a b c
+--R                               + 
+--R                                       6 14
+--R                                 - 256b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          2 9        2 8     4 7
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                                5   12        4 3 11        3 5 10        2 7 9
+--R                         - 5120a b c   + 8960a b c   - 5824a b c   + 1808a b c
+--R                       + 
+--R                                 9 8      11 7
+--R                         - 272a b c  + 16b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                          7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                     - 16a c  + 152a b c  - 457a b c  + 553a b c  - 328a b c
+--R                   + 
+--R                         2 10 2        12     14
+--R                     102a b  c  - 16a b  c + b
+--R                *
+--R                   ROOT
+--R                                 2 9         2 8      4 7
+--R                            (256a c  - 128a b c  + 16b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                         3 17         2 2 16          4 15
+--R                                   16384a c   - 12288a b c   + 3072a b c
+--R                                 + 
+--R                                         6 14
+--R                                   - 256b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                            2 9        2 8     4 7
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      2 9         2 8      4 7
+--R                                 (256a c  - 128a b c  + 16b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              3 17         2 2 16          4 15
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 14
+--R                                        - 256b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 2 9        2 8     4 7
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                   8 3     7 2 2     6 4     5 6  +-+
+--R                 (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R         6c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            2 9         2 8      4 7
+--R                       (256a c  - 128a b c  + 16b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       2 9        2 8     4 7
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         atan
+--R                           5   12        4 3 11        3 5 10        2 7 9
+--R                      5120a b c   - 8960a b c   + 5824a b c   - 1808a b c
+--R                    + 
+--R                            9 8      11 7
+--R                      272a b c  - 16b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               3 17         2 2 16          4 15       6 14
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                     7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                  16a c  - 152a b c  + 457a b c  - 553a b c  + 328a b c
+--R                + 
+--R                        2 10 2        12     14
+--R                  - 102a b  c  + 16a b  c - b
+--R             *
+--R                ROOT
+--R                              2 9         2 8      4 7
+--R                         (256a c  - 128a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                    3 17         2 2 16          4 15       6 14
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                         2 9        2 8     4 7
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   2 9         2 8      4 7
+--R                              (256a c  - 128a b c  + 16b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           3 17         2 2 16          4 15
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 14
+--R                                     - 256b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              2 9        2 8     4 7
+--R                          128a c  - 64a b c  + 8b c
+--R           /
+--R                8 3     7 2 2     6 4     5 6  +-+
+--R              (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R       -
+--R            6c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 2 9         2 8      4 7
+--R                          (- 256a c  + 128a b c  - 16b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                       3 17         2 2 16          4 15
+--R                                 16384a c   - 12288a b c   + 3072a b c
+--R                               + 
+--R                                       6 14
+--R                                 - 256b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          2 9        2 8     4 7
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            atan
+--R                              5   12        4 3 11        3 5 10        2 7 9
+--R                         5120a b c   - 8960a b c   + 5824a b c   - 1808a b c
+--R                       + 
+--R                               9 8      11 7
+--R                         272a b c  - 16b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                          7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                     - 16a c  + 152a b c  - 457a b c  + 553a b c  - 328a b c
+--R                   + 
+--R                         2 10 2        12     14
+--R                     102a b  c  - 16a b  c + b
+--R                *
+--R                   ROOT
+--R                                   2 9         2 8      4 7
+--R                            (- 256a c  + 128a b c  - 16b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                         3 17         2 2 16          4 15
+--R                                   16384a c   - 12288a b c   + 3072a b c
+--R                                 + 
+--R                                         6 14
+--R                                   - 256b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                            2 9        2 8     4 7
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        2 9         2 8      4 7
+--R                                 (- 256a c  + 128a b c  - 16b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              3 17         2 2 16          4 15
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 14
+--R                                        - 256b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 2 9        2 8     4 7
+--R                             128a c  - 64a b c  + 8b c
+--R              /
+--R                   8 3     7 2 2     6 4     5 6  +-+
+--R                 (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R          +-+
+--R       4x\|x
+--R  /
+--R     6c
+--R                                         Type: Union(Expression(Integer),...)
+--E 587
+
+--S 588 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     +--------------------+ +------------------+
+--R                 +-----------+       |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R         c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            2 9         2 8      4 7
+--R                       (256a c  - 128a b c  + 16b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       2 9        2 8     4 7
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                           5   12        4 3 11        3 5 10        2 7 9
+--R                      5120a b c   - 8960a b c   + 5824a b c   - 1808a b c
+--R                    + 
+--R                            9 8      11 7
+--R                      272a b c  - 16b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               3 17         2 2 16          4 15       6 14
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                     7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                  16a c  - 152a b c  + 457a b c  - 553a b c  + 328a b c
+--R                + 
+--R                        2 10 2        12     14
+--R                  - 102a b  c  + 16a b  c - b
+--R             *
+--R                ROOT
+--R                              2 9         2 8      4 7
+--R                         (256a c  - 128a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                    3 17         2 2 16          4 15       6 14
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                         2 9        2 8     4 7
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   2 9         2 8      4 7
+--R                              (256a c  - 128a b c  + 16b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           3 17         2 2 16          4 15
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 14
+--R                                     - 256b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              2 9        2 8     4 7
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                8 3     7 2 2     6 4     5 6  +-+
+--R              (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R       -
+--R                                        +--------------------+
+--R                    +-----------+       |   +-----------+
+--R              4+-+3 |          2 4+-+3 4|   |          2
+--R            c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 2 9         2 8      4 7
+--R                          (- 256a c  + 128a b c  - 16b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                       3 17         2 2 16          4 15
+--R                                 16384a c   - 12288a b c   + 3072a b c
+--R                               + 
+--R                                       6 14
+--R                                 - 256b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          2 9        2 8     4 7
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                              5   12        4 3 11        3 5 10        2 7 9
+--R                         5120a b c   - 8960a b c   + 5824a b c   - 1808a b c
+--R                       + 
+--R                               9 8      11 7
+--R                         272a b c  - 16b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                          7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                     - 16a c  + 152a b c  - 457a b c  + 553a b c  - 328a b c
+--R                   + 
+--R                         2 10 2        12     14
+--R                     102a b  c  - 16a b  c + b
+--R                *
+--R                   ROOT
+--R                                   2 9         2 8      4 7
+--R                            (- 256a c  + 128a b c  - 16b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                         3 17         2 2 16          4 15
+--R                                   16384a c   - 12288a b c   + 3072a b c
+--R                                 + 
+--R                                         6 14
+--R                                   - 256b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                            2 9        2 8     4 7
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        2 9         2 8      4 7
+--R                                 (- 256a c  + 128a b c  - 16b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              3 17         2 2 16          4 15
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 14
+--R                                        - 256b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 2 9        2 8     4 7
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                   8 3     7 2 2     6 4     5 6  +-+
+--R                 (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R                                     +--------------------+ +------------------+
+--R                 +-----------+       |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R         c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              2 9         2 8      4 7
+--R                       (- 256a c  + 128a b c  - 16b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       2 9        2 8     4 7
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                             5   12        4 3 11        3 5 10        2 7 9
+--R                      - 5120a b c   + 8960a b c   - 5824a b c   + 1808a b c
+--R                    + 
+--R                              9 8      11 7
+--R                      - 272a b c  + 16b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               3 17         2 2 16          4 15       6 14
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                     7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                  16a c  - 152a b c  + 457a b c  - 553a b c  + 328a b c
+--R                + 
+--R                        2 10 2        12     14
+--R                  - 102a b  c  + 16a b  c - b
+--R             *
+--R                ROOT
+--R                                2 9         2 8      4 7
+--R                         (- 256a c  + 128a b c  - 16b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                    3 17         2 2 16          4 15       6 14
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                         2 9        2 8     4 7
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     2 9         2 8      4 7
+--R                              (- 256a c  + 128a b c  - 16b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           3 17         2 2 16          4 15
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 14
+--R                                     - 256b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              2 9        2 8     4 7
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                8 3     7 2 2     6 4     5 6  +-+
+--R              (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R       -
+--R                                        +--------------------+
+--R                    +-----------+       |   +-----------+
+--R              4+-+3 |          2 4+-+3 4|   |          2
+--R            c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               2 9         2 8      4 7
+--R                          (256a c  - 128a b c  + 16b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                       3 17         2 2 16          4 15
+--R                                 16384a c   - 12288a b c   + 3072a b c
+--R                               + 
+--R                                       6 14
+--R                                 - 256b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          2 9        2 8     4 7
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                                5   12        4 3 11        3 5 10        2 7 9
+--R                         - 5120a b c   + 8960a b c   - 5824a b c   + 1808a b c
+--R                       + 
+--R                                 9 8      11 7
+--R                         - 272a b c  + 16b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                          7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                     - 16a c  + 152a b c  - 457a b c  + 553a b c  - 328a b c
+--R                   + 
+--R                         2 10 2        12     14
+--R                     102a b  c  - 16a b  c + b
+--R                *
+--R                   ROOT
+--R                                 2 9         2 8      4 7
+--R                            (256a c  - 128a b c  + 16b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                         3 17         2 2 16          4 15
+--R                                   16384a c   - 12288a b c   + 3072a b c
+--R                                 + 
+--R                                         6 14
+--R                                   - 256b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                            2 9        2 8     4 7
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      2 9         2 8      4 7
+--R                                 (256a c  - 128a b c  + 16b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              3 17         2 2 16          4 15
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 14
+--R                                        - 256b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 2 9        2 8     4 7
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                   8 3     7 2 2     6 4     5 6  +-+
+--R                 (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R            4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R         2c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            2 9         2 8      4 7
+--R                       (256a c  - 128a b c  + 16b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       2 9        2 8     4 7
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         atan
+--R                           5   12        4 3 11        3 5 10        2 7 9
+--R                      5120a b c   - 8960a b c   + 5824a b c   - 1808a b c
+--R                    + 
+--R                            9 8      11 7
+--R                      272a b c  - 16b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               3 17         2 2 16          4 15       6 14
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                     7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                  16a c  - 152a b c  + 457a b c  - 553a b c  + 328a b c
+--R                + 
+--R                        2 10 2        12     14
+--R                  - 102a b  c  + 16a b  c - b
+--R             *
+--R                ROOT
+--R                              2 9         2 8      4 7
+--R                         (256a c  - 128a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                    3 17         2 2 16          4 15       6 14
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                         2 9        2 8     4 7
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   2 9         2 8      4 7
+--R                              (256a c  - 128a b c  + 16b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           3 17         2 2 16          4 15
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 14
+--R                                     - 256b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              2 9        2 8     4 7
+--R                          128a c  - 64a b c  + 8b c
+--R           /
+--R                8 3     7 2 2     6 4     5 6  +-+
+--R              (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R       -
+--R                                         +--------------------+
+--R                     +-----------+       |   +-----------+
+--R               4+-+3 |          2 4+-+3 4|   |          2
+--R            2c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 2 9         2 8      4 7
+--R                          (- 256a c  + 128a b c  - 16b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                       3 17         2 2 16          4 15
+--R                                 16384a c   - 12288a b c   + 3072a b c
+--R                               + 
+--R                                       6 14
+--R                                 - 256b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          2 9        2 8     4 7
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            atan
+--R                              5   12        4 3 11        3 5 10        2 7 9
+--R                         5120a b c   - 8960a b c   + 5824a b c   - 1808a b c
+--R                       + 
+--R                               9 8      11 7
+--R                         272a b c  - 16b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  3 17         2 2 16          4 15       6 14
+--R                            16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                          7 7       6 2 6       5 4 5       4 6 4       3 8 3
+--R                     - 16a c  + 152a b c  - 457a b c  + 553a b c  - 328a b c
+--R                   + 
+--R                         2 10 2        12     14
+--R                     102a b  c  - 16a b  c + b
+--R                *
+--R                   ROOT
+--R                                   2 9         2 8      4 7
+--R                            (- 256a c  + 128a b c  - 16b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                         3 17         2 2 16          4 15
+--R                                   16384a c   - 12288a b c   + 3072a b c
+--R                                 + 
+--R                                         6 14
+--R                                   - 256b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                            2 9        2 8     4 7
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        2 9         2 8      4 7
+--R                                 (- 256a c  + 128a b c  - 16b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              3 17         2 2 16          4 15
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 14
+--R                                        - 256b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 2 9        2 8     4 7
+--R                             128a c  - 64a b c  + 8b c
+--R              /
+--R                   8 3     7 2 2     6 4     5 6  +-+
+--R                 (a c  - 6a b c  + 5a b c - a b )\|x
+--R     + 
+--R                                           +------------------+
+--R               +-----------+               | +-----------+
+--R               |          2             2 4| |          2
+--R         (- 2b\|- 4a c + b   + 4a c - 2b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+
+--R               +-----------+               |   +-----------+
+--R               |          2             2 4|   |          2
+--R         (- 2b\|- 4a c + b   - 4a c + 2b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                         +------------------+
+--R             +-----------+               | +-----------+
+--R             |          2             2 4| |          2
+--R         (2b\|- 4a c + b   - 4a c + 2b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                         +--------------------+
+--R             +-----------+               |   +-----------+
+--R             |          2             2 4|   |          2
+--R         (2b\|- 4a c + b   + 4a c - 2b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                  +--------------------+ +------------------+
+--R              +-----------+       |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R     2c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 588
+
+--S 589 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 589
+
+)clear all
+
+--S 590 of 1057
+t0:=x^(7/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R              3 +-+
+--R             x \|x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 1057
+r0:=atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b-sqrt(b^2-4*a*c))^(3/4))+_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))+atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(5/4)*(-b+sqrt(b^2-4*a*c))^(3/4))+atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(5/4)*(-b+sqrt(b^2-4*a*c))^(3/4))+2*sqrt(x)/c
+--R 
+--R
+--R   (2)
+--R                                       +------------------+3
+--R            +-----------+              | +-----------+
+--R            |          2            2 4| |          2
+--R         (b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                       +--------------------+3
+--R            +-----------+              |   +-----------+
+--R            |          2            2 4|   |          2
+--R         (b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                       +------------------+3
+--R            +-----------+              | +-----------+
+--R            |          2            2 4| |          2
+--R         (b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                       +--------------------+3
+--R            +-----------+              |   +-----------+
+--R            |          2            2 4|   |          2
+--R         (b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                                 +--------------------+3  +------------------+3
+--R           +-----------+         |   +-----------+        | +-----------+
+--R      4+-+ |          2 4+-+ +-+4|   |          2        4| |          2
+--R     2\|2 \|- 4a c + b  \|c \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R                             +--------------------+3  +------------------+3
+--R           +-----------+     |   +-----------+        | +-----------+
+--R      4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            2 7         2 6      4 5
+--R                       (256a c  - 128a b c  + 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       2 7        2 6     4 5
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                         2   7         3 6      5 5
+--R                    (256a b c  - 128a b c  + 16b c )
+--R                 *
+--R                     +--------------------------------------------------+
+--R                     |        4 4     3 2 3      2 4 2       6     8
+--R                     |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |--------------------------------------------------
+--R                     |      3 13         2 2 12          4 11       6 10
+--R                    \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                      3 3      2 2 2       4     6
+--R                  - 4a c  + 13a b c  - 7a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   2 7         2 6      4 5
+--R                              (256a c  - 128a b c  + 16b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 256b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              2 7        2 6     4 5
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                 3 2     2 2        4  +-+
+--R              (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 2 7         2 6      4 5
+--R                          (- 256a c  + 128a b c  - 16b c )
+--R                       *
+--R                           +--------------------------------------------------+
+--R                           |        4 4     3 2 3      2 4 2       6     8
+--R                           |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |--------------------------------------------------
+--R                           |      3 13         2 2 12          4 11       6 10
+--R                          \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          2 7        2 6     4 5
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                            2   7         3 6      5 5
+--R                       (256a b c  - 128a b c  + 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                       3 3      2 2 2       4     6
+--R                     4a c  - 13a b c  + 7a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        2 7         2 6      4 5
+--R                                 (- 256a c  + 128a b c  - 16b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              3 13         2 2 12          4 11
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 10
+--R                                        - 256b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 2 7        2 6     4 5
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                    3 2     2 2        4  +-+
+--R                 (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R         c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              2 7         2 6      4 5
+--R                       (- 256a c  + 128a b c  - 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       2 7        2 6     4 5
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                           2   7         3 6      5 5
+--R                    (- 256a b c  + 128a b c  - 16b c )
+--R                 *
+--R                     +--------------------------------------------------+
+--R                     |        4 4     3 2 3      2 4 2       6     8
+--R                     |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |--------------------------------------------------
+--R                     |      3 13         2 2 12          4 11       6 10
+--R                    \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                      3 3      2 2 2       4     6
+--R                  - 4a c  + 13a b c  - 7a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     2 7         2 6      4 5
+--R                              (- 256a c  + 128a b c  - 16b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 256b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              2 7        2 6     4 5
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                 3 2     2 2        4  +-+
+--R              (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               2 7         2 6      4 5
+--R                          (256a c  - 128a b c  + 16b c )
+--R                       *
+--R                           +--------------------------------------------------+
+--R                           |        4 4     3 2 3      2 4 2       6     8
+--R                           |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |--------------------------------------------------
+--R                           |      3 13         2 2 12          4 11       6 10
+--R                          \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          2 7        2 6     4 5
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                              2   7         3 6      5 5
+--R                       (- 256a b c  + 128a b c  - 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                       3 3      2 2 2       4     6
+--R                     4a c  - 13a b c  + 7a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      2 7         2 6      4 5
+--R                                 (256a c  - 128a b c  + 16b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              3 13         2 2 12          4 11
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 10
+--R                                        - 256b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 2 7        2 6     4 5
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                    3 2     2 2        4  +-+
+--R                 (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R       -
+--R            2c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               2 7         2 6      4 5
+--R                          (256a c  - 128a b c  + 16b c )
+--R                       *
+--R                           +--------------------------------------------------+
+--R                           |        4 4     3 2 3      2 4 2       6     8
+--R                           |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |--------------------------------------------------
+--R                           |      3 13         2 2 12          4 11       6 10
+--R                          \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          2 7        2 6     4 5
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            atan
+--R                            2   7         3 6      5 5
+--R                       (256a b c  - 128a b c  + 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                         3 3      2 2 2       4     6
+--R                     - 4a c  + 13a b c  - 7a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      2 7         2 6      4 5
+--R                                 (256a c  - 128a b c  + 16b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              3 13         2 2 12          4 11
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 10
+--R                                        - 256b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 2 7        2 6     4 5
+--R                             128a c  - 64a b c  + 8b c
+--R              /
+--R                    3 2     2 2        4  +-+
+--R                 (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R         2c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              2 7         2 6      4 5
+--R                       (- 256a c  + 128a b c  - 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       2 7        2 6     4 5
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         atan
+--R                         2   7         3 6      5 5
+--R                    (256a b c  - 128a b c  + 16b c )
+--R                 *
+--R                     +--------------------------------------------------+
+--R                     |        4 4     3 2 3      2 4 2       6     8
+--R                     |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |--------------------------------------------------
+--R                     |      3 13         2 2 12          4 11       6 10
+--R                    \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                    3 3      2 2 2       4     6
+--R                  4a c  - 13a b c  + 7a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     2 7         2 6      4 5
+--R                              (- 256a c  + 128a b c  - 16b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 256b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              2 7        2 6     4 5
+--R                          128a c  - 64a b c  + 8b c
+--R           /
+--R                 3 2     2 2        4  +-+
+--R              (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R         +-+
+--R       4\|x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 592
+
+--S 593 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------------------+3  +------------------+3
+--R               +-----------+     |   +-----------+        | +-----------+
+--R          4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            2 7         2 6      4 5
+--R                       (256a c  - 128a b c  + 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       2 7        2 6     4 5
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                         2   7         3 6      5 5
+--R                    (256a b c  - 128a b c  + 16b c )
+--R                 *
+--R                     +--------------------------------------------------+
+--R                     |        4 4     3 2 3      2 4 2       6     8
+--R                     |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |--------------------------------------------------
+--R                     |      3 13         2 2 12          4 11       6 10
+--R                    \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                      3 3      2 2 2       4     6
+--R                  - 4a c  + 13a b c  - 7a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   2 7         2 6      4 5
+--R                              (256a c  - 128a b c  + 16b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 256b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              2 7        2 6     4 5
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                 3 2     2 2        4  +-+
+--R              (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R       -
+--R                                    +--------------------+3
+--R                  +-----------+     |   +-----------+
+--R             4+-+ |          2 4+-+4|   |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 2 7         2 6      4 5
+--R                          (- 256a c  + 128a b c  - 16b c )
+--R                       *
+--R                           +--------------------------------------------------+
+--R                           |        4 4     3 2 3      2 4 2       6     8
+--R                           |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |--------------------------------------------------
+--R                           |      3 13         2 2 12          4 11       6 10
+--R                          \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          2 7        2 6     4 5
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                            2   7         3 6      5 5
+--R                       (256a b c  - 128a b c  + 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                       3 3      2 2 2       4     6
+--R                     4a c  - 13a b c  + 7a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        2 7         2 6      4 5
+--R                                 (- 256a c  + 128a b c  - 16b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              3 13         2 2 12          4 11
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 10
+--R                                        - 256b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 2 7        2 6     4 5
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                    3 2     2 2        4  +-+
+--R                 (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R                                 +--------------------+3  +------------------+3
+--R               +-----------+     |   +-----------+        | +-----------+
+--R          4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              2 7         2 6      4 5
+--R                       (- 256a c  + 128a b c  - 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       2 7        2 6     4 5
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                           2   7         3 6      5 5
+--R                    (- 256a b c  + 128a b c  - 16b c )
+--R                 *
+--R                     +--------------------------------------------------+
+--R                     |        4 4     3 2 3      2 4 2       6     8
+--R                     |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |--------------------------------------------------
+--R                     |      3 13         2 2 12          4 11       6 10
+--R                    \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                      3 3      2 2 2       4     6
+--R                  - 4a c  + 13a b c  - 7a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     2 7         2 6      4 5
+--R                              (- 256a c  + 128a b c  - 16b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 256b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              2 7        2 6     4 5
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                 3 2     2 2        4  +-+
+--R              (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R       -
+--R                                    +--------------------+3
+--R                  +-----------+     |   +-----------+
+--R             4+-+ |          2 4+-+4|   |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               2 7         2 6      4 5
+--R                          (256a c  - 128a b c  + 16b c )
+--R                       *
+--R                           +--------------------------------------------------+
+--R                           |        4 4     3 2 3      2 4 2       6     8
+--R                           |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |--------------------------------------------------
+--R                           |      3 13         2 2 12          4 11       6 10
+--R                          \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          2 7        2 6     4 5
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                              2   7         3 6      5 5
+--R                       (- 256a b c  + 128a b c  - 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                       3 3      2 2 2       4     6
+--R                     4a c  - 13a b c  + 7a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      2 7         2 6      4 5
+--R                                 (256a c  - 128a b c  + 16b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              3 13         2 2 12          4 11
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 10
+--R                                        - 256b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 2 7        2 6     4 5
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                    3 2     2 2        4  +-+
+--R                 (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R       -
+--R                                     +--------------------+3
+--R                   +-----------+     |   +-----------+
+--R              4+-+ |          2 4+-+4|   |          2
+--R            2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               2 7         2 6      4 5
+--R                          (256a c  - 128a b c  + 16b c )
+--R                       *
+--R                           +--------------------------------------------------+
+--R                           |        4 4     3 2 3      2 4 2       6     8
+--R                           |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |--------------------------------------------------
+--R                           |      3 13         2 2 12          4 11       6 10
+--R                          \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          2 7        2 6     4 5
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            atan
+--R                            2   7         3 6      5 5
+--R                       (256a b c  - 128a b c  + 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                         3 3      2 2 2       4     6
+--R                     - 4a c  + 13a b c  - 7a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      2 7         2 6      4 5
+--R                                 (256a c  - 128a b c  + 16b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              3 13         2 2 12          4 11
+--R                                        16384a c   - 12288a b c   + 3072a b c
+--R                                      + 
+--R                                              6 10
+--R                                        - 256b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 2 7        2 6     4 5
+--R                             128a c  - 64a b c  + 8b c
+--R              /
+--R                    3 2     2 2        4  +-+
+--R                 (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R                                  +--------------------+3  +------------------+3
+--R                +-----------+     |   +-----------+        | +-----------+
+--R           4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              2 7         2 6      4 5
+--R                       (- 256a c  + 128a b c  - 16b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |        4 4     3 2 3      2 4 2       6     8
+--R                        |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       2 7        2 6     4 5
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         atan
+--R                         2   7         3 6      5 5
+--R                    (256a b c  - 128a b c  + 16b c )
+--R                 *
+--R                     +--------------------------------------------------+
+--R                     |        4 4     3 2 3      2 4 2       6     8
+--R                     |     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |--------------------------------------------------
+--R                     |      3 13         2 2 12          4 11       6 10
+--R                    \|16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                    3 3      2 2 2       4     6
+--R                  4a c  - 13a b c  + 7a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     2 7         2 6      4 5
+--R                              (- 256a c  + 128a b c  - 16b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     16384a c   - 12288a b c   + 3072a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 256b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              2 7        2 6     4 5
+--R                          128a c  - 64a b c  + 8b c
+--R           /
+--R                 3 2     2 2        4  +-+
+--R              (2a c  - 6a b c + 2a b )\|x
+--R     + 
+--R                                           +------------------+3
+--R               +-----------+               | +-----------+
+--R               |          2             2 4| |          2
+--R         (- 2b\|- 4a c + b   + 4a c - 2b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+3
+--R               +-----------+               |   +-----------+
+--R               |          2             2 4|   |          2
+--R         (- 2b\|- 4a c + b   - 4a c + 2b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                           +------------------+3
+--R               +-----------+               | +-----------+
+--R               |          2             2 4| |          2
+--R         (- 2b\|- 4a c + b   + 4a c - 2b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+3
+--R               +-----------+               |   +-----------+
+--R               |          2             2 4|   |          2
+--R         (- 2b\|- 4a c + b   - 4a c + 2b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+3  +------------------+3
+--R            +-----------+     |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 594
+
+)clear all
+
+--S 595 of 1057
+t0:=x^(5/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R              2 +-+
+--R             x \|x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 1057
+r0:=-atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (-b-sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))+_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(-b-_
+   sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))+_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(-b+_
+   sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))-_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(-b+_
+   sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +--------------------+3
+--R        |   +-----------+                  4+-+4+-+ +-+
+--R       4|   |          2                   \|2 \|c \|x
+--R       \|- \|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R       - \|\|- 4a c + b   - b  atanh(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R       - \|- \|- 4a c + b   - b  atan(-----------------------)
+--R                                       +--------------------+
+--R                                       |   +-----------+
+--R                                      4|   |          2
+--R                                      \|- \|- 4a c + b   - b
+--R     + 
+--R        +------------------+3
+--R        | +-----------+                4+-+4+-+ +-+
+--R       4| |          2                 \|2 \|c \|x
+--R       \|\|- 4a c + b   - b  atan(---------------------)
+--R                                   +------------------+
+--R                                   | +-----------+
+--R                                  4| |          2
+--R                                  \|\|- 4a c + b   - b
+--R  /
+--R           +-----------+
+--R     4+-+3 |          2 4+-+3
+--R     \|2  \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            2 5         2 4      4 3
+--R                       (256a c  - 128a b c  + 16b c )
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       2 5        2 4     4 3
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                          4 7        3 2 6        2 4 5         6 4      8 3
+--R                    (2048a c  - 2560a b c  + 1152a b c  - 224a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       3   3      2 3 2       5     7
+--R                  - 16a b c  + 24a b c  - 9a b c + b
+--R             *
+--R                ROOT
+--R                              2 5         2 4      4 3
+--R                         (256a c  - 128a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |             - a c  + 2a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                         2 5        2 4     4 3
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   2 5         2 4      4 3
+--R                              (256a c  - 128a b c  + 16b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 9         2 2 8          4 7       6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              2 5        2 4     4 3
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                3     2 2  +-+
+--R              (a c - a b )\|x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 2 5         2 4      4 3
+--R                          (- 256a c  + 128a b c  - 16b c )
+--R                       *
+--R                           +----------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |----------------------------------------------
+--R                           |      3 9         2 2 8          4 7       6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          2 5        2 4     4 3
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                             4 7        3 2 6        2 4 5         6 4      8 3
+--R                       (2048a c  - 2560a b c  + 1152a b c  - 224a b c  + 16b c )
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                        3   3      2 3 2       5     7
+--R                     16a b c  - 24a b c  + 9a b c - b
+--R                *
+--R                   ROOT
+--R                                   2 5         2 4      4 3
+--R                            (- 256a c  + 128a b c  - 16b c )
+--R                         *
+--R                             +----------------------------------------------+
+--R                             |                2 2       2     4
+--R                             |             - a c  + 2a b c - b
+--R                             |----------------------------------------------
+--R                             |      3 9         2 2 8          4 7       6 6
+--R                            \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                            2 5        2 4     4 3
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        2 5         2 4      4 3
+--R                                 (- 256a c  + 128a b c  - 16b c )
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |----------------------------------------------
+--R                                |      3 9         2 2 8          4 7       6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 2 5        2 4     4 3
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                   3     2 2  +-+
+--R                 (a c - a b )\|x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              2 5         2 4      4 3
+--R                       (- 256a c  + 128a b c  - 16b c )
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       2 5        2 4     4 3
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                            4 7        3 2 6        2 4 5         6 4      8 3
+--R                    (- 2048a c  + 2560a b c  - 1152a b c  + 224a b c  - 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       3   3      2 3 2       5     7
+--R                  - 16a b c  + 24a b c  - 9a b c + b
+--R             *
+--R                ROOT
+--R                                2 5         2 4      4 3
+--R                         (- 256a c  + 128a b c  - 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |             - a c  + 2a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                         2 5        2 4     4 3
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     2 5         2 4      4 3
+--R                              (- 256a c  + 128a b c  - 16b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 9         2 2 8          4 7       6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              2 5        2 4     4 3
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                3     2 2  +-+
+--R              (a c - a b )\|x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               2 5         2 4      4 3
+--R                          (256a c  - 128a b c  + 16b c )
+--R                       *
+--R                           +----------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |----------------------------------------------
+--R                           |      3 9         2 2 8          4 7       6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          2 5        2 4     4 3
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                                  4 7        3 2 6        2 4 5         6 4
+--R                           - 2048a c  + 2560a b c  - 1152a b c  + 224a b c
+--R                         + 
+--R                                8 3
+--R                           - 16b c
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                        3   3      2 3 2       5     7
+--R                     16a b c  - 24a b c  + 9a b c - b
+--R                *
+--R                   ROOT
+--R                                 2 5         2 4      4 3
+--R                            (256a c  - 128a b c  + 16b c )
+--R                         *
+--R                             +----------------------------------------------+
+--R                             |                2 2       2     4
+--R                             |             - a c  + 2a b c - b
+--R                             |----------------------------------------------
+--R                             |      3 9         2 2 8          4 7       6 6
+--R                            \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                            2 5        2 4     4 3
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      2 5         2 4      4 3
+--R                                 (256a c  - 128a b c  + 16b c )
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |----------------------------------------------
+--R                                |      3 9         2 2 8          4 7       6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 2 5        2 4     4 3
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                   3     2 2  +-+
+--R                 (a c - a b )\|x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            2 5         2 4      4 3
+--R                       (256a c  - 128a b c  + 16b c )
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       2 5        2 4     4 3
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         atan
+--R                          4 7        3 2 6        2 4 5         6 4      8 3
+--R                    (2048a c  - 2560a b c  + 1152a b c  - 224a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       3   3      2 3 2       5     7
+--R                  - 16a b c  + 24a b c  - 9a b c + b
+--R             *
+--R                ROOT
+--R                              2 5         2 4      4 3
+--R                         (256a c  - 128a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |             - a c  + 2a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                         2 5        2 4     4 3
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   2 5         2 4      4 3
+--R                              (256a c  - 128a b c  + 16b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 9         2 2 8          4 7       6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              2 5        2 4     4 3
+--R                          128a c  - 64a b c  + 8b c
+--R           /
+--R                3     2 2  +-+
+--R              (a c - a b )\|x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 2 5         2 4      4 3
+--R                          (- 256a c  + 128a b c  - 16b c )
+--R                       *
+--R                           +----------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |----------------------------------------------
+--R                           |      3 9         2 2 8          4 7       6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          2 5        2 4     4 3
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            atan
+--R                             4 7        3 2 6        2 4 5         6 4      8 3
+--R                       (2048a c  - 2560a b c  + 1152a b c  - 224a b c  + 16b c )
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                        3   3      2 3 2       5     7
+--R                     16a b c  - 24a b c  + 9a b c - b
+--R                *
+--R                   ROOT
+--R                                   2 5         2 4      4 3
+--R                            (- 256a c  + 128a b c  - 16b c )
+--R                         *
+--R                             +----------------------------------------------+
+--R                             |                2 2       2     4
+--R                             |             - a c  + 2a b c - b
+--R                             |----------------------------------------------
+--R                             |      3 9         2 2 8          4 7       6 6
+--R                            \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                            2 5        2 4     4 3
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        2 5         2 4      4 3
+--R                                 (- 256a c  + 128a b c  - 16b c )
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |----------------------------------------------
+--R                                |      3 9         2 2 8          4 7       6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 2 5        2 4     4 3
+--R                             128a c  - 64a b c  + 8b c
+--R              /
+--R                   3     2 2  +-+
+--R                 (a c - a b )\|x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 597
+
+--S 598 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-----------+
+--R         4+-+3 |          2 4+-+3
+--R         \|2  \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            2 5         2 4      4 3
+--R                       (256a c  - 128a b c  + 16b c )
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       2 5        2 4     4 3
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                          4 7        3 2 6        2 4 5         6 4      8 3
+--R                    (2048a c  - 2560a b c  + 1152a b c  - 224a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       3   3      2 3 2       5     7
+--R                  - 16a b c  + 24a b c  - 9a b c + b
+--R             *
+--R                ROOT
+--R                              2 5         2 4      4 3
+--R                         (256a c  - 128a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |             - a c  + 2a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                         2 5        2 4     4 3
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   2 5         2 4      4 3
+--R                              (256a c  - 128a b c  + 16b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 9         2 2 8          4 7       6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              2 5        2 4     4 3
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                3     2 2  +-+
+--R              (a c - a b )\|x
+--R     + 
+--R       -
+--R                  +-----------+
+--R            4+-+3 |          2 4+-+3
+--R            \|2  \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 2 5         2 4      4 3
+--R                          (- 256a c  + 128a b c  - 16b c )
+--R                       *
+--R                           +----------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |----------------------------------------------
+--R                           |      3 9         2 2 8          4 7       6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          2 5        2 4     4 3
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                             4 7        3 2 6        2 4 5         6 4      8 3
+--R                       (2048a c  - 2560a b c  + 1152a b c  - 224a b c  + 16b c )
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                        3   3      2 3 2       5     7
+--R                     16a b c  - 24a b c  + 9a b c - b
+--R                *
+--R                   ROOT
+--R                                   2 5         2 4      4 3
+--R                            (- 256a c  + 128a b c  - 16b c )
+--R                         *
+--R                             +----------------------------------------------+
+--R                             |                2 2       2     4
+--R                             |             - a c  + 2a b c - b
+--R                             |----------------------------------------------
+--R                             |      3 9         2 2 8          4 7       6 6
+--R                            \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                            2 5        2 4     4 3
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        2 5         2 4      4 3
+--R                                 (- 256a c  + 128a b c  - 16b c )
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |----------------------------------------------
+--R                                |      3 9         2 2 8          4 7       6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 2 5        2 4     4 3
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                   3     2 2  +-+
+--R                 (a c - a b )\|x
+--R     + 
+--R               +-----------+
+--R         4+-+3 |          2 4+-+3
+--R         \|2  \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              2 5         2 4      4 3
+--R                       (- 256a c  + 128a b c  - 16b c )
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       2 5        2 4     4 3
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         log
+--R                            4 7        3 2 6        2 4 5         6 4      8 3
+--R                    (- 2048a c  + 2560a b c  - 1152a b c  + 224a b c  - 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       3   3      2 3 2       5     7
+--R                  - 16a b c  + 24a b c  - 9a b c + b
+--R             *
+--R                ROOT
+--R                                2 5         2 4      4 3
+--R                         (- 256a c  + 128a b c  - 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |             - a c  + 2a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                         2 5        2 4     4 3
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     2 5         2 4      4 3
+--R                              (- 256a c  + 128a b c  - 16b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 9         2 2 8          4 7       6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              2 5        2 4     4 3
+--R                          128a c  - 64a b c  + 8b c
+--R            + 
+--R                3     2 2  +-+
+--R              (a c - a b )\|x
+--R     + 
+--R       -
+--R                  +-----------+
+--R            4+-+3 |          2 4+-+3
+--R            \|2  \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               2 5         2 4      4 3
+--R                          (256a c  - 128a b c  + 16b c )
+--R                       *
+--R                           +----------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |----------------------------------------------
+--R                           |      3 9         2 2 8          4 7       6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          2 5        2 4     4 3
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            log
+--R                                  4 7        3 2 6        2 4 5         6 4
+--R                           - 2048a c  + 2560a b c  - 1152a b c  + 224a b c
+--R                         + 
+--R                                8 3
+--R                           - 16b c
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                        3   3      2 3 2       5     7
+--R                     16a b c  - 24a b c  + 9a b c - b
+--R                *
+--R                   ROOT
+--R                                 2 5         2 4      4 3
+--R                            (256a c  - 128a b c  + 16b c )
+--R                         *
+--R                             +----------------------------------------------+
+--R                             |                2 2       2     4
+--R                             |             - a c  + 2a b c - b
+--R                             |----------------------------------------------
+--R                             |      3 9         2 2 8          4 7       6 6
+--R                            \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                            2 5        2 4     4 3
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      2 5         2 4      4 3
+--R                                 (256a c  - 128a b c  + 16b c )
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |----------------------------------------------
+--R                                |      3 9         2 2 8          4 7       6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 2 5        2 4     4 3
+--R                             128a c  - 64a b c  + 8b c
+--R               + 
+--R                   3     2 2  +-+
+--R                 (a c - a b )\|x
+--R     + 
+--R                +-----------+
+--R          4+-+3 |          2 4+-+3
+--R         2\|2  \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            2 5         2 4      4 3
+--R                       (256a c  - 128a b c  + 16b c )
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       2 5        2 4     4 3
+--R                   128a c  - 64a b c  + 8b c
+--R      *
+--R         atan
+--R                          4 7        3 2 6        2 4 5         6 4      8 3
+--R                    (2048a c  - 2560a b c  + 1152a b c  - 224a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       3   3      2 3 2       5     7
+--R                  - 16a b c  + 24a b c  - 9a b c + b
+--R             *
+--R                ROOT
+--R                              2 5         2 4      4 3
+--R                         (256a c  - 128a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |             - a c  + 2a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                         2 5        2 4     4 3
+--R                     128a c  - 64a b c  + 8b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   2 5         2 4      4 3
+--R                              (256a c  - 128a b c  + 16b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 9         2 2 8          4 7       6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              2 5        2 4     4 3
+--R                          128a c  - 64a b c  + 8b c
+--R           /
+--R                3     2 2  +-+
+--R              (a c - a b )\|x
+--R     + 
+--R       -
+--R                   +-----------+
+--R             4+-+3 |          2 4+-+3
+--R            2\|2  \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 2 5         2 4      4 3
+--R                          (- 256a c  + 128a b c  - 16b c )
+--R                       *
+--R                           +----------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |----------------------------------------------
+--R                           |      3 9         2 2 8          4 7       6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          2 5        2 4     4 3
+--R                      128a c  - 64a b c  + 8b c
+--R         *
+--R            atan
+--R                             4 7        3 2 6        2 4 5         6 4      8 3
+--R                       (2048a c  - 2560a b c  + 1152a b c  - 224a b c  + 16b c )
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 9         2 2 8          4 7       6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                   + 
+--R                        3   3      2 3 2       5     7
+--R                     16a b c  - 24a b c  + 9a b c - b
+--R                *
+--R                   ROOT
+--R                                   2 5         2 4      4 3
+--R                            (- 256a c  + 128a b c  - 16b c )
+--R                         *
+--R                             +----------------------------------------------+
+--R                             |                2 2       2     4
+--R                             |             - a c  + 2a b c - b
+--R                             |----------------------------------------------
+--R                             |      3 9         2 2 8          4 7       6 6
+--R                            \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                            2 5        2 4     4 3
+--R                        128a c  - 64a b c  + 8b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        2 5         2 4      4 3
+--R                                 (- 256a c  + 128a b c  - 16b c )
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |----------------------------------------------
+--R                                |      3 9         2 2 8          4 7       6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 2 5        2 4     4 3
+--R                             128a c  - 64a b c  + 8b c
+--R              /
+--R                   3     2 2  +-+
+--R                 (a c - a b )\|x
+--R     + 
+--R           +--------------------+3
+--R           |   +-----------+                  4+-+4+-+ +-+
+--R          4|   |          2                   \|2 \|c \|x
+--R       - 2\|- \|- 4a c + b   - b  atanh(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R         +------------------+3
+--R         | +-----------+                 4+-+4+-+ +-+
+--R        4| |          2                  \|2 \|c \|x
+--R       2\|\|- 4a c + b   - b  atanh(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                    4| |          2
+--R                                    \|\|- 4a c + b   - b
+--R     + 
+--R         +--------------------+3
+--R         |   +-----------+                 4+-+4+-+ +-+
+--R        4|   |          2                  \|2 \|c \|x
+--R       2\|- \|- 4a c + b   - b  atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R           +------------------+3
+--R           | +-----------+                4+-+4+-+ +-+
+--R          4| |          2                 \|2 \|c \|x
+--R       - 2\|\|- 4a c + b   - b  atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R  /
+--R            +-----------+
+--R      4+-+3 |          2 4+-+3
+--R     2\|2  \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 599
+
+)clear all
+
+--S 600 of 1057
+t0:=x^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               +-+
+--R             x\|x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 600
+
+--S 601 of 1057
+r0:=atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(-b-_
+   sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))+_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(-b-_
+   sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))-_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(-b+_
+   sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))-_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(-b+_
+   sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +--------------------+
+--R        |   +-----------+                 4+-+4+-+ +-+
+--R       4|   |          2                  \|2 \|c \|x
+--R       \|- \|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R       - \|\|- 4a c + b   - b atanh(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                    4| |          2
+--R                                    \|\|- 4a c + b   - b
+--R     + 
+--R        +--------------------+
+--R        |   +-----------+                4+-+4+-+ +-+
+--R       4|   |          2                 \|2 \|c \|x
+--R       \|- \|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+
+--R          | +-----------+               4+-+4+-+ +-+
+--R         4| |          2                \|2 \|c \|x
+--R       - \|\|- 4a c + b   - b atan(---------------------)
+--R                                    +------------------+
+--R                                    | +-----------+
+--R                                   4| |          2
+--R                                   \|\|- 4a c + b   - b
+--R  /
+--R          +-----------+
+--R     4+-+ |          2 4+-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           a
+--R                   4  |------------------------------------------------------
+--R                     4|     4 5        3 2 4        2 4 3         6 2      8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R                *
+--R                     sin
+--R                          atan
+--R                                      2 3         2 2      4
+--R                                 (256a c  - 128a b c  + 16b c)
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                       1
+--R                                |----------------------------------------------
+--R                                |      3 5         2 2 4          4 3       6 2
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           a
+--R                   4  |------------------------------------------------------
+--R                     4|     4 5        3 2 4        2 4 3         6 2      8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R                *
+--R                     cos
+--R                          atan
+--R                                      2 3         2 2      4
+--R                                 (256a c  - 128a b c  + 16b c)
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                       1
+--R                                |----------------------------------------------
+--R                                |      3 5         2 2 4          4 3       6 2
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       2 3         2 2      4
+--R                                  (256a c  - 128a b c  + 16b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                               3 5         2 2 4          4 3
+--R                                         16384a c  - 12288a b c  + 3072a b c
+--R                                       + 
+--R                                               6 2
+--R                                         - 256b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       2 3         2 2      4
+--R                                  (256a c  - 128a b c  + 16b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                               3 5         2 2 4          4 3
+--R                                         16384a c  - 12288a b c  + 3072a b c
+--R                                       + 
+--R                                               6 2
+--R                                         - 256b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                            2
+--R                   (4a c - b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                        2 3         2 2      4
+--R                   (512a c  - 256a b c  + 32b c)
+--R                *
+--R                    +----------------------------------------------+
+--R                    |                       1                        +-+
+--R                    |---------------------------------------------- \|x
+--R                    |      3 5         2 2 4          4 3       6 2
+--R                   \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                        4 5        3 2 4        2 4 3
+--R                                   4096a c  - 4096a b c  + 1536a b c
+--R                                 + 
+--R                                           6 2      8
+--R                                   - 256a b c  + 16b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                        4 5        3 2 4        2 4 3
+--R                                   4096a c  - 4096a b c  + 1536a b c
+--R                                 + 
+--R                                           6 2      8
+--R                                   - 256a b c  + 16b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              2 3         2 2      4
+--R                                         (256a c  - 128a b c  + 16b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      3 5         2 2 4
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                       4 3       6 2
+--R                                                3072a b c  - 256b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              2 3         2 2      4
+--R                                         (256a c  - 128a b c  + 16b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      3 5         2 2 4
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                       4 3       6 2
+--R                                                3072a b c  - 256b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                            2
+--R                   (4a c - b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                 x
+--R     + 
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           a
+--R                4  |------------------------------------------------------
+--R                  4|     4 5        3 2 4        2 4 3         6 2      8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R             *
+--R                  sin
+--R                       atan
+--R                                   2 3         2 2      4
+--R                              (256a c  - 128a b c  + 16b c)
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                       1
+--R                               |----------------------------------------------
+--R                               |      3 5         2 2 4          4 3       6 2
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           a
+--R                4  |------------------------------------------------------
+--R                  4|     4 5        3 2 4        2 4 3         6 2      8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R             *
+--R                  cos
+--R                       atan
+--R                                   2 3         2 2      4
+--R                              (256a c  - 128a b c  + 16b c)
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                       1
+--R                               |----------------------------------------------
+--R                               |      3 5         2 2 4          4 3       6 2
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    2 3         2 2      4
+--R                               (256a c  - 128a b c  + 16b c)
+--R                            *
+--R                              +----------------------------------------------+
+--R                              |                       1
+--R                              |----------------------------------------------
+--R                              |      3 5         2 2 4          4 3       6 2
+--R                             \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    2 3         2 2      4
+--R                               (256a c  - 128a b c  + 16b c)
+--R                            *
+--R                              +----------------------------------------------+
+--R                              |                       1
+--R                              |----------------------------------------------
+--R                              |      3 5         2 2 4          4 3       6 2
+--R                             \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                         2
+--R                (4a c - b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                         2
+--R                (4a c - b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                     2 3         2 2      4
+--R                (512a c  - 256a b c  + 32b c)
+--R             *
+--R                 +----------------------------------------------+
+--R                 |                       1                        +-+
+--R                 |---------------------------------------------- \|x
+--R                 |      3 5         2 2 4          4 3       6 2
+--R                \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                     4 5        3 2 4        2 4 3         6 2
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                   8
+--R                                16b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          2 3         2 2      4
+--R                                     (256a c  - 128a b c  + 16b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  3 5         2 2 4          4 3
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  6 2
+--R                                            - 256b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                     4 5        3 2 4        2 4 3         6 2
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                   8
+--R                                16b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          2 3         2 2      4
+--R                                     (256a c  - 128a b c  + 16b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  3 5         2 2 4          4 3
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  6 2
+--R                                            - 256b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           2 3         2 2      4
+--R                                      (256a c  - 128a b c  + 16b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   3 5         2 2 4
+--R                                             16384a c  - 12288a b c
+--R                                           + 
+--R                                                    4 3       6 2
+--R                                             3072a b c  - 256b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           2 3         2 2      4
+--R                                      (256a c  - 128a b c  + 16b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   3 5         2 2 4
+--R                                             16384a c  - 12288a b c
+--R                                           + 
+--R                                                    4 3       6 2
+--R                                             3072a b c  - 256b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           a
+--R                   4  |------------------------------------------------------
+--R                     4|     4 5        3 2 4        2 4 3         6 2      8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R                *
+--R                     sin
+--R                          atan
+--R                                      2 3         2 2      4
+--R                                 (256a c  - 128a b c  + 16b c)
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                       1
+--R                                |----------------------------------------------
+--R                                |      3 5         2 2 4          4 3       6 2
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           a
+--R                   4  |------------------------------------------------------
+--R                     4|     4 5        3 2 4        2 4 3         6 2      8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R                *
+--R                     cos
+--R                          atan
+--R                                      2 3         2 2      4
+--R                                 (256a c  - 128a b c  + 16b c)
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                       1
+--R                                |----------------------------------------------
+--R                                |      3 5         2 2 4          4 3       6 2
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       2 3         2 2      4
+--R                                  (256a c  - 128a b c  + 16b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                               3 5         2 2 4          4 3
+--R                                         16384a c  - 12288a b c  + 3072a b c
+--R                                       + 
+--R                                               6 2
+--R                                         - 256b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       2 3         2 2      4
+--R                                  (256a c  - 128a b c  + 16b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                               3 5         2 2 4          4 3
+--R                                         16384a c  - 12288a b c  + 3072a b c
+--R                                       + 
+--R                                               6 2
+--R                                         - 256b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                            2
+--R                   (4a c - b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                            2
+--R                   (4a c - b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                          2 3         2 2      4
+--R                   (- 512a c  + 256a b c  - 32b c)
+--R                *
+--R                    +----------------------------------------------+
+--R                    |                       1                        +-+
+--R                    |---------------------------------------------- \|x
+--R                    |      3 5         2 2 4          4 3       6 2
+--R                   \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                        4 5        3 2 4        2 4 3
+--R                                   4096a c  - 4096a b c  + 1536a b c
+--R                                 + 
+--R                                           6 2      8
+--R                                   - 256a b c  + 16b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                        4 5        3 2 4        2 4 3
+--R                                   4096a c  - 4096a b c  + 1536a b c
+--R                                 + 
+--R                                           6 2      8
+--R                                   - 256a b c  + 16b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              2 3         2 2      4
+--R                                         (256a c  - 128a b c  + 16b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      3 5         2 2 4
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                       4 3       6 2
+--R                                                3072a b c  - 256b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              2 3         2 2      4
+--R                                         (256a c  - 128a b c  + 16b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      3 5         2 2 4
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                       4 3       6 2
+--R                                                3072a b c  - 256b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                 x
+--R     + 
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           a
+--R                4  |------------------------------------------------------
+--R                  4|     4 5        3 2 4        2 4 3         6 2      8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R             *
+--R                  sin
+--R                       atan
+--R                                   2 3         2 2      4
+--R                              (256a c  - 128a b c  + 16b c)
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                       1
+--R                               |----------------------------------------------
+--R                               |      3 5         2 2 4          4 3       6 2
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           a
+--R                4  |------------------------------------------------------
+--R                  4|     4 5        3 2 4        2 4 3         6 2      8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R             *
+--R                  cos
+--R                       atan
+--R                                   2 3         2 2      4
+--R                              (256a c  - 128a b c  + 16b c)
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                       1
+--R                               |----------------------------------------------
+--R                               |      3 5         2 2 4          4 3       6 2
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    2 3         2 2      4
+--R                               (256a c  - 128a b c  + 16b c)
+--R                            *
+--R                              +----------------------------------------------+
+--R                              |                       1
+--R                              |----------------------------------------------
+--R                              |      3 5         2 2 4          4 3       6 2
+--R                             \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    2 3         2 2      4
+--R                               (256a c  - 128a b c  + 16b c)
+--R                            *
+--R                              +----------------------------------------------+
+--R                              |                       1
+--R                              |----------------------------------------------
+--R                              |      3 5         2 2 4          4 3       6 2
+--R                             \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                         2
+--R                (4a c - b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                       2 3         2 2      4
+--R                (- 512a c  + 256a b c  - 32b c)
+--R             *
+--R                 +----------------------------------------------+
+--R                 |                       1                        +-+
+--R                 |---------------------------------------------- \|x
+--R                 |      3 5         2 2 4          4 3       6 2
+--R                \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                     4 5        3 2 4        2 4 3         6 2
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                   8
+--R                                16b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          2 3         2 2      4
+--R                                     (256a c  - 128a b c  + 16b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  3 5         2 2 4          4 3
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  6 2
+--R                                            - 256b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                     4 5        3 2 4        2 4 3         6 2
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                   8
+--R                                16b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          2 3         2 2      4
+--R                                     (256a c  - 128a b c  + 16b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  3 5         2 2 4          4 3
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  6 2
+--R                                            - 256b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           2 3         2 2      4
+--R                                      (256a c  - 128a b c  + 16b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   3 5         2 2 4
+--R                                             16384a c  - 12288a b c
+--R                                           + 
+--R                                                    4 3       6 2
+--R                                             3072a b c  - 256b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           2 3         2 2      4
+--R                                      (256a c  - 128a b c  + 16b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   3 5         2 2 4
+--R                                             16384a c  - 12288a b c
+--R                                           + 
+--R                                                    4 3       6 2
+--R                                             3072a b c  - 256b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                         2
+--R                (4a c - b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           a
+--R                   4  |------------------------------------------------------
+--R                     4|     4 5        3 2 4        2 4 3         6 2      8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R                *
+--R                     sin
+--R                          atan
+--R                                      2 3         2 2      4
+--R                                 (256a c  - 128a b c  + 16b c)
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                       1
+--R                                |----------------------------------------------
+--R                                |      3 5         2 2 4          4 3       6 2
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           a
+--R                   4  |------------------------------------------------------
+--R                     4|     4 5        3 2 4        2 4 3         6 2      8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R                *
+--R                     cos
+--R                          atan
+--R                                      2 3         2 2      4
+--R                                 (256a c  - 128a b c  + 16b c)
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                       1
+--R                                |----------------------------------------------
+--R                                |      3 5         2 2 4          4 3       6 2
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       2 3         2 2      4
+--R                                  (256a c  - 128a b c  + 16b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                               3 5         2 2 4          4 3
+--R                                         16384a c  - 12288a b c  + 3072a b c
+--R                                       + 
+--R                                               6 2
+--R                                         - 256b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       2 3         2 2      4
+--R                                  (256a c  - 128a b c  + 16b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                               3 5         2 2 4          4 3
+--R                                         16384a c  - 12288a b c  + 3072a b c
+--R                                       + 
+--R                                               6 2
+--R                                         - 256b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                        2 3         2 2      4
+--R                   (256a c  - 128a b c  + 16b c)
+--R                *
+--R                    +----------------------------------------------+
+--R                    |                       1
+--R                    |----------------------------------------------
+--R                    |      3 5         2 2 4          4 3       6 2
+--R                   \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                        4 5        3 2 4        2 4 3
+--R                                   4096a c  - 4096a b c  + 1536a b c
+--R                                 + 
+--R                                           6 2      8
+--R                                   - 256a b c  + 16b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                        4 5        3 2 4        2 4 3
+--R                                   4096a c  - 4096a b c  + 1536a b c
+--R                                 + 
+--R                                           6 2      8
+--R                                   - 256a b c  + 16b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              2 3         2 2      4
+--R                                         (256a c  - 128a b c  + 16b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      3 5         2 2 4
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                       4 3       6 2
+--R                                                3072a b c  - 256b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              2 3         2 2      4
+--R                                         (256a c  - 128a b c  + 16b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      3 5         2 2 4
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                       4 3       6 2
+--R                                                3072a b c  - 256b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R              /
+--R                          2 3         2 2      4
+--R                     (256a c  - 128a b c  + 16b c)
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                       1
+--R                      |----------------------------------------------
+--R                      |      3 5         2 2 4          4 3       6 2
+--R                     \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                      +-+
+--R                   - \|x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           a
+--R                4  |------------------------------------------------------
+--R                  4|     4 5        3 2 4        2 4 3         6 2      8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R             *
+--R                  sin
+--R                       atan
+--R                                   2 3         2 2      4
+--R                              (256a c  - 128a b c  + 16b c)
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                       1
+--R                               |----------------------------------------------
+--R                               |      3 5         2 2 4          4 3       6 2
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           a
+--R                4  |------------------------------------------------------
+--R                  4|     4 5        3 2 4        2 4 3         6 2      8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R             *
+--R                  cos
+--R                       atan
+--R                                   2 3         2 2      4
+--R                              (256a c  - 128a b c  + 16b c)
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                       1
+--R                               |----------------------------------------------
+--R                               |      3 5         2 2 4          4 3       6 2
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    2 3         2 2      4
+--R                               (256a c  - 128a b c  + 16b c)
+--R                            *
+--R                              +----------------------------------------------+
+--R                              |                       1
+--R                              |----------------------------------------------
+--R                              |      3 5         2 2 4          4 3       6 2
+--R                             \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    2 3         2 2      4
+--R                               (256a c  - 128a b c  + 16b c)
+--R                            *
+--R                              +----------------------------------------------+
+--R                              |                       1
+--R                              |----------------------------------------------
+--R                              |      3 5         2 2 4          4 3       6 2
+--R                             \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                     2 3         2 2      4
+--R                (256a c  - 128a b c  + 16b c)
+--R             *
+--R                 +----------------------------------------------+
+--R                 |                       1
+--R                 |----------------------------------------------
+--R                 |      3 5         2 2 4          4 3       6 2
+--R                \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                     4 5        3 2 4        2 4 3         6 2
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                   8
+--R                                16b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          2 3         2 2      4
+--R                                     (256a c  - 128a b c  + 16b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  3 5         2 2 4          4 3
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  6 2
+--R                                            - 256b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                     4 5        3 2 4        2 4 3         6 2
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                   8
+--R                                16b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          2 3         2 2      4
+--R                                     (256a c  - 128a b c  + 16b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  3 5         2 2 4          4 3
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  6 2
+--R                                            - 256b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           2 3         2 2      4
+--R                                      (256a c  - 128a b c  + 16b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   3 5         2 2 4
+--R                                             16384a c  - 12288a b c
+--R                                           + 
+--R                                                    4 3       6 2
+--R                                             3072a b c  - 256b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           2 3         2 2      4
+--R                                      (256a c  - 128a b c  + 16b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   3 5         2 2 4
+--R                                             16384a c  - 12288a b c
+--R                                           + 
+--R                                                    4 3       6 2
+--R                                             3072a b c  - 256b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R           /
+--R                       2 3         2 2      4
+--R                  (256a c  - 128a b c  + 16b c)
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                       1
+--R                   |----------------------------------------------
+--R                   |      3 5         2 2 4          4 3       6 2
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                 +-+
+--R                \|x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           a
+--R                4  |------------------------------------------------------
+--R                  4|     4 5        3 2 4        2 4 3         6 2      8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R             *
+--R                  sin
+--R                       atan
+--R                                   2 3         2 2      4
+--R                              (256a c  - 128a b c  + 16b c)
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                       1
+--R                               |----------------------------------------------
+--R                               |      3 5         2 2 4          4 3       6 2
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           a
+--R                4  |------------------------------------------------------
+--R                  4|     4 5        3 2 4        2 4 3         6 2      8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R             *
+--R                  cos
+--R                       atan
+--R                                   2 3         2 2      4
+--R                              (256a c  - 128a b c  + 16b c)
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                       1
+--R                               |----------------------------------------------
+--R                               |      3 5         2 2 4          4 3       6 2
+--R                              \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    2 3         2 2      4
+--R                               (256a c  - 128a b c  + 16b c)
+--R                            *
+--R                              +----------------------------------------------+
+--R                              |                       1
+--R                              |----------------------------------------------
+--R                              |      3 5         2 2 4          4 3       6 2
+--R                             \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    2 3         2 2      4
+--R                               (256a c  - 128a b c  + 16b c)
+--R                            *
+--R                              +----------------------------------------------+
+--R                              |                       1
+--R                              |----------------------------------------------
+--R                              |      3 5         2 2 4          4 3       6 2
+--R                             \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                     2 3         2 2      4
+--R                (256a c  - 128a b c  + 16b c)
+--R             *
+--R                 +----------------------------------------------+
+--R                 |                       1
+--R                 |----------------------------------------------
+--R                 |      3 5         2 2 4          4 3       6 2
+--R                \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                     4 5        3 2 4        2 4 3         6 2
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                   8
+--R                                16b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          2 3         2 2      4
+--R                                     (256a c  - 128a b c  + 16b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  3 5         2 2 4          4 3
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  6 2
+--R                                            - 256b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                     4 5        3 2 4        2 4 3         6 2
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                   8
+--R                                16b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          2 3         2 2      4
+--R                                     (256a c  - 128a b c  + 16b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  3 5         2 2 4          4 3
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  6 2
+--R                                            - 256b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           2 3         2 2      4
+--R                                      (256a c  - 128a b c  + 16b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   3 5         2 2 4
+--R                                             16384a c  - 12288a b c
+--R                                           + 
+--R                                                    4 3       6 2
+--R                                             3072a b c  - 256b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           2 3         2 2      4
+--R                                      (256a c  - 128a b c  + 16b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   3 5         2 2 4
+--R                                             16384a c  - 12288a b c
+--R                                           + 
+--R                                                    4 3       6 2
+--R                                             3072a b c  - 256b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R           /
+--R                       2 3         2 2      4
+--R                  (256a c  - 128a b c  + 16b c)
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                       1
+--R                   |----------------------------------------------
+--R                   |      3 5         2 2 4          4 3       6 2
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                       4 5        3 2 4        2 4 3         6 2
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                     8
+--R                                  16b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            2 3         2 2      4
+--R                                       (256a c  - 128a b c  + 16b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    3 5         2 2 4
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                     4 3       6 2
+--R                                              3072a b c  - 256b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                   +-+
+--R                - \|x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           a
+--R                   4  |------------------------------------------------------
+--R                     4|     4 5        3 2 4        2 4 3         6 2      8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R                *
+--R                     sin
+--R                          atan
+--R                                      2 3         2 2      4
+--R                                 (256a c  - 128a b c  + 16b c)
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                       1
+--R                                |----------------------------------------------
+--R                                |      3 5         2 2 4          4 3       6 2
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           a
+--R                   4  |------------------------------------------------------
+--R                     4|     4 5        3 2 4        2 4 3         6 2      8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c  + 16b c
+--R                *
+--R                     cos
+--R                          atan
+--R                                      2 3         2 2      4
+--R                                 (256a c  - 128a b c  + 16b c)
+--R                              *
+--R                                +----------------------------------------------+
+--R                                |                       1
+--R                                |----------------------------------------------
+--R                                |      3 5         2 2 4          4 3       6 2
+--R                               \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       2 3         2 2      4
+--R                                  (256a c  - 128a b c  + 16b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                               3 5         2 2 4          4 3
+--R                                         16384a c  - 12288a b c  + 3072a b c
+--R                                       + 
+--R                                               6 2
+--R                                         - 256b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       2 3         2 2      4
+--R                                  (256a c  - 128a b c  + 16b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                               3 5         2 2 4          4 3
+--R                                         16384a c  - 12288a b c  + 3072a b c
+--R                                       + 
+--R                                               6 2
+--R                                         - 256b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                        2 3         2 2      4
+--R                   (256a c  - 128a b c  + 16b c)
+--R                *
+--R                    +----------------------------------------------+
+--R                    |                       1
+--R                    |----------------------------------------------
+--R                    |      3 5         2 2 4          4 3       6 2
+--R                   \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                        4 5        3 2 4        2 4 3
+--R                                   4096a c  - 4096a b c  + 1536a b c
+--R                                 + 
+--R                                           6 2      8
+--R                                   - 256a b c  + 16b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                        4 5        3 2 4        2 4 3
+--R                                   4096a c  - 4096a b c  + 1536a b c
+--R                                 + 
+--R                                           6 2      8
+--R                                   - 256a b c  + 16b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             2 3         2 2      4
+--R                                        (256a c  - 128a b c  + 16b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     3 5         2 2 4
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                      4 3       6 2
+--R                                               3072a b c  - 256b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              2 3         2 2      4
+--R                                         (256a c  - 128a b c  + 16b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      3 5         2 2 4
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                       4 3       6 2
+--R                                                3072a b c  - 256b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              2 3         2 2      4
+--R                                         (256a c  - 128a b c  + 16b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      3 5         2 2 4
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                       4 3       6 2
+--R                                                3072a b c  - 256b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R              /
+--R                          2 3         2 2      4
+--R                     (256a c  - 128a b c  + 16b c)
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                       1
+--R                      |----------------------------------------------
+--R                      |      3 5         2 2 4          4 3       6 2
+--R                     \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                          4 5        3 2 4        2 4 3
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                             6 2      8
+--R                                     - 256a b c  + 16b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               2 3         2 2      4
+--R                                          (256a c  - 128a b c  + 16b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       3 5         2 2 4
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                        4 3       6 2
+--R                                                 3072a b c  - 256b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                2 3         2 2      4
+--R                                           (256a c  - 128a b c  + 16b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        3 5         2 2 4
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                         4 3       6 2
+--R                                                  3072a b c  - 256b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                    +-+
+--R                   \|x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 602
+
+--S 603 of 1057
+--m0:=a0-r0
+--E 603
+
+--S 604 of 1057
+--d0:=D(m0,x)
+--E 604
+
+)clear all
+
+--S 605 of 1057
+t0:=x^(1/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               +-+
+--R              \|x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 1057
+r0:=-2^(1/4)*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))/((-b-sqrt(b^2-4*a*c))^(1/4)*sqrt(b^2-4*a*c))+2^(1/4)*_
+   c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))/_
+   ((-b-sqrt(b^2-4*a*c))^(1/4)*sqrt(b^2-4*a*c))+2^(1/4)*c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))/(sqrt(b^2-_
+   4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))-2^(1/4)*c^(1/4)*atanh(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))/(sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                +------------------+
+--R                | +-----------+                 4+-+4+-+ +-+
+--R       4+-+4+-+4| |          2                  \|2 \|c \|x
+--R       \|2 \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                  +--------------------+
+--R                  |   +-----------+                4+-+4+-+ +-+
+--R         4+-+4+-+4|   |          2                 \|2 \|c \|x
+--R       - \|2 \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                               +------------------+
+--R                                               | +-----------+
+--R                                              4| |          2
+--R                                              \|\|- 4a c + b   - b
+--R     + 
+--R                  +------------------+
+--R                  | +-----------+                4+-+4+-+ +-+
+--R         4+-+4+-+4| |          2                 \|2 \|c \|x
+--R       - \|2 \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                +--------------------+
+--R                |   +-----------+               4+-+4+-+ +-+
+--R       4+-+4+-+4|   |          2                \|2 \|c \|x
+--R       \|2 \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                            +------------------+
+--R                                            | +-----------+
+--R                                           4| |          2
+--R                                           \|\|- 4a c + b   - b
+--R  /
+--R                    +--------------------+ +------------------+
+--R      +-----------+ |   +-----------+      | +-----------+
+--R      |          2 4|   |          2      4| |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     sin
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     cos
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                             4   3        3 3 2       2 5         7
+--R                       (2048a b c  - 1536a b c  + 384a b c - 32a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                      1
+--R                        |---------------------------------------------
+--R                        |      5 3         4 2 2        3 4        2 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       sin
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                             2 2        2      4
+--R                       (- 32a c  + 16a b c - 2b )
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       cos
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                             2 2        2      4
+--R                       (- 32a c  + 16a b c - 2b )
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       sin
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                               4   3        3 3 2       2 5         7
+--R                       (- 2048a b c  + 1536a b c  - 384a b c + 32a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                      1
+--R                        |---------------------------------------------
+--R                        |      5 3         4 2 2        3 4        2 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       cos
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                 c x
+--R     + 
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  sin
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  cos
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                        2 2        2      4
+--R                    (32a c  - 16a b c + 2b )
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    sin
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                          4   3        3 3 2       2 5         7
+--R                    (2048a b c  - 1536a b c  + 384a b c - 32a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                      1
+--R                     |---------------------------------------------
+--R                     |      5 3         4 2 2        3 4        2 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    cos
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                          4   3        3 3 2       2 5         7
+--R                    (2048a b c  - 1536a b c  + 384a b c - 32a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                      1
+--R                     |---------------------------------------------
+--R                     |      5 3         4 2 2        3 4        2 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    sin
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                          2 2        2      4
+--R                    (- 32a c  + 16a b c - 2b )
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    cos
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R              c x
+--R     + 
+--R       -
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     sin
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     cos
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                             2 2        2      4
+--R                       (- 32a c  + 16a b c - 2b )
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       sin
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                               4   3        3 3 2       2 5         7
+--R                       (- 2048a b c  + 1536a b c  - 384a b c + 32a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                      1
+--R                        |---------------------------------------------
+--R                        |      5 3         4 2 2        3 4        2 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       cos
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                               4   3        3 3 2       2 5         7
+--R                       (- 2048a b c  + 1536a b c  - 384a b c + 32a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                      1
+--R                        |---------------------------------------------
+--R                        |      5 3         4 2 2        3 4        2 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       sin
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                           2 2        2      4
+--R                       (32a c  - 16a b c + 2b )
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       cos
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                 c x
+--R     + 
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  sin
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  cos
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                            4   3        3 3 2       2 5         7
+--R                    (- 2048a b c  + 1536a b c  - 384a b c + 32a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                      1
+--R                     |---------------------------------------------
+--R                     |      5 3         4 2 2        3 4        2 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    sin
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                        2 2        2      4
+--R                    (32a c  - 16a b c + 2b )
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    cos
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                        2 2        2      4
+--R                    (32a c  - 16a b c + 2b )
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    sin
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                          4   3        3 3 2       2 5         7
+--R                    (2048a b c  - 1536a b c  + 384a b c - 32a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                      1
+--R                     |---------------------------------------------
+--R                     |      5 3         4 2 2        3 4        2 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    cos
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R              c x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  sin
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  cos
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                              4   3       3 3 2       2 5         7
+--R                      (- 1024a b c  + 768a b c  - 192a b c + 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R           /
+--R                          2 2       2     4
+--R                      (16a c  - 8a b c + b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                    +-+
+--R                - c\|x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     sin
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     cos
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                 4   3       3 3 2       2 5         7
+--R                         (- 1024a b c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R              /
+--R                             2 2       2     4
+--R                         (16a c  - 8a b c + b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                     +-+
+--R                   c\|x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     sin
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     cos
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                             2 2       2     4
+--R                         (16a c  - 8a b c + b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R              /
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                 4   3       3 3 2       2 5         7
+--R                         (- 1024a b c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                       +-+
+--R                   - c\|x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  sin
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  cos
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                          2 2       2     4
+--R                      (16a c  - 8a b c + b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R           /
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                              4   3       3 3 2       2 5         7
+--R                      (- 1024a b c  + 768a b c  - 192a b c + 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                  +-+
+--R                c\|x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 607
+
+--S 608 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R             |          2 4|   |          2      4| |          2
+--R            \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     sin
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     cos
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                             4   3        3 3 2       2 5         7
+--R                       (2048a b c  - 1536a b c  + 384a b c - 32a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                      1
+--R                        |---------------------------------------------
+--R                        |      5 3         4 2 2        3 4        2 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       sin
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                             2 2        2      4
+--R                       (- 32a c  + 16a b c - 2b )
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       cos
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                             2 2        2      4
+--R                       (- 32a c  + 16a b c - 2b )
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       sin
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                               4   3        3 3 2       2 5         7
+--R                       (- 2048a b c  + 1536a b c  - 384a b c + 32a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                      1
+--R                        |---------------------------------------------
+--R                        |      5 3         4 2 2        3 4        2 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       cos
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                 c x
+--R     + 
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2 4|   |          2      4| |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  sin
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  cos
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                        2 2        2      4
+--R                    (32a c  - 16a b c + 2b )
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    sin
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                          4   3        3 3 2       2 5         7
+--R                    (2048a b c  - 1536a b c  + 384a b c - 32a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                      1
+--R                     |---------------------------------------------
+--R                     |      5 3         4 2 2        3 4        2 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    cos
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                          4   3        3 3 2       2 5         7
+--R                    (2048a b c  - 1536a b c  + 384a b c - 32a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                      1
+--R                     |---------------------------------------------
+--R                     |      5 3         4 2 2        3 4        2 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    sin
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                          2 2        2      4
+--R                    (- 32a c  + 16a b c - 2b )
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    cos
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R              c x
+--R     + 
+--R       -
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R             |          2 4|   |          2      4| |          2
+--R            \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     sin
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     cos
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                             2 2        2      4
+--R                       (- 32a c  + 16a b c - 2b )
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       sin
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                               4   3        3 3 2       2 5         7
+--R                       (- 2048a b c  + 1536a b c  - 384a b c + 32a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                      1
+--R                        |---------------------------------------------
+--R                        |      5 3         4 2 2        3 4        2 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       cos
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                            4 3       3 2 2      2 4        6
+--R                       (256a c  - 192a b c  + 48a b c - 4a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                               4   3        3 3 2       2 5         7
+--R                       (- 2048a b c  + 1536a b c  - 384a b c + 32a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                      1
+--R                        |---------------------------------------------
+--R                        |      5 3         4 2 2        3 4        2 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       sin
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                           2 2        2      4
+--R                       (32a c  - 16a b c + 2b )
+--R                    *
+--R                        +------------------------------------------------------+
+--R                        |                           c
+--R                        |------------------------------------------------------
+--R                       4|     5 4        4 2 3        3 4 2       2 6         8
+--R                       \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                    *
+--R                        +-+
+--R                       \|x
+--R                    *
+--R                       cos
+--R                            atan
+--R                                        3 2       2 2         4
+--R                                   (256a c  - 128a b c + 16a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                5 3         4 2 2        3 4
+--R                                          16384a c  - 12288a b c  + 3072a b c
+--R                                        + 
+--R                                                2 6
+--R                                          - 256a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                        5 4        4 2 3        3 4 2       2 6
+--R                                   4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                 + 
+--R                                        8
+--R                                   16a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                              3 2       2 2         4
+--R                                         (256a c  - 128a b c + 16a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                      5 3         4 2 2
+--R                                                16384a c  - 12288a b c
+--R                                              + 
+--R                                                     3 4        2 6
+--R                                                3072a b c - 256a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                 c x
+--R     + 
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2 4|   |          2      4| |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  sin
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  cos
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                            4   3        3 3 2       2 5         7
+--R                    (- 2048a b c  + 1536a b c  - 384a b c + 32a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                      1
+--R                     |---------------------------------------------
+--R                     |      5 3         4 2 2        3 4        2 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    sin
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                        2 2        2      4
+--R                    (32a c  - 16a b c + 2b )
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    cos
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                         4 3       3 2 2      2 4        6
+--R                    (256a c  - 192a b c  + 48a b c - 4a b )
+--R                 *
+--R                     +------------------------------------------------------+2
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                        2 2        2      4
+--R                    (32a c  - 16a b c + 2b )
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    sin
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                          4   3        3 3 2       2 5         7
+--R                    (2048a b c  - 1536a b c  + 384a b c - 32a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                      1
+--R                     |---------------------------------------------
+--R                     |      5 3         4 2 2        3 4        2 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                           c
+--R                     |------------------------------------------------------
+--R                    4|     5 4        4 2 3        3 4 2       2 6         8
+--R                    \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                 *
+--R                     +-+
+--R                    \|x
+--R                 *
+--R                    cos
+--R                         atan
+--R                                     3 2       2 2         4
+--R                                (256a c  - 128a b c + 16a b )
+--R                             *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                           3 2       2 2         4
+--R                                      (256a c  - 128a b c + 16a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                   5 3         4 2 2        3 4
+--R                                             16384a c  - 12288a b c  + 3072a b c
+--R                                           + 
+--R                                                   2 6
+--R                                             - 256a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R              c x
+--R     + 
+--R                         +--------------------+ +------------------+
+--R           +-----------+ |   +-----------+      | +-----------+
+--R           |          2 4|   |          2      4| |          2
+--R         2\|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  sin
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  cos
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                              4   3       3 3 2       2 5         7
+--R                      (- 1024a b c  + 768a b c  - 192a b c + 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R           /
+--R                          2 2       2     4
+--R                      (16a c  - 8a b c + b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                    +-+
+--R                - c\|x
+--R     + 
+--R       -
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R              |          2 4|   |          2      4| |          2
+--R            2\|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     sin
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     cos
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                 4   3       3 3 2       2 5         7
+--R                         (- 1024a b c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R              /
+--R                             2 2       2     4
+--R                         (16a c  - 8a b c + b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                     +-+
+--R                   c\|x
+--R     + 
+--R       -
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R              |          2 4|   |          2      4| |          2
+--R            2\|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     sin
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                      +------------------------------------------------------+2
+--R                      |                           c
+--R                   4  |------------------------------------------------------
+--R                     4|     5 4        4 2 3        3 4 2       2 6         8
+--R                     \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                *
+--R                     cos
+--R                          atan
+--R                                      3 2       2 2         4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                             2 2       2     4
+--R                         (16a c  - 8a b c + b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R              /
+--R                               4   3       3 3 2       2 5         7
+--R                         (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               2 2       2     4
+--R                         (- 16a c  + 8a b c - b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                 4   3       3 3 2       2 5         7
+--R                         (- 1024a b c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                      1
+--R                          |---------------------------------------------
+--R                          |      5 3         4 2 2        3 4        2 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                     5 4        4 2 3        3 4 2       2 6
+--R                                4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                              + 
+--R                                     8
+--R                                16a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                          3 2       2 2         4
+--R                                     (256a c  - 128a b c + 16a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                  5 3         4 2 2        3 4
+--R                                            16384a c  - 12288a b c  + 3072a b c
+--R                                          + 
+--R                                                  2 6
+--R                                            - 256a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                          5 4        4 2 3        3 4 2
+--R                                     4096a c  - 4096a b c  + 1536a b c
+--R                                   + 
+--R                                           2 6         8
+--R                                     - 256a b c + 16a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                               3 2       2 2         4
+--R                                          (256a c  - 128a b c + 16a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                       5 3         4 2 2
+--R                                                 16384a c  - 12288a b c
+--R                                               + 
+--R                                                      3 4        2 6
+--R                                                 3072a b c - 256a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                3 2       2 2         4
+--R                                           (256a c  - 128a b c + 16a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                        5 3         4 2 2
+--R                                                  16384a c  - 12288a b c
+--R                                                + 
+--R                                                       3 4        2 6
+--R                                                  3072a b c - 256a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                       +-+
+--R                   - c\|x
+--R     + 
+--R                         +--------------------+ +------------------+
+--R           +-----------+ |   +-----------+      | +-----------+
+--R           |          2 4|   |          2      4| |          2
+--R         2\|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  sin
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                   +------------------------------------------------------+2
+--R                   |                           c
+--R                4  |------------------------------------------------------
+--R                  4|     5 4        4 2 3        3 4 2       2 6         8
+--R                  \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R             *
+--R                  cos
+--R                       atan
+--R                                   3 2       2 2         4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                      1
+--R                               |---------------------------------------------
+--R                               |      5 3         4 2 2        3 4        2 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                    3 2       2 2         4
+--R                               (256a c  - 128a b c + 16a b )
+--R                            *
+--R                                +---------------------------------------------+
+--R                                |                      1
+--R                                |---------------------------------------------
+--R                                |      5 3         4 2 2        3 4        2 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                          2 2       2     4
+--R                      (16a c  - 8a b c + b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R           /
+--R                            4   3       3 3 2       2 5         7
+--R                      (1024a b c  - 768a b c  + 192a b c - 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            2 2       2     4
+--R                      (- 16a c  + 8a b c - b )
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      sin
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                              4   3       3 3 2       2 5         7
+--R                      (- 1024a b c  + 768a b c  - 192a b c + 16a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                      1
+--R                       |---------------------------------------------
+--R                       |      5 3         4 2 2        3 4        2 6
+--R                      \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   *
+--R                       +------------------------------------------------------+
+--R                       |                           c
+--R                       |------------------------------------------------------
+--R                      4|     5 4        4 2 3        3 4 2       2 6         8
+--R                      \|4096a c  - 4096a b c  + 1536a b c  - 256a b c + 16a b
+--R                   *
+--R                      cos
+--R                           atan
+--R                                       3 2       2 2         4
+--R                                  (256a c  - 128a b c + 16a b )
+--R                               *
+--R                                 +---------------------------------------------+
+--R                                 |                      1
+--R                                 |---------------------------------------------
+--R                                 |      5 3         4 2 2        3 4        2 6
+--R                                \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                       5 4        4 2 3        3 4 2       2 6
+--R                                  4096a c  - 4096a b c  + 1536a b c  - 256a b c
+--R                                + 
+--R                                       8
+--R                                  16a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                            3 2       2 2         4
+--R                                       (256a c  - 128a b c + 16a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                    5 3         4 2 2
+--R                                              16384a c  - 12288a b c
+--R                                            + 
+--R                                                   3 4        2 6
+--R                                              3072a b c - 256a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                             3 2       2 2         4
+--R                                        (256a c  - 128a b c + 16a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                     5 3         4 2 2
+--R                                               16384a c  - 12288a b c
+--R                                             + 
+--R                                                    3 4        2 6
+--R                                               3072a b c - 256a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                  +-+
+--R                c\|x
+--R     + 
+--R                   +------------------+
+--R                   | +-----------+                 4+-+4+-+ +-+
+--R          4+-+4+-+4| |          2                  \|2 \|c \|x
+--R       - 2\|2 \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                              +--------------------+
+--R                                              |   +-----------+
+--R                                             4|   |          2
+--R                                             \|- \|- 4a c + b   - b
+--R     + 
+--R                 +--------------------+
+--R                 |   +-----------+                4+-+4+-+ +-+
+--R        4+-+4+-+4|   |          2                 \|2 \|c \|x
+--R       2\|2 \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                 +------------------+
+--R                 | +-----------+                4+-+4+-+ +-+
+--R        4+-+4+-+4| |          2                 \|2 \|c \|x
+--R       2\|2 \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                   +--------------------+
+--R                   |   +-----------+               4+-+4+-+ +-+
+--R          4+-+4+-+4|   |          2                \|2 \|c \|x
+--R       - 2\|2 \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                               +------------------+
+--R                                               | +-----------+
+--R                                              4| |          2
+--R                                              \|\|- 4a c + b   - b
+--R  /
+--R                     +--------------------+ +------------------+
+--R       +-----------+ |   +-----------+      | +-----------+
+--R       |          2 4|   |          2      4| |          2
+--R     2\|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 1057
+--d0:=D(m0,x)
+--E 609
+
+)clear all
+
+--S 610 of 1057
+t0:=1/(x^(1/2)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R            4      2      +-+
+--R        (c x  + b x  + a)\|x
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 1057
+r0:=2^(3/4)*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))/((-b-sqrt(b^2-4*a*c))^(3/4)*sqrt(b^2-4*a*c))+2^(3/4)*_
+   c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))/_
+   ((-b-sqrt(b^2-4*a*c))^(3/4)*sqrt(b^2-4*a*c))-2^(3/4)*c^(3/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))/_
+   (sqrt(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))-2^(3/4)*c^(3/4)*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))/_
+   (sqrt(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                    +------------------+3
+--R                    | +-----------+                  4+-+4+-+ +-+
+--R       4+-+3 4+-+3 4| |          2                   \|2 \|c \|x
+--R       \|2   \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                                +--------------------+
+--R                                                |   +-----------+
+--R                                               4|   |          2
+--R                                               \|- \|- 4a c + b   - b
+--R     + 
+--R                      +--------------------+3
+--R                      |   +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4+-+3 4|   |          2                  \|2 \|c \|x
+--R       - \|2   \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                                    +------------------+
+--R                                                    | +-----------+
+--R                                                   4| |          2
+--R                                                   \|\|- 4a c + b   - b
+--R     + 
+--R                    +------------------+3
+--R                    | +-----------+                 4+-+4+-+ +-+
+--R       4+-+3 4+-+3 4| |          2                  \|2 \|c \|x
+--R       \|2   \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                               +--------------------+
+--R                                               |   +-----------+
+--R                                              4|   |          2
+--R                                              \|- \|- 4a c + b   - b
+--R     + 
+--R                      +--------------------+3
+--R                      |   +-----------+                4+-+4+-+ +-+
+--R         4+-+3 4+-+3 4|   |          2                 \|2 \|c \|x
+--R       - \|2   \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                                   +------------------+
+--R                                                   | +-----------+
+--R                                                  4| |          2
+--R                                                  \|\|- 4a c + b   - b
+--R  /
+--R                    +--------------------+3  +------------------+3
+--R      +-----------+ |   +-----------+        | +-----------+
+--R      |          2 4|   |          2        4| |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            5 2       4 2       3 4
+--R                       (256a c  - 128a b c + 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       5 2      4 2      3 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                         5   2       4 3       3 5
+--R                    (256a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                    2 2       2     4
+--R                  4a c  - 5a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   5 2       4 2       3 4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |---------------------------------------------
+--R                               |      9 3         8 2 2        7 4        6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              5 2      4 2      3 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                   2     2   +-+
+--R              (2a c  - 2b c)\|x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 5 2       4 2       3 4
+--R                          (- 256a c  + 128a b c - 16a b )
+--R                       *
+--R                           +---------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |---------------------------------------------
+--R                           |      9 3         8 2 2        7 4        6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          5 2      4 2      3 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                            5   2       4 3       3 5
+--R                       (256a b c  - 128a b c + 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                         2 2       2     4
+--R                     - 4a c  + 5a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        5 2       4 2       3 4
+--R                                 (- 256a c  + 128a b c - 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |---------------------------------------------
+--R                                |      9 3         8 2 2        7 4        6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 5 2      4 2      3 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                      2     2   +-+
+--R                 (2a c  - 2b c)\|x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              5 2       4 2       3 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       5 2      4 2      3 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                           5   2       4 3       3 5
+--R                    (- 256a b c  + 128a b c - 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                    2 2       2     4
+--R                  4a c  - 5a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     5 2       4 2       3 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |---------------------------------------------
+--R                               |      9 3         8 2 2        7 4        6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              5 2      4 2      3 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                   2     2   +-+
+--R              (2a c  - 2b c)\|x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               5 2       4 2       3 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                           +---------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |---------------------------------------------
+--R                           |      9 3         8 2 2        7 4        6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          5 2      4 2      3 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                              5   2       4 3       3 5
+--R                       (- 256a b c  + 128a b c - 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                         2 2       2     4
+--R                     - 4a c  + 5a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      5 2       4 2       3 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |---------------------------------------------
+--R                                |      9 3         8 2 2        7 4        6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 5 2      4 2      3 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                      2     2   +-+
+--R                 (2a c  - 2b c)\|x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               5 2       4 2       3 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                           +---------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |---------------------------------------------
+--R                           |      9 3         8 2 2        7 4        6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          5 2      4 2      3 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            atan
+--R                            5   2       4 3       3 5
+--R                       (256a b c  - 128a b c + 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                       2 2       2     4
+--R                     4a c  - 5a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      5 2       4 2       3 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |---------------------------------------------
+--R                                |      9 3         8 2 2        7 4        6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 5 2      4 2      3 4
+--R                             128a c  - 64a b c + 8a b
+--R              /
+--R                      2     2   +-+
+--R                 (2a c  - 2b c)\|x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              5 2       4 2       3 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       5 2      4 2      3 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         atan
+--R                         5   2       4 3       3 5
+--R                    (256a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      2 2       2     4
+--R                  - 4a c  + 5a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     5 2       4 2       3 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |---------------------------------------------
+--R                               |      9 3         8 2 2        7 4        6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              5 2      4 2      3 4
+--R                          128a c  - 64a b c + 8a b
+--R           /
+--R                   2     2   +-+
+--R              (2a c  - 2b c)\|x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 612
+
+--S 613 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        +--------------------+3  +------------------+3
+--R          +-----------+ |   +-----------+        | +-----------+
+--R          |          2 4|   |          2        4| |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            5 2       4 2       3 4
+--R                       (256a c  - 128a b c + 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       5 2      4 2      3 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                         5   2       4 3       3 5
+--R                    (256a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                    2 2       2     4
+--R                  4a c  - 5a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   5 2       4 2       3 4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |---------------------------------------------
+--R                               |      9 3         8 2 2        7 4        6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              5 2      4 2      3 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                   2     2   +-+
+--R              (2a c  - 2b c)\|x
+--R     + 
+--R       -
+--R                           +--------------------+3  +------------------+3
+--R             +-----------+ |   +-----------+        | +-----------+
+--R             |          2 4|   |          2        4| |          2
+--R            \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 5 2       4 2       3 4
+--R                          (- 256a c  + 128a b c - 16a b )
+--R                       *
+--R                           +---------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |---------------------------------------------
+--R                           |      9 3         8 2 2        7 4        6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          5 2      4 2      3 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                            5   2       4 3       3 5
+--R                       (256a b c  - 128a b c + 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                         2 2       2     4
+--R                     - 4a c  + 5a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        5 2       4 2       3 4
+--R                                 (- 256a c  + 128a b c - 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |---------------------------------------------
+--R                                |      9 3         8 2 2        7 4        6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 5 2      4 2      3 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                      2     2   +-+
+--R                 (2a c  - 2b c)\|x
+--R     + 
+--R                        +--------------------+3  +------------------+3
+--R          +-----------+ |   +-----------+        | +-----------+
+--R          |          2 4|   |          2        4| |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              5 2       4 2       3 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       5 2      4 2      3 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                           5   2       4 3       3 5
+--R                    (- 256a b c  + 128a b c - 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                    2 2       2     4
+--R                  4a c  - 5a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     5 2       4 2       3 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |---------------------------------------------
+--R                               |      9 3         8 2 2        7 4        6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              5 2      4 2      3 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                   2     2   +-+
+--R              (2a c  - 2b c)\|x
+--R     + 
+--R       -
+--R                           +--------------------+3  +------------------+3
+--R             +-----------+ |   +-----------+        | +-----------+
+--R             |          2 4|   |          2        4| |          2
+--R            \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               5 2       4 2       3 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                           +---------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |---------------------------------------------
+--R                           |      9 3         8 2 2        7 4        6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          5 2      4 2      3 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                              5   2       4 3       3 5
+--R                       (- 256a b c  + 128a b c - 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                         2 2       2     4
+--R                     - 4a c  + 5a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      5 2       4 2       3 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |---------------------------------------------
+--R                                |      9 3         8 2 2        7 4        6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 5 2      4 2      3 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                      2     2   +-+
+--R                 (2a c  - 2b c)\|x
+--R     + 
+--R       -
+--R                            +--------------------+3  +------------------+3
+--R              +-----------+ |   +-----------+        | +-----------+
+--R              |          2 4|   |          2        4| |          2
+--R            2\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               5 2       4 2       3 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                           +---------------------------------------------+
+--R                           |                2 2       2     4
+--R                           |             - a c  + 2a b c - b
+--R                           |---------------------------------------------
+--R                           |      9 3         8 2 2        7 4        6 6
+--R                          \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                          5 2      4 2      3 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            atan
+--R                            5   2       4 3       3 5
+--R                       (256a b c  - 128a b c + 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                       2 2       2     4
+--R                     4a c  - 5a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      5 2       4 2       3 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                +---------------------------------------------+
+--R                                |                2 2       2     4
+--R                                |             - a c  + 2a b c - b
+--R                                |---------------------------------------------
+--R                                |      9 3         8 2 2        7 4        6 6
+--R                               \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                 5 2      4 2      3 4
+--R                             128a c  - 64a b c + 8a b
+--R              /
+--R                      2     2   +-+
+--R                 (2a c  - 2b c)\|x
+--R     + 
+--R                         +--------------------+3  +------------------+3
+--R           +-----------+ |   +-----------+        | +-----------+
+--R           |          2 4|   |          2        4| |          2
+--R         2\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              5 2       4 2       3 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |             - a c  + 2a b c - b
+--R                        |---------------------------------------------
+--R                        |      9 3         8 2 2        7 4        6 6
+--R                       \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                       5 2      4 2      3 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         atan
+--R                         5   2       4 3       3 5
+--R                    (256a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |             - a c  + 2a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      2 2       2     4
+--R                  - 4a c  + 5a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     5 2       4 2       3 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |             - a c  + 2a b c - b
+--R                               |---------------------------------------------
+--R                               |      9 3         8 2 2        7 4        6 6
+--R                              \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                              5 2      4 2      3 4
+--R                          128a c  - 64a b c + 8a b
+--R           /
+--R                   2     2   +-+
+--R              (2a c  - 2b c)\|x
+--R     + 
+--R                       +------------------+3
+--R                       | +-----------+                  4+-+4+-+ +-+
+--R          4+-+3 4+-+3 4| |          2                   \|2 \|c \|x
+--R       - 2\|2   \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                                   +--------------------+
+--R                                                   |   +-----------+
+--R                                                  4|   |          2
+--R                                                  \|- \|- 4a c + b   - b
+--R     + 
+--R                     +--------------------+3
+--R                     |   +-----------+                 4+-+4+-+ +-+
+--R        4+-+3 4+-+3 4|   |          2                  \|2 \|c \|x
+--R       2\|2   \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                                   +------------------+
+--R                                                   | +-----------+
+--R                                                  4| |          2
+--R                                                  \|\|- 4a c + b   - b
+--R     + 
+--R                       +------------------+3
+--R                       | +-----------+                 4+-+4+-+ +-+
+--R          4+-+3 4+-+3 4| |          2                  \|2 \|c \|x
+--R       - 2\|2   \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                                  +--------------------+
+--R                                                  |   +-----------+
+--R                                                 4|   |          2
+--R                                                 \|- \|- 4a c + b   - b
+--R     + 
+--R                     +--------------------+3
+--R                     |   +-----------+                4+-+4+-+ +-+
+--R        4+-+3 4+-+3 4|   |          2                 \|2 \|c \|x
+--R       2\|2   \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                                  +------------------+
+--R                                                  | +-----------+
+--R                                                 4| |          2
+--R                                                 \|\|- 4a c + b   - b
+--R  /
+--R                     +--------------------+3  +------------------+3
+--R       +-----------+ |   +-----------+        | +-----------+
+--R       |          2 4|   |          2        4| |          2
+--R     2\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 614
+
+)clear all
+
+--S 615 of 1057
+t0:=1/(x^(3/2)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R            5      3        +-+
+--R        (c x  + b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 1057
+r0:=-c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (1-b/sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b-sqrt(b^2-4*a*c))^(1/4))+c^(1/4)*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (1-b/sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b-sqrt(b^2-4*a*c))^(1/4))-c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/_
+   sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b+sqrt(b^2-4*a*c))^(1/4))+c^(1/4)*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/_
+   sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b+sqrt(b^2-4*a*c))^(1/4))+(-2)/(a*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                                      +------------------+
+--R           +-----------+              | +-----------+
+--R           |          2      4+-+ +-+4| |          2
+--R         (\|- 4a c + b   - b)\|c \|x \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                      +--------------------+
+--R           +-----------+              |   +-----------+
+--R           |          2      4+-+ +-+4|   |          2
+--R         (\|- 4a c + b   + b)\|c \|x \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                        +------------------+
+--R             +-----------+              | +-----------+
+--R             |          2      4+-+ +-+4| |          2
+--R         (- \|- 4a c + b   + b)\|c \|x \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+
+--R             +-----------+              |   +-----------+
+--R             |          2      4+-+ +-+4|   |          2
+--R         (- \|- 4a c + b   - b)\|c \|x \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R       - 2\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       4+-+3 |          2  +-+4|   |          2      4| |          2
+--R     a \|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R              +-+
+--R            a\|x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               7 2       6 2       5 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          7 2      6 2      5 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                              10 5        9 2 4        8 4 3        7 6 2
+--R                         2048a  c  - 5632a b c  + 4480a b c  - 1568a b c
+--R                       + 
+--R                             6 8       5 10
+--R                         256a b c - 16a b
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                      5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                   32a b c  - 128a b c  + 138a b c  - 63a b c  + 13a b c - b
+--R                *
+--R                   ROOT
+--R                                 7 2       6 2       5 4
+--R                            (256a c  - 128a b c + 16a b )
+--R                         *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                            7 2      6 2      5 4
+--R                        128a c  - 64a b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      7 2       6 2       5 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              13 3         12 2 2        11 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              10 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 7 2      6 2      5 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                   2 6       2 5    4 4  +-+
+--R                 (a c  - 3a b c  + b c )\|x
+--R     + 
+--R           +-+
+--R         a\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              7 2       6 2       5 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       7 2      6 2      5 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                           10 5        9 2 4        8 4 3        7 6 2
+--R                      2048a  c  - 5632a b c  + 4480a b c  - 1568a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      256a b c - 16a b
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |       4 4     3 2 3      2 4 2       6     8
+--R                     |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                  - 32a b c  + 128a b c  - 138a b c  + 63a b c  - 13a b c + b
+--R             *
+--R                ROOT
+--R                                7 2       6 2       5 4
+--R                         (- 256a c  + 128a b c - 16a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |       4 4     3 2 3      2 4 2       6     8
+--R                          |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                         7 2      6 2      5 4
+--R                     128a c  - 64a b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     7 2       6 2       5 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                             +-------------------------------------------------+
+--R                             |       4 4     3 2 3      2 4 2       6     8
+--R                             |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-------------------------------------------------
+--R                             |      13 3         12 2 2        11 4        10 6
+--R                            \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              7 2      6 2      5 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                2 6       2 5    4 4  +-+
+--R              (a c  - 3a b c  + b c )\|x
+--R     + 
+--R       -
+--R              +-+
+--R            a\|x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 7 2       6 2       5 4
+--R                          (- 256a c  + 128a b c - 16a b )
+--R                       *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          7 2      6 2      5 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                                10 5        9 2 4        8 4 3        7 6 2
+--R                         - 2048a  c  + 5632a b c  - 4480a b c  + 1568a b c
+--R                       + 
+--R                               6 8       5 10
+--R                         - 256a b c + 16a b
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                      5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                   32a b c  - 128a b c  + 138a b c  - 63a b c  + 13a b c - b
+--R                *
+--R                   ROOT
+--R                                   7 2       6 2       5 4
+--R                            (- 256a c  + 128a b c - 16a b )
+--R                         *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                            7 2      6 2      5 4
+--R                        128a c  - 64a b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        7 2       6 2       5 4
+--R                                 (- 256a c  + 128a b c - 16a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              13 3         12 2 2        11 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              10 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 7 2      6 2      5 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                   2 6       2 5    4 4  +-+
+--R                 (a c  - 3a b c  + b c )\|x
+--R     + 
+--R           +-+
+--R         a\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            7 2       6 2       5 4
+--R                       (256a c  - 128a b c + 16a b )
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       7 2      6 2      5 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                             10 5        9 2 4        8 4 3        7 6 2
+--R                      - 2048a  c  + 5632a b c  - 4480a b c  + 1568a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 256a b c + 16a b
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |       4 4     3 2 3      2 4 2       6     8
+--R                     |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                  - 32a b c  + 128a b c  - 138a b c  + 63a b c  - 13a b c + b
+--R             *
+--R                ROOT
+--R                              7 2       6 2       5 4
+--R                         (256a c  - 128a b c + 16a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |       4 4     3 2 3      2 4 2       6     8
+--R                          |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                         7 2      6 2      5 4
+--R                     128a c  - 64a b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   7 2       6 2       5 4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                             +-------------------------------------------------+
+--R                             |       4 4     3 2 3      2 4 2       6     8
+--R                             |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-------------------------------------------------
+--R                             |      13 3         12 2 2        11 4        10 6
+--R                            \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              7 2      6 2      5 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                2 6       2 5    4 4  +-+
+--R              (a c  - 3a b c  + b c )\|x
+--R     + 
+--R       -
+--R               +-+
+--R            2a\|x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               7 2       6 2       5 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          7 2      6 2      5 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            atan
+--R                              10 5        9 2 4        8 4 3        7 6 2
+--R                         2048a  c  - 5632a b c  + 4480a b c  - 1568a b c
+--R                       + 
+--R                             6 8       5 10
+--R                         256a b c - 16a b
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                      5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                   32a b c  - 128a b c  + 138a b c  - 63a b c  + 13a b c - b
+--R                *
+--R                   ROOT
+--R                                 7 2       6 2       5 4
+--R                            (256a c  - 128a b c + 16a b )
+--R                         *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                            7 2      6 2      5 4
+--R                        128a c  - 64a b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      7 2       6 2       5 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              13 3         12 2 2        11 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              10 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 7 2      6 2      5 4
+--R                             128a c  - 64a b c + 8a b
+--R              /
+--R                   2 6       2 5    4 4  +-+
+--R                 (a c  - 3a b c  + b c )\|x
+--R     + 
+--R            +-+
+--R         2a\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              7 2       6 2       5 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       7 2      6 2      5 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         atan
+--R                           10 5        9 2 4        8 4 3        7 6 2
+--R                      2048a  c  - 5632a b c  + 4480a b c  - 1568a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      256a b c - 16a b
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |       4 4     3 2 3      2 4 2       6     8
+--R                     |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                  - 32a b c  + 128a b c  - 138a b c  + 63a b c  - 13a b c + b
+--R             *
+--R                ROOT
+--R                                7 2       6 2       5 4
+--R                         (- 256a c  + 128a b c - 16a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |       4 4     3 2 3      2 4 2       6     8
+--R                          |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                         7 2      6 2      5 4
+--R                     128a c  - 64a b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     7 2       6 2       5 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                             +-------------------------------------------------+
+--R                             |       4 4     3 2 3      2 4 2       6     8
+--R                             |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-------------------------------------------------
+--R                             |      13 3         12 2 2        11 4        10 6
+--R                            \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              7 2      6 2      5 4
+--R                          128a c  - 64a b c + 8a b
+--R           /
+--R                2 6       2 5    4 4  +-+
+--R              (a c  - 3a b c  + b c )\|x
+--R     + 
+--R       - 4
+--R  /
+--R        +-+
+--R     2a\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 617
+
+--S 618 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              4+-+3 |          2 4|   |          2      4| |          2
+--R            a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               7 2       6 2       5 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          7 2      6 2      5 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                              10 5        9 2 4        8 4 3        7 6 2
+--R                         2048a  c  - 5632a b c  + 4480a b c  - 1568a b c
+--R                       + 
+--R                             6 8       5 10
+--R                         256a b c - 16a b
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                      5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                   32a b c  - 128a b c  + 138a b c  - 63a b c  + 13a b c - b
+--R                *
+--R                   ROOT
+--R                                 7 2       6 2       5 4
+--R                            (256a c  - 128a b c + 16a b )
+--R                         *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                            7 2      6 2      5 4
+--R                        128a c  - 64a b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      7 2       6 2       5 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              13 3         12 2 2        11 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              10 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 7 2      6 2      5 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                   2 6       2 5    4 4  +-+
+--R                 (a c  - 3a b c  + b c )\|x
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4|   |          2      4| |          2
+--R         a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              7 2       6 2       5 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       7 2      6 2      5 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                           10 5        9 2 4        8 4 3        7 6 2
+--R                      2048a  c  - 5632a b c  + 4480a b c  - 1568a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      256a b c - 16a b
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |       4 4     3 2 3      2 4 2       6     8
+--R                     |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                  - 32a b c  + 128a b c  - 138a b c  + 63a b c  - 13a b c + b
+--R             *
+--R                ROOT
+--R                                7 2       6 2       5 4
+--R                         (- 256a c  + 128a b c - 16a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |       4 4     3 2 3      2 4 2       6     8
+--R                          |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                         7 2      6 2      5 4
+--R                     128a c  - 64a b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     7 2       6 2       5 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                             +-------------------------------------------------+
+--R                             |       4 4     3 2 3      2 4 2       6     8
+--R                             |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-------------------------------------------------
+--R                             |      13 3         12 2 2        11 4        10 6
+--R                            \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              7 2      6 2      5 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                2 6       2 5    4 4  +-+
+--R              (a c  - 3a b c  + b c )\|x
+--R     + 
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              4+-+3 |          2 4|   |          2      4| |          2
+--R            a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 7 2       6 2       5 4
+--R                          (- 256a c  + 128a b c - 16a b )
+--R                       *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          7 2      6 2      5 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                                10 5        9 2 4        8 4 3        7 6 2
+--R                         - 2048a  c  + 5632a b c  - 4480a b c  + 1568a b c
+--R                       + 
+--R                               6 8       5 10
+--R                         - 256a b c + 16a b
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                      5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                   32a b c  - 128a b c  + 138a b c  - 63a b c  + 13a b c - b
+--R                *
+--R                   ROOT
+--R                                   7 2       6 2       5 4
+--R                            (- 256a c  + 128a b c - 16a b )
+--R                         *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                            7 2      6 2      5 4
+--R                        128a c  - 64a b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        7 2       6 2       5 4
+--R                                 (- 256a c  + 128a b c - 16a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              13 3         12 2 2        11 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              10 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 7 2      6 2      5 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                   2 6       2 5    4 4  +-+
+--R                 (a c  - 3a b c  + b c )\|x
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4|   |          2      4| |          2
+--R         a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            7 2       6 2       5 4
+--R                       (256a c  - 128a b c + 16a b )
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       7 2      6 2      5 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                             10 5        9 2 4        8 4 3        7 6 2
+--R                      - 2048a  c  + 5632a b c  - 4480a b c  + 1568a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 256a b c + 16a b
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |       4 4     3 2 3      2 4 2       6     8
+--R                     |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                  - 32a b c  + 128a b c  - 138a b c  + 63a b c  - 13a b c + b
+--R             *
+--R                ROOT
+--R                              7 2       6 2       5 4
+--R                         (256a c  - 128a b c + 16a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |       4 4     3 2 3      2 4 2       6     8
+--R                          |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                         7 2      6 2      5 4
+--R                     128a c  - 64a b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   7 2       6 2       5 4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                             +-------------------------------------------------+
+--R                             |       4 4     3 2 3      2 4 2       6     8
+--R                             |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-------------------------------------------------
+--R                             |      13 3         12 2 2        11 4        10 6
+--R                            \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              7 2      6 2      5 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                2 6       2 5    4 4  +-+
+--R              (a c  - 3a b c  + b c )\|x
+--R     + 
+--R       -
+--R                                   +--------------------+ +------------------+
+--R                     +-----------+ |   +-----------+      | +-----------+
+--R               4+-+3 |          2 4|   |          2      4| |          2
+--R            2a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               7 2       6 2       5 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                          7 2      6 2      5 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            atan
+--R                              10 5        9 2 4        8 4 3        7 6 2
+--R                         2048a  c  - 5632a b c  + 4480a b c  - 1568a b c
+--R                       + 
+--R                             6 8       5 10
+--R                         256a b c - 16a b
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                      5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                   32a b c  - 128a b c  + 138a b c  - 63a b c  + 13a b c - b
+--R                *
+--R                   ROOT
+--R                                 7 2       6 2       5 4
+--R                            (256a c  - 128a b c + 16a b )
+--R                         *
+--R                           +-------------------------------------------------+
+--R                           |       4 4     3 2 3      2 4 2       6     8
+--R                           |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                            7 2      6 2      5 4
+--R                        128a c  - 64a b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      7 2       6 2       5 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                              13 3         12 2 2        11 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              10 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                 7 2      6 2      5 4
+--R                             128a c  - 64a b c + 8a b
+--R              /
+--R                   2 6       2 5    4 4  +-+
+--R                 (a c  - 3a b c  + b c )\|x
+--R     + 
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R            4+-+3 |          2 4|   |          2      4| |          2
+--R         2a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              7 2       6 2       5 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |       4 4     3 2 3      2 4 2       6     8
+--R                        |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                       7 2      6 2      5 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         atan
+--R                           10 5        9 2 4        8 4 3        7 6 2
+--R                      2048a  c  - 5632a b c  + 4480a b c  - 1568a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      256a b c - 16a b
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |       4 4     3 2 3      2 4 2       6     8
+--R                     |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5       4 3 4       3 5 3      2 7 2        9     11
+--R                  - 32a b c  + 128a b c  - 138a b c  + 63a b c  - 13a b c + b
+--R             *
+--R                ROOT
+--R                                7 2       6 2       5 4
+--R                         (- 256a c  + 128a b c - 16a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |       4 4     3 2 3      2 4 2       6     8
+--R                          |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                         7 2      6 2      5 4
+--R                     128a c  - 64a b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     7 2       6 2       5 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                             +-------------------------------------------------+
+--R                             |       4 4     3 2 3      2 4 2       6     8
+--R                             |    - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-------------------------------------------------
+--R                             |      13 3         12 2 2        11 4        10 6
+--R                            \|16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                              7 2      6 2      5 4
+--R                          128a c  - 64a b c + 8a b
+--R           /
+--R                2 6       2 5    4 4  +-+
+--R              (a c  - 3a b c  + b c )\|x
+--R     + 
+--R                                      +------------------+
+--R              +-----------+           | +-----------+
+--R              |          2       4+-+4| |          2
+--R         (- 2\|- 4a c + b   + 2b)\|c \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                      +--------------------+
+--R              +-----------+           |   +-----------+
+--R              |          2       4+-+4|   |          2
+--R         (- 2\|- 4a c + b   - 2b)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                    +------------------+
+--R            +-----------+           | +-----------+
+--R            |          2       4+-+4| |          2
+--R         (2\|- 4a c + b   - 2b)\|c \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                    +--------------------+
+--R            +-----------+           |   +-----------+
+--R            |          2       4+-+4|   |          2
+--R         (2\|- 4a c + b   + 2b)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4|   |          2      4| |          2
+--R     2a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 619
+
+)clear all
+
+--S 620 of 1057
+t0:=1/(x^(5/2)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R            6      4      2  +-+
+--R        (c x  + b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 1057
+r0:=(-2/3)/(a*x^(3/2))+c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))+c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))+c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))+c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                            +------------------+3
+--R             +-----------+                  | +-----------+
+--R             |          2         4+-+3 +-+4| |          2
+--R         (3x\|- 4a c + b   - 3b x)\|c  \|x \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                            +--------------------+3
+--R             +-----------+                  |   +-----------+
+--R             |          2         4+-+3 +-+4|   |          2
+--R         (3x\|- 4a c + b   + 3b x)\|c  \|x \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                            +------------------+3
+--R             +-----------+                  | +-----------+
+--R             |          2         4+-+3 +-+4| |          2
+--R         (3x\|- 4a c + b   - 3b x)\|c  \|x \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                            +--------------------+3
+--R             +-----------+                  |   +-----------+
+--R             |          2         4+-+3 +-+4|   |          2
+--R         (3x\|- 4a c + b   + 3b x)\|c  \|x \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R       - 2\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2  +-+4|   |          2        4| |          2
+--R     3a x\|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +-+
+--R         3a x\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            9 2       8 2       7 4
+--R                       (256a c  - 128a b c + 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       9 2      8 2      7 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                         10 3       9 2 2       8 4       7 6
+--R                    (512a  c  - 512a b c  + 160a b c - 16a b )
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                      4   4      3 3 3      2 5 2       7     9
+--R                  - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   9 2       8 2       7 4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           17 3         16 2 2        15 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           14 6
+--R                                     - 256a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              9 2      8 2      7 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                 3 5      2 2 4        4 3     6 2  +-+
+--R              (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R       -
+--R                 +-+
+--R            3a x\|x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 9 2       8 2       7 4
+--R                          (- 256a c  + 128a b c - 16a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                     17 3         16 2 2        15 4        14 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          9 2      8 2      7 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                            10 3       9 2 2       8 4       7 6
+--R                       (512a  c  - 512a b c  + 160a b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                       4   4      3 3 3      2 5 2       7     9
+--R                     4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        9 2       8 2       7 4
+--R                                 (- 256a c  + 128a b c - 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              17 3         16 2 2        15 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              14 6
+--R                                        - 256a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 9 2      8 2      7 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                    3 5      2 2 4        4 3     6 2  +-+
+--R                 (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R              +-+
+--R         3a x\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              9 2       8 2       7 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       9 2      8 2      7 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                           10 3       9 2 2       8 4       7 6
+--R                    (- 512a  c  + 512a b c  - 160a b c + 16a b )
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                      4   4      3 3 3      2 5 2       7     9
+--R                  - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     9 2       8 2       7 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           17 3         16 2 2        15 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           14 6
+--R                                     - 256a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              9 2      8 2      7 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                 3 5      2 2 4        4 3     6 2  +-+
+--R              (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R       -
+--R                 +-+
+--R            3a x\|x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               9 2       8 2       7 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                     17 3         16 2 2        15 4        14 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          9 2      8 2      7 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                              10 3       9 2 2       8 4       7 6
+--R                       (- 512a  c  + 512a b c  - 160a b c + 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                       4   4      3 3 3      2 5 2       7     9
+--R                     4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      9 2       8 2       7 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              17 3         16 2 2        15 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              14 6
+--R                                        - 256a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 9 2      8 2      7 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                    3 5      2 2 4        4 3     6 2  +-+
+--R                 (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R       -
+--R                 +-+
+--R            6a x\|x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               9 2       8 2       7 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                     17 3         16 2 2        15 4        14 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          9 2      8 2      7 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            atan
+--R                            10 3       9 2 2       8 4       7 6
+--R                       (512a  c  - 512a b c  + 160a b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         4   4      3 3 3      2 5 2       7     9
+--R                     - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      9 2       8 2       7 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              17 3         16 2 2        15 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              14 6
+--R                                        - 256a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 9 2      8 2      7 4
+--R                             128a c  - 64a b c + 8a b
+--R              /
+--R                    3 5      2 2 4        4 3     6 2  +-+
+--R                 (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R              +-+
+--R         6a x\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              9 2       8 2       7 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       9 2      8 2      7 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         atan
+--R                         10 3       9 2 2       8 4       7 6
+--R                    (512a  c  - 512a b c  + 160a b c - 16a b )
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                    4   4      3 3 3      2 5 2       7     9
+--R                  4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     9 2       8 2       7 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           17 3         16 2 2        15 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           14 6
+--R                                     - 256a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              9 2      8 2      7 4
+--R                          128a c  - 64a b c + 8a b
+--R           /
+--R                 3 5      2 2 4        4 3     6 2  +-+
+--R              (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R       - 4
+--R  /
+--R          +-+
+--R     6a x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 622
+
+--S 623 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            9 2       8 2       7 4
+--R                       (256a c  - 128a b c + 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       9 2      8 2      7 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                         10 3       9 2 2       8 4       7 6
+--R                    (512a  c  - 512a b c  + 160a b c - 16a b )
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                      4   4      3 3 3      2 5 2       7     9
+--R                  - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   9 2       8 2       7 4
+--R                              (256a c  - 128a b c + 16a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           17 3         16 2 2        15 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           14 6
+--R                                     - 256a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              9 2      8 2      7 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                 3 5      2 2 4        4 3     6 2  +-+
+--R              (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R       -
+--R                                +--------------------+3  +------------------+3
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             4+-+ |          2 4|   |          2        4| |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 9 2       8 2       7 4
+--R                          (- 256a c  + 128a b c - 16a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                     17 3         16 2 2        15 4        14 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          9 2      8 2      7 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                            10 3       9 2 2       8 4       7 6
+--R                       (512a  c  - 512a b c  + 160a b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                       4   4      3 3 3      2 5 2       7     9
+--R                     4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        9 2       8 2       7 4
+--R                                 (- 256a c  + 128a b c - 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              17 3         16 2 2        15 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              14 6
+--R                                        - 256a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 9 2      8 2      7 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                    3 5      2 2 4        4 3     6 2  +-+
+--R                 (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              9 2       8 2       7 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       9 2      8 2      7 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         log
+--R                           10 3       9 2 2       8 4       7 6
+--R                    (- 512a  c  + 512a b c  - 160a b c + 16a b )
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                      4   4      3 3 3      2 5 2       7     9
+--R                  - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     9 2       8 2       7 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           17 3         16 2 2        15 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           14 6
+--R                                     - 256a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              9 2      8 2      7 4
+--R                          128a c  - 64a b c + 8a b
+--R            + 
+--R                 3 5      2 2 4        4 3     6 2  +-+
+--R              (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R       -
+--R                                +--------------------+3  +------------------+3
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             4+-+ |          2 4|   |          2        4| |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               9 2       8 2       7 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                     17 3         16 2 2        15 4        14 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          9 2      8 2      7 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            log
+--R                              10 3       9 2 2       8 4       7 6
+--R                       (- 512a  c  + 512a b c  - 160a b c + 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                       4   4      3 3 3      2 5 2       7     9
+--R                     4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      9 2       8 2       7 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              17 3         16 2 2        15 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              14 6
+--R                                        - 256a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 9 2      8 2      7 4
+--R                             128a c  - 64a b c + 8a b
+--R               + 
+--R                    3 5      2 2 4        4 3     6 2  +-+
+--R                 (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R       -
+--R                                 +--------------------+3  +------------------+3
+--R                   +-----------+ |   +-----------+        | +-----------+
+--R              4+-+ |          2 4|   |          2        4| |          2
+--R            2a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               9 2       8 2       7 4
+--R                          (256a c  - 128a b c + 16a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                     17 3         16 2 2        15 4        14 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                          9 2      8 2      7 4
+--R                      128a c  - 64a b c + 8a b
+--R         *
+--R            atan
+--R                            10 3       9 2 2       8 4       7 6
+--R                       (512a  c  - 512a b c  + 160a b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         4   4      3 3 3      2 5 2       7     9
+--R                     - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      9 2       8 2       7 4
+--R                                 (256a c  - 128a b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                              17 3         16 2 2        15 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              14 6
+--R                                        - 256a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                 9 2      8 2      7 4
+--R                             128a c  - 64a b c + 8a b
+--R              /
+--R                    3 5      2 2 4        4 3     6 2  +-+
+--R                 (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R                              +--------------------+3  +------------------+3
+--R                +-----------+ |   +-----------+        | +-----------+
+--R           4+-+ |          2 4|   |          2        4| |          2
+--R         2a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              9 2       8 2       7 4
+--R                       (- 256a c  + 128a b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                  17 3         16 2 2        15 4        14 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                       9 2      8 2      7 4
+--R                   128a c  - 64a b c + 8a b
+--R      *
+--R         atan
+--R                         10 3       9 2 2       8 4       7 6
+--R                    (512a  c  - 512a b c  + 160a b c - 16a b )
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                    4   4      3 3 3      2 5 2       7     9
+--R                  4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     9 2       8 2       7 4
+--R                              (- 256a c  + 128a b c - 16a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                           17 3         16 2 2        15 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           14 6
+--R                                     - 256a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                              9 2      8 2      7 4
+--R                          128a c  - 64a b c + 8a b
+--R           /
+--R                 3 5      2 2 4        4 3     6 2  +-+
+--R              (2a c  - 12a b c  + 10a b c  - 2b c )\|x
+--R     + 
+--R                                        +------------------+3
+--R              +-----------+             | +-----------+
+--R              |          2       4+-+3 4| |          2
+--R         (- 2\|- 4a c + b   + 2b)\|c   \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+3
+--R              +-----------+             |   +-----------+
+--R              |          2       4+-+3 4|   |          2
+--R         (- 2\|- 4a c + b   - 2b)\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                        +------------------+3
+--R              +-----------+             | +-----------+
+--R              |          2       4+-+3 4| |          2
+--R         (- 2\|- 4a c + b   + 2b)\|c   \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+3
+--R              +-----------+             |   +-----------+
+--R              |          2       4+-+3 4|   |          2
+--R         (- 2\|- 4a c + b   - 2b)\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                          +--------------------+3  +------------------+3
+--R            +-----------+ |   +-----------+        | +-----------+
+--R       4+-+ |          2 4|   |          2        4| |          2
+--R     2a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 624
+
+)clear all
+
+--S 625 of 1057
+t0:=1/(x^(7/2)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R            7      5      3  +-+
+--R        (c x  + b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 1057
+r0:=(-2/5)/(a*x^(5/2))+c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a^2*(-b-sqrt(b^2-4*a*c))^(1/4))-c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a^2*(-b-sqrt(b^2-4*a*c))^(1/4))+c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a^2*(-b+sqrt(b^2-4*a*c))^(1/4))-c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a^2*(-b+sqrt(b^2-4*a*c))^(1/4))+2*b/(a^2*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                  +-----------+
+--R                2 |          2                 2  2 4+-+ +-+
+--R         (- 5b x \|- 4a c + b   + (- 10a c + 5b )x )\|c \|x
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                  +-----------+
+--R                2 |          2               2  2 4+-+ +-+
+--R         (- 5b x \|- 4a c + b   + (10a c - 5b )x )\|c \|x
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                                         +------------------+
+--R                +-----------+                            | +-----------+
+--R              2 |          2               2  2 4+-+ +-+4| |          2
+--R         (5b x \|- 4a c + b   + (10a c - 5b )x )\|c \|x \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                +-----------+
+--R              2 |          2                 2  2 4+-+ +-+
+--R         (5b x \|- 4a c + b   + (- 10a c + 5b )x )\|c \|x
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R               2      4+-+3 |          2 4|   |          2
+--R         (10b x  - 2a)\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R                                   +--------------------+ +------------------+
+--R                 +-----------+     |   +-----------+      | +-----------+
+--R       2 2 4+-+3 |          2  +-+4|   |          2      4| |          2
+--R     5a x  \|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R              2 2 +-+
+--R            5a x \|x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               11 2       10 2       9 4
+--R                          (256a  c  - 128a  b c + 16a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8      7 2 7       6 4 6       5 6 5
+--R                                 - a c  + 20a b c  - 130a b c  + 314a b c
+--R                               + 
+--R                                       4 8 4       3 10 3      2 12 2        14
+--R                                 - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                               + 
+--R                                    16
+--R                                 - b
+--R                            /
+--R                                     21 3         20 2 2        19 4        18 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            4   4      3 3 3      2 5 2       7     9
+--R                        - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                   /
+--R                          11 2      10 2      9 4
+--R                      128a  c  - 64a  b c + 8a b
+--R         *
+--R            log
+--R                              15   6         14 3 5         13 5 4        12 7 3
+--R                         7168a  b c  - 19712a  b c  + 19264a  b c  - 9200a  b c
+--R                       + 
+--R                              11 9 2       10 11       9 13
+--R                         2336a  b c  - 304a  b  c + 16a b
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                          9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                     - 16a c  + 264a b c  - 1409a b c  + 3024a b c  - 3312a b c
+--R                   + 
+--R                          4 10 4       3 12 3       2 14 2        16     18
+--R                     2068a b  c  - 768a b  c  + 168a b  c  - 20a b  c + b
+--R                *
+--R                   ROOT
+--R                                 11 2       10 2       9 4
+--R                            (256a  c  - 128a  b c + 16a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8      7 2 7       6 4 6       5 6 5
+--R                                   - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                 + 
+--R                                         4 8 4       3 10 3      2 12 2
+--R                                   - 367a b c  + 230a b  c  - 79a b  c
+--R                                 + 
+--R                                        14     16
+--R                                   14a b  c - b
+--R                              /
+--R                                         21 3         20 2 2        19 4
+--R                                   16384a  c  - 12288a  b c  + 3072a  b c
+--R                                 + 
+--R                                         18 6
+--R                                   - 256a  b
+--R                        + 
+--R                              4   4      3 3 3      2 5 2       7     9
+--R                          - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                     /
+--R                            11 2      10 2      9 4
+--R                        128a  c  - 64a  b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      11 2       10 2       9 4
+--R                                 (256a  c  - 128a  b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8      7 2 7       6 4 6
+--R                                        - a c  + 20a b c  - 130a b c
+--R                                      + 
+--R                                            5 6 5       4 8 4       3 10 3
+--R                                        314a b c  - 367a b c  + 230a b  c
+--R                                      + 
+--R                                             2 12 2        14     16
+--R                                        - 79a b  c  + 14a b  c - b
+--R                                   /
+--R                                              21 3         20 2 2        19 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              18 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   4   4      3 3 3      2 5 2       7     9
+--R                               - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                          /
+--R                                 11 2      10 2      9 4
+--R                             128a  c  - 64a  b c + 8a b
+--R               + 
+--R                   4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R                 (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R           2 2 +-+
+--R         5a x \|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              11 2       10 2       9 4
+--R                       (- 256a  c  + 128a  b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         4   4      3 3 3      2 5 2       7     9
+--R                     - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                /
+--R                       11 2      10 2      9 4
+--R                   128a  c  - 64a  b c + 8a b
+--R      *
+--R         log
+--R                           15   6         14 3 5         13 5 4        12 7 3
+--R                      7168a  b c  - 19712a  b c  + 19264a  b c  - 9200a  b c
+--R                    + 
+--R                           11 9 2       10 11       9 13
+--R                      2336a  b c  - 304a  b  c + 16a b
+--R                 *
+--R                    ROOT
+--R                              8 8      7 2 7       6 4 6       5 6 5       4 8 4
+--R                           - a c  + 20a b c  - 130a b c  + 314a b c  - 367a b c
+--R                         + 
+--R                               3 10 3      2 12 2        14     16
+--R                           230a b  c  - 79a b  c  + 14a b  c - b
+--R                      /
+--R                               21 3         20 2 2        19 4        18 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                     9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                  16a c  - 264a b c  + 1409a b c  - 3024a b c  + 3312a b c
+--R                + 
+--R                         4 10 4       3 12 3       2 14 2        16     18
+--R                  - 2068a b  c  + 768a b  c  - 168a b  c  + 20a b  c - b
+--R             *
+--R                ROOT
+--R                                11 2       10 2       9 4
+--R                         (- 256a  c  + 128a  b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8      7 2 7       6 4 6       5 6 5
+--R                                - a c  + 20a b c  - 130a b c  + 314a b c
+--R                              + 
+--R                                      4 8 4       3 10 3      2 12 2        14
+--R                                - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                              + 
+--R                                   16
+--R                                - b
+--R                           /
+--R                                    21 3         20 2 2        19 4        18 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           4   4      3 3 3      2 5 2       7     9
+--R                       - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                  /
+--R                         11 2      10 2      9 4
+--R                     128a  c  - 64a  b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     11 2       10 2       9 4
+--R                              (- 256a  c  + 128a  b c - 16a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8      7 2 7       6 4 6       5 6 5
+--R                                     - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                   + 
+--R                                           4 8 4       3 10 3      2 12 2
+--R                                     - 367a b c  + 230a b  c  - 79a b  c
+--R                                   + 
+--R                                          14     16
+--R                                     14a b  c - b
+--R                                /
+--R                                           21 3         20 2 2        19 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           18 6
+--R                                     - 256a  b
+--R                          + 
+--R                                4   4      3 3 3      2 5 2       7     9
+--R                            - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                       /
+--R                              11 2      10 2      9 4
+--R                          128a  c  - 64a  b c + 8a b
+--R            + 
+--R                4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R              (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R       -
+--R              2 2 +-+
+--R            5a x \|x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 11 2       10 2       9 4
+--R                          (- 256a  c  + 128a  b c - 16a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8      7 2 7       6 4 6       5 6 5
+--R                                 - a c  + 20a b c  - 130a b c  + 314a b c
+--R                               + 
+--R                                       4 8 4       3 10 3      2 12 2        14
+--R                                 - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                               + 
+--R                                    16
+--R                                 - b
+--R                            /
+--R                                     21 3         20 2 2        19 4        18 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            4   4      3 3 3      2 5 2       7     9
+--R                        - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                   /
+--R                          11 2      10 2      9 4
+--R                      128a  c  - 64a  b c + 8a b
+--R         *
+--R            log
+--R                                15   6         14 3 5         13 5 4
+--R                         - 7168a  b c  + 19712a  b c  - 19264a  b c
+--R                       + 
+--R                              12 7 3        11 9 2       10 11       9 13
+--R                         9200a  b c  - 2336a  b c  + 304a  b  c - 16a b
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                          9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                     - 16a c  + 264a b c  - 1409a b c  + 3024a b c  - 3312a b c
+--R                   + 
+--R                          4 10 4       3 12 3       2 14 2        16     18
+--R                     2068a b  c  - 768a b  c  + 168a b  c  - 20a b  c + b
+--R                *
+--R                   ROOT
+--R                                   11 2       10 2       9 4
+--R                            (- 256a  c  + 128a  b c - 16a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8      7 2 7       6 4 6       5 6 5
+--R                                   - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                 + 
+--R                                         4 8 4       3 10 3      2 12 2
+--R                                   - 367a b c  + 230a b  c  - 79a b  c
+--R                                 + 
+--R                                        14     16
+--R                                   14a b  c - b
+--R                              /
+--R                                         21 3         20 2 2        19 4
+--R                                   16384a  c  - 12288a  b c  + 3072a  b c
+--R                                 + 
+--R                                         18 6
+--R                                   - 256a  b
+--R                        + 
+--R                              4   4      3 3 3      2 5 2       7     9
+--R                          - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                     /
+--R                            11 2      10 2      9 4
+--R                        128a  c  - 64a  b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        11 2       10 2       9 4
+--R                                 (- 256a  c  + 128a  b c - 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8      7 2 7       6 4 6
+--R                                        - a c  + 20a b c  - 130a b c
+--R                                      + 
+--R                                            5 6 5       4 8 4       3 10 3
+--R                                        314a b c  - 367a b c  + 230a b  c
+--R                                      + 
+--R                                             2 12 2        14     16
+--R                                        - 79a b  c  + 14a b  c - b
+--R                                   /
+--R                                              21 3         20 2 2        19 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              18 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   4   4      3 3 3      2 5 2       7     9
+--R                               - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                          /
+--R                                 11 2      10 2      9 4
+--R                             128a  c  - 64a  b c + 8a b
+--R               + 
+--R                   4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R                 (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R           2 2 +-+
+--R         5a x \|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            11 2       10 2       9 4
+--R                       (256a  c  - 128a  b c + 16a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         4   4      3 3 3      2 5 2       7     9
+--R                     - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                /
+--R                       11 2      10 2      9 4
+--R                   128a  c  - 64a  b c + 8a b
+--R      *
+--R         log
+--R                             15   6         14 3 5         13 5 4        12 7 3
+--R                      - 7168a  b c  + 19712a  b c  - 19264a  b c  + 9200a  b c
+--R                    + 
+--R                             11 9 2       10 11       9 13
+--R                      - 2336a  b c  + 304a  b  c - 16a b
+--R                 *
+--R                    ROOT
+--R                              8 8      7 2 7       6 4 6       5 6 5       4 8 4
+--R                           - a c  + 20a b c  - 130a b c  + 314a b c  - 367a b c
+--R                         + 
+--R                               3 10 3      2 12 2        14     16
+--R                           230a b  c  - 79a b  c  + 14a b  c - b
+--R                      /
+--R                               21 3         20 2 2        19 4        18 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                     9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                  16a c  - 264a b c  + 1409a b c  - 3024a b c  + 3312a b c
+--R                + 
+--R                         4 10 4       3 12 3       2 14 2        16     18
+--R                  - 2068a b  c  + 768a b  c  - 168a b  c  + 20a b  c - b
+--R             *
+--R                ROOT
+--R                              11 2       10 2       9 4
+--R                         (256a  c  - 128a  b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8      7 2 7       6 4 6       5 6 5
+--R                                - a c  + 20a b c  - 130a b c  + 314a b c
+--R                              + 
+--R                                      4 8 4       3 10 3      2 12 2        14
+--R                                - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                              + 
+--R                                   16
+--R                                - b
+--R                           /
+--R                                    21 3         20 2 2        19 4        18 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           4   4      3 3 3      2 5 2       7     9
+--R                       - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                  /
+--R                         11 2      10 2      9 4
+--R                     128a  c  - 64a  b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   11 2       10 2       9 4
+--R                              (256a  c  - 128a  b c + 16a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8      7 2 7       6 4 6       5 6 5
+--R                                     - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                   + 
+--R                                           4 8 4       3 10 3      2 12 2
+--R                                     - 367a b c  + 230a b  c  - 79a b  c
+--R                                   + 
+--R                                          14     16
+--R                                     14a b  c - b
+--R                                /
+--R                                           21 3         20 2 2        19 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           18 6
+--R                                     - 256a  b
+--R                          + 
+--R                                4   4      3 3 3      2 5 2       7     9
+--R                            - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                       /
+--R                              11 2      10 2      9 4
+--R                          128a  c  - 64a  b c + 8a b
+--R            + 
+--R                4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R              (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R       -
+--R               2 2 +-+
+--R            10a x \|x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               11 2       10 2       9 4
+--R                          (256a  c  - 128a  b c + 16a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8      7 2 7       6 4 6       5 6 5
+--R                                 - a c  + 20a b c  - 130a b c  + 314a b c
+--R                               + 
+--R                                       4 8 4       3 10 3      2 12 2        14
+--R                                 - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                               + 
+--R                                    16
+--R                                 - b
+--R                            /
+--R                                     21 3         20 2 2        19 4        18 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            4   4      3 3 3      2 5 2       7     9
+--R                        - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                   /
+--R                          11 2      10 2      9 4
+--R                      128a  c  - 64a  b c + 8a b
+--R         *
+--R            atan
+--R                              15   6         14 3 5         13 5 4        12 7 3
+--R                         7168a  b c  - 19712a  b c  + 19264a  b c  - 9200a  b c
+--R                       + 
+--R                              11 9 2       10 11       9 13
+--R                         2336a  b c  - 304a  b  c + 16a b
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                          9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                     - 16a c  + 264a b c  - 1409a b c  + 3024a b c  - 3312a b c
+--R                   + 
+--R                          4 10 4       3 12 3       2 14 2        16     18
+--R                     2068a b  c  - 768a b  c  + 168a b  c  - 20a b  c + b
+--R                *
+--R                   ROOT
+--R                                 11 2       10 2       9 4
+--R                            (256a  c  - 128a  b c + 16a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8      7 2 7       6 4 6       5 6 5
+--R                                   - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                 + 
+--R                                         4 8 4       3 10 3      2 12 2
+--R                                   - 367a b c  + 230a b  c  - 79a b  c
+--R                                 + 
+--R                                        14     16
+--R                                   14a b  c - b
+--R                              /
+--R                                         21 3         20 2 2        19 4
+--R                                   16384a  c  - 12288a  b c  + 3072a  b c
+--R                                 + 
+--R                                         18 6
+--R                                   - 256a  b
+--R                        + 
+--R                              4   4      3 3 3      2 5 2       7     9
+--R                          - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                     /
+--R                            11 2      10 2      9 4
+--R                        128a  c  - 64a  b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      11 2       10 2       9 4
+--R                                 (256a  c  - 128a  b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8      7 2 7       6 4 6
+--R                                        - a c  + 20a b c  - 130a b c
+--R                                      + 
+--R                                            5 6 5       4 8 4       3 10 3
+--R                                        314a b c  - 367a b c  + 230a b  c
+--R                                      + 
+--R                                             2 12 2        14     16
+--R                                        - 79a b  c  + 14a b  c - b
+--R                                   /
+--R                                              21 3         20 2 2        19 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              18 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   4   4      3 3 3      2 5 2       7     9
+--R                               - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                          /
+--R                                 11 2      10 2      9 4
+--R                             128a  c  - 64a  b c + 8a b
+--R              /
+--R                   4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R                 (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R            2 2 +-+
+--R         10a x \|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              11 2       10 2       9 4
+--R                       (- 256a  c  + 128a  b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         4   4      3 3 3      2 5 2       7     9
+--R                     - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                /
+--R                       11 2      10 2      9 4
+--R                   128a  c  - 64a  b c + 8a b
+--R      *
+--R         atan
+--R                           15   6         14 3 5         13 5 4        12 7 3
+--R                      7168a  b c  - 19712a  b c  + 19264a  b c  - 9200a  b c
+--R                    + 
+--R                           11 9 2       10 11       9 13
+--R                      2336a  b c  - 304a  b  c + 16a b
+--R                 *
+--R                    ROOT
+--R                              8 8      7 2 7       6 4 6       5 6 5       4 8 4
+--R                           - a c  + 20a b c  - 130a b c  + 314a b c  - 367a b c
+--R                         + 
+--R                               3 10 3      2 12 2        14     16
+--R                           230a b  c  - 79a b  c  + 14a b  c - b
+--R                      /
+--R                               21 3         20 2 2        19 4        18 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                     9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                  16a c  - 264a b c  + 1409a b c  - 3024a b c  + 3312a b c
+--R                + 
+--R                         4 10 4       3 12 3       2 14 2        16     18
+--R                  - 2068a b  c  + 768a b  c  - 168a b  c  + 20a b  c - b
+--R             *
+--R                ROOT
+--R                                11 2       10 2       9 4
+--R                         (- 256a  c  + 128a  b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8      7 2 7       6 4 6       5 6 5
+--R                                - a c  + 20a b c  - 130a b c  + 314a b c
+--R                              + 
+--R                                      4 8 4       3 10 3      2 12 2        14
+--R                                - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                              + 
+--R                                   16
+--R                                - b
+--R                           /
+--R                                    21 3         20 2 2        19 4        18 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           4   4      3 3 3      2 5 2       7     9
+--R                       - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                  /
+--R                         11 2      10 2      9 4
+--R                     128a  c  - 64a  b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     11 2       10 2       9 4
+--R                              (- 256a  c  + 128a  b c - 16a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8      7 2 7       6 4 6       5 6 5
+--R                                     - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                   + 
+--R                                           4 8 4       3 10 3      2 12 2
+--R                                     - 367a b c  + 230a b  c  - 79a b  c
+--R                                   + 
+--R                                          14     16
+--R                                     14a b  c - b
+--R                                /
+--R                                           21 3         20 2 2        19 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           18 6
+--R                                     - 256a  b
+--R                          + 
+--R                                4   4      3 3 3      2 5 2       7     9
+--R                            - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                       /
+--R                              11 2      10 2      9 4
+--R                          128a  c  - 64a  b c + 8a b
+--R           /
+--R                4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R              (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R            2
+--R       20b x  - 4a
+--R  /
+--R        2 2 +-+
+--R     10a x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 627
+
+--S 628 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                   +--------------------+ +------------------+
+--R                     +-----------+ |   +-----------+      | +-----------+
+--R             2 4+-+3 |          2 4|   |          2      4| |          2
+--R            a  \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               11 2       10 2       9 4
+--R                          (256a  c  - 128a  b c + 16a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8      7 2 7       6 4 6       5 6 5
+--R                                 - a c  + 20a b c  - 130a b c  + 314a b c
+--R                               + 
+--R                                       4 8 4       3 10 3      2 12 2        14
+--R                                 - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                               + 
+--R                                    16
+--R                                 - b
+--R                            /
+--R                                     21 3         20 2 2        19 4        18 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            4   4      3 3 3      2 5 2       7     9
+--R                        - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                   /
+--R                          11 2      10 2      9 4
+--R                      128a  c  - 64a  b c + 8a b
+--R         *
+--R            log
+--R                              15   6         14 3 5         13 5 4        12 7 3
+--R                         7168a  b c  - 19712a  b c  + 19264a  b c  - 9200a  b c
+--R                       + 
+--R                              11 9 2       10 11       9 13
+--R                         2336a  b c  - 304a  b  c + 16a b
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                          9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                     - 16a c  + 264a b c  - 1409a b c  + 3024a b c  - 3312a b c
+--R                   + 
+--R                          4 10 4       3 12 3       2 14 2        16     18
+--R                     2068a b  c  - 768a b  c  + 168a b  c  - 20a b  c + b
+--R                *
+--R                   ROOT
+--R                                 11 2       10 2       9 4
+--R                            (256a  c  - 128a  b c + 16a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8      7 2 7       6 4 6       5 6 5
+--R                                   - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                 + 
+--R                                         4 8 4       3 10 3      2 12 2
+--R                                   - 367a b c  + 230a b  c  - 79a b  c
+--R                                 + 
+--R                                        14     16
+--R                                   14a b  c - b
+--R                              /
+--R                                         21 3         20 2 2        19 4
+--R                                   16384a  c  - 12288a  b c  + 3072a  b c
+--R                                 + 
+--R                                         18 6
+--R                                   - 256a  b
+--R                        + 
+--R                              4   4      3 3 3      2 5 2       7     9
+--R                          - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                     /
+--R                            11 2      10 2      9 4
+--R                        128a  c  - 64a  b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      11 2       10 2       9 4
+--R                                 (256a  c  - 128a  b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8      7 2 7       6 4 6
+--R                                        - a c  + 20a b c  - 130a b c
+--R                                      + 
+--R                                            5 6 5       4 8 4       3 10 3
+--R                                        314a b c  - 367a b c  + 230a b  c
+--R                                      + 
+--R                                             2 12 2        14     16
+--R                                        - 79a b  c  + 14a b  c - b
+--R                                   /
+--R                                              21 3         20 2 2        19 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              18 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   4   4      3 3 3      2 5 2       7     9
+--R                               - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                          /
+--R                                 11 2      10 2      9 4
+--R                             128a  c  - 64a  b c + 8a b
+--R               + 
+--R                   4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R                 (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R          2 4+-+3 |          2 4|   |          2      4| |          2
+--R         a  \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              11 2       10 2       9 4
+--R                       (- 256a  c  + 128a  b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         4   4      3 3 3      2 5 2       7     9
+--R                     - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                /
+--R                       11 2      10 2      9 4
+--R                   128a  c  - 64a  b c + 8a b
+--R      *
+--R         log
+--R                           15   6         14 3 5         13 5 4        12 7 3
+--R                      7168a  b c  - 19712a  b c  + 19264a  b c  - 9200a  b c
+--R                    + 
+--R                           11 9 2       10 11       9 13
+--R                      2336a  b c  - 304a  b  c + 16a b
+--R                 *
+--R                    ROOT
+--R                              8 8      7 2 7       6 4 6       5 6 5       4 8 4
+--R                           - a c  + 20a b c  - 130a b c  + 314a b c  - 367a b c
+--R                         + 
+--R                               3 10 3      2 12 2        14     16
+--R                           230a b  c  - 79a b  c  + 14a b  c - b
+--R                      /
+--R                               21 3         20 2 2        19 4        18 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                     9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                  16a c  - 264a b c  + 1409a b c  - 3024a b c  + 3312a b c
+--R                + 
+--R                         4 10 4       3 12 3       2 14 2        16     18
+--R                  - 2068a b  c  + 768a b  c  - 168a b  c  + 20a b  c - b
+--R             *
+--R                ROOT
+--R                                11 2       10 2       9 4
+--R                         (- 256a  c  + 128a  b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8      7 2 7       6 4 6       5 6 5
+--R                                - a c  + 20a b c  - 130a b c  + 314a b c
+--R                              + 
+--R                                      4 8 4       3 10 3      2 12 2        14
+--R                                - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                              + 
+--R                                   16
+--R                                - b
+--R                           /
+--R                                    21 3         20 2 2        19 4        18 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           4   4      3 3 3      2 5 2       7     9
+--R                       - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                  /
+--R                         11 2      10 2      9 4
+--R                     128a  c  - 64a  b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     11 2       10 2       9 4
+--R                              (- 256a  c  + 128a  b c - 16a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8      7 2 7       6 4 6       5 6 5
+--R                                     - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                   + 
+--R                                           4 8 4       3 10 3      2 12 2
+--R                                     - 367a b c  + 230a b  c  - 79a b  c
+--R                                   + 
+--R                                          14     16
+--R                                     14a b  c - b
+--R                                /
+--R                                           21 3         20 2 2        19 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           18 6
+--R                                     - 256a  b
+--R                          + 
+--R                                4   4      3 3 3      2 5 2       7     9
+--R                            - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                       /
+--R                              11 2      10 2      9 4
+--R                          128a  c  - 64a  b c + 8a b
+--R            + 
+--R                4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R              (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R       -
+--R                                   +--------------------+ +------------------+
+--R                     +-----------+ |   +-----------+      | +-----------+
+--R             2 4+-+3 |          2 4|   |          2      4| |          2
+--R            a  \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                 11 2       10 2       9 4
+--R                          (- 256a  c  + 128a  b c - 16a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8      7 2 7       6 4 6       5 6 5
+--R                                 - a c  + 20a b c  - 130a b c  + 314a b c
+--R                               + 
+--R                                       4 8 4       3 10 3      2 12 2        14
+--R                                 - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                               + 
+--R                                    16
+--R                                 - b
+--R                            /
+--R                                     21 3         20 2 2        19 4        18 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            4   4      3 3 3      2 5 2       7     9
+--R                        - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                   /
+--R                          11 2      10 2      9 4
+--R                      128a  c  - 64a  b c + 8a b
+--R         *
+--R            log
+--R                                15   6         14 3 5         13 5 4
+--R                         - 7168a  b c  + 19712a  b c  - 19264a  b c
+--R                       + 
+--R                              12 7 3        11 9 2       10 11       9 13
+--R                         9200a  b c  - 2336a  b c  + 304a  b  c - 16a b
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                          9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                     - 16a c  + 264a b c  - 1409a b c  + 3024a b c  - 3312a b c
+--R                   + 
+--R                          4 10 4       3 12 3       2 14 2        16     18
+--R                     2068a b  c  - 768a b  c  + 168a b  c  - 20a b  c + b
+--R                *
+--R                   ROOT
+--R                                   11 2       10 2       9 4
+--R                            (- 256a  c  + 128a  b c - 16a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8      7 2 7       6 4 6       5 6 5
+--R                                   - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                 + 
+--R                                         4 8 4       3 10 3      2 12 2
+--R                                   - 367a b c  + 230a b  c  - 79a b  c
+--R                                 + 
+--R                                        14     16
+--R                                   14a b  c - b
+--R                              /
+--R                                         21 3         20 2 2        19 4
+--R                                   16384a  c  - 12288a  b c  + 3072a  b c
+--R                                 + 
+--R                                         18 6
+--R                                   - 256a  b
+--R                        + 
+--R                              4   4      3 3 3      2 5 2       7     9
+--R                          - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                     /
+--R                            11 2      10 2      9 4
+--R                        128a  c  - 64a  b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                        11 2       10 2       9 4
+--R                                 (- 256a  c  + 128a  b c - 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8      7 2 7       6 4 6
+--R                                        - a c  + 20a b c  - 130a b c
+--R                                      + 
+--R                                            5 6 5       4 8 4       3 10 3
+--R                                        314a b c  - 367a b c  + 230a b  c
+--R                                      + 
+--R                                             2 12 2        14     16
+--R                                        - 79a b  c  + 14a b  c - b
+--R                                   /
+--R                                              21 3         20 2 2        19 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              18 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   4   4      3 3 3      2 5 2       7     9
+--R                               - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                          /
+--R                                 11 2      10 2      9 4
+--R                             128a  c  - 64a  b c + 8a b
+--R               + 
+--R                   4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R                 (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R          2 4+-+3 |          2 4|   |          2      4| |          2
+--R         a  \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                            11 2       10 2       9 4
+--R                       (256a  c  - 128a  b c + 16a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         4   4      3 3 3      2 5 2       7     9
+--R                     - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                /
+--R                       11 2      10 2      9 4
+--R                   128a  c  - 64a  b c + 8a b
+--R      *
+--R         log
+--R                             15   6         14 3 5         13 5 4        12 7 3
+--R                      - 7168a  b c  + 19712a  b c  - 19264a  b c  + 9200a  b c
+--R                    + 
+--R                             11 9 2       10 11       9 13
+--R                      - 2336a  b c  + 304a  b  c - 16a b
+--R                 *
+--R                    ROOT
+--R                              8 8      7 2 7       6 4 6       5 6 5       4 8 4
+--R                           - a c  + 20a b c  - 130a b c  + 314a b c  - 367a b c
+--R                         + 
+--R                               3 10 3      2 12 2        14     16
+--R                           230a b  c  - 79a b  c  + 14a b  c - b
+--R                      /
+--R                               21 3         20 2 2        19 4        18 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                     9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                  16a c  - 264a b c  + 1409a b c  - 3024a b c  + 3312a b c
+--R                + 
+--R                         4 10 4       3 12 3       2 14 2        16     18
+--R                  - 2068a b  c  + 768a b  c  - 168a b  c  + 20a b  c - b
+--R             *
+--R                ROOT
+--R                              11 2       10 2       9 4
+--R                         (256a  c  - 128a  b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8      7 2 7       6 4 6       5 6 5
+--R                                - a c  + 20a b c  - 130a b c  + 314a b c
+--R                              + 
+--R                                      4 8 4       3 10 3      2 12 2        14
+--R                                - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                              + 
+--R                                   16
+--R                                - b
+--R                           /
+--R                                    21 3         20 2 2        19 4        18 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           4   4      3 3 3      2 5 2       7     9
+--R                       - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                  /
+--R                         11 2      10 2      9 4
+--R                     128a  c  - 64a  b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                   11 2       10 2       9 4
+--R                              (256a  c  - 128a  b c + 16a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8      7 2 7       6 4 6       5 6 5
+--R                                     - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                   + 
+--R                                           4 8 4       3 10 3      2 12 2
+--R                                     - 367a b c  + 230a b  c  - 79a b  c
+--R                                   + 
+--R                                          14     16
+--R                                     14a b  c - b
+--R                                /
+--R                                           21 3         20 2 2        19 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           18 6
+--R                                     - 256a  b
+--R                          + 
+--R                                4   4      3 3 3      2 5 2       7     9
+--R                            - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                       /
+--R                              11 2      10 2      9 4
+--R                          128a  c  - 64a  b c + 8a b
+--R            + 
+--R                4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R              (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R       -
+--R                                    +--------------------+ +------------------+
+--R                      +-----------+ |   +-----------+      | +-----------+
+--R              2 4+-+3 |          2 4|   |          2      4| |          2
+--R            2a  \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                               11 2       10 2       9 4
+--R                          (256a  c  - 128a  b c + 16a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8      7 2 7       6 4 6       5 6 5
+--R                                 - a c  + 20a b c  - 130a b c  + 314a b c
+--R                               + 
+--R                                       4 8 4       3 10 3      2 12 2        14
+--R                                 - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                               + 
+--R                                    16
+--R                                 - b
+--R                            /
+--R                                     21 3         20 2 2        19 4        18 6
+--R                               16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                      + 
+--R                            4   4      3 3 3      2 5 2       7     9
+--R                        - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                   /
+--R                          11 2      10 2      9 4
+--R                      128a  c  - 64a  b c + 8a b
+--R         *
+--R            atan
+--R                              15   6         14 3 5         13 5 4        12 7 3
+--R                         7168a  b c  - 19712a  b c  + 19264a  b c  - 9200a  b c
+--R                       + 
+--R                              11 9 2       10 11       9 13
+--R                         2336a  b c  - 304a  b  c + 16a b
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                          9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                     - 16a c  + 264a b c  - 1409a b c  + 3024a b c  - 3312a b c
+--R                   + 
+--R                          4 10 4       3 12 3       2 14 2        16     18
+--R                     2068a b  c  - 768a b  c  + 168a b  c  - 20a b  c + b
+--R                *
+--R                   ROOT
+--R                                 11 2       10 2       9 4
+--R                            (256a  c  - 128a  b c + 16a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8      7 2 7       6 4 6       5 6 5
+--R                                   - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                 + 
+--R                                         4 8 4       3 10 3      2 12 2
+--R                                   - 367a b c  + 230a b  c  - 79a b  c
+--R                                 + 
+--R                                        14     16
+--R                                   14a b  c - b
+--R                              /
+--R                                         21 3         20 2 2        19 4
+--R                                   16384a  c  - 12288a  b c  + 3072a  b c
+--R                                 + 
+--R                                         18 6
+--R                                   - 256a  b
+--R                        + 
+--R                              4   4      3 3 3      2 5 2       7     9
+--R                          - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                     /
+--R                            11 2      10 2      9 4
+--R                        128a  c  - 64a  b c + 8a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                      11 2       10 2       9 4
+--R                                 (256a  c  - 128a  b c + 16a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8      7 2 7       6 4 6
+--R                                        - a c  + 20a b c  - 130a b c
+--R                                      + 
+--R                                            5 6 5       4 8 4       3 10 3
+--R                                        314a b c  - 367a b c  + 230a b  c
+--R                                      + 
+--R                                             2 12 2        14     16
+--R                                        - 79a b  c  + 14a b  c - b
+--R                                   /
+--R                                              21 3         20 2 2        19 4
+--R                                        16384a  c  - 12288a  b c  + 3072a  b c
+--R                                      + 
+--R                                              18 6
+--R                                        - 256a  b
+--R                             + 
+--R                                   4   4      3 3 3      2 5 2       7     9
+--R                               - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                          /
+--R                                 11 2      10 2      9 4
+--R                             128a  c  - 64a  b c + 8a b
+--R              /
+--R                   4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R                 (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R                   +-----------+ |   +-----------+      | +-----------+
+--R           2 4+-+3 |          2 4|   |          2      4| |          2
+--R         2a  \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                              11 2       10 2       9 4
+--R                       (- 256a  c  + 128a  b c - 16a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8      7 2 7       6 4 6       5 6 5
+--R                              - a c  + 20a b c  - 130a b c  + 314a b c
+--R                            + 
+--R                                    4 8 4       3 10 3      2 12 2        14
+--R                              - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                            + 
+--R                                 16
+--R                              - b
+--R                         /
+--R                                  21 3         20 2 2        19 4        18 6
+--R                            16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                   + 
+--R                         4   4      3 3 3      2 5 2       7     9
+--R                     - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                /
+--R                       11 2      10 2      9 4
+--R                   128a  c  - 64a  b c + 8a b
+--R      *
+--R         atan
+--R                           15   6         14 3 5         13 5 4        12 7 3
+--R                      7168a  b c  - 19712a  b c  + 19264a  b c  - 9200a  b c
+--R                    + 
+--R                           11 9 2       10 11       9 13
+--R                      2336a  b c  - 304a  b  c + 16a b
+--R                 *
+--R                    ROOT
+--R                              8 8      7 2 7       6 4 6       5 6 5       4 8 4
+--R                           - a c  + 20a b c  - 130a b c  + 314a b c  - 367a b c
+--R                         + 
+--R                               3 10 3      2 12 2        14     16
+--R                           230a b  c  - 79a b  c  + 14a b  c - b
+--R                      /
+--R                               21 3         20 2 2        19 4        18 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                     9 9       8 2 8        7 4 7        6 6 6        5 8 5
+--R                  16a c  - 264a b c  + 1409a b c  - 3024a b c  + 3312a b c
+--R                + 
+--R                         4 10 4       3 12 3       2 14 2        16     18
+--R                  - 2068a b  c  + 768a b  c  - 168a b  c  + 20a b  c - b
+--R             *
+--R                ROOT
+--R                                11 2       10 2       9 4
+--R                         (- 256a  c  + 128a  b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8      7 2 7       6 4 6       5 6 5
+--R                                - a c  + 20a b c  - 130a b c  + 314a b c
+--R                              + 
+--R                                      4 8 4       3 10 3      2 12 2        14
+--R                                - 367a b c  + 230a b  c  - 79a b  c  + 14a b  c
+--R                              + 
+--R                                   16
+--R                                - b
+--R                           /
+--R                                    21 3         20 2 2        19 4        18 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                           4   4      3 3 3      2 5 2       7     9
+--R                       - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                  /
+--R                         11 2      10 2      9 4
+--R                     128a  c  - 64a  b c + 8a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                     11 2       10 2       9 4
+--R                              (- 256a  c  + 128a  b c - 16a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8      7 2 7       6 4 6       5 6 5
+--R                                     - a c  + 20a b c  - 130a b c  + 314a b c
+--R                                   + 
+--R                                           4 8 4       3 10 3      2 12 2
+--R                                     - 367a b c  + 230a b  c  - 79a b  c
+--R                                   + 
+--R                                          14     16
+--R                                     14a b  c - b
+--R                                /
+--R                                           21 3         20 2 2        19 4
+--R                                     16384a  c  - 12288a  b c  + 3072a  b c
+--R                                   + 
+--R                                           18 6
+--R                                     - 256a  b
+--R                          + 
+--R                                4   4      3 3 3      2 5 2       7     9
+--R                            - 9a b c  + 30a b c  - 27a b c  + 9a b c - b
+--R                       /
+--R                              11 2      10 2      9 4
+--R                          128a  c  - 64a  b c + 8a b
+--R           /
+--R                4 11      3 2 10      2 4 9       6 8    8 7  +-+
+--R              (a c   - 10a b c   + 15a b c  - 7a b c  + b c )\|x
+--R     + 
+--R                                             +------------------+
+--R             +-----------+                   | +-----------+
+--R             |          2             2 4+-+4| |          2
+--R         (2b\|- 4a c + b   + 4a c - 2b )\|c \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                             +--------------------+
+--R             +-----------+                   |   +-----------+
+--R             |          2             2 4+-+4|   |          2
+--R         (2b\|- 4a c + b   - 4a c + 2b )\|c \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                               +------------------+
+--R               +-----------+                   | +-----------+
+--R               |          2             2 4+-+4| |          2
+--R         (- 2b\|- 4a c + b   - 4a c + 2b )\|c \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                               +--------------------+
+--R               +-----------+                   |   +-----------+
+--R               |          2             2 4+-+4|   |          2
+--R         (- 2b\|- 4a c + b   + 4a c - 2b )\|c \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R       2 4+-+3 |          2 4|   |          2      4| |          2
+--R     2a  \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 628
+
+--S 629 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 629
+
+)clear all
+
+--S 630 of 1057
+t0:=x^(13/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             6 +-+
+--R                            x \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 1057
+r0:=-1/2*b*x^(3/2)/(c*(b^2-4*a*c))+1/2*x^(7/2)*(2*a+b*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/4*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(3*b^2-14*a*c+b*(3*b^2-20*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*c^(7/4)*(b^2-4*a*c)*(-b-sqrt(b^2-4*a*c))^(1/4))-1/4*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(3*b^2-_
+   14*a*c+b*(3*b^2-20*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*(b^2-4*a*c)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))+1/4*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(3*b^2-14*a*c+(-3*b^3+20*a*b*c)/sqrt(b^2-_
+   4*a*c))/(2^(3/4)*c^(7/4)*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))-_
+   1/4*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(3*b^2-_
+   14*a*c+(-3*b^3+20*a*b*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*(b^2-_
+   4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                      2     2   4                  3  2      2        2
+--R             ((- 14a c  + 3b c)x  + (- 14a b c + 3b )x  - 14a c + 3a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   4           2      4  2      2          3
+--R           (- 20a b c  + 3b c)x  + (- 20a b c + 3b )x  - 20a b c + 3a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                      2     2   4                  3  2      2        2
+--R             ((- 14a c  + 3b c)x  + (- 14a b c + 3b )x  - 14a c + 3a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   4         2      4  2      2          3
+--R           (20a b c  - 3b c)x  + (20a b c - 3b )x  + 20a b c - 3a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                                                   +-----------+
+--R                  2     2   4                3  2      2        2  |          2
+--R           ((14a c  - 3b c)x  + (14a b c - 3b )x  + 14a c - 3a b )\|- 4a c + b
+--R         + 
+--R                   2     3   4         2      4  2      2          3
+--R           (20a b c  - 3b c)x  + (20a b c - 3b )x  + 20a b c - 3a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                                                                   +-----------+
+--R                  2     2   4                3  2      2        2  |          2
+--R           ((14a c  - 3b c)x  + (14a b c - 3b )x  + 14a c - 3a b )\|- 4a c + b
+--R         + 
+--R                     2     3   4           2      4  2      2          3
+--R           (- 20a b c  + 3b c)x  + (- 20a b c + 3b )x  - 20a b c + 3a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                                          +-----------+
+--R                      2  3          4+-+3 |          2 4+-+3 +-+
+--R         ((- 4a c + 2b )x  + 2a b x)\|2  \|- 4a c + b  \|c  \|x
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R              3     2 2  4           2     3   2      2 2       2  4+-+3
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c)x  + 16a c  - 4a b c)\|2
+--R    *
+--R                            +--------------------+ +------------------+
+--R        +-----------+       |   +-----------+      | +-----------+
+--R        |          2 4+-+3 4|   |          2      4| |          2
+--R       \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3    2 2  4          2    3   2     2 2      2
+--R         ((4a c  - b c )x  + (4a b c  - b c)x  + 4a c  - a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 13            5 2 12            4 4 11
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                   3 6 10          2 8 9           10 8
+--R                         - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                       + 
+--R                              12 7
+--R                         4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                      13 20                    12 2 19
+--R                      377132488327168a  c   - 1452729738199040a  b c
+--R                    + 
+--R                                       11 4 18                    10 6 17
+--R                      2442358922674176a  b c   - 2417052975366144a  b c
+--R                    + 
+--R                                       9 8 16                   8 10 15
+--R                      1587187984367616a b c   - 734922591436800a b  c
+--R                    + 
+--R                                      7 12 14                  6 14 13
+--R                      247891016810496a b  c   - 61847931715584a b  c
+--R                    + 
+--R                                     5 16 12                 4 18 11
+--R                      11437414023168a b  c   - 1550722269184a b  c
+--R                    + 
+--R                                   3 20 10              2 22 9
+--R                      150006136832a b  c   - 9812312064a b  c
+--R                    + 
+--R                                  24 8           26 7
+--R                      389283840a b  c  - 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                  12   12                  11 3 11
+--R                  - 2837370109952a  b c   + 12923629207552a  b c
+--R                + 
+--R                                   10 5 10                  9 7 9
+--R                  - 21350329548800a  b c   + 19196566716416a b c
+--R                + 
+--R                                   8 9 8                 7 11 7
+--R                  - 10931185782784a b c  + 4238941420544a b  c
+--R                + 
+--R                                  6 13 6                5 15 5
+--R                  - 1160828675328a b  c  + 227754700992a b  c
+--R                + 
+--R                                4 17 4              3 19 3             2 21 2
+--R                  - 31919275584a b  c  + 3126283776a b  c  - 203606784a b  c
+--R                + 
+--R                            23           25
+--R                  7931520a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                           16777216a c   - 25165824a b c   + 15728640a b c
+--R                         + 
+--R                                     3 6 10          2 8 9           10 8
+--R                           - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 7
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 13            5 2 12
+--R                                16777216a c   - 25165824a b c
+--R                              + 
+--R                                         4 4 11           3 6 10          2 8 9
+--R                                15728640a b c   - 5242880a b c   + 983040a b c
+--R                              + 
+--R                                          10 8        12 7
+--R                                - 98304a b  c  + 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R            + 
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                 3    2 2  4            2    3   2     2 2      2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c)x  - 4a c  + a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                       5242880a b c   - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                      13 20                    12 2 19
+--R                      377132488327168a  c   - 1452729738199040a  b c
+--R                    + 
+--R                                       11 4 18                    10 6 17
+--R                      2442358922674176a  b c   - 2417052975366144a  b c
+--R                    + 
+--R                                       9 8 16                   8 10 15
+--R                      1587187984367616a b c   - 734922591436800a b  c
+--R                    + 
+--R                                      7 12 14                  6 14 13
+--R                      247891016810496a b  c   - 61847931715584a b  c
+--R                    + 
+--R                                     5 16 12                 4 18 11
+--R                      11437414023168a b  c   - 1550722269184a b  c
+--R                    + 
+--R                                   3 20 10              2 22 9
+--R                      150006136832a b  c   - 9812312064a b  c
+--R                    + 
+--R                                  24 8           26 7
+--R                      389283840a b  c  - 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                12   12                  11 3 11
+--R                  2837370109952a  b c   - 12923629207552a  b c
+--R                + 
+--R                                 10 5 10                  9 7 9
+--R                  21350329548800a  b c   - 19196566716416a b c
+--R                + 
+--R                                 8 9 8                 7 11 7
+--R                  10931185782784a b c  - 4238941420544a b  c
+--R                + 
+--R                                6 13 6                5 15 5
+--R                  1160828675328a b  c  - 227754700992a b  c
+--R                + 
+--R                              4 17 4              3 19 3             2 21 2
+--R                  31919275584a b  c  - 3126283776a b  c  + 203606784a b  c
+--R                + 
+--R                              23           25
+--R                  - 7931520a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                      6 13            5 2 12            4 4 11
+--R                           - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                         + 
+--R                                   3 6 10          2 8 9           10 8
+--R                           5242880a b c   - 983040a b c  + 98304a b  c
+--R                         + 
+--R                                  12 7
+--R                           - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 13            5 2 12
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 11           3 6 10
+--R                                - 15728640a b c   + 5242880a b c
+--R                              + 
+--R                                         2 8 9           10 8        12 7
+--R                                - 983040a b c  + 98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R            + 
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               3    2 2  4          2    3   2     2 2      2
+--R         ((4a c  - b c )x  + (4a b c  - b c)x  + 4a c  - a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                       5242880a b c   - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                        13 20                    12 2 19
+--R                      - 377132488327168a  c   + 1452729738199040a  b c
+--R                    + 
+--R                                         11 4 18                    10 6 17
+--R                      - 2442358922674176a  b c   + 2417052975366144a  b c
+--R                    + 
+--R                                         9 8 16                   8 10 15
+--R                      - 1587187984367616a b c   + 734922591436800a b  c
+--R                    + 
+--R                                        7 12 14                  6 14 13
+--R                      - 247891016810496a b  c   + 61847931715584a b  c
+--R                    + 
+--R                                       5 16 12                 4 18 11
+--R                      - 11437414023168a b  c   + 1550722269184a b  c
+--R                    + 
+--R                                     3 20 10              2 22 9
+--R                      - 150006136832a b  c   + 9812312064a b  c
+--R                    + 
+--R                                    24 8           26 7
+--R                      - 389283840a b  c  + 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                  12   12                  11 3 11
+--R                  - 2837370109952a  b c   + 12923629207552a  b c
+--R                + 
+--R                                   10 5 10                  9 7 9
+--R                  - 21350329548800a  b c   + 19196566716416a b c
+--R                + 
+--R                                   8 9 8                 7 11 7
+--R                  - 10931185782784a b c  + 4238941420544a b  c
+--R                + 
+--R                                  6 13 6                5 15 5
+--R                  - 1160828675328a b  c  + 227754700992a b  c
+--R                + 
+--R                                4 17 4              3 19 3             2 21 2
+--R                  - 31919275584a b  c  + 3126283776a b  c  - 203606784a b  c
+--R                + 
+--R                            23           25
+--R                  7931520a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                      6 13            5 2 12            4 4 11
+--R                           - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                         + 
+--R                                   3 6 10          2 8 9           10 8
+--R                           5242880a b c   - 983040a b c  + 98304a b  c
+--R                         + 
+--R                                  12 7
+--R                           - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 13            5 2 12
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 11           3 6 10
+--R                                - 15728640a b c   + 5242880a b c
+--R                              + 
+--R                                         2 8 9           10 8        12 7
+--R                                - 983040a b c  + 98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R            + 
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                 3    2 2  4            2    3   2     2 2      2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c)x  - 4a c  + a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 13            5 2 12            4 4 11
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                   3 6 10          2 8 9           10 8
+--R                         - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                       + 
+--R                              12 7
+--R                         4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                        13 20                    12 2 19
+--R                      - 377132488327168a  c   + 1452729738199040a  b c
+--R                    + 
+--R                                         11 4 18                    10 6 17
+--R                      - 2442358922674176a  b c   + 2417052975366144a  b c
+--R                    + 
+--R                                         9 8 16                   8 10 15
+--R                      - 1587187984367616a b c   + 734922591436800a b  c
+--R                    + 
+--R                                        7 12 14                  6 14 13
+--R                      - 247891016810496a b  c   + 61847931715584a b  c
+--R                    + 
+--R                                       5 16 12                 4 18 11
+--R                      - 11437414023168a b  c   + 1550722269184a b  c
+--R                    + 
+--R                                     3 20 10              2 22 9
+--R                      - 150006136832a b  c   + 9812312064a b  c
+--R                    + 
+--R                                    24 8           26 7
+--R                      - 389283840a b  c  + 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                12   12                  11 3 11
+--R                  2837370109952a  b c   - 12923629207552a  b c
+--R                + 
+--R                                 10 5 10                  9 7 9
+--R                  21350329548800a  b c   - 19196566716416a b c
+--R                + 
+--R                                 8 9 8                 7 11 7
+--R                  10931185782784a b c  - 4238941420544a b  c
+--R                + 
+--R                                6 13 6                5 15 5
+--R                  1160828675328a b  c  - 227754700992a b  c
+--R                + 
+--R                              4 17 4              3 19 3             2 21 2
+--R                  31919275584a b  c  - 3126283776a b  c  + 203606784a b  c
+--R                + 
+--R                              23           25
+--R                  - 7931520a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                           16777216a c   - 25165824a b c   + 15728640a b c
+--R                         + 
+--R                                     3 6 10          2 8 9           10 8
+--R                           - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 7
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 13            5 2 12
+--R                                16777216a c   - 25165824a b c
+--R                              + 
+--R                                         4 4 11           3 6 10          2 8 9
+--R                                15728640a b c   - 5242880a b c   + 983040a b c
+--R                              + 
+--R                                          10 8        12 7
+--R                                - 98304a b  c  + 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R            + 
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               3     2 2  4          2     3   2     2 2       2
+--R         ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 13            5 2 12            4 4 11
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                   3 6 10          2 8 9           10 8
+--R                         - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                       + 
+--R                              12 7
+--R                         4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                      13 20                    12 2 19
+--R                      377132488327168a  c   - 1452729738199040a  b c
+--R                    + 
+--R                                       11 4 18                    10 6 17
+--R                      2442358922674176a  b c   - 2417052975366144a  b c
+--R                    + 
+--R                                       9 8 16                   8 10 15
+--R                      1587187984367616a b c   - 734922591436800a b  c
+--R                    + 
+--R                                      7 12 14                  6 14 13
+--R                      247891016810496a b  c   - 61847931715584a b  c
+--R                    + 
+--R                                     5 16 12                 4 18 11
+--R                      11437414023168a b  c   - 1550722269184a b  c
+--R                    + 
+--R                                   3 20 10              2 22 9
+--R                      150006136832a b  c   - 9812312064a b  c
+--R                    + 
+--R                                  24 8           26 7
+--R                      389283840a b  c  - 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                  12   12                  11 3 11
+--R                  - 2837370109952a  b c   + 12923629207552a  b c
+--R                + 
+--R                                   10 5 10                  9 7 9
+--R                  - 21350329548800a  b c   + 19196566716416a b c
+--R                + 
+--R                                   8 9 8                 7 11 7
+--R                  - 10931185782784a b c  + 4238941420544a b  c
+--R                + 
+--R                                  6 13 6                5 15 5
+--R                  - 1160828675328a b  c  + 227754700992a b  c
+--R                + 
+--R                                4 17 4              3 19 3             2 21 2
+--R                  - 31919275584a b  c  + 3126283776a b  c  - 203606784a b  c
+--R                + 
+--R                            23           25
+--R                  7931520a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                           16777216a c   - 25165824a b c   + 15728640a b c
+--R                         + 
+--R                                     3 6 10          2 8 9           10 8
+--R                           - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 7
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 13            5 2 12
+--R                                16777216a c   - 25165824a b c
+--R                              + 
+--R                                         4 4 11           3 6 10          2 8 9
+--R                                15728640a b c   - 5242880a b c   + 983040a b c
+--R                              + 
+--R                                          10 8        12 7
+--R                                - 98304a b  c  + 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R           /
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                 3     2 2  4            2     3   2     2 2       2
+--R         ((- 8a c  + 2b c )x  + (- 8a b c  + 2b c)x  - 8a c  + 2a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                       5242880a b c   - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                      13 20                    12 2 19
+--R                      377132488327168a  c   - 1452729738199040a  b c
+--R                    + 
+--R                                       11 4 18                    10 6 17
+--R                      2442358922674176a  b c   - 2417052975366144a  b c
+--R                    + 
+--R                                       9 8 16                   8 10 15
+--R                      1587187984367616a b c   - 734922591436800a b  c
+--R                    + 
+--R                                      7 12 14                  6 14 13
+--R                      247891016810496a b  c   - 61847931715584a b  c
+--R                    + 
+--R                                     5 16 12                 4 18 11
+--R                      11437414023168a b  c   - 1550722269184a b  c
+--R                    + 
+--R                                   3 20 10              2 22 9
+--R                      150006136832a b  c   - 9812312064a b  c
+--R                    + 
+--R                                  24 8           26 7
+--R                      389283840a b  c  - 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                12   12                  11 3 11
+--R                  2837370109952a  b c   - 12923629207552a  b c
+--R                + 
+--R                                 10 5 10                  9 7 9
+--R                  21350329548800a  b c   - 19196566716416a b c
+--R                + 
+--R                                 8 9 8                 7 11 7
+--R                  10931185782784a b c  - 4238941420544a b  c
+--R                + 
+--R                                6 13 6                5 15 5
+--R                  1160828675328a b  c  - 227754700992a b  c
+--R                + 
+--R                              4 17 4              3 19 3             2 21 2
+--R                  31919275584a b  c  - 3126283776a b  c  + 203606784a b  c
+--R                + 
+--R                              23           25
+--R                  - 7931520a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                      6 13            5 2 12            4 4 11
+--R                           - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                         + 
+--R                                   3 6 10          2 8 9           10 8
+--R                           5242880a b c   - 983040a b c  + 98304a b  c
+--R                         + 
+--R                                  12 7
+--R                           - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 13            5 2 12
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 11           3 6 10
+--R                                - 15728640a b c   + 5242880a b c
+--R                              + 
+--R                                         2 8 9           10 8        12 7
+--R                                - 983040a b c  + 98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R           /
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                   2  3          +-+
+--R       ((- 2a c + b )x  + a b x)\|x
+--R  /
+--R          3     2 2  4          2     3   2     2 2       2
+--R     (8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 632
+
+--S 633 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +--------------------+
+--R                             +-----------+       |   +-----------+
+--R              2     2  4+-+3 |          2 4+-+3 4|   |          2
+--R         (8a c  - 2b c)\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 13            5 2 12            4 4 11
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                   3 6 10          2 8 9           10 8
+--R                         - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                       + 
+--R                              12 7
+--R                         4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                      13 20                    12 2 19
+--R                      377132488327168a  c   - 1452729738199040a  b c
+--R                    + 
+--R                                       11 4 18                    10 6 17
+--R                      2442358922674176a  b c   - 2417052975366144a  b c
+--R                    + 
+--R                                       9 8 16                   8 10 15
+--R                      1587187984367616a b c   - 734922591436800a b  c
+--R                    + 
+--R                                      7 12 14                  6 14 13
+--R                      247891016810496a b  c   - 61847931715584a b  c
+--R                    + 
+--R                                     5 16 12                 4 18 11
+--R                      11437414023168a b  c   - 1550722269184a b  c
+--R                    + 
+--R                                   3 20 10              2 22 9
+--R                      150006136832a b  c   - 9812312064a b  c
+--R                    + 
+--R                                  24 8           26 7
+--R                      389283840a b  c  - 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                  12   12                  11 3 11
+--R                  - 2837370109952a  b c   + 12923629207552a  b c
+--R                + 
+--R                                   10 5 10                  9 7 9
+--R                  - 21350329548800a  b c   + 19196566716416a b c
+--R                + 
+--R                                   8 9 8                 7 11 7
+--R                  - 10931185782784a b c  + 4238941420544a b  c
+--R                + 
+--R                                  6 13 6                5 15 5
+--R                  - 1160828675328a b  c  + 227754700992a b  c
+--R                + 
+--R                                4 17 4              3 19 3             2 21 2
+--R                  - 31919275584a b  c  + 3126283776a b  c  - 203606784a b  c
+--R                + 
+--R                            23           25
+--R                  7931520a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                           16777216a c   - 25165824a b c   + 15728640a b c
+--R                         + 
+--R                                     3 6 10          2 8 9           10 8
+--R                           - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 7
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 13            5 2 12
+--R                                16777216a c   - 25165824a b c
+--R                              + 
+--R                                         4 4 11           3 6 10          2 8 9
+--R                                15728640a b c   - 5242880a b c   + 983040a b c
+--R                              + 
+--R                                          10 8        12 7
+--R                                - 98304a b  c  + 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R            + 
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                   +--------------------+
+--R                               +-----------+       |   +-----------+
+--R                2     2  4+-+3 |          2 4+-+3 4|   |          2
+--R         (- 8a c  + 2b c)\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                       5242880a b c   - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                      13 20                    12 2 19
+--R                      377132488327168a  c   - 1452729738199040a  b c
+--R                    + 
+--R                                       11 4 18                    10 6 17
+--R                      2442358922674176a  b c   - 2417052975366144a  b c
+--R                    + 
+--R                                       9 8 16                   8 10 15
+--R                      1587187984367616a b c   - 734922591436800a b  c
+--R                    + 
+--R                                      7 12 14                  6 14 13
+--R                      247891016810496a b  c   - 61847931715584a b  c
+--R                    + 
+--R                                     5 16 12                 4 18 11
+--R                      11437414023168a b  c   - 1550722269184a b  c
+--R                    + 
+--R                                   3 20 10              2 22 9
+--R                      150006136832a b  c   - 9812312064a b  c
+--R                    + 
+--R                                  24 8           26 7
+--R                      389283840a b  c  - 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                12   12                  11 3 11
+--R                  2837370109952a  b c   - 12923629207552a  b c
+--R                + 
+--R                                 10 5 10                  9 7 9
+--R                  21350329548800a  b c   - 19196566716416a b c
+--R                + 
+--R                                 8 9 8                 7 11 7
+--R                  10931185782784a b c  - 4238941420544a b  c
+--R                + 
+--R                                6 13 6                5 15 5
+--R                  1160828675328a b  c  - 227754700992a b  c
+--R                + 
+--R                              4 17 4              3 19 3             2 21 2
+--R                  31919275584a b  c  - 3126283776a b  c  + 203606784a b  c
+--R                + 
+--R                              23           25
+--R                  - 7931520a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                      6 13            5 2 12            4 4 11
+--R                           - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                         + 
+--R                                   3 6 10          2 8 9           10 8
+--R                           5242880a b c   - 983040a b c  + 98304a b  c
+--R                         + 
+--R                                  12 7
+--R                           - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 13            5 2 12
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 11           3 6 10
+--R                                - 15728640a b c   + 5242880a b c
+--R                              + 
+--R                                         2 8 9           10 8        12 7
+--R                                - 983040a b c  + 98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R            + 
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                 +--------------------+
+--R                             +-----------+       |   +-----------+
+--R              2     2  4+-+3 |          2 4+-+3 4|   |          2
+--R         (8a c  - 2b c)\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                       5242880a b c   - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                        13 20                    12 2 19
+--R                      - 377132488327168a  c   + 1452729738199040a  b c
+--R                    + 
+--R                                         11 4 18                    10 6 17
+--R                      - 2442358922674176a  b c   + 2417052975366144a  b c
+--R                    + 
+--R                                         9 8 16                   8 10 15
+--R                      - 1587187984367616a b c   + 734922591436800a b  c
+--R                    + 
+--R                                        7 12 14                  6 14 13
+--R                      - 247891016810496a b  c   + 61847931715584a b  c
+--R                    + 
+--R                                       5 16 12                 4 18 11
+--R                      - 11437414023168a b  c   + 1550722269184a b  c
+--R                    + 
+--R                                     3 20 10              2 22 9
+--R                      - 150006136832a b  c   + 9812312064a b  c
+--R                    + 
+--R                                    24 8           26 7
+--R                      - 389283840a b  c  + 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                  12   12                  11 3 11
+--R                  - 2837370109952a  b c   + 12923629207552a  b c
+--R                + 
+--R                                   10 5 10                  9 7 9
+--R                  - 21350329548800a  b c   + 19196566716416a b c
+--R                + 
+--R                                   8 9 8                 7 11 7
+--R                  - 10931185782784a b c  + 4238941420544a b  c
+--R                + 
+--R                                  6 13 6                5 15 5
+--R                  - 1160828675328a b  c  + 227754700992a b  c
+--R                + 
+--R                                4 17 4              3 19 3             2 21 2
+--R                  - 31919275584a b  c  + 3126283776a b  c  - 203606784a b  c
+--R                + 
+--R                            23           25
+--R                  7931520a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                      6 13            5 2 12            4 4 11
+--R                           - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                         + 
+--R                                   3 6 10          2 8 9           10 8
+--R                           5242880a b c   - 983040a b c  + 98304a b  c
+--R                         + 
+--R                                  12 7
+--R                           - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 13            5 2 12
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 11           3 6 10
+--R                                - 15728640a b c   + 5242880a b c
+--R                              + 
+--R                                         2 8 9           10 8        12 7
+--R                                - 983040a b c  + 98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R            + 
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                   +--------------------+
+--R                               +-----------+       |   +-----------+
+--R                2     2  4+-+3 |          2 4+-+3 4|   |          2
+--R         (- 8a c  + 2b c)\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 13            5 2 12            4 4 11
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                   3 6 10          2 8 9           10 8
+--R                         - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                       + 
+--R                              12 7
+--R                         4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                        13 20                    12 2 19
+--R                      - 377132488327168a  c   + 1452729738199040a  b c
+--R                    + 
+--R                                         11 4 18                    10 6 17
+--R                      - 2442358922674176a  b c   + 2417052975366144a  b c
+--R                    + 
+--R                                         9 8 16                   8 10 15
+--R                      - 1587187984367616a b c   + 734922591436800a b  c
+--R                    + 
+--R                                        7 12 14                  6 14 13
+--R                      - 247891016810496a b  c   + 61847931715584a b  c
+--R                    + 
+--R                                       5 16 12                 4 18 11
+--R                      - 11437414023168a b  c   + 1550722269184a b  c
+--R                    + 
+--R                                     3 20 10              2 22 9
+--R                      - 150006136832a b  c   + 9812312064a b  c
+--R                    + 
+--R                                    24 8           26 7
+--R                      - 389283840a b  c  + 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                12   12                  11 3 11
+--R                  2837370109952a  b c   - 12923629207552a  b c
+--R                + 
+--R                                 10 5 10                  9 7 9
+--R                  21350329548800a  b c   - 19196566716416a b c
+--R                + 
+--R                                 8 9 8                 7 11 7
+--R                  10931185782784a b c  - 4238941420544a b  c
+--R                + 
+--R                                6 13 6                5 15 5
+--R                  1160828675328a b  c  - 227754700992a b  c
+--R                + 
+--R                              4 17 4              3 19 3             2 21 2
+--R                  31919275584a b  c  - 3126283776a b  c  + 203606784a b  c
+--R                + 
+--R                              23           25
+--R                  - 7931520a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                           16777216a c   - 25165824a b c   + 15728640a b c
+--R                         + 
+--R                                     3 6 10          2 8 9           10 8
+--R                           - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 7
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 13            5 2 12
+--R                                16777216a c   - 25165824a b c
+--R                              + 
+--R                                         4 4 11           3 6 10          2 8 9
+--R                                15728640a b c   - 5242880a b c   + 983040a b c
+--R                              + 
+--R                                          10 8        12 7
+--R                                - 98304a b  c  + 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R            + 
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                  +--------------------+
+--R                              +-----------+       |   +-----------+
+--R               2     2  4+-+3 |          2 4+-+3 4|   |          2
+--R         (16a c  - 4b c)\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 13            5 2 12            4 4 11
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                   3 6 10          2 8 9           10 8
+--R                         - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                       + 
+--R                              12 7
+--R                         4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                      13 20                    12 2 19
+--R                      377132488327168a  c   - 1452729738199040a  b c
+--R                    + 
+--R                                       11 4 18                    10 6 17
+--R                      2442358922674176a  b c   - 2417052975366144a  b c
+--R                    + 
+--R                                       9 8 16                   8 10 15
+--R                      1587187984367616a b c   - 734922591436800a b  c
+--R                    + 
+--R                                      7 12 14                  6 14 13
+--R                      247891016810496a b  c   - 61847931715584a b  c
+--R                    + 
+--R                                     5 16 12                 4 18 11
+--R                      11437414023168a b  c   - 1550722269184a b  c
+--R                    + 
+--R                                   3 20 10              2 22 9
+--R                      150006136832a b  c   - 9812312064a b  c
+--R                    + 
+--R                                  24 8           26 7
+--R                      389283840a b  c  - 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                  12   12                  11 3 11
+--R                  - 2837370109952a  b c   + 12923629207552a  b c
+--R                + 
+--R                                   10 5 10                  9 7 9
+--R                  - 21350329548800a  b c   + 19196566716416a b c
+--R                + 
+--R                                   8 9 8                 7 11 7
+--R                  - 10931185782784a b c  + 4238941420544a b  c
+--R                + 
+--R                                  6 13 6                5 15 5
+--R                  - 1160828675328a b  c  + 227754700992a b  c
+--R                + 
+--R                                4 17 4              3 19 3             2 21 2
+--R                  - 31919275584a b  c  + 3126283776a b  c  - 203606784a b  c
+--R                + 
+--R                            23           25
+--R                  7931520a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                           16777216a c   - 25165824a b c   + 15728640a b c
+--R                         + 
+--R                                     3 6 10          2 8 9           10 8
+--R                           - 5242880a b c   + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 7
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 13            5 2 12
+--R                                16777216a c   - 25165824a b c
+--R                              + 
+--R                                         4 4 11           3 6 10          2 8 9
+--R                                15728640a b c   - 5242880a b c   + 983040a b c
+--R                              + 
+--R                                          10 8        12 7
+--R                                - 98304a b  c  + 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R           /
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                    +--------------------+
+--R                                +-----------+       |   +-----------+
+--R                 2     2  4+-+3 |          2 4+-+3 4|   |          2
+--R         (- 16a c  + 4b c)\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 13            5 2 12            4 4 11
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                       5242880a b c   - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            9 23                 8 2 22
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 21                 6 6 20
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 19                4 10 18
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 17              2 14 16
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 15            18 14
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             6 13            5 2 12           4 4 11
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                      13 20                    12 2 19
+--R                      377132488327168a  c   - 1452729738199040a  b c
+--R                    + 
+--R                                       11 4 18                    10 6 17
+--R                      2442358922674176a  b c   - 2417052975366144a  b c
+--R                    + 
+--R                                       9 8 16                   8 10 15
+--R                      1587187984367616a b c   - 734922591436800a b  c
+--R                    + 
+--R                                      7 12 14                  6 14 13
+--R                      247891016810496a b  c   - 61847931715584a b  c
+--R                    + 
+--R                                     5 16 12                 4 18 11
+--R                      11437414023168a b  c   - 1550722269184a b  c
+--R                    + 
+--R                                   3 20 10              2 22 9
+--R                      150006136832a b  c   - 9812312064a b  c
+--R                    + 
+--R                                  24 8           26 7
+--R                      389283840a b  c  - 7077888b  c
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         9 23                 8 2 22
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 21                 6 6 20
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 19                4 10 18
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 17              2 14 16
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 15            18 14
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                                12   12                  11 3 11
+--R                  2837370109952a  b c   - 12923629207552a  b c
+--R                + 
+--R                                 10 5 10                  9 7 9
+--R                  21350329548800a  b c   - 19196566716416a b c
+--R                + 
+--R                                 8 9 8                 7 11 7
+--R                  10931185782784a b c  - 4238941420544a b  c
+--R                + 
+--R                                6 13 6                5 15 5
+--R                  1160828675328a b  c  - 227754700992a b  c
+--R                + 
+--R                              4 17 4              3 19 3             2 21 2
+--R                  31919275584a b  c  - 3126283776a b  c  + 203606784a b  c
+--R                + 
+--R                              23           25
+--R                  - 7931520a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                      6 13            5 2 12            4 4 11
+--R                           - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                         + 
+--R                                   3 6 10          2 8 9           10 8
+--R                           5242880a b c   - 983040a b c  + 98304a b  c
+--R                         + 
+--R                                  12 7
+--R                           - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 92236816a c  + 505420104a b c
+--R                              + 
+--R                                            6 4 6             5 6 5
+--R                                - 898783137a b c  + 596117340a b c
+--R                              + 
+--R                                            4 8 4            3 10 3
+--R                                - 200865582a b c  + 38499462a b  c
+--R                              + 
+--R                                          2 12 2            14         16
+--R                                - 4278501a b  c  + 258066a b  c - 6561b
+--R                           /
+--R                                              9 23                 8 2 22
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 21                 6 6 20
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 19                4 10 18
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 17              2 14 16
+--R                                90194313216a b  c   - 9663676416a b  c
+--R                              + 
+--R                                            16 15            18 14
+--R                                603979776a b  c   - 16777216b  c
+--R                     + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                     + 
+--R                              9       11
+--R                       2079a b c - 81b
+--R                  /
+--R                               6 13            5 2 12           4 4 11
+--R                       8388608a c   - 12582912a b c   + 7864320a b c
+--R                     + 
+--R                               3 6 10          2 8 9           10 8        12 7
+--R                     - 2621440a b c   + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 13            5 2 12
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 11           3 6 10
+--R                                - 15728640a b c   + 5242880a b c
+--R                              + 
+--R                                         2 8 9           10 8        12 7
+--R                                - 983040a b c  + 98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   9 23                 8 2 22
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 21                 6 6 20
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 19                4 10 18
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 17              2 14 16
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 15            18 14
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    6 13            5 2 12           4 4 11
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 10          2 8 9           10 8
+--R                            - 2621440a b c   + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 7
+--R                            2048b  c
+--R           /
+--R                              12 7                11 2 6                10 4 5
+--R                  72313663744a  c  - 234650459904a  b c  + 187135322976a  b c
+--R                + 
+--R                                9 6 4               8 8 3              7 10 2
+--R                  - 70057760976a b c  + 14494982481a b c  - 1714285782a b  c
+--R                + 
+--R                            6 12            5 14
+--R                  109114533a b  c - 2910897a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                       +------------------+
+--R                        +-----------+                  | +-----------+
+--R                     2  |          2                3 4| |          2
+--R         ((14a c - 3b )\|- 4a c + b   + 20a b c - 3b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                       +--------------------+
+--R                        +-----------+                  |   +-----------+
+--R                     2  |          2                3 4|   |          2
+--R         ((14a c - 3b )\|- 4a c + b   - 20a b c + 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                                         +------------------+
+--R                          +-----------+                  | +-----------+
+--R                       2  |          2                3 4| |          2
+--R         ((- 14a c + 3b )\|- 4a c + b   - 20a b c + 3b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                                         +--------------------+
+--R                          +-----------+                  |   +-----------+
+--R                       2  |          2                3 4|   |          2
+--R         ((- 14a c + 3b )\|- 4a c + b   + 20a b c - 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                                +--------------------+
+--R                            +-----------+       |   +-----------+
+--R             2     2  4+-+3 |          2 4+-+3 4|   |          2
+--R       (16a c  - 4b c)\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 633
+
+--S 634 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 634
+
+)clear all
+
+--S 635 of 1057
+t0:=x^(11/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             5 +-+
+--R                            x \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 1057
+r0:=1/2*x^(5/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-1/4*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(b^2-10*a*c+_
+   b*(b^2-12*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(b^2-4*a*c)*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))-1/4*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(b^2-10*a*c+b*(b^2-12*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(5/4)*(b^2-4*a*c)*(-b-sqrt(b^2-4*a*c))^(3/4))-1/4*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b^2-10*a*c-_
+   b*(b^2-12*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(b^2-4*a*c)*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))-1/4*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(b^2-10*a*c-b*(b^2-12*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(5/4)*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))-1/2*b*sqrt(x)/_
+   (c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                      2    2   4                 3  2      2       2
+--R             ((- 10a c  + b c)x  + (- 10a b c + b )x  - 10a c + a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2    3   4           2     4  2      2         3
+--R           (- 12a b c  + b c)x  + (- 12a b c + b )x  - 12a b c + a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                      2    2   4                 3  2      2       2
+--R             ((- 10a c  + b c)x  + (- 10a b c + b )x  - 10a c + a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2    3   4         2     4  2      2         3
+--R           (12a b c  - b c)x  + (12a b c - b )x  + 12a b c - a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                      2    2   4                 3  2      2       2
+--R             ((- 10a c  + b c)x  + (- 10a b c + b )x  - 10a c + a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2    3   4           2     4  2      2         3
+--R           (- 12a b c  + b c)x  + (- 12a b c + b )x  - 12a b c + a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                      2    2   4                 3  2      2       2
+--R             ((- 10a c  + b c)x  + (- 10a b c + b )x  - 10a c + a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2    3   4         2     4  2      2         3
+--R           (12a b c  - b c)x  + (12a b c - b )x  + 12a b c - a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                       +-----------+
+--R                      2  2        4+-+ |          2 4+-+ +-+
+--R         ((- 4a c + 2b )x  + 2a b)\|2 \|- 4a c + b  \|c \|x
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              3     2 2  4           2     3   2      2 2       2  4+-+
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c)x  + 16a c  - 4a b c)\|2
+--R    *
+--R                          +--------------------+3  +------------------+3
+--R        +-----------+     |   +-----------+        | +-----------+
+--R        |          2 4+-+4|   |          2        4| |          2
+--R       \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3    2 2  4            2    3   2     2 2      2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c)x  - 4a c  + a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 11            5 2 10            4 4 9
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                 3 6 8          2 8 7           10 6        12 5
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                7 12              6 2 11             5 4 10
+--R                      671088640a c   - 1040187392a b c   + 679477248a b c
+--R                    + 
+--R                                  4 6 9            3 8 8           2 10 7
+--R                      - 241172480a b c  + 49807360a b c  - 5898240a b  c
+--R                    + 
+--R                               12 6        14 5
+--R                      360448a b  c  - 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                        5   5         4 3 4         3 5 3        2 7 2        9
+--R                  80000a b c  - 56800a b c  + 14648a b c  - 1706a b c  + 94a b c
+--R                + 
+--R                      11
+--R                  - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 11            5 2 10            4 4 9
+--R                                16777216a c   - 25165824a b c   + 15728640a b c
+--R                              + 
+--R                                          3 6 8          2 8 7           10 6
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 5
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R            + 
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R               3    2 2  4          2    3   2     2 2      2
+--R         ((4a c  - b c )x  + (4a b c  - b c)x  + 4a c  - a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 11            5 2 10            4 4 9
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                7 12              6 2 11             5 4 10
+--R                      671088640a c   - 1040187392a b c   + 679477248a b c
+--R                    + 
+--R                                  4 6 9            3 8 8           2 10 7
+--R                      - 241172480a b c  + 49807360a b c  - 5898240a b  c
+--R                    + 
+--R                               12 6        14 5
+--R                      360448a b  c  - 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                          5   5         4 3 4         3 5 3        2 7 2
+--R                  - 80000a b c  + 56800a b c  - 14648a b c  + 1706a b c
+--R                + 
+--R                         9      11
+--R                  - 94a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 11            5 2 10
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 9           3 6 8          2 8 7
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                        10 6        12 5
+--R                                98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R            + 
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R                 3    2 2  4            2    3   2     2 2      2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c)x  - 4a c  + a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 11            5 2 10            4 4 9
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                  7 12              6 2 11             5 4 10
+--R                      - 671088640a c   + 1040187392a b c   - 679477248a b c
+--R                    + 
+--R                                4 6 9            3 8 8           2 10 7
+--R                      241172480a b c  - 49807360a b c  + 5898240a b  c
+--R                    + 
+--R                                 12 6        14 5
+--R                      - 360448a b  c  + 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                        5   5         4 3 4         3 5 3        2 7 2        9
+--R                  80000a b c  - 56800a b c  + 14648a b c  - 1706a b c  + 94a b c
+--R                + 
+--R                      11
+--R                  - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 11            5 2 10
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 9           3 6 8          2 8 7
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                        10 6        12 5
+--R                                98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R            + 
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R               3    2 2  4          2    3   2     2 2      2
+--R         ((4a c  - b c )x  + (4a b c  - b c)x  + 4a c  - a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 11            5 2 10            4 4 9
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                 3 6 8          2 8 7           10 6        12 5
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                  7 12              6 2 11             5 4 10
+--R                      - 671088640a c   + 1040187392a b c   - 679477248a b c
+--R                    + 
+--R                                4 6 9            3 8 8           2 10 7
+--R                      241172480a b c  - 49807360a b c  + 5898240a b  c
+--R                    + 
+--R                                 12 6        14 5
+--R                      - 360448a b  c  + 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                          5   5         4 3 4         3 5 3        2 7 2
+--R                  - 80000a b c  + 56800a b c  - 14648a b c  + 1706a b c
+--R                + 
+--R                         9      11
+--R                  - 94a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 11            5 2 10            4 4 9
+--R                                16777216a c   - 25165824a b c   + 15728640a b c
+--R                              + 
+--R                                          3 6 8          2 8 7           10 6
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 5
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R            + 
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R               3     2 2  4          2     3   2     2 2       2
+--R         ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 11            5 2 10            4 4 9
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                 3 6 8          2 8 7           10 6        12 5
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                7 12              6 2 11             5 4 10
+--R                      671088640a c   - 1040187392a b c   + 679477248a b c
+--R                    + 
+--R                                  4 6 9            3 8 8           2 10 7
+--R                      - 241172480a b c  + 49807360a b c  - 5898240a b  c
+--R                    + 
+--R                               12 6        14 5
+--R                      360448a b  c  - 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                        5   5         4 3 4         3 5 3        2 7 2        9
+--R                  80000a b c  - 56800a b c  + 14648a b c  - 1706a b c  + 94a b c
+--R                + 
+--R                      11
+--R                  - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 11            5 2 10            4 4 9
+--R                                16777216a c   - 25165824a b c   + 15728640a b c
+--R                              + 
+--R                                          3 6 8          2 8 7           10 6
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 5
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R           /
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R                 3     2 2  4            2     3   2     2 2       2
+--R         ((- 8a c  + 2b c )x  + (- 8a b c  + 2b c)x  - 8a c  + 2a b c)
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 11            5 2 10            4 4 9
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                7 12              6 2 11             5 4 10
+--R                      671088640a c   - 1040187392a b c   + 679477248a b c
+--R                    + 
+--R                                  4 6 9            3 8 8           2 10 7
+--R                      - 241172480a b c  + 49807360a b c  - 5898240a b  c
+--R                    + 
+--R                               12 6        14 5
+--R                      360448a b  c  - 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                          5   5         4 3 4         3 5 3        2 7 2
+--R                  - 80000a b c  + 56800a b c  - 14648a b c  + 1706a b c
+--R                + 
+--R                         9      11
+--R                  - 94a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 11            5 2 10
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 9           3 6 8          2 8 7
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                        10 6        12 5
+--R                                98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R           /
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R                   2  2        +-+
+--R       ((- 2a c + b )x  + a b)\|x
+--R  /
+--R          3     2 2  4          2     3   2     2 2       2
+--R     (8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 637
+
+--S 638 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                +--------------------+3
+--R                              +-----------+     |   +-----------+
+--R                2     2  4+-+ |          2 4+-+4|   |          2
+--R         (- 8a c  + 2b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 11            5 2 10            4 4 9
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                 3 6 8          2 8 7           10 6        12 5
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                7 12              6 2 11             5 4 10
+--R                      671088640a c   - 1040187392a b c   + 679477248a b c
+--R                    + 
+--R                                  4 6 9            3 8 8           2 10 7
+--R                      - 241172480a b c  + 49807360a b c  - 5898240a b  c
+--R                    + 
+--R                               12 6        14 5
+--R                      360448a b  c  - 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                        5   5         4 3 4         3 5 3        2 7 2        9
+--R                  80000a b c  - 56800a b c  + 14648a b c  - 1706a b c  + 94a b c
+--R                + 
+--R                      11
+--R                  - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 11            5 2 10            4 4 9
+--R                                16777216a c   - 25165824a b c   + 15728640a b c
+--R                              + 
+--R                                          3 6 8          2 8 7           10 6
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 5
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R            + 
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R                                              +--------------------+3
+--R                            +-----------+     |   +-----------+
+--R              2     2  4+-+ |          2 4+-+4|   |          2
+--R         (8a c  - 2b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 11            5 2 10            4 4 9
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                7 12              6 2 11             5 4 10
+--R                      671088640a c   - 1040187392a b c   + 679477248a b c
+--R                    + 
+--R                                  4 6 9            3 8 8           2 10 7
+--R                      - 241172480a b c  + 49807360a b c  - 5898240a b  c
+--R                    + 
+--R                               12 6        14 5
+--R                      360448a b  c  - 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                          5   5         4 3 4         3 5 3        2 7 2
+--R                  - 80000a b c  + 56800a b c  - 14648a b c  + 1706a b c
+--R                + 
+--R                         9      11
+--R                  - 94a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 11            5 2 10
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 9           3 6 8          2 8 7
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                        10 6        12 5
+--R                                98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R            + 
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R                                                +--------------------+3
+--R                              +-----------+     |   +-----------+
+--R                2     2  4+-+ |          2 4+-+4|   |          2
+--R         (- 8a c  + 2b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 11            5 2 10            4 4 9
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                  7 12              6 2 11             5 4 10
+--R                      - 671088640a c   + 1040187392a b c   - 679477248a b c
+--R                    + 
+--R                                4 6 9            3 8 8           2 10 7
+--R                      241172480a b c  - 49807360a b c  + 5898240a b  c
+--R                    + 
+--R                                 12 6        14 5
+--R                      - 360448a b  c  + 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                        5   5         4 3 4         3 5 3        2 7 2        9
+--R                  80000a b c  - 56800a b c  + 14648a b c  - 1706a b c  + 94a b c
+--R                + 
+--R                      11
+--R                  - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 11            5 2 10
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 9           3 6 8          2 8 7
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                        10 6        12 5
+--R                                98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R            + 
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R                                              +--------------------+3
+--R                            +-----------+     |   +-----------+
+--R              2     2  4+-+ |          2 4+-+4|   |          2
+--R         (8a c  - 2b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 11            5 2 10            4 4 9
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                 3 6 8          2 8 7           10 6        12 5
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                  7 12              6 2 11             5 4 10
+--R                      - 671088640a c   + 1040187392a b c   - 679477248a b c
+--R                    + 
+--R                                4 6 9            3 8 8           2 10 7
+--R                      241172480a b c  - 49807360a b c  + 5898240a b  c
+--R                    + 
+--R                                 12 6        14 5
+--R                      - 360448a b  c  + 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                          5   5         4 3 4         3 5 3        2 7 2
+--R                  - 80000a b c  + 56800a b c  - 14648a b c  + 1706a b c
+--R                + 
+--R                         9      11
+--R                  - 94a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 11            5 2 10            4 4 9
+--R                                16777216a c   - 25165824a b c   + 15728640a b c
+--R                              + 
+--R                                          3 6 8          2 8 7           10 6
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 5
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R            + 
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R                                               +--------------------+3
+--R                             +-----------+     |   +-----------+
+--R               2     2  4+-+ |          2 4+-+4|   |          2
+--R         (16a c  - 4b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 11            5 2 10            4 4 9
+--R                         16777216a c   - 25165824a b c   + 15728640a b c
+--R                       + 
+--R                                 3 6 8          2 8 7           10 6        12 5
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                7 12              6 2 11             5 4 10
+--R                      671088640a c   - 1040187392a b c   + 679477248a b c
+--R                    + 
+--R                                  4 6 9            3 8 8           2 10 7
+--R                      - 241172480a b c  + 49807360a b c  - 5898240a b  c
+--R                    + 
+--R                               12 6        14 5
+--R                      360448a b  c  - 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                        5   5         4 3 4         3 5 3        2 7 2        9
+--R                  80000a b c  - 56800a b c  + 14648a b c  - 1706a b c  + 94a b c
+--R                + 
+--R                      11
+--R                  - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 11            5 2 10            4 4 9
+--R                                16777216a c   - 25165824a b c   + 15728640a b c
+--R                              + 
+--R                                          3 6 8          2 8 7           10 6
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 5
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R           /
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R                                                 +--------------------+3
+--R                               +-----------+     |   +-----------+
+--R                 2     2  4+-+ |          2 4+-+4|   |          2
+--R         (- 16a c  + 4b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 11            5 2 10            4 4 9
+--R                         - 16777216a c   + 25165824a b c   - 15728640a b c
+--R                       + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            9 19                 8 2 18
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 17                 6 6 16
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 15                4 10 14
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 13              2 14 12
+--R                              90194313216a b  c   - 9663676416a b  c
+--R                            + 
+--R                                          16 11            18 10
+--R                              603979776a b  c   - 16777216b  c
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             6 11            5 2 10           4 4 9
+--R                     8388608a c   - 12582912a b c   + 7864320a b c
+--R                   + 
+--R                               3 6 8          2 8 7           10 6        12 5
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                7 12              6 2 11             5 4 10
+--R                      671088640a c   - 1040187392a b c   + 679477248a b c
+--R                    + 
+--R                                  4 6 9            3 8 8           2 10 7
+--R                      - 241172480a b c  + 49807360a b c  - 5898240a b  c
+--R                    + 
+--R                               12 6        14 5
+--R                      360448a b  c  - 8192b  c
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         9 19                 8 2 18
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 17                 6 6 16
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 15                4 10 14
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 13              2 14 12
+--R                           90194313216a b  c   - 9663676416a b  c
+--R                         + 
+--R                                       16 11            18 10
+--R                           603979776a b  c   - 16777216b  c
+--R                + 
+--R                          5   5         4 3 4         3 5 3        2 7 2
+--R                  - 80000a b c  + 56800a b c  - 14648a b c  + 1706a b c
+--R                + 
+--R                         9      11
+--R                  - 94a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 11            5 2 10
+--R                                - 16777216a c   + 25165824a b c
+--R                              + 
+--R                                           4 4 9           3 6 8          2 8 7
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                        10 6        12 5
+--R                                98304a b  c  - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   9 19                 8 2 18
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 17                 6 6 16
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 15                4 10 14
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 13              2 14 12
+--R                                     90194313216a b  c   - 9663676416a b  c
+--R                                   + 
+--R                                                 16 11            18 10
+--R                                     603979776a b  c   - 16777216b  c
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    6 11            5 2 10           4 4 9
+--R                            8388608a c   - 12582912a b c   + 7864320a b c
+--R                          + 
+--R                                      3 6 8          2 8 7           10 6
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 5
+--R                            2048b  c
+--R           /
+--R                      5 4         4 2 3        3 4 2       2 6        8  +-+
+--R              (250000a c  - 75000a b c  + 8625a b c  - 451a b c + 9a b )\|x
+--R     + 
+--R                                                     +------------------+3
+--R                       +-----------+                 | +-----------+
+--R                    2  |          2               3 4| |          2
+--R         ((10a c - b )\|- 4a c + b   + 12a b c - b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                     +--------------------+3
+--R                       +-----------+                 |   +-----------+
+--R                    2  |          2               3 4|   |          2
+--R         ((10a c - b )\|- 4a c + b   - 12a b c + b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                                     +------------------+3
+--R                       +-----------+                 | +-----------+
+--R                    2  |          2               3 4| |          2
+--R         ((10a c - b )\|- 4a c + b   + 12a b c - b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                                     +--------------------+3
+--R                       +-----------+                 |   +-----------+
+--R                    2  |          2               3 4|   |          2
+--R         ((10a c - b )\|- 4a c + b   - 12a b c + b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                             +--------------------+3
+--R                           +-----------+     |   +-----------+
+--R             2     2  4+-+ |          2 4+-+4|   |          2
+--R       (16a c  - 4b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+3
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 639
+
+)clear all
+
+--S 640 of 1057
+t0:=x^(9/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             4 +-+
+--R                            x \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 1057
+r0:=1/2*x^(3/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/4*atan(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2-12*a*c)/sqrt(b^2-_
+   4*a*c))/(2^(3/4)*c^(3/4)*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))-1/4*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2-_
+   12*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*(b^2-4*a*c)*(-b+sqrt(b^2-_
+   4*a*c))^(1/4))+1/4*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(b^2+12*a*c+b*sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*(b^2-_
+   4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(1/4))-1/4*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(b^2+12*a*c+b*sqrt(b^2-4*a*c))/_
+   (2^(3/4)*c^(3/4)*(b^2-4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                 +-----------+
+--R                 4    2 2        |          2          2    2   4
+--R           (b c x  + b x  + a b)\|- 4a c + b   + (12a c  + b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c + b )x  + 12a c + a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                                 +-----------+
+--R                 4    2 2        |          2            2    2   4
+--R           (b c x  + b x  + a b)\|- 4a c + b   + (- 12a c  - b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c - b )x  - 12a c - a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2            2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (- 12a c  - b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c - b )x  - 12a c - a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2          2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (12a c  + b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c + b )x  + 12a c + a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                                                      +--------------------+
+--R                               +-----------+          |   +-----------+
+--R                3        4+-+3 |          2 4+-+3 +-+4|   |          2
+--R         (- 2b x  - 4a x)\|2  \|- 4a c + b  \|c  \|x \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R              2     2   4                3  2      2        2 4+-+3
+--R       ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )\|2
+--R    *
+--R                            +--------------------+ +------------------+
+--R        +-----------+       |   +-----------+      | +-----------+
+--R        |          2 4+-+3 4|   |          2      4| |          2
+--R       \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 9            5 2 8            4 4 7
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                     11   14                  10 3 13
+--R                      29686813949952a  b c   - 65695819759616a  b c
+--R                    + 
+--R                                     9 5 12                  8 7 11
+--R                      64390149701632a b c   - 36644660969472a b c
+--R                    + 
+--R                                     7 9 10                 6 11 9
+--R                      13322988552192a b c   - 3201898119168a b  c
+--R                    + 
+--R                                   5 13 8               4 15 7
+--R                      507343011840a b  c  - 51136954368a b  c
+--R                    + 
+--R                                 3 17 6             2 19 5             21 4
+--R                      3070230528a b  c  - 113246208a b  c  + 5242880a b  c
+--R                    + 
+--R                               23 3
+--R                      - 262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                               9 9              8 2 8              7 4 7
+--R                  - 4586471424a c  + 5733089280a b c  - 2827616256a b c
+--R                + 
+--R                            6 6 6            5 8 5          4 10 4
+--R                  670924800a b c  - 68870144a b c  + 157696a b  c
+--R                + 
+--R                         3 12 3        2 14 2          16       18
+--R                  340480a b  c  + 9344a b  c  - 1600a b  c - 64b
+--R             *
+--R                ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     3 6 6          2 8 5           10 4
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 3
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 9            5 2 8            4 4 7
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 6          2 8 5           10 4
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 3
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R            + 
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                     11   14                  10 3 13
+--R                      29686813949952a  b c   - 65695819759616a  b c
+--R                    + 
+--R                                     9 5 12                  8 7 11
+--R                      64390149701632a b c   - 36644660969472a b c
+--R                    + 
+--R                                     7 9 10                 6 11 9
+--R                      13322988552192a b c   - 3201898119168a b  c
+--R                    + 
+--R                                   5 13 8               4 15 7
+--R                      507343011840a b  c  - 51136954368a b  c
+--R                    + 
+--R                                 3 17 6             2 19 5             21 4
+--R                      3070230528a b  c  - 113246208a b  c  + 5242880a b  c
+--R                    + 
+--R                               23 3
+--R                      - 262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                             9 9              8 2 8              7 4 7
+--R                  4586471424a c  - 5733089280a b c  + 2827616256a b c
+--R                + 
+--R                              6 6 6            5 8 5          4 10 4
+--R                  - 670924800a b c  + 68870144a b c  - 157696a b  c
+--R                + 
+--R                           3 12 3        2 14 2          16       18
+--R                  - 340480a b  c  - 9344a b  c  + 1600a b  c + 64b
+--R             *
+--R                ROOT
+--R                                      6 9            5 2 8            4 4 7
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 9            5 2 8            4 4 7
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 6          2 8 5           10 4
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12 3
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R            + 
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                       11   14                  10 3 13
+--R                      - 29686813949952a  b c   + 65695819759616a  b c
+--R                    + 
+--R                                       9 5 12                  8 7 11
+--R                      - 64390149701632a b c   + 36644660969472a b c
+--R                    + 
+--R                                       7 9 10                 6 11 9
+--R                      - 13322988552192a b c   + 3201898119168a b  c
+--R                    + 
+--R                                     5 13 8               4 15 7
+--R                      - 507343011840a b  c  + 51136954368a b  c
+--R                    + 
+--R                                   3 17 6             2 19 5             21 4
+--R                      - 3070230528a b  c  + 113246208a b  c  - 5242880a b  c
+--R                    + 
+--R                             23 3
+--R                      262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                               9 9              8 2 8              7 4 7
+--R                  - 4586471424a c  + 5733089280a b c  - 2827616256a b c
+--R                + 
+--R                            6 6 6            5 8 5          4 10 4
+--R                  670924800a b c  - 68870144a b c  + 157696a b  c
+--R                + 
+--R                         3 12 3        2 14 2          16       18
+--R                  340480a b  c  + 9344a b  c  - 1600a b  c - 64b
+--R             *
+--R                ROOT
+--R                                      6 9            5 2 8            4 4 7
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 9            5 2 8            4 4 7
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 6          2 8 5           10 4
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12 3
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R            + 
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 9            5 2 8            4 4 7
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                       11   14                  10 3 13
+--R                      - 29686813949952a  b c   + 65695819759616a  b c
+--R                    + 
+--R                                       9 5 12                  8 7 11
+--R                      - 64390149701632a b c   + 36644660969472a b c
+--R                    + 
+--R                                       7 9 10                 6 11 9
+--R                      - 13322988552192a b c   + 3201898119168a b  c
+--R                    + 
+--R                                     5 13 8               4 15 7
+--R                      - 507343011840a b  c  + 51136954368a b  c
+--R                    + 
+--R                                   3 17 6             2 19 5             21 4
+--R                      - 3070230528a b  c  + 113246208a b  c  - 5242880a b  c
+--R                    + 
+--R                             23 3
+--R                      262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                             9 9              8 2 8              7 4 7
+--R                  4586471424a c  - 5733089280a b c  + 2827616256a b c
+--R                + 
+--R                              6 6 6            5 8 5          4 10 4
+--R                  - 670924800a b c  + 68870144a b c  - 157696a b  c
+--R                + 
+--R                           3 12 3        2 14 2          16       18
+--R                  - 340480a b  c  - 9344a b  c  + 1600a b  c + 64b
+--R             *
+--R                ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     3 6 6          2 8 5           10 4
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 3
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 9            5 2 8            4 4 7
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 6          2 8 5           10 4
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 3
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R            + 
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 9            5 2 8            4 4 7
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                     11   14                  10 3 13
+--R                      29686813949952a  b c   - 65695819759616a  b c
+--R                    + 
+--R                                     9 5 12                  8 7 11
+--R                      64390149701632a b c   - 36644660969472a b c
+--R                    + 
+--R                                     7 9 10                 6 11 9
+--R                      13322988552192a b c   - 3201898119168a b  c
+--R                    + 
+--R                                   5 13 8               4 15 7
+--R                      507343011840a b  c  - 51136954368a b  c
+--R                    + 
+--R                                 3 17 6             2 19 5             21 4
+--R                      3070230528a b  c  - 113246208a b  c  + 5242880a b  c
+--R                    + 
+--R                               23 3
+--R                      - 262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                               9 9              8 2 8              7 4 7
+--R                  - 4586471424a c  + 5733089280a b c  - 2827616256a b c
+--R                + 
+--R                            6 6 6            5 8 5          4 10 4
+--R                  670924800a b c  - 68870144a b c  + 157696a b  c
+--R                + 
+--R                         3 12 3        2 14 2          16       18
+--R                  340480a b  c  + 9344a b  c  - 1600a b  c - 64b
+--R             *
+--R                ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     3 6 6          2 8 5           10 4
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 3
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 9            5 2 8            4 4 7
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 6          2 8 5           10 4
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 3
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R           /
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                 2     2   4                 3  2     2        2
+--R         ((- 8a c  + 2b c)x  + (- 8a b c + 2b )x  - 8a c + 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                     11   14                  10 3 13
+--R                      29686813949952a  b c   - 65695819759616a  b c
+--R                    + 
+--R                                     9 5 12                  8 7 11
+--R                      64390149701632a b c   - 36644660969472a b c
+--R                    + 
+--R                                     7 9 10                 6 11 9
+--R                      13322988552192a b c   - 3201898119168a b  c
+--R                    + 
+--R                                   5 13 8               4 15 7
+--R                      507343011840a b  c  - 51136954368a b  c
+--R                    + 
+--R                                 3 17 6             2 19 5             21 4
+--R                      3070230528a b  c  - 113246208a b  c  + 5242880a b  c
+--R                    + 
+--R                               23 3
+--R                      - 262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                             9 9              8 2 8              7 4 7
+--R                  4586471424a c  - 5733089280a b c  + 2827616256a b c
+--R                + 
+--R                              6 6 6            5 8 5          4 10 4
+--R                  - 670924800a b c  + 68870144a b c  - 157696a b  c
+--R                + 
+--R                           3 12 3        2 14 2          16       18
+--R                  - 340480a b  c  - 9344a b  c  + 1600a b  c + 64b
+--R             *
+--R                ROOT
+--R                                      6 9            5 2 8            4 4 7
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 9            5 2 8            4 4 7
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 6          2 8 5           10 4
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12 3
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R           /
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R             3         +-+
+--R       (- b x  - 2a x)\|x
+--R  /
+--R          2     2   4               3  2     2        2
+--R     (8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 642
+
+--S 643 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +--------------------+
+--R                           +-----------+       |   +-----------+
+--R                   2 4+-+3 |          2 4+-+3 4|   |          2
+--R         (8a c - 2b )\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 9            5 2 8            4 4 7
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                     11   14                  10 3 13
+--R                      29686813949952a  b c   - 65695819759616a  b c
+--R                    + 
+--R                                     9 5 12                  8 7 11
+--R                      64390149701632a b c   - 36644660969472a b c
+--R                    + 
+--R                                     7 9 10                 6 11 9
+--R                      13322988552192a b c   - 3201898119168a b  c
+--R                    + 
+--R                                   5 13 8               4 15 7
+--R                      507343011840a b  c  - 51136954368a b  c
+--R                    + 
+--R                                 3 17 6             2 19 5             21 4
+--R                      3070230528a b  c  - 113246208a b  c  + 5242880a b  c
+--R                    + 
+--R                               23 3
+--R                      - 262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                               9 9              8 2 8              7 4 7
+--R                  - 4586471424a c  + 5733089280a b c  - 2827616256a b c
+--R                + 
+--R                            6 6 6            5 8 5          4 10 4
+--R                  670924800a b c  - 68870144a b c  + 157696a b  c
+--R                + 
+--R                         3 12 3        2 14 2          16       18
+--R                  340480a b  c  + 9344a b  c  - 1600a b  c - 64b
+--R             *
+--R                ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     3 6 6          2 8 5           10 4
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 3
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 9            5 2 8            4 4 7
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 6          2 8 5           10 4
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 3
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R            + 
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                 +--------------------+
+--R                             +-----------+       |   +-----------+
+--R                     2 4+-+3 |          2 4+-+3 4|   |          2
+--R         (- 8a c + 2b )\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                     11   14                  10 3 13
+--R                      29686813949952a  b c   - 65695819759616a  b c
+--R                    + 
+--R                                     9 5 12                  8 7 11
+--R                      64390149701632a b c   - 36644660969472a b c
+--R                    + 
+--R                                     7 9 10                 6 11 9
+--R                      13322988552192a b c   - 3201898119168a b  c
+--R                    + 
+--R                                   5 13 8               4 15 7
+--R                      507343011840a b  c  - 51136954368a b  c
+--R                    + 
+--R                                 3 17 6             2 19 5             21 4
+--R                      3070230528a b  c  - 113246208a b  c  + 5242880a b  c
+--R                    + 
+--R                               23 3
+--R                      - 262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                             9 9              8 2 8              7 4 7
+--R                  4586471424a c  - 5733089280a b c  + 2827616256a b c
+--R                + 
+--R                              6 6 6            5 8 5          4 10 4
+--R                  - 670924800a b c  + 68870144a b c  - 157696a b  c
+--R                + 
+--R                           3 12 3        2 14 2          16       18
+--R                  - 340480a b  c  - 9344a b  c  + 1600a b  c + 64b
+--R             *
+--R                ROOT
+--R                                      6 9            5 2 8            4 4 7
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 9            5 2 8            4 4 7
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 6          2 8 5           10 4
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12 3
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R            + 
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                               +--------------------+
+--R                           +-----------+       |   +-----------+
+--R                   2 4+-+3 |          2 4+-+3 4|   |          2
+--R         (8a c - 2b )\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                       11   14                  10 3 13
+--R                      - 29686813949952a  b c   + 65695819759616a  b c
+--R                    + 
+--R                                       9 5 12                  8 7 11
+--R                      - 64390149701632a b c   + 36644660969472a b c
+--R                    + 
+--R                                       7 9 10                 6 11 9
+--R                      - 13322988552192a b c   + 3201898119168a b  c
+--R                    + 
+--R                                     5 13 8               4 15 7
+--R                      - 507343011840a b  c  + 51136954368a b  c
+--R                    + 
+--R                                   3 17 6             2 19 5             21 4
+--R                      - 3070230528a b  c  + 113246208a b  c  - 5242880a b  c
+--R                    + 
+--R                             23 3
+--R                      262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                               9 9              8 2 8              7 4 7
+--R                  - 4586471424a c  + 5733089280a b c  - 2827616256a b c
+--R                + 
+--R                            6 6 6            5 8 5          4 10 4
+--R                  670924800a b c  - 68870144a b c  + 157696a b  c
+--R                + 
+--R                         3 12 3        2 14 2          16       18
+--R                  340480a b  c  + 9344a b  c  - 1600a b  c - 64b
+--R             *
+--R                ROOT
+--R                                      6 9            5 2 8            4 4 7
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 9            5 2 8            4 4 7
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 6          2 8 5           10 4
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12 3
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R            + 
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                 +--------------------+
+--R                             +-----------+       |   +-----------+
+--R                     2 4+-+3 |          2 4+-+3 4|   |          2
+--R         (- 8a c + 2b )\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 9            5 2 8            4 4 7
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                       11   14                  10 3 13
+--R                      - 29686813949952a  b c   + 65695819759616a  b c
+--R                    + 
+--R                                       9 5 12                  8 7 11
+--R                      - 64390149701632a b c   + 36644660969472a b c
+--R                    + 
+--R                                       7 9 10                 6 11 9
+--R                      - 13322988552192a b c   + 3201898119168a b  c
+--R                    + 
+--R                                     5 13 8               4 15 7
+--R                      - 507343011840a b  c  + 51136954368a b  c
+--R                    + 
+--R                                   3 17 6             2 19 5             21 4
+--R                      - 3070230528a b  c  + 113246208a b  c  - 5242880a b  c
+--R                    + 
+--R                             23 3
+--R                      262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                             9 9              8 2 8              7 4 7
+--R                  4586471424a c  - 5733089280a b c  + 2827616256a b c
+--R                + 
+--R                              6 6 6            5 8 5          4 10 4
+--R                  - 670924800a b c  + 68870144a b c  - 157696a b  c
+--R                + 
+--R                           3 12 3        2 14 2          16       18
+--R                  - 340480a b  c  - 9344a b  c  + 1600a b  c + 64b
+--R             *
+--R                ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     3 6 6          2 8 5           10 4
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 3
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 9            5 2 8            4 4 7
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 6          2 8 5           10 4
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 3
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R            + 
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                +--------------------+
+--R                            +-----------+       |   +-----------+
+--R                    2 4+-+3 |          2 4+-+3 4|   |          2
+--R         (16a c - 4b )\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 9            5 2 8            4 4 7
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                     11   14                  10 3 13
+--R                      29686813949952a  b c   - 65695819759616a  b c
+--R                    + 
+--R                                     9 5 12                  8 7 11
+--R                      64390149701632a b c   - 36644660969472a b c
+--R                    + 
+--R                                     7 9 10                 6 11 9
+--R                      13322988552192a b c   - 3201898119168a b  c
+--R                    + 
+--R                                   5 13 8               4 15 7
+--R                      507343011840a b  c  - 51136954368a b  c
+--R                    + 
+--R                                 3 17 6             2 19 5             21 4
+--R                      3070230528a b  c  - 113246208a b  c  + 5242880a b  c
+--R                    + 
+--R                               23 3
+--R                      - 262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                               9 9              8 2 8              7 4 7
+--R                  - 4586471424a c  + 5733089280a b c  - 2827616256a b c
+--R                + 
+--R                            6 6 6            5 8 5          4 10 4
+--R                  670924800a b c  - 68870144a b c  + 157696a b  c
+--R                + 
+--R                         3 12 3        2 14 2          16       18
+--R                  340480a b  c  + 9344a b  c  - 1600a b  c - 64b
+--R             *
+--R                ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     3 6 6          2 8 5           10 4
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                12 3
+--R                           4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 9            5 2 8            4 4 7
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 6          2 8 5           10 4
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12 3
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R           /
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                  +--------------------+
+--R                              +-----------+       |   +-----------+
+--R                      2 4+-+3 |          2 4+-+3 4|   |          2
+--R         (- 16a c + 4b )\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 9            5 2 8            4 4 7
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                       5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            9 15                 8 2 14
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 13                 6 6 12
+--R                              9895604649984a b c   - 5772436045824a b c
+--R                            + 
+--R                                            5 8 11                4 10 10
+--R                              2164663517184a b c   - 541165879296a b  c
+--R                            + 
+--R                                          3 12 9              2 14 8
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 7            18 6
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             6 9            5 2 8           4 4 7
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                     11   14                  10 3 13
+--R                      29686813949952a  b c   - 65695819759616a  b c
+--R                    + 
+--R                                     9 5 12                  8 7 11
+--R                      64390149701632a b c   - 36644660969472a b c
+--R                    + 
+--R                                     7 9 10                 6 11 9
+--R                      13322988552192a b c   - 3201898119168a b  c
+--R                    + 
+--R                                   5 13 8               4 15 7
+--R                      507343011840a b  c  - 51136954368a b  c
+--R                    + 
+--R                                 3 17 6             2 19 5             21 4
+--R                      3070230528a b  c  - 113246208a b  c  + 5242880a b  c
+--R                    + 
+--R                               23 3
+--R                      - 262144b  c
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         9 15                 8 2 14
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 13                 6 6 12
+--R                           9895604649984a b c   - 5772436045824a b c
+--R                         + 
+--R                                         5 8 11                4 10 10
+--R                           2164663517184a b c   - 541165879296a b  c
+--R                         + 
+--R                                       3 12 9              2 14 8
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 7            18 6
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                             9 9              8 2 8              7 4 7
+--R                  4586471424a c  - 5733089280a b c  + 2827616256a b c
+--R                + 
+--R                              6 6 6            5 8 5          4 10 4
+--R                  - 670924800a b c  + 68870144a b c  - 157696a b  c
+--R                + 
+--R                           3 12 3        2 14 2          16       18
+--R                  - 340480a b  c  - 9344a b  c  + 1600a b  c + 64b
+--R             *
+--R                ROOT
+--R                                      6 9            5 2 8            4 4 7
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 3 6 6          2 8 5           10 4        12 3
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3        2 4 2
+--R                                - 104976a c  - 17496a b c  - 1377a b c
+--R                              + 
+--R                                       6     8
+--R                                - 54a b c - b
+--R                           /
+--R                                              9 15                 8 2 14
+--R                                4398046511104a c   - 9895604649984a b c
+--R                              + 
+--R                                              7 4 13                 6 6 12
+--R                                9895604649984a b c   - 5772436045824a b c
+--R                              + 
+--R                                              5 8 11                4 10 10
+--R                                2164663517184a b c   - 541165879296a b  c
+--R                              + 
+--R                                            3 12 9              2 14 8
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                            16 7            18 6
+--R                                603979776a b  c  - 16777216b  c
+--R                     + 
+--R                              3   3       2 3 2        5     7
+--R                       - 3024a b c  - 168a b c  - 21a b c - b
+--R                  /
+--R                               6 9            5 2 8           4 4 7
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                               3 6 6          2 8 5           10 4        12 3
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 9            5 2 8            4 4 7
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 6          2 8 5           10 4
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12 3
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   9 15                 8 2 14
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 13                 6 6 12
+--R                                     9895604649984a b c   - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 11                4 10 10
+--R                                     2164663517184a b c   - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 9              2 14 8
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 7            18 6
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    6 9            5 2 8           4 4 7
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 6          2 8 5           10 4
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12 3
+--R                            2048b  c
+--R           /
+--R                           7 5            6 2 4           5 4 3          4 6 2
+--R                  15116544a c  + 10077696a b c  + 2496096a b c  + 281232a b c
+--R                + 
+--R                        3 8        2 10
+--R                  14553a b c + 343a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                          +------------------+
+--R              +-----------+               | +-----------+
+--R              |          2             2 4| |          2
+--R         (- b\|- 4a c + b   - 12a c - b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                          +--------------------+
+--R              +-----------+               |   +-----------+
+--R              |          2             2 4|   |          2
+--R         (- b\|- 4a c + b   + 12a c + b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2             2 4| |          2
+--R         (b\|- 4a c + b   + 12a c + b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2             2 4|   |          2
+--R         (b\|- 4a c + b   - 12a c - b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                              +--------------------+
+--R                          +-----------+       |   +-----------+
+--R                  2 4+-+3 |          2 4+-+3 4|   |          2
+--R       (16a c - 4b )\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 644
+
+)clear all
+
+--S 645 of 1057
+t0:=x^(7/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             3 +-+
+--R                            x \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 645
+
+--S 646 of 1057
+r0:=1/4*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(3*b^2+_
+   4*a*c-3*b*sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*(b^2-4*a*c)^(3/2)*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))+1/4*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(3*b^2+4*a*c-3*b*sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(1/4)*(b^2-4*a*c)^(3/2)*(-b+sqrt(b^2-4*a*c))^(3/4))-1/4*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(3*b^2+_
+   4*a*c+3*b*sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*(b^2-4*a*c)^(3/2)*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))-1/4*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(3*b^2+4*a*c+3*b*sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(1/4)*(b^2-4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(3/4))+1/2*(2*a+b*x^2)*_
+   sqrt(x)/((b^2-4*a*c)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                                    +-----------+
+--R                  4     2 2         |          2         2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (4a c  + 3b c)x
+--R         + 
+--R                       3  2     2        2
+--R           (4a b c + 3b )x  + 4a c + 3a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2           2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (- 4a c  - 3b c)x
+--R         + 
+--R                         3  2     2        2
+--R           (- 4a b c - 3b )x  - 4a c - 3a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2         2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (4a c  + 3b c)x
+--R         + 
+--R                       3  2     2        2
+--R           (4a b c + 3b )x  + 4a c + 3a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2           2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (- 4a c  - 3b c)x
+--R         + 
+--R                         3  2     2        2
+--R           (- 4a b c - 3b )x  - 4a c - 3a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                                  +--------------------+3
+--R                            +-----------+         |   +-----------+
+--R                2      4+-+ |          2 4+-+ +-+4|   |          2
+--R         (- 2b x  - 4a)\|2 \|- 4a c + b  \|c \|x \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R                                                                   +-----------+
+--R              2     2   4                3  2      2        2 4+-+ |          2
+--R       ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )\|2 \|- 4a c + b
+--R    *
+--R            +--------------------+3  +------------------+3
+--R            |   +-----------+        | +-----------+
+--R       4+-+4|   |          2        4| |          2
+--R       \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 7            5 2 6            4 4 5
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                6   7             5 3 6             4 5 5
+--R                      268435456a b c  - 402653184a b c  + 251658240a b c
+--R                    + 
+--R                                 3 7 4            2 9 3             11 2
+--R                      - 83886080a b c  + 15728640a b c  - 1572864a b  c
+--R                    + 
+--R                            13
+--R                      65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                      3 3        2 2 2          4        6
+--R                  256a c  - 5312a b c  + 2608a b c - 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 7            5 2 6            4 4 5
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 4          2 8 3           10 2
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R            + 
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 7            5 2 6            4 4 5
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                6   7             5 3 6             4 5 5
+--R                      268435456a b c  - 402653184a b c  + 251658240a b c
+--R                    + 
+--R                                 3 7 4            2 9 3             11 2
+--R                      - 83886080a b c  + 15728640a b c  - 1572864a b  c
+--R                    + 
+--R                            13
+--R                      65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                        3 3        2 2 2          4        6
+--R                  - 256a c  + 5312a b c  - 2608a b c + 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 7            5 2 6            4 4 5
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 4          2 8 3           10 2
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R            + 
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 7            5 2 6            4 4 5
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                  6   7             5 3 6             4 5 5
+--R                      - 268435456a b c  + 402653184a b c  - 251658240a b c
+--R                    + 
+--R                             3 7 4            2 9 3             11 2         13
+--R                    83886080a b c  - 15728640a b c  + 1572864a b  c  - 65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                      3 3        2 2 2          4        6
+--R                  256a c  - 5312a b c  + 2608a b c - 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 7            5 2 6            4 4 5
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 4          2 8 3           10 2
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R            + 
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 7            5 2 6            4 4 5
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                  6   7             5 3 6             4 5 5
+--R                      - 268435456a b c  + 402653184a b c  - 251658240a b c
+--R                    + 
+--R                             3 7 4            2 9 3             11 2         13
+--R                    83886080a b c  - 15728640a b c  + 1572864a b  c  - 65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                        3 3        2 2 2          4        6
+--R                  - 256a c  + 5312a b c  - 2608a b c + 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 7            5 2 6            4 4 5
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 4          2 8 3           10 2
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R            + 
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R                 2     2   4                 3  2     2        2
+--R         ((- 8a c  + 2b c)x  + (- 8a b c + 2b )x  - 8a c + 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 7            5 2 6            4 4 5
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                6   7             5 3 6             4 5 5
+--R                      268435456a b c  - 402653184a b c  + 251658240a b c
+--R                    + 
+--R                                 3 7 4            2 9 3             11 2
+--R                      - 83886080a b c  + 15728640a b c  - 1572864a b  c
+--R                    + 
+--R                            13
+--R                      65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                      3 3        2 2 2          4        6
+--R                  256a c  - 5312a b c  + 2608a b c - 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 7            5 2 6            4 4 5
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 4          2 8 3           10 2
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R           /
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 7            5 2 6            4 4 5
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                6   7             5 3 6             4 5 5
+--R                      268435456a b c  - 402653184a b c  + 251658240a b c
+--R                    + 
+--R                                 3 7 4            2 9 3             11 2
+--R                      - 83886080a b c  + 15728640a b c  - 1572864a b  c
+--R                    + 
+--R                            13
+--R                      65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                        3 3        2 2 2          4        6
+--R                  - 256a c  + 5312a b c  - 2608a b c + 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 7            5 2 6            4 4 5
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 4          2 8 3           10 2
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R           /
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R             2       +-+
+--R       (- b x  - 2a)\|x
+--R  /
+--R          2     2   4               3  2     2        2
+--R     (8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 647
+
+--S 648 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +--------------------+3
+--R                          +-----------+     |   +-----------+
+--R                   2 4+-+ |          2 4+-+4|   |          2
+--R         (8a c - 2b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 7            5 2 6            4 4 5
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                6   7             5 3 6             4 5 5
+--R                      268435456a b c  - 402653184a b c  + 251658240a b c
+--R                    + 
+--R                                 3 7 4            2 9 3             11 2
+--R                      - 83886080a b c  + 15728640a b c  - 1572864a b  c
+--R                    + 
+--R                            13
+--R                      65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                      3 3        2 2 2          4        6
+--R                  256a c  - 5312a b c  + 2608a b c - 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 7            5 2 6            4 4 5
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 4          2 8 3           10 2
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R            + 
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R                                              +--------------------+3
+--R                            +-----------+     |   +-----------+
+--R                     2 4+-+ |          2 4+-+4|   |          2
+--R         (- 8a c + 2b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 7            5 2 6            4 4 5
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                6   7             5 3 6             4 5 5
+--R                      268435456a b c  - 402653184a b c  + 251658240a b c
+--R                    + 
+--R                                 3 7 4            2 9 3             11 2
+--R                      - 83886080a b c  + 15728640a b c  - 1572864a b  c
+--R                    + 
+--R                            13
+--R                      65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                        3 3        2 2 2          4        6
+--R                  - 256a c  + 5312a b c  - 2608a b c + 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 7            5 2 6            4 4 5
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 4          2 8 3           10 2
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R            + 
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R                                            +--------------------+3
+--R                          +-----------+     |   +-----------+
+--R                   2 4+-+ |          2 4+-+4|   |          2
+--R         (8a c - 2b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 7            5 2 6            4 4 5
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                  6   7             5 3 6             4 5 5
+--R                      - 268435456a b c  + 402653184a b c  - 251658240a b c
+--R                    + 
+--R                             3 7 4            2 9 3             11 2         13
+--R                    83886080a b c  - 15728640a b c  + 1572864a b  c  - 65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                      3 3        2 2 2          4        6
+--R                  256a c  - 5312a b c  + 2608a b c - 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 7            5 2 6            4 4 5
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 4          2 8 3           10 2
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R            + 
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R                                              +--------------------+3
+--R                            +-----------+     |   +-----------+
+--R                     2 4+-+ |          2 4+-+4|   |          2
+--R         (- 8a c + 2b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 7            5 2 6            4 4 5
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         log
+--R                                  6   7             5 3 6             4 5 5
+--R                      - 268435456a b c  + 402653184a b c  - 251658240a b c
+--R                    + 
+--R                             3 7 4            2 9 3             11 2         13
+--R                    83886080a b c  - 15728640a b c  + 1572864a b  c  - 65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                        3 3        2 2 2          4        6
+--R                  - 256a c  + 5312a b c  - 2608a b c + 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 7            5 2 6            4 4 5
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 4          2 8 3           10 2
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R            + 
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R                                               +--------------------+3
+--R                             +-----------+     |   +-----------+
+--R                      2 4+-+ |          2 4+-+4|   |          2
+--R         (- 16a c + 4b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  6 7            5 2 6            4 4 5
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c  + 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                6   7             5 3 6             4 5 5
+--R                      268435456a b c  - 402653184a b c  + 251658240a b c
+--R                    + 
+--R                                 3 7 4            2 9 3             11 2
+--R                      - 83886080a b c  + 15728640a b c  - 1572864a b  c
+--R                    + 
+--R                            13
+--R                      65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                      3 3        2 2 2          4        6
+--R                  256a c  - 5312a b c  + 2608a b c - 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         6 7            5 2 6            4 4 5
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          3 6 4          2 8 3           10 2
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     12
+--R                                4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R           /
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R                                             +--------------------+3
+--R                           +-----------+     |   +-----------+
+--R                    2 4+-+ |          2 4+-+4|   |          2
+--R         (16a c - 4b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    6 7            5 2 6            4 4 5
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 3 6 4          2 8 3           10 2        12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c  - 4096b  c
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            9 11                 8 2 10
+--R                              4398046511104a c   - 9895604649984a b c
+--R                            + 
+--R                                            7 4 9                 6 6 8
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            5 8 7                4 10 6
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          3 12 5              2 14 4
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                          16 3            18 2
+--R                              603979776a b  c  - 16777216b  c
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             6 7            5 2 6           4 4 5
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               3 6 4          2 8 3           10 2        12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c  + 2048b  c
+--R      *
+--R         atan
+--R                                6   7             5 3 6             4 5 5
+--R                      268435456a b c  - 402653184a b c  + 251658240a b c
+--R                    + 
+--R                                 3 7 4            2 9 3             11 2
+--R                      - 83886080a b c  + 15728640a b c  - 1572864a b  c
+--R                    + 
+--R                            13
+--R                      65536b  c
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         9 11                 8 2 10
+--R                           4398046511104a c   - 9895604649984a b c
+--R                         + 
+--R                                         7 4 9                 6 6 8
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         5 8 7                4 10 6
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       3 12 5              2 14 4
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                       16 3            18 2
+--R                           603979776a b  c  - 16777216b  c
+--R                + 
+--R                        3 3        2 2 2          4        6
+--R                  - 256a c  + 5312a b c  - 2608a b c + 324b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           6 7            5 2 6            4 4 5
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        3 6 4          2 8 3           10 2
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       12
+--R                                - 4096b  c
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   9 11                 8 2 10
+--R                                     4398046511104a c   - 9895604649984a b c
+--R                                   + 
+--R                                                   7 4 9                 6 6 8
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   5 8 7                4 10 6
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 3 12 5              2 14 4
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                                 16 3            18 2
+--R                                     603979776a b  c  - 16777216b  c
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    6 7            5 2 6           4 4 5
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      3 6 4          2 8 3           10 2
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 12
+--R                            2048b  c
+--R           /
+--R                  2 2         2         4  +-+
+--R              (16a c  - 264a b c - 1215b )\|x
+--R     + 
+--R                                           +------------------+3
+--R               +-----------+               | +-----------+
+--R               |          2             2 4| |          2
+--R         (- 3b\|- 4a c + b   - 4a c - 3b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+3
+--R               +-----------+               |   +-----------+
+--R               |          2             2 4|   |          2
+--R         (- 3b\|- 4a c + b   + 4a c + 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                           +------------------+3
+--R               +-----------+               | +-----------+
+--R               |          2             2 4| |          2
+--R         (- 3b\|- 4a c + b   - 4a c - 3b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+3
+--R               +-----------+               |   +-----------+
+--R               |          2             2 4|   |          2
+--R         (- 3b\|- 4a c + b   + 4a c + 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                           +--------------------+3
+--R                         +-----------+     |   +-----------+
+--R                  2 4+-+ |          2 4+-+4|   |          2
+--R       (16a c - 4b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+3
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 649
+
+)clear all
+
+--S 650 of 1057
+t0:=x^(5/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             2 +-+
+--R                            x \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 1057
+r0:=-1/2*x^(3/2)*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(4*b-_
+   sqrt(b^2-4*a*c))/(2^(3/4)*(b^2-4*a*c)^(3/2)*(-b+sqrt(b^2-4*a*c))^(1/4))-_
+   1/2*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (4*b-sqrt(b^2-4*a*c))/(2^(3/4)*(b^2-4*a*c)^(3/2)*(-b+sqrt(b^2-_
+   4*a*c))^(1/4))-1/2*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(4*b+sqrt(b^2-4*a*c))/(2^(3/4)*(b^2-_
+   4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(1/4))+1/2*c^(1/4)*atanh(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(4*b+sqrt(b^2-4*a*c))/_
+   (2^(3/4)*(b^2-4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                              +-----------+
+--R                4      2      |          2          4     2 2        4+-+
+--R         ((- c x  - b x  - a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                              +-----------+
+--R                4      2      |          2          4     2 2        4+-+
+--R         ((- c x  - b x  - a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R              4      2      |          2          4     2 2        4+-+
+--R         ((c x  + b x  + a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R              4      2      |          2          4     2 2        4+-+
+--R         ((c x  + b x  + a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                                              +--------------------+
+--R                            +-----------+     |   +-----------+
+--R              3       4+-+3 |          2  +-+4|   |          2
+--R         (2c x  + b x)\|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R                                                                 +-----------+
+--R             2     2   4               3  2     2        2 4+-+3 |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2  \|- 4a c + b
+--R    *
+--R        +--------------------+ +------------------+
+--R        |   +-----------+      | +-----------+
+--R       4|   |          2      4| |          2
+--R       \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  7 6            6 2 5            5 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                    12 11                  11 2 10
+--R                      1099511627776a  c   - 12919261626368a  b c
+--R                    + 
+--R                                     10 4 9                  9 6 8
+--R                      24120536334336a  b c  - 20770461843456a b c
+--R                    + 
+--R                                     8 8 7                 7 10 6
+--R                      10075993276416a b c  - 2841120866304a b  c
+--R                    + 
+--R                                   6 12 5               5 14 4
+--R                      394600120320a b  c  + 11676942336a b  c
+--R                    + 
+--R                                    4 16 3              3 18 2             2 20
+--R                      - 14948499456a b  c  + 2638217216a b  c  - 214958080a b  c
+--R                    + 
+--R                                22
+--R                      7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                             7   7             6 3 6             5 5 5
+--R                  - 11534336a b c  + 255066112a b c  - 451346432a b c
+--R                + 
+--R                            4 7 4             3 9 3            2 11 2
+--R                  331366400a b c  - 127406080a b c  + 27106304a b  c
+--R                + 
+--R                              13           15
+--R                  - 3034368a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     4 6 3          3 8 2         2 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                  12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         7 6            6 2 5            5 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          4 6 3          3 8 2         2 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                       12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R            + 
+--R                 4 5        3 2 4         2 4 3            6 2          8   +-+
+--R            (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)\|x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                    12 11                  11 2 10
+--R                      1099511627776a  c   - 12919261626368a  b c
+--R                    + 
+--R                                     10 4 9                  9 6 8
+--R                      24120536334336a  b c  - 20770461843456a b c
+--R                    + 
+--R                                     8 8 7                 7 10 6
+--R                      10075993276416a b c  - 2841120866304a b  c
+--R                    + 
+--R                                   6 12 5               5 14 4
+--R                      394600120320a b  c  + 11676942336a b  c
+--R                    + 
+--R                                    4 16 3              3 18 2             2 20
+--R                      - 14948499456a b  c  + 2638217216a b  c  - 214958080a b  c
+--R                    + 
+--R                                22
+--R                      7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                           7   7             6 3 6             5 5 5
+--R                  11534336a b c  - 255066112a b c  + 451346432a b c
+--R                + 
+--R                              4 7 4             3 9 3            2 11 2
+--R                  - 331366400a b c  + 127406080a b c  - 27106304a b  c
+--R                + 
+--R                            13           15
+--R                  3034368a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                      7 6            6 2 5            5 4 4
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           7 6            6 2 5            5 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        4 6 3          3 8 2         2 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                         12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R            + 
+--R                 4 5        3 2 4         2 4 3            6 2          8   +-+
+--R            (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)\|x
+--R     + 
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                      12 11                  11 2 10
+--R                      - 1099511627776a  c   + 12919261626368a  b c
+--R                    + 
+--R                                       10 4 9                  9 6 8
+--R                      - 24120536334336a  b c  + 20770461843456a b c
+--R                    + 
+--R                                       8 8 7                 7 10 6
+--R                      - 10075993276416a b c  + 2841120866304a b  c
+--R                    + 
+--R                                     6 12 5               5 14 4
+--R                      - 394600120320a b  c  - 11676942336a b  c
+--R                    + 
+--R                                  4 16 3              3 18 2             2 20
+--R                      14948499456a b  c  - 2638217216a b  c  + 214958080a b  c
+--R                    + 
+--R                                  22
+--R                      - 7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                             7   7             6 3 6             5 5 5
+--R                  - 11534336a b c  + 255066112a b c  - 451346432a b c
+--R                + 
+--R                            4 7 4             3 9 3            2 11 2
+--R                  331366400a b c  - 127406080a b c  + 27106304a b  c
+--R                + 
+--R                              13           15
+--R                  - 3034368a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                      7 6            6 2 5            5 4 4
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           7 6            6 2 5            5 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        4 6 3          3 8 2         2 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                         12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R            + 
+--R                 4 5        3 2 4         2 4 3            6 2          8   +-+
+--R            (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)\|x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  7 6            6 2 5            5 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                      12 11                  11 2 10
+--R                      - 1099511627776a  c   + 12919261626368a  b c
+--R                    + 
+--R                                       10 4 9                  9 6 8
+--R                      - 24120536334336a  b c  + 20770461843456a b c
+--R                    + 
+--R                                       8 8 7                 7 10 6
+--R                      - 10075993276416a b c  + 2841120866304a b  c
+--R                    + 
+--R                                     6 12 5               5 14 4
+--R                      - 394600120320a b  c  - 11676942336a b  c
+--R                    + 
+--R                                  4 16 3              3 18 2             2 20
+--R                      14948499456a b  c  - 2638217216a b  c  + 214958080a b  c
+--R                    + 
+--R                                  22
+--R                      - 7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                           7   7             6 3 6             5 5 5
+--R                  11534336a b c  - 255066112a b c  + 451346432a b c
+--R                + 
+--R                              4 7 4             3 9 3            2 11 2
+--R                  - 331366400a b c  + 127406080a b c  - 27106304a b  c
+--R                + 
+--R                            13           15
+--R                  3034368a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     4 6 3          3 8 2         2 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                  12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         7 6            6 2 5            5 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          4 6 3          3 8 2         2 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                       12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R            + 
+--R                 4 5        3 2 4         2 4 3            6 2          8   +-+
+--R            (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)\|x
+--R     + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  7 6            6 2 5            5 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                    12 11                  11 2 10
+--R                      1099511627776a  c   - 12919261626368a  b c
+--R                    + 
+--R                                     10 4 9                  9 6 8
+--R                      24120536334336a  b c  - 20770461843456a b c
+--R                    + 
+--R                                     8 8 7                 7 10 6
+--R                      10075993276416a b c  - 2841120866304a b  c
+--R                    + 
+--R                                   6 12 5               5 14 4
+--R                      394600120320a b  c  + 11676942336a b  c
+--R                    + 
+--R                                    4 16 3              3 18 2             2 20
+--R                      - 14948499456a b  c  + 2638217216a b  c  - 214958080a b  c
+--R                    + 
+--R                                22
+--R                      7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                             7   7             6 3 6             5 5 5
+--R                  - 11534336a b c  + 255066112a b c  - 451346432a b c
+--R                + 
+--R                            4 7 4             3 9 3            2 11 2
+--R                  331366400a b c  - 127406080a b c  + 27106304a b  c
+--R                + 
+--R                              13           15
+--R                  - 3034368a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     4 6 3          3 8 2         2 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                  12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         7 6            6 2 5            5 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          4 6 3          3 8 2         2 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                       12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R           /
+--R                     4 5        3 2 4         2 4 3            6 2          8
+--R                (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                 2     2   4                 3  2     2        2
+--R         ((- 8a c  + 2b c)x  + (- 8a b c + 2b )x  - 8a c + 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                    12 11                  11 2 10
+--R                      1099511627776a  c   - 12919261626368a  b c
+--R                    + 
+--R                                     10 4 9                  9 6 8
+--R                      24120536334336a  b c  - 20770461843456a b c
+--R                    + 
+--R                                     8 8 7                 7 10 6
+--R                      10075993276416a b c  - 2841120866304a b  c
+--R                    + 
+--R                                   6 12 5               5 14 4
+--R                      394600120320a b  c  + 11676942336a b  c
+--R                    + 
+--R                                    4 16 3              3 18 2             2 20
+--R                      - 14948499456a b  c  + 2638217216a b  c  - 214958080a b  c
+--R                    + 
+--R                                22
+--R                      7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                           7   7             6 3 6             5 5 5
+--R                  11534336a b c  - 255066112a b c  + 451346432a b c
+--R                + 
+--R                              4 7 4             3 9 3            2 11 2
+--R                  - 331366400a b c  + 127406080a b c  - 27106304a b  c
+--R                + 
+--R                            13           15
+--R                  3034368a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                      7 6            6 2 5            5 4 4
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           7 6            6 2 5            5 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        4 6 3          3 8 2         2 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                         12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R           /
+--R                     4 5        3 2 4         2 4 3            6 2          8
+--R                (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R            3        +-+
+--R       (2c x  + b x)\|x
+--R  /
+--R          2     2   4               3  2     2        2
+--R     (8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 652
+
+--S 653 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R                  2 4+-+3 |          2 4|   |          2
+--R         (4a c - b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  7 6            6 2 5            5 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                    12 11                  11 2 10
+--R                      1099511627776a  c   - 12919261626368a  b c
+--R                    + 
+--R                                     10 4 9                  9 6 8
+--R                      24120536334336a  b c  - 20770461843456a b c
+--R                    + 
+--R                                     8 8 7                 7 10 6
+--R                      10075993276416a b c  - 2841120866304a b  c
+--R                    + 
+--R                                   6 12 5               5 14 4
+--R                      394600120320a b  c  + 11676942336a b  c
+--R                    + 
+--R                                    4 16 3              3 18 2             2 20
+--R                      - 14948499456a b  c  + 2638217216a b  c  - 214958080a b  c
+--R                    + 
+--R                                22
+--R                      7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                             7   7             6 3 6             5 5 5
+--R                  - 11534336a b c  + 255066112a b c  - 451346432a b c
+--R                + 
+--R                            4 7 4             3 9 3            2 11 2
+--R                  331366400a b c  - 127406080a b c  + 27106304a b  c
+--R                + 
+--R                              13           15
+--R                  - 3034368a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     4 6 3          3 8 2         2 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                  12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         7 6            6 2 5            5 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          4 6 3          3 8 2         2 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                       12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R            + 
+--R                 4 5        3 2 4         2 4 3            6 2          8   +-+
+--R            (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)\|x
+--R     + 
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R                    2 4+-+3 |          2 4|   |          2
+--R         (- 4a c + b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                    12 11                  11 2 10
+--R                      1099511627776a  c   - 12919261626368a  b c
+--R                    + 
+--R                                     10 4 9                  9 6 8
+--R                      24120536334336a  b c  - 20770461843456a b c
+--R                    + 
+--R                                     8 8 7                 7 10 6
+--R                      10075993276416a b c  - 2841120866304a b  c
+--R                    + 
+--R                                   6 12 5               5 14 4
+--R                      394600120320a b  c  + 11676942336a b  c
+--R                    + 
+--R                                    4 16 3              3 18 2             2 20
+--R                      - 14948499456a b  c  + 2638217216a b  c  - 214958080a b  c
+--R                    + 
+--R                                22
+--R                      7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                           7   7             6 3 6             5 5 5
+--R                  11534336a b c  - 255066112a b c  + 451346432a b c
+--R                + 
+--R                              4 7 4             3 9 3            2 11 2
+--R                  - 331366400a b c  + 127406080a b c  - 27106304a b  c
+--R                + 
+--R                            13           15
+--R                  3034368a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                      7 6            6 2 5            5 4 4
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           7 6            6 2 5            5 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        4 6 3          3 8 2         2 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                         12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R            + 
+--R                 4 5        3 2 4         2 4 3            6 2          8   +-+
+--R            (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)\|x
+--R     + 
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R                  2 4+-+3 |          2 4|   |          2
+--R         (4a c - b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                      12 11                  11 2 10
+--R                      - 1099511627776a  c   + 12919261626368a  b c
+--R                    + 
+--R                                       10 4 9                  9 6 8
+--R                      - 24120536334336a  b c  + 20770461843456a b c
+--R                    + 
+--R                                       8 8 7                 7 10 6
+--R                      - 10075993276416a b c  + 2841120866304a b  c
+--R                    + 
+--R                                     6 12 5               5 14 4
+--R                      - 394600120320a b  c  - 11676942336a b  c
+--R                    + 
+--R                                  4 16 3              3 18 2             2 20
+--R                      14948499456a b  c  - 2638217216a b  c  + 214958080a b  c
+--R                    + 
+--R                                  22
+--R                      - 7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                             7   7             6 3 6             5 5 5
+--R                  - 11534336a b c  + 255066112a b c  - 451346432a b c
+--R                + 
+--R                            4 7 4             3 9 3            2 11 2
+--R                  331366400a b c  - 127406080a b c  + 27106304a b  c
+--R                + 
+--R                              13           15
+--R                  - 3034368a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                      7 6            6 2 5            5 4 4
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           7 6            6 2 5            5 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        4 6 3          3 8 2         2 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                         12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R            + 
+--R                 4 5        3 2 4         2 4 3            6 2          8   +-+
+--R            (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)\|x
+--R     + 
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R                    2 4+-+3 |          2 4|   |          2
+--R         (- 4a c + b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  7 6            6 2 5            5 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                      12 11                  11 2 10
+--R                      - 1099511627776a  c   + 12919261626368a  b c
+--R                    + 
+--R                                       10 4 9                  9 6 8
+--R                      - 24120536334336a  b c  + 20770461843456a b c
+--R                    + 
+--R                                       8 8 7                 7 10 6
+--R                      - 10075993276416a b c  + 2841120866304a b  c
+--R                    + 
+--R                                     6 12 5               5 14 4
+--R                      - 394600120320a b  c  - 11676942336a b  c
+--R                    + 
+--R                                  4 16 3              3 18 2             2 20
+--R                      14948499456a b  c  - 2638217216a b  c  + 214958080a b  c
+--R                    + 
+--R                                  22
+--R                      - 7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                           7   7             6 3 6             5 5 5
+--R                  11534336a b c  - 255066112a b c  + 451346432a b c
+--R                + 
+--R                              4 7 4             3 9 3            2 11 2
+--R                  - 331366400a b c  + 127406080a b c  - 27106304a b  c
+--R                + 
+--R                            13           15
+--R                  3034368a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     4 6 3          3 8 2         2 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                  12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         7 6            6 2 5            5 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          4 6 3          3 8 2         2 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                       12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R            + 
+--R                 4 5        3 2 4         2 4 3            6 2          8   +-+
+--R            (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)\|x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R                   2 4+-+3 |          2 4|   |          2
+--R         (8a c - 2b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  7 6            6 2 5            5 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                    12 11                  11 2 10
+--R                      1099511627776a  c   - 12919261626368a  b c
+--R                    + 
+--R                                     10 4 9                  9 6 8
+--R                      24120536334336a  b c  - 20770461843456a b c
+--R                    + 
+--R                                     8 8 7                 7 10 6
+--R                      10075993276416a b c  - 2841120866304a b  c
+--R                    + 
+--R                                   6 12 5               5 14 4
+--R                      394600120320a b  c  + 11676942336a b  c
+--R                    + 
+--R                                    4 16 3              3 18 2             2 20
+--R                      - 14948499456a b  c  + 2638217216a b  c  - 214958080a b  c
+--R                    + 
+--R                                22
+--R                      7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                             7   7             6 3 6             5 5 5
+--R                  - 11534336a b c  + 255066112a b c  - 451346432a b c
+--R                + 
+--R                            4 7 4             3 9 3            2 11 2
+--R                  331366400a b c  - 127406080a b c  + 27106304a b  c
+--R                + 
+--R                              13           15
+--R                  - 3034368a b  c + 139968b
+--R             *
+--R                ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                           16777216a c  - 25165824a b c  + 15728640a b c
+--R                         + 
+--R                                     4 6 3          3 8 2         2 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                  12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         7 6            6 2 5            5 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          4 6 3          3 8 2         2 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                       12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R           /
+--R                     4 5        3 2 4         2 4 3            6 2          8
+--R                (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R                     2 4+-+3 |          2 4|   |          2
+--R         (- 8a c + 2b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    7 6            6 2 5            5 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                 2 2         2         4
+--R                            - 16a c  + 648a b c - 6561b
+--R                         /
+--R                                            11 9                 10 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            9 4 7                 8 6 6
+--R                              9895604649984a b c  - 5772436045824a b c
+--R                            + 
+--R                                            7 8 5                6 10 4
+--R                              2164663517184a b c  - 541165879296a b  c
+--R                            + 
+--R                                          5 12 3              4 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        3 16             2 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                         2   2         3       5
+--R                     240a b c  - 760a b c - 81b
+--R                /
+--R                             7 6            6 2 5           5 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               4 6 3          3 8 2         2 10           12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                    12 11                  11 2 10
+--R                      1099511627776a  c   - 12919261626368a  b c
+--R                    + 
+--R                                     10 4 9                  9 6 8
+--R                      24120536334336a  b c  - 20770461843456a b c
+--R                    + 
+--R                                     8 8 7                 7 10 6
+--R                      10075993276416a b c  - 2841120866304a b  c
+--R                    + 
+--R                                   6 12 5               5 14 4
+--R                      394600120320a b  c  + 11676942336a b  c
+--R                    + 
+--R                                    4 16 3              3 18 2             2 20
+--R                      - 14948499456a b  c  + 2638217216a b  c  - 214958080a b  c
+--R                    + 
+--R                                22
+--R                      7077888a b
+--R                 *
+--R                    ROOT
+--R                              2 2         2         4
+--R                         - 16a c  + 648a b c - 6561b
+--R                      /
+--R                                         11 9                 10 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         9 4 7                 8 6 6
+--R                           9895604649984a b c  - 5772436045824a b c
+--R                         + 
+--R                                         7 8 5                6 10 4
+--R                           2164663517184a b c  - 541165879296a b  c
+--R                         + 
+--R                                       5 12 3              4 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     3 16             2 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                           7   7             6 3 6             5 5 5
+--R                  11534336a b c  - 255066112a b c  + 451346432a b c
+--R                + 
+--R                              4 7 4             3 9 3            2 11 2
+--R                  - 331366400a b c  + 127406080a b c  - 27106304a b  c
+--R                + 
+--R                            13           15
+--R                  3034368a b  c - 139968b
+--R             *
+--R                ROOT
+--R                                      7 6            6 2 5            5 4 4
+--R                           - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                         + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                   2 2         2         4
+--R                              - 16a c  + 648a b c - 6561b
+--R                           /
+--R                                              11 9                 10 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              9 4 7                 8 6 6
+--R                                9895604649984a b c  - 5772436045824a b c
+--R                              + 
+--R                                              7 8 5                6 10 4
+--R                                2164663517184a b c  - 541165879296a b  c
+--R                              + 
+--R                                            5 12 3              4 14 2
+--R                                90194313216a b  c  - 9663676416a b  c
+--R                              + 
+--R                                          3 16             2 18
+--R                                603979776a b  c - 16777216a b
+--R                     + 
+--R                           2   2         3       5
+--R                       240a b c  - 760a b c - 81b
+--R                  /
+--R                               7 6            6 2 5           5 4 4
+--R                       8388608a c  - 12582912a b c  + 7864320a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10           12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           7 6            6 2 5            5 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        4 6 3          3 8 2         2 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                         12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                        2 2         2         4
+--R                                   - 16a c  + 648a b c - 6561b
+--R                                /
+--R                                                   11 9                 10 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   9 4 7                 8 6 6
+--R                                     9895604649984a b c  - 5772436045824a b c
+--R                                   + 
+--R                                                   7 8 5                6 10 4
+--R                                     2164663517184a b c  - 541165879296a b  c
+--R                                   + 
+--R                                                 5 12 3              4 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               3 16             2 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                2   2         3       5
+--R                            240a b c  - 760a b c - 81b
+--R                       /
+--R                                    7 6            6 2 5           5 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      4 6 3          3 8 2         2 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                   12
+--R                            2048a b
+--R           /
+--R                     4 5        3 2 4         2 4 3            6 2          8
+--R                (256a c  - 2304a b c  - 47520a b c  - 205200a b c  - 273375b c)
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                   +------------------+
+--R           +-----------+           | +-----------+
+--R           |          2       4+-+4| |          2
+--R         (\|- 4a c + b   + 4b)\|c \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                   +--------------------+
+--R           +-----------+           |   +-----------+
+--R           |          2       4+-+4|   |          2
+--R         (\|- 4a c + b   - 4b)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                     +------------------+
+--R             +-----------+           | +-----------+
+--R             |          2       4+-+4| |          2
+--R         (- \|- 4a c + b   - 4b)\|c \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                     +--------------------+
+--R             +-----------+           |   +-----------+
+--R             |          2       4+-+4|   |          2
+--R         (- \|- 4a c + b   + 4b)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                     +--------------------+ +------------------+
+--R                       +-----------+ |   +-----------+      | +-----------+
+--R               2 4+-+3 |          2 4|   |          2      4| |          2
+--R     (8a c - 2b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 653
+
+--S 654 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 654
+
+)clear all
+
+--S 655 of 1057
+t0:=x^(3/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                              +-+
+--R                            x\|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 1057
+r0:=1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (3+4*b/sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)*(-b-sqrt(b^2-4*a*c))^(3/4))+_
+   1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (3+4*b/sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)*(-b-sqrt(b^2-4*a*c))^(3/4))+_
+   1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (3-4*b/sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))+_
+   1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (3-4*b/sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))-_
+   1/2*(b+2*c*x^2)*sqrt(x)/((b^2-4*a*c)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                                 +-----------+
+--R                 4       2       |          2          4     2 2        4+-+3
+--R         ((- 3c x  - 3b x  - 3a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                                 +-----------+
+--R                 4       2       |          2          4     2 2        4+-+3
+--R         ((- 3c x  - 3b x  - 3a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                                 +-----------+
+--R                 4       2       |          2          4     2 2        4+-+3
+--R         ((- 3c x  - 3b x  - 3a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                                 +-----------+
+--R                 4       2       |          2          4     2 2        4+-+3
+--R         ((- 3c x  - 3b x  - 3a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+3
+--R                         +-----------+     |   +-----------+
+--R              2     4+-+ |          2  +-+4|   |          2
+--R         (2c x  + b)\|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R                                                                +-----------+
+--R             2     2   4               3  2     2        2 4+-+ |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2 \|- 4a c + b
+--R    *
+--R        +--------------------+3  +------------------+3
+--R        |   +-----------+        | +-----------+
+--R       4|   |          2        4| |          2
+--R       \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  9 6            8 2 5            7 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                10 7             9 2 6             8 4 5
+--R                      402653184a  c  - 570425344a b c  + 327155712a b c
+--R                    + 
+--R                                 7 6 4            6 8 3          5 10 2
+--R                      - 94371840a b c  + 13107200a b c  - 393216a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 98304a b  c + 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                        4   4        3 3 3       2 5 2        7      9
+--R                  10368a b c  - 4320a b c  + 248a b c  + 38a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         9 6            8 2 5            7 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          6 6 3          5 8 2         4 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     3 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R            + 
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    9 6            8 2 5            7 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                10 7             9 2 6             8 4 5
+--R                      402653184a  c  - 570425344a b c  + 327155712a b c
+--R                    + 
+--R                                 7 6 4            6 8 3          5 10 2
+--R                      - 94371840a b c  + 13107200a b c  - 393216a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 98304a b  c + 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                          4   4        3 3 3       2 5 2        7      9
+--R                  - 10368a b c  + 4320a b c  - 248a b c  - 38a b c - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           9 6            8 2 5            7 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        6 6 3          5 8 2         4 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       3 12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R            + 
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    9 6            8 2 5            7 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                  10 7             9 2 6             8 4 5
+--R                      - 402653184a  c  + 570425344a b c  - 327155712a b c
+--R                    + 
+--R                               7 6 4            6 8 3          5 10 2
+--R                      94371840a b c  - 13107200a b c  + 393216a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      98304a b  c - 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                        4   4        3 3 3       2 5 2        7      9
+--R                  10368a b c  - 4320a b c  + 248a b c  + 38a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           9 6            8 2 5            7 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        6 6 3          5 8 2         4 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       3 12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R            + 
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  9 6            8 2 5            7 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                  10 7             9 2 6             8 4 5
+--R                      - 402653184a  c  + 570425344a b c  - 327155712a b c
+--R                    + 
+--R                               7 6 4            6 8 3          5 10 2
+--R                      94371840a b c  - 13107200a b c  + 393216a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      98304a b  c - 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                          4   4        3 3 3       2 5 2        7      9
+--R                  - 10368a b c  + 4320a b c  - 248a b c  - 38a b c - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         9 6            8 2 5            7 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          6 6 3          5 8 2         4 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     3 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R            + 
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  9 6            8 2 5            7 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                10 7             9 2 6             8 4 5
+--R                      402653184a  c  - 570425344a b c  + 327155712a b c
+--R                    + 
+--R                                 7 6 4            6 8 3          5 10 2
+--R                      - 94371840a b c  + 13107200a b c  - 393216a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 98304a b  c + 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                        4   4        3 3 3       2 5 2        7      9
+--R                  10368a b c  - 4320a b c  + 248a b c  + 38a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         9 6            8 2 5            7 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          6 6 3          5 8 2         4 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     3 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R           /
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R                 2     2   4                 3  2     2        2
+--R         ((- 8a c  + 2b c)x  + (- 8a b c + 2b )x  - 8a c + 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    9 6            8 2 5            7 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                10 7             9 2 6             8 4 5
+--R                      402653184a  c  - 570425344a b c  + 327155712a b c
+--R                    + 
+--R                                 7 6 4            6 8 3          5 10 2
+--R                      - 94371840a b c  + 13107200a b c  - 393216a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 98304a b  c + 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                          4   4        3 3 3       2 5 2        7      9
+--R                  - 10368a b c  + 4320a b c  - 248a b c  - 38a b c - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           9 6            8 2 5            7 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        6 6 3          5 8 2         4 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       3 12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R           /
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R            2      +-+
+--R       (2c x  + b)\|x
+--R  /
+--R          2     2   4               3  2     2        2
+--R     (8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 657
+
+--S 658 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +--------------------+3
+--R                           +-----------+ |   +-----------+
+--R                    2 4+-+ |          2 4|   |          2
+--R         (- 4a c + b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  9 6            8 2 5            7 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                10 7             9 2 6             8 4 5
+--R                      402653184a  c  - 570425344a b c  + 327155712a b c
+--R                    + 
+--R                                 7 6 4            6 8 3          5 10 2
+--R                      - 94371840a b c  + 13107200a b c  - 393216a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 98304a b  c + 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                        4   4        3 3 3       2 5 2        7      9
+--R                  10368a b c  - 4320a b c  + 248a b c  + 38a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         9 6            8 2 5            7 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          6 6 3          5 8 2         4 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     3 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R            + 
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R                                       +--------------------+3
+--R                         +-----------+ |   +-----------+
+--R                  2 4+-+ |          2 4|   |          2
+--R         (4a c - b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    9 6            8 2 5            7 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                10 7             9 2 6             8 4 5
+--R                      402653184a  c  - 570425344a b c  + 327155712a b c
+--R                    + 
+--R                                 7 6 4            6 8 3          5 10 2
+--R                      - 94371840a b c  + 13107200a b c  - 393216a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 98304a b  c + 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                          4   4        3 3 3       2 5 2        7      9
+--R                  - 10368a b c  + 4320a b c  - 248a b c  - 38a b c - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           9 6            8 2 5            7 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        6 6 3          5 8 2         4 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       3 12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R            + 
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R                                         +--------------------+3
+--R                           +-----------+ |   +-----------+
+--R                    2 4+-+ |          2 4|   |          2
+--R         (- 4a c + b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    9 6            8 2 5            7 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                  10 7             9 2 6             8 4 5
+--R                      - 402653184a  c  + 570425344a b c  - 327155712a b c
+--R                    + 
+--R                               7 6 4            6 8 3          5 10 2
+--R                      94371840a b c  - 13107200a b c  + 393216a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      98304a b  c - 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                        4   4        3 3 3       2 5 2        7      9
+--R                  10368a b c  - 4320a b c  + 248a b c  + 38a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           9 6            8 2 5            7 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        6 6 3          5 8 2         4 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       3 12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R            + 
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R                                       +--------------------+3
+--R                         +-----------+ |   +-----------+
+--R                  2 4+-+ |          2 4|   |          2
+--R         (4a c - b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  9 6            8 2 5            7 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                  10 7             9 2 6             8 4 5
+--R                      - 402653184a  c  + 570425344a b c  - 327155712a b c
+--R                    + 
+--R                               7 6 4            6 8 3          5 10 2
+--R                      94371840a b c  - 13107200a b c  + 393216a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      98304a b  c - 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                          4   4        3 3 3       2 5 2        7      9
+--R                  - 10368a b c  + 4320a b c  - 248a b c  - 38a b c - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         9 6            8 2 5            7 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          6 6 3          5 8 2         4 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     3 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R            + 
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R                                        +--------------------+3
+--R                          +-----------+ |   +-----------+
+--R                   2 4+-+ |          2 4|   |          2
+--R         (8a c - 2b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  9 6            8 2 5            7 4 4
+--R                         16777216a c  - 25165824a b c  + 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                10 7             9 2 6             8 4 5
+--R                      402653184a  c  - 570425344a b c  + 327155712a b c
+--R                    + 
+--R                                 7 6 4            6 8 3          5 10 2
+--R                      - 94371840a b c  + 13107200a b c  - 393216a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 98304a b  c + 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                        4   4        3 3 3       2 5 2        7      9
+--R                  10368a b c  - 4320a b c  + 248a b c  + 38a b c + 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         9 6            8 2 5            7 4 4
+--R                                16777216a c  - 25165824a b c  + 15728640a b c
+--R                              + 
+--R                                          6 6 3          5 8 2         4 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     3 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R           /
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R                                          +--------------------+3
+--R                            +-----------+ |   +-----------+
+--R                     2 4+-+ |          2 4|   |          2
+--R         (- 8a c + 2b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    9 6            8 2 5            7 4 4
+--R                         - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                       + 
+--R                                 6 6 3          5 8 2         4 10         3 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                       4 4         3 2 3        2 4 2        6
+--R                              - 104976a c  - 17496a b c  - 1377a b c  - 54a b c
+--R                            + 
+--R                                 8
+--R                              - b
+--R                         /
+--R                                            15 9                 14 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            13 4 7                 12 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            11 8 5                10 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          9 12 3              8 14 2
+--R                              90194313216a b  c  - 9663676416a b  c
+--R                            + 
+--R                                        7 16             6 18
+--R                              603979776a b  c - 16777216a b
+--R                   + 
+--R                            3   3       2 3 2        5     7
+--R                     - 3024a b c  - 168a b c  - 21a b c - b
+--R                /
+--R                             9 6            8 2 5           7 4 4
+--R                     8388608a c  - 12582912a b c  + 7864320a b c
+--R                   + 
+--R                               6 6 3          5 8 2         4 10         3 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                10 7             9 2 6             8 4 5
+--R                      402653184a  c  - 570425344a b c  + 327155712a b c
+--R                    + 
+--R                                 7 6 4            6 8 3          5 10 2
+--R                      - 94371840a b c  + 13107200a b c  - 393216a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 98304a b  c + 8192a b
+--R                 *
+--R                    ROOT
+--R                                  4 4         3 2 3        2 4 2        6     8
+--R                         - 104976a c  - 17496a b c  - 1377a b c  - 54a b c - b
+--R                      /
+--R                                         15 9                 14 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         13 4 7                 12 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         11 8 5                10 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       9 12 3              8 14 2
+--R                           90194313216a b  c  - 9663676416a b  c
+--R                         + 
+--R                                     7 16             6 18
+--R                           603979776a b  c - 16777216a b
+--R                + 
+--R                          4   4        3 3 3       2 5 2        7      9
+--R                  - 10368a b c  + 4320a b c  - 248a b c  - 38a b c - 2b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           9 6            8 2 5            7 4 4
+--R                                - 16777216a c  + 25165824a b c  - 15728640a b c
+--R                              + 
+--R                                        6 6 3          5 8 2         4 10
+--R                                5242880a b c  - 983040a b c  + 98304a b  c
+--R                              + 
+--R                                       3 12
+--R                                - 4096a b
+--R                           *
+--R                              ROOT
+--R                                              4 4         3 2 3        2 4 2
+--R                                     - 104976a c  - 17496a b c  - 1377a b c
+--R                                   + 
+--R                                            6     8
+--R                                     - 54a b c - b
+--R                                /
+--R                                                   15 9                 14 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   13 4 7                 12 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   11 8 5                10 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 9 12 3              8 14 2
+--R                                     90194313216a b  c  - 9663676416a b  c
+--R                                   + 
+--R                                               7 16             6 18
+--R                                     603979776a b  c - 16777216a b
+--R                          + 
+--R                                   3   3       2 3 2        5     7
+--R                            - 3024a b c  - 168a b c  - 21a b c - b
+--R                       /
+--R                                    9 6            8 2 5           7 4 4
+--R                            8388608a c  - 12582912a b c  + 7864320a b c
+--R                          + 
+--R                                      6 6 3          5 8 2         4 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 3 12
+--R                            2048a b
+--R           /
+--R                     3 4        2 2 3         4 2     6   +-+
+--R              (11664a c  + 3240a b c  + 225a b c  + 7b c)\|x
+--R     + 
+--R                                      +------------------+3
+--R            +-----------+             | +-----------+
+--R            |          2       4+-+3 4| |          2
+--R         (3\|- 4a c + b   + 4b)\|c   \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                      +--------------------+3
+--R            +-----------+             |   +-----------+
+--R            |          2       4+-+3 4|   |          2
+--R         (3\|- 4a c + b   - 4b)\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                      +------------------+3
+--R            +-----------+             | +-----------+
+--R            |          2       4+-+3 4| |          2
+--R         (3\|- 4a c + b   + 4b)\|c   \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                      +--------------------+3
+--R            +-----------+             |   +-----------+
+--R            |          2       4+-+3 4|   |          2
+--R         (3\|- 4a c + b   - 4b)\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                      +--------------------+3
+--R                        +-----------+ |   +-----------+
+--R                 2 4+-+ |          2 4|   |          2
+--R       (8a c - 2b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+3
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 658
+
+--S 659 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 659
+
+)clear all
+
+--S 660 of 1057
+t0:=x^(1/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                              +-+
+--R                             \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 1057
+r0:=1/2*x^(3/2)*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   1/4*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(-b^2+20*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*a*(b^2-4*a*c)*(-b-sqrt(b^2-4*_
+   a*c))^(1/4))-1/4*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(b+(-b^2+20*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*a*(b^2-4*a*c)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))+1/4*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b+(b^2-20*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))-1/4*c^(1/4)*atanh(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b+(b^2-20*a*c)/sqrt(b^2-_
+   4*a*c))/(2^(3/4)*a*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                 +-----------+
+--R                 4    2 2        |          2          2    2   4
+--R           (b c x  + b x  + a b)\|- 4a c + b   + (20a c  - b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (20a b c - b )x  + 20a c - a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                 4+-+4+-+ +-+
+--R         4+-+4| |          2                  \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R                                 +-----------+
+--R                 4    2 2        |          2            2    2   4
+--R           (b c x  + b x  + a b)\|- 4a c + b   + (- 20a c  + b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 20a b c + b )x  - 20a c + a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                4+-+4+-+ +-+
+--R         4+-+4|   |          2                 \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2            2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (- 20a c  + b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 20a b c + b )x  - 20a c + a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                4+-+4+-+ +-+
+--R         4+-+4| |          2                 \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2          2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (20a c  - b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (20a b c - b )x  + 20a c - a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+               4+-+4+-+ +-+
+--R         4+-+4|   |          2                \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                         4| |          2
+--R                                         \|\|- 4a c + b   - b
+--R     + 
+--R                                          +-----------+
+--R                  3             2   4+-+3 |          2  +-+
+--R         (- 2b c x  + (4a c - 2b )x)\|2  \|- 4a c + b  \|x
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R            2 2       2   4       2          3  2      3      2 2 4+-+3
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2 4|   |          2      4| |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 2      2   4      2         3  2     3     2 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  11 6            10 2 5            9 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                      17   12                   16 3 11
+--R                      109951162777600a  b c   - 274328151130112a  b c
+--R                    + 
+--R                                      15 5 10                   14 7 9
+--R                      310337156939776a  b c   - 210247239073792a  b c
+--R                    + 
+--R                                     13 9 8                  12 11 7
+--R                      94884417503232a  b c  - 30008936497152a  b  c
+--R                    + 
+--R                                    11 13 6                 10 15 5
+--R                      6809670647808a  b  c  - 1115349319680a  b  c
+--R                    + 
+--R                                   9 17 4               8 19 3
+--R                      130660958208a b  c  - 10661920768a b  c
+--R                    + 
+--R                                7 21 2            6 23           5 25
+--R                      574619648a b  c  - 18350080a b  c + 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 11 11                10 2 10
+--R                  - 163840000000a  c   + 293273600000a  b c
+--R                + 
+--R                                 9 4 9                8 6 8               7 8 7
+--R                  - 232144896000a b c  + 107010949120a b c  - 31849668608a b c
+--R                + 
+--R                             6 10 6             5 12 5            4 14 4
+--R                  6416214016a b  c  - 892161536a b  c  + 85686400a b  c
+--R                + 
+--R                            3 16 3          2 18 2          20       22
+--R                  - 5582720a b  c  + 235712a b  c  - 5824a b  c + 64b
+--R             *
+--R                ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                         + 
+--R                                     8 6 3          7 8 2         6 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                5 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         11 6            10 2 5            9 4 4
+--R                                16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                              + 
+--R                                          8 6 3          7 8 2         6 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     5 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R            + 
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               2 2      2   4        2         3  2     3     2 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                      17   12                   16 3 11
+--R                      109951162777600a  b c   - 274328151130112a  b c
+--R                    + 
+--R                                      15 5 10                   14 7 9
+--R                      310337156939776a  b c   - 210247239073792a  b c
+--R                    + 
+--R                                     13 9 8                  12 11 7
+--R                      94884417503232a  b c  - 30008936497152a  b  c
+--R                    + 
+--R                                    11 13 6                 10 15 5
+--R                      6809670647808a  b  c  - 1115349319680a  b  c
+--R                    + 
+--R                                   9 17 4               8 19 3
+--R                      130660958208a b  c  - 10661920768a b  c
+--R                    + 
+--R                                7 21 2            6 23           5 25
+--R                      574619648a b  c  - 18350080a b  c + 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                               11 11                10 2 10                9 4 9
+--R                  163840000000a  c   - 293273600000a  b c   + 232144896000a b c
+--R                + 
+--R                                 8 6 8               7 8 7              6 10 6
+--R                  - 107010949120a b c  + 31849668608a b c  - 6416214016a b  c
+--R                + 
+--R                            5 12 5            4 14 4           3 16 3
+--R                  892161536a b  c  - 85686400a b  c  + 5582720a b  c
+--R                + 
+--R                           2 18 2          20       22
+--R                  - 235712a b  c  + 5824a b  c - 64b
+--R             *
+--R                ROOT
+--R                                      11 6            10 2 5            9 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                         + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           11 6            10 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           9 4 4           8 6 3          7 8 2
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                      6 10         5 12
+--R                                98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R            + 
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R             2 2      2   4      2         3  2     3     2 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                        17   12                   16 3 11
+--R                      - 109951162777600a  b c   + 274328151130112a  b c
+--R                    + 
+--R                                        15 5 10                   14 7 9
+--R                      - 310337156939776a  b c   + 210247239073792a  b c
+--R                    + 
+--R                                       13 9 8                  12 11 7
+--R                      - 94884417503232a  b c  + 30008936497152a  b  c
+--R                    + 
+--R                                      11 13 6                 10 15 5
+--R                      - 6809670647808a  b  c  + 1115349319680a  b  c
+--R                    + 
+--R                                     9 17 4               8 19 3
+--R                      - 130660958208a b  c  + 10661920768a b  c
+--R                    + 
+--R                                  7 21 2            6 23           5 25
+--R                      - 574619648a b  c  + 18350080a b  c - 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 11 11                10 2 10
+--R                  - 163840000000a  c   + 293273600000a  b c
+--R                + 
+--R                                 9 4 9                8 6 8               7 8 7
+--R                  - 232144896000a b c  + 107010949120a b c  - 31849668608a b c
+--R                + 
+--R                             6 10 6             5 12 5            4 14 4
+--R                  6416214016a b  c  - 892161536a b  c  + 85686400a b  c
+--R                + 
+--R                            3 16 3          2 18 2          20       22
+--R                  - 5582720a b  c  + 235712a b  c  - 5824a b  c + 64b
+--R             *
+--R                ROOT
+--R                                      11 6            10 2 5            9 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                         + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           11 6            10 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           9 4 4           8 6 3          7 8 2
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                      6 10         5 12
+--R                                98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R            + 
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               2 2      2   4        2         3  2     3     2 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  11 6            10 2 5            9 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                        17   12                   16 3 11
+--R                      - 109951162777600a  b c   + 274328151130112a  b c
+--R                    + 
+--R                                        15 5 10                   14 7 9
+--R                      - 310337156939776a  b c   + 210247239073792a  b c
+--R                    + 
+--R                                       13 9 8                  12 11 7
+--R                      - 94884417503232a  b c  + 30008936497152a  b  c
+--R                    + 
+--R                                      11 13 6                 10 15 5
+--R                      - 6809670647808a  b  c  + 1115349319680a  b  c
+--R                    + 
+--R                                     9 17 4               8 19 3
+--R                      - 130660958208a b  c  + 10661920768a b  c
+--R                    + 
+--R                                  7 21 2            6 23           5 25
+--R                      - 574619648a b  c  + 18350080a b  c - 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                               11 11                10 2 10                9 4 9
+--R                  163840000000a  c   - 293273600000a  b c   + 232144896000a b c
+--R                + 
+--R                                 8 6 8               7 8 7              6 10 6
+--R                  - 107010949120a b c  + 31849668608a b c  - 6416214016a b  c
+--R                + 
+--R                            5 12 5            4 14 4           3 16 3
+--R                  892161536a b  c  - 85686400a b  c  + 5582720a b  c
+--R                + 
+--R                           2 18 2          20       22
+--R                  - 235712a b  c  + 5824a b  c - 64b
+--R             *
+--R                ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                         + 
+--R                                     8 6 3          7 8 2         6 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                5 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         11 6            10 2 5            9 4 4
+--R                                16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                              + 
+--R                                          8 6 3          7 8 2         6 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     5 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R            + 
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R             2 2       2   4      2          3  2     3      2 2
+--R         ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  11 6            10 2 5            9 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                      17   12                   16 3 11
+--R                      109951162777600a  b c   - 274328151130112a  b c
+--R                    + 
+--R                                      15 5 10                   14 7 9
+--R                      310337156939776a  b c   - 210247239073792a  b c
+--R                    + 
+--R                                     13 9 8                  12 11 7
+--R                      94884417503232a  b c  - 30008936497152a  b  c
+--R                    + 
+--R                                    11 13 6                 10 15 5
+--R                      6809670647808a  b  c  - 1115349319680a  b  c
+--R                    + 
+--R                                   9 17 4               8 19 3
+--R                      130660958208a b  c  - 10661920768a b  c
+--R                    + 
+--R                                7 21 2            6 23           5 25
+--R                      574619648a b  c  - 18350080a b  c + 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 11 11                10 2 10
+--R                  - 163840000000a  c   + 293273600000a  b c
+--R                + 
+--R                                 9 4 9                8 6 8               7 8 7
+--R                  - 232144896000a b c  + 107010949120a b c  - 31849668608a b c
+--R                + 
+--R                             6 10 6             5 12 5            4 14 4
+--R                  6416214016a b  c  - 892161536a b  c  + 85686400a b  c
+--R                + 
+--R                            3 16 3          2 18 2          20       22
+--R                  - 5582720a b  c  + 235712a b  c  - 5824a b  c + 64b
+--R             *
+--R                ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                         + 
+--R                                     8 6 3          7 8 2         6 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                5 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         11 6            10 2 5            9 4 4
+--R                                16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                              + 
+--R                                          8 6 3          7 8 2         6 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     5 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R           /
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               2 2       2   4        2          3  2     3      2 2
+--R         ((- 8a c  + 2a b c)x  + (- 8a b c + 2a b )x  - 8a c + 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                      17   12                   16 3 11
+--R                      109951162777600a  b c   - 274328151130112a  b c
+--R                    + 
+--R                                      15 5 10                   14 7 9
+--R                      310337156939776a  b c   - 210247239073792a  b c
+--R                    + 
+--R                                     13 9 8                  12 11 7
+--R                      94884417503232a  b c  - 30008936497152a  b  c
+--R                    + 
+--R                                    11 13 6                 10 15 5
+--R                      6809670647808a  b  c  - 1115349319680a  b  c
+--R                    + 
+--R                                   9 17 4               8 19 3
+--R                      130660958208a b  c  - 10661920768a b  c
+--R                    + 
+--R                                7 21 2            6 23           5 25
+--R                      574619648a b  c  - 18350080a b  c + 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                               11 11                10 2 10                9 4 9
+--R                  163840000000a  c   - 293273600000a  b c   + 232144896000a b c
+--R                + 
+--R                                 8 6 8               7 8 7              6 10 6
+--R                  - 107010949120a b c  + 31849668608a b c  - 6416214016a b  c
+--R                + 
+--R                            5 12 5            4 14 4           3 16 3
+--R                  892161536a b  c  - 85686400a b  c  + 5582720a b  c
+--R                + 
+--R                           2 18 2          20       22
+--R                  - 235712a b  c  + 5824a b  c - 64b
+--R             *
+--R                ROOT
+--R                                      11 6            10 2 5            9 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                         + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           11 6            10 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           9 4 4           8 6 3          7 8 2
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                      6 10         5 12
+--R                                98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R           /
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               3            2    +-+
+--R       (- b c x  + (2a c - b )x)\|x
+--R  /
+--R        2 2       2   4      2          3  2     3      2 2
+--R     (8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 662
+
+--S 663 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R            2        2 4+-+3 |          2 4|   |          2
+--R         (8a c - 2a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  11 6            10 2 5            9 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                      17   12                   16 3 11
+--R                      109951162777600a  b c   - 274328151130112a  b c
+--R                    + 
+--R                                      15 5 10                   14 7 9
+--R                      310337156939776a  b c   - 210247239073792a  b c
+--R                    + 
+--R                                     13 9 8                  12 11 7
+--R                      94884417503232a  b c  - 30008936497152a  b  c
+--R                    + 
+--R                                    11 13 6                 10 15 5
+--R                      6809670647808a  b  c  - 1115349319680a  b  c
+--R                    + 
+--R                                   9 17 4               8 19 3
+--R                      130660958208a b  c  - 10661920768a b  c
+--R                    + 
+--R                                7 21 2            6 23           5 25
+--R                      574619648a b  c  - 18350080a b  c + 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 11 11                10 2 10
+--R                  - 163840000000a  c   + 293273600000a  b c
+--R                + 
+--R                                 9 4 9                8 6 8               7 8 7
+--R                  - 232144896000a b c  + 107010949120a b c  - 31849668608a b c
+--R                + 
+--R                             6 10 6             5 12 5            4 14 4
+--R                  6416214016a b  c  - 892161536a b  c  + 85686400a b  c
+--R                + 
+--R                            3 16 3          2 18 2          20       22
+--R                  - 5582720a b  c  + 235712a b  c  - 5824a b  c + 64b
+--R             *
+--R                ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                         + 
+--R                                     8 6 3          7 8 2         6 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                5 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         11 6            10 2 5            9 4 4
+--R                                16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                              + 
+--R                                          8 6 3          7 8 2         6 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     5 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R            + 
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +--------------------+
+--R                               +-----------+ |   +-----------+
+--R              2        2 4+-+3 |          2 4|   |          2
+--R         (- 8a c + 2a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                      17   12                   16 3 11
+--R                      109951162777600a  b c   - 274328151130112a  b c
+--R                    + 
+--R                                      15 5 10                   14 7 9
+--R                      310337156939776a  b c   - 210247239073792a  b c
+--R                    + 
+--R                                     13 9 8                  12 11 7
+--R                      94884417503232a  b c  - 30008936497152a  b  c
+--R                    + 
+--R                                    11 13 6                 10 15 5
+--R                      6809670647808a  b  c  - 1115349319680a  b  c
+--R                    + 
+--R                                   9 17 4               8 19 3
+--R                      130660958208a b  c  - 10661920768a b  c
+--R                    + 
+--R                                7 21 2            6 23           5 25
+--R                      574619648a b  c  - 18350080a b  c + 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                               11 11                10 2 10                9 4 9
+--R                  163840000000a  c   - 293273600000a  b c   + 232144896000a b c
+--R                + 
+--R                                 8 6 8               7 8 7              6 10 6
+--R                  - 107010949120a b c  + 31849668608a b c  - 6416214016a b  c
+--R                + 
+--R                            5 12 5            4 14 4           3 16 3
+--R                  892161536a b  c  - 85686400a b  c  + 5582720a b  c
+--R                + 
+--R                           2 18 2          20       22
+--R                  - 235712a b  c  + 5824a b  c - 64b
+--R             *
+--R                ROOT
+--R                                      11 6            10 2 5            9 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                         + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           11 6            10 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           9 4 4           8 6 3          7 8 2
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                      6 10         5 12
+--R                                98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R            + 
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R            2        2 4+-+3 |          2 4|   |          2
+--R         (8a c - 2a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                        17   12                   16 3 11
+--R                      - 109951162777600a  b c   + 274328151130112a  b c
+--R                    + 
+--R                                        15 5 10                   14 7 9
+--R                      - 310337156939776a  b c   + 210247239073792a  b c
+--R                    + 
+--R                                       13 9 8                  12 11 7
+--R                      - 94884417503232a  b c  + 30008936497152a  b  c
+--R                    + 
+--R                                      11 13 6                 10 15 5
+--R                      - 6809670647808a  b  c  + 1115349319680a  b  c
+--R                    + 
+--R                                     9 17 4               8 19 3
+--R                      - 130660958208a b  c  + 10661920768a b  c
+--R                    + 
+--R                                  7 21 2            6 23           5 25
+--R                      - 574619648a b  c  + 18350080a b  c - 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 11 11                10 2 10
+--R                  - 163840000000a  c   + 293273600000a  b c
+--R                + 
+--R                                 9 4 9                8 6 8               7 8 7
+--R                  - 232144896000a b c  + 107010949120a b c  - 31849668608a b c
+--R                + 
+--R                             6 10 6             5 12 5            4 14 4
+--R                  6416214016a b  c  - 892161536a b  c  + 85686400a b  c
+--R                + 
+--R                            3 16 3          2 18 2          20       22
+--R                  - 5582720a b  c  + 235712a b  c  - 5824a b  c + 64b
+--R             *
+--R                ROOT
+--R                                      11 6            10 2 5            9 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                         + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           11 6            10 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           9 4 4           8 6 3          7 8 2
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                      6 10         5 12
+--R                                98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R            + 
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +--------------------+
+--R                               +-----------+ |   +-----------+
+--R              2        2 4+-+3 |          2 4|   |          2
+--R         (- 8a c + 2a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  11 6            10 2 5            9 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                        17   12                   16 3 11
+--R                      - 109951162777600a  b c   + 274328151130112a  b c
+--R                    + 
+--R                                        15 5 10                   14 7 9
+--R                      - 310337156939776a  b c   + 210247239073792a  b c
+--R                    + 
+--R                                       13 9 8                  12 11 7
+--R                      - 94884417503232a  b c  + 30008936497152a  b  c
+--R                    + 
+--R                                      11 13 6                 10 15 5
+--R                      - 6809670647808a  b  c  + 1115349319680a  b  c
+--R                    + 
+--R                                     9 17 4               8 19 3
+--R                      - 130660958208a b  c  + 10661920768a b  c
+--R                    + 
+--R                                  7 21 2            6 23           5 25
+--R                      - 574619648a b  c  + 18350080a b  c - 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                               11 11                10 2 10                9 4 9
+--R                  163840000000a  c   - 293273600000a  b c   + 232144896000a b c
+--R                + 
+--R                                 8 6 8               7 8 7              6 10 6
+--R                  - 107010949120a b c  + 31849668608a b c  - 6416214016a b  c
+--R                + 
+--R                            5 12 5            4 14 4           3 16 3
+--R                  892161536a b  c  - 85686400a b  c  + 5582720a b  c
+--R                + 
+--R                           2 18 2          20       22
+--R                  - 235712a b  c  + 5824a b  c - 64b
+--R             *
+--R                ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                         + 
+--R                                     8 6 3          7 8 2         6 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                5 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         11 6            10 2 5            9 4 4
+--R                                16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                              + 
+--R                                          8 6 3          7 8 2         6 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     5 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R            + 
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                            +--------------------+
+--R                              +-----------+ |   +-----------+
+--R             2        2 4+-+3 |          2 4|   |          2
+--R         (16a c - 4a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  11 6            10 2 5            9 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 5242880a b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                      17   12                   16 3 11
+--R                      109951162777600a  b c   - 274328151130112a  b c
+--R                    + 
+--R                                      15 5 10                   14 7 9
+--R                      310337156939776a  b c   - 210247239073792a  b c
+--R                    + 
+--R                                     13 9 8                  12 11 7
+--R                      94884417503232a  b c  - 30008936497152a  b  c
+--R                    + 
+--R                                    11 13 6                 10 15 5
+--R                      6809670647808a  b  c  - 1115349319680a  b  c
+--R                    + 
+--R                                   9 17 4               8 19 3
+--R                      130660958208a b  c  - 10661920768a b  c
+--R                    + 
+--R                                7 21 2            6 23           5 25
+--R                      574619648a b  c  - 18350080a b  c + 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 11 11                10 2 10
+--R                  - 163840000000a  c   + 293273600000a  b c
+--R                + 
+--R                                 9 4 9                8 6 8               7 8 7
+--R                  - 232144896000a b c  + 107010949120a b c  - 31849668608a b c
+--R                + 
+--R                             6 10 6             5 12 5            4 14 4
+--R                  6416214016a b  c  - 892161536a b  c  + 85686400a b  c
+--R                + 
+--R                            3 16 3          2 18 2          20       22
+--R                  - 5582720a b  c  + 235712a b  c  - 5824a b  c + 64b
+--R             *
+--R                ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                         + 
+--R                                     8 6 3          7 8 2         6 10
+--R                           - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                         + 
+--R                                5 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         11 6            10 2 5            9 4 4
+--R                                16777216a  c  - 25165824a  b c  + 15728640a b c
+--R                              + 
+--R                                          8 6 3          7 8 2         6 10
+--R                                - 5242880a b c  + 983040a b c  - 98304a b  c
+--R                              + 
+--R                                     5 12
+--R                                4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R           /
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                              +--------------------+
+--R                                +-----------+ |   +-----------+
+--R               2        2 4+-+3 |          2 4|   |          2
+--R         (- 16a c + 4a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    11 6            10 2 5            9 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                       + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                        6 6           5 2 5          4 4 4
+--R                              - 6250000a c  + 2625000a b c  - 470625a b c
+--R                            + 
+--R                                    3 6 3        2 8 2        10     12
+--R                              45950a b c  - 2571a b c  + 78a b  c - b
+--R                         /
+--R                                            19 9                 18 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            17 4 7                 16 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            15 8 5                14 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          13 12 3              12 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        11 16             10 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                             4   4        3 3 3       2 5 2        7     9
+--R                     - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                /
+--R                             11 6            10 2 5           9 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                   + 
+--R                               8 6 3          7 8 2         6 10         5 12
+--R                     - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                      17   12                   16 3 11
+--R                      109951162777600a  b c   - 274328151130112a  b c
+--R                    + 
+--R                                      15 5 10                   14 7 9
+--R                      310337156939776a  b c   - 210247239073792a  b c
+--R                    + 
+--R                                     13 9 8                  12 11 7
+--R                      94884417503232a  b c  - 30008936497152a  b  c
+--R                    + 
+--R                                    11 13 6                 10 15 5
+--R                      6809670647808a  b  c  - 1115349319680a  b  c
+--R                    + 
+--R                                   9 17 4               8 19 3
+--R                      130660958208a b  c  - 10661920768a b  c
+--R                    + 
+--R                                7 21 2            6 23           5 25
+--R                      574619648a b  c  - 18350080a b  c + 262144a b
+--R                 *
+--R                    ROOT
+--R                                     6 6           5 2 5          4 4 4
+--R                           - 6250000a c  + 2625000a b c  - 470625a b c
+--R                         + 
+--R                                 3 6 3        2 8 2        10     12
+--R                           45950a b c  - 2571a b c  + 78a b  c - b
+--R                      /
+--R                                         19 9                 18 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         17 4 7                 16 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         15 8 5                14 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       13 12 3              12 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     11 16             10 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                               11 11                10 2 10                9 4 9
+--R                  163840000000a  c   - 293273600000a  b c   + 232144896000a b c
+--R                + 
+--R                                 8 6 8               7 8 7              6 10 6
+--R                  - 107010949120a b c  + 31849668608a b c  - 6416214016a b  c
+--R                + 
+--R                            5 12 5            4 14 4           3 16 3
+--R                  892161536a b  c  - 85686400a b  c  + 5582720a b  c
+--R                + 
+--R                           2 18 2          20       22
+--R                  - 235712a b  c  + 5824a b  c - 64b
+--R             *
+--R                ROOT
+--R                                      11 6            10 2 5            9 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a b c
+--R                         + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                         5242880a b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                      *
+--R                         ROOT
+--R                                          6 6           5 2 5          4 4 4
+--R                                - 6250000a c  + 2625000a b c  - 470625a b c
+--R                              + 
+--R                                      3 6 3        2 8 2        10     12
+--R                                45950a b c  - 2571a b c  + 78a b  c - b
+--R                           /
+--R                                              19 9                 18 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              17 4 7                 16 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              15 8 5                14 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            13 12 3              12 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          11 16             10 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                               4   4        3 3 3       2 5 2        7     9
+--R                       - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                  /
+--R                               11 6            10 2 5           9 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                     + 
+--R                                 8 6 3          7 8 2         6 10         5 12
+--R                       - 2621440a b c  + 491520a b c  - 49152a b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           11 6            10 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           9 4 4           8 6 3          7 8 2
+--R                                - 15728640a b c  + 5242880a b c  - 983040a b c
+--R                              + 
+--R                                      6 10         5 12
+--R                                98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                               6 6           5 2 5
+--R                                     - 6250000a c  + 2625000a b c
+--R                                   + 
+--R                                              4 4 4         3 6 3        2 8 2
+--R                                     - 470625a b c  + 45950a b c  - 2571a b c
+--R                                   + 
+--R                                          10     12
+--R                                     78a b  c - b
+--R                                /
+--R                                                   19 9                 18 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   17 4 7                 16 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   15 8 5                14 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 13 12 3              12 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               11 16             10 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                  4   4        3 3 3       2 5 2        7     9
+--R                          - 18000a b c  + 5880a b c  - 765a b c  + 45a b c - b
+--R                       /
+--R                                    11 6            10 2 5           9 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a b c
+--R                          + 
+--R                                      8 6 3          7 8 2         6 10
+--R                            - 2621440a b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 5 12
+--R                            2048a b
+--R           /
+--R                             6 10              5 2 9             4 4 8
+--R                  2500000000a c   - 1200000000a b c  + 241500000a b c
+--R                + 
+--R                             3 6 7           2 8 6           10 5       12 4
+--R                  - 26110000a b c  + 1600425a b c  - 52731a b  c  + 729b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                              +------------------+
+--R              +-----------+                   | +-----------+
+--R              |          2             2 4+-+4| |          2
+--R         (- b\|- 4a c + b   - 20a c + b )\|c \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                              +--------------------+
+--R              +-----------+                   |   +-----------+
+--R              |          2             2 4+-+4|   |          2
+--R         (- b\|- 4a c + b   + 20a c - b )\|c \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                            +------------------+
+--R            +-----------+                   | +-----------+
+--R            |          2             2 4+-+4| |          2
+--R         (b\|- 4a c + b   + 20a c - b )\|c \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                            +--------------------+
+--R            +-----------+                   |   +-----------+
+--R            |          2             2 4+-+4|   |          2
+--R         (b\|- 4a c + b   - 20a c + b )\|c \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R           2        2 4+-+3 |          2 4|   |          2
+--R       (16a c - 4a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 663
+
+--S 664 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 664
+
+)clear all
+
+--S 665 of 1057
+t0:=1/(x^(1/2)*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                 1
+--R   (1)  ---------------------------------------------------
+--R          2 8         6            2  4         2    2  +-+
+--R        (c x  + 2b c x  + (2a c + b )x  + 2a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 1057
+r0:=-1/4*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (3*b+(3*b^2-28*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*a*(b^2-4*a*c)*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))-1/4*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(3*b+(3*b^2-28*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*a*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))+1/4*c^(3/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(3*b^2-_
+   28*a*c-3*b*sqrt(b^2-4*a*c))/(2^(1/4)*a*(b^2-4*a*c)^(3/2)*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))+1/4*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))*(3*b^2-28*a*c-3*b*sqrt(b^2-4*a*c))/_
+   (2^(1/4)*a*(b^2-4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(3/4))+1/2*(b^2-_
+   2*a*c+b*c*x^2)*sqrt(x)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                                    +-----------+
+--R                  4     2 2         |          2          2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (28a c  - 3b c)x
+--R         + 
+--R                        3  2      2        2
+--R           (28a b c - 3b )x  + 28a c - 3a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                  4+-+4+-+ +-+
+--R         4+-+3 4| |          2                   \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2            2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (- 28a c  + 3b c)x
+--R         + 
+--R                          3  2      2        2
+--R           (- 28a b c + 3b )x  - 28a c + 3a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                  \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2          2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (28a c  - 3b c)x
+--R         + 
+--R                        3  2      2        2
+--R           (28a b c - 3b )x  + 28a c - 3a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4| |          2                  \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2            2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (- 28a c  + 3b c)x
+--R         + 
+--R                          3  2      2        2
+--R           (- 28a b c + 3b )x  - 28a c + 3a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                 \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R     + 
+--R                                                        +--------------------+3
+--R                                      +-----------+     |   +-----------+
+--R                  2            2 4+-+ |          2  +-+4|   |          2
+--R         (- 2b c x  + 4a c - 2b )\|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R            2 2       2   4       2          3  2      3      2 2 4+-+
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|2
+--R    *
+--R                      +--------------------+3  +------------------+3
+--R        +-----------+ |   +-----------+        | +-----------+
+--R        |          2 4|   |          2        4| |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 2      2   4      2         3  2     3     2 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  13 6            12 2 5            11 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                 10 6 3          9 8 2         8 10         7 12
+--R                       - 5242880a  b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                14   7              13 3 6             12 5 5
+--R                      671088640a  b c  - 1107296256a  b c  + 780140544a  b c
+--R                    + 
+--R                                  11 7 4            10 9 3           9 11 2
+--R                      - 304087040a  b c  + 70778880a  b c  - 9830400a b  c
+--R                    + 
+--R                             8 13          7 15
+--R                      753664a b  c - 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                          7 7            6 2 6            5 4 5           4 6 4
+--R                  4302592a c  - 14861504a b c  + 13964272a b c  - 6209796a b c
+--R                + 
+--R                          3 8 3          2 10 2           12        14
+--R                  1520622a b c  - 211464a b  c  + 15714a b  c - 486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         13 6            12 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         11 4 4           10 6 3          9 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a b c
+--R                              + 
+--R                                        8 10         7 12
+--R                                - 98304a b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R            + 
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               2 2      2   4        2         3  2     3     2 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    13 6            12 2 5            11 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                       5242880a  b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                14   7              13 3 6             12 5 5
+--R                      671088640a  b c  - 1107296256a  b c  + 780140544a  b c
+--R                    + 
+--R                                  11 7 4            10 9 3           9 11 2
+--R                      - 304087040a  b c  + 70778880a  b c  - 9830400a b  c
+--R                    + 
+--R                             8 13          7 15
+--R                      753664a b  c - 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                            7 7            6 2 6            5 4 5
+--R                  - 4302592a c  + 14861504a b c  - 13964272a b c
+--R                + 
+--R                          4 6 4           3 8 3          2 10 2           12
+--R                  6209796a b c  - 1520622a b c  + 211464a b  c  - 15714a b  c
+--R                + 
+--R                      14
+--R                  486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           13 6            12 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           11 4 4           10 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         9 8 2         8 10         7 12
+--R                                - 983040a b c  + 98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R            + 
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R             2 2      2   4      2         3  2     3     2 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    13 6            12 2 5            11 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                       5242880a  b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                  14   7              13 3 6             12 5 5
+--R                      - 671088640a  b c  + 1107296256a  b c  - 780140544a  b c
+--R                    + 
+--R                                11 7 4            10 9 3           9 11 2
+--R                      304087040a  b c  - 70778880a  b c  + 9830400a b  c
+--R                    + 
+--R                               8 13          7 15
+--R                      - 753664a b  c + 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                          7 7            6 2 6            5 4 5           4 6 4
+--R                  4302592a c  - 14861504a b c  + 13964272a b c  - 6209796a b c
+--R                + 
+--R                          3 8 3          2 10 2           12        14
+--R                  1520622a b c  - 211464a b  c  + 15714a b  c - 486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           13 6            12 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           11 4 4           10 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         9 8 2         8 10         7 12
+--R                                - 983040a b c  + 98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R            + 
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               2 2      2   4        2         3  2     3     2 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  13 6            12 2 5            11 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                 10 6 3          9 8 2         8 10         7 12
+--R                       - 5242880a  b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                  14   7              13 3 6             12 5 5
+--R                      - 671088640a  b c  + 1107296256a  b c  - 780140544a  b c
+--R                    + 
+--R                                11 7 4            10 9 3           9 11 2
+--R                      304087040a  b c  - 70778880a  b c  + 9830400a b  c
+--R                    + 
+--R                               8 13          7 15
+--R                      - 753664a b  c + 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                            7 7            6 2 6            5 4 5
+--R                  - 4302592a c  + 14861504a b c  - 13964272a b c
+--R                + 
+--R                          4 6 4           3 8 3          2 10 2           12
+--R                  6209796a b c  - 1520622a b c  + 211464a b  c  - 15714a b  c
+--R                + 
+--R                      14
+--R                  486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         13 6            12 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         11 4 4           10 6 3          9 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a b c
+--R                              + 
+--R                                        8 10         7 12
+--R                                - 98304a b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R            + 
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               2 2       2   4        2          3  2     3      2 2
+--R         ((- 8a c  + 2a b c)x  + (- 8a b c + 2a b )x  - 8a c + 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  13 6            12 2 5            11 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                 10 6 3          9 8 2         8 10         7 12
+--R                       - 5242880a  b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                14   7              13 3 6             12 5 5
+--R                      671088640a  b c  - 1107296256a  b c  + 780140544a  b c
+--R                    + 
+--R                                  11 7 4            10 9 3           9 11 2
+--R                      - 304087040a  b c  + 70778880a  b c  - 9830400a b  c
+--R                    + 
+--R                             8 13          7 15
+--R                      753664a b  c - 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                          7 7            6 2 6            5 4 5           4 6 4
+--R                  4302592a c  - 14861504a b c  + 13964272a b c  - 6209796a b c
+--R                + 
+--R                          3 8 3          2 10 2           12        14
+--R                  1520622a b c  - 211464a b  c  + 15714a b  c - 486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         13 6            12 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         11 4 4           10 6 3          9 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a b c
+--R                              + 
+--R                                        8 10         7 12
+--R                                - 98304a b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R           /
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R             2 2       2   4      2          3  2     3      2 2
+--R         ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b )
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    13 6            12 2 5            11 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                       5242880a  b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                14   7              13 3 6             12 5 5
+--R                      671088640a  b c  - 1107296256a  b c  + 780140544a  b c
+--R                    + 
+--R                                  11 7 4            10 9 3           9 11 2
+--R                      - 304087040a  b c  + 70778880a  b c  - 9830400a b  c
+--R                    + 
+--R                             8 13          7 15
+--R                      753664a b  c - 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                            7 7            6 2 6            5 4 5
+--R                  - 4302592a c  + 14861504a b c  - 13964272a b c
+--R                + 
+--R                          4 6 4           3 8 3          2 10 2           12
+--R                  6209796a b c  - 1520622a b c  + 211464a b  c  - 15714a b  c
+--R                + 
+--R                      14
+--R                  486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           13 6            12 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           11 4 4           10 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         9 8 2         8 10         7 12
+--R                                - 983040a b c  + 98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R           /
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               2           2  +-+
+--R       (- b c x  + 2a c - b )\|x
+--R  /
+--R        2 2       2   4      2          3  2     3      2 2
+--R     (8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 667
+
+--S 668 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                          +--------------------+3
+--R                            +-----------+ |   +-----------+
+--R            2        2 4+-+ |          2 4|   |          2
+--R         (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  13 6            12 2 5            11 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                 10 6 3          9 8 2         8 10         7 12
+--R                       - 5242880a  b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                14   7              13 3 6             12 5 5
+--R                      671088640a  b c  - 1107296256a  b c  + 780140544a  b c
+--R                    + 
+--R                                  11 7 4            10 9 3           9 11 2
+--R                      - 304087040a  b c  + 70778880a  b c  - 9830400a b  c
+--R                    + 
+--R                             8 13          7 15
+--R                      753664a b  c - 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                          7 7            6 2 6            5 4 5           4 6 4
+--R                  4302592a c  - 14861504a b c  + 13964272a b c  - 6209796a b c
+--R                + 
+--R                          3 8 3          2 10 2           12        14
+--R                  1520622a b c  - 211464a b  c  + 15714a b  c - 486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         13 6            12 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         11 4 4           10 6 3          9 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a b c
+--R                              + 
+--R                                        8 10         7 12
+--R                                - 98304a b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R            + 
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                            +--------------------+3
+--R                              +-----------+ |   +-----------+
+--R              2        2 4+-+ |          2 4|   |          2
+--R         (- 8a c + 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    13 6            12 2 5            11 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                       5242880a  b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                14   7              13 3 6             12 5 5
+--R                      671088640a  b c  - 1107296256a  b c  + 780140544a  b c
+--R                    + 
+--R                                  11 7 4            10 9 3           9 11 2
+--R                      - 304087040a  b c  + 70778880a  b c  - 9830400a b  c
+--R                    + 
+--R                             8 13          7 15
+--R                      753664a b  c - 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                            7 7            6 2 6            5 4 5
+--R                  - 4302592a c  + 14861504a b c  - 13964272a b c
+--R                + 
+--R                          4 6 4           3 8 3          2 10 2           12
+--R                  6209796a b c  - 1520622a b c  + 211464a b  c  - 15714a b  c
+--R                + 
+--R                      14
+--R                  486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           13 6            12 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           11 4 4           10 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         9 8 2         8 10         7 12
+--R                                - 983040a b c  + 98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R            + 
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                          +--------------------+3
+--R                            +-----------+ |   +-----------+
+--R            2        2 4+-+ |          2 4|   |          2
+--R         (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    13 6            12 2 5            11 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                       5242880a  b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                  14   7              13 3 6             12 5 5
+--R                      - 671088640a  b c  + 1107296256a  b c  - 780140544a  b c
+--R                    + 
+--R                                11 7 4            10 9 3           9 11 2
+--R                      304087040a  b c  - 70778880a  b c  + 9830400a b  c
+--R                    + 
+--R                               8 13          7 15
+--R                      - 753664a b  c + 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                          7 7            6 2 6            5 4 5           4 6 4
+--R                  4302592a c  - 14861504a b c  + 13964272a b c  - 6209796a b c
+--R                + 
+--R                          3 8 3          2 10 2           12        14
+--R                  1520622a b c  - 211464a b  c  + 15714a b  c - 486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           13 6            12 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           11 4 4           10 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         9 8 2         8 10         7 12
+--R                                - 983040a b c  + 98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R            + 
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                            +--------------------+3
+--R                              +-----------+ |   +-----------+
+--R              2        2 4+-+ |          2 4|   |          2
+--R         (- 8a c + 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  13 6            12 2 5            11 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                 10 6 3          9 8 2         8 10         7 12
+--R                       - 5242880a  b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         log
+--R                                  14   7              13 3 6             12 5 5
+--R                      - 671088640a  b c  + 1107296256a  b c  - 780140544a  b c
+--R                    + 
+--R                                11 7 4            10 9 3           9 11 2
+--R                      304087040a  b c  - 70778880a  b c  + 9830400a b  c
+--R                    + 
+--R                               8 13          7 15
+--R                      - 753664a b  c + 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                            7 7            6 2 6            5 4 5
+--R                  - 4302592a c  + 14861504a b c  - 13964272a b c
+--R                + 
+--R                          4 6 4           3 8 3          2 10 2           12
+--R                  6209796a b c  - 1520622a b c  + 211464a b  c  - 15714a b  c
+--R                + 
+--R                      14
+--R                  486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         13 6            12 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         11 4 4           10 6 3          9 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a b c
+--R                              + 
+--R                                        8 10         7 12
+--R                                - 98304a b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R            + 
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +--------------------+3
+--R                               +-----------+ |   +-----------+
+--R               2        2 4+-+ |          2 4|   |          2
+--R         (- 16a c + 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  13 6            12 2 5            11 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                 10 6 3          9 8 2         8 10         7 12
+--R                       - 5242880a  b c  + 983040a b c  - 98304a b  c + 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                14   7              13 3 6             12 5 5
+--R                      671088640a  b c  - 1107296256a  b c  + 780140544a  b c
+--R                    + 
+--R                                  11 7 4            10 9 3           9 11 2
+--R                      - 304087040a  b c  + 70778880a  b c  - 9830400a b  c
+--R                    + 
+--R                             8 13          7 15
+--R                      753664a b  c - 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                          7 7            6 2 6            5 4 5           4 6 4
+--R                  4302592a c  - 14861504a b c  + 13964272a b c  - 6209796a b c
+--R                + 
+--R                          3 8 3          2 10 2           12        14
+--R                  1520622a b c  - 211464a b  c  + 15714a b  c - 486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         13 6            12 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         11 4 4           10 6 3          9 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a b c
+--R                              + 
+--R                                        8 10         7 12
+--R                                - 98304a b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R           /
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                           +--------------------+3
+--R                             +-----------+ |   +-----------+
+--R             2        2 4+-+ |          2 4|   |          2
+--R         (16a c - 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    13 6            12 2 5            11 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                       5242880a  b c  - 983040a b c  + 98304a b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                         8 8             7 2 7             6 4 6
+--R                              - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                            + 
+--R                                        5 6 5             4 8 4
+--R                              596117340a b c  - 200865582a b c
+--R                            + 
+--R                                       3 10 3           2 12 2            14
+--R                              38499462a b  c  - 4278501a b  c  + 258066a b  c
+--R                            + 
+--R                                     16
+--R                              - 6561b
+--R                         /
+--R                                            23 9                 22 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            21 4 7                 20 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            19 8 5                18 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          17 12 3              16 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        15 16             14 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     181104a b c  - 226072a b c  + 100023a b c  - 20790a b c
+--R                   + 
+--R                            9       11
+--R                     2079a b c - 81b
+--R                /
+--R                             13 6            12 2 5           11 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                               10 6 3          9 8 2         8 10         7 12
+--R                     - 2621440a  b c  + 491520a b c  - 49152a b  c + 2048a b
+--R      *
+--R         atan
+--R                                14   7              13 3 6             12 5 5
+--R                      671088640a  b c  - 1107296256a  b c  + 780140544a  b c
+--R                    + 
+--R                                  11 7 4            10 9 3           9 11 2
+--R                      - 304087040a  b c  + 70778880a  b c  - 9830400a b  c
+--R                    + 
+--R                             8 13          7 15
+--R                      753664a b  c - 24576a b
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7             6 4 6
+--R                           - 92236816a c  + 505420104a b c  - 898783137a b c
+--R                         + 
+--R                                     5 6 5             4 8 4            3 10 3
+--R                           596117340a b c  - 200865582a b c  + 38499462a b  c
+--R                         + 
+--R                                     2 12 2            14         16
+--R                           - 4278501a b  c  + 258066a b  c - 6561b
+--R                      /
+--R                                         23 9                 22 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         21 4 7                 20 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         19 8 5                18 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       17 12 3              16 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     15 16             14 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                            7 7            6 2 6            5 4 5
+--R                  - 4302592a c  + 14861504a b c  - 13964272a b c
+--R                + 
+--R                          4 6 4           3 8 3          2 10 2           12
+--R                  6209796a b c  - 1520622a b c  + 211464a b  c  - 15714a b  c
+--R                + 
+--R                      14
+--R                  486b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           13 6            12 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           11 4 4           10 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         9 8 2         8 10         7 12
+--R                                - 983040a b c  + 98304a b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                8 8             7 2 7
+--R                                     - 92236816a c  + 505420104a b c
+--R                                   + 
+--R                                                 6 4 6             5 6 5
+--R                                     - 898783137a b c  + 596117340a b c
+--R                                   + 
+--R                                                 4 8 4            3 10 3
+--R                                     - 200865582a b c  + 38499462a b  c
+--R                                   + 
+--R                                               2 12 2            14         16
+--R                                     - 4278501a b  c  + 258066a b  c - 6561b
+--R                                /
+--R                                                   23 9                 22 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   21 4 7                 20 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   19 8 5                18 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 17 12 3              16 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               15 16             14 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                   5   5          4 3 4          3 5 3
+--R                            181104a b c  - 226072a b c  + 100023a b c
+--R                          + 
+--R                                    2 7 2          9       11
+--R                            - 20790a b c  + 2079a b c - 81b
+--R                       /
+--R                                    13 6            12 2 5           11 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      10 6 3          9 8 2         8 10
+--R                            - 2621440a  b c  + 491520a b c  - 49152a b  c
+--R                          + 
+--R                                 7 12
+--R                            2048a b
+--R           /
+--R                          5 7           4 2 6           3 4 5          2 6 4
+--R                  1882384a c  - 5474280a b c  + 2974545a b c  - 666846a b c
+--R                + 
+--R                          8 3        10 2
+--R                  68445a b c  - 2673b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                  +------------------+3
+--R               +-----------+                      | +-----------+
+--R               |          2              2 4+-+3 4| |          2
+--R         (- 3b\|- 4a c + b   - 28a c + 3b )\|c   \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                  +--------------------+3
+--R               +-----------+                      |   +-----------+
+--R               |          2              2 4+-+3 4|   |          2
+--R         (- 3b\|- 4a c + b   + 28a c - 3b )\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                                  +------------------+3
+--R               +-----------+                      | +-----------+
+--R               |          2              2 4+-+3 4| |          2
+--R         (- 3b\|- 4a c + b   - 28a c + 3b )\|c   \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                                  +--------------------+3
+--R               +-----------+                      |   +-----------+
+--R               |          2              2 4+-+3 4|   |          2
+--R         (- 3b\|- 4a c + b   + 28a c - 3b )\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                         +--------------------+3
+--R                           +-----------+ |   +-----------+
+--R           2        2 4+-+ |          2 4|   |          2
+--R       (16a c - 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+3
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 668
+
+--S 669 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 669
+
+)clear all
+
+--S 670 of 1057
+t0:=1/(x^(3/2)*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R          2 9         7            2  5         3    2   +-+
+--R        (c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 1057
+r0:=-1/4*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (5*b^2-18*a*c-5*b^3/sqrt(b^2-4*a*c)+28*a*b*c/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a^2*(b^2-4*a*c)*(-b-sqrt(b^2-4*a*c))^(1/4))+1/4*c^(1/4)*atanh(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(5*b^2-18*a*c-5*b^3/_
+   sqrt(b^2-4*a*c)+28*a*b*c/sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-1/4*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(5*b^2-18*a*c+5*b^3/sqrt(b^2-4*a*c)-_
+   28*a*b*c/sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)*(-b+sqrt(b^2-_
+   4*a*c))^(1/4))+1/4*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(5*b^2-18*a*c+5*b^3/sqrt(b^2-4*a*c)-28*a*b*c/sqrt(b^2-_
+   4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))+_
+   1/2*(-5*b^2+18*a*c)/(a^2*(b^2-4*a*c)*sqrt(x))+1/2*(b^2-2*a*c+b*c*x^2)/_
+   (a*(b^2-4*a*c)*(a+b*x^2+c*x^4)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                                                                   +-----------+
+--R                  2     2   4                3  2      2        2  |          2
+--R           ((18a c  - 5b c)x  + (18a b c - 5b )x  + 18a c - 5a b )\|- 4a c + b
+--R         + 
+--R                     2     3   4           2      4  2      2          3
+--R           (- 28a b c  + 5b c)x  + (- 28a b c + 5b )x  - 28a b c + 5a b
+--R      *
+--R                  +------------------+
+--R                  | +-----------+                 4+-+4+-+ +-+
+--R         4+-+ +-+4| |          2                  \|2 \|c \|x
+--R         \|c \|x \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                             +--------------------+
+--R                                             |   +-----------+
+--R                                            4|   |          2
+--R                                            \|- \|- 4a c + b   - b
+--R     + 
+--R                                                                   +-----------+
+--R                  2     2   4                3  2      2        2  |          2
+--R           ((18a c  - 5b c)x  + (18a b c - 5b )x  + 18a c - 5a b )\|- 4a c + b
+--R         + 
+--R                   2     3   4         2      4  2      2          3
+--R           (28a b c  - 5b c)x  + (28a b c - 5b )x  + 28a b c - 5a b
+--R      *
+--R                  +--------------------+
+--R                  |   +-----------+                4+-+4+-+ +-+
+--R         4+-+ +-+4|   |          2                 \|2 \|c \|x
+--R         \|c \|x \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                               +------------------+
+--R                                               | +-----------+
+--R                                              4| |          2
+--R                                              \|\|- 4a c + b   - b
+--R     + 
+--R                      2     2   4                  3  2      2        2
+--R             ((- 18a c  + 5b c)x  + (- 18a b c + 5b )x  - 18a c + 5a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   4         2      4  2      2          3
+--R           (28a b c  - 5b c)x  + (28a b c - 5b )x  + 28a b c - 5a b
+--R      *
+--R                  +------------------+
+--R                  | +-----------+                4+-+4+-+ +-+
+--R         4+-+ +-+4| |          2                 \|2 \|c \|x
+--R         \|c \|x \|\|- 4a c + b   - b atan(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                      2     2   4                  3  2      2        2
+--R             ((- 18a c  + 5b c)x  + (- 18a b c + 5b )x  - 18a c + 5a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   4           2      4  2      2          3
+--R           (- 28a b c  + 5b c)x  + (- 28a b c + 5b )x  - 28a b c + 5a b
+--R      *
+--R                  +--------------------+
+--R                  |   +-----------+               4+-+4+-+ +-+
+--R         4+-+ +-+4|   |          2                \|2 \|c \|x
+--R         \|c \|x \|- \|- 4a c + b   - b atan(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                  2      2   4                   3  2      2        2 4+-+3
+--R         ((- 36a c  + 10b c)x  + (- 38a b c + 10b )x  - 32a c + 8a b )\|2
+--R      *
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2 4|   |          2      4| |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R            3 2     2 2   4       3        2 3  2      4      3 2 4+-+3
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|2
+--R    *
+--R                          +--------------------+ +------------------+
+--R        +-----------+     |   +-----------+      | +-----------+
+--R        |          2  +-+4|   |          2      4| |          2
+--R       \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 2    2 2   4        3       2 3  2     4     3 2  +-+
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  15 6            14 2 5            13 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                   12 6 3          11 8 2         10 10
+--R                         - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                       + 
+--R                              9 12
+--R                         4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         log
+--R                                      23 14                    22 2 13
+--R                      801543976648704a  c   - 5261987772628992a  b c
+--R                    + 
+--R                                        21 4 12                     20 6 11
+--R                      12550856511586304a  b c   - 16517430608134144a  b c
+--R                    + 
+--R                                        19 8 10                    18 10 9
+--R                      14034037567913984a  b c   - 8320440426561536a  b  c
+--R                    + 
+--R                                       17 12 8                    16 14 7
+--R                      3591803303362560a  b  c  - 1155155210797056a  b  c
+--R                    + 
+--R                                      15 16 6                  14 18 5
+--R                      279443675283456a  b  c  - 50766928674816a  b  c
+--R                    + 
+--R                                    13 20 4                12 22 3
+--R                      6834235637760a  b  c  - 662258843648a  b  c
+--R                    + 
+--R                                  11 24 2              10 26             9 28
+--R                      43728240640a  b  c  - 1762918400a  b  c + 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 14   14                   13 3 13
+--R                  28420070178816a  b c   - 263859127713792a  b c
+--R                + 
+--R                                  12 5 12                    11 7 11
+--R                  796025257132032a  b c   - 1257965305610240a  b c
+--R                + 
+--R                                   10 9 10                   9 11 9
+--R                  1238589537095680a  b c   - 828140100762624a b  c
+--R                + 
+--R                                  8 13 8                   7 15 7
+--R                  394501795013888a b  c  - 137537083595968a b  c
+--R                + 
+--R                                 6 17 6                 5 19 5
+--R                  35534940412160a b  c  - 6808455404800a b  c
+--R                + 
+--R                               4 21 4               3 23 3              2 25 2
+--R                  956241680000a b  c  - 95773600000a b  c  + 6482800000a b  c
+--R                + 
+--R                                27            29
+--R                  - 266000000a b  c + 5000000b
+--R             *
+--R                ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                         + 
+--R                                     12 6 3          11 8 2         10 10
+--R                           - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                         + 
+--R                                9 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         15 6            14 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         13 4 4           12 6 3          11 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a  b c
+--R                              + 
+--R                                        10 10         9 12
+--R                                - 98304a  b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R            + 
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R             3 2    2 2   4      3       2 3  2     4     3 2  +-+
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                       5242880a  b c  - 983040a  b c  + 98304a  b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         log
+--R                                      23 14                    22 2 13
+--R                      801543976648704a  c   - 5261987772628992a  b c
+--R                    + 
+--R                                        21 4 12                     20 6 11
+--R                      12550856511586304a  b c   - 16517430608134144a  b c
+--R                    + 
+--R                                        19 8 10                    18 10 9
+--R                      14034037567913984a  b c   - 8320440426561536a  b  c
+--R                    + 
+--R                                       17 12 8                    16 14 7
+--R                      3591803303362560a  b  c  - 1155155210797056a  b  c
+--R                    + 
+--R                                      15 16 6                  14 18 5
+--R                      279443675283456a  b  c  - 50766928674816a  b  c
+--R                    + 
+--R                                    13 20 4                12 22 3
+--R                      6834235637760a  b  c  - 662258843648a  b  c
+--R                    + 
+--R                                  11 24 2              10 26             9 28
+--R                      43728240640a  b  c  - 1762918400a  b  c + 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                   14   14                   13 3 13
+--R                  - 28420070178816a  b c   + 263859127713792a  b c
+--R                + 
+--R                                    12 5 12                    11 7 11
+--R                  - 796025257132032a  b c   + 1257965305610240a  b c
+--R                + 
+--R                                     10 9 10                   9 11 9
+--R                  - 1238589537095680a  b c   + 828140100762624a b  c
+--R                + 
+--R                                    8 13 8                   7 15 7
+--R                  - 394501795013888a b  c  + 137537083595968a b  c
+--R                + 
+--R                                   6 17 6                 5 19 5
+--R                  - 35534940412160a b  c  + 6808455404800a b  c
+--R                + 
+--R                                 4 21 4               3 23 3              2 25 2
+--R                  - 956241680000a b  c  + 95773600000a b  c  - 6482800000a b  c
+--R                + 
+--R                              27            29
+--R                  266000000a b  c - 5000000b
+--R             *
+--R                ROOT
+--R                                      15 6            14 2 5            13 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                         + 
+--R                                   12 6 3          11 8 2         10 10
+--R                           5242880a  b c  - 983040a  b c  + 98304a  b  c
+--R                         + 
+--R                                  9 12
+--R                           - 4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           15 6            14 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           13 4 4           12 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         11 8 2         10 10         9 12
+--R                                - 983040a  b c  + 98304a  b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R            + 
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               3 2    2 2   4        3       2 3  2     4     3 2  +-+
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                       5242880a  b c  - 983040a  b c  + 98304a  b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         log
+--R                                        23 14                    22 2 13
+--R                      - 801543976648704a  c   + 5261987772628992a  b c
+--R                    + 
+--R                                          21 4 12                     20 6 11
+--R                      - 12550856511586304a  b c   + 16517430608134144a  b c
+--R                    + 
+--R                                          19 8 10                    18 10 9
+--R                      - 14034037567913984a  b c   + 8320440426561536a  b  c
+--R                    + 
+--R                                         17 12 8                    16 14 7
+--R                      - 3591803303362560a  b  c  + 1155155210797056a  b  c
+--R                    + 
+--R                                        15 16 6                  14 18 5
+--R                      - 279443675283456a  b  c  + 50766928674816a  b  c
+--R                    + 
+--R                                      13 20 4                12 22 3
+--R                      - 6834235637760a  b  c  + 662258843648a  b  c
+--R                    + 
+--R                                    11 24 2              10 26             9 28
+--R                      - 43728240640a  b  c  + 1762918400a  b  c - 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 14   14                   13 3 13
+--R                  28420070178816a  b c   - 263859127713792a  b c
+--R                + 
+--R                                  12 5 12                    11 7 11
+--R                  796025257132032a  b c   - 1257965305610240a  b c
+--R                + 
+--R                                   10 9 10                   9 11 9
+--R                  1238589537095680a  b c   - 828140100762624a b  c
+--R                + 
+--R                                  8 13 8                   7 15 7
+--R                  394501795013888a b  c  - 137537083595968a b  c
+--R                + 
+--R                                 6 17 6                 5 19 5
+--R                  35534940412160a b  c  - 6808455404800a b  c
+--R                + 
+--R                               4 21 4               3 23 3              2 25 2
+--R                  956241680000a b  c  - 95773600000a b  c  + 6482800000a b  c
+--R                + 
+--R                                27            29
+--R                  - 266000000a b  c + 5000000b
+--R             *
+--R                ROOT
+--R                                      15 6            14 2 5            13 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                         + 
+--R                                   12 6 3          11 8 2         10 10
+--R                           5242880a  b c  - 983040a  b c  + 98304a  b  c
+--R                         + 
+--R                                  9 12
+--R                           - 4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           15 6            14 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           13 4 4           12 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         11 8 2         10 10         9 12
+--R                                - 983040a  b c  + 98304a  b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R            + 
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R             3 2    2 2   4      3       2 3  2     4     3 2  +-+
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  15 6            14 2 5            13 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                   12 6 3          11 8 2         10 10
+--R                         - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                       + 
+--R                              9 12
+--R                         4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         log
+--R                                        23 14                    22 2 13
+--R                      - 801543976648704a  c   + 5261987772628992a  b c
+--R                    + 
+--R                                          21 4 12                     20 6 11
+--R                      - 12550856511586304a  b c   + 16517430608134144a  b c
+--R                    + 
+--R                                          19 8 10                    18 10 9
+--R                      - 14034037567913984a  b c   + 8320440426561536a  b  c
+--R                    + 
+--R                                         17 12 8                    16 14 7
+--R                      - 3591803303362560a  b  c  + 1155155210797056a  b  c
+--R                    + 
+--R                                        15 16 6                  14 18 5
+--R                      - 279443675283456a  b  c  + 50766928674816a  b  c
+--R                    + 
+--R                                      13 20 4                12 22 3
+--R                      - 6834235637760a  b  c  + 662258843648a  b  c
+--R                    + 
+--R                                    11 24 2              10 26             9 28
+--R                      - 43728240640a  b  c  + 1762918400a  b  c - 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                   14   14                   13 3 13
+--R                  - 28420070178816a  b c   + 263859127713792a  b c
+--R                + 
+--R                                    12 5 12                    11 7 11
+--R                  - 796025257132032a  b c   + 1257965305610240a  b c
+--R                + 
+--R                                     10 9 10                   9 11 9
+--R                  - 1238589537095680a  b c   + 828140100762624a b  c
+--R                + 
+--R                                    8 13 8                   7 15 7
+--R                  - 394501795013888a b  c  + 137537083595968a b  c
+--R                + 
+--R                                   6 17 6                 5 19 5
+--R                  - 35534940412160a b  c  + 6808455404800a b  c
+--R                + 
+--R                                 4 21 4               3 23 3              2 25 2
+--R                  - 956241680000a b  c  + 95773600000a b  c  - 6482800000a b  c
+--R                + 
+--R                              27            29
+--R                  266000000a b  c - 5000000b
+--R             *
+--R                ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                         + 
+--R                                     12 6 3          11 8 2         10 10
+--R                           - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                         + 
+--R                                9 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         15 6            14 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         13 4 4           12 6 3          11 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a  b c
+--R                              + 
+--R                                        10 10         9 12
+--R                                - 98304a  b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R            + 
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               3 2     2 2   4        3        2 3  2     4      3 2  +-+
+--R         ((- 8a c  + 2a b c)x  + (- 8a b c + 2a b )x  - 8a c + 2a b )\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  15 6            14 2 5            13 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                   12 6 3          11 8 2         10 10
+--R                         - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                       + 
+--R                              9 12
+--R                         4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         atan
+--R                                      23 14                    22 2 13
+--R                      801543976648704a  c   - 5261987772628992a  b c
+--R                    + 
+--R                                        21 4 12                     20 6 11
+--R                      12550856511586304a  b c   - 16517430608134144a  b c
+--R                    + 
+--R                                        19 8 10                    18 10 9
+--R                      14034037567913984a  b c   - 8320440426561536a  b  c
+--R                    + 
+--R                                       17 12 8                    16 14 7
+--R                      3591803303362560a  b  c  - 1155155210797056a  b  c
+--R                    + 
+--R                                      15 16 6                  14 18 5
+--R                      279443675283456a  b  c  - 50766928674816a  b  c
+--R                    + 
+--R                                    13 20 4                12 22 3
+--R                      6834235637760a  b  c  - 662258843648a  b  c
+--R                    + 
+--R                                  11 24 2              10 26             9 28
+--R                      43728240640a  b  c  - 1762918400a  b  c + 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 14   14                   13 3 13
+--R                  28420070178816a  b c   - 263859127713792a  b c
+--R                + 
+--R                                  12 5 12                    11 7 11
+--R                  796025257132032a  b c   - 1257965305610240a  b c
+--R                + 
+--R                                   10 9 10                   9 11 9
+--R                  1238589537095680a  b c   - 828140100762624a b  c
+--R                + 
+--R                                  8 13 8                   7 15 7
+--R                  394501795013888a b  c  - 137537083595968a b  c
+--R                + 
+--R                                 6 17 6                 5 19 5
+--R                  35534940412160a b  c  - 6808455404800a b  c
+--R                + 
+--R                               4 21 4               3 23 3              2 25 2
+--R                  956241680000a b  c  - 95773600000a b  c  + 6482800000a b  c
+--R                + 
+--R                                27            29
+--R                  - 266000000a b  c + 5000000b
+--R             *
+--R                ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                         + 
+--R                                     12 6 3          11 8 2         10 10
+--R                           - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                         + 
+--R                                9 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         15 6            14 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         13 4 4           12 6 3          11 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a  b c
+--R                              + 
+--R                                        10 10         9 12
+--R                                - 98304a  b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R           /
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R             3 2     2 2   4      3        2 3  2     4      3 2  +-+
+--R         ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b )\|x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                       5242880a  b c  - 983040a  b c  + 98304a  b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         atan
+--R                                      23 14                    22 2 13
+--R                      801543976648704a  c   - 5261987772628992a  b c
+--R                    + 
+--R                                        21 4 12                     20 6 11
+--R                      12550856511586304a  b c   - 16517430608134144a  b c
+--R                    + 
+--R                                        19 8 10                    18 10 9
+--R                      14034037567913984a  b c   - 8320440426561536a  b  c
+--R                    + 
+--R                                       17 12 8                    16 14 7
+--R                      3591803303362560a  b  c  - 1155155210797056a  b  c
+--R                    + 
+--R                                      15 16 6                  14 18 5
+--R                      279443675283456a  b  c  - 50766928674816a  b  c
+--R                    + 
+--R                                    13 20 4                12 22 3
+--R                      6834235637760a  b  c  - 662258843648a  b  c
+--R                    + 
+--R                                  11 24 2              10 26             9 28
+--R                      43728240640a  b  c  - 1762918400a  b  c + 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                   14   14                   13 3 13
+--R                  - 28420070178816a  b c   + 263859127713792a  b c
+--R                + 
+--R                                    12 5 12                    11 7 11
+--R                  - 796025257132032a  b c   + 1257965305610240a  b c
+--R                + 
+--R                                     10 9 10                   9 11 9
+--R                  - 1238589537095680a  b c   + 828140100762624a b  c
+--R                + 
+--R                                    8 13 8                   7 15 7
+--R                  - 394501795013888a b  c  + 137537083595968a b  c
+--R                + 
+--R                                   6 17 6                 5 19 5
+--R                  - 35534940412160a b  c  + 6808455404800a b  c
+--R                + 
+--R                                 4 21 4               3 23 3              2 25 2
+--R                  - 956241680000a b  c  + 95773600000a b  c  - 6482800000a b  c
+--R                + 
+--R                              27            29
+--R                  266000000a b  c - 5000000b
+--R             *
+--R                ROOT
+--R                                      15 6            14 2 5            13 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                         + 
+--R                                   12 6 3          11 8 2         10 10
+--R                           5242880a  b c  - 983040a  b c  + 98304a  b  c
+--R                         + 
+--R                                  9 12
+--R                           - 4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           15 6            14 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           13 4 4           12 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         11 8 2         10 10         9 12
+--R                                - 983040a  b c  + 98304a  b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R           /
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R               2     2   4                  3  2      2        2
+--R       (- 18a c  + 5b c)x  + (- 19a b c + 5b )x  - 16a c + 4a b
+--R  /
+--R         3 2     2 2   4      3        2 3  2     4      3 2  +-+
+--R     ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 672
+
+--S 673 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +--------------------+
+--R                               +-----------+ |   +-----------+
+--R              3      2 2 4+-+3 |          2 4|   |          2
+--R         (- 8a c + 2a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  15 6            14 2 5            13 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                   12 6 3          11 8 2         10 10
+--R                         - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                       + 
+--R                              9 12
+--R                         4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         log
+--R                                      23 14                    22 2 13
+--R                      801543976648704a  c   - 5261987772628992a  b c
+--R                    + 
+--R                                        21 4 12                     20 6 11
+--R                      12550856511586304a  b c   - 16517430608134144a  b c
+--R                    + 
+--R                                        19 8 10                    18 10 9
+--R                      14034037567913984a  b c   - 8320440426561536a  b  c
+--R                    + 
+--R                                       17 12 8                    16 14 7
+--R                      3591803303362560a  b  c  - 1155155210797056a  b  c
+--R                    + 
+--R                                      15 16 6                  14 18 5
+--R                      279443675283456a  b  c  - 50766928674816a  b  c
+--R                    + 
+--R                                    13 20 4                12 22 3
+--R                      6834235637760a  b  c  - 662258843648a  b  c
+--R                    + 
+--R                                  11 24 2              10 26             9 28
+--R                      43728240640a  b  c  - 1762918400a  b  c + 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 14   14                   13 3 13
+--R                  28420070178816a  b c   - 263859127713792a  b c
+--R                + 
+--R                                  12 5 12                    11 7 11
+--R                  796025257132032a  b c   - 1257965305610240a  b c
+--R                + 
+--R                                   10 9 10                   9 11 9
+--R                  1238589537095680a  b c   - 828140100762624a b  c
+--R                + 
+--R                                  8 13 8                   7 15 7
+--R                  394501795013888a b  c  - 137537083595968a b  c
+--R                + 
+--R                                 6 17 6                 5 19 5
+--R                  35534940412160a b  c  - 6808455404800a b  c
+--R                + 
+--R                               4 21 4               3 23 3              2 25 2
+--R                  956241680000a b  c  - 95773600000a b  c  + 6482800000a b  c
+--R                + 
+--R                                27            29
+--R                  - 266000000a b  c + 5000000b
+--R             *
+--R                ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                         + 
+--R                                     12 6 3          11 8 2         10 10
+--R                           - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                         + 
+--R                                9 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         15 6            14 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         13 4 4           12 6 3          11 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a  b c
+--R                              + 
+--R                                        10 10         9 12
+--R                                - 98304a  b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R            + 
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R            3      2 2 4+-+3 |          2 4|   |          2
+--R         (8a c - 2a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                       5242880a  b c  - 983040a  b c  + 98304a  b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         log
+--R                                      23 14                    22 2 13
+--R                      801543976648704a  c   - 5261987772628992a  b c
+--R                    + 
+--R                                        21 4 12                     20 6 11
+--R                      12550856511586304a  b c   - 16517430608134144a  b c
+--R                    + 
+--R                                        19 8 10                    18 10 9
+--R                      14034037567913984a  b c   - 8320440426561536a  b  c
+--R                    + 
+--R                                       17 12 8                    16 14 7
+--R                      3591803303362560a  b  c  - 1155155210797056a  b  c
+--R                    + 
+--R                                      15 16 6                  14 18 5
+--R                      279443675283456a  b  c  - 50766928674816a  b  c
+--R                    + 
+--R                                    13 20 4                12 22 3
+--R                      6834235637760a  b  c  - 662258843648a  b  c
+--R                    + 
+--R                                  11 24 2              10 26             9 28
+--R                      43728240640a  b  c  - 1762918400a  b  c + 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                   14   14                   13 3 13
+--R                  - 28420070178816a  b c   + 263859127713792a  b c
+--R                + 
+--R                                    12 5 12                    11 7 11
+--R                  - 796025257132032a  b c   + 1257965305610240a  b c
+--R                + 
+--R                                     10 9 10                   9 11 9
+--R                  - 1238589537095680a  b c   + 828140100762624a b  c
+--R                + 
+--R                                    8 13 8                   7 15 7
+--R                  - 394501795013888a b  c  + 137537083595968a b  c
+--R                + 
+--R                                   6 17 6                 5 19 5
+--R                  - 35534940412160a b  c  + 6808455404800a b  c
+--R                + 
+--R                                 4 21 4               3 23 3              2 25 2
+--R                  - 956241680000a b  c  + 95773600000a b  c  - 6482800000a b  c
+--R                + 
+--R                              27            29
+--R                  266000000a b  c - 5000000b
+--R             *
+--R                ROOT
+--R                                      15 6            14 2 5            13 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                         + 
+--R                                   12 6 3          11 8 2         10 10
+--R                           5242880a  b c  - 983040a  b c  + 98304a  b  c
+--R                         + 
+--R                                  9 12
+--R                           - 4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           15 6            14 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           13 4 4           12 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         11 8 2         10 10         9 12
+--R                                - 983040a  b c  + 98304a  b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R            + 
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +--------------------+
+--R                               +-----------+ |   +-----------+
+--R              3      2 2 4+-+3 |          2 4|   |          2
+--R         (- 8a c + 2a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                       5242880a  b c  - 983040a  b c  + 98304a  b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         log
+--R                                        23 14                    22 2 13
+--R                      - 801543976648704a  c   + 5261987772628992a  b c
+--R                    + 
+--R                                          21 4 12                     20 6 11
+--R                      - 12550856511586304a  b c   + 16517430608134144a  b c
+--R                    + 
+--R                                          19 8 10                    18 10 9
+--R                      - 14034037567913984a  b c   + 8320440426561536a  b  c
+--R                    + 
+--R                                         17 12 8                    16 14 7
+--R                      - 3591803303362560a  b  c  + 1155155210797056a  b  c
+--R                    + 
+--R                                        15 16 6                  14 18 5
+--R                      - 279443675283456a  b  c  + 50766928674816a  b  c
+--R                    + 
+--R                                      13 20 4                12 22 3
+--R                      - 6834235637760a  b  c  + 662258843648a  b  c
+--R                    + 
+--R                                    11 24 2              10 26             9 28
+--R                      - 43728240640a  b  c  + 1762918400a  b  c - 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 14   14                   13 3 13
+--R                  28420070178816a  b c   - 263859127713792a  b c
+--R                + 
+--R                                  12 5 12                    11 7 11
+--R                  796025257132032a  b c   - 1257965305610240a  b c
+--R                + 
+--R                                   10 9 10                   9 11 9
+--R                  1238589537095680a  b c   - 828140100762624a b  c
+--R                + 
+--R                                  8 13 8                   7 15 7
+--R                  394501795013888a b  c  - 137537083595968a b  c
+--R                + 
+--R                                 6 17 6                 5 19 5
+--R                  35534940412160a b  c  - 6808455404800a b  c
+--R                + 
+--R                               4 21 4               3 23 3              2 25 2
+--R                  956241680000a b  c  - 95773600000a b  c  + 6482800000a b  c
+--R                + 
+--R                                27            29
+--R                  - 266000000a b  c + 5000000b
+--R             *
+--R                ROOT
+--R                                      15 6            14 2 5            13 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                         + 
+--R                                   12 6 3          11 8 2         10 10
+--R                           5242880a  b c  - 983040a  b c  + 98304a  b  c
+--R                         + 
+--R                                  9 12
+--R                           - 4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           15 6            14 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           13 4 4           12 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         11 8 2         10 10         9 12
+--R                                - 983040a  b c  + 98304a  b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R            + 
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R            3      2 2 4+-+3 |          2 4|   |          2
+--R         (8a c - 2a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  15 6            14 2 5            13 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                   12 6 3          11 8 2         10 10
+--R                         - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                       + 
+--R                              9 12
+--R                         4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         log
+--R                                        23 14                    22 2 13
+--R                      - 801543976648704a  c   + 5261987772628992a  b c
+--R                    + 
+--R                                          21 4 12                     20 6 11
+--R                      - 12550856511586304a  b c   + 16517430608134144a  b c
+--R                    + 
+--R                                          19 8 10                    18 10 9
+--R                      - 14034037567913984a  b c   + 8320440426561536a  b  c
+--R                    + 
+--R                                         17 12 8                    16 14 7
+--R                      - 3591803303362560a  b  c  + 1155155210797056a  b  c
+--R                    + 
+--R                                        15 16 6                  14 18 5
+--R                      - 279443675283456a  b  c  + 50766928674816a  b  c
+--R                    + 
+--R                                      13 20 4                12 22 3
+--R                      - 6834235637760a  b  c  + 662258843648a  b  c
+--R                    + 
+--R                                    11 24 2              10 26             9 28
+--R                      - 43728240640a  b  c  + 1762918400a  b  c - 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                   14   14                   13 3 13
+--R                  - 28420070178816a  b c   + 263859127713792a  b c
+--R                + 
+--R                                    12 5 12                    11 7 11
+--R                  - 796025257132032a  b c   + 1257965305610240a  b c
+--R                + 
+--R                                     10 9 10                   9 11 9
+--R                  - 1238589537095680a  b c   + 828140100762624a b  c
+--R                + 
+--R                                    8 13 8                   7 15 7
+--R                  - 394501795013888a b  c  + 137537083595968a b  c
+--R                + 
+--R                                   6 17 6                 5 19 5
+--R                  - 35534940412160a b  c  + 6808455404800a b  c
+--R                + 
+--R                                 4 21 4               3 23 3              2 25 2
+--R                  - 956241680000a b  c  + 95773600000a b  c  - 6482800000a b  c
+--R                + 
+--R                              27            29
+--R                  266000000a b  c - 5000000b
+--R             *
+--R                ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                         + 
+--R                                     12 6 3          11 8 2         10 10
+--R                           - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                         + 
+--R                                9 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         15 6            14 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         13 4 4           12 6 3          11 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a  b c
+--R                              + 
+--R                                        10 10         9 12
+--R                                - 98304a  b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R            + 
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                              +--------------------+
+--R                                +-----------+ |   +-----------+
+--R               3      2 2 4+-+3 |          2 4|   |          2
+--R         (- 16a c + 4a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                  15 6            14 2 5            13 4 4
+--R                         16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                       + 
+--R                                   12 6 3          11 8 2         10 10
+--R                         - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                       + 
+--R                              9 12
+--R                         4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         atan
+--R                                      23 14                    22 2 13
+--R                      801543976648704a  c   - 5261987772628992a  b c
+--R                    + 
+--R                                        21 4 12                     20 6 11
+--R                      12550856511586304a  b c   - 16517430608134144a  b c
+--R                    + 
+--R                                        19 8 10                    18 10 9
+--R                      14034037567913984a  b c   - 8320440426561536a  b  c
+--R                    + 
+--R                                       17 12 8                    16 14 7
+--R                      3591803303362560a  b  c  - 1155155210797056a  b  c
+--R                    + 
+--R                                      15 16 6                  14 18 5
+--R                      279443675283456a  b  c  - 50766928674816a  b  c
+--R                    + 
+--R                                    13 20 4                12 22 3
+--R                      6834235637760a  b  c  - 662258843648a  b  c
+--R                    + 
+--R                                  11 24 2              10 26             9 28
+--R                      43728240640a  b  c  - 1762918400a  b  c + 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                 14   14                   13 3 13
+--R                  28420070178816a  b c   - 263859127713792a  b c
+--R                + 
+--R                                  12 5 12                    11 7 11
+--R                  796025257132032a  b c   - 1257965305610240a  b c
+--R                + 
+--R                                   10 9 10                   9 11 9
+--R                  1238589537095680a  b c   - 828140100762624a b  c
+--R                + 
+--R                                  8 13 8                   7 15 7
+--R                  394501795013888a b  c  - 137537083595968a b  c
+--R                + 
+--R                                 6 17 6                 5 19 5
+--R                  35534940412160a b  c  - 6808455404800a b  c
+--R                + 
+--R                               4 21 4               3 23 3              2 25 2
+--R                  956241680000a b  c  - 95773600000a b  c  + 6482800000a b  c
+--R                + 
+--R                                27            29
+--R                  - 266000000a b  c + 5000000b
+--R             *
+--R                ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                           16777216a  c  - 25165824a  b c  + 15728640a  b c
+--R                         + 
+--R                                     12 6 3          11 8 2         10 10
+--R                           - 5242880a  b c  + 983040a  b c  - 98304a  b  c
+--R                         + 
+--R                                9 12
+--R                           4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                         15 6            14 2 5
+--R                                16777216a  c  - 25165824a  b c
+--R                              + 
+--R                                         13 4 4           12 6 3          11 8 2
+--R                                15728640a  b c  - 5242880a  b c  + 983040a  b c
+--R                              + 
+--R                                        10 10         9 12
+--R                                - 98304a  b  c + 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R           /
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                            +--------------------+
+--R                              +-----------+ |   +-----------+
+--R             3      2 2 4+-+3 |          2 4|   |          2
+--R         (16a c - 4a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                    15 6            14 2 5            13 4 4
+--R                         - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                       + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                       5242880a  b c  - 983040a  b c  + 98304a  b  c - 4096a b
+--R                    *
+--R                       ROOT
+--R                                          10 10              9 2 9
+--R                              - 688747536a  c   + 9017490888a b c
+--R                            + 
+--R                                            8 4 8               7 6 7
+--R                              - 39067874721a b c  + 66126243780a b c
+--R                            + 
+--R                                            6 8 6               5 10 5
+--R                              - 57219314050a b c  + 28693007250a b  c
+--R                            + 
+--R                                           4 12 4              3 14 3
+--R                              - 8861859375a b  c  + 1716818750a b  c
+--R                            + 
+--R                                          2 16 2              18           20
+--R                              - 203859375a b  c  + 13593750a b  c - 390625b
+--R                         /
+--R                                            27 9                 26 2 8
+--R                              4398046511104a  c  - 9895604649984a  b c
+--R                            + 
+--R                                            25 4 7                 24 6 6
+--R                              9895604649984a  b c  - 5772436045824a  b c
+--R                            + 
+--R                                            23 8 5                22 10 4
+--R                              2164663517184a  b c  - 541165879296a  b  c
+--R                            + 
+--R                                          21 12 3              20 14 2
+--R                              90194313216a  b  c  - 9663676416a  b  c
+--R                            + 
+--R                                        19 16             18 18
+--R                              603979776a  b  c - 16777216a  b
+--R                   + 
+--R                              6   6           5 3 5           4 5 4
+--R                     - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                   + 
+--R                            3 7 3          2 9 2           11        13
+--R                     655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                /
+--R                             15 6            14 2 5           13 4 4
+--R                     8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                   + 
+--R                             12 6 3          11 8 2         10 10         9 12
+--R                   - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R      *
+--R         atan
+--R                                      23 14                    22 2 13
+--R                      801543976648704a  c   - 5261987772628992a  b c
+--R                    + 
+--R                                        21 4 12                     20 6 11
+--R                      12550856511586304a  b c   - 16517430608134144a  b c
+--R                    + 
+--R                                        19 8 10                    18 10 9
+--R                      14034037567913984a  b c   - 8320440426561536a  b  c
+--R                    + 
+--R                                       17 12 8                    16 14 7
+--R                      3591803303362560a  b  c  - 1155155210797056a  b  c
+--R                    + 
+--R                                      15 16 6                  14 18 5
+--R                      279443675283456a  b  c  - 50766928674816a  b  c
+--R                    + 
+--R                                    13 20 4                12 22 3
+--R                      6834235637760a  b  c  - 662258843648a  b  c
+--R                    + 
+--R                                  11 24 2              10 26             9 28
+--R                      43728240640a  b  c  - 1762918400a  b  c + 32768000a b
+--R                 *
+--R                    ROOT
+--R                                       10 10              9 2 9
+--R                           - 688747536a  c   + 9017490888a b c
+--R                         + 
+--R                                         8 4 8               7 6 7
+--R                           - 39067874721a b c  + 66126243780a b c
+--R                         + 
+--R                                         6 8 6               5 10 5
+--R                           - 57219314050a b c  + 28693007250a b  c
+--R                         + 
+--R                                        4 12 4              3 14 3
+--R                           - 8861859375a b  c  + 1716818750a b  c
+--R                         + 
+--R                                       2 16 2              18           20
+--R                           - 203859375a b  c  + 13593750a b  c - 390625b
+--R                      /
+--R                                         27 9                 26 2 8
+--R                           4398046511104a  c  - 9895604649984a  b c
+--R                         + 
+--R                                         25 4 7                 24 6 6
+--R                           9895604649984a  b c  - 5772436045824a  b c
+--R                         + 
+--R                                         23 8 5                22 10 4
+--R                           2164663517184a  b c  - 541165879296a  b  c
+--R                         + 
+--R                                       21 12 3              20 14 2
+--R                           90194313216a  b  c  - 9663676416a  b  c
+--R                         + 
+--R                                     19 16             18 18
+--R                           603979776a  b  c - 16777216a  b
+--R                + 
+--R                                   14   14                   13 3 13
+--R                  - 28420070178816a  b c   + 263859127713792a  b c
+--R                + 
+--R                                    12 5 12                    11 7 11
+--R                  - 796025257132032a  b c   + 1257965305610240a  b c
+--R                + 
+--R                                     10 9 10                   9 11 9
+--R                  - 1238589537095680a  b c   + 828140100762624a b  c
+--R                + 
+--R                                    8 13 8                   7 15 7
+--R                  - 394501795013888a b  c  + 137537083595968a b  c
+--R                + 
+--R                                   6 17 6                 5 19 5
+--R                  - 35534940412160a b  c  + 6808455404800a b  c
+--R                + 
+--R                                 4 21 4               3 23 3              2 25 2
+--R                  - 956241680000a b  c  + 95773600000a b  c  - 6482800000a b  c
+--R                + 
+--R                              27            29
+--R                  266000000a b  c - 5000000b
+--R             *
+--R                ROOT
+--R                                      15 6            14 2 5            13 4 4
+--R                           - 16777216a  c  + 25165824a  b c  - 15728640a  b c
+--R                         + 
+--R                                   12 6 3          11 8 2         10 10
+--R                           5242880a  b c  - 983040a  b c  + 98304a  b  c
+--R                         + 
+--R                                  9 12
+--R                           - 4096a b
+--R                      *
+--R                         ROOT
+--R                                            10 10              9 2 9
+--R                                - 688747536a  c   + 9017490888a b c
+--R                              + 
+--R                                              8 4 8               7 6 7
+--R                                - 39067874721a b c  + 66126243780a b c
+--R                              + 
+--R                                              6 8 6               5 10 5
+--R                                - 57219314050a b c  + 28693007250a b  c
+--R                              + 
+--R                                             4 12 4              3 14 3
+--R                                - 8861859375a b  c  + 1716818750a b  c
+--R                              + 
+--R                                            2 16 2              18           20
+--R                                - 203859375a b  c  + 13593750a b  c - 390625b
+--R                           /
+--R                                              27 9                 26 2 8
+--R                                4398046511104a  c  - 9895604649984a  b c
+--R                              + 
+--R                                              25 4 7                 24 6 6
+--R                                9895604649984a  b c  - 5772436045824a  b c
+--R                              + 
+--R                                              23 8 5                22 10 4
+--R                                2164663517184a  b c  - 541165879296a  b  c
+--R                              + 
+--R                                            21 12 3              20 14 2
+--R                                90194313216a  b  c  - 9663676416a  b  c
+--R                              + 
+--R                                          19 16             18 18
+--R                                603979776a  b  c - 16777216a  b
+--R                     + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                     + 
+--R                              3 7 3          2 9 2           11        13
+--R                       655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                  /
+--R                               15 6            14 2 5           13 4 4
+--R                       8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                     + 
+--R                               12 6 3          11 8 2         10 10         9 12
+--R                     - 2621440a  b c  + 491520a  b c  - 49152a  b  c + 2048a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                           15 6            14 2 5
+--R                                - 16777216a  c  + 25165824a  b c
+--R                              + 
+--R                                           13 4 4           12 6 3
+--R                                - 15728640a  b c  + 5242880a  b c
+--R                              + 
+--R                                         11 8 2         10 10         9 12
+--R                                - 983040a  b c  + 98304a  b  c - 4096a b
+--R                           *
+--R                              ROOT
+--R                                                 10 10              9 2 9
+--R                                     - 688747536a  c   + 9017490888a b c
+--R                                   + 
+--R                                                   8 4 8               7 6 7
+--R                                     - 39067874721a b c  + 66126243780a b c
+--R                                   + 
+--R                                                   6 8 6               5 10 5
+--R                                     - 57219314050a b c  + 28693007250a b  c
+--R                                   + 
+--R                                                  4 12 4              3 14 3
+--R                                     - 8861859375a b  c  + 1716818750a b  c
+--R                                   + 
+--R                                                 2 16 2              18
+--R                                     - 203859375a b  c  + 13593750a b  c
+--R                                   + 
+--R                                              20
+--R                                     - 390625b
+--R                                /
+--R                                                   27 9                 26 2 8
+--R                                     4398046511104a  c  - 9895604649984a  b c
+--R                                   + 
+--R                                                   25 4 7                 24 6 6
+--R                                     9895604649984a  b c  - 5772436045824a  b c
+--R                                   + 
+--R                                                   23 8 5                22 10 4
+--R                                     2164663517184a  b c  - 541165879296a  b  c
+--R                                   + 
+--R                                                 21 12 3              20 14 2
+--R                                     90194313216a  b  c  - 9663676416a  b  c
+--R                                   + 
+--R                                               19 16             18 18
+--R                                     603979776a  b  c - 16777216a  b
+--R                          + 
+--R                                     6   6           5 3 5           4 5 4
+--R                            - 758160a b c  + 1932840a b c  - 1634841a b c
+--R                          + 
+--R                                   3 7 3          2 9 2           11        13
+--R                            655590a b c  - 137475a b c  + 14625a b  c - 625b
+--R                       /
+--R                                    15 6            14 2 5           13 4 4
+--R                            8388608a  c  - 12582912a  b c  + 7864320a  b c
+--R                          + 
+--R                                      12 6 3          11 8 2         10 10
+--R                            - 2621440a  b c  + 491520a  b c  - 49152a  b  c
+--R                          + 
+--R                                 9 12
+--R                            2048a b
+--R           /
+--R                               8 15                 7 2 14
+--R                  892616806656a c   - 6380557173504a b c
+--R                + 
+--R                                6 4 13                 5 6 12
+--R                  9814482326880a b c   - 6767123000400a b c
+--R                + 
+--R                                4 8 11                3 10 10
+--R                  2566147280625a b c   - 575057656250a b  c
+--R                + 
+--R                              2 12 9                14 8             16 7
+--R                  76259259375a b  c  - 5553234375a b  c  + 171640625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                          +-----------+
+--R                       2  |          2                3 4+-+
+--R         ((- 18a c + 5b )\|- 4a c + b   + 28a b c - 5b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                          +-----------+
+--R                       2  |          2                3 4+-+
+--R         ((- 18a c + 5b )\|- 4a c + b   - 28a b c + 5b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                                           +------------------+
+--R                        +-----------+                      | +-----------+
+--R                     2  |          2                3 4+-+4| |          2
+--R         ((18a c - 5b )\|- 4a c + b   - 28a b c + 5b )\|c \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                     2  |          2                3 4+-+
+--R         ((18a c - 5b )\|- 4a c + b   + 28a b c - 5b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R  /
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R           3      2 2 4+-+3 |          2 4|   |          2
+--R       (16a c - 4a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 673
+
+--S 674 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 674
+
+)clear all
+
+--S 675 of 1057
+t0:=x^(15/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      7 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 1057
+r0:=1/4*x^(9/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+3/16*x^(5/2)*_
+   (8*a*b+(b^2+12*a*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))-_
+   3/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b^3-28*a*b*c+(b^4-30*a*b^2*c-24*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(5/4)*(b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(3/4))-3/32*atanh(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(b^3-28*a*b*c+(b^4-_
+   30*a*b^2*c-24*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(b^2-4*a*c)^2*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))-3/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b^3-28*a*b*c+(-b^4+30*a*b^2*c+24*a^2*c^2)/_
+   sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(b^2-4*a*c)^2*(-b+sqrt(b^2-_
+   4*a*c))^(3/4))-3/32*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(b^3-28*a*b*c+(-b^4+30*a*b^2*c+24*a^2*c^2)/sqrt(b^2-_
+   4*a*c))/(2^(1/4)*c^(5/4)*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))-_
+   3/16*(b^2+12*a*c)*sqrt(x)/(c*(b^2-4*a*c)^2)
+--R 
+--R
+--R   (2)
+--R                       3     3 2  8          2 2     4   6
+--R               (84a b c  - 3b c )x  + (168a b c  - 6b c)x
+--R             + 
+--R                    2   2        3      5  4        2 2        4  2      3
+--R               (168a b c  + 78a b c - 3b )x  + (168a b c - 6a b )x  + 84a b c
+--R             + 
+--R                   2 3
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 4        2 3     4 2  8        2   3         3 2     5   6
+--R           (72a c  + 90a b c  - 3b c )x  + (144a b c  + 180a b c  - 6b c)x
+--R         + 
+--R                3 3       2 2 2        4      6  4
+--R           (144a c  + 252a b c  + 84a b c - 3b )x
+--R         + 
+--R                3   2       2 3        5  2      4 2      3 2      2 4
+--R           (144a b c  + 180a b c - 6a b )x  + 72a c  + 90a b c - 3a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                       3     3 2  8          2 2     4   6
+--R               (84a b c  - 3b c )x  + (168a b c  - 6b c)x
+--R             + 
+--R                    2   2        3      5  4        2 2        4  2      3
+--R               (168a b c  + 78a b c - 3b )x  + (168a b c - 6a b )x  + 84a b c
+--R             + 
+--R                   2 3
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 4        2 3     4 2  8          2   3         3 2     5   6
+--R           (- 72a c  - 90a b c  + 3b c )x  + (- 144a b c  - 180a b c  + 6b c)x
+--R         + 
+--R                  3 3       2 2 2        4      6  4
+--R           (- 144a c  - 252a b c  - 84a b c + 3b )x
+--R         + 
+--R                  3   2       2 3        5  2      4 2      3 2      2 4
+--R           (- 144a b c  - 180a b c + 6a b )x  - 72a c  - 90a b c + 3a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                       3     3 2  8          2 2     4   6
+--R               (84a b c  - 3b c )x  + (168a b c  - 6b c)x
+--R             + 
+--R                    2   2        3      5  4        2 2        4  2      3
+--R               (168a b c  + 78a b c - 3b )x  + (168a b c - 6a b )x  + 84a b c
+--R             + 
+--R                   2 3
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 4        2 3     4 2  8        2   3         3 2     5   6
+--R           (72a c  + 90a b c  - 3b c )x  + (144a b c  + 180a b c  - 6b c)x
+--R         + 
+--R                3 3       2 2 2        4      6  4
+--R           (144a c  + 252a b c  + 84a b c - 3b )x
+--R         + 
+--R                3   2       2 3        5  2      4 2      3 2      2 4
+--R           (144a b c  + 180a b c - 6a b )x  + 72a c  + 90a b c - 3a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                       3     3 2  8          2 2     4   6
+--R               (84a b c  - 3b c )x  + (168a b c  - 6b c)x
+--R             + 
+--R                    2   2        3      5  4        2 2        4  2      3
+--R               (168a b c  + 78a b c - 3b )x  + (168a b c - 6a b )x  + 84a b c
+--R             + 
+--R                   2 3
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 4        2 3     4 2  8          2   3         3 2     5   6
+--R           (- 72a c  - 90a b c  + 3b c )x  + (- 144a b c  - 180a b c  + 6b c)x
+--R         + 
+--R                  3 3       2 2 2        4      6  4
+--R           (- 144a c  - 252a b c  - 84a b c + 3b )x
+--R         + 
+--R                  3   2       2 3        5  2      4 2      3 2      2 4
+--R           (- 144a b c  - 180a b c + 6a b )x  - 72a c  - 90a b c + 3a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                     2     3   6          2 2        2      4  4
+--R           (- 56a b c  + 2b c)x  + (- 136a c  - 14a b c - 6b )x
+--R         + 
+--R                 2           3  2      3      2 2
+--R           (- 96a b c - 12a b )x  - 72a c - 6a b
+--R      *
+--R                                  +--------------------+3  +------------------+3
+--R            +-----------+         |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+ +-+4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|c \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              2 5         2 4      4 3  8         2   4         3 3      5 2  6
+--R         (512a c  - 256a b c  + 32b c )x  + (1024a b c  - 512a b c  + 64b c )x
+--R       + 
+--R               3 4         4 2      6   4         3   3       2 3 2        5   2
+--R         (1024a c  - 192a b c  + 32b c)x  + (1024a b c  - 512a b c  + 64a b c)x
+--R       + 
+--R             4 3       3 2 2      2 4
+--R         512a c  - 256a b c  + 32a b c
+--R    *
+--R                              +--------------------+3  +------------------+3
+--R            +-----------+     |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 5        2 4     4 3  8        2   4         3 3      5 2  6
+--R           (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R         + 
+--R                3 4        4 2     6   4        3   3       2 3 2        5   2
+--R           (256a c  - 48a b c  + 8b c)x  + (256a b c  - 128a b c  + 16a b c)x
+--R         + 
+--R               4 3      3 2 2     2 4
+--R           128a c  - 64a b c  + 8a b c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 15                  9 2 14
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 13                  7 6 12
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 11                 5 10 10
+--R                         14431090114560a b c   - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 9                3 14 8
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                        11   16                     10 3 15
+--R                      19140298416324608a  b c   - 48132221017522176a  b c
+--R                    + 
+--R                                        9 5 14                     8 7 13
+--R                      54535776737689600a b c   - 36679707902607360a b c
+--R                    + 
+--R                                        7 9 12                    6 11 11
+--R                      16228791625973760a b c   - 4941205255225344a b  c
+--R                    + 
+--R                                       5 13 10                   4 15 9
+--R                      1050583360339968a b  c   - 154618822656000a b  c
+--R                    + 
+--R                                     3 17 8                2 19 7
+--R                      15204184227840a b  c  - 923417968640a b  c
+--R                    + 
+--R                                    21 6             23 5
+--R                      28991029248a b  c  - 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                             8 8               7 2 7               6 4 6
+--R                  1289945088a c  - 55252647936a b c  + 40413302784a b c
+--R                + 
+--R                               5 6 5             4 8 4            3 10 3
+--R                  - 9565765632a b c  + 569099520a b c  + 56847744a b  c
+--R                + 
+--R                            2 12 2            14         16
+--R                  - 5071248a b  c  + 138672a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 15                  9 2 14
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 13                  7 6 12
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 11                 5 10 10
+--R                                14431090114560a b c   - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 9                3 14 8
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 7               18 6
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 5
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 5        2 4     4 3  8
+--R           (- 128a c  + 64a b c  - 8b c )x
+--R         + 
+--R                  2   4         3 3      5 2  6
+--R           (- 256a b c  + 128a b c  - 16b c )x
+--R         + 
+--R                  3 4        4 2     6   4
+--R           (- 256a c  + 48a b c  - 8b c)x
+--R         + 
+--R                  3   3       2 3 2        5   2       4 3      3 2 2     2 4
+--R           (- 256a b c  + 128a b c  - 16a b c)x  - 128a c  + 64a b c  - 8a b c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 15                  9 2 14
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 13                  7 6 12
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 11                 5 10 10
+--R                         - 14431090114560a b c   + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 9                3 14 8
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                        11   16                     10 3 15
+--R                      19140298416324608a  b c   - 48132221017522176a  b c
+--R                    + 
+--R                                        9 5 14                     8 7 13
+--R                      54535776737689600a b c   - 36679707902607360a b c
+--R                    + 
+--R                                        7 9 12                    6 11 11
+--R                      16228791625973760a b c   - 4941205255225344a b  c
+--R                    + 
+--R                                       5 13 10                   4 15 9
+--R                      1050583360339968a b  c   - 154618822656000a b  c
+--R                    + 
+--R                                     3 17 8                2 19 7
+--R                      15204184227840a b  c  - 923417968640a b  c
+--R                    + 
+--R                                    21 6             23 5
+--R                      28991029248a b  c  - 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                               8 8               7 2 7               6 4 6
+--R                  - 1289945088a c  + 55252647936a b c  - 40413302784a b c
+--R                + 
+--R                             5 6 5             4 8 4            3 10 3
+--R                  9565765632a b c  - 569099520a b c  - 56847744a b  c
+--R                + 
+--R                          2 12 2            14         16
+--R                  5071248a b  c  - 138672a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 15                  9 2 14
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 13                  7 6 12
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 11                 5 10 10
+--R                                - 14431090114560a b c   + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 9                3 14 8
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 7               18 6
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 5
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 5        2 4     4 3  8        2   4         3 3      5 2  6
+--R           (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R         + 
+--R                3 4        4 2     6   4        3   3       2 3 2        5   2
+--R           (256a c  - 48a b c  + 8b c)x  + (256a b c  - 128a b c  + 16a b c)x
+--R         + 
+--R               4 3      3 2 2     2 4
+--R           128a c  - 64a b c  + 8a b c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 15                  9 2 14
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 13                  7 6 12
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 11                 5 10 10
+--R                         - 14431090114560a b c   + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 9                3 14 8
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                          11   16                     10 3 15
+--R                      - 19140298416324608a  b c   + 48132221017522176a  b c
+--R                    + 
+--R                                          9 5 14                     8 7 13
+--R                      - 54535776737689600a b c   + 36679707902607360a b c
+--R                    + 
+--R                                          7 9 12                    6 11 11
+--R                      - 16228791625973760a b c   + 4941205255225344a b  c
+--R                    + 
+--R                                         5 13 10                   4 15 9
+--R                      - 1050583360339968a b  c   + 154618822656000a b  c
+--R                    + 
+--R                                       3 17 8                2 19 7
+--R                      - 15204184227840a b  c  + 923417968640a b  c
+--R                    + 
+--R                                      21 6             23 5
+--R                      - 28991029248a b  c  + 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                             8 8               7 2 7               6 4 6
+--R                  1289945088a c  - 55252647936a b c  + 40413302784a b c
+--R                + 
+--R                               5 6 5             4 8 4            3 10 3
+--R                  - 9565765632a b c  + 569099520a b c  + 56847744a b  c
+--R                + 
+--R                            2 12 2            14         16
+--R                  - 5071248a b  c  + 138672a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 15                  9 2 14
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 13                  7 6 12
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 11                 5 10 10
+--R                                - 14431090114560a b c   + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 9                3 14 8
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 7               18 6
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 5
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 5        2 4     4 3  8
+--R           (- 128a c  + 64a b c  - 8b c )x
+--R         + 
+--R                  2   4         3 3      5 2  6
+--R           (- 256a b c  + 128a b c  - 16b c )x
+--R         + 
+--R                  3 4        4 2     6   4
+--R           (- 256a c  + 48a b c  - 8b c)x
+--R         + 
+--R                  3   3       2 3 2        5   2       4 3      3 2 2     2 4
+--R           (- 256a b c  + 128a b c  - 16a b c)x  - 128a c  + 64a b c  - 8a b c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 15                  9 2 14
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 13                  7 6 12
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 11                 5 10 10
+--R                         14431090114560a b c   - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 9                3 14 8
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                          11   16                     10 3 15
+--R                      - 19140298416324608a  b c   + 48132221017522176a  b c
+--R                    + 
+--R                                          9 5 14                     8 7 13
+--R                      - 54535776737689600a b c   + 36679707902607360a b c
+--R                    + 
+--R                                          7 9 12                    6 11 11
+--R                      - 16228791625973760a b c   + 4941205255225344a b  c
+--R                    + 
+--R                                         5 13 10                   4 15 9
+--R                      - 1050583360339968a b  c   + 154618822656000a b  c
+--R                    + 
+--R                                       3 17 8                2 19 7
+--R                      - 15204184227840a b  c  + 923417968640a b  c
+--R                    + 
+--R                                      21 6             23 5
+--R                      - 28991029248a b  c  + 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                               8 8               7 2 7               6 4 6
+--R                  - 1289945088a c  + 55252647936a b c  - 40413302784a b c
+--R                + 
+--R                             5 6 5             4 8 4            3 10 3
+--R                  9565765632a b c  - 569099520a b c  - 56847744a b  c
+--R                + 
+--R                          2 12 2            14         16
+--R                  5071248a b  c  - 138672a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 15                  9 2 14
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 13                  7 6 12
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 11                 5 10 10
+--R                                14431090114560a b c   - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 9                3 14 8
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 7               18 6
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 5
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 5         2 4      4 3  8
+--R           (- 256a c  + 128a b c  - 16b c )x
+--R         + 
+--R                  2   4         3 3      5 2  6
+--R           (- 512a b c  + 256a b c  - 32b c )x
+--R         + 
+--R                  3 4        4 2      6   4
+--R           (- 512a c  + 96a b c  - 16b c)x
+--R         + 
+--R                3   3       2 3 2        5   2       4 3       3 2 2      2 4
+--R         (- 512a b c  + 256a b c  - 32a b c)x  - 256a c  + 128a b c  - 16a b c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 15                  9 2 14
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 13                  7 6 12
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 11                 5 10 10
+--R                         14431090114560a b c   - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 9                3 14 8
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                        11   16                     10 3 15
+--R                      19140298416324608a  b c   - 48132221017522176a  b c
+--R                    + 
+--R                                        9 5 14                     8 7 13
+--R                      54535776737689600a b c   - 36679707902607360a b c
+--R                    + 
+--R                                        7 9 12                    6 11 11
+--R                      16228791625973760a b c   - 4941205255225344a b  c
+--R                    + 
+--R                                       5 13 10                   4 15 9
+--R                      1050583360339968a b  c   - 154618822656000a b  c
+--R                    + 
+--R                                     3 17 8                2 19 7
+--R                      15204184227840a b  c  - 923417968640a b  c
+--R                    + 
+--R                                    21 6             23 5
+--R                      28991029248a b  c  - 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                             8 8               7 2 7               6 4 6
+--R                  1289945088a c  - 55252647936a b c  + 40413302784a b c
+--R                + 
+--R                               5 6 5             4 8 4            3 10 3
+--R                  - 9565765632a b c  + 569099520a b c  + 56847744a b  c
+--R                + 
+--R                            2 12 2            14         16
+--R                  - 5071248a b  c  + 138672a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 15                  9 2 14
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 13                  7 6 12
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 11                 5 10 10
+--R                                14431090114560a b c   - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 9                3 14 8
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 7               18 6
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 5
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 5         2 4      4 3  8        2   4         3 3      5 2  6
+--R           (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c )x
+--R         + 
+--R                3 4        4 2      6   4        3   3       2 3 2        5   2
+--R           (512a c  - 96a b c  + 16b c)x  + (512a b c  - 256a b c  + 32a b c)x
+--R         + 
+--R               4 3       3 2 2      2 4
+--R           256a c  - 128a b c  + 16a b c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 15                  9 2 14
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 13                  7 6 12
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 11                 5 10 10
+--R                         - 14431090114560a b c   + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 9                3 14 8
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                        11   16                     10 3 15
+--R                      19140298416324608a  b c   - 48132221017522176a  b c
+--R                    + 
+--R                                        9 5 14                     8 7 13
+--R                      54535776737689600a b c   - 36679707902607360a b c
+--R                    + 
+--R                                        7 9 12                    6 11 11
+--R                      16228791625973760a b c   - 4941205255225344a b  c
+--R                    + 
+--R                                       5 13 10                   4 15 9
+--R                      1050583360339968a b  c   - 154618822656000a b  c
+--R                    + 
+--R                                     3 17 8                2 19 7
+--R                      15204184227840a b  c  - 923417968640a b  c
+--R                    + 
+--R                                    21 6             23 5
+--R                      28991029248a b  c  - 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                               8 8               7 2 7               6 4 6
+--R                  - 1289945088a c  + 55252647936a b c  - 40413302784a b c
+--R                + 
+--R                             5 6 5             4 8 4            3 10 3
+--R                  9565765632a b c  - 569099520a b c  - 56847744a b  c
+--R                + 
+--R                          2 12 2            14         16
+--R                  5071248a b  c  - 138672a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 15                  9 2 14
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 13                  7 6 12
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 11                 5 10 10
+--R                                - 14431090114560a b c   + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 9                3 14 8
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 7               18 6
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 5
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                     2    3   6         2 2       2      4  4
+--R           (- 28a b c  + b c)x  + (- 68a c  - 7a b c - 3b )x
+--R         + 
+--R                 2          3  2      3      2 2
+--R           (- 48a b c - 6a b )x  - 36a c - 3a b
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R            2 5         2 4      4 3  8        2   4         3 3      5 2  6
+--R       (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c )x
+--R     + 
+--R            3 4        4 2      6   4        3   3       2 3 2        5   2
+--R       (512a c  - 96a b c  + 16b c)x  + (512a b c  - 256a b c  + 32a b c)x
+--R     + 
+--R           4 3       3 2 2      2 4
+--R       256a c  - 128a b c  + 16a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 677
+
+--S 678 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +-----------+
+--R              2 3         2 2      4  4+-+ |          2 4+-+
+--R         (256a c  - 128a b c  + 16b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 15                  9 2 14
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 13                  7 6 12
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 11                 5 10 10
+--R                         14431090114560a b c   - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 9                3 14 8
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                        11   16                     10 3 15
+--R                      19140298416324608a  b c   - 48132221017522176a  b c
+--R                    + 
+--R                                        9 5 14                     8 7 13
+--R                      54535776737689600a b c   - 36679707902607360a b c
+--R                    + 
+--R                                        7 9 12                    6 11 11
+--R                      16228791625973760a b c   - 4941205255225344a b  c
+--R                    + 
+--R                                       5 13 10                   4 15 9
+--R                      1050583360339968a b  c   - 154618822656000a b  c
+--R                    + 
+--R                                     3 17 8                2 19 7
+--R                      15204184227840a b  c  - 923417968640a b  c
+--R                    + 
+--R                                    21 6             23 5
+--R                      28991029248a b  c  - 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                             8 8               7 2 7               6 4 6
+--R                  1289945088a c  - 55252647936a b c  + 40413302784a b c
+--R                + 
+--R                               5 6 5             4 8 4            3 10 3
+--R                  - 9565765632a b c  + 569099520a b c  + 56847744a b  c
+--R                + 
+--R                            2 12 2            14         16
+--R                  - 5071248a b  c  + 138672a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 15                  9 2 14
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 13                  7 6 12
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 11                 5 10 10
+--R                                14431090114560a b c   - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 9                3 14 8
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 7               18 6
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 5
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +-----------+
+--R                2 3         2 2      4  4+-+ |          2 4+-+
+--R         (- 256a c  + 128a b c  - 16b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 15                  9 2 14
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 13                  7 6 12
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 11                 5 10 10
+--R                         - 14431090114560a b c   + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 9                3 14 8
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                        11   16                     10 3 15
+--R                      19140298416324608a  b c   - 48132221017522176a  b c
+--R                    + 
+--R                                        9 5 14                     8 7 13
+--R                      54535776737689600a b c   - 36679707902607360a b c
+--R                    + 
+--R                                        7 9 12                    6 11 11
+--R                      16228791625973760a b c   - 4941205255225344a b  c
+--R                    + 
+--R                                       5 13 10                   4 15 9
+--R                      1050583360339968a b  c   - 154618822656000a b  c
+--R                    + 
+--R                                     3 17 8                2 19 7
+--R                      15204184227840a b  c  - 923417968640a b  c
+--R                    + 
+--R                                    21 6             23 5
+--R                      28991029248a b  c  - 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                               8 8               7 2 7               6 4 6
+--R                  - 1289945088a c  + 55252647936a b c  - 40413302784a b c
+--R                + 
+--R                             5 6 5             4 8 4            3 10 3
+--R                  9565765632a b c  - 569099520a b c  - 56847744a b  c
+--R                + 
+--R                          2 12 2            14         16
+--R                  5071248a b  c  - 138672a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 15                  9 2 14
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 13                  7 6 12
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 11                 5 10 10
+--R                                - 14431090114560a b c   + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 9                3 14 8
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 7               18 6
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 5
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                           +-----------+
+--R              2 3         2 2      4  4+-+ |          2 4+-+
+--R         (256a c  - 128a b c  + 16b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 15                  9 2 14
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 13                  7 6 12
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 11                 5 10 10
+--R                         - 14431090114560a b c   + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 9                3 14 8
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                          11   16                     10 3 15
+--R                      - 19140298416324608a  b c   + 48132221017522176a  b c
+--R                    + 
+--R                                          9 5 14                     8 7 13
+--R                      - 54535776737689600a b c   + 36679707902607360a b c
+--R                    + 
+--R                                          7 9 12                    6 11 11
+--R                      - 16228791625973760a b c   + 4941205255225344a b  c
+--R                    + 
+--R                                         5 13 10                   4 15 9
+--R                      - 1050583360339968a b  c   + 154618822656000a b  c
+--R                    + 
+--R                                       3 17 8                2 19 7
+--R                      - 15204184227840a b  c  + 923417968640a b  c
+--R                    + 
+--R                                      21 6             23 5
+--R                      - 28991029248a b  c  + 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                             8 8               7 2 7               6 4 6
+--R                  1289945088a c  - 55252647936a b c  + 40413302784a b c
+--R                + 
+--R                               5 6 5             4 8 4            3 10 3
+--R                  - 9565765632a b c  + 569099520a b c  + 56847744a b  c
+--R                + 
+--R                            2 12 2            14         16
+--R                  - 5071248a b  c  + 138672a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 15                  9 2 14
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 13                  7 6 12
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 11                 5 10 10
+--R                                - 14431090114560a b c   + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 9                3 14 8
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 7               18 6
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 5
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +-----------+
+--R                2 3         2 2      4  4+-+ |          2 4+-+
+--R         (- 256a c  + 128a b c  - 16b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 15                  9 2 14
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 13                  7 6 12
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 11                 5 10 10
+--R                         14431090114560a b c   - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 9                3 14 8
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                          11   16                     10 3 15
+--R                      - 19140298416324608a  b c   + 48132221017522176a  b c
+--R                    + 
+--R                                          9 5 14                     8 7 13
+--R                      - 54535776737689600a b c   + 36679707902607360a b c
+--R                    + 
+--R                                          7 9 12                    6 11 11
+--R                      - 16228791625973760a b c   + 4941205255225344a b  c
+--R                    + 
+--R                                         5 13 10                   4 15 9
+--R                      - 1050583360339968a b  c   + 154618822656000a b  c
+--R                    + 
+--R                                       3 17 8                2 19 7
+--R                      - 15204184227840a b  c  + 923417968640a b  c
+--R                    + 
+--R                                      21 6             23 5
+--R                      - 28991029248a b  c  + 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                               8 8               7 2 7               6 4 6
+--R                  - 1289945088a c  + 55252647936a b c  - 40413302784a b c
+--R                + 
+--R                             5 6 5             4 8 4            3 10 3
+--R                  9565765632a b c  - 569099520a b c  - 56847744a b  c
+--R                + 
+--R                          2 12 2            14         16
+--R                  5071248a b  c  - 138672a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 15                  9 2 14
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 13                  7 6 12
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 11                 5 10 10
+--R                                14431090114560a b c   - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 9                3 14 8
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 7               18 6
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 5
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +-----------+
+--R                2 3         2 2      4  4+-+ |          2 4+-+
+--R         (- 512a c  + 256a b c  - 32b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 15                  9 2 14
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 13                  7 6 12
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 11                 5 10 10
+--R                         14431090114560a b c   - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 9                3 14 8
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                        11   16                     10 3 15
+--R                      19140298416324608a  b c   - 48132221017522176a  b c
+--R                    + 
+--R                                        9 5 14                     8 7 13
+--R                      54535776737689600a b c   - 36679707902607360a b c
+--R                    + 
+--R                                        7 9 12                    6 11 11
+--R                      16228791625973760a b c   - 4941205255225344a b  c
+--R                    + 
+--R                                       5 13 10                   4 15 9
+--R                      1050583360339968a b  c   - 154618822656000a b  c
+--R                    + 
+--R                                     3 17 8                2 19 7
+--R                      15204184227840a b  c  - 923417968640a b  c
+--R                    + 
+--R                                    21 6             23 5
+--R                      28991029248a b  c  - 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                             8 8               7 2 7               6 4 6
+--R                  1289945088a c  - 55252647936a b c  + 40413302784a b c
+--R                + 
+--R                               5 6 5             4 8 4            3 10 3
+--R                  - 9565765632a b c  + 569099520a b c  + 56847744a b  c
+--R                + 
+--R                            2 12 2            14         16
+--R                  - 5071248a b  c  + 138672a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 15                  9 2 14
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 13                  7 6 12
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 11                 5 10 10
+--R                                14431090114560a b c   - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 9                3 14 8
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 7               18 6
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 5
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                           +-----------+
+--R              2 3         2 2      4  4+-+ |          2 4+-+
+--R         (512a c  - 256a b c  + 32b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 15                  9 2 14
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 13                  7 6 12
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 11                 5 10 10
+--R                         - 14431090114560a b c   + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 9                3 14 8
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 7               18 6            20 5
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       15 25
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 24
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 23
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 22
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 21
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 20
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 19
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 18
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 17
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 16
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 15
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 14
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 13
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 12
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 11                   30 10
+--R                              16888498602639360a b  c   - 281474976710656b  c
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   10 15                  9 2 14
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 13                  7 6 12
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 11                 5 10 10
+--R                     7215545057280a b c   - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 9               3 14 8
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 7               18 6           20 5
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                        11   16                     10 3 15
+--R                      19140298416324608a  b c   - 48132221017522176a  b c
+--R                    + 
+--R                                        9 5 14                     8 7 13
+--R                      54535776737689600a b c   - 36679707902607360a b c
+--R                    + 
+--R                                        7 9 12                    6 11 11
+--R                      16228791625973760a b c   - 4941205255225344a b  c
+--R                    + 
+--R                                       5 13 10                   4 15 9
+--R                      1050583360339968a b  c   - 154618822656000a b  c
+--R                    + 
+--R                                     3 17 8                2 19 7
+--R                      15204184227840a b  c  - 923417968640a b  c
+--R                    + 
+--R                                    21 6             23 5
+--R                      28991029248a b  c  - 268435456b  c
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    15 25
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 24
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 23
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 22
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 21
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 20
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 19
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 18
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 17
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 16
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 15
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 14
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 13
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 12
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 11                   30 10
+--R                           16888498602639360a b  c   - 281474976710656b  c
+--R                + 
+--R                               8 8               7 2 7               6 4 6
+--R                  - 1289945088a c  + 55252647936a b c  - 40413302784a b c
+--R                + 
+--R                             5 6 5             4 8 4            3 10 3
+--R                  9565765632a b c  - 569099520a b c  - 56847744a b  c
+--R                + 
+--R                          2 12 2            14         16
+--R                  5071248a b  c  - 138672a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 15                  9 2 14
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 13                  7 6 12
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 11                 5 10 10
+--R                                - 14431090114560a b c   + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 9                3 14 8
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 7               18 6
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 5
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              15 25
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 24
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 23
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 22
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 21
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 20
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 19
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 18
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 17
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 16
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 15
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 14
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 13
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 12
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 11
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 10
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          10 15                  9 2 14
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 13                  7 6 12
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 11                 5 10 10
+--R                            7215545057280a b c   - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 9               3 14 8
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 7               18 6           20 5
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                           7 6              6 2 5               5 4 4
+--R                  45349632a c  - 1551965184a b c  - 15063706080a b c
+--R                + 
+--R                             4 6 3            3 8 2           2 10           12
+--R                  1628624880a b c  - 67703445a b c  + 1292031a b  c - 9477a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4
+--R         ((- 84a b c + 3b )\|- 4a c + b   - 72a c  - 90a b c + 3b )
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4
+--R         ((- 84a b c + 3b )\|- 4a c + b   + 72a c  + 90a b c - 3b )
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4
+--R         ((- 84a b c + 3b )\|- 4a c + b   - 72a c  - 90a b c + 3b )
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4
+--R         ((- 84a b c + 3b )\|- 4a c + b   + 72a c  + 90a b c - 3b )
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R  /
+--R                                         +-----------+
+--R            2 3         2 2      4  4+-+ |          2 4+-+
+--R       (512a c  - 256a b c  + 32b c)\|2 \|- 4a c + b  \|c
+--R    *
+--R        +--------------------+3  +------------------+3
+--R        |   +-----------+        | +-----------+
+--R       4|   |          2        4| |          2
+--R       \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 678
+
+--S 679 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 679
+
+)clear all
+
+--S 680 of 1057
+t0:=x^(13/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      6 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 1057
+r0:=1/4*x^(7/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+1/16*x^(3/2)*_
+   (24*a*b+(5*b^2+28*a*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+_
+   1/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(5*b^2+_
+   28*a*c+b*(5*b^2+172*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*(b^2-_
+   4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(1/4))-1/32*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(5*b^2+28*a*c+b*(5*b^2+172*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*(b^2-4*a*c)^2*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+1/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(5*b^2+28*a*c-b*(5*b^2+172*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*c^(3/4)*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(1/4))-_
+   1/32*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (5*b^2+28*a*c-b*(5*b^2+172*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*_
+   (b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                       3     2 2  8             2      3   6
+--R               (- 28a c  - 5b c )x  + (- 56a b c  - 10b c)x
+--R             + 
+--R                     2 2        2      4  4         2           3  2      3
+--R               (- 56a c  - 38a b c - 5b )x  + (- 56a b c - 10a b )x  - 28a c
+--R             + 
+--R                   2 2
+--R               - 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2      4   6
+--R           (- 172a b c  - 5b c )x  + (- 344a b c  - 10b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2         4  2       3
+--R           (- 344a b c  - 182a b c - 5b )x  + (- 344a b c - 10a b )x  - 172a b c
+--R         + 
+--R               2 3
+--R           - 5a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                       3     2 2  8             2      3   6
+--R               (- 28a c  - 5b c )x  + (- 56a b c  - 10b c)x
+--R             + 
+--R                     2 2        2      4  4         2           3  2      3
+--R               (- 56a c  - 38a b c - 5b )x  + (- 56a b c - 10a b )x  - 28a c
+--R             + 
+--R                   2 2
+--R               - 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2      4   6
+--R           (172a b c  + 5b c )x  + (344a b c  + 10b c)x
+--R         + 
+--R                2   2         3      5  4        2 2         4  2       3
+--R           (344a b c  + 182a b c + 5b )x  + (344a b c + 10a b )x  + 172a b c
+--R         + 
+--R             2 3
+--R           5a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                     3     2 2  8           2      3   6
+--R               (28a c  + 5b c )x  + (56a b c  + 10b c)x
+--R             + 
+--R                 2 2        2      4  4       2           3  2      3      2 2
+--R             (56a c  + 38a b c + 5b )x  + (56a b c + 10a b )x  + 28a c + 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2      4   6
+--R           (172a b c  + 5b c )x  + (344a b c  + 10b c)x
+--R         + 
+--R                2   2         3      5  4        2 2         4  2       3
+--R           (344a b c  + 182a b c + 5b )x  + (344a b c + 10a b )x  + 172a b c
+--R         + 
+--R             2 3
+--R           5a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                     3     2 2  8           2      3   6
+--R               (28a c  + 5b c )x  + (56a b c  + 10b c)x
+--R             + 
+--R                 2 2        2      4  4       2           3  2      3      2 2
+--R             (56a c  + 38a b c + 5b )x  + (56a b c + 10a b )x  + 28a c + 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2      4   6
+--R           (- 172a b c  - 5b c )x  + (- 344a b c  - 10b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2         4  2       3
+--R           (- 344a b c  - 182a b c - 5b )x  + (- 344a b c - 10a b )x  - 172a b c
+--R         + 
+--R               2 3
+--R           - 5a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                   2      2   7                 3  5        2         2  3
+--R             (56a c  + 10b c)x  + (72a b c + 18b )x  + (- 8a c + 74a b )x
+--R           + 
+--R                2
+--R             48a b x
+--R      *
+--R                                    +--------------------+ +------------------+
+--R             +-----------+          |   +-----------+      | +-----------+
+--R       4+-+3 |          2 4+-+3 +-+4|   |          2      4| |          2
+--R       \|2  \|- 4a c + b  \|c  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R              2 4         2 3      4 2  8         2   3         3 2      5   6
+--R         (512a c  - 256a b c  + 32b c )x  + (1024a b c  - 512a b c  + 64b c)x
+--R       + 
+--R               3 3         4       6  4         3   2       2 3         5  2
+--R         (1024a c  - 192a b c + 32b )x  + (1024a b c  - 512a b c + 64a b )x
+--R       + 
+--R             4 2       3 2       2 4
+--R         512a c  - 256a b c + 32a b
+--R    *
+--R                                 +--------------------+ +------------------+
+--R             +-----------+       |   +-----------+      | +-----------+
+--R       4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R       \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 4        2 3     4 2  8        2   3         3 2      5   6
+--R           (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R         + 
+--R                3 3        4      6  4        3   2       2 3         5  2
+--R           (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R         + 
+--R               4 2      3 2      2 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 13                  9 2 12
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 11                  7 6 10
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 9                 5 10 8
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 7                3 14 6
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                                 19 22
+--R                      25916347257988612932763648a  c
+--R                    + 
+--R                                                    18 2 21
+--R                      - 710319476887320554463297536a  b c
+--R                    + 
+--R                                                   17 4 20
+--R                      2117032171903979079654703104a  b c
+--R                    + 
+--R                                                     16 6 19
+--R                      - 2891115402226247018615930880a  b c
+--R                    + 
+--R                                                   15 8 18
+--R                      2201230785701924136403599360a  b c
+--R                    + 
+--R                                                    14 10 17
+--R                      - 868471530398624972669976576a  b  c
+--R                    + 
+--R                                                   13 12 16
+--R                      - 18744622097011813455495168a  b  c
+--R                    + 
+--R                                                  12 14 15
+--R                      251465683171415280857382912a  b  c
+--R                    + 
+--R                                                    11 16 14
+--R                      - 174958732157065591793909760a  b  c
+--R                    + 
+--R                                                 10 18 13
+--R                      72655579834722369321041920a  b  c
+--R                    + 
+--R                                                   9 20 12
+--R                      - 21220564118596252017360896a b  c
+--R                    + 
+--R                                                8 22 11
+--R                      4570564695064981454979072a b  c
+--R                    + 
+--R                                                 7 24 10
+--R                      - 734221072631076055154688a b  c
+--R                    + 
+--R                                              6 26 9
+--R                      87134384582468692869120a b  c
+--R                    + 
+--R                                               5 28 8
+--R                      - 7412007378227759677440a b  c
+--R                    + 
+--R                                            4 30 7                        3 32 6
+--R                      424869025896179171328a b  c  - 14419980649072951296a b  c
+--R                    + 
+--R                                         2 34 5                     36 4
+--R                      204403609650069504a b  c  - 137438953472000a b  c
+--R                    + 
+--R                                     38 3
+--R                      68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                         14   14                         13 3 13
+--R                  - 15781486106538672128a  b c   + 841443865487264972800a  b c
+--R                + 
+--R                                           12 5 12
+--R                  - 2860949643992143757312a  b c
+--R                + 
+--R                                         11 7 11
+--R                  3854117596814391640064a  b c
+--R                + 
+--R                                           10 9 10
+--R                  - 2827477675767953883136a  b c
+--R                + 
+--R                                         9 11 9                         8 13 8
+--R                  1275028264002164621312a b  c  - 370951843406822768640a b  c
+--R                + 
+--R                                       7 15 7                       6 17 6
+--R                  69964837141849571328a b  c  - 8218108953284837376a b  c
+--R                + 
+--R                                     5 19 5                     4 21 4
+--R                  529478543583739904a b  c  - 11075494346752000a b  c
+--R                + 
+--R                                    3 23 3                 2 25 2
+--R                  - 384332333056000a b  c  + 4130652160000a b  c
+--R                + 
+--R                                 27               29
+--R                  294400000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                          10 13                  9 2 12
+--R                           17592186044416a  c   - 43980465111040a b c
+--R                         + 
+--R                                          8 4 11                  7 6 10
+--R                           49478023249920a b c   - 32985348833280a b c
+--R                         + 
+--R                                          6 8 9                 5 10 8
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        4 12 7                3 14 6
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 13                  9 2 12
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 11                  7 6 10
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 9                 5 10 8
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 7                3 14 6
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 5               18 4
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 3
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4        2 3     4 2  8
+--R           (- 128a c  + 64a b c  - 8b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4      6  4
+--R           (- 256a b c  + 128a b c  - 16b c)x  + (- 256a c  + 48a b c - 8b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 256a b c  + 128a b c - 16a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 13                  9 2 12
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 11                  7 6 10
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 9                 5 10 8
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 7                3 14 6
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                                 19 22
+--R                      25916347257988612932763648a  c
+--R                    + 
+--R                                                    18 2 21
+--R                      - 710319476887320554463297536a  b c
+--R                    + 
+--R                                                   17 4 20
+--R                      2117032171903979079654703104a  b c
+--R                    + 
+--R                                                     16 6 19
+--R                      - 2891115402226247018615930880a  b c
+--R                    + 
+--R                                                   15 8 18
+--R                      2201230785701924136403599360a  b c
+--R                    + 
+--R                                                    14 10 17
+--R                      - 868471530398624972669976576a  b  c
+--R                    + 
+--R                                                   13 12 16
+--R                      - 18744622097011813455495168a  b  c
+--R                    + 
+--R                                                  12 14 15
+--R                      251465683171415280857382912a  b  c
+--R                    + 
+--R                                                    11 16 14
+--R                      - 174958732157065591793909760a  b  c
+--R                    + 
+--R                                                 10 18 13
+--R                      72655579834722369321041920a  b  c
+--R                    + 
+--R                                                   9 20 12
+--R                      - 21220564118596252017360896a b  c
+--R                    + 
+--R                                                8 22 11
+--R                      4570564695064981454979072a b  c
+--R                    + 
+--R                                                 7 24 10
+--R                      - 734221072631076055154688a b  c
+--R                    + 
+--R                                              6 26 9
+--R                      87134384582468692869120a b  c
+--R                    + 
+--R                                               5 28 8
+--R                      - 7412007378227759677440a b  c
+--R                    + 
+--R                                            4 30 7                        3 32 6
+--R                      424869025896179171328a b  c  - 14419980649072951296a b  c
+--R                    + 
+--R                                         2 34 5                     36 4
+--R                      204403609650069504a b  c  - 137438953472000a b  c
+--R                    + 
+--R                                     38 3
+--R                      68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                       14   14                         13 3 13
+--R                  15781486106538672128a  b c   - 841443865487264972800a  b c
+--R                + 
+--R                                         12 5 12
+--R                  2860949643992143757312a  b c
+--R                + 
+--R                                           11 7 11
+--R                  - 3854117596814391640064a  b c
+--R                + 
+--R                                         10 9 10                          9 11 9
+--R                  2827477675767953883136a  b c   - 1275028264002164621312a b  c
+--R                + 
+--R                                        8 13 8                        7 15 7
+--R                  370951843406822768640a b  c  - 69964837141849571328a b  c
+--R                + 
+--R                                      6 17 6                      5 19 5
+--R                  8218108953284837376a b  c  - 529478543583739904a b  c
+--R                + 
+--R                                    4 21 4                   3 23 3
+--R                  11075494346752000a b  c  + 384332333056000a b  c
+--R                + 
+--R                                  2 25 2                  27               29
+--R                  - 4130652160000a b  c  - 294400000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                            10 13                  9 2 12
+--R                           - 17592186044416a  c   + 43980465111040a b c
+--R                         + 
+--R                                            8 4 11                  7 6 10
+--R                           - 49478023249920a b c   + 32985348833280a b c
+--R                         + 
+--R                                            6 8 9                 5 10 8
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          4 12 7                3 14 6
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       2 16 5               18 4            20 3
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 13                  9 2 12
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 11                  7 6 10
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 9                 5 10 8
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 7                3 14 6
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 5               18 4
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 3
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 4        2 3     4 2  8        2   3         3 2      5   6
+--R           (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R         + 
+--R                3 3        4      6  4        3   2       2 3         5  2
+--R           (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R         + 
+--R               4 2      3 2      2 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 13                  9 2 12
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 11                  7 6 10
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 9                 5 10 8
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 7                3 14 6
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                                   19 22
+--R                      - 25916347257988612932763648a  c
+--R                    + 
+--R                                                  18 2 21
+--R                      710319476887320554463297536a  b c
+--R                    + 
+--R                                                     17 4 20
+--R                      - 2117032171903979079654703104a  b c
+--R                    + 
+--R                                                   16 6 19
+--R                      2891115402226247018615930880a  b c
+--R                    + 
+--R                                                     15 8 18
+--R                      - 2201230785701924136403599360a  b c
+--R                    + 
+--R                                                  14 10 17
+--R                      868471530398624972669976576a  b  c
+--R                    + 
+--R                                                 13 12 16
+--R                      18744622097011813455495168a  b  c
+--R                    + 
+--R                                                    12 14 15
+--R                      - 251465683171415280857382912a  b  c
+--R                    + 
+--R                                                  11 16 14
+--R                      174958732157065591793909760a  b  c
+--R                    + 
+--R                                                   10 18 13
+--R                      - 72655579834722369321041920a  b  c
+--R                    + 
+--R                                                 9 20 12
+--R                      21220564118596252017360896a b  c
+--R                    + 
+--R                                                  8 22 11
+--R                      - 4570564695064981454979072a b  c
+--R                    + 
+--R                                               7 24 10
+--R                      734221072631076055154688a b  c
+--R                    + 
+--R                                                6 26 9
+--R                      - 87134384582468692869120a b  c
+--R                    + 
+--R                                             5 28 8
+--R                      7412007378227759677440a b  c
+--R                    + 
+--R                                              4 30 7
+--R                      - 424869025896179171328a b  c
+--R                    + 
+--R                                           3 32 6                      2 34 5
+--R                      14419980649072951296a b  c  - 204403609650069504a b  c
+--R                    + 
+--R                                        36 4                  38 3
+--R                      137438953472000a b  c  - 68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                         14   14                         13 3 13
+--R                  - 15781486106538672128a  b c   + 841443865487264972800a  b c
+--R                + 
+--R                                           12 5 12
+--R                  - 2860949643992143757312a  b c
+--R                + 
+--R                                         11 7 11
+--R                  3854117596814391640064a  b c
+--R                + 
+--R                                           10 9 10
+--R                  - 2827477675767953883136a  b c
+--R                + 
+--R                                         9 11 9                         8 13 8
+--R                  1275028264002164621312a b  c  - 370951843406822768640a b  c
+--R                + 
+--R                                       7 15 7                       6 17 6
+--R                  69964837141849571328a b  c  - 8218108953284837376a b  c
+--R                + 
+--R                                     5 19 5                     4 21 4
+--R                  529478543583739904a b  c  - 11075494346752000a b  c
+--R                + 
+--R                                    3 23 3                 2 25 2
+--R                  - 384332333056000a b  c  + 4130652160000a b  c
+--R                + 
+--R                                 27               29
+--R                  294400000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                            10 13                  9 2 12
+--R                           - 17592186044416a  c   + 43980465111040a b c
+--R                         + 
+--R                                            8 4 11                  7 6 10
+--R                           - 49478023249920a b c   + 32985348833280a b c
+--R                         + 
+--R                                            6 8 9                 5 10 8
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          4 12 7                3 14 6
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       2 16 5               18 4            20 3
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 13                  9 2 12
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 11                  7 6 10
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 9                 5 10 8
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 7                3 14 6
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 5               18 4
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 3
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4        2 3     4 2  8
+--R           (- 128a c  + 64a b c  - 8b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4      6  4
+--R           (- 256a b c  + 128a b c  - 16b c)x  + (- 256a c  + 48a b c - 8b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 256a b c  + 128a b c - 16a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 13                  9 2 12
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 11                  7 6 10
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 9                 5 10 8
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 7                3 14 6
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                                   19 22
+--R                      - 25916347257988612932763648a  c
+--R                    + 
+--R                                                  18 2 21
+--R                      710319476887320554463297536a  b c
+--R                    + 
+--R                                                     17 4 20
+--R                      - 2117032171903979079654703104a  b c
+--R                    + 
+--R                                                   16 6 19
+--R                      2891115402226247018615930880a  b c
+--R                    + 
+--R                                                     15 8 18
+--R                      - 2201230785701924136403599360a  b c
+--R                    + 
+--R                                                  14 10 17
+--R                      868471530398624972669976576a  b  c
+--R                    + 
+--R                                                 13 12 16
+--R                      18744622097011813455495168a  b  c
+--R                    + 
+--R                                                    12 14 15
+--R                      - 251465683171415280857382912a  b  c
+--R                    + 
+--R                                                  11 16 14
+--R                      174958732157065591793909760a  b  c
+--R                    + 
+--R                                                   10 18 13
+--R                      - 72655579834722369321041920a  b  c
+--R                    + 
+--R                                                 9 20 12
+--R                      21220564118596252017360896a b  c
+--R                    + 
+--R                                                  8 22 11
+--R                      - 4570564695064981454979072a b  c
+--R                    + 
+--R                                               7 24 10
+--R                      734221072631076055154688a b  c
+--R                    + 
+--R                                                6 26 9
+--R                      - 87134384582468692869120a b  c
+--R                    + 
+--R                                             5 28 8
+--R                      7412007378227759677440a b  c
+--R                    + 
+--R                                              4 30 7
+--R                      - 424869025896179171328a b  c
+--R                    + 
+--R                                           3 32 6                      2 34 5
+--R                      14419980649072951296a b  c  - 204403609650069504a b  c
+--R                    + 
+--R                                        36 4                  38 3
+--R                      137438953472000a b  c  - 68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                       14   14                         13 3 13
+--R                  15781486106538672128a  b c   - 841443865487264972800a  b c
+--R                + 
+--R                                         12 5 12
+--R                  2860949643992143757312a  b c
+--R                + 
+--R                                           11 7 11
+--R                  - 3854117596814391640064a  b c
+--R                + 
+--R                                         10 9 10                          9 11 9
+--R                  2827477675767953883136a  b c   - 1275028264002164621312a b  c
+--R                + 
+--R                                        8 13 8                        7 15 7
+--R                  370951843406822768640a b  c  - 69964837141849571328a b  c
+--R                + 
+--R                                      6 17 6                      5 19 5
+--R                  8218108953284837376a b  c  - 529478543583739904a b  c
+--R                + 
+--R                                    4 21 4                   3 23 3
+--R                  11075494346752000a b  c  + 384332333056000a b  c
+--R                + 
+--R                                  2 25 2                  27               29
+--R                  - 4130652160000a b  c  - 294400000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                          10 13                  9 2 12
+--R                           17592186044416a  c   - 43980465111040a b c
+--R                         + 
+--R                                          8 4 11                  7 6 10
+--R                           49478023249920a b c   - 32985348833280a b c
+--R                         + 
+--R                                          6 8 9                 5 10 8
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        4 12 7                3 14 6
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 13                  9 2 12
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 11                  7 6 10
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 9                 5 10 8
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 7                3 14 6
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 5               18 4
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 3
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 4         2 3      4 2  8        2   3         3 2      5   6
+--R           (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R         + 
+--R                3 3        4       6  4        3   2       2 3         5  2
+--R           (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R         + 
+--R               4 2       3 2       2 4
+--R           256a c  - 128a b c + 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 13                  9 2 12
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 11                  7 6 10
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 9                 5 10 8
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 7                3 14 6
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                                 19 22
+--R                      25916347257988612932763648a  c
+--R                    + 
+--R                                                    18 2 21
+--R                      - 710319476887320554463297536a  b c
+--R                    + 
+--R                                                   17 4 20
+--R                      2117032171903979079654703104a  b c
+--R                    + 
+--R                                                     16 6 19
+--R                      - 2891115402226247018615930880a  b c
+--R                    + 
+--R                                                   15 8 18
+--R                      2201230785701924136403599360a  b c
+--R                    + 
+--R                                                    14 10 17
+--R                      - 868471530398624972669976576a  b  c
+--R                    + 
+--R                                                   13 12 16
+--R                      - 18744622097011813455495168a  b  c
+--R                    + 
+--R                                                  12 14 15
+--R                      251465683171415280857382912a  b  c
+--R                    + 
+--R                                                    11 16 14
+--R                      - 174958732157065591793909760a  b  c
+--R                    + 
+--R                                                 10 18 13
+--R                      72655579834722369321041920a  b  c
+--R                    + 
+--R                                                   9 20 12
+--R                      - 21220564118596252017360896a b  c
+--R                    + 
+--R                                                8 22 11
+--R                      4570564695064981454979072a b  c
+--R                    + 
+--R                                                 7 24 10
+--R                      - 734221072631076055154688a b  c
+--R                    + 
+--R                                              6 26 9
+--R                      87134384582468692869120a b  c
+--R                    + 
+--R                                               5 28 8
+--R                      - 7412007378227759677440a b  c
+--R                    + 
+--R                                            4 30 7                        3 32 6
+--R                      424869025896179171328a b  c  - 14419980649072951296a b  c
+--R                    + 
+--R                                         2 34 5                     36 4
+--R                      204403609650069504a b  c  - 137438953472000a b  c
+--R                    + 
+--R                                     38 3
+--R                      68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                         14   14                         13 3 13
+--R                  - 15781486106538672128a  b c   + 841443865487264972800a  b c
+--R                + 
+--R                                           12 5 12
+--R                  - 2860949643992143757312a  b c
+--R                + 
+--R                                         11 7 11
+--R                  3854117596814391640064a  b c
+--R                + 
+--R                                           10 9 10
+--R                  - 2827477675767953883136a  b c
+--R                + 
+--R                                         9 11 9                         8 13 8
+--R                  1275028264002164621312a b  c  - 370951843406822768640a b  c
+--R                + 
+--R                                       7 15 7                       6 17 6
+--R                  69964837141849571328a b  c  - 8218108953284837376a b  c
+--R                + 
+--R                                     5 19 5                     4 21 4
+--R                  529478543583739904a b  c  - 11075494346752000a b  c
+--R                + 
+--R                                    3 23 3                 2 25 2
+--R                  - 384332333056000a b  c  + 4130652160000a b  c
+--R                + 
+--R                                 27               29
+--R                  294400000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                          10 13                  9 2 12
+--R                           17592186044416a  c   - 43980465111040a b c
+--R                         + 
+--R                                          8 4 11                  7 6 10
+--R                           49478023249920a b c   - 32985348833280a b c
+--R                         + 
+--R                                          6 8 9                 5 10 8
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        4 12 7                3 14 6
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 13                  9 2 12
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 11                  7 6 10
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 9                 5 10 8
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 7                3 14 6
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 5               18 4
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 3
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4         2 3      4 2  8
+--R           (- 256a c  + 128a b c  - 16b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4       6  4
+--R           (- 512a b c  + 256a b c  - 32b c)x  + (- 512a c  + 96a b c - 16b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2       3 2       2 4
+--R           (- 512a b c  + 256a b c - 32a b )x  - 256a c  + 128a b c - 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 13                  9 2 12
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 11                  7 6 10
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 9                 5 10 8
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 7                3 14 6
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                                 19 22
+--R                      25916347257988612932763648a  c
+--R                    + 
+--R                                                    18 2 21
+--R                      - 710319476887320554463297536a  b c
+--R                    + 
+--R                                                   17 4 20
+--R                      2117032171903979079654703104a  b c
+--R                    + 
+--R                                                     16 6 19
+--R                      - 2891115402226247018615930880a  b c
+--R                    + 
+--R                                                   15 8 18
+--R                      2201230785701924136403599360a  b c
+--R                    + 
+--R                                                    14 10 17
+--R                      - 868471530398624972669976576a  b  c
+--R                    + 
+--R                                                   13 12 16
+--R                      - 18744622097011813455495168a  b  c
+--R                    + 
+--R                                                  12 14 15
+--R                      251465683171415280857382912a  b  c
+--R                    + 
+--R                                                    11 16 14
+--R                      - 174958732157065591793909760a  b  c
+--R                    + 
+--R                                                 10 18 13
+--R                      72655579834722369321041920a  b  c
+--R                    + 
+--R                                                   9 20 12
+--R                      - 21220564118596252017360896a b  c
+--R                    + 
+--R                                                8 22 11
+--R                      4570564695064981454979072a b  c
+--R                    + 
+--R                                                 7 24 10
+--R                      - 734221072631076055154688a b  c
+--R                    + 
+--R                                              6 26 9
+--R                      87134384582468692869120a b  c
+--R                    + 
+--R                                               5 28 8
+--R                      - 7412007378227759677440a b  c
+--R                    + 
+--R                                            4 30 7                        3 32 6
+--R                      424869025896179171328a b  c  - 14419980649072951296a b  c
+--R                    + 
+--R                                         2 34 5                     36 4
+--R                      204403609650069504a b  c  - 137438953472000a b  c
+--R                    + 
+--R                                     38 3
+--R                      68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                       14   14                         13 3 13
+--R                  15781486106538672128a  b c   - 841443865487264972800a  b c
+--R                + 
+--R                                         12 5 12
+--R                  2860949643992143757312a  b c
+--R                + 
+--R                                           11 7 11
+--R                  - 3854117596814391640064a  b c
+--R                + 
+--R                                         10 9 10                          9 11 9
+--R                  2827477675767953883136a  b c   - 1275028264002164621312a b  c
+--R                + 
+--R                                        8 13 8                        7 15 7
+--R                  370951843406822768640a b  c  - 69964837141849571328a b  c
+--R                + 
+--R                                      6 17 6                      5 19 5
+--R                  8218108953284837376a b  c  - 529478543583739904a b  c
+--R                + 
+--R                                    4 21 4                   3 23 3
+--R                  11075494346752000a b  c  + 384332333056000a b  c
+--R                + 
+--R                                  2 25 2                  27               29
+--R                  - 4130652160000a b  c  - 294400000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                            10 13                  9 2 12
+--R                           - 17592186044416a  c   + 43980465111040a b c
+--R                         + 
+--R                                            8 4 11                  7 6 10
+--R                           - 49478023249920a b c   + 32985348833280a b c
+--R                         + 
+--R                                            6 8 9                 5 10 8
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          4 12 7                3 14 6
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       2 16 5               18 4            20 3
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 13                  9 2 12
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 11                  7 6 10
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 9                 5 10 8
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 7                3 14 6
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 5               18 4
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 3
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R            2     2   7                3  5        2         2  3      2     +-+
+--R     ((28a c  + 5b c)x  + (36a b c + 9b )x  + (- 4a c + 37a b )x  + 24a b x)\|x
+--R  /
+--R            2 4         2 3      4 2  8        2   3         3 2      5   6
+--R       (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R     + 
+--R            3 3        4       6  4        3   2       2 3         5  2
+--R       (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R     + 
+--R           4 2       3 2       2 4
+--R       256a c  - 128a b c + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 682
+
+--S 683 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                          +-----------+
+--R              2 2         2       4 4+-+3 |          2 4+-+3
+--R         (256a c  - 128a b c + 16b )\|2  \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 13                  9 2 12
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 11                  7 6 10
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 9                 5 10 8
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 7                3 14 6
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                                 19 22
+--R                      25916347257988612932763648a  c
+--R                    + 
+--R                                                    18 2 21
+--R                      - 710319476887320554463297536a  b c
+--R                    + 
+--R                                                   17 4 20
+--R                      2117032171903979079654703104a  b c
+--R                    + 
+--R                                                     16 6 19
+--R                      - 2891115402226247018615930880a  b c
+--R                    + 
+--R                                                   15 8 18
+--R                      2201230785701924136403599360a  b c
+--R                    + 
+--R                                                    14 10 17
+--R                      - 868471530398624972669976576a  b  c
+--R                    + 
+--R                                                   13 12 16
+--R                      - 18744622097011813455495168a  b  c
+--R                    + 
+--R                                                  12 14 15
+--R                      251465683171415280857382912a  b  c
+--R                    + 
+--R                                                    11 16 14
+--R                      - 174958732157065591793909760a  b  c
+--R                    + 
+--R                                                 10 18 13
+--R                      72655579834722369321041920a  b  c
+--R                    + 
+--R                                                   9 20 12
+--R                      - 21220564118596252017360896a b  c
+--R                    + 
+--R                                                8 22 11
+--R                      4570564695064981454979072a b  c
+--R                    + 
+--R                                                 7 24 10
+--R                      - 734221072631076055154688a b  c
+--R                    + 
+--R                                              6 26 9
+--R                      87134384582468692869120a b  c
+--R                    + 
+--R                                               5 28 8
+--R                      - 7412007378227759677440a b  c
+--R                    + 
+--R                                            4 30 7                        3 32 6
+--R                      424869025896179171328a b  c  - 14419980649072951296a b  c
+--R                    + 
+--R                                         2 34 5                     36 4
+--R                      204403609650069504a b  c  - 137438953472000a b  c
+--R                    + 
+--R                                     38 3
+--R                      68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                         14   14                         13 3 13
+--R                  - 15781486106538672128a  b c   + 841443865487264972800a  b c
+--R                + 
+--R                                           12 5 12
+--R                  - 2860949643992143757312a  b c
+--R                + 
+--R                                         11 7 11
+--R                  3854117596814391640064a  b c
+--R                + 
+--R                                           10 9 10
+--R                  - 2827477675767953883136a  b c
+--R                + 
+--R                                         9 11 9                         8 13 8
+--R                  1275028264002164621312a b  c  - 370951843406822768640a b  c
+--R                + 
+--R                                       7 15 7                       6 17 6
+--R                  69964837141849571328a b  c  - 8218108953284837376a b  c
+--R                + 
+--R                                     5 19 5                     4 21 4
+--R                  529478543583739904a b  c  - 11075494346752000a b  c
+--R                + 
+--R                                    3 23 3                 2 25 2
+--R                  - 384332333056000a b  c  + 4130652160000a b  c
+--R                + 
+--R                                 27               29
+--R                  294400000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                          10 13                  9 2 12
+--R                           17592186044416a  c   - 43980465111040a b c
+--R                         + 
+--R                                          8 4 11                  7 6 10
+--R                           49478023249920a b c   - 32985348833280a b c
+--R                         + 
+--R                                          6 8 9                 5 10 8
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        4 12 7                3 14 6
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 13                  9 2 12
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 11                  7 6 10
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 9                 5 10 8
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 7                3 14 6
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 5               18 4
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 3
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                            +-----------+
+--R                2 2         2       4 4+-+3 |          2 4+-+3
+--R         (- 256a c  + 128a b c - 16b )\|2  \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 13                  9 2 12
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 11                  7 6 10
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 9                 5 10 8
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 7                3 14 6
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                                 19 22
+--R                      25916347257988612932763648a  c
+--R                    + 
+--R                                                    18 2 21
+--R                      - 710319476887320554463297536a  b c
+--R                    + 
+--R                                                   17 4 20
+--R                      2117032171903979079654703104a  b c
+--R                    + 
+--R                                                     16 6 19
+--R                      - 2891115402226247018615930880a  b c
+--R                    + 
+--R                                                   15 8 18
+--R                      2201230785701924136403599360a  b c
+--R                    + 
+--R                                                    14 10 17
+--R                      - 868471530398624972669976576a  b  c
+--R                    + 
+--R                                                   13 12 16
+--R                      - 18744622097011813455495168a  b  c
+--R                    + 
+--R                                                  12 14 15
+--R                      251465683171415280857382912a  b  c
+--R                    + 
+--R                                                    11 16 14
+--R                      - 174958732157065591793909760a  b  c
+--R                    + 
+--R                                                 10 18 13
+--R                      72655579834722369321041920a  b  c
+--R                    + 
+--R                                                   9 20 12
+--R                      - 21220564118596252017360896a b  c
+--R                    + 
+--R                                                8 22 11
+--R                      4570564695064981454979072a b  c
+--R                    + 
+--R                                                 7 24 10
+--R                      - 734221072631076055154688a b  c
+--R                    + 
+--R                                              6 26 9
+--R                      87134384582468692869120a b  c
+--R                    + 
+--R                                               5 28 8
+--R                      - 7412007378227759677440a b  c
+--R                    + 
+--R                                            4 30 7                        3 32 6
+--R                      424869025896179171328a b  c  - 14419980649072951296a b  c
+--R                    + 
+--R                                         2 34 5                     36 4
+--R                      204403609650069504a b  c  - 137438953472000a b  c
+--R                    + 
+--R                                     38 3
+--R                      68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                       14   14                         13 3 13
+--R                  15781486106538672128a  b c   - 841443865487264972800a  b c
+--R                + 
+--R                                         12 5 12
+--R                  2860949643992143757312a  b c
+--R                + 
+--R                                           11 7 11
+--R                  - 3854117596814391640064a  b c
+--R                + 
+--R                                         10 9 10                          9 11 9
+--R                  2827477675767953883136a  b c   - 1275028264002164621312a b  c
+--R                + 
+--R                                        8 13 8                        7 15 7
+--R                  370951843406822768640a b  c  - 69964837141849571328a b  c
+--R                + 
+--R                                      6 17 6                      5 19 5
+--R                  8218108953284837376a b  c  - 529478543583739904a b  c
+--R                + 
+--R                                    4 21 4                   3 23 3
+--R                  11075494346752000a b  c  + 384332333056000a b  c
+--R                + 
+--R                                  2 25 2                  27               29
+--R                  - 4130652160000a b  c  - 294400000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                            10 13                  9 2 12
+--R                           - 17592186044416a  c   + 43980465111040a b c
+--R                         + 
+--R                                            8 4 11                  7 6 10
+--R                           - 49478023249920a b c   + 32985348833280a b c
+--R                         + 
+--R                                            6 8 9                 5 10 8
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          4 12 7                3 14 6
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       2 16 5               18 4            20 3
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 13                  9 2 12
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 11                  7 6 10
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 9                 5 10 8
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 7                3 14 6
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 5               18 4
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 3
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                          +-----------+
+--R              2 2         2       4 4+-+3 |          2 4+-+3
+--R         (256a c  - 128a b c + 16b )\|2  \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 13                  9 2 12
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 11                  7 6 10
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 9                 5 10 8
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 7                3 14 6
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                                   19 22
+--R                      - 25916347257988612932763648a  c
+--R                    + 
+--R                                                  18 2 21
+--R                      710319476887320554463297536a  b c
+--R                    + 
+--R                                                     17 4 20
+--R                      - 2117032171903979079654703104a  b c
+--R                    + 
+--R                                                   16 6 19
+--R                      2891115402226247018615930880a  b c
+--R                    + 
+--R                                                     15 8 18
+--R                      - 2201230785701924136403599360a  b c
+--R                    + 
+--R                                                  14 10 17
+--R                      868471530398624972669976576a  b  c
+--R                    + 
+--R                                                 13 12 16
+--R                      18744622097011813455495168a  b  c
+--R                    + 
+--R                                                    12 14 15
+--R                      - 251465683171415280857382912a  b  c
+--R                    + 
+--R                                                  11 16 14
+--R                      174958732157065591793909760a  b  c
+--R                    + 
+--R                                                   10 18 13
+--R                      - 72655579834722369321041920a  b  c
+--R                    + 
+--R                                                 9 20 12
+--R                      21220564118596252017360896a b  c
+--R                    + 
+--R                                                  8 22 11
+--R                      - 4570564695064981454979072a b  c
+--R                    + 
+--R                                               7 24 10
+--R                      734221072631076055154688a b  c
+--R                    + 
+--R                                                6 26 9
+--R                      - 87134384582468692869120a b  c
+--R                    + 
+--R                                             5 28 8
+--R                      7412007378227759677440a b  c
+--R                    + 
+--R                                              4 30 7
+--R                      - 424869025896179171328a b  c
+--R                    + 
+--R                                           3 32 6                      2 34 5
+--R                      14419980649072951296a b  c  - 204403609650069504a b  c
+--R                    + 
+--R                                        36 4                  38 3
+--R                      137438953472000a b  c  - 68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                         14   14                         13 3 13
+--R                  - 15781486106538672128a  b c   + 841443865487264972800a  b c
+--R                + 
+--R                                           12 5 12
+--R                  - 2860949643992143757312a  b c
+--R                + 
+--R                                         11 7 11
+--R                  3854117596814391640064a  b c
+--R                + 
+--R                                           10 9 10
+--R                  - 2827477675767953883136a  b c
+--R                + 
+--R                                         9 11 9                         8 13 8
+--R                  1275028264002164621312a b  c  - 370951843406822768640a b  c
+--R                + 
+--R                                       7 15 7                       6 17 6
+--R                  69964837141849571328a b  c  - 8218108953284837376a b  c
+--R                + 
+--R                                     5 19 5                     4 21 4
+--R                  529478543583739904a b  c  - 11075494346752000a b  c
+--R                + 
+--R                                    3 23 3                 2 25 2
+--R                  - 384332333056000a b  c  + 4130652160000a b  c
+--R                + 
+--R                                 27               29
+--R                  294400000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                            10 13                  9 2 12
+--R                           - 17592186044416a  c   + 43980465111040a b c
+--R                         + 
+--R                                            8 4 11                  7 6 10
+--R                           - 49478023249920a b c   + 32985348833280a b c
+--R                         + 
+--R                                            6 8 9                 5 10 8
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          4 12 7                3 14 6
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       2 16 5               18 4            20 3
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 13                  9 2 12
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 11                  7 6 10
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 9                 5 10 8
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 7                3 14 6
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 5               18 4
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 3
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                            +-----------+
+--R                2 2         2       4 4+-+3 |          2 4+-+3
+--R         (- 256a c  + 128a b c - 16b )\|2  \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 13                  9 2 12
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 11                  7 6 10
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 9                 5 10 8
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 7                3 14 6
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                                   19 22
+--R                      - 25916347257988612932763648a  c
+--R                    + 
+--R                                                  18 2 21
+--R                      710319476887320554463297536a  b c
+--R                    + 
+--R                                                     17 4 20
+--R                      - 2117032171903979079654703104a  b c
+--R                    + 
+--R                                                   16 6 19
+--R                      2891115402226247018615930880a  b c
+--R                    + 
+--R                                                     15 8 18
+--R                      - 2201230785701924136403599360a  b c
+--R                    + 
+--R                                                  14 10 17
+--R                      868471530398624972669976576a  b  c
+--R                    + 
+--R                                                 13 12 16
+--R                      18744622097011813455495168a  b  c
+--R                    + 
+--R                                                    12 14 15
+--R                      - 251465683171415280857382912a  b  c
+--R                    + 
+--R                                                  11 16 14
+--R                      174958732157065591793909760a  b  c
+--R                    + 
+--R                                                   10 18 13
+--R                      - 72655579834722369321041920a  b  c
+--R                    + 
+--R                                                 9 20 12
+--R                      21220564118596252017360896a b  c
+--R                    + 
+--R                                                  8 22 11
+--R                      - 4570564695064981454979072a b  c
+--R                    + 
+--R                                               7 24 10
+--R                      734221072631076055154688a b  c
+--R                    + 
+--R                                                6 26 9
+--R                      - 87134384582468692869120a b  c
+--R                    + 
+--R                                             5 28 8
+--R                      7412007378227759677440a b  c
+--R                    + 
+--R                                              4 30 7
+--R                      - 424869025896179171328a b  c
+--R                    + 
+--R                                           3 32 6                      2 34 5
+--R                      14419980649072951296a b  c  - 204403609650069504a b  c
+--R                    + 
+--R                                        36 4                  38 3
+--R                      137438953472000a b  c  - 68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                       14   14                         13 3 13
+--R                  15781486106538672128a  b c   - 841443865487264972800a  b c
+--R                + 
+--R                                         12 5 12
+--R                  2860949643992143757312a  b c
+--R                + 
+--R                                           11 7 11
+--R                  - 3854117596814391640064a  b c
+--R                + 
+--R                                         10 9 10                          9 11 9
+--R                  2827477675767953883136a  b c   - 1275028264002164621312a b  c
+--R                + 
+--R                                        8 13 8                        7 15 7
+--R                  370951843406822768640a b  c  - 69964837141849571328a b  c
+--R                + 
+--R                                      6 17 6                      5 19 5
+--R                  8218108953284837376a b  c  - 529478543583739904a b  c
+--R                + 
+--R                                    4 21 4                   3 23 3
+--R                  11075494346752000a b  c  + 384332333056000a b  c
+--R                + 
+--R                                  2 25 2                  27               29
+--R                  - 4130652160000a b  c  - 294400000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                          10 13                  9 2 12
+--R                           17592186044416a  c   - 43980465111040a b c
+--R                         + 
+--R                                          8 4 11                  7 6 10
+--R                           49478023249920a b c   - 32985348833280a b c
+--R                         + 
+--R                                          6 8 9                 5 10 8
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        4 12 7                3 14 6
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 13                  9 2 12
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 11                  7 6 10
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 9                 5 10 8
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 7                3 14 6
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 5               18 4
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 3
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                          +-----------+
+--R              2 2         2       4 4+-+3 |          2 4+-+3
+--R         (512a c  - 256a b c + 32b )\|2  \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 13                  9 2 12
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 11                  7 6 10
+--R                         49478023249920a b c   - 32985348833280a b c
+--R                       + 
+--R                                        6 8 9                 5 10 8
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 7                3 14 6
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                                 19 22
+--R                      25916347257988612932763648a  c
+--R                    + 
+--R                                                    18 2 21
+--R                      - 710319476887320554463297536a  b c
+--R                    + 
+--R                                                   17 4 20
+--R                      2117032171903979079654703104a  b c
+--R                    + 
+--R                                                     16 6 19
+--R                      - 2891115402226247018615930880a  b c
+--R                    + 
+--R                                                   15 8 18
+--R                      2201230785701924136403599360a  b c
+--R                    + 
+--R                                                    14 10 17
+--R                      - 868471530398624972669976576a  b  c
+--R                    + 
+--R                                                   13 12 16
+--R                      - 18744622097011813455495168a  b  c
+--R                    + 
+--R                                                  12 14 15
+--R                      251465683171415280857382912a  b  c
+--R                    + 
+--R                                                    11 16 14
+--R                      - 174958732157065591793909760a  b  c
+--R                    + 
+--R                                                 10 18 13
+--R                      72655579834722369321041920a  b  c
+--R                    + 
+--R                                                   9 20 12
+--R                      - 21220564118596252017360896a b  c
+--R                    + 
+--R                                                8 22 11
+--R                      4570564695064981454979072a b  c
+--R                    + 
+--R                                                 7 24 10
+--R                      - 734221072631076055154688a b  c
+--R                    + 
+--R                                              6 26 9
+--R                      87134384582468692869120a b  c
+--R                    + 
+--R                                               5 28 8
+--R                      - 7412007378227759677440a b  c
+--R                    + 
+--R                                            4 30 7                        3 32 6
+--R                      424869025896179171328a b  c  - 14419980649072951296a b  c
+--R                    + 
+--R                                         2 34 5                     36 4
+--R                      204403609650069504a b  c  - 137438953472000a b  c
+--R                    + 
+--R                                     38 3
+--R                      68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                         14   14                         13 3 13
+--R                  - 15781486106538672128a  b c   + 841443865487264972800a  b c
+--R                + 
+--R                                           12 5 12
+--R                  - 2860949643992143757312a  b c
+--R                + 
+--R                                         11 7 11
+--R                  3854117596814391640064a  b c
+--R                + 
+--R                                           10 9 10
+--R                  - 2827477675767953883136a  b c
+--R                + 
+--R                                         9 11 9                         8 13 8
+--R                  1275028264002164621312a b  c  - 370951843406822768640a b  c
+--R                + 
+--R                                       7 15 7                       6 17 6
+--R                  69964837141849571328a b  c  - 8218108953284837376a b  c
+--R                + 
+--R                                     5 19 5                     4 21 4
+--R                  529478543583739904a b  c  - 11075494346752000a b  c
+--R                + 
+--R                                    3 23 3                 2 25 2
+--R                  - 384332333056000a b  c  + 4130652160000a b  c
+--R                + 
+--R                                 27               29
+--R                  294400000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                          10 13                  9 2 12
+--R                           17592186044416a  c   - 43980465111040a b c
+--R                         + 
+--R                                          8 4 11                  7 6 10
+--R                           49478023249920a b c   - 32985348833280a b c
+--R                         + 
+--R                                          6 8 9                 5 10 8
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        4 12 7                3 14 6
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                     2 16 5               18 4            20 3
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 13                  9 2 12
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 11                  7 6 10
+--R                                49478023249920a b c   - 32985348833280a b c
+--R                              + 
+--R                                               6 8 9                 5 10 8
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 7                3 14 6
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 5               18 4
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20 3
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                            +-----------+
+--R                2 2         2       4 4+-+3 |          2 4+-+3
+--R         (- 512a c  + 256a b c - 32b )\|2  \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 13                  9 2 12
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 11                  7 6 10
+--R                         - 49478023249920a b c   + 32985348833280a b c
+--R                       + 
+--R                                          6 8 9                 5 10 8
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 7                3 14 6
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                     2 16 5               18 4            20 3
+--R                       - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       15 21
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 20
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 19
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 18
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 17
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 16
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 15
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 14
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 13
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 12
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 11
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 10
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 9
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 8
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 7                   30 6
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   10 13                  9 2 12
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 11                  7 6 10
+--R                     24739011624960a b c   - 16492674416640a b c
+--R                   + 
+--R                                   6 8 9                 5 10 8
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 7               3 14 6
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 5               18 4           20 3
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                                 19 22
+--R                      25916347257988612932763648a  c
+--R                    + 
+--R                                                    18 2 21
+--R                      - 710319476887320554463297536a  b c
+--R                    + 
+--R                                                   17 4 20
+--R                      2117032171903979079654703104a  b c
+--R                    + 
+--R                                                     16 6 19
+--R                      - 2891115402226247018615930880a  b c
+--R                    + 
+--R                                                   15 8 18
+--R                      2201230785701924136403599360a  b c
+--R                    + 
+--R                                                    14 10 17
+--R                      - 868471530398624972669976576a  b  c
+--R                    + 
+--R                                                   13 12 16
+--R                      - 18744622097011813455495168a  b  c
+--R                    + 
+--R                                                  12 14 15
+--R                      251465683171415280857382912a  b  c
+--R                    + 
+--R                                                    11 16 14
+--R                      - 174958732157065591793909760a  b  c
+--R                    + 
+--R                                                 10 18 13
+--R                      72655579834722369321041920a  b  c
+--R                    + 
+--R                                                   9 20 12
+--R                      - 21220564118596252017360896a b  c
+--R                    + 
+--R                                                8 22 11
+--R                      4570564695064981454979072a b  c
+--R                    + 
+--R                                                 7 24 10
+--R                      - 734221072631076055154688a b  c
+--R                    + 
+--R                                              6 26 9
+--R                      87134384582468692869120a b  c
+--R                    + 
+--R                                               5 28 8
+--R                      - 7412007378227759677440a b  c
+--R                    + 
+--R                                            4 30 7                        3 32 6
+--R                      424869025896179171328a b  c  - 14419980649072951296a b  c
+--R                    + 
+--R                                         2 34 5                     36 4
+--R                      204403609650069504a b  c  - 137438953472000a b  c
+--R                    + 
+--R                                     38 3
+--R                      68719476736000b  c
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    15 21
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 20
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 19
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 18
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 17
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 16
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 15
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 14
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 13
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 12
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 11
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 10
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 9
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 8
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 7                   30 6
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                                       14   14                         13 3 13
+--R                  15781486106538672128a  b c   - 841443865487264972800a  b c
+--R                + 
+--R                                         12 5 12
+--R                  2860949643992143757312a  b c
+--R                + 
+--R                                           11 7 11
+--R                  - 3854117596814391640064a  b c
+--R                + 
+--R                                         10 9 10                          9 11 9
+--R                  2827477675767953883136a  b c   - 1275028264002164621312a b  c
+--R                + 
+--R                                        8 13 8                        7 15 7
+--R                  370951843406822768640a b  c  - 69964837141849571328a b  c
+--R                + 
+--R                                      6 17 6                      5 19 5
+--R                  8218108953284837376a b  c  - 529478543583739904a b  c
+--R                + 
+--R                                    4 21 4                   3 23 3
+--R                  11075494346752000a b  c  + 384332333056000a b  c
+--R                + 
+--R                                  2 25 2                  27               29
+--R                  - 4130652160000a b  c  - 294400000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                            10 13                  9 2 12
+--R                           - 17592186044416a  c   + 43980465111040a b c
+--R                         + 
+--R                                            8 4 11                  7 6 10
+--R                           - 49478023249920a b c   + 32985348833280a b c
+--R                         + 
+--R                                            6 8 9                 5 10 8
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          4 12 7                3 14 6
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       2 16 5               18 4            20 3
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                      *
+--R                         ROOT
+--R                                             6 6                5 2 5
+--R                                - 1475789056a c  + 146825952000a b c
+--R                              + 
+--R                                                4 4 4                3 6 3
+--R                                - 3647743260000a b c  - 207773230000a b c
+--R                              + 
+--R                                             2 8 2              10           12
+--R                                - 5345390625a b c  - 67968750a b  c - 390625b
+--R                           /
+--R                                                         15 21
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            14 2 20
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          13 4 19
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            12 6 18
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          11 8 17
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           10 10 16
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         9 12 15
+--R                                369303816355665223352320a b  c
+--R                              + 
+--R                                                           8 14 14
+--R                                - 118704798114320964648960a b  c
+--R                              + 
+--R                                                        7 16 13
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         6 18 12
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      5 20 11
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       4 22 10
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    3 24 9
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     2 26 8
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                    28 7                   30 6
+--R                                16888498602639360a b  c  - 281474976710656b  c
+--R                     + 
+--R                                5   5             4 3 4            3 5 3
+--R                       14488320a b c  - 106839040a b c  - 52776416a b c
+--R                     + 
+--R                                 2 7 2           9        11
+--R                       - 1386000a b c  - 48125a b c - 625b
+--R                  /
+--R                                     10 13                  9 2 12
+--R                       8796093022208a  c   - 21990232555520a b c
+--R                     + 
+--R                                      8 4 11                  7 6 10
+--R                       24739011624960a b c   - 16492674416640a b c
+--R                     + 
+--R                                     6 8 9                 5 10 8
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    4 12 7               3 14 6
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  2 16 5               18 4           20 3
+--R                       6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 13                  9 2 12
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 11                  7 6 10
+--R                                - 49478023249920a b c   + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 9                 5 10 8
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 7                3 14 6
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 5               18 4
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20 3
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              15 21
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 20
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 19
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 18
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 17
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 16
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 15
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 14
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 13
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 12
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 11
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 10
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 9
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 8
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 7
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 6
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          10 13                  9 2 12
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 11                  7 6 10
+--R                            24739011624960a b c   - 16492674416640a b c
+--R                          + 
+--R                                          6 8 9                 5 10 8
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 7               3 14 6
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 5               18 4           20 3
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                                 11 9                   10 2 8
+--R                  18512297918464a  c  - 391025068277760a  b c
+--R                + 
+--R                                      9 4 7                      8 6 6
+--R                  - 21301758494392320a b c  - 236987810308300800a b c
+--R                + 
+--R                                       7 8 5                      6 10 4
+--R                  - 830364977197324800a b c  - 147608159757696000a b  c
+--R                + 
+--R                                      5 12 3                   4 14 2
+--R                  - 10156967879784000a b  c  - 330521845500000a b  c
+--R                + 
+--R                                  3 16                2 18
+--R                  - 5181853359375a b  c - 35666640625a b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                        +------------------+
+--R                        +-----------+                   | +-----------+
+--R                     2  |          2                 3 4| |          2
+--R         ((28a c + 5b )\|- 4a c + b   + 172a b c + 5b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                        +--------------------+
+--R                        +-----------+                   |   +-----------+
+--R                     2  |          2                 3 4|   |          2
+--R         ((28a c + 5b )\|- 4a c + b   - 172a b c - 5b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                                          +------------------+
+--R                          +-----------+                   | +-----------+
+--R                       2  |          2                 3 4| |          2
+--R         ((- 28a c - 5b )\|- 4a c + b   - 172a b c - 5b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                                          +--------------------+
+--R                          +-----------+                   |   +-----------+
+--R                       2  |          2                 3 4|   |          2
+--R         ((- 28a c - 5b )\|- 4a c + b   + 172a b c + 5b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                        +-----------+
+--R            2 2         2       4 4+-+3 |          2 4+-+3
+--R       (512a c  - 256a b c + 32b )\|2  \|- 4a c + b  \|c
+--R    *
+--R        +--------------------+ +------------------+
+--R        |   +-----------+      | +-----------+
+--R       4|   |          2      4| |          2
+--R       \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 683
+
+--S 684 of 1057
+--d0:=D(m0,x)
+--E 684
+
+)clear all
+
+--S 685 of 1057
+t0:=x^(11/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      5 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 685
+
+--S 686 of 1057
+r0:=1/4*x^(5/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-_
+   3/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (7*b^2+20*a*c+b*(7*b^2+36*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*_
+   (b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(3/4))-3/32*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(7*b^2+20*a*c+b*(7*b^2+36*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*(b^2-4*a*c)^2*(-b-sqrt(b^2-_
+   4*a*c))^(3/4))-3/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(7*b^2+20*a*c-b*(7*b^2+36*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(1/4)*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))-_
+   3/32*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (7*b^2+20*a*c-b*(7*b^2+36*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*_
+   (b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))+1/16*(24*a*b+(7*b^2+_
+   20*a*c)*x^2)*sqrt(x)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                       3      2 2  8              2      3   6
+--R               (- 60a c  - 21b c )x  + (- 120a b c  - 42b c)x
+--R             + 
+--R                      2 2         2       4  4          2           3  2      3
+--R               (- 120a c  - 102a b c - 21b )x  + (- 120a b c - 42a b )x  - 60a c
+--R             + 
+--R                    2 2
+--R               - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3      3 2  8            2 2      4   6
+--R           (- 108a b c  - 21b c )x  + (- 216a b c  - 42b c)x
+--R         + 
+--R                  2   2         3       5  4          2 2         4  2
+--R           (- 216a b c  - 150a b c - 21b )x  + (- 216a b c - 42a b )x
+--R         + 
+--R                 3         2 3
+--R           - 108a b c - 21a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                       3      2 2  8              2      3   6
+--R               (- 60a c  - 21b c )x  + (- 120a b c  - 42b c)x
+--R             + 
+--R                      2 2         2       4  4          2           3  2      3
+--R               (- 120a c  - 102a b c - 21b )x  + (- 120a b c - 42a b )x  - 60a c
+--R             + 
+--R                    2 2
+--R               - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3      3 2  8          2 2      4   6
+--R           (108a b c  + 21b c )x  + (216a b c  + 42b c)x
+--R         + 
+--R                2   2         3       5  4        2 2         4  2       3
+--R           (216a b c  + 150a b c + 21b )x  + (216a b c + 42a b )x  + 108a b c
+--R         + 
+--R              2 3
+--R           21a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                       3      2 2  8              2      3   6
+--R               (- 60a c  - 21b c )x  + (- 120a b c  - 42b c)x
+--R             + 
+--R                      2 2         2       4  4          2           3  2      3
+--R               (- 120a c  - 102a b c - 21b )x  + (- 120a b c - 42a b )x  - 60a c
+--R             + 
+--R                    2 2
+--R               - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3      3 2  8            2 2      4   6
+--R           (- 108a b c  - 21b c )x  + (- 216a b c  - 42b c)x
+--R         + 
+--R                  2   2         3       5  4          2 2         4  2
+--R           (- 216a b c  - 150a b c - 21b )x  + (- 216a b c - 42a b )x
+--R         + 
+--R                 3         2 3
+--R           - 108a b c - 21a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                       3      2 2  8              2      3   6
+--R               (- 60a c  - 21b c )x  + (- 120a b c  - 42b c)x
+--R             + 
+--R                      2 2         2       4  4          2           3  2      3
+--R               (- 120a c  - 102a b c - 21b )x  + (- 120a b c - 42a b )x  - 60a c
+--R             + 
+--R                    2 2
+--R               - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3      3 2  8          2 2      4   6
+--R           (108a b c  + 21b c )x  + (216a b c  + 42b c)x
+--R         + 
+--R                2   2         3       5  4        2 2         4  2       3
+--R           (216a b c  + 150a b c + 21b )x  + (216a b c + 42a b )x  + 108a b c
+--R         + 
+--R              2 3
+--R           21a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                   2      2   6                 3  4         2         2  2
+--R             (40a c  + 14b c)x  + (56a b c + 22b )x  + (- 24a c + 78a b )x
+--R           + 
+--R                2
+--R             48a b
+--R      *
+--R                                  +--------------------+3  +------------------+3
+--R            +-----------+         |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+ +-+4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|c \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              2 4         2 3      4 2  8         2   3         3 2      5   6
+--R         (512a c  - 256a b c  + 32b c )x  + (1024a b c  - 512a b c  + 64b c)x
+--R       + 
+--R               3 3         4       6  4         3   2       2 3         5  2
+--R         (1024a c  - 192a b c + 32b )x  + (1024a b c  - 512a b c + 64a b )x
+--R       + 
+--R             4 2       3 2       2 4
+--R         512a c  - 256a b c + 32a b
+--R    *
+--R                              +--------------------+3  +------------------+3
+--R            +-----------+     |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2 4        2 3     4 2  8
+--R           (- 128a c  + 64a b c  - 8b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4      6  4
+--R           (- 256a b c  + 128a b c  - 16b c)x  + (- 256a c  + 48a b c - 8b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 256a b c  + 128a b c - 16a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 11                  9 2 10
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 9                  7 6 8
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        6 8 7                 5 10 6
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 5                3 14 4
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 3               18 2            20
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                        11 12                     10 2 11
+--R                      11258999068426240a  c   - 21955048183431168a  b c
+--R                    + 
+--R                                        9 4 10                    8 6 9
+--R                      16184811160862720a b c   - 3694359069327360a b c
+--R                    + 
+--R                                         7 8 8                    6 10 7
+--R                      - 2374945115996160a b c  + 2308974418329600a b  c
+--R                    + 
+--R                                        5 12 6                   4 14 5
+--R                      - 946679511515136a b  c  + 235020610437120a b  c
+--R                    + 
+--R                                       3 16 4                 2 18 3
+--R                      - 37623913512960a b  c  + 3822520893440a b  c
+--R                    + 
+--R                                       20 2              22
+--R                      - 225485783040a b  c  + 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                             5   5              4 3 4              3 5 3
+--R                  6635520000a b c  + 1260748800a b c  - 1840693248a b c
+--R                + 
+--R                              2 7 2               9             11
+--R                  - 129060864a b c  + 201263616a b c - 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 11                  9 2 10
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 9                  7 6 8
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               6 8 7                 5 10 6
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 5                3 14 4
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 3               18 2
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 4        2 3     4 2  8        2   3         3 2      5   6
+--R           (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R         + 
+--R                3 3        4      6  4        3   2       2 3         5  2
+--R           (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R         + 
+--R               4 2      3 2      2 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 11                  9 2 10
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 9                  7 6 8
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          6 8 7                 5 10 6
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 5                3 14 4
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       2 16 3               18 2            20
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                        11 12                     10 2 11
+--R                      11258999068426240a  c   - 21955048183431168a  b c
+--R                    + 
+--R                                        9 4 10                    8 6 9
+--R                      16184811160862720a b c   - 3694359069327360a b c
+--R                    + 
+--R                                         7 8 8                    6 10 7
+--R                      - 2374945115996160a b c  + 2308974418329600a b  c
+--R                    + 
+--R                                        5 12 6                   4 14 5
+--R                      - 946679511515136a b  c  + 235020610437120a b  c
+--R                    + 
+--R                                       3 16 4                 2 18 3
+--R                      - 37623913512960a b  c  + 3822520893440a b  c
+--R                    + 
+--R                                       20 2              22
+--R                      - 225485783040a b  c  + 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                               5   5              4 3 4              3 5 3
+--R                  - 6635520000a b c  - 1260748800a b c  + 1840693248a b c
+--R                + 
+--R                            2 7 2               9             11
+--R                  129060864a b c  - 201263616a b c + 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 11                  9 2 10
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 9                  7 6 8
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 7                 5 10 6
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 5                3 14 4
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 3               18 2
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4        2 3     4 2  8
+--R           (- 128a c  + 64a b c  - 8b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4      6  4
+--R           (- 256a b c  + 128a b c  - 16b c)x  + (- 256a c  + 48a b c - 8b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 256a b c  + 128a b c - 16a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 11                  9 2 10
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 9                  7 6 8
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          6 8 7                 5 10 6
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 5                3 14 4
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       2 16 3               18 2            20
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                          11 12                     10 2 11
+--R                      - 11258999068426240a  c   + 21955048183431168a  b c
+--R                    + 
+--R                                          9 4 10                    8 6 9
+--R                      - 16184811160862720a b c   + 3694359069327360a b c
+--R                    + 
+--R                                       7 8 8                    6 10 7
+--R                      2374945115996160a b c  - 2308974418329600a b  c
+--R                    + 
+--R                                      5 12 6                   4 14 5
+--R                      946679511515136a b  c  - 235020610437120a b  c
+--R                    + 
+--R                                     3 16 4                 2 18 3
+--R                      37623913512960a b  c  - 3822520893440a b  c
+--R                    + 
+--R                                     20 2              22
+--R                      225485783040a b  c  - 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                             5   5              4 3 4              3 5 3
+--R                  6635520000a b c  + 1260748800a b c  - 1840693248a b c
+--R                + 
+--R                              2 7 2               9             11
+--R                  - 129060864a b c  + 201263616a b c - 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 11                  9 2 10
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 9                  7 6 8
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 7                 5 10 6
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 5                3 14 4
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 3               18 2
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 4        2 3     4 2  8        2   3         3 2      5   6
+--R           (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R         + 
+--R                3 3        4      6  4        3   2       2 3         5  2
+--R           (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R         + 
+--R               4 2      3 2      2 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 11                  9 2 10
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 9                  7 6 8
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        6 8 7                 5 10 6
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 5                3 14 4
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 3               18 2            20
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                          11 12                     10 2 11
+--R                      - 11258999068426240a  c   + 21955048183431168a  b c
+--R                    + 
+--R                                          9 4 10                    8 6 9
+--R                      - 16184811160862720a b c   + 3694359069327360a b c
+--R                    + 
+--R                                       7 8 8                    6 10 7
+--R                      2374945115996160a b c  - 2308974418329600a b  c
+--R                    + 
+--R                                      5 12 6                   4 14 5
+--R                      946679511515136a b  c  - 235020610437120a b  c
+--R                    + 
+--R                                     3 16 4                 2 18 3
+--R                      37623913512960a b  c  - 3822520893440a b  c
+--R                    + 
+--R                                     20 2              22
+--R                      225485783040a b  c  - 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                               5   5              4 3 4              3 5 3
+--R                  - 6635520000a b c  - 1260748800a b c  + 1840693248a b c
+--R                + 
+--R                            2 7 2               9             11
+--R                  129060864a b c  - 201263616a b c + 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 11                  9 2 10
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 9                  7 6 8
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               6 8 7                 5 10 6
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 5                3 14 4
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 3               18 2
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 4         2 3      4 2  8        2   3         3 2      5   6
+--R           (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R         + 
+--R                3 3        4       6  4        3   2       2 3         5  2
+--R           (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R         + 
+--R               4 2       3 2       2 4
+--R           256a c  - 128a b c + 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 11                  9 2 10
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 9                  7 6 8
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        6 8 7                 5 10 6
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 5                3 14 4
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 3               18 2            20
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                        11 12                     10 2 11
+--R                      11258999068426240a  c   - 21955048183431168a  b c
+--R                    + 
+--R                                        9 4 10                    8 6 9
+--R                      16184811160862720a b c   - 3694359069327360a b c
+--R                    + 
+--R                                         7 8 8                    6 10 7
+--R                      - 2374945115996160a b c  + 2308974418329600a b  c
+--R                    + 
+--R                                        5 12 6                   4 14 5
+--R                      - 946679511515136a b  c  + 235020610437120a b  c
+--R                    + 
+--R                                       3 16 4                 2 18 3
+--R                      - 37623913512960a b  c  + 3822520893440a b  c
+--R                    + 
+--R                                       20 2              22
+--R                      - 225485783040a b  c  + 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                             5   5              4 3 4              3 5 3
+--R                  6635520000a b c  + 1260748800a b c  - 1840693248a b c
+--R                + 
+--R                              2 7 2               9             11
+--R                  - 129060864a b c  + 201263616a b c - 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 11                  9 2 10
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 9                  7 6 8
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               6 8 7                 5 10 6
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 5                3 14 4
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 3               18 2
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4         2 3      4 2  8
+--R           (- 256a c  + 128a b c  - 16b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4       6  4
+--R           (- 512a b c  + 256a b c  - 32b c)x  + (- 512a c  + 96a b c - 16b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2       3 2       2 4
+--R           (- 512a b c  + 256a b c - 32a b )x  - 256a c  + 128a b c - 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 11                  9 2 10
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 9                  7 6 8
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          6 8 7                 5 10 6
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 5                3 14 4
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       2 16 3               18 2            20
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                        11 12                     10 2 11
+--R                      11258999068426240a  c   - 21955048183431168a  b c
+--R                    + 
+--R                                        9 4 10                    8 6 9
+--R                      16184811160862720a b c   - 3694359069327360a b c
+--R                    + 
+--R                                         7 8 8                    6 10 7
+--R                      - 2374945115996160a b c  + 2308974418329600a b  c
+--R                    + 
+--R                                        5 12 6                   4 14 5
+--R                      - 946679511515136a b  c  + 235020610437120a b  c
+--R                    + 
+--R                                       3 16 4                 2 18 3
+--R                      - 37623913512960a b  c  + 3822520893440a b  c
+--R                    + 
+--R                                       20 2              22
+--R                      - 225485783040a b  c  + 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                               5   5              4 3 4              3 5 3
+--R                  - 6635520000a b c  - 1260748800a b c  + 1840693248a b c
+--R                + 
+--R                            2 7 2               9             11
+--R                  129060864a b c  - 201263616a b c + 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 11                  9 2 10
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 9                  7 6 8
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 7                 5 10 6
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 5                3 14 4
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 3               18 2
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R            2     2   6                 3  4         2         2  2      2   +-+
+--R     ((20a c  + 7b c)x  + (28a b c + 11b )x  + (- 12a c + 39a b )x  + 24a b)\|x
+--R  /
+--R            2 4         2 3      4 2  8        2   3         3 2      5   6
+--R       (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R     + 
+--R            3 3        4       6  4        3   2       2 3         5  2
+--R       (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R     + 
+--R           4 2       3 2       2 4
+--R       256a c  - 128a b c + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 687
+
+--S 688 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +-----------+
+--R                2 2         2       4 4+-+ |          2 4+-+
+--R         (- 256a c  + 128a b c - 16b )\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 11                  9 2 10
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 9                  7 6 8
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        6 8 7                 5 10 6
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 5                3 14 4
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 3               18 2            20
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                        11 12                     10 2 11
+--R                      11258999068426240a  c   - 21955048183431168a  b c
+--R                    + 
+--R                                        9 4 10                    8 6 9
+--R                      16184811160862720a b c   - 3694359069327360a b c
+--R                    + 
+--R                                         7 8 8                    6 10 7
+--R                      - 2374945115996160a b c  + 2308974418329600a b  c
+--R                    + 
+--R                                        5 12 6                   4 14 5
+--R                      - 946679511515136a b  c  + 235020610437120a b  c
+--R                    + 
+--R                                       3 16 4                 2 18 3
+--R                      - 37623913512960a b  c  + 3822520893440a b  c
+--R                    + 
+--R                                       20 2              22
+--R                      - 225485783040a b  c  + 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                             5   5              4 3 4              3 5 3
+--R                  6635520000a b c  + 1260748800a b c  - 1840693248a b c
+--R                + 
+--R                              2 7 2               9             11
+--R                  - 129060864a b c  + 201263616a b c - 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 11                  9 2 10
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 9                  7 6 8
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               6 8 7                 5 10 6
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 5                3 14 4
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 3               18 2
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                         +-----------+
+--R              2 2         2       4 4+-+ |          2 4+-+
+--R         (256a c  - 128a b c + 16b )\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 11                  9 2 10
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 9                  7 6 8
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          6 8 7                 5 10 6
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 5                3 14 4
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       2 16 3               18 2            20
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                        11 12                     10 2 11
+--R                      11258999068426240a  c   - 21955048183431168a  b c
+--R                    + 
+--R                                        9 4 10                    8 6 9
+--R                      16184811160862720a b c   - 3694359069327360a b c
+--R                    + 
+--R                                         7 8 8                    6 10 7
+--R                      - 2374945115996160a b c  + 2308974418329600a b  c
+--R                    + 
+--R                                        5 12 6                   4 14 5
+--R                      - 946679511515136a b  c  + 235020610437120a b  c
+--R                    + 
+--R                                       3 16 4                 2 18 3
+--R                      - 37623913512960a b  c  + 3822520893440a b  c
+--R                    + 
+--R                                       20 2              22
+--R                      - 225485783040a b  c  + 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                               5   5              4 3 4              3 5 3
+--R                  - 6635520000a b c  - 1260748800a b c  + 1840693248a b c
+--R                + 
+--R                            2 7 2               9             11
+--R                  129060864a b c  - 201263616a b c + 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 11                  9 2 10
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 9                  7 6 8
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 7                 5 10 6
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 5                3 14 4
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 3               18 2
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                           +-----------+
+--R                2 2         2       4 4+-+ |          2 4+-+
+--R         (- 256a c  + 128a b c - 16b )\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 11                  9 2 10
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 9                  7 6 8
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          6 8 7                 5 10 6
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 5                3 14 4
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       2 16 3               18 2            20
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                          11 12                     10 2 11
+--R                      - 11258999068426240a  c   + 21955048183431168a  b c
+--R                    + 
+--R                                          9 4 10                    8 6 9
+--R                      - 16184811160862720a b c   + 3694359069327360a b c
+--R                    + 
+--R                                       7 8 8                    6 10 7
+--R                      2374945115996160a b c  - 2308974418329600a b  c
+--R                    + 
+--R                                      5 12 6                   4 14 5
+--R                      946679511515136a b  c  - 235020610437120a b  c
+--R                    + 
+--R                                     3 16 4                 2 18 3
+--R                      37623913512960a b  c  - 3822520893440a b  c
+--R                    + 
+--R                                     20 2              22
+--R                      225485783040a b  c  - 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                             5   5              4 3 4              3 5 3
+--R                  6635520000a b c  + 1260748800a b c  - 1840693248a b c
+--R                + 
+--R                              2 7 2               9             11
+--R                  - 129060864a b c  + 201263616a b c - 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 11                  9 2 10
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 9                  7 6 8
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 7                 5 10 6
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 5                3 14 4
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 3               18 2
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                         +-----------+
+--R              2 2         2       4 4+-+ |          2 4+-+
+--R         (256a c  - 128a b c + 16b )\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 11                  9 2 10
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 9                  7 6 8
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        6 8 7                 5 10 6
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 5                3 14 4
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 3               18 2            20
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         log
+--R                                          11 12                     10 2 11
+--R                      - 11258999068426240a  c   + 21955048183431168a  b c
+--R                    + 
+--R                                          9 4 10                    8 6 9
+--R                      - 16184811160862720a b c   + 3694359069327360a b c
+--R                    + 
+--R                                       7 8 8                    6 10 7
+--R                      2374945115996160a b c  - 2308974418329600a b  c
+--R                    + 
+--R                                      5 12 6                   4 14 5
+--R                      946679511515136a b  c  - 235020610437120a b  c
+--R                    + 
+--R                                     3 16 4                 2 18 3
+--R                      37623913512960a b  c  - 3822520893440a b  c
+--R                    + 
+--R                                     20 2              22
+--R                      225485783040a b  c  - 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                               5   5              4 3 4              3 5 3
+--R                  - 6635520000a b c  - 1260748800a b c  + 1840693248a b c
+--R                + 
+--R                            2 7 2               9             11
+--R                  129060864a b c  - 201263616a b c + 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 11                  9 2 10
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 9                  7 6 8
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               6 8 7                 5 10 6
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 5                3 14 4
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 3               18 2
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R            + 
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                         +-----------+
+--R              2 2         2       4 4+-+ |          2 4+-+
+--R         (512a c  - 256a b c + 32b )\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        10 11                  9 2 10
+--R                         17592186044416a  c   - 43980465111040a b c
+--R                       + 
+--R                                        8 4 9                  7 6 8
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        6 8 7                 5 10 6
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      4 12 5                3 14 4
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     2 16 3               18 2            20
+--R                         12079595520a b  c  - 671088640a b  c  + 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                        11 12                     10 2 11
+--R                      11258999068426240a  c   - 21955048183431168a  b c
+--R                    + 
+--R                                        9 4 10                    8 6 9
+--R                      16184811160862720a b c   - 3694359069327360a b c
+--R                    + 
+--R                                         7 8 8                    6 10 7
+--R                      - 2374945115996160a b c  + 2308974418329600a b  c
+--R                    + 
+--R                                        5 12 6                   4 14 5
+--R                      - 946679511515136a b  c  + 235020610437120a b  c
+--R                    + 
+--R                                       3 16 4                 2 18 3
+--R                      - 37623913512960a b  c  + 3822520893440a b  c
+--R                    + 
+--R                                       20 2              22
+--R                      - 225485783040a b  c  + 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                             5   5              4 3 4              3 5 3
+--R                  6635520000a b c  + 1260748800a b c  - 1840693248a b c
+--R                + 
+--R                              2 7 2               9             11
+--R                  - 129060864a b c  + 201263616a b c - 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               10 11                  9 2 10
+--R                                17592186044416a  c   - 43980465111040a b c
+--R                              + 
+--R                                               8 4 9                  7 6 8
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               6 8 7                 5 10 6
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             4 12 5                3 14 4
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            2 16 3               18 2
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         20
+--R                                16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                           +-----------+
+--R                2 2         2       4 4+-+ |          2 4+-+
+--R         (- 512a c  + 256a b c - 32b )\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          10 11                  9 2 10
+--R                         - 17592186044416a  c   + 43980465111040a b c
+--R                       + 
+--R                                          8 4 9                  7 6 8
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          6 8 7                 5 10 6
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        4 12 5                3 14 4
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       2 16 3               18 2            20
+--R                         - 12079595520a b  c  + 671088640a b  c  - 16777216b  c
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       15 17
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          14 2 16
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        13 4 15
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          12 6 14
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        11 8 13
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         10 10 12
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       9 12 11
+--R                              369303816355665223352320a b  c
+--R                            + 
+--R                                                         8 14 10
+--R                              - 118704798114320964648960a b  c
+--R                            + 
+--R                                                      7 16 9
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       6 18 8
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    5 20 7
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     4 22 6
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  3 24 5
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   2 26 4
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                  28 3                   30 2
+--R                              16888498602639360a b  c  - 281474976710656b  c
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   10 11                  9 2 10
+--R                     8796093022208a  c   - 21990232555520a b c
+--R                   + 
+--R                                    8 4 9                  7 6 8
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   6 8 7                 5 10 6
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  4 12 5               3 14 4
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                2 16 3               18 2           20
+--R                     6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R      *
+--R         atan
+--R                                        11 12                     10 2 11
+--R                      11258999068426240a  c   - 21955048183431168a  b c
+--R                    + 
+--R                                        9 4 10                    8 6 9
+--R                      16184811160862720a b c   - 3694359069327360a b c
+--R                    + 
+--R                                         7 8 8                    6 10 7
+--R                      - 2374945115996160a b c  + 2308974418329600a b  c
+--R                    + 
+--R                                        5 12 6                   4 14 5
+--R                      - 946679511515136a b  c  + 235020610437120a b  c
+--R                    + 
+--R                                       3 16 4                 2 18 3
+--R                      - 37623913512960a b  c  + 3822520893440a b  c
+--R                    + 
+--R                                       20 2              22
+--R                      - 225485783040a b  c  + 5905580032b  c
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    15 17
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       14 2 16
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     13 4 15
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       12 6 14
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     11 8 13
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      10 10 12
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    9 12 11
+--R                           369303816355665223352320a b  c
+--R                         + 
+--R                                                      8 14 10
+--R                           - 118704798114320964648960a b  c
+--R                         + 
+--R                                                   7 16 9
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    6 18 8
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 5 20 7
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  4 22 6
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               3 24 5
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                2 26 4
+--R                           - 472877960873902080a b  c
+--R                         + 
+--R                                               28 3                   30 2
+--R                           16888498602639360a b  c  - 281474976710656b  c
+--R                + 
+--R                               5   5              4 3 4              3 5 3
+--R                  - 6635520000a b c  - 1260748800a b c  + 1840693248a b c
+--R                + 
+--R                            2 7 2               9             11
+--R                  129060864a b c  - 201263616a b c + 24893568b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 10 11                  9 2 10
+--R                                - 17592186044416a  c   + 43980465111040a b c
+--R                              + 
+--R                                                 8 4 9                  7 6 8
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 6 8 7                 5 10 6
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               4 12 5                3 14 4
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              2 16 3               18 2
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                - 16777216b  c
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              15 17
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 14 2 16
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               13 4 15
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 12 6 14
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               11 8 13
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                10 10 12
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              9 12 11
+--R                                     369303816355665223352320a b  c
+--R                                   + 
+--R                                                                8 14 10
+--R                                     - 118704798114320964648960a b  c
+--R                                   + 
+--R                                                             7 16 9
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              6 18 8
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           5 20 7
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            4 22 6
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         3 24 5
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          2 26 4
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                         28 3
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       30 2
+--R                                     - 281474976710656b  c
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          10 11                  9 2 10
+--R                            8796093022208a  c   - 21990232555520a b c
+--R                          + 
+--R                                           8 4 9                  7 6 8
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          6 8 7                 5 10 6
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         4 12 5               3 14 4
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       2 16 3               18 2           20
+--R                            6039797760a b  c  - 335544320a b  c  + 8388608b  c
+--R           /
+--R                            4 4              3 2 3              2 4 2
+--R                  972000000a c  + 2138400000a b c  + 1639764000a b c
+--R                + 
+--R                              6             8
+--R                  533896272a b c + 61261515b
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                          +------------------+3
+--R                         +-----------+                    | +-----------+
+--R                      2  |          2                  3 4| |          2
+--R         ((60a c + 21b )\|- 4a c + b   + 108a b c + 21b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                         +-----------+
+--R                      2  |          2                  3
+--R         ((60a c + 21b )\|- 4a c + b   - 108a b c - 21b )
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                                                          +------------------+3
+--R                         +-----------+                    | +-----------+
+--R                      2  |          2                  3 4| |          2
+--R         ((60a c + 21b )\|- 4a c + b   + 108a b c + 21b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                         +-----------+
+--R                      2  |          2                  3
+--R         ((60a c + 21b )\|- 4a c + b   - 108a b c - 21b )
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R  /
+--R                                                         +--------------------+3
+--R                                       +-----------+     |   +-----------+
+--R            2 2         2       4 4+-+ |          2 4+-+4|   |          2
+--R       (512a c  - 256a b c + 32b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+3
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 688
+
+--S 689 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 689
+
+)clear all
+
+--S 690 of 1057
+t0:=x^(9/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      4 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 690
+
+--S 691 of 1057
+r0:=1/4*x^(3/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-3/16*x^(3/2)*_
+   (5*b^2-4*a*c+8*b*c*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+3/16*c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(11*b^2+_
+   20*a*c-4*b*sqrt(b^2-4*a*c))/(2^(3/4)*(b^2-4*a*c)^(5/2)*(-b+sqrt(b^2-_
+   4*a*c))^(1/4))-3/16*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(11*b^2+20*a*c-4*b*sqrt(b^2-4*a*c))/(2^(3/4)*_
+   (b^2-4*a*c)^(5/2)*(-b+sqrt(b^2-4*a*c))^(1/4))-3/16*c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(11*b^2+_
+   20*a*c+4*b*sqrt(b^2-4*a*c))/(2^(3/4)*(b^2-4*a*c)^(5/2)*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+3/16*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(11*b^2+20*a*c+4*b*sqrt(b^2-4*a*c))/(2^(3/4)*_
+   (b^2-4*a*c)^(5/2)*(-b-sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (12b c x  + 24b c x  + (24a b c + 12b )x  + 24a b x  + 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8            2      3   6
+--R           (60a c  + 33b c )x  + (120a b c  + 66b c)x
+--R         + 
+--R              2 2         2       4  4        2           3  2      3       2 2
+--R         (120a c  + 126a b c + 33b )x  + (120a b c + 66a b )x  + 60a c + 33a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                 4+-+4+-+ +-+
+--R         4+-+4| |          2                  \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (12b c x  + 24b c x  + (24a b c + 12b )x  + 24a b x  + 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8              2      3   6
+--R           (- 60a c  - 33b c )x  + (- 120a b c  - 66b c)x
+--R         + 
+--R                  2 2         2       4  4          2           3  2      3
+--R           (- 120a c  - 126a b c - 33b )x  + (- 120a b c - 66a b )x  - 60a c
+--R         + 
+--R                2 2
+--R           - 33a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                4+-+4+-+ +-+
+--R         4+-+4|   |          2                 \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R     + 
+--R                     2 8      2   6                   3  4        2 2      2
+--R             (- 12b c x  - 24b c x  + (- 24a b c - 12b )x  - 24a b x  - 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8              2      3   6
+--R           (- 60a c  - 33b c )x  + (- 120a b c  - 66b c)x
+--R         + 
+--R                  2 2         2       4  4          2           3  2      3
+--R           (- 120a c  - 126a b c - 33b )x  + (- 120a b c - 66a b )x  - 60a c
+--R         + 
+--R                2 2
+--R           - 33a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                4+-+4+-+ +-+
+--R         4+-+4| |          2                 \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R                     2 8      2   6                   3  4        2 2      2
+--R             (- 12b c x  - 24b c x  + (- 24a b c - 12b )x  - 24a b x  - 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8            2      3   6
+--R           (60a c  + 33b c )x  + (120a b c  + 66b c)x
+--R         + 
+--R              2 2         2       4  4        2           3  2      3       2 2
+--R         (120a c  + 126a b c + 33b )x  + (120a b c + 66a b )x  + 60a c + 33a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+               4+-+4+-+ +-+
+--R         4+-+4|   |          2                \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                         4| |          2
+--R                                         \|\|- 4a c + b   - b
+--R     + 
+--R                  2 7         2      2   5                   3  3
+--R           - 24b c x  + (12a c  - 39b c)x  + (- 28a b c - 11b )x
+--R         + 
+--R                 2        2
+--R           (- 20a c - 7a b )x
+--R      *
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R         4+-+3 |          2  +-+4|   |          2      4| |          2
+--R         \|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R              2 4         2 3      4 2  8        2   3         3 2      5   6
+--R         (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R       + 
+--R              3 3        4       6  4        3   2       2 3         5  2
+--R         (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R       + 
+--R             4 2       3 2       2 4
+--R         256a c  - 128a b c + 16a b
+--R    *
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R       4+-+3 |          2 4|   |          2      4| |          2
+--R       \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 691
+
+--S 692 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 4        2 3     4 2  8        2   3         3 2      5   6
+--R           (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R         + 
+--R                3 3        4      6  4        3   2       2 3         5  2
+--R           (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R         + 
+--R               4 2      3 2      2 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        11 10                  10 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        9 4 8                  8 6 7
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        7 8 6                 6 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      5 12 4                4 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     3 16 2             2 18               20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                 19   18
+--R                      16056046041756793726566400a  b c
+--R                    + 
+--R                                                   18 3 17
+--R                      - 45655839156383729926012928a  b c
+--R                    + 
+--R                                                 17 5 16
+--R                      55008485975707062271737856a  b c
+--R                    + 
+--R                                                   16 7 15
+--R                      - 34256046466736406380150784a  b c
+--R                    + 
+--R                                                15 9 14
+--R                      9069895126161512338554880a  b c
+--R                    + 
+--R                                                14 11 13
+--R                      1849101625948645453987840a  b  c
+--R                    + 
+--R                                                  13 13 12
+--R                      - 2004312530584837621284864a  b  c
+--R                    + 
+--R                                               12 15 11
+--R                      183692677485999714992128a  b  c
+--R                    + 
+--R                                               11 17 10
+--R                      422226372181633320091648a  b  c
+--R                    + 
+--R                                                 10 19 9
+--R                      - 287282098214172612362240a  b  c
+--R                    + 
+--R                                               9 21 8
+--R                      102887795935025593057280a b  c
+--R                    + 
+--R                                                8 23 7
+--R                      - 24222448466225627398144a b  c
+--R                    + 
+--R                                             7 25 6
+--R                      3917131876695055269888a b  c
+--R                    + 
+--R                                              6 27 5
+--R                      - 423730178140407857152a b  c
+--R                    + 
+--R                                           5 29 4                      4 31 3
+--R                      26664124543800442880a b  c  - 312437224148828160a b  c
+--R                    + 
+--R                                          3 33 2                    2 35
+--R                      - 94566796081758208a b  c  + 7384320092143616a b  c
+--R                    + 
+--R                                          37
+--R                      - 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                         13 13                       12 2 12
+--R                  - 13915694039040000000a  c   + 6818690079129600000a  b c
+--R                + 
+--R                                      11 4 11                       10 6 10
+--R                  4990167882399744000a  b c   - 3503999590418350080a  b c
+--R                + 
+--R                                      9 8 9                      8 10 8
+--R                  - 80287292542943232a b c  + 517958657019740160a b  c
+--R                + 
+--R                                       7 12 7                     6 14 6
+--R                  - 161825779926171648a b  c  + 24373903434448896a b  c
+--R                + 
+--R                                   5 16 5                    4 18 4
+--R                  5257449770582016a b  c  - 7082727463452672a b  c
+--R                + 
+--R                                   3 20 3                   2 22 2
+--R                  2798605408665600a b  c  - 549567398412288a b  c
+--R                + 
+--R                                   24                  26
+--R                  54481579278336a b  c - 2185854418944b
+--R             *
+--R                ROOT
+--R                                          11 10                  10 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          9 4 8                  8 6 7
+--R                           49478023249920a b c  - 32985348833280a b c
+--R                         + 
+--R                                          7 8 6                 6 10 5
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        5 12 4                4 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               11 10                  10 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               9 4 8                  8 6 7
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               7 8 6                 6 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             5 12 4                4 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            3 16 2             2 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4        2 3     4 2  8
+--R           (- 128a c  + 64a b c  - 8b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4      6  4
+--R           (- 256a b c  + 128a b c  - 16b c)x  + (- 256a c  + 48a b c - 8b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 256a b c  + 128a b c - 16a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          11 10                  10 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          9 4 8                  8 6 7
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          7 8 6                 6 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        5 12 4                4 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                 19   18
+--R                      16056046041756793726566400a  b c
+--R                    + 
+--R                                                   18 3 17
+--R                      - 45655839156383729926012928a  b c
+--R                    + 
+--R                                                 17 5 16
+--R                      55008485975707062271737856a  b c
+--R                    + 
+--R                                                   16 7 15
+--R                      - 34256046466736406380150784a  b c
+--R                    + 
+--R                                                15 9 14
+--R                      9069895126161512338554880a  b c
+--R                    + 
+--R                                                14 11 13
+--R                      1849101625948645453987840a  b  c
+--R                    + 
+--R                                                  13 13 12
+--R                      - 2004312530584837621284864a  b  c
+--R                    + 
+--R                                               12 15 11
+--R                      183692677485999714992128a  b  c
+--R                    + 
+--R                                               11 17 10
+--R                      422226372181633320091648a  b  c
+--R                    + 
+--R                                                 10 19 9
+--R                      - 287282098214172612362240a  b  c
+--R                    + 
+--R                                               9 21 8
+--R                      102887795935025593057280a b  c
+--R                    + 
+--R                                                8 23 7
+--R                      - 24222448466225627398144a b  c
+--R                    + 
+--R                                             7 25 6
+--R                      3917131876695055269888a b  c
+--R                    + 
+--R                                              6 27 5
+--R                      - 423730178140407857152a b  c
+--R                    + 
+--R                                           5 29 4                      4 31 3
+--R                      26664124543800442880a b  c  - 312437224148828160a b  c
+--R                    + 
+--R                                          3 33 2                    2 35
+--R                      - 94566796081758208a b  c  + 7384320092143616a b  c
+--R                    + 
+--R                                          37
+--R                      - 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                       13 13                       12 2 12
+--R                  13915694039040000000a  c   - 6818690079129600000a  b c
+--R                + 
+--R                                        11 4 11                       10 6 10
+--R                  - 4990167882399744000a  b c   + 3503999590418350080a  b c
+--R                + 
+--R                                    9 8 9                      8 10 8
+--R                  80287292542943232a b c  - 517958657019740160a b  c
+--R                + 
+--R                                     7 12 7                     6 14 6
+--R                  161825779926171648a b  c  - 24373903434448896a b  c
+--R                + 
+--R                                     5 16 5                    4 18 4
+--R                  - 5257449770582016a b  c  + 7082727463452672a b  c
+--R                + 
+--R                                     3 20 3                   2 22 2
+--R                  - 2798605408665600a b  c  + 549567398412288a b  c
+--R                + 
+--R                                     24                  26
+--R                  - 54481579278336a b  c + 2185854418944b
+--R             *
+--R                ROOT
+--R                                            11 10                  10 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            9 4 8                  8 6 7
+--R                           - 49478023249920a b c  + 32985348833280a b c
+--R                         + 
+--R                                            7 8 6                 6 10 5
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          5 12 4                4 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 11 10                  10 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 9 4 8                  8 6 7
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 7 8 6                 6 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               5 12 4                4 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              3 16 2             2 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                             20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 4        2 3     4 2  8        2   3         3 2      5   6
+--R           (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R         + 
+--R                3 3        4      6  4        3   2       2 3         5  2
+--R           (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R         + 
+--R               4 2      3 2      2 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          11 10                  10 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          9 4 8                  8 6 7
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          7 8 6                 6 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        5 12 4                4 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                   19   18
+--R                      - 16056046041756793726566400a  b c
+--R                    + 
+--R                                                 18 3 17
+--R                      45655839156383729926012928a  b c
+--R                    + 
+--R                                                   17 5 16
+--R                      - 55008485975707062271737856a  b c
+--R                    + 
+--R                                                 16 7 15
+--R                      34256046466736406380150784a  b c
+--R                    + 
+--R                                                  15 9 14
+--R                      - 9069895126161512338554880a  b c
+--R                    + 
+--R                                                  14 11 13
+--R                      - 1849101625948645453987840a  b  c
+--R                    + 
+--R                                                13 13 12
+--R                      2004312530584837621284864a  b  c
+--R                    + 
+--R                                                 12 15 11
+--R                      - 183692677485999714992128a  b  c
+--R                    + 
+--R                                                 11 17 10
+--R                      - 422226372181633320091648a  b  c
+--R                    + 
+--R                                               10 19 9
+--R                      287282098214172612362240a  b  c
+--R                    + 
+--R                                                 9 21 8
+--R                      - 102887795935025593057280a b  c
+--R                    + 
+--R                                              8 23 7
+--R                      24222448466225627398144a b  c
+--R                    + 
+--R                                               7 25 6
+--R                      - 3917131876695055269888a b  c
+--R                    + 
+--R                                            6 27 5                        5 29 4
+--R                      423730178140407857152a b  c  - 26664124543800442880a b  c
+--R                    + 
+--R                                         4 31 3                     3 33 2
+--R                      312437224148828160a b  c  + 94566796081758208a b  c
+--R                    + 
+--R                                         2 35                      37
+--R                      - 7384320092143616a b  c + 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                         13 13                       12 2 12
+--R                  - 13915694039040000000a  c   + 6818690079129600000a  b c
+--R                + 
+--R                                      11 4 11                       10 6 10
+--R                  4990167882399744000a  b c   - 3503999590418350080a  b c
+--R                + 
+--R                                      9 8 9                      8 10 8
+--R                  - 80287292542943232a b c  + 517958657019740160a b  c
+--R                + 
+--R                                       7 12 7                     6 14 6
+--R                  - 161825779926171648a b  c  + 24373903434448896a b  c
+--R                + 
+--R                                   5 16 5                    4 18 4
+--R                  5257449770582016a b  c  - 7082727463452672a b  c
+--R                + 
+--R                                   3 20 3                   2 22 2
+--R                  2798605408665600a b  c  - 549567398412288a b  c
+--R                + 
+--R                                   24                  26
+--R                  54481579278336a b  c - 2185854418944b
+--R             *
+--R                ROOT
+--R                                            11 10                  10 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            9 4 8                  8 6 7
+--R                           - 49478023249920a b c  + 32985348833280a b c
+--R                         + 
+--R                                            7 8 6                 6 10 5
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          5 12 4                4 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 11 10                  10 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 9 4 8                  8 6 7
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 7 8 6                 6 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               5 12 4                4 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              3 16 2             2 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                             20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4        2 3     4 2  8
+--R           (- 128a c  + 64a b c  - 8b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4      6  4
+--R           (- 256a b c  + 128a b c  - 16b c)x  + (- 256a c  + 48a b c - 8b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 256a b c  + 128a b c - 16a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        11 10                  10 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        9 4 8                  8 6 7
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        7 8 6                 6 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      5 12 4                4 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     3 16 2             2 18               20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                   19   18
+--R                      - 16056046041756793726566400a  b c
+--R                    + 
+--R                                                 18 3 17
+--R                      45655839156383729926012928a  b c
+--R                    + 
+--R                                                   17 5 16
+--R                      - 55008485975707062271737856a  b c
+--R                    + 
+--R                                                 16 7 15
+--R                      34256046466736406380150784a  b c
+--R                    + 
+--R                                                  15 9 14
+--R                      - 9069895126161512338554880a  b c
+--R                    + 
+--R                                                  14 11 13
+--R                      - 1849101625948645453987840a  b  c
+--R                    + 
+--R                                                13 13 12
+--R                      2004312530584837621284864a  b  c
+--R                    + 
+--R                                                 12 15 11
+--R                      - 183692677485999714992128a  b  c
+--R                    + 
+--R                                                 11 17 10
+--R                      - 422226372181633320091648a  b  c
+--R                    + 
+--R                                               10 19 9
+--R                      287282098214172612362240a  b  c
+--R                    + 
+--R                                                 9 21 8
+--R                      - 102887795935025593057280a b  c
+--R                    + 
+--R                                              8 23 7
+--R                      24222448466225627398144a b  c
+--R                    + 
+--R                                               7 25 6
+--R                      - 3917131876695055269888a b  c
+--R                    + 
+--R                                            6 27 5                        5 29 4
+--R                      423730178140407857152a b  c  - 26664124543800442880a b  c
+--R                    + 
+--R                                         4 31 3                     3 33 2
+--R                      312437224148828160a b  c  + 94566796081758208a b  c
+--R                    + 
+--R                                         2 35                      37
+--R                      - 7384320092143616a b  c + 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                       13 13                       12 2 12
+--R                  13915694039040000000a  c   - 6818690079129600000a  b c
+--R                + 
+--R                                        11 4 11                       10 6 10
+--R                  - 4990167882399744000a  b c   + 3503999590418350080a  b c
+--R                + 
+--R                                    9 8 9                      8 10 8
+--R                  80287292542943232a b c  - 517958657019740160a b  c
+--R                + 
+--R                                     7 12 7                     6 14 6
+--R                  161825779926171648a b  c  - 24373903434448896a b  c
+--R                + 
+--R                                     5 16 5                    4 18 4
+--R                  - 5257449770582016a b  c  + 7082727463452672a b  c
+--R                + 
+--R                                     3 20 3                   2 22 2
+--R                  - 2798605408665600a b  c  + 549567398412288a b  c
+--R                + 
+--R                                     24                  26
+--R                  - 54481579278336a b  c + 2185854418944b
+--R             *
+--R                ROOT
+--R                                          11 10                  10 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          9 4 8                  8 6 7
+--R                           49478023249920a b c  - 32985348833280a b c
+--R                         + 
+--R                                          7 8 6                 6 10 5
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        5 12 4                4 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               11 10                  10 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               9 4 8                  8 6 7
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               7 8 6                 6 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             5 12 4                4 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            3 16 2             2 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 4         2 3      4 2  8        2   3         3 2      5   6
+--R           (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R         + 
+--R                3 3        4       6  4        3   2       2 3         5  2
+--R           (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R         + 
+--R               4 2       3 2       2 4
+--R           256a c  - 128a b c + 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        11 10                  10 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        9 4 8                  8 6 7
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        7 8 6                 6 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      5 12 4                4 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     3 16 2             2 18               20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                 19   18
+--R                      16056046041756793726566400a  b c
+--R                    + 
+--R                                                   18 3 17
+--R                      - 45655839156383729926012928a  b c
+--R                    + 
+--R                                                 17 5 16
+--R                      55008485975707062271737856a  b c
+--R                    + 
+--R                                                   16 7 15
+--R                      - 34256046466736406380150784a  b c
+--R                    + 
+--R                                                15 9 14
+--R                      9069895126161512338554880a  b c
+--R                    + 
+--R                                                14 11 13
+--R                      1849101625948645453987840a  b  c
+--R                    + 
+--R                                                  13 13 12
+--R                      - 2004312530584837621284864a  b  c
+--R                    + 
+--R                                               12 15 11
+--R                      183692677485999714992128a  b  c
+--R                    + 
+--R                                               11 17 10
+--R                      422226372181633320091648a  b  c
+--R                    + 
+--R                                                 10 19 9
+--R                      - 287282098214172612362240a  b  c
+--R                    + 
+--R                                               9 21 8
+--R                      102887795935025593057280a b  c
+--R                    + 
+--R                                                8 23 7
+--R                      - 24222448466225627398144a b  c
+--R                    + 
+--R                                             7 25 6
+--R                      3917131876695055269888a b  c
+--R                    + 
+--R                                              6 27 5
+--R                      - 423730178140407857152a b  c
+--R                    + 
+--R                                           5 29 4                      4 31 3
+--R                      26664124543800442880a b  c  - 312437224148828160a b  c
+--R                    + 
+--R                                          3 33 2                    2 35
+--R                      - 94566796081758208a b  c  + 7384320092143616a b  c
+--R                    + 
+--R                                          37
+--R                      - 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                         13 13                       12 2 12
+--R                  - 13915694039040000000a  c   + 6818690079129600000a  b c
+--R                + 
+--R                                      11 4 11                       10 6 10
+--R                  4990167882399744000a  b c   - 3503999590418350080a  b c
+--R                + 
+--R                                      9 8 9                      8 10 8
+--R                  - 80287292542943232a b c  + 517958657019740160a b  c
+--R                + 
+--R                                       7 12 7                     6 14 6
+--R                  - 161825779926171648a b  c  + 24373903434448896a b  c
+--R                + 
+--R                                   5 16 5                    4 18 4
+--R                  5257449770582016a b  c  - 7082727463452672a b  c
+--R                + 
+--R                                   3 20 3                   2 22 2
+--R                  2798605408665600a b  c  - 549567398412288a b  c
+--R                + 
+--R                                   24                  26
+--R                  54481579278336a b  c - 2185854418944b
+--R             *
+--R                ROOT
+--R                                          11 10                  10 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          9 4 8                  8 6 7
+--R                           49478023249920a b c  - 32985348833280a b c
+--R                         + 
+--R                                          7 8 6                 6 10 5
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        5 12 4                4 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               11 10                  10 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               9 4 8                  8 6 7
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               7 8 6                 6 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             5 12 4                4 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            3 16 2             2 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4         2 3      4 2  8
+--R           (- 256a c  + 128a b c  - 16b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4       6  4
+--R           (- 512a b c  + 256a b c  - 32b c)x  + (- 512a c  + 96a b c - 16b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2       3 2       2 4
+--R           (- 512a b c  + 256a b c - 32a b )x  - 256a c  + 128a b c - 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          11 10                  10 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          9 4 8                  8 6 7
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          7 8 6                 6 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        5 12 4                4 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                 19   18
+--R                      16056046041756793726566400a  b c
+--R                    + 
+--R                                                   18 3 17
+--R                      - 45655839156383729926012928a  b c
+--R                    + 
+--R                                                 17 5 16
+--R                      55008485975707062271737856a  b c
+--R                    + 
+--R                                                   16 7 15
+--R                      - 34256046466736406380150784a  b c
+--R                    + 
+--R                                                15 9 14
+--R                      9069895126161512338554880a  b c
+--R                    + 
+--R                                                14 11 13
+--R                      1849101625948645453987840a  b  c
+--R                    + 
+--R                                                  13 13 12
+--R                      - 2004312530584837621284864a  b  c
+--R                    + 
+--R                                               12 15 11
+--R                      183692677485999714992128a  b  c
+--R                    + 
+--R                                               11 17 10
+--R                      422226372181633320091648a  b  c
+--R                    + 
+--R                                                 10 19 9
+--R                      - 287282098214172612362240a  b  c
+--R                    + 
+--R                                               9 21 8
+--R                      102887795935025593057280a b  c
+--R                    + 
+--R                                                8 23 7
+--R                      - 24222448466225627398144a b  c
+--R                    + 
+--R                                             7 25 6
+--R                      3917131876695055269888a b  c
+--R                    + 
+--R                                              6 27 5
+--R                      - 423730178140407857152a b  c
+--R                    + 
+--R                                           5 29 4                      4 31 3
+--R                      26664124543800442880a b  c  - 312437224148828160a b  c
+--R                    + 
+--R                                          3 33 2                    2 35
+--R                      - 94566796081758208a b  c  + 7384320092143616a b  c
+--R                    + 
+--R                                          37
+--R                      - 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                       13 13                       12 2 12
+--R                  13915694039040000000a  c   - 6818690079129600000a  b c
+--R                + 
+--R                                        11 4 11                       10 6 10
+--R                  - 4990167882399744000a  b c   + 3503999590418350080a  b c
+--R                + 
+--R                                    9 8 9                      8 10 8
+--R                  80287292542943232a b c  - 517958657019740160a b  c
+--R                + 
+--R                                     7 12 7                     6 14 6
+--R                  161825779926171648a b  c  - 24373903434448896a b  c
+--R                + 
+--R                                     5 16 5                    4 18 4
+--R                  - 5257449770582016a b  c  + 7082727463452672a b  c
+--R                + 
+--R                                     3 20 3                   2 22 2
+--R                  - 2798605408665600a b  c  + 549567398412288a b  c
+--R                + 
+--R                                     24                  26
+--R                  - 54481579278336a b  c + 2185854418944b
+--R             *
+--R                ROOT
+--R                                            11 10                  10 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            9 4 8                  8 6 7
+--R                           - 49478023249920a b c  + 32985348833280a b c
+--R                         + 
+--R                                            7 8 6                 6 10 5
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          5 12 4                4 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 11 10                  10 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 9 4 8                  8 6 7
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 7 8 6                 6 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               5 12 4                4 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              3 16 2             2 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                             20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 7         2      2   5                   3  3
+--R           - 24b c x  + (12a c  - 39b c)x  + (- 28a b c - 11b )x
+--R         + 
+--R                 2        2
+--R           (- 20a c - 7a b )x
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R            2 4         2 3      4 2  8        2   3         3 2      5   6
+--R       (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R     + 
+--R            3 3        4       6  4        3   2       2 3         5  2
+--R       (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R     + 
+--R           4 2       3 2       2 4
+--R       256a c  - 128a b c + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 692
+
+--S 693 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R              2 2        2      4 4+-+3 |          2 4|   |          2
+--R         (128a c  - 64a b c + 8b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        11 10                  10 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        9 4 8                  8 6 7
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        7 8 6                 6 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      5 12 4                4 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     3 16 2             2 18               20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                 19   18
+--R                      16056046041756793726566400a  b c
+--R                    + 
+--R                                                   18 3 17
+--R                      - 45655839156383729926012928a  b c
+--R                    + 
+--R                                                 17 5 16
+--R                      55008485975707062271737856a  b c
+--R                    + 
+--R                                                   16 7 15
+--R                      - 34256046466736406380150784a  b c
+--R                    + 
+--R                                                15 9 14
+--R                      9069895126161512338554880a  b c
+--R                    + 
+--R                                                14 11 13
+--R                      1849101625948645453987840a  b  c
+--R                    + 
+--R                                                  13 13 12
+--R                      - 2004312530584837621284864a  b  c
+--R                    + 
+--R                                               12 15 11
+--R                      183692677485999714992128a  b  c
+--R                    + 
+--R                                               11 17 10
+--R                      422226372181633320091648a  b  c
+--R                    + 
+--R                                                 10 19 9
+--R                      - 287282098214172612362240a  b  c
+--R                    + 
+--R                                               9 21 8
+--R                      102887795935025593057280a b  c
+--R                    + 
+--R                                                8 23 7
+--R                      - 24222448466225627398144a b  c
+--R                    + 
+--R                                             7 25 6
+--R                      3917131876695055269888a b  c
+--R                    + 
+--R                                              6 27 5
+--R                      - 423730178140407857152a b  c
+--R                    + 
+--R                                           5 29 4                      4 31 3
+--R                      26664124543800442880a b  c  - 312437224148828160a b  c
+--R                    + 
+--R                                          3 33 2                    2 35
+--R                      - 94566796081758208a b  c  + 7384320092143616a b  c
+--R                    + 
+--R                                          37
+--R                      - 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                         13 13                       12 2 12
+--R                  - 13915694039040000000a  c   + 6818690079129600000a  b c
+--R                + 
+--R                                      11 4 11                       10 6 10
+--R                  4990167882399744000a  b c   - 3503999590418350080a  b c
+--R                + 
+--R                                      9 8 9                      8 10 8
+--R                  - 80287292542943232a b c  + 517958657019740160a b  c
+--R                + 
+--R                                       7 12 7                     6 14 6
+--R                  - 161825779926171648a b  c  + 24373903434448896a b  c
+--R                + 
+--R                                   5 16 5                    4 18 4
+--R                  5257449770582016a b  c  - 7082727463452672a b  c
+--R                + 
+--R                                   3 20 3                   2 22 2
+--R                  2798605408665600a b  c  - 549567398412288a b  c
+--R                + 
+--R                                   24                  26
+--R                  54481579278336a b  c - 2185854418944b
+--R             *
+--R                ROOT
+--R                                          11 10                  10 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          9 4 8                  8 6 7
+--R                           49478023249920a b c  - 32985348833280a b c
+--R                         + 
+--R                                          7 8 6                 6 10 5
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        5 12 4                4 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               11 10                  10 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               9 4 8                  8 6 7
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               7 8 6                 6 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             5 12 4                4 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            3 16 2             2 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R                2 2        2      4 4+-+3 |          2 4|   |          2
+--R         (- 128a c  + 64a b c - 8b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          11 10                  10 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          9 4 8                  8 6 7
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          7 8 6                 6 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        5 12 4                4 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                 19   18
+--R                      16056046041756793726566400a  b c
+--R                    + 
+--R                                                   18 3 17
+--R                      - 45655839156383729926012928a  b c
+--R                    + 
+--R                                                 17 5 16
+--R                      55008485975707062271737856a  b c
+--R                    + 
+--R                                                   16 7 15
+--R                      - 34256046466736406380150784a  b c
+--R                    + 
+--R                                                15 9 14
+--R                      9069895126161512338554880a  b c
+--R                    + 
+--R                                                14 11 13
+--R                      1849101625948645453987840a  b  c
+--R                    + 
+--R                                                  13 13 12
+--R                      - 2004312530584837621284864a  b  c
+--R                    + 
+--R                                               12 15 11
+--R                      183692677485999714992128a  b  c
+--R                    + 
+--R                                               11 17 10
+--R                      422226372181633320091648a  b  c
+--R                    + 
+--R                                                 10 19 9
+--R                      - 287282098214172612362240a  b  c
+--R                    + 
+--R                                               9 21 8
+--R                      102887795935025593057280a b  c
+--R                    + 
+--R                                                8 23 7
+--R                      - 24222448466225627398144a b  c
+--R                    + 
+--R                                             7 25 6
+--R                      3917131876695055269888a b  c
+--R                    + 
+--R                                              6 27 5
+--R                      - 423730178140407857152a b  c
+--R                    + 
+--R                                           5 29 4                      4 31 3
+--R                      26664124543800442880a b  c  - 312437224148828160a b  c
+--R                    + 
+--R                                          3 33 2                    2 35
+--R                      - 94566796081758208a b  c  + 7384320092143616a b  c
+--R                    + 
+--R                                          37
+--R                      - 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                       13 13                       12 2 12
+--R                  13915694039040000000a  c   - 6818690079129600000a  b c
+--R                + 
+--R                                        11 4 11                       10 6 10
+--R                  - 4990167882399744000a  b c   + 3503999590418350080a  b c
+--R                + 
+--R                                    9 8 9                      8 10 8
+--R                  80287292542943232a b c  - 517958657019740160a b  c
+--R                + 
+--R                                     7 12 7                     6 14 6
+--R                  161825779926171648a b  c  - 24373903434448896a b  c
+--R                + 
+--R                                     5 16 5                    4 18 4
+--R                  - 5257449770582016a b  c  + 7082727463452672a b  c
+--R                + 
+--R                                     3 20 3                   2 22 2
+--R                  - 2798605408665600a b  c  + 549567398412288a b  c
+--R                + 
+--R                                     24                  26
+--R                  - 54481579278336a b  c + 2185854418944b
+--R             *
+--R                ROOT
+--R                                            11 10                  10 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            9 4 8                  8 6 7
+--R                           - 49478023249920a b c  + 32985348833280a b c
+--R                         + 
+--R                                            7 8 6                 6 10 5
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          5 12 4                4 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 11 10                  10 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 9 4 8                  8 6 7
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 7 8 6                 6 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               5 12 4                4 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              3 16 2             2 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                             20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R              2 2        2      4 4+-+3 |          2 4|   |          2
+--R         (128a c  - 64a b c + 8b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          11 10                  10 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          9 4 8                  8 6 7
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          7 8 6                 6 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        5 12 4                4 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                   19   18
+--R                      - 16056046041756793726566400a  b c
+--R                    + 
+--R                                                 18 3 17
+--R                      45655839156383729926012928a  b c
+--R                    + 
+--R                                                   17 5 16
+--R                      - 55008485975707062271737856a  b c
+--R                    + 
+--R                                                 16 7 15
+--R                      34256046466736406380150784a  b c
+--R                    + 
+--R                                                  15 9 14
+--R                      - 9069895126161512338554880a  b c
+--R                    + 
+--R                                                  14 11 13
+--R                      - 1849101625948645453987840a  b  c
+--R                    + 
+--R                                                13 13 12
+--R                      2004312530584837621284864a  b  c
+--R                    + 
+--R                                                 12 15 11
+--R                      - 183692677485999714992128a  b  c
+--R                    + 
+--R                                                 11 17 10
+--R                      - 422226372181633320091648a  b  c
+--R                    + 
+--R                                               10 19 9
+--R                      287282098214172612362240a  b  c
+--R                    + 
+--R                                                 9 21 8
+--R                      - 102887795935025593057280a b  c
+--R                    + 
+--R                                              8 23 7
+--R                      24222448466225627398144a b  c
+--R                    + 
+--R                                               7 25 6
+--R                      - 3917131876695055269888a b  c
+--R                    + 
+--R                                            6 27 5                        5 29 4
+--R                      423730178140407857152a b  c  - 26664124543800442880a b  c
+--R                    + 
+--R                                         4 31 3                     3 33 2
+--R                      312437224148828160a b  c  + 94566796081758208a b  c
+--R                    + 
+--R                                         2 35                      37
+--R                      - 7384320092143616a b  c + 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                         13 13                       12 2 12
+--R                  - 13915694039040000000a  c   + 6818690079129600000a  b c
+--R                + 
+--R                                      11 4 11                       10 6 10
+--R                  4990167882399744000a  b c   - 3503999590418350080a  b c
+--R                + 
+--R                                      9 8 9                      8 10 8
+--R                  - 80287292542943232a b c  + 517958657019740160a b  c
+--R                + 
+--R                                       7 12 7                     6 14 6
+--R                  - 161825779926171648a b  c  + 24373903434448896a b  c
+--R                + 
+--R                                   5 16 5                    4 18 4
+--R                  5257449770582016a b  c  - 7082727463452672a b  c
+--R                + 
+--R                                   3 20 3                   2 22 2
+--R                  2798605408665600a b  c  - 549567398412288a b  c
+--R                + 
+--R                                   24                  26
+--R                  54481579278336a b  c - 2185854418944b
+--R             *
+--R                ROOT
+--R                                            11 10                  10 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            9 4 8                  8 6 7
+--R                           - 49478023249920a b c  + 32985348833280a b c
+--R                         + 
+--R                                            7 8 6                 6 10 5
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          5 12 4                4 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 11 10                  10 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 9 4 8                  8 6 7
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 7 8 6                 6 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               5 12 4                4 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              3 16 2             2 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                             20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R                2 2        2      4 4+-+3 |          2 4|   |          2
+--R         (- 128a c  + 64a b c - 8b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        11 10                  10 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        9 4 8                  8 6 7
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        7 8 6                 6 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      5 12 4                4 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     3 16 2             2 18               20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                   19   18
+--R                      - 16056046041756793726566400a  b c
+--R                    + 
+--R                                                 18 3 17
+--R                      45655839156383729926012928a  b c
+--R                    + 
+--R                                                   17 5 16
+--R                      - 55008485975707062271737856a  b c
+--R                    + 
+--R                                                 16 7 15
+--R                      34256046466736406380150784a  b c
+--R                    + 
+--R                                                  15 9 14
+--R                      - 9069895126161512338554880a  b c
+--R                    + 
+--R                                                  14 11 13
+--R                      - 1849101625948645453987840a  b  c
+--R                    + 
+--R                                                13 13 12
+--R                      2004312530584837621284864a  b  c
+--R                    + 
+--R                                                 12 15 11
+--R                      - 183692677485999714992128a  b  c
+--R                    + 
+--R                                                 11 17 10
+--R                      - 422226372181633320091648a  b  c
+--R                    + 
+--R                                               10 19 9
+--R                      287282098214172612362240a  b  c
+--R                    + 
+--R                                                 9 21 8
+--R                      - 102887795935025593057280a b  c
+--R                    + 
+--R                                              8 23 7
+--R                      24222448466225627398144a b  c
+--R                    + 
+--R                                               7 25 6
+--R                      - 3917131876695055269888a b  c
+--R                    + 
+--R                                            6 27 5                        5 29 4
+--R                      423730178140407857152a b  c  - 26664124543800442880a b  c
+--R                    + 
+--R                                         4 31 3                     3 33 2
+--R                      312437224148828160a b  c  + 94566796081758208a b  c
+--R                    + 
+--R                                         2 35                      37
+--R                      - 7384320092143616a b  c + 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                       13 13                       12 2 12
+--R                  13915694039040000000a  c   - 6818690079129600000a  b c
+--R                + 
+--R                                        11 4 11                       10 6 10
+--R                  - 4990167882399744000a  b c   + 3503999590418350080a  b c
+--R                + 
+--R                                    9 8 9                      8 10 8
+--R                  80287292542943232a b c  - 517958657019740160a b  c
+--R                + 
+--R                                     7 12 7                     6 14 6
+--R                  161825779926171648a b  c  - 24373903434448896a b  c
+--R                + 
+--R                                     5 16 5                    4 18 4
+--R                  - 5257449770582016a b  c  + 7082727463452672a b  c
+--R                + 
+--R                                     3 20 3                   2 22 2
+--R                  - 2798605408665600a b  c  + 549567398412288a b  c
+--R                + 
+--R                                     24                  26
+--R                  - 54481579278336a b  c + 2185854418944b
+--R             *
+--R                ROOT
+--R                                          11 10                  10 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          9 4 8                  8 6 7
+--R                           49478023249920a b c  - 32985348833280a b c
+--R                         + 
+--R                                          7 8 6                 6 10 5
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        5 12 4                4 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               11 10                  10 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               9 4 8                  8 6 7
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               7 8 6                 6 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             5 12 4                4 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            3 16 2             2 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R              2 2         2       4 4+-+3 |          2 4|   |          2
+--R         (256a c  - 128a b c + 16b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        11 10                  10 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        9 4 8                  8 6 7
+--R                         49478023249920a b c  - 32985348833280a b c
+--R                       + 
+--R                                        7 8 6                 6 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      5 12 4                4 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     3 16 2             2 18               20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                 19   18
+--R                      16056046041756793726566400a  b c
+--R                    + 
+--R                                                   18 3 17
+--R                      - 45655839156383729926012928a  b c
+--R                    + 
+--R                                                 17 5 16
+--R                      55008485975707062271737856a  b c
+--R                    + 
+--R                                                   16 7 15
+--R                      - 34256046466736406380150784a  b c
+--R                    + 
+--R                                                15 9 14
+--R                      9069895126161512338554880a  b c
+--R                    + 
+--R                                                14 11 13
+--R                      1849101625948645453987840a  b  c
+--R                    + 
+--R                                                  13 13 12
+--R                      - 2004312530584837621284864a  b  c
+--R                    + 
+--R                                               12 15 11
+--R                      183692677485999714992128a  b  c
+--R                    + 
+--R                                               11 17 10
+--R                      422226372181633320091648a  b  c
+--R                    + 
+--R                                                 10 19 9
+--R                      - 287282098214172612362240a  b  c
+--R                    + 
+--R                                               9 21 8
+--R                      102887795935025593057280a b  c
+--R                    + 
+--R                                                8 23 7
+--R                      - 24222448466225627398144a b  c
+--R                    + 
+--R                                             7 25 6
+--R                      3917131876695055269888a b  c
+--R                    + 
+--R                                              6 27 5
+--R                      - 423730178140407857152a b  c
+--R                    + 
+--R                                           5 29 4                      4 31 3
+--R                      26664124543800442880a b  c  - 312437224148828160a b  c
+--R                    + 
+--R                                          3 33 2                    2 35
+--R                      - 94566796081758208a b  c  + 7384320092143616a b  c
+--R                    + 
+--R                                          37
+--R                      - 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                         13 13                       12 2 12
+--R                  - 13915694039040000000a  c   + 6818690079129600000a  b c
+--R                + 
+--R                                      11 4 11                       10 6 10
+--R                  4990167882399744000a  b c   - 3503999590418350080a  b c
+--R                + 
+--R                                      9 8 9                      8 10 8
+--R                  - 80287292542943232a b c  + 517958657019740160a b  c
+--R                + 
+--R                                       7 12 7                     6 14 6
+--R                  - 161825779926171648a b  c  + 24373903434448896a b  c
+--R                + 
+--R                                   5 16 5                    4 18 4
+--R                  5257449770582016a b  c  - 7082727463452672a b  c
+--R                + 
+--R                                   3 20 3                   2 22 2
+--R                  2798605408665600a b  c  - 549567398412288a b  c
+--R                + 
+--R                                   24                  26
+--R                  54481579278336a b  c - 2185854418944b
+--R             *
+--R                ROOT
+--R                                          11 10                  10 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          9 4 8                  8 6 7
+--R                           49478023249920a b c  - 32985348833280a b c
+--R                         + 
+--R                                          7 8 6                 6 10 5
+--R                           14431090114560a b c  - 4329327034368a b  c
+--R                         + 
+--R                                        5 12 4                4 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               11 10                  10 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               9 4 8                  8 6 7
+--R                                49478023249920a b c  - 32985348833280a b c
+--R                              + 
+--R                                               7 8 6                 6 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             5 12 4                4 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            3 16 2             2 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                           20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                          +--------------------+
+--R                                            +-----------+ |   +-----------+
+--R                2 2         2       4 4+-+3 |          2 4|   |          2
+--R         (- 256a c  + 128a b c - 16b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          11 10                  10 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          9 4 8                  8 6 7
+--R                         - 49478023249920a b c  + 32985348833280a b c
+--R                       + 
+--R                                          7 8 6                 6 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        5 12 4                4 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                             4 4                 3 2 3
+--R                              - 656100000000a c  - 1233468000000a b c
+--R                            + 
+--R                                             2 4 2                  6
+--R                              - 894789180000a b c  - 296155666800a b c
+--R                            + 
+--R                                            8
+--R                              - 37822859361b
+--R                         /
+--R                                                       17 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          16 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        15 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          14 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        13 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         12 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       11 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         10 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      9 16 7
+--R                              29676199528580241162240a b  c
+--R                            + 
+--R                                                       8 18 6
+--R                              - 5770372130557269114880a b  c
+--R                            + 
+--R                                                    7 20 5
+--R                              865555819583590367232a b  c
+--R                            + 
+--R                                                     6 22 4
+--R                              - 98358615861771632640a b  c
+--R                            + 
+--R                                                  5 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   4 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                3 28                    2 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                                4   4            3 3 3            2 5 2
+--R                     - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                   + 
+--R                                 7           9
+--R                     - 7017840a b c - 194481b
+--R                /
+--R                                   11 10                  10 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    9 4 8                  8 6 7
+--R                     24739011624960a b c  - 16492674416640a b c
+--R                   + 
+--R                                   7 8 6                 6 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  5 12 4               4 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                3 16 2             2 18              20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                 19   18
+--R                      16056046041756793726566400a  b c
+--R                    + 
+--R                                                   18 3 17
+--R                      - 45655839156383729926012928a  b c
+--R                    + 
+--R                                                 17 5 16
+--R                      55008485975707062271737856a  b c
+--R                    + 
+--R                                                   16 7 15
+--R                      - 34256046466736406380150784a  b c
+--R                    + 
+--R                                                15 9 14
+--R                      9069895126161512338554880a  b c
+--R                    + 
+--R                                                14 11 13
+--R                      1849101625948645453987840a  b  c
+--R                    + 
+--R                                                  13 13 12
+--R                      - 2004312530584837621284864a  b  c
+--R                    + 
+--R                                               12 15 11
+--R                      183692677485999714992128a  b  c
+--R                    + 
+--R                                               11 17 10
+--R                      422226372181633320091648a  b  c
+--R                    + 
+--R                                                 10 19 9
+--R                      - 287282098214172612362240a  b  c
+--R                    + 
+--R                                               9 21 8
+--R                      102887795935025593057280a b  c
+--R                    + 
+--R                                                8 23 7
+--R                      - 24222448466225627398144a b  c
+--R                    + 
+--R                                             7 25 6
+--R                      3917131876695055269888a b  c
+--R                    + 
+--R                                              6 27 5
+--R                      - 423730178140407857152a b  c
+--R                    + 
+--R                                           5 29 4                      4 31 3
+--R                      26664124543800442880a b  c  - 312437224148828160a b  c
+--R                    + 
+--R                                          3 33 2                    2 35
+--R                      - 94566796081758208a b  c  + 7384320092143616a b  c
+--R                    + 
+--R                                          37
+--R                      - 188566244163584a b
+--R                 *
+--R                    ROOT
+--R                                          4 4                 3 2 3
+--R                           - 656100000000a c  - 1233468000000a b c
+--R                         + 
+--R                                          2 4 2                  6
+--R                           - 894789180000a b c  - 296155666800a b c
+--R                         + 
+--R                                         8
+--R                           - 37822859361b
+--R                      /
+--R                                                    17 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       16 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     15 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       14 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     13 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      12 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    11 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      10 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   9 16 7
+--R                           29676199528580241162240a b  c
+--R                         + 
+--R                                                    8 18 6
+--R                           - 5770372130557269114880a b  c
+--R                         + 
+--R                                                 7 20 5
+--R                           865555819583590367232a b  c
+--R                         + 
+--R                                                  6 22 4
+--R                           - 98358615861771632640a b  c
+--R                         + 
+--R                                               5 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                4 26 2                     3 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             2 30
+--R                           - 281474976710656a b
+--R                + 
+--R                                       13 13                       12 2 12
+--R                  13915694039040000000a  c   - 6818690079129600000a  b c
+--R                + 
+--R                                        11 4 11                       10 6 10
+--R                  - 4990167882399744000a  b c   + 3503999590418350080a  b c
+--R                + 
+--R                                    9 8 9                      8 10 8
+--R                  80287292542943232a b c  - 517958657019740160a b  c
+--R                + 
+--R                                     7 12 7                     6 14 6
+--R                  161825779926171648a b  c  - 24373903434448896a b  c
+--R                + 
+--R                                     5 16 5                    4 18 4
+--R                  - 5257449770582016a b  c  + 7082727463452672a b  c
+--R                + 
+--R                                     3 20 3                   2 22 2
+--R                  - 2798605408665600a b  c  + 549567398412288a b  c
+--R                + 
+--R                                     24                  26
+--R                  - 54481579278336a b  c + 2185854418944b
+--R             *
+--R                ROOT
+--R                                            11 10                  10 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            9 4 8                  8 6 7
+--R                           - 49478023249920a b c  + 32985348833280a b c
+--R                         + 
+--R                                            7 8 6                 6 10 5
+--R                           - 14431090114560a b c  + 4329327034368a b  c
+--R                         + 
+--R                                          5 12 4                4 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       3 16 2             2 18               20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                               4 4                 3 2 3
+--R                                - 656100000000a c  - 1233468000000a b c
+--R                              + 
+--R                                               2 4 2                  6
+--R                                - 894789180000a b c  - 296155666800a b c
+--R                              + 
+--R                                              8
+--R                                - 37822859361b
+--R                           /
+--R                                                         17 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            16 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          15 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            14 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          13 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           12 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         11 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           10 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        9 16 7
+--R                                29676199528580241162240a b  c
+--R                              + 
+--R                                                         8 18 6
+--R                                - 5770372130557269114880a b  c
+--R                              + 
+--R                                                      7 20 5
+--R                                865555819583590367232a b  c
+--R                              + 
+--R                                                       6 22 4
+--R                                - 98358615861771632640a b  c
+--R                              + 
+--R                                                    5 24 3
+--R                                8196551321814302720a b  c
+--R                              + 
+--R                                                     4 26 2
+--R                                - 472877960873902080a b  c
+--R                              + 
+--R                                                  3 28                    2 30
+--R                                16888498602639360a b  c - 281474976710656a b
+--R                     + 
+--R                                  4   4            3 3 3            2 5 2
+--R                       - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                     + 
+--R                                   7           9
+--R                       - 7017840a b c - 194481b
+--R                  /
+--R                                     11 10                  10 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      9 4 8                  8 6 7
+--R                       24739011624960a b c  - 16492674416640a b c
+--R                     + 
+--R                                     7 8 6                 6 10 5
+--R                       7215545057280a b c  - 2164663517184a b  c
+--R                     + 
+--R                                    5 12 4               4 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  3 16 2             2 18              20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 11 10                  10 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 9 4 8                  8 6 7
+--R                                - 49478023249920a b c  + 32985348833280a b c
+--R                              + 
+--R                                                 7 8 6                 6 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               5 12 4                4 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              3 16 2             2 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                             20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                    4 4                 3 2 3
+--R                                     - 656100000000a c  - 1233468000000a b c
+--R                                   + 
+--R                                                    2 4 2                  6
+--R                                     - 894789180000a b c  - 296155666800a b c
+--R                                   + 
+--R                                                   8
+--R                                     - 37822859361b
+--R                                /
+--R                                                              17 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 16 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               15 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 14 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               13 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                12 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              11 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                10 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             9 16 7
+--R                                     29676199528580241162240a b  c
+--R                                   + 
+--R                                                              8 18 6
+--R                                     - 5770372130557269114880a b  c
+--R                                   + 
+--R                                                           7 20 5
+--R                                     865555819583590367232a b  c
+--R                                   + 
+--R                                                            6 22 4
+--R                                     - 98358615861771632640a b  c
+--R                                   + 
+--R                                                         5 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          4 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       3 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       2 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                       4   4            3 3 3            2 5 2
+--R                            - 54432000a b c  - 67495680a b c  - 33475680a b c
+--R                          + 
+--R                                        7           9
+--R                            - 7017840a b c - 194481b
+--R                       /
+--R                                          11 10                  10 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           9 4 8                  8 6 7
+--R                            24739011624960a b c  - 16492674416640a b c
+--R                          + 
+--R                                          7 8 6                 6 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         5 12 4               4 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       3 16 2             2 18              20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                                   8 9                    7 2 8
+--R                  1399680000000000a c  + 6606489600000000a b c
+--R                + 
+--R                                    6 4 7                     5 6 6
+--R                  13078050048000000a b c  + 14150395284480000a b c
+--R                + 
+--R                                   4 8 5                    3 10 4
+--R                  9147418591449600a b c  + 3620651461959168a b  c
+--R                + 
+--R                                  2 12 3                     14 2
+--R                  857640166044480a b  c  + 111331126317600a b  c
+--R                + 
+--R                                16
+--R                  6078673825875b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                  +------------------+
+--R                +-----------+                     | +-----------+
+--R                |          2               2 4+-+4| |          2
+--R         (- 12b\|- 4a c + b   - 60a c - 33b )\|c \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                  +--------------------+
+--R                +-----------+                     |   +-----------+
+--R                |          2               2 4+-+4|   |          2
+--R         (- 12b\|- 4a c + b   + 60a c + 33b )\|c \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                                +------------------+
+--R              +-----------+                     | +-----------+
+--R              |          2               2 4+-+4| |          2
+--R         (12b\|- 4a c + b   + 60a c + 33b )\|c \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                                +--------------------+
+--R              +-----------+                     |   +-----------+
+--R              |          2               2 4+-+4|   |          2
+--R         (12b\|- 4a c + b   - 60a c - 33b )\|c \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R            2 2         2       4 4+-+3 |          2 4|   |          2
+--R       (256a c  - 128a b c + 16b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 693
+
+--S 694 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 694
+
+)clear all
+
+--S 695 of 1057
+t0:=x^(7/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 1057
+r0:=-1/16*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (41*b^2+28*a*c-36*b*sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)^(5/2)*_
+   (-b+sqrt(b^2-4*a*c))^(3/4))-1/16*c^(3/4)*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(41*b^2+28*a*c-36*b*sqrt(b^2-_
+   4*a*c))/(2^(1/4)*(b^2-4*a*c)^(5/2)*(-b+sqrt(b^2-4*a*c))^(3/4))+_
+   1/16*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (41*b^2+28*a*c+36*b*sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)^(5/2)*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))+1/16*c^(3/4)*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(41*b^2+28*a*c+36*b*sqrt(b^2-4*a*c))/_
+   (2^(1/4)*(b^2-4*a*c)^(5/2)*(-b-sqrt(b^2-4*a*c))^(3/4))+1/4*(2*a+b*x^2)*_
+   sqrt(x)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-1/16*(13*b^2-4*a*c+_
+   24*b*c*x^2)*sqrt(x)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (36b c x  + 72b c x  + (72a b c + 36b )x  + 72a b x  + 36a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8           2      3   6
+--R           (28a c  + 41b c )x  + (56a b c  + 82b c)x
+--R         + 
+--R               2 2         2       4  4       2           3  2      3       2 2
+--R           (56a c  + 110a b c + 41b )x  + (56a b c + 82a b )x  + 28a c + 41a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                  4+-+4+-+ +-+
+--R         4+-+3 4| |          2                   \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (36b c x  + 72b c x  + (72a b c + 36b )x  + 72a b x  + 36a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8             2      3   6
+--R           (- 28a c  - 41b c )x  + (- 56a b c  - 82b c)x
+--R         + 
+--R                 2 2         2       4  4         2           3  2      3
+--R           (- 56a c  - 110a b c - 41b )x  + (- 56a b c - 82a b )x  - 28a c
+--R         + 
+--R                2 2
+--R           - 41a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                  \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (36b c x  + 72b c x  + (72a b c + 36b )x  + 72a b x  + 36a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8           2      3   6
+--R           (28a c  + 41b c )x  + (56a b c  + 82b c)x
+--R         + 
+--R               2 2         2       4  4       2           3  2      3       2 2
+--R           (56a c  + 110a b c + 41b )x  + (56a b c + 82a b )x  + 28a c + 41a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4| |          2                  \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (36b c x  + 72b c x  + (72a b c + 36b )x  + 72a b x  + 36a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8             2      3   6
+--R           (- 28a c  - 41b c )x  + (- 56a b c  - 82b c)x
+--R         + 
+--R                 2 2         2       4  4         2           3  2      3
+--R           (- 56a c  - 110a b c - 41b )x  + (- 56a b c - 82a b )x  - 28a c
+--R         + 
+--R                2 2
+--R           - 41a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                 \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R     + 
+--R                 2 6        2      2   4                  3  2      2        2
+--R         (- 24b c x  + (4a c  - 37b c)x  + (- 36a b c - 9b )x  - 28a c - 5a b )
+--R      *
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2  +-+4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              2 4         2 3      4 2  8        2   3         3 2      5   6
+--R         (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R       + 
+--R              3 3        4       6  4        3   2       2 3         5  2
+--R         (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R       + 
+--R             4 2       3 2       2 4
+--R         256a c  - 128a b c + 16a b
+--R    *
+--R                          +--------------------+3  +------------------+3
+--R            +-----------+ |   +-----------+        | +-----------+
+--R       4+-+ |          2 4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 4        2 3     4 2  8        2   3         3 2      5   6
+--R           (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R         + 
+--R                3 3        4      6  4        3   2       2 3         5  2
+--R           (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R         + 
+--R               4 2      3 2      2 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        13 10                  12 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        11 4 8                  10 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        9 8 6                 8 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      7 12 4                6 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     5 16 2             4 18             3 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                        14   11                      13 3 10
+--R                      48413695994232832a  b c   - 119626865102028800a  b c
+--R                    + 
+--R                                         12 5 9                     11 7 8
+--R                      132645082774896640a  b c  - 86817438129192960a  b c
+--R                    + 
+--R                                        10 9 7                     9 11 6
+--R                      37075532088606720a  b c  - 10759820789415936a b  c
+--R                    + 
+--R                                       8 13 5                   7 15 4
+--R                      2135801336954880a b  c  - 282437049384960a b  c
+--R                    + 
+--R                                     6 17 3                5 19 2
+--R                      22935125360640a b  c  - 880468295680a b  c
+--R                    + 
+--R                                   4 21               3 23
+--R                      - 7516192768a b  c + 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                             7 7               6 2 6               5 4 5
+--R                  1101463552a c  - 55421599744a b c  + 29809790976a b c
+--R                + 
+--R                               4 6 4              3 8 3             2 10 2
+--R                  - 2042667008a b c  - 1054785280a b c  + 124080000a b  c
+--R                + 
+--R                            12          14
+--R                  4030000a b  c + 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               13 10                  12 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               11 4 8                  10 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               9 8 6                 8 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             7 12 4                6 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            5 16 2             4 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         3 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4        2 3     4 2  8
+--R           (- 128a c  + 64a b c  - 8b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4      6  4
+--R           (- 256a b c  + 128a b c  - 16b c)x  + (- 256a c  + 48a b c - 8b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 256a b c  + 128a b c - 16a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          13 10                  12 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          11 4 8                  10 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          9 8 6                 8 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        7 12 4                6 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       5 16 2             4 18             3 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                        14   11                      13 3 10
+--R                      48413695994232832a  b c   - 119626865102028800a  b c
+--R                    + 
+--R                                         12 5 9                     11 7 8
+--R                      132645082774896640a  b c  - 86817438129192960a  b c
+--R                    + 
+--R                                        10 9 7                     9 11 6
+--R                      37075532088606720a  b c  - 10759820789415936a b  c
+--R                    + 
+--R                                       8 13 5                   7 15 4
+--R                      2135801336954880a b  c  - 282437049384960a b  c
+--R                    + 
+--R                                     6 17 3                5 19 2
+--R                      22935125360640a b  c  - 880468295680a b  c
+--R                    + 
+--R                                   4 21               3 23
+--R                      - 7516192768a b  c + 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                               7 7               6 2 6               5 4 5
+--R                  - 1101463552a c  + 55421599744a b c  - 29809790976a b c
+--R                + 
+--R                             4 6 4              3 8 3             2 10 2
+--R                  2042667008a b c  + 1054785280a b c  - 124080000a b  c
+--R                + 
+--R                              12          14
+--R                  - 4030000a b  c - 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 13 10                  12 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 11 4 8                  10 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 9 8 6                 8 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               7 12 4                6 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              5 16 2             4 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           3 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 4        2 3     4 2  8        2   3         3 2      5   6
+--R           (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R         + 
+--R                3 3        4      6  4        3   2       2 3         5  2
+--R           (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R         + 
+--R               4 2      3 2      2 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          13 10                  12 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          11 4 8                  10 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          9 8 6                 8 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        7 12 4                6 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       5 16 2             4 18             3 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                          14   11                      13 3 10
+--R                      - 48413695994232832a  b c   + 119626865102028800a  b c
+--R                    + 
+--R                                           12 5 9                     11 7 8
+--R                      - 132645082774896640a  b c  + 86817438129192960a  b c
+--R                    + 
+--R                                          10 9 7                     9 11 6
+--R                      - 37075532088606720a  b c  + 10759820789415936a b  c
+--R                    + 
+--R                                         8 13 5                   7 15 4
+--R                      - 2135801336954880a b  c  + 282437049384960a b  c
+--R                    + 
+--R                                       6 17 3                5 19 2
+--R                      - 22935125360640a b  c  + 880468295680a b  c
+--R                    + 
+--R                                 4 21               3 23
+--R                      7516192768a b  c - 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                             7 7               6 2 6               5 4 5
+--R                  1101463552a c  - 55421599744a b c  + 29809790976a b c
+--R                + 
+--R                               4 6 4              3 8 3             2 10 2
+--R                  - 2042667008a b c  - 1054785280a b c  + 124080000a b  c
+--R                + 
+--R                            12          14
+--R                  4030000a b  c + 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 13 10                  12 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 11 4 8                  10 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 9 8 6                 8 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               7 12 4                6 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              5 16 2             4 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           3 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4        2 3     4 2  8
+--R           (- 128a c  + 64a b c  - 8b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4      6  4
+--R           (- 256a b c  + 128a b c  - 16b c)x  + (- 256a c  + 48a b c - 8b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 256a b c  + 128a b c - 16a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        13 10                  12 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        11 4 8                  10 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        9 8 6                 8 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      7 12 4                6 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     5 16 2             4 18             3 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                          14   11                      13 3 10
+--R                      - 48413695994232832a  b c   + 119626865102028800a  b c
+--R                    + 
+--R                                           12 5 9                     11 7 8
+--R                      - 132645082774896640a  b c  + 86817438129192960a  b c
+--R                    + 
+--R                                          10 9 7                     9 11 6
+--R                      - 37075532088606720a  b c  + 10759820789415936a b  c
+--R                    + 
+--R                                         8 13 5                   7 15 4
+--R                      - 2135801336954880a b  c  + 282437049384960a b  c
+--R                    + 
+--R                                       6 17 3                5 19 2
+--R                      - 22935125360640a b  c  + 880468295680a b  c
+--R                    + 
+--R                                 4 21               3 23
+--R                      7516192768a b  c - 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                               7 7               6 2 6               5 4 5
+--R                  - 1101463552a c  + 55421599744a b c  - 29809790976a b c
+--R                + 
+--R                             4 6 4              3 8 3             2 10 2
+--R                  2042667008a b c  + 1054785280a b c  - 124080000a b  c
+--R                + 
+--R                              12          14
+--R                  - 4030000a b  c - 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               13 10                  12 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               11 4 8                  10 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               9 8 6                 8 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             7 12 4                6 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            5 16 2             4 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         3 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  2 4         2 3      4 2  8
+--R           (- 256a c  + 128a b c  - 16b c )x
+--R         + 
+--R                  2   3         3 2      5   6          3 3        4       6  4
+--R           (- 512a b c  + 256a b c  - 32b c)x  + (- 512a c  + 96a b c - 16b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2       3 2       2 4
+--R           (- 512a b c  + 256a b c - 32a b )x  - 256a c  + 128a b c - 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        13 10                  12 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        11 4 8                  10 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        9 8 6                 8 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      7 12 4                6 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     5 16 2             4 18             3 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                        14   11                      13 3 10
+--R                      48413695994232832a  b c   - 119626865102028800a  b c
+--R                    + 
+--R                                         12 5 9                     11 7 8
+--R                      132645082774896640a  b c  - 86817438129192960a  b c
+--R                    + 
+--R                                        10 9 7                     9 11 6
+--R                      37075532088606720a  b c  - 10759820789415936a b  c
+--R                    + 
+--R                                       8 13 5                   7 15 4
+--R                      2135801336954880a b  c  - 282437049384960a b  c
+--R                    + 
+--R                                     6 17 3                5 19 2
+--R                      22935125360640a b  c  - 880468295680a b  c
+--R                    + 
+--R                                   4 21               3 23
+--R                      - 7516192768a b  c + 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                             7 7               6 2 6               5 4 5
+--R                  1101463552a c  - 55421599744a b c  + 29809790976a b c
+--R                + 
+--R                               4 6 4              3 8 3             2 10 2
+--R                  - 2042667008a b c  - 1054785280a b c  + 124080000a b  c
+--R                + 
+--R                            12          14
+--R                  4030000a b  c + 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               13 10                  12 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               11 4 8                  10 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               9 8 6                 8 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             7 12 4                6 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            5 16 2             4 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         3 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                2 4         2 3      4 2  8        2   3         3 2      5   6
+--R           (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R         + 
+--R                3 3        4       6  4        3   2       2 3         5  2
+--R           (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R         + 
+--R               4 2       3 2       2 4
+--R           256a c  - 128a b c + 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          13 10                  12 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          11 4 8                  10 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          9 8 6                 8 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        7 12 4                6 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       5 16 2             4 18             3 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                        14   11                      13 3 10
+--R                      48413695994232832a  b c   - 119626865102028800a  b c
+--R                    + 
+--R                                         12 5 9                     11 7 8
+--R                      132645082774896640a  b c  - 86817438129192960a  b c
+--R                    + 
+--R                                        10 9 7                     9 11 6
+--R                      37075532088606720a  b c  - 10759820789415936a b  c
+--R                    + 
+--R                                       8 13 5                   7 15 4
+--R                      2135801336954880a b  c  - 282437049384960a b  c
+--R                    + 
+--R                                     6 17 3                5 19 2
+--R                      22935125360640a b  c  - 880468295680a b  c
+--R                    + 
+--R                                   4 21               3 23
+--R                      - 7516192768a b  c + 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                               7 7               6 2 6               5 4 5
+--R                  - 1101463552a c  + 55421599744a b c  - 29809790976a b c
+--R                + 
+--R                             4 6 4              3 8 3             2 10 2
+--R                  2042667008a b c  + 1054785280a b c  - 124080000a b  c
+--R                + 
+--R                              12          14
+--R                  - 4030000a b  c - 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 13 10                  12 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 11 4 8                  10 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 9 8 6                 8 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               7 12 4                6 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              5 16 2             4 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           3 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R             2 6        2      2   4                  3  2      2        2  +-+
+--R     (- 24b c x  + (4a c  - 37b c)x  + (- 36a b c - 9b )x  - 28a c - 5a b )\|x
+--R  /
+--R            2 4         2 3      4 2  8        2   3         3 2      5   6
+--R       (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R     + 
+--R            3 3        4       6  4        3   2       2 3         5  2
+--R       (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R     + 
+--R           4 2       3 2       2 4
+--R       256a c  - 128a b c + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 697
+
+--S 698 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                     +--------------------+3
+--R                                       +-----------+ |   +-----------+
+--R              2 2        2      4 4+-+ |          2 4|   |          2
+--R         (128a c  - 64a b c + 8b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        13 10                  12 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        11 4 8                  10 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        9 8 6                 8 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      7 12 4                6 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     5 16 2             4 18             3 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                        14   11                      13 3 10
+--R                      48413695994232832a  b c   - 119626865102028800a  b c
+--R                    + 
+--R                                         12 5 9                     11 7 8
+--R                      132645082774896640a  b c  - 86817438129192960a  b c
+--R                    + 
+--R                                        10 9 7                     9 11 6
+--R                      37075532088606720a  b c  - 10759820789415936a b  c
+--R                    + 
+--R                                       8 13 5                   7 15 4
+--R                      2135801336954880a b  c  - 282437049384960a b  c
+--R                    + 
+--R                                     6 17 3                5 19 2
+--R                      22935125360640a b  c  - 880468295680a b  c
+--R                    + 
+--R                                   4 21               3 23
+--R                      - 7516192768a b  c + 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                             7 7               6 2 6               5 4 5
+--R                  1101463552a c  - 55421599744a b c  + 29809790976a b c
+--R                + 
+--R                               4 6 4              3 8 3             2 10 2
+--R                  - 2042667008a b c  - 1054785280a b c  + 124080000a b  c
+--R                + 
+--R                            12          14
+--R                  4030000a b  c + 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               13 10                  12 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               11 4 8                  10 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               9 8 6                 8 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             7 12 4                6 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            5 16 2             4 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         3 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                       +--------------------+3
+--R                                         +-----------+ |   +-----------+
+--R                2 2        2      4 4+-+ |          2 4|   |          2
+--R         (- 128a c  + 64a b c - 8b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          13 10                  12 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          11 4 8                  10 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          9 8 6                 8 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        7 12 4                6 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       5 16 2             4 18             3 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                        14   11                      13 3 10
+--R                      48413695994232832a  b c   - 119626865102028800a  b c
+--R                    + 
+--R                                         12 5 9                     11 7 8
+--R                      132645082774896640a  b c  - 86817438129192960a  b c
+--R                    + 
+--R                                        10 9 7                     9 11 6
+--R                      37075532088606720a  b c  - 10759820789415936a b  c
+--R                    + 
+--R                                       8 13 5                   7 15 4
+--R                      2135801336954880a b  c  - 282437049384960a b  c
+--R                    + 
+--R                                     6 17 3                5 19 2
+--R                      22935125360640a b  c  - 880468295680a b  c
+--R                    + 
+--R                                   4 21               3 23
+--R                      - 7516192768a b  c + 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                               7 7               6 2 6               5 4 5
+--R                  - 1101463552a c  + 55421599744a b c  - 29809790976a b c
+--R                + 
+--R                             4 6 4              3 8 3             2 10 2
+--R                  2042667008a b c  + 1054785280a b c  - 124080000a b  c
+--R                + 
+--R                              12          14
+--R                  - 4030000a b  c - 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 13 10                  12 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 11 4 8                  10 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 9 8 6                 8 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               7 12 4                6 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              5 16 2             4 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           3 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                     +--------------------+3
+--R                                       +-----------+ |   +-----------+
+--R              2 2        2      4 4+-+ |          2 4|   |          2
+--R         (128a c  - 64a b c + 8b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          13 10                  12 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          11 4 8                  10 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          9 8 6                 8 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        7 12 4                6 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       5 16 2             4 18             3 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                          14   11                      13 3 10
+--R                      - 48413695994232832a  b c   + 119626865102028800a  b c
+--R                    + 
+--R                                           12 5 9                     11 7 8
+--R                      - 132645082774896640a  b c  + 86817438129192960a  b c
+--R                    + 
+--R                                          10 9 7                     9 11 6
+--R                      - 37075532088606720a  b c  + 10759820789415936a b  c
+--R                    + 
+--R                                         8 13 5                   7 15 4
+--R                      - 2135801336954880a b  c  + 282437049384960a b  c
+--R                    + 
+--R                                       6 17 3                5 19 2
+--R                      - 22935125360640a b  c  + 880468295680a b  c
+--R                    + 
+--R                                 4 21               3 23
+--R                      7516192768a b  c - 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                             7 7               6 2 6               5 4 5
+--R                  1101463552a c  - 55421599744a b c  + 29809790976a b c
+--R                + 
+--R                               4 6 4              3 8 3             2 10 2
+--R                  - 2042667008a b c  - 1054785280a b c  + 124080000a b  c
+--R                + 
+--R                            12          14
+--R                  4030000a b  c + 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 13 10                  12 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 11 4 8                  10 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 9 8 6                 8 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               7 12 4                6 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              5 16 2             4 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           3 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                       +--------------------+3
+--R                                         +-----------+ |   +-----------+
+--R                2 2        2      4 4+-+ |          2 4|   |          2
+--R         (- 128a c  + 64a b c - 8b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        13 10                  12 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        11 4 8                  10 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        9 8 6                 8 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      7 12 4                6 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     5 16 2             4 18             3 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                          14   11                      13 3 10
+--R                      - 48413695994232832a  b c   + 119626865102028800a  b c
+--R                    + 
+--R                                           12 5 9                     11 7 8
+--R                      - 132645082774896640a  b c  + 86817438129192960a  b c
+--R                    + 
+--R                                          10 9 7                     9 11 6
+--R                      - 37075532088606720a  b c  + 10759820789415936a b  c
+--R                    + 
+--R                                         8 13 5                   7 15 4
+--R                      - 2135801336954880a b  c  + 282437049384960a b  c
+--R                    + 
+--R                                       6 17 3                5 19 2
+--R                      - 22935125360640a b  c  + 880468295680a b  c
+--R                    + 
+--R                                 4 21               3 23
+--R                      7516192768a b  c - 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                               7 7               6 2 6               5 4 5
+--R                  - 1101463552a c  + 55421599744a b c  - 29809790976a b c
+--R                + 
+--R                             4 6 4              3 8 3             2 10 2
+--R                  2042667008a b c  + 1054785280a b c  - 124080000a b  c
+--R                + 
+--R                              12          14
+--R                  - 4030000a b  c - 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               13 10                  12 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               11 4 8                  10 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               9 8 6                 8 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             7 12 4                6 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            5 16 2             4 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         3 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                         +--------------------+3
+--R                                           +-----------+ |   +-----------+
+--R                2 2         2       4 4+-+ |          2 4|   |          2
+--R         (- 256a c  + 128a b c - 16b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        13 10                  12 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        11 4 8                  10 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        9 8 6                 8 10 5
+--R                         14431090114560a b c  - 4329327034368a b  c
+--R                       + 
+--R                                      7 12 4                6 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     5 16 2             4 18             3 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                        14   11                      13 3 10
+--R                      48413695994232832a  b c   - 119626865102028800a  b c
+--R                    + 
+--R                                         12 5 9                     11 7 8
+--R                      132645082774896640a  b c  - 86817438129192960a  b c
+--R                    + 
+--R                                        10 9 7                     9 11 6
+--R                      37075532088606720a  b c  - 10759820789415936a b  c
+--R                    + 
+--R                                       8 13 5                   7 15 4
+--R                      2135801336954880a b  c  - 282437049384960a b  c
+--R                    + 
+--R                                     6 17 3                5 19 2
+--R                      22935125360640a b  c  - 880468295680a b  c
+--R                    + 
+--R                                   4 21               3 23
+--R                      - 7516192768a b  c + 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                             7 7               6 2 6               5 4 5
+--R                  1101463552a c  - 55421599744a b c  + 29809790976a b c
+--R                + 
+--R                               4 6 4              3 8 3             2 10 2
+--R                  - 2042667008a b c  - 1054785280a b c  + 124080000a b  c
+--R                + 
+--R                            12          14
+--R                  4030000a b  c + 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               13 10                  12 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               11 4 8                  10 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               9 8 6                 8 10 5
+--R                                14431090114560a b c  - 4329327034368a b  c
+--R                              + 
+--R                                             7 12 4                6 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            5 16 2             4 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         3 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                       +--------------------+3
+--R                                         +-----------+ |   +-----------+
+--R              2 2         2       4 4+-+ |          2 4|   |          2
+--R         (256a c  - 128a b c + 16b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          13 10                  12 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          11 4 8                  10 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          9 8 6                 8 10 5
+--R                         - 14431090114560a b c  + 4329327034368a b  c
+--R                       + 
+--R                                        7 12 4                6 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       5 16 2             4 18             3 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                           6 6                5 2 5
+--R                              - 1475789056a c  + 146825952000a b c
+--R                            + 
+--R                                              4 4 4                3 6 3
+--R                              - 3647743260000a b c  - 207773230000a b c
+--R                            + 
+--R                                           2 8 2              10           12
+--R                              - 5345390625a b c  - 67968750a b  c - 390625b
+--R                         /
+--R                                                       21 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          20 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        19 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          18 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        17 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         16 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       15 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         14 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      13 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       12 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    11 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     10 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  9 24 3
+--R                              8196551321814302720a b  c
+--R                            + 
+--R                                                   8 26 2
+--R                              - 472877960873902080a b  c
+--R                            + 
+--R                                                7 28                    6 30
+--R                              16888498602639360a b  c - 281474976710656a b
+--R                   + 
+--R                              5   5             4 3 4            3 5 3
+--R                     14488320a b c  - 106839040a b c  - 52776416a b c
+--R                   + 
+--R                               2 7 2           9        11
+--R                     - 1386000a b c  - 48125a b c - 625b
+--R                /
+--R                                   13 10                  12 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    11 4 8                  10 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   9 8 6                 8 10 5
+--R                     7215545057280a b c  - 2164663517184a b  c
+--R                   + 
+--R                                  7 12 4               6 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                5 16 2             4 18            3 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                        14   11                      13 3 10
+--R                      48413695994232832a  b c   - 119626865102028800a  b c
+--R                    + 
+--R                                         12 5 9                     11 7 8
+--R                      132645082774896640a  b c  - 86817438129192960a  b c
+--R                    + 
+--R                                        10 9 7                     9 11 6
+--R                      37075532088606720a  b c  - 10759820789415936a b  c
+--R                    + 
+--R                                       8 13 5                   7 15 4
+--R                      2135801336954880a b  c  - 282437049384960a b  c
+--R                    + 
+--R                                     6 17 3                5 19 2
+--R                      22935125360640a b  c  - 880468295680a b  c
+--R                    + 
+--R                                   4 21               3 23
+--R                      - 7516192768a b  c + 1342177280a b
+--R                 *
+--R                    ROOT
+--R                                        6 6                5 2 5
+--R                           - 1475789056a c  + 146825952000a b c
+--R                         + 
+--R                                           4 4 4                3 6 3
+--R                           - 3647743260000a b c  - 207773230000a b c
+--R                         + 
+--R                                        2 8 2              10           12
+--R                           - 5345390625a b c  - 67968750a b  c - 390625b
+--R                      /
+--R                                                    21 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       20 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     19 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       18 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     17 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      16 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    15 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      14 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   13 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    12 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 11 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  10 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               9 24 3
+--R                           8196551321814302720a b  c
+--R                         + 
+--R                                                8 26 2                     7 28
+--R                           - 472877960873902080a b  c  + 16888498602639360a b  c
+--R                         + 
+--R                                             6 30
+--R                           - 281474976710656a b
+--R                + 
+--R                               7 7               6 2 6               5 4 5
+--R                  - 1101463552a c  + 55421599744a b c  - 29809790976a b c
+--R                + 
+--R                             4 6 4              3 8 3             2 10 2
+--R                  2042667008a b c  + 1054785280a b c  - 124080000a b  c
+--R                + 
+--R                              12          14
+--R                  - 4030000a b  c - 50000b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 13 10                  12 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 11 4 8                  10 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 9 8 6                 8 10 5
+--R                                - 14431090114560a b c  + 4329327034368a b  c
+--R                              + 
+--R                                               7 12 4                6 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              5 16 2             4 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           3 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                  6 6                5 2 5
+--R                                     - 1475789056a c  + 146825952000a b c
+--R                                   + 
+--R                                                     4 4 4                3 6 3
+--R                                     - 3647743260000a b c  - 207773230000a b c
+--R                                   + 
+--R                                                  2 8 2              10
+--R                                     - 5345390625a b c  - 67968750a b  c
+--R                                   + 
+--R                                              12
+--R                                     - 390625b
+--R                                /
+--R                                                              21 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 20 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               19 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 18 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               17 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                16 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              15 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                14 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             13 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              12 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           11 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            10 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         9 24 3
+--R                                     8196551321814302720a b  c
+--R                                   + 
+--R                                                          8 26 2
+--R                                     - 472877960873902080a b  c
+--R                                   + 
+--R                                                       7 28
+--R                                     16888498602639360a b  c
+--R                                   + 
+--R                                                       6 30
+--R                                     - 281474976710656a b
+--R                          + 
+--R                                     5   5             4 3 4            3 5 3
+--R                            14488320a b c  - 106839040a b c  - 52776416a b c
+--R                          + 
+--R                                      2 7 2           9        11
+--R                            - 1386000a b c  - 48125a b c - 625b
+--R                       /
+--R                                          13 10                  12 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           11 4 8                  10 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          9 8 6                 8 10 5
+--R                            7215545057280a b c  - 2164663517184a b  c
+--R                          + 
+--R                                         7 12 4               6 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       5 16 2             4 18            3 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                           5 6              4 2 5               3 4 4
+--R                  30118144a c  - 1210872320a b c  - 14322119840a b c
+--R                + 
+--R                               2 6 3              8 2          10
+--R                  - 1142950000a b c  - 25609375a b c  - 240625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                    +------------------+3
+--R                +-----------+                       | +-----------+
+--R                |          2               2 4+-+3 4| |          2
+--R         (- 36b\|- 4a c + b   - 28a c - 41b )\|c   \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                    +--------------------+3
+--R                +-----------+                       |   +-----------+
+--R                |          2               2 4+-+3 4|   |          2
+--R         (- 36b\|- 4a c + b   + 28a c + 41b )\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                                    +------------------+3
+--R                +-----------+                       | +-----------+
+--R                |          2               2 4+-+3 4| |          2
+--R         (- 36b\|- 4a c + b   - 28a c - 41b )\|c   \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                                    +--------------------+3
+--R                +-----------+                       |   +-----------+
+--R                |          2               2 4+-+3 4|   |          2
+--R         (- 36b\|- 4a c + b   + 28a c + 41b )\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                                     +--------------------+3
+--R                                       +-----------+ |   +-----------+
+--R            2 2         2       4 4+-+ |          2 4|   |          2
+--R       (256a c  - 128a b c + 16b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+3
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 698
+
+--S 699 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 699
+
+)clear all
+
+--S 700 of 1057
+t0:=x^(5/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      2 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 700
+
+--S 701 of 1057
+r0:=-1/4*x^(3/2)*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+3/16*x^(3/2)*_
+   (b*(b^2+4*a*c)+c*(b^2+12*a*c)*x^2)/(a*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))+_
+   3/32*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b^2+12*a*c-b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*a*(b^2-4*a*c)^2*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-3/32*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))*(b^2+12*a*c-b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*a*(b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(1/4))+3/32*c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b^2+12*a*c+_
+   b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*a*(b^2-4*a*c)^2*(-b+sqrt(b^2-_
+   4*a*c))^(1/4))-3/32*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(b^2+12*a*c+b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                       3     2 2  8             2     3   6
+--R               (- 36a c  - 3b c )x  + (- 72a b c  - 6b c)x
+--R             + 
+--R                     2 2        2      4  4         2          3  2      3
+--R               (- 72a c  - 42a b c - 3b )x  + (- 72a b c - 6a b )x  - 36a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2     4   6
+--R           (- 204a b c  + 3b c )x  + (- 408a b c  + 6b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2        4  2       3
+--R           (- 408a b c  - 198a b c + 3b )x  + (- 408a b c + 6a b )x  - 204a b c
+--R         + 
+--R             2 3
+--R           3a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                 4+-+4+-+ +-+
+--R         4+-+4| |          2                  \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R                       3     2 2  8             2     3   6
+--R               (- 36a c  - 3b c )x  + (- 72a b c  - 6b c)x
+--R             + 
+--R                     2 2        2      4  4         2          3  2      3
+--R               (- 72a c  - 42a b c - 3b )x  + (- 72a b c - 6a b )x  - 36a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2     4   6
+--R           (204a b c  - 3b c )x  + (408a b c  - 6b c)x
+--R         + 
+--R                2   2         3      5  4        2 2        4  2       3
+--R           (408a b c  + 198a b c - 3b )x  + (408a b c - 6a b )x  + 204a b c
+--R         + 
+--R               2 3
+--R           - 3a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                4+-+4+-+ +-+
+--R         4+-+4|   |          2                 \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R     + 
+--R                     3     2 2  8           2     3   6
+--R               (36a c  + 3b c )x  + (72a b c  + 6b c)x
+--R             + 
+--R                   2 2        2      4  4       2          3  2      3      2 2
+--R               (72a c  + 42a b c + 3b )x  + (72a b c + 6a b )x  + 36a c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2     4   6
+--R           (204a b c  - 3b c )x  + (408a b c  - 6b c)x
+--R         + 
+--R                2   2         3      5  4        2 2        4  2       3
+--R           (408a b c  + 198a b c - 3b )x  + (408a b c - 6a b )x  + 204a b c
+--R         + 
+--R               2 3
+--R           - 3a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                4+-+4+-+ +-+
+--R         4+-+4| |          2                 \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R                     3     2 2  8           2     3   6
+--R               (36a c  + 3b c )x  + (72a b c  + 6b c)x
+--R             + 
+--R                   2 2        2      4  4       2          3  2      3      2 2
+--R               (72a c  + 42a b c + 3b )x  + (72a b c + 6a b )x  + 36a c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2     4   6
+--R           (- 204a b c  + 3b c )x  + (- 408a b c  + 6b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2        4  2       3
+--R           (- 408a b c  - 198a b c + 3b )x  + (- 408a b c + 6a b )x  - 204a b c
+--R         + 
+--R             2 3
+--R           3a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+               4+-+4+-+ +-+
+--R         4+-+4|   |          2                \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                         4| |          2
+--R                                         \|\|- 4a c + b   - b
+--R     + 
+--R                 3     2 2  7           2      3   5
+--R           (72a c  + 6b c )x  + (96a b c  + 12b c)x
+--R         + 
+--R                2 2        2      4  3       2          3
+--R           (136a c  + 14a b c + 6b )x  + (56a b c - 2a b )x
+--R      *
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R         4+-+3 |          2  +-+4|   |          2      4| |          2
+--R         \|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R              3 4       2 2 3        4 2  8
+--R         (512a c  - 256a b c  + 32a b c )x
+--R       + 
+--R               3   3       2 3 2        5   6         4 3       2 4         6  4
+--R         (1024a b c  - 512a b c  + 64a b c)x  + (1024a c  - 192a b c + 32a b )x
+--R       + 
+--R               4   2       3 3       2 5  2       5 2       4 2       3 4
+--R         (1024a b c  - 512a b c + 64a b )x  + 512a c  - 256a b c + 32a b
+--R    *
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R       4+-+3 |          2 4|   |          2      4| |          2
+--R       \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 4      2 2 3       4 2  8
+--R           (128a c  - 64a b c  + 8a b c )x
+--R         + 
+--R                3   3       2 3 2        5   6        4 3      2 4        6  4
+--R           (256a b c  - 128a b c  + 16a b c)x  + (256a c  - 48a b c + 8a b )x
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (256a b c  - 128a b c + 16a b )x  + 128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        15 10                  14 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        13 4 8                  12 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        11 8 6                 10 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      9 12 4                8 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     7 16 2             6 18             5 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                25 20
+--R                      2040062320599686732316672a  c
+--R                    + 
+--R                                                   24 2 19
+--R                      - 48621485307625867120214016a  b c
+--R                    + 
+--R                                                  23 4 18
+--R                      152527715030206670757167104a  b c
+--R                    + 
+--R                                                    22 6 17
+--R                      - 227476393479830809943736320a  b c
+--R                    + 
+--R                                                  21 8 16
+--R                      201244828259110648192958464a  b c
+--R                    + 
+--R                                                    20 10 15
+--R                      - 111188709134976155262124032a  b  c
+--R                    + 
+--R                                                 19 12 14
+--R                      34190154696905115861778432a  b  c
+--R                    + 
+--R                                               18 14 13
+--R                      127134960156006229737472a  b  c
+--R                    + 
+--R                                                  17 16 12
+--R                      - 6158710680953993381806080a  b  c
+--R                    + 
+--R                                                16 18 11
+--R                      3643263083438260829028352a  b  c
+--R                    + 
+--R                                                  15 20 10
+--R                      - 1296952961758430775738368a  b  c
+--R                    + 
+--R                                               14 22 9
+--R                      328971163360003895590912a  b  c
+--R                    + 
+--R                                                13 24 8
+--R                      - 62441093782400734855168a  b  c
+--R                    + 
+--R                                             12 26 7
+--R                      8999768315355830681600a  b  c
+--R                    + 
+--R                                              11 28 6
+--R                      - 982839686979479666688a  b  c
+--R                    + 
+--R                                           10 30 5                       9 32 4
+--R                      80138177669337448448a  b  c  - 4746741230690369536a b  c
+--R                    + 
+--R                                         8 34 3                    7 36 2
+--R                      195563536162750464a b  c  - 5239172906352640a b  c
+--R                    + 
+--R                                     6 38                 5 40
+--R                      81363860455424a b  c - 549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                        16   16                         15 3 15
+--R                  - 3116402981210161152a  b c   + 142135388747184734208a  b c
+--R                + 
+--R                                          14 5 14
+--R                  - 476947922461126557696a  b c
+--R                + 
+--R                                        13 7 13                         12 9 12
+--R                  676927478164365508608a  b c   - 546073570406018580480a  b c
+--R                + 
+--R                                        11 11 11                        10 13 10
+--R                  282644228028814589952a  b  c   - 99676215691783962624a  b  c
+--R                + 
+--R                                       9 15 9                       8 17 8
+--R                  24684324213328183296a b  c  - 4345605828271669248a b  c
+--R                + 
+--R                                     7 19 7                     6 21 6
+--R                  543725555401359360a b  c  - 47898027481890816a b  c
+--R                + 
+--R                                   5 23 5                   4 25 4
+--R                  2925152100679680a b  c  - 121589310947328a b  c
+--R                + 
+--R                                3 27 3               2 29 2               31
+--R                  3359585009664a b  c  - 59016314880a b  c  + 597196800a b  c
+--R                + 
+--R                            33
+--R                  - 2654208b
+--R             *
+--R                ROOT
+--R                                          15 10                  14 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          13 4 8                  12 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          11 8 6                 10 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        9 12 4                8 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               15 10                  14 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               13 4 8                  12 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               11 8 6                 10 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             9 12 4                8 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            7 16 2             6 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         5 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  3 4      2 2 3       4 2  8
+--R           (- 128a c  + 64a b c  - 8a b c )x
+--R         + 
+--R                  3   3       2 3 2        5   6
+--R           (- 256a b c  + 128a b c  - 16a b c)x
+--R         + 
+--R                  4 3      2 4        6  4          4   2       3 3       2 5  2
+--R           (- 256a c  + 48a b c - 8a b )x  + (- 256a b c  + 128a b c - 16a b )x
+--R         + 
+--R                 5 2      4 2      3 4
+--R           - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          15 10                  14 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          13 4 8                  12 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          11 8 6                 10 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        9 12 4                8 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                25 20
+--R                      2040062320599686732316672a  c
+--R                    + 
+--R                                                   24 2 19
+--R                      - 48621485307625867120214016a  b c
+--R                    + 
+--R                                                  23 4 18
+--R                      152527715030206670757167104a  b c
+--R                    + 
+--R                                                    22 6 17
+--R                      - 227476393479830809943736320a  b c
+--R                    + 
+--R                                                  21 8 16
+--R                      201244828259110648192958464a  b c
+--R                    + 
+--R                                                    20 10 15
+--R                      - 111188709134976155262124032a  b  c
+--R                    + 
+--R                                                 19 12 14
+--R                      34190154696905115861778432a  b  c
+--R                    + 
+--R                                               18 14 13
+--R                      127134960156006229737472a  b  c
+--R                    + 
+--R                                                  17 16 12
+--R                      - 6158710680953993381806080a  b  c
+--R                    + 
+--R                                                16 18 11
+--R                      3643263083438260829028352a  b  c
+--R                    + 
+--R                                                  15 20 10
+--R                      - 1296952961758430775738368a  b  c
+--R                    + 
+--R                                               14 22 9
+--R                      328971163360003895590912a  b  c
+--R                    + 
+--R                                                13 24 8
+--R                      - 62441093782400734855168a  b  c
+--R                    + 
+--R                                             12 26 7
+--R                      8999768315355830681600a  b  c
+--R                    + 
+--R                                              11 28 6
+--R                      - 982839686979479666688a  b  c
+--R                    + 
+--R                                           10 30 5                       9 32 4
+--R                      80138177669337448448a  b  c  - 4746741230690369536a b  c
+--R                    + 
+--R                                         8 34 3                    7 36 2
+--R                      195563536162750464a b  c  - 5239172906352640a b  c
+--R                    + 
+--R                                     6 38                 5 40
+--R                      81363860455424a b  c - 549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                      16   16                         15 3 15
+--R                  3116402981210161152a  b c   - 142135388747184734208a  b c
+--R                + 
+--R                                        14 5 14                         13 7 13
+--R                  476947922461126557696a  b c   - 676927478164365508608a  b c
+--R                + 
+--R                                        12 9 12                         11 11 11
+--R                  546073570406018580480a  b c   - 282644228028814589952a  b  c
+--R                + 
+--R                                       10 13 10                        9 15 9
+--R                  99676215691783962624a  b  c   - 24684324213328183296a b  c
+--R                + 
+--R                                      8 17 8                      7 19 7
+--R                  4345605828271669248a b  c  - 543725555401359360a b  c
+--R                + 
+--R                                    6 21 6                    5 23 5
+--R                  47898027481890816a b  c  - 2925152100679680a b  c
+--R                + 
+--R                                  4 25 4                 3 27 3
+--R                  121589310947328a b  c  - 3359585009664a b  c
+--R                + 
+--R                              2 29 2               31            33
+--R                  59016314880a b  c  - 597196800a b  c + 2654208b
+--R             *
+--R                ROOT
+--R                                            15 10                  14 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            13 4 8                  12 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            11 8 6                 10 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          9 12 4                8 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 15 10                  14 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 13 4 8                  12 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 11 8 6                 10 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               9 12 4                8 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              7 16 2             6 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           5 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                3 4      2 2 3       4 2  8
+--R           (128a c  - 64a b c  + 8a b c )x
+--R         + 
+--R                3   3       2 3 2        5   6        4 3      2 4        6  4
+--R           (256a b c  - 128a b c  + 16a b c)x  + (256a c  - 48a b c + 8a b )x
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (256a b c  - 128a b c + 16a b )x  + 128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          15 10                  14 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          13 4 8                  12 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          11 8 6                 10 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        9 12 4                8 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                  25 20
+--R                      - 2040062320599686732316672a  c
+--R                    + 
+--R                                                 24 2 19
+--R                      48621485307625867120214016a  b c
+--R                    + 
+--R                                                    23 4 18
+--R                      - 152527715030206670757167104a  b c
+--R                    + 
+--R                                                  22 6 17
+--R                      227476393479830809943736320a  b c
+--R                    + 
+--R                                                    21 8 16
+--R                      - 201244828259110648192958464a  b c
+--R                    + 
+--R                                                  20 10 15
+--R                      111188709134976155262124032a  b  c
+--R                    + 
+--R                                                   19 12 14
+--R                      - 34190154696905115861778432a  b  c
+--R                    + 
+--R                                                 18 14 13
+--R                      - 127134960156006229737472a  b  c
+--R                    + 
+--R                                                17 16 12
+--R                      6158710680953993381806080a  b  c
+--R                    + 
+--R                                                  16 18 11
+--R                      - 3643263083438260829028352a  b  c
+--R                    + 
+--R                                                15 20 10
+--R                      1296952961758430775738368a  b  c
+--R                    + 
+--R                                                 14 22 9
+--R                      - 328971163360003895590912a  b  c
+--R                    + 
+--R                                              13 24 8
+--R                      62441093782400734855168a  b  c
+--R                    + 
+--R                                               12 26 7
+--R                      - 8999768315355830681600a  b  c
+--R                    + 
+--R                                            11 28 6
+--R                      982839686979479666688a  b  c
+--R                    + 
+--R                                             10 30 5
+--R                      - 80138177669337448448a  b  c
+--R                    + 
+--R                                          9 32 4                      8 34 3
+--R                      4746741230690369536a b  c  - 195563536162750464a b  c
+--R                    + 
+--R                                       7 36 2                  6 38
+--R                      5239172906352640a b  c  - 81363860455424a b  c
+--R                    + 
+--R                                   5 40
+--R                      549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                        16   16                         15 3 15
+--R                  - 3116402981210161152a  b c   + 142135388747184734208a  b c
+--R                + 
+--R                                          14 5 14
+--R                  - 476947922461126557696a  b c
+--R                + 
+--R                                        13 7 13                         12 9 12
+--R                  676927478164365508608a  b c   - 546073570406018580480a  b c
+--R                + 
+--R                                        11 11 11                        10 13 10
+--R                  282644228028814589952a  b  c   - 99676215691783962624a  b  c
+--R                + 
+--R                                       9 15 9                       8 17 8
+--R                  24684324213328183296a b  c  - 4345605828271669248a b  c
+--R                + 
+--R                                     7 19 7                     6 21 6
+--R                  543725555401359360a b  c  - 47898027481890816a b  c
+--R                + 
+--R                                   5 23 5                   4 25 4
+--R                  2925152100679680a b  c  - 121589310947328a b  c
+--R                + 
+--R                                3 27 3               2 29 2               31
+--R                  3359585009664a b  c  - 59016314880a b  c  + 597196800a b  c
+--R                + 
+--R                            33
+--R                  - 2654208b
+--R             *
+--R                ROOT
+--R                                            15 10                  14 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            13 4 8                  12 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            11 8 6                 10 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          9 12 4                8 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 15 10                  14 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 13 4 8                  12 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 11 8 6                 10 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               9 12 4                8 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              7 16 2             6 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           5 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  3 4      2 2 3       4 2  8
+--R           (- 128a c  + 64a b c  - 8a b c )x
+--R         + 
+--R                  3   3       2 3 2        5   6
+--R           (- 256a b c  + 128a b c  - 16a b c)x
+--R         + 
+--R                  4 3      2 4        6  4          4   2       3 3       2 5  2
+--R           (- 256a c  + 48a b c - 8a b )x  + (- 256a b c  + 128a b c - 16a b )x
+--R         + 
+--R                 5 2      4 2      3 4
+--R           - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        15 10                  14 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        13 4 8                  12 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        11 8 6                 10 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      9 12 4                8 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     7 16 2             6 18             5 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                  25 20
+--R                      - 2040062320599686732316672a  c
+--R                    + 
+--R                                                 24 2 19
+--R                      48621485307625867120214016a  b c
+--R                    + 
+--R                                                    23 4 18
+--R                      - 152527715030206670757167104a  b c
+--R                    + 
+--R                                                  22 6 17
+--R                      227476393479830809943736320a  b c
+--R                    + 
+--R                                                    21 8 16
+--R                      - 201244828259110648192958464a  b c
+--R                    + 
+--R                                                  20 10 15
+--R                      111188709134976155262124032a  b  c
+--R                    + 
+--R                                                   19 12 14
+--R                      - 34190154696905115861778432a  b  c
+--R                    + 
+--R                                                 18 14 13
+--R                      - 127134960156006229737472a  b  c
+--R                    + 
+--R                                                17 16 12
+--R                      6158710680953993381806080a  b  c
+--R                    + 
+--R                                                  16 18 11
+--R                      - 3643263083438260829028352a  b  c
+--R                    + 
+--R                                                15 20 10
+--R                      1296952961758430775738368a  b  c
+--R                    + 
+--R                                                 14 22 9
+--R                      - 328971163360003895590912a  b  c
+--R                    + 
+--R                                              13 24 8
+--R                      62441093782400734855168a  b  c
+--R                    + 
+--R                                               12 26 7
+--R                      - 8999768315355830681600a  b  c
+--R                    + 
+--R                                            11 28 6
+--R                      982839686979479666688a  b  c
+--R                    + 
+--R                                             10 30 5
+--R                      - 80138177669337448448a  b  c
+--R                    + 
+--R                                          9 32 4                      8 34 3
+--R                      4746741230690369536a b  c  - 195563536162750464a b  c
+--R                    + 
+--R                                       7 36 2                  6 38
+--R                      5239172906352640a b  c  - 81363860455424a b  c
+--R                    + 
+--R                                   5 40
+--R                      549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                      16   16                         15 3 15
+--R                  3116402981210161152a  b c   - 142135388747184734208a  b c
+--R                + 
+--R                                        14 5 14                         13 7 13
+--R                  476947922461126557696a  b c   - 676927478164365508608a  b c
+--R                + 
+--R                                        12 9 12                         11 11 11
+--R                  546073570406018580480a  b c   - 282644228028814589952a  b  c
+--R                + 
+--R                                       10 13 10                        9 15 9
+--R                  99676215691783962624a  b  c   - 24684324213328183296a b  c
+--R                + 
+--R                                      8 17 8                      7 19 7
+--R                  4345605828271669248a b  c  - 543725555401359360a b  c
+--R                + 
+--R                                    6 21 6                    5 23 5
+--R                  47898027481890816a b  c  - 2925152100679680a b  c
+--R                + 
+--R                                  4 25 4                 3 27 3
+--R                  121589310947328a b  c  - 3359585009664a b  c
+--R                + 
+--R                              2 29 2               31            33
+--R                  59016314880a b  c  - 597196800a b  c + 2654208b
+--R             *
+--R                ROOT
+--R                                          15 10                  14 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          13 4 8                  12 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          11 8 6                 10 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        9 12 4                8 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               15 10                  14 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               13 4 8                  12 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               11 8 6                 10 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             9 12 4                8 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            7 16 2             6 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         5 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                3 4       2 2 3        4 2  8
+--R           (256a c  - 128a b c  + 16a b c )x
+--R         + 
+--R                3   3       2 3 2        5   6        4 3      2 4         6  4
+--R           (512a b c  - 256a b c  + 32a b c)x  + (512a c  - 96a b c + 16a b )x
+--R         + 
+--R                4   2       3 3       2 5  2       5 2       4 2       3 4
+--R           (512a b c  - 256a b c + 32a b )x  + 256a c  - 128a b c + 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        15 10                  14 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        13 4 8                  12 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        11 8 6                 10 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      9 12 4                8 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     7 16 2             6 18             5 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                25 20
+--R                      2040062320599686732316672a  c
+--R                    + 
+--R                                                   24 2 19
+--R                      - 48621485307625867120214016a  b c
+--R                    + 
+--R                                                  23 4 18
+--R                      152527715030206670757167104a  b c
+--R                    + 
+--R                                                    22 6 17
+--R                      - 227476393479830809943736320a  b c
+--R                    + 
+--R                                                  21 8 16
+--R                      201244828259110648192958464a  b c
+--R                    + 
+--R                                                    20 10 15
+--R                      - 111188709134976155262124032a  b  c
+--R                    + 
+--R                                                 19 12 14
+--R                      34190154696905115861778432a  b  c
+--R                    + 
+--R                                               18 14 13
+--R                      127134960156006229737472a  b  c
+--R                    + 
+--R                                                  17 16 12
+--R                      - 6158710680953993381806080a  b  c
+--R                    + 
+--R                                                16 18 11
+--R                      3643263083438260829028352a  b  c
+--R                    + 
+--R                                                  15 20 10
+--R                      - 1296952961758430775738368a  b  c
+--R                    + 
+--R                                               14 22 9
+--R                      328971163360003895590912a  b  c
+--R                    + 
+--R                                                13 24 8
+--R                      - 62441093782400734855168a  b  c
+--R                    + 
+--R                                             12 26 7
+--R                      8999768315355830681600a  b  c
+--R                    + 
+--R                                              11 28 6
+--R                      - 982839686979479666688a  b  c
+--R                    + 
+--R                                           10 30 5                       9 32 4
+--R                      80138177669337448448a  b  c  - 4746741230690369536a b  c
+--R                    + 
+--R                                         8 34 3                    7 36 2
+--R                      195563536162750464a b  c  - 5239172906352640a b  c
+--R                    + 
+--R                                     6 38                 5 40
+--R                      81363860455424a b  c - 549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                        16   16                         15 3 15
+--R                  - 3116402981210161152a  b c   + 142135388747184734208a  b c
+--R                + 
+--R                                          14 5 14
+--R                  - 476947922461126557696a  b c
+--R                + 
+--R                                        13 7 13                         12 9 12
+--R                  676927478164365508608a  b c   - 546073570406018580480a  b c
+--R                + 
+--R                                        11 11 11                        10 13 10
+--R                  282644228028814589952a  b  c   - 99676215691783962624a  b  c
+--R                + 
+--R                                       9 15 9                       8 17 8
+--R                  24684324213328183296a b  c  - 4345605828271669248a b  c
+--R                + 
+--R                                     7 19 7                     6 21 6
+--R                  543725555401359360a b  c  - 47898027481890816a b  c
+--R                + 
+--R                                   5 23 5                   4 25 4
+--R                  2925152100679680a b  c  - 121589310947328a b  c
+--R                + 
+--R                                3 27 3               2 29 2               31
+--R                  3359585009664a b  c  - 59016314880a b  c  + 597196800a b  c
+--R                + 
+--R                            33
+--R                  - 2654208b
+--R             *
+--R                ROOT
+--R                                          15 10                  14 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          13 4 8                  12 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          11 8 6                 10 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        9 12 4                8 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               15 10                  14 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               13 4 8                  12 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               11 8 6                 10 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             9 12 4                8 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            7 16 2             6 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         5 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  3 4       2 2 3        4 2  8
+--R           (- 256a c  + 128a b c  - 16a b c )x
+--R         + 
+--R                  3   3       2 3 2        5   6
+--R           (- 512a b c  + 256a b c  - 32a b c)x
+--R         + 
+--R                  4 3      2 4         6  4
+--R           (- 512a c  + 96a b c - 16a b )x
+--R         + 
+--R                  4   2       3 3       2 5  2       5 2       4 2       3 4
+--R           (- 512a b c  + 256a b c - 32a b )x  - 256a c  + 128a b c - 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          15 10                  14 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          13 4 8                  12 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          11 8 6                 10 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        9 12 4                8 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                25 20
+--R                      2040062320599686732316672a  c
+--R                    + 
+--R                                                   24 2 19
+--R                      - 48621485307625867120214016a  b c
+--R                    + 
+--R                                                  23 4 18
+--R                      152527715030206670757167104a  b c
+--R                    + 
+--R                                                    22 6 17
+--R                      - 227476393479830809943736320a  b c
+--R                    + 
+--R                                                  21 8 16
+--R                      201244828259110648192958464a  b c
+--R                    + 
+--R                                                    20 10 15
+--R                      - 111188709134976155262124032a  b  c
+--R                    + 
+--R                                                 19 12 14
+--R                      34190154696905115861778432a  b  c
+--R                    + 
+--R                                               18 14 13
+--R                      127134960156006229737472a  b  c
+--R                    + 
+--R                                                  17 16 12
+--R                      - 6158710680953993381806080a  b  c
+--R                    + 
+--R                                                16 18 11
+--R                      3643263083438260829028352a  b  c
+--R                    + 
+--R                                                  15 20 10
+--R                      - 1296952961758430775738368a  b  c
+--R                    + 
+--R                                               14 22 9
+--R                      328971163360003895590912a  b  c
+--R                    + 
+--R                                                13 24 8
+--R                      - 62441093782400734855168a  b  c
+--R                    + 
+--R                                             12 26 7
+--R                      8999768315355830681600a  b  c
+--R                    + 
+--R                                              11 28 6
+--R                      - 982839686979479666688a  b  c
+--R                    + 
+--R                                           10 30 5                       9 32 4
+--R                      80138177669337448448a  b  c  - 4746741230690369536a b  c
+--R                    + 
+--R                                         8 34 3                    7 36 2
+--R                      195563536162750464a b  c  - 5239172906352640a b  c
+--R                    + 
+--R                                     6 38                 5 40
+--R                      81363860455424a b  c - 549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                      16   16                         15 3 15
+--R                  3116402981210161152a  b c   - 142135388747184734208a  b c
+--R                + 
+--R                                        14 5 14                         13 7 13
+--R                  476947922461126557696a  b c   - 676927478164365508608a  b c
+--R                + 
+--R                                        12 9 12                         11 11 11
+--R                  546073570406018580480a  b c   - 282644228028814589952a  b  c
+--R                + 
+--R                                       10 13 10                        9 15 9
+--R                  99676215691783962624a  b  c   - 24684324213328183296a b  c
+--R                + 
+--R                                      8 17 8                      7 19 7
+--R                  4345605828271669248a b  c  - 543725555401359360a b  c
+--R                + 
+--R                                    6 21 6                    5 23 5
+--R                  47898027481890816a b  c  - 2925152100679680a b  c
+--R                + 
+--R                                  4 25 4                 3 27 3
+--R                  121589310947328a b  c  - 3359585009664a b  c
+--R                + 
+--R                              2 29 2               31            33
+--R                  59016314880a b  c  - 597196800a b  c + 2654208b
+--R             *
+--R                ROOT
+--R                                            15 10                  14 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            13 4 8                  12 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            11 8 6                 10 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          9 12 4                8 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 15 10                  14 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 13 4 8                  12 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 11 8 6                 10 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               9 12 4                8 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              7 16 2             6 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           5 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                 3     2 2  7           2     3   5       2 2       2      4  3
+--R           (36a c  + 3b c )x  + (48a b c  + 6b c)x  + (68a c  + 7a b c + 3b )x
+--R         + 
+--R               2         3
+--R           (28a b c - a b )x
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R            3 4       2 2 3        4 2  8        3   3       2 3 2        5   6
+--R       (256a c  - 128a b c  + 16a b c )x  + (512a b c  - 256a b c  + 32a b c)x
+--R     + 
+--R            4 3      2 4         6  4        4   2       3 3       2 5  2
+--R       (512a c  - 96a b c + 16a b )x  + (512a b c  - 256a b c + 32a b )x
+--R     + 
+--R           5 2       4 2       3 4
+--R       256a c  - 128a b c + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 702
+
+--S 703 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +--------------------+
+--R                                            +-----------+ |   +-----------+
+--R              3 2       2 2         4 4+-+3 |          2 4|   |          2
+--R         (256a c  - 128a b c + 16a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        15 10                  14 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        13 4 8                  12 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        11 8 6                 10 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      9 12 4                8 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     7 16 2             6 18             5 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                25 20
+--R                      2040062320599686732316672a  c
+--R                    + 
+--R                                                   24 2 19
+--R                      - 48621485307625867120214016a  b c
+--R                    + 
+--R                                                  23 4 18
+--R                      152527715030206670757167104a  b c
+--R                    + 
+--R                                                    22 6 17
+--R                      - 227476393479830809943736320a  b c
+--R                    + 
+--R                                                  21 8 16
+--R                      201244828259110648192958464a  b c
+--R                    + 
+--R                                                    20 10 15
+--R                      - 111188709134976155262124032a  b  c
+--R                    + 
+--R                                                 19 12 14
+--R                      34190154696905115861778432a  b  c
+--R                    + 
+--R                                               18 14 13
+--R                      127134960156006229737472a  b  c
+--R                    + 
+--R                                                  17 16 12
+--R                      - 6158710680953993381806080a  b  c
+--R                    + 
+--R                                                16 18 11
+--R                      3643263083438260829028352a  b  c
+--R                    + 
+--R                                                  15 20 10
+--R                      - 1296952961758430775738368a  b  c
+--R                    + 
+--R                                               14 22 9
+--R                      328971163360003895590912a  b  c
+--R                    + 
+--R                                                13 24 8
+--R                      - 62441093782400734855168a  b  c
+--R                    + 
+--R                                             12 26 7
+--R                      8999768315355830681600a  b  c
+--R                    + 
+--R                                              11 28 6
+--R                      - 982839686979479666688a  b  c
+--R                    + 
+--R                                           10 30 5                       9 32 4
+--R                      80138177669337448448a  b  c  - 4746741230690369536a b  c
+--R                    + 
+--R                                         8 34 3                    7 36 2
+--R                      195563536162750464a b  c  - 5239172906352640a b  c
+--R                    + 
+--R                                     6 38                 5 40
+--R                      81363860455424a b  c - 549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                        16   16                         15 3 15
+--R                  - 3116402981210161152a  b c   + 142135388747184734208a  b c
+--R                + 
+--R                                          14 5 14
+--R                  - 476947922461126557696a  b c
+--R                + 
+--R                                        13 7 13                         12 9 12
+--R                  676927478164365508608a  b c   - 546073570406018580480a  b c
+--R                + 
+--R                                        11 11 11                        10 13 10
+--R                  282644228028814589952a  b  c   - 99676215691783962624a  b  c
+--R                + 
+--R                                       9 15 9                       8 17 8
+--R                  24684324213328183296a b  c  - 4345605828271669248a b  c
+--R                + 
+--R                                     7 19 7                     6 21 6
+--R                  543725555401359360a b  c  - 47898027481890816a b  c
+--R                + 
+--R                                   5 23 5                   4 25 4
+--R                  2925152100679680a b  c  - 121589310947328a b  c
+--R                + 
+--R                                3 27 3               2 29 2               31
+--R                  3359585009664a b  c  - 59016314880a b  c  + 597196800a b  c
+--R                + 
+--R                            33
+--R                  - 2654208b
+--R             *
+--R                ROOT
+--R                                          15 10                  14 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          13 4 8                  12 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          11 8 6                 10 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        9 12 4                8 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               15 10                  14 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               13 4 8                  12 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               11 8 6                 10 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             9 12 4                8 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            7 16 2             6 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         5 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                              +-----------+
+--R                3 2       2 2         4 4+-+3 |          2
+--R         (- 256a c  + 128a b c - 16a b )\|2  \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          15 10                  14 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          13 4 8                  12 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          11 8 6                 10 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        9 12 4                8 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                25 20
+--R                      2040062320599686732316672a  c
+--R                    + 
+--R                                                   24 2 19
+--R                      - 48621485307625867120214016a  b c
+--R                    + 
+--R                                                  23 4 18
+--R                      152527715030206670757167104a  b c
+--R                    + 
+--R                                                    22 6 17
+--R                      - 227476393479830809943736320a  b c
+--R                    + 
+--R                                                  21 8 16
+--R                      201244828259110648192958464a  b c
+--R                    + 
+--R                                                    20 10 15
+--R                      - 111188709134976155262124032a  b  c
+--R                    + 
+--R                                                 19 12 14
+--R                      34190154696905115861778432a  b  c
+--R                    + 
+--R                                               18 14 13
+--R                      127134960156006229737472a  b  c
+--R                    + 
+--R                                                  17 16 12
+--R                      - 6158710680953993381806080a  b  c
+--R                    + 
+--R                                                16 18 11
+--R                      3643263083438260829028352a  b  c
+--R                    + 
+--R                                                  15 20 10
+--R                      - 1296952961758430775738368a  b  c
+--R                    + 
+--R                                               14 22 9
+--R                      328971163360003895590912a  b  c
+--R                    + 
+--R                                                13 24 8
+--R                      - 62441093782400734855168a  b  c
+--R                    + 
+--R                                             12 26 7
+--R                      8999768315355830681600a  b  c
+--R                    + 
+--R                                              11 28 6
+--R                      - 982839686979479666688a  b  c
+--R                    + 
+--R                                           10 30 5                       9 32 4
+--R                      80138177669337448448a  b  c  - 4746741230690369536a b  c
+--R                    + 
+--R                                         8 34 3                    7 36 2
+--R                      195563536162750464a b  c  - 5239172906352640a b  c
+--R                    + 
+--R                                     6 38                 5 40
+--R                      81363860455424a b  c - 549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                      16   16                         15 3 15
+--R                  3116402981210161152a  b c   - 142135388747184734208a  b c
+--R                + 
+--R                                        14 5 14                         13 7 13
+--R                  476947922461126557696a  b c   - 676927478164365508608a  b c
+--R                + 
+--R                                        12 9 12                         11 11 11
+--R                  546073570406018580480a  b c   - 282644228028814589952a  b  c
+--R                + 
+--R                                       10 13 10                        9 15 9
+--R                  99676215691783962624a  b  c   - 24684324213328183296a b  c
+--R                + 
+--R                                      8 17 8                      7 19 7
+--R                  4345605828271669248a b  c  - 543725555401359360a b  c
+--R                + 
+--R                                    6 21 6                    5 23 5
+--R                  47898027481890816a b  c  - 2925152100679680a b  c
+--R                + 
+--R                                  4 25 4                 3 27 3
+--R                  121589310947328a b  c  - 3359585009664a b  c
+--R                + 
+--R                              2 29 2               31            33
+--R                  59016314880a b  c  - 597196800a b  c + 2654208b
+--R             *
+--R                ROOT
+--R                                            15 10                  14 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            13 4 8                  12 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            11 8 6                 10 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          9 12 4                8 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 15 10                  14 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 13 4 8                  12 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 11 8 6                 10 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               9 12 4                8 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              7 16 2             6 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           5 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                          +--------------------+
+--R                                            +-----------+ |   +-----------+
+--R              3 2       2 2         4 4+-+3 |          2 4|   |          2
+--R         (256a c  - 128a b c + 16a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          15 10                  14 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          13 4 8                  12 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          11 8 6                 10 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        9 12 4                8 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                  25 20
+--R                      - 2040062320599686732316672a  c
+--R                    + 
+--R                                                 24 2 19
+--R                      48621485307625867120214016a  b c
+--R                    + 
+--R                                                    23 4 18
+--R                      - 152527715030206670757167104a  b c
+--R                    + 
+--R                                                  22 6 17
+--R                      227476393479830809943736320a  b c
+--R                    + 
+--R                                                    21 8 16
+--R                      - 201244828259110648192958464a  b c
+--R                    + 
+--R                                                  20 10 15
+--R                      111188709134976155262124032a  b  c
+--R                    + 
+--R                                                   19 12 14
+--R                      - 34190154696905115861778432a  b  c
+--R                    + 
+--R                                                 18 14 13
+--R                      - 127134960156006229737472a  b  c
+--R                    + 
+--R                                                17 16 12
+--R                      6158710680953993381806080a  b  c
+--R                    + 
+--R                                                  16 18 11
+--R                      - 3643263083438260829028352a  b  c
+--R                    + 
+--R                                                15 20 10
+--R                      1296952961758430775738368a  b  c
+--R                    + 
+--R                                                 14 22 9
+--R                      - 328971163360003895590912a  b  c
+--R                    + 
+--R                                              13 24 8
+--R                      62441093782400734855168a  b  c
+--R                    + 
+--R                                               12 26 7
+--R                      - 8999768315355830681600a  b  c
+--R                    + 
+--R                                            11 28 6
+--R                      982839686979479666688a  b  c
+--R                    + 
+--R                                             10 30 5
+--R                      - 80138177669337448448a  b  c
+--R                    + 
+--R                                          9 32 4                      8 34 3
+--R                      4746741230690369536a b  c  - 195563536162750464a b  c
+--R                    + 
+--R                                       7 36 2                  6 38
+--R                      5239172906352640a b  c  - 81363860455424a b  c
+--R                    + 
+--R                                   5 40
+--R                      549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                        16   16                         15 3 15
+--R                  - 3116402981210161152a  b c   + 142135388747184734208a  b c
+--R                + 
+--R                                          14 5 14
+--R                  - 476947922461126557696a  b c
+--R                + 
+--R                                        13 7 13                         12 9 12
+--R                  676927478164365508608a  b c   - 546073570406018580480a  b c
+--R                + 
+--R                                        11 11 11                        10 13 10
+--R                  282644228028814589952a  b  c   - 99676215691783962624a  b  c
+--R                + 
+--R                                       9 15 9                       8 17 8
+--R                  24684324213328183296a b  c  - 4345605828271669248a b  c
+--R                + 
+--R                                     7 19 7                     6 21 6
+--R                  543725555401359360a b  c  - 47898027481890816a b  c
+--R                + 
+--R                                   5 23 5                   4 25 4
+--R                  2925152100679680a b  c  - 121589310947328a b  c
+--R                + 
+--R                                3 27 3               2 29 2               31
+--R                  3359585009664a b  c  - 59016314880a b  c  + 597196800a b  c
+--R                + 
+--R                            33
+--R                  - 2654208b
+--R             *
+--R                ROOT
+--R                                            15 10                  14 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            13 4 8                  12 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            11 8 6                 10 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          9 12 4                8 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 15 10                  14 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 13 4 8                  12 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 11 8 6                 10 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               9 12 4                8 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              7 16 2             6 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           5 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                              +-----------+
+--R                3 2       2 2         4 4+-+3 |          2
+--R         (- 256a c  + 128a b c - 16a b )\|2  \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        15 10                  14 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        13 4 8                  12 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        11 8 6                 10 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      9 12 4                8 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     7 16 2             6 18             5 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                                  25 20
+--R                      - 2040062320599686732316672a  c
+--R                    + 
+--R                                                 24 2 19
+--R                      48621485307625867120214016a  b c
+--R                    + 
+--R                                                    23 4 18
+--R                      - 152527715030206670757167104a  b c
+--R                    + 
+--R                                                  22 6 17
+--R                      227476393479830809943736320a  b c
+--R                    + 
+--R                                                    21 8 16
+--R                      - 201244828259110648192958464a  b c
+--R                    + 
+--R                                                  20 10 15
+--R                      111188709134976155262124032a  b  c
+--R                    + 
+--R                                                   19 12 14
+--R                      - 34190154696905115861778432a  b  c
+--R                    + 
+--R                                                 18 14 13
+--R                      - 127134960156006229737472a  b  c
+--R                    + 
+--R                                                17 16 12
+--R                      6158710680953993381806080a  b  c
+--R                    + 
+--R                                                  16 18 11
+--R                      - 3643263083438260829028352a  b  c
+--R                    + 
+--R                                                15 20 10
+--R                      1296952961758430775738368a  b  c
+--R                    + 
+--R                                                 14 22 9
+--R                      - 328971163360003895590912a  b  c
+--R                    + 
+--R                                              13 24 8
+--R                      62441093782400734855168a  b  c
+--R                    + 
+--R                                               12 26 7
+--R                      - 8999768315355830681600a  b  c
+--R                    + 
+--R                                            11 28 6
+--R                      982839686979479666688a  b  c
+--R                    + 
+--R                                             10 30 5
+--R                      - 80138177669337448448a  b  c
+--R                    + 
+--R                                          9 32 4                      8 34 3
+--R                      4746741230690369536a b  c  - 195563536162750464a b  c
+--R                    + 
+--R                                       7 36 2                  6 38
+--R                      5239172906352640a b  c  - 81363860455424a b  c
+--R                    + 
+--R                                   5 40
+--R                      549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                      16   16                         15 3 15
+--R                  3116402981210161152a  b c   - 142135388747184734208a  b c
+--R                + 
+--R                                        14 5 14                         13 7 13
+--R                  476947922461126557696a  b c   - 676927478164365508608a  b c
+--R                + 
+--R                                        12 9 12                         11 11 11
+--R                  546073570406018580480a  b c   - 282644228028814589952a  b  c
+--R                + 
+--R                                       10 13 10                        9 15 9
+--R                  99676215691783962624a  b  c   - 24684324213328183296a b  c
+--R                + 
+--R                                      8 17 8                      7 19 7
+--R                  4345605828271669248a b  c  - 543725555401359360a b  c
+--R                + 
+--R                                    6 21 6                    5 23 5
+--R                  47898027481890816a b  c  - 2925152100679680a b  c
+--R                + 
+--R                                  4 25 4                 3 27 3
+--R                  121589310947328a b  c  - 3359585009664a b  c
+--R                + 
+--R                              2 29 2               31            33
+--R                  59016314880a b  c  - 597196800a b  c + 2654208b
+--R             *
+--R                ROOT
+--R                                          15 10                  14 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          13 4 8                  12 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          11 8 6                 10 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        9 12 4                8 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               15 10                  14 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               13 4 8                  12 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               11 8 6                 10 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             9 12 4                8 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            7 16 2             6 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         5 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                          +--------------------+
+--R                                            +-----------+ |   +-----------+
+--R              3 2       2 2         4 4+-+3 |          2 4|   |          2
+--R         (512a c  - 256a b c + 32a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        15 10                  14 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        13 4 8                  12 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        11 8 6                 10 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      9 12 4                8 14 3
+--R                         901943132160a b  c  - 128849018880a b  c
+--R                       + 
+--R                                     7 16 2             6 18             5 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                25 20
+--R                      2040062320599686732316672a  c
+--R                    + 
+--R                                                   24 2 19
+--R                      - 48621485307625867120214016a  b c
+--R                    + 
+--R                                                  23 4 18
+--R                      152527715030206670757167104a  b c
+--R                    + 
+--R                                                    22 6 17
+--R                      - 227476393479830809943736320a  b c
+--R                    + 
+--R                                                  21 8 16
+--R                      201244828259110648192958464a  b c
+--R                    + 
+--R                                                    20 10 15
+--R                      - 111188709134976155262124032a  b  c
+--R                    + 
+--R                                                 19 12 14
+--R                      34190154696905115861778432a  b  c
+--R                    + 
+--R                                               18 14 13
+--R                      127134960156006229737472a  b  c
+--R                    + 
+--R                                                  17 16 12
+--R                      - 6158710680953993381806080a  b  c
+--R                    + 
+--R                                                16 18 11
+--R                      3643263083438260829028352a  b  c
+--R                    + 
+--R                                                  15 20 10
+--R                      - 1296952961758430775738368a  b  c
+--R                    + 
+--R                                               14 22 9
+--R                      328971163360003895590912a  b  c
+--R                    + 
+--R                                                13 24 8
+--R                      - 62441093782400734855168a  b  c
+--R                    + 
+--R                                             12 26 7
+--R                      8999768315355830681600a  b  c
+--R                    + 
+--R                                              11 28 6
+--R                      - 982839686979479666688a  b  c
+--R                    + 
+--R                                           10 30 5                       9 32 4
+--R                      80138177669337448448a  b  c  - 4746741230690369536a b  c
+--R                    + 
+--R                                         8 34 3                    7 36 2
+--R                      195563536162750464a b  c  - 5239172906352640a b  c
+--R                    + 
+--R                                     6 38                 5 40
+--R                      81363860455424a b  c - 549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                        16   16                         15 3 15
+--R                  - 3116402981210161152a  b c   + 142135388747184734208a  b c
+--R                + 
+--R                                          14 5 14
+--R                  - 476947922461126557696a  b c
+--R                + 
+--R                                        13 7 13                         12 9 12
+--R                  676927478164365508608a  b c   - 546073570406018580480a  b c
+--R                + 
+--R                                        11 11 11                        10 13 10
+--R                  282644228028814589952a  b  c   - 99676215691783962624a  b  c
+--R                + 
+--R                                       9 15 9                       8 17 8
+--R                  24684324213328183296a b  c  - 4345605828271669248a b  c
+--R                + 
+--R                                     7 19 7                     6 21 6
+--R                  543725555401359360a b  c  - 47898027481890816a b  c
+--R                + 
+--R                                   5 23 5                   4 25 4
+--R                  2925152100679680a b  c  - 121589310947328a b  c
+--R                + 
+--R                                3 27 3               2 29 2               31
+--R                  3359585009664a b  c  - 59016314880a b  c  + 597196800a b  c
+--R                + 
+--R                            33
+--R                  - 2654208b
+--R             *
+--R                ROOT
+--R                                          15 10                  14 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          13 4 8                  12 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          11 8 6                 10 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        9 12 4                8 14 3
+--R                           901943132160a b  c  - 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                           12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               15 10                  14 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               13 4 8                  12 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               11 8 6                 10 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             9 12 4                8 14 3
+--R                                901943132160a b  c  - 128849018880a b  c
+--R                              + 
+--R                                            7 16 2             6 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         5 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                              +-----------+
+--R                3 2       2 2         4 4+-+3 |          2
+--R         (- 512a c  + 256a b c - 32a b )\|2  \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          15 10                  14 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          13 4 8                  12 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          11 8 6                 10 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        9 12 4                8 14 3
+--R                         - 901943132160a b  c  + 128849018880a b  c
+--R                       + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                            8 8                7 2 7
+--R                              - 11019960576a c  + 929350008576a b c
+--R                            + 
+--R                                               6 4 6                 5 6 5
+--R                              - 19661973517152a b c  + 2876637697488a b c
+--R                            + 
+--R                                             4 8 4              3 10 3
+--R                              - 182194672545a b c  + 6345943542a b  c
+--R                            + 
+--R                                          2 12 2             14         16
+--R                              - 127722987a b  c  + 1404054a b  c - 6561b
+--R                         /
+--R                                                       25 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          24 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        23 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          22 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        21 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         20 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       19 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         18 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      17 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       16 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    15 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     14 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  13 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   12 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                              6   6             5 3 5            4 5 4
+--R                     36391680a b c  - 234524160a b c  - 54284256a b c
+--R                   + 
+--R                             3 7 3          2 9 2          11       13
+--R                     7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                /
+--R                                   15 10                  14 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    13 4 8                  12 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   11 8 6                 10 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  9 12 4               8 14 3
+--R                     450971566080a b  c  - 64424509440a b  c
+--R                   + 
+--R                                7 16 2             6 18            5 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                25 20
+--R                      2040062320599686732316672a  c
+--R                    + 
+--R                                                   24 2 19
+--R                      - 48621485307625867120214016a  b c
+--R                    + 
+--R                                                  23 4 18
+--R                      152527715030206670757167104a  b c
+--R                    + 
+--R                                                    22 6 17
+--R                      - 227476393479830809943736320a  b c
+--R                    + 
+--R                                                  21 8 16
+--R                      201244828259110648192958464a  b c
+--R                    + 
+--R                                                    20 10 15
+--R                      - 111188709134976155262124032a  b  c
+--R                    + 
+--R                                                 19 12 14
+--R                      34190154696905115861778432a  b  c
+--R                    + 
+--R                                               18 14 13
+--R                      127134960156006229737472a  b  c
+--R                    + 
+--R                                                  17 16 12
+--R                      - 6158710680953993381806080a  b  c
+--R                    + 
+--R                                                16 18 11
+--R                      3643263083438260829028352a  b  c
+--R                    + 
+--R                                                  15 20 10
+--R                      - 1296952961758430775738368a  b  c
+--R                    + 
+--R                                               14 22 9
+--R                      328971163360003895590912a  b  c
+--R                    + 
+--R                                                13 24 8
+--R                      - 62441093782400734855168a  b  c
+--R                    + 
+--R                                             12 26 7
+--R                      8999768315355830681600a  b  c
+--R                    + 
+--R                                              11 28 6
+--R                      - 982839686979479666688a  b  c
+--R                    + 
+--R                                           10 30 5                       9 32 4
+--R                      80138177669337448448a  b  c  - 4746741230690369536a b  c
+--R                    + 
+--R                                         8 34 3                    7 36 2
+--R                      195563536162750464a b  c  - 5239172906352640a b  c
+--R                    + 
+--R                                     6 38                 5 40
+--R                      81363860455424a b  c - 549755813888a b
+--R                 *
+--R                    ROOT
+--R                                         8 8                7 2 7
+--R                           - 11019960576a c  + 929350008576a b c
+--R                         + 
+--R                                            6 4 6                 5 6 5
+--R                           - 19661973517152a b c  + 2876637697488a b c
+--R                         + 
+--R                                          4 8 4              3 10 3
+--R                           - 182194672545a b c  + 6345943542a b  c
+--R                         + 
+--R                                       2 12 2             14         16
+--R                           - 127722987a b  c  + 1404054a b  c - 6561b
+--R                      /
+--R                                                    25 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       24 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     23 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       22 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     21 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      20 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    19 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      18 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   17 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    16 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 15 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  14 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               13 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                12 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             11 28                    10 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                      16   16                         15 3 15
+--R                  3116402981210161152a  b c   - 142135388747184734208a  b c
+--R                + 
+--R                                        14 5 14                         13 7 13
+--R                  476947922461126557696a  b c   - 676927478164365508608a  b c
+--R                + 
+--R                                        12 9 12                         11 11 11
+--R                  546073570406018580480a  b c   - 282644228028814589952a  b  c
+--R                + 
+--R                                       10 13 10                        9 15 9
+--R                  99676215691783962624a  b  c   - 24684324213328183296a b  c
+--R                + 
+--R                                      8 17 8                      7 19 7
+--R                  4345605828271669248a b  c  - 543725555401359360a b  c
+--R                + 
+--R                                    6 21 6                    5 23 5
+--R                  47898027481890816a b  c  - 2925152100679680a b  c
+--R                + 
+--R                                  4 25 4                 3 27 3
+--R                  121589310947328a b  c  - 3359585009664a b  c
+--R                + 
+--R                              2 29 2               31            33
+--R                  59016314880a b  c  - 597196800a b  c + 2654208b
+--R             *
+--R                ROOT
+--R                                            15 10                  14 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            13 4 8                  12 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            11 8 6                 10 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          9 12 4                8 14 3
+--R                           - 901943132160a b  c  + 128849018880a b  c
+--R                         + 
+--R                                       7 16 2             6 18             5 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                              8 8                7 2 7
+--R                                - 11019960576a c  + 929350008576a b c
+--R                              + 
+--R                                                 6 4 6                 5 6 5
+--R                                - 19661973517152a b c  + 2876637697488a b c
+--R                              + 
+--R                                               4 8 4              3 10 3
+--R                                - 182194672545a b c  + 6345943542a b  c
+--R                              + 
+--R                                            2 12 2             14         16
+--R                                - 127722987a b  c  + 1404054a b  c - 6561b
+--R                           /
+--R                                                         25 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            24 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          23 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            22 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          21 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           20 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         19 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           18 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        17 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         16 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      15 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       14 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    13 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     12 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                11 28                    10 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                6   6             5 3 5            4 5 4
+--R                       36391680a b c  - 234524160a b c  - 54284256a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11       13
+--R                       7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                  /
+--R                                     15 10                  14 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      13 4 8                  12 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     11 8 6                 10 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    9 12 4               8 14 3
+--R                       450971566080a b  c  - 64424509440a b  c
+--R                     + 
+--R                                  7 16 2             6 18            5 20
+--R                       6039797760a b  c  - 335544320a b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 15 10                  14 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 13 4 8                  12 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 11 8 6                 10 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               9 12 4                8 14 3
+--R                                - 901943132160a b  c  + 128849018880a b  c
+--R                              + 
+--R                                              7 16 2             6 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           5 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                   8 8                7 2 7
+--R                                     - 11019960576a c  + 929350008576a b c
+--R                                   + 
+--R                                                      6 4 6
+--R                                     - 19661973517152a b c
+--R                                   + 
+--R                                                   5 6 5                4 8 4
+--R                                     2876637697488a b c  - 182194672545a b c
+--R                                   + 
+--R                                                3 10 3             2 12 2
+--R                                     6345943542a b  c  - 127722987a b  c
+--R                                   + 
+--R                                               14         16
+--R                                     1404054a b  c - 6561b
+--R                                /
+--R                                                              25 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 24 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               23 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 22 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               21 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                20 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              19 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                18 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             17 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              16 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           15 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            14 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         13 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          12 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       11 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       10 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                     6   6             5 3 5            4 5 4
+--R                            36391680a b c  - 234524160a b c  - 54284256a b c
+--R                          + 
+--R                                    3 7 3          2 9 2          11       13
+--R                            7935408a b c  - 413829a b c  + 9477a b  c - 81b
+--R                       /
+--R                                          15 10                  14 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           13 4 8                  12 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          11 8 6                 10 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         9 12 4               8 14 3
+--R                            450971566080a b  c  - 64424509440a b  c
+--R                          + 
+--R                                       7 16 2             6 18            5 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                                10 14                   9 2 13
+--R                  8463329722368a  c   - 155161044910080a b c
+--R                + 
+--R                                     8 4 12                     7 6 11
+--R                  - 6883638781132800a b c   - 62523232888872960a b c
+--R                + 
+--R                                       6 8 10                     5 10 9
+--R                  - 169843343055367680a b c   + 30894046022780928a b  c
+--R                + 
+--R                                     4 12 8                  3 14 7
+--R                  - 2300916162767040a b  c  + 91725707080800a b  c
+--R                + 
+--R                                  2 16 6                 18 5             20 4
+--R                  - 2075075059005a b  c  + 25297477335a b  c  - 129730653b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                            +------------------+
+--R                        +-----------+                       | +-----------+
+--R                     2  |          2                 3 4+-+4| |          2
+--R         ((36a c + 3b )\|- 4a c + b   + 204a b c - 3b )\|c \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                     2  |          2                 3 4+-+
+--R         ((36a c + 3b )\|- 4a c + b   - 204a b c + 3b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                          +-----------+
+--R                       2  |          2                 3 4+-+
+--R         ((- 36a c - 3b )\|- 4a c + b   - 204a b c + 3b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                          +-----------+
+--R                       2  |          2                 3 4+-+
+--R         ((- 36a c - 3b )\|- 4a c + b   + 204a b c - 3b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R  /
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R            3 2       2 2         4 4+-+3 |          2 4|   |          2
+--R       (512a c  - 256a b c + 32a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 703
+
+--S 704 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 704
+
+)clear all
+
+--S 705 of 1057
+t0:=x^(3/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R       +-+
+--R     x\|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 705
+
+--S 706 of 1057
+r0:=-3/32*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b^2+44*a*c-b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*a*(b^2-4*a*c)^2*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))-3/32*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))*(b^2+44*a*c-b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*a*(b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(3/4))-3/32*c^(3/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b^2+44*a*c+_
+   b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*a*(b^2-4*a*c)^2*(-b+sqrt(b^2-_
+   4*a*c))^(3/4))-3/32*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(b^2+44*a*c+b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))-1/4*(b+2*c*x^2)*sqrt(x)/_
+   ((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+1/16*(b*(b^2+20*a*c)+c*(b^2+44*a*c)*_
+   x^2)*sqrt(x)/(a*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                        3     2 2  8              2     3   6
+--R               (- 132a c  - 3b c )x  + (- 264a b c  - 6b c)x
+--R             + 
+--R                      2 2         2      4  4          2          3  2       3
+--R               (- 264a c  - 138a b c - 3b )x  + (- 264a b c - 6a b )x  - 132a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2     4   6
+--R           (- 204a b c  + 3b c )x  + (- 408a b c  + 6b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2        4  2       3
+--R           (- 408a b c  - 198a b c + 3b )x  + (- 408a b c + 6a b )x  - 204a b c
+--R         + 
+--R             2 3
+--R           3a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                  4+-+4+-+ +-+
+--R         4+-+3 4| |          2                   \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                        3     2 2  8              2     3   6
+--R               (- 132a c  - 3b c )x  + (- 264a b c  - 6b c)x
+--R             + 
+--R                      2 2         2      4  4          2          3  2       3
+--R               (- 264a c  - 138a b c - 3b )x  + (- 264a b c - 6a b )x  - 132a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2     4   6
+--R           (204a b c  - 3b c )x  + (408a b c  - 6b c)x
+--R         + 
+--R                2   2         3      5  4        2 2        4  2       3
+--R           (408a b c  + 198a b c - 3b )x  + (408a b c - 6a b )x  + 204a b c
+--R         + 
+--R               2 3
+--R           - 3a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                  \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                        3     2 2  8              2     3   6
+--R               (- 132a c  - 3b c )x  + (- 264a b c  - 6b c)x
+--R             + 
+--R                      2 2         2      4  4          2          3  2       3
+--R               (- 264a c  - 138a b c - 3b )x  + (- 264a b c - 6a b )x  - 132a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2     4   6
+--R           (- 204a b c  + 3b c )x  + (- 408a b c  + 6b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2        4  2       3
+--R           (- 408a b c  - 198a b c + 3b )x  + (- 408a b c + 6a b )x  - 204a b c
+--R         + 
+--R             2 3
+--R           3a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4| |          2                  \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                        3     2 2  8              2     3   6
+--R               (- 132a c  - 3b c )x  + (- 264a b c  - 6b c)x
+--R             + 
+--R                      2 2         2      4  4          2          3  2       3
+--R               (- 264a c  - 138a b c - 3b )x  + (- 264a b c - 6a b )x  - 132a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2     4   6
+--R           (204a b c  - 3b c )x  + (408a b c  - 6b c)x
+--R         + 
+--R                2   2         3      5  4        2 2        4  2       3
+--R           (408a b c  + 198a b c - 3b )x  + (408a b c - 6a b )x  + 204a b c
+--R         + 
+--R               2 3
+--R           - 3a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                 \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R     + 
+--R                 3     2 2  6            2     3   4
+--R           (88a c  + 2b c )x  + (128a b c  + 4b c)x
+--R         + 
+--R                2 2        2      4  2      2          3
+--R           (152a c  + 26a b c + 2b )x  + 72a b c - 6a b
+--R      *
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2  +-+4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              3 4       2 2 3        4 2  8
+--R         (512a c  - 256a b c  + 32a b c )x
+--R       + 
+--R               3   3       2 3 2        5   6         4 3       2 4         6  4
+--R         (1024a b c  - 512a b c  + 64a b c)x  + (1024a c  - 192a b c + 32a b )x
+--R       + 
+--R               4   2       3 3       2 5  2       5 2       4 2       3 4
+--R         (1024a b c  - 512a b c + 64a b )x  + 512a c  - 256a b c + 32a b
+--R    *
+--R                          +--------------------+3  +------------------+3
+--R            +-----------+ |   +-----------+        | +-----------+
+--R       4+-+ |          2 4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  3 4      2 2 3       4 2  8
+--R           (- 128a c  + 64a b c  - 8a b c )x
+--R         + 
+--R                  3   3       2 3 2        5   6
+--R           (- 256a b c  + 128a b c  - 16a b c)x
+--R         + 
+--R                  4 3      2 4        6  4          4   2       3 3       2 5  2
+--R           (- 256a c  + 48a b c - 8a b )x  + (- 256a b c  + 128a b c - 16a b )x
+--R         + 
+--R                 5 2      4 2      3 4
+--R           - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        17 10                  16 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        15 4 8                  14 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        13 8 6                 12 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      11 12 4                10 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     9 16 2             8 18             7 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                        19 12                     18 2 11
+--R                      24769797950537728a  c   - 57983845202395136a  b c
+--R                    + 
+--R                                        17 4 10                     16 6 9
+--R                      59531957574303744a  b c   - 34656606507499520a  b c
+--R                    + 
+--R                                        15 8 8                    14 10 7
+--R                      12138608370647040a  b c  - 2335362697396224a  b  c
+--R                    + 
+--R                                     13 12 6                  12 14 5
+--R                      69269232549888a  b  c  + 89885075570688a  b  c
+--R                    + 
+--R                                       11 16 4                 10 18 3
+--R                      - 26285199851520a  b  c  + 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                    - 319975063552a b  c  + 14495514624a b  c - 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                               9   9                8 3 8               7 5 7
+--R                  233161555968a b c  - 160579584000a b c  + 28183375872a b c
+--R                + 
+--R                             6 7 6             5 9 5            4 11 4
+--R                  2307833856a b c  - 783800064a b c  - 58641408a b  c
+--R                + 
+--R                           3 13 3           2 15 2           17         19
+--R                  25278480a b  c  - 2309472a b  c  + 89424a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               17 10                  16 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               15 4 8                  14 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               13 8 6                 12 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             11 12 4                10 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            9 16 2             8 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         7 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                3 4      2 2 3       4 2  8
+--R           (128a c  - 64a b c  + 8a b c )x
+--R         + 
+--R                3   3       2 3 2        5   6        4 3      2 4        6  4
+--R           (256a b c  - 128a b c  + 16a b c)x  + (256a c  - 48a b c + 8a b )x
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (256a b c  - 128a b c + 16a b )x  + 128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          17 10                  16 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          15 4 8                  14 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          13 8 6                 12 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        11 12 4                10 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                       9 16 2             8 18             7 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                        19 12                     18 2 11
+--R                      24769797950537728a  c   - 57983845202395136a  b c
+--R                    + 
+--R                                        17 4 10                     16 6 9
+--R                      59531957574303744a  b c   - 34656606507499520a  b c
+--R                    + 
+--R                                        15 8 8                    14 10 7
+--R                      12138608370647040a  b c  - 2335362697396224a  b  c
+--R                    + 
+--R                                     13 12 6                  12 14 5
+--R                      69269232549888a  b  c  + 89885075570688a  b  c
+--R                    + 
+--R                                       11 16 4                 10 18 3
+--R                      - 26285199851520a  b  c  + 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                    - 319975063552a b  c  + 14495514624a b  c - 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                 9   9                8 3 8               7 5 7
+--R                  - 233161555968a b c  + 160579584000a b c  - 28183375872a b c
+--R                + 
+--R                               6 7 6             5 9 5            4 11 4
+--R                  - 2307833856a b c  + 783800064a b c  + 58641408a b  c
+--R                + 
+--R                             3 13 3           2 15 2           17         19
+--R                  - 25278480a b  c  + 2309472a b  c  - 89424a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 17 10                  16 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 15 4 8                  14 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 13 8 6                 12 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               11 12 4                10 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              9 16 2             8 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           7 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  3 4      2 2 3       4 2  8
+--R           (- 128a c  + 64a b c  - 8a b c )x
+--R         + 
+--R                  3   3       2 3 2        5   6
+--R           (- 256a b c  + 128a b c  - 16a b c)x
+--R         + 
+--R                  4 3      2 4        6  4          4   2       3 3       2 5  2
+--R           (- 256a c  + 48a b c - 8a b )x  + (- 256a b c  + 128a b c - 16a b )x
+--R         + 
+--R                 5 2      4 2      3 4
+--R           - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          17 10                  16 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          15 4 8                  14 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          13 8 6                 12 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        11 12 4                10 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                       9 16 2             8 18             7 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                          19 12                     18 2 11
+--R                      - 24769797950537728a  c   + 57983845202395136a  b c
+--R                    + 
+--R                                          17 4 10                     16 6 9
+--R                      - 59531957574303744a  b c   + 34656606507499520a  b c
+--R                    + 
+--R                                          15 8 8                    14 10 7
+--R                      - 12138608370647040a  b c  + 2335362697396224a  b  c
+--R                    + 
+--R                                       13 12 6                  12 14 5
+--R                      - 69269232549888a  b  c  - 89885075570688a  b  c
+--R                    + 
+--R                                     11 16 4                 10 18 3
+--R                      26285199851520a  b  c  - 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                      319975063552a b  c  - 14495514624a b  c + 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                               9   9                8 3 8               7 5 7
+--R                  233161555968a b c  - 160579584000a b c  + 28183375872a b c
+--R                + 
+--R                             6 7 6             5 9 5            4 11 4
+--R                  2307833856a b c  - 783800064a b c  - 58641408a b  c
+--R                + 
+--R                           3 13 3           2 15 2           17         19
+--R                  25278480a b  c  - 2309472a b  c  + 89424a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 17 10                  16 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 15 4 8                  14 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 13 8 6                 12 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               11 12 4                10 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              9 16 2             8 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           7 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                3 4      2 2 3       4 2  8
+--R           (128a c  - 64a b c  + 8a b c )x
+--R         + 
+--R                3   3       2 3 2        5   6        4 3      2 4        6  4
+--R           (256a b c  - 128a b c  + 16a b c)x  + (256a c  - 48a b c + 8a b )x
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (256a b c  - 128a b c + 16a b )x  + 128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        17 10                  16 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        15 4 8                  14 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        13 8 6                 12 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      11 12 4                10 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     9 16 2             8 18             7 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                          19 12                     18 2 11
+--R                      - 24769797950537728a  c   + 57983845202395136a  b c
+--R                    + 
+--R                                          17 4 10                     16 6 9
+--R                      - 59531957574303744a  b c   + 34656606507499520a  b c
+--R                    + 
+--R                                          15 8 8                    14 10 7
+--R                      - 12138608370647040a  b c  + 2335362697396224a  b  c
+--R                    + 
+--R                                       13 12 6                  12 14 5
+--R                      - 69269232549888a  b  c  - 89885075570688a  b  c
+--R                    + 
+--R                                     11 16 4                 10 18 3
+--R                      26285199851520a  b  c  - 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                      319975063552a b  c  - 14495514624a b  c + 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                 9   9                8 3 8               7 5 7
+--R                  - 233161555968a b c  + 160579584000a b c  - 28183375872a b c
+--R                + 
+--R                               6 7 6             5 9 5            4 11 4
+--R                  - 2307833856a b c  + 783800064a b c  + 58641408a b  c
+--R                + 
+--R                             3 13 3           2 15 2           17         19
+--R                  - 25278480a b  c  + 2309472a b  c  - 89424a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               17 10                  16 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               15 4 8                  14 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               13 8 6                 12 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             11 12 4                10 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            9 16 2             8 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         7 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                3 4       2 2 3        4 2  8
+--R           (256a c  - 128a b c  + 16a b c )x
+--R         + 
+--R                3   3       2 3 2        5   6        4 3      2 4         6  4
+--R           (512a b c  - 256a b c  + 32a b c)x  + (512a c  - 96a b c + 16a b )x
+--R         + 
+--R                4   2       3 3       2 5  2       5 2       4 2       3 4
+--R           (512a b c  - 256a b c + 32a b )x  + 256a c  - 128a b c + 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        17 10                  16 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        15 4 8                  14 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        13 8 6                 12 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      11 12 4                10 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     9 16 2             8 18             7 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                        19 12                     18 2 11
+--R                      24769797950537728a  c   - 57983845202395136a  b c
+--R                    + 
+--R                                        17 4 10                     16 6 9
+--R                      59531957574303744a  b c   - 34656606507499520a  b c
+--R                    + 
+--R                                        15 8 8                    14 10 7
+--R                      12138608370647040a  b c  - 2335362697396224a  b  c
+--R                    + 
+--R                                     13 12 6                  12 14 5
+--R                      69269232549888a  b  c  + 89885075570688a  b  c
+--R                    + 
+--R                                       11 16 4                 10 18 3
+--R                      - 26285199851520a  b  c  + 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                    - 319975063552a b  c  + 14495514624a b  c - 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                               9   9                8 3 8               7 5 7
+--R                  233161555968a b c  - 160579584000a b c  + 28183375872a b c
+--R                + 
+--R                             6 7 6             5 9 5            4 11 4
+--R                  2307833856a b c  - 783800064a b c  - 58641408a b  c
+--R                + 
+--R                           3 13 3           2 15 2           17         19
+--R                  25278480a b  c  - 2309472a b  c  + 89424a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               17 10                  16 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               15 4 8                  14 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               13 8 6                 12 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             11 12 4                10 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            9 16 2             8 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         7 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  3 4       2 2 3        4 2  8
+--R           (- 256a c  + 128a b c  - 16a b c )x
+--R         + 
+--R                  3   3       2 3 2        5   6
+--R           (- 512a b c  + 256a b c  - 32a b c)x
+--R         + 
+--R                  4 3      2 4         6  4
+--R           (- 512a c  + 96a b c - 16a b )x
+--R         + 
+--R                  4   2       3 3       2 5  2       5 2       4 2       3 4
+--R           (- 512a b c  + 256a b c - 32a b )x  - 256a c  + 128a b c - 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          17 10                  16 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          15 4 8                  14 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          13 8 6                 12 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        11 12 4                10 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                       9 16 2             8 18             7 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                        19 12                     18 2 11
+--R                      24769797950537728a  c   - 57983845202395136a  b c
+--R                    + 
+--R                                        17 4 10                     16 6 9
+--R                      59531957574303744a  b c   - 34656606507499520a  b c
+--R                    + 
+--R                                        15 8 8                    14 10 7
+--R                      12138608370647040a  b c  - 2335362697396224a  b  c
+--R                    + 
+--R                                     13 12 6                  12 14 5
+--R                      69269232549888a  b  c  + 89885075570688a  b  c
+--R                    + 
+--R                                       11 16 4                 10 18 3
+--R                      - 26285199851520a  b  c  + 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                    - 319975063552a b  c  + 14495514624a b  c - 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                 9   9                8 3 8               7 5 7
+--R                  - 233161555968a b c  + 160579584000a b c  - 28183375872a b c
+--R                + 
+--R                               6 7 6             5 9 5            4 11 4
+--R                  - 2307833856a b c  + 783800064a b c  + 58641408a b  c
+--R                + 
+--R                             3 13 3           2 15 2           17         19
+--R                  - 25278480a b  c  + 2309472a b  c  - 89424a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 17 10                  16 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 15 4 8                  14 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 13 8 6                 12 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               11 12 4                10 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              9 16 2             8 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           7 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                 3    2 2  6           2     3   4       2 2        2     4  2
+--R           (44a c  + b c )x  + (64a b c  + 2b c)x  + (76a c  + 13a b c + b )x
+--R         + 
+--R              2          3
+--R           36a b c - 3a b
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R            3 4       2 2 3        4 2  8        3   3       2 3 2        5   6
+--R       (256a c  - 128a b c  + 16a b c )x  + (512a b c  - 256a b c  + 32a b c)x
+--R     + 
+--R            4 3      2 4         6  4        4   2       3 3       2 5  2
+--R       (512a c  - 96a b c + 16a b )x  + (512a b c  - 256a b c + 32a b )x
+--R     + 
+--R           5 2       4 2       3 4
+--R       256a c  - 128a b c + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 707
+
+--S 708 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +-----------+
+--R                3 2       2 2         4 4+-+ |          2
+--R         (- 256a c  + 128a b c - 16a b )\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        17 10                  16 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        15 4 8                  14 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        13 8 6                 12 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      11 12 4                10 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     9 16 2             8 18             7 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                        19 12                     18 2 11
+--R                      24769797950537728a  c   - 57983845202395136a  b c
+--R                    + 
+--R                                        17 4 10                     16 6 9
+--R                      59531957574303744a  b c   - 34656606507499520a  b c
+--R                    + 
+--R                                        15 8 8                    14 10 7
+--R                      12138608370647040a  b c  - 2335362697396224a  b  c
+--R                    + 
+--R                                     13 12 6                  12 14 5
+--R                      69269232549888a  b  c  + 89885075570688a  b  c
+--R                    + 
+--R                                       11 16 4                 10 18 3
+--R                      - 26285199851520a  b  c  + 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                    - 319975063552a b  c  + 14495514624a b  c - 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                               9   9                8 3 8               7 5 7
+--R                  233161555968a b c  - 160579584000a b c  + 28183375872a b c
+--R                + 
+--R                             6 7 6             5 9 5            4 11 4
+--R                  2307833856a b c  - 783800064a b c  - 58641408a b  c
+--R                + 
+--R                           3 13 3           2 15 2           17         19
+--R                  25278480a b  c  - 2309472a b  c  + 89424a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               17 10                  16 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               15 4 8                  14 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               13 8 6                 12 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             11 12 4                10 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            9 16 2             8 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         7 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                         +--------------------+3
+--R                                           +-----------+ |   +-----------+
+--R              3 2       2 2         4 4+-+ |          2 4|   |          2
+--R         (256a c  - 128a b c + 16a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          17 10                  16 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          15 4 8                  14 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          13 8 6                 12 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        11 12 4                10 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                       9 16 2             8 18             7 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                        19 12                     18 2 11
+--R                      24769797950537728a  c   - 57983845202395136a  b c
+--R                    + 
+--R                                        17 4 10                     16 6 9
+--R                      59531957574303744a  b c   - 34656606507499520a  b c
+--R                    + 
+--R                                        15 8 8                    14 10 7
+--R                      12138608370647040a  b c  - 2335362697396224a  b  c
+--R                    + 
+--R                                     13 12 6                  12 14 5
+--R                      69269232549888a  b  c  + 89885075570688a  b  c
+--R                    + 
+--R                                       11 16 4                 10 18 3
+--R                      - 26285199851520a  b  c  + 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                    - 319975063552a b  c  + 14495514624a b  c - 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                 9   9                8 3 8               7 5 7
+--R                  - 233161555968a b c  + 160579584000a b c  - 28183375872a b c
+--R                + 
+--R                               6 7 6             5 9 5            4 11 4
+--R                  - 2307833856a b c  + 783800064a b c  + 58641408a b  c
+--R                + 
+--R                             3 13 3           2 15 2           17         19
+--R                  - 25278480a b  c  + 2309472a b  c  - 89424a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 17 10                  16 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 15 4 8                  14 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 13 8 6                 12 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               11 12 4                10 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              9 16 2             8 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           7 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +-----------+
+--R                3 2       2 2         4 4+-+ |          2
+--R         (- 256a c  + 128a b c - 16a b )\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          17 10                  16 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          15 4 8                  14 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          13 8 6                 12 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        11 12 4                10 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                       9 16 2             8 18             7 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                          19 12                     18 2 11
+--R                      - 24769797950537728a  c   + 57983845202395136a  b c
+--R                    + 
+--R                                          17 4 10                     16 6 9
+--R                      - 59531957574303744a  b c   + 34656606507499520a  b c
+--R                    + 
+--R                                          15 8 8                    14 10 7
+--R                      - 12138608370647040a  b c  + 2335362697396224a  b  c
+--R                    + 
+--R                                       13 12 6                  12 14 5
+--R                      - 69269232549888a  b  c  - 89885075570688a  b  c
+--R                    + 
+--R                                     11 16 4                 10 18 3
+--R                      26285199851520a  b  c  - 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                      319975063552a b  c  - 14495514624a b  c + 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                               9   9                8 3 8               7 5 7
+--R                  233161555968a b c  - 160579584000a b c  + 28183375872a b c
+--R                + 
+--R                             6 7 6             5 9 5            4 11 4
+--R                  2307833856a b c  - 783800064a b c  - 58641408a b  c
+--R                + 
+--R                           3 13 3           2 15 2           17         19
+--R                  25278480a b  c  - 2309472a b  c  + 89424a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 17 10                  16 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 15 4 8                  14 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 13 8 6                 12 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               11 12 4                10 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              9 16 2             8 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           7 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                         +--------------------+3
+--R                                           +-----------+ |   +-----------+
+--R              3 2       2 2         4 4+-+ |          2 4|   |          2
+--R         (256a c  - 128a b c + 16a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        17 10                  16 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        15 4 8                  14 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        13 8 6                 12 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      11 12 4                10 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     9 16 2             8 18             7 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         log
+--R                                          19 12                     18 2 11
+--R                      - 24769797950537728a  c   + 57983845202395136a  b c
+--R                    + 
+--R                                          17 4 10                     16 6 9
+--R                      - 59531957574303744a  b c   + 34656606507499520a  b c
+--R                    + 
+--R                                          15 8 8                    14 10 7
+--R                      - 12138608370647040a  b c  + 2335362697396224a  b  c
+--R                    + 
+--R                                       13 12 6                  12 14 5
+--R                      - 69269232549888a  b  c  - 89885075570688a  b  c
+--R                    + 
+--R                                     11 16 4                 10 18 3
+--R                      26285199851520a  b  c  - 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                      319975063552a b  c  - 14495514624a b  c + 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                 9   9                8 3 8               7 5 7
+--R                  - 233161555968a b c  + 160579584000a b c  - 28183375872a b c
+--R                + 
+--R                               6 7 6             5 9 5            4 11 4
+--R                  - 2307833856a b c  + 783800064a b c  + 58641408a b  c
+--R                + 
+--R                             3 13 3           2 15 2           17         19
+--R                  - 25278480a b  c  + 2309472a b  c  - 89424a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               17 10                  16 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               15 4 8                  14 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               13 8 6                 12 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             11 12 4                10 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            9 16 2             8 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         7 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R            + 
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                         +--------------------+3
+--R                                           +-----------+ |   +-----------+
+--R              3 2       2 2         4 4+-+ |          2 4|   |          2
+--R         (512a c  - 256a b c + 32a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        17 10                  16 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        15 4 8                  14 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        13 8 6                 12 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      11 12 4                10 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     9 16 2             8 18             7 20
+--R                         12079595520a b  c  - 671088640a b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                        19 12                     18 2 11
+--R                      24769797950537728a  c   - 57983845202395136a  b c
+--R                    + 
+--R                                        17 4 10                     16 6 9
+--R                      59531957574303744a  b c   - 34656606507499520a  b c
+--R                    + 
+--R                                        15 8 8                    14 10 7
+--R                      12138608370647040a  b c  - 2335362697396224a  b  c
+--R                    + 
+--R                                     13 12 6                  12 14 5
+--R                      69269232549888a  b  c  + 89885075570688a  b  c
+--R                    + 
+--R                                       11 16 4                 10 18 3
+--R                      - 26285199851520a  b  c  + 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                    - 319975063552a b  c  + 14495514624a b  c - 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                               9   9                8 3 8               7 5 7
+--R                  233161555968a b c  - 160579584000a b c  + 28183375872a b c
+--R                + 
+--R                             6 7 6             5 9 5            4 11 4
+--R                  2307833856a b c  - 783800064a b c  - 58641408a b  c
+--R                + 
+--R                           3 13 3           2 15 2           17         19
+--R                  25278480a b  c  - 2309472a b  c  + 89424a b  c - 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               17 10                  16 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               15 4 8                  14 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               13 8 6                 12 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             11 12 4                10 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            9 16 2             8 18
+--R                                12079595520a b  c  - 671088640a b  c
+--R                              + 
+--R                                         7 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +-----------+
+--R                3 2       2 2         4 4+-+ |          2
+--R         (- 512a c  + 256a b c - 32a b )\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          17 10                  16 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          15 4 8                  14 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          13 8 6                 12 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        11 12 4                10 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                       9 16 2             8 18             7 20
+--R                         - 12079595520a b  c  + 671088640a b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                10 10                   9 2 9
+--R                              - 360040606269696a  c   - 104143977020160a b c
+--R                            + 
+--R                                              8 4 8                 7 6 7
+--R                              - 1337149645920a b c  + 2463508008720a b c
+--R                            + 
+--R                                          6 8 6               5 10 5
+--R                              61767451935a b c  - 30416717268a b  c
+--R                            + 
+--R                                         4 12 4             3 14 3
+--R                              - 72105390a b  c  + 274709070a b  c
+--R                            + 
+--R                                         2 16 2            18         20
+--R                              - 19978245a b  c  + 590490a b  c - 6561b
+--R                         /
+--R                                                       29 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          28 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        27 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          26 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        25 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         24 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       23 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         22 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      21 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       20 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    19 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     18 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  17 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   16 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                15 28                    14 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                 7   7             6 3 6            5 5 5
+--R                     - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                   + 
+--R                             4 7 4          3 9 3         2 11 2          13
+--R                     3065040a b c  + 360855a b c  - 80190a b  c  + 4455a b  c
+--R                   + 
+--R                          15
+--R                     - 81b
+--R                /
+--R                                   17 10                  16 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    15 4 8                  14 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   13 8 6                 12 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  11 12 4               10 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                9 16 2             8 18            7 20
+--R                     6039797760a b  c  - 335544320a b  c + 8388608a b
+--R      *
+--R         atan
+--R                                        19 12                     18 2 11
+--R                      24769797950537728a  c   - 57983845202395136a  b c
+--R                    + 
+--R                                        17 4 10                     16 6 9
+--R                      59531957574303744a  b c   - 34656606507499520a  b c
+--R                    + 
+--R                                        15 8 8                    14 10 7
+--R                      12138608370647040a  b c  - 2335362697396224a  b  c
+--R                    + 
+--R                                     13 12 6                  12 14 5
+--R                      69269232549888a  b  c  + 89885075570688a  b  c
+--R                    + 
+--R                                       11 16 4                 10 18 3
+--R                      - 26285199851520a  b  c  + 3822520893440a  b  c
+--R                    + 
+--R                                   9 20 2               8 22              7 24
+--R                    - 319975063552a b  c  + 14495514624a b  c - 268435456a b
+--R                 *
+--R                    ROOT
+--R                                             10 10                   9 2 9
+--R                           - 360040606269696a  c   - 104143977020160a b c
+--R                         + 
+--R                                           8 4 8                 7 6 7
+--R                           - 1337149645920a b c  + 2463508008720a b c
+--R                         + 
+--R                                       6 8 6               5 10 5
+--R                           61767451935a b c  - 30416717268a b  c
+--R                         + 
+--R                                      4 12 4             3 14 3
+--R                           - 72105390a b  c  + 274709070a b  c
+--R                         + 
+--R                                      2 16 2            18         20
+--R                           - 19978245a b  c  + 590490a b  c - 6561b
+--R                      /
+--R                                                    29 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       28 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     27 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       26 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     25 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      24 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    23 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      22 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   21 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    20 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 19 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  18 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               17 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                16 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             15 28                    14 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                 9   9                8 3 8               7 5 7
+--R                  - 233161555968a b c  + 160579584000a b c  - 28183375872a b c
+--R                + 
+--R                               6 7 6             5 9 5            4 11 4
+--R                  - 2307833856a b c  + 783800064a b c  + 58641408a b  c
+--R                + 
+--R                             3 13 3           2 15 2           17         19
+--R                  - 25278480a b  c  + 2309472a b  c  - 89424a b  c + 1296b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 17 10                  16 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 15 4 8                  14 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 13 8 6                 12 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               11 12 4                10 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              9 16 2             8 18
+--R                                - 12079595520a b  c  + 671088640a b  c
+--R                              + 
+--R                                           7 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                       10 10
+--R                                     - 360040606269696a  c
+--R                                   + 
+--R                                                       9 2 9
+--R                                     - 104143977020160a b c
+--R                                   + 
+--R                                                     8 4 8                 7 6 7
+--R                                     - 1337149645920a b c  + 2463508008720a b c
+--R                                   + 
+--R                                                 6 8 6               5 10 5
+--R                                     61767451935a b c  - 30416717268a b  c
+--R                                   + 
+--R                                                4 12 4             3 14 3
+--R                                     - 72105390a b  c  + 274709070a b  c
+--R                                   + 
+--R                                                2 16 2            18         20
+--R                                     - 19978245a b  c  + 590490a b  c - 6561b
+--R                                /
+--R                                                              29 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 28 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               27 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 26 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               25 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                24 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              23 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                22 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             21 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              20 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           19 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            18 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         17 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          16 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       15 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       14 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                        7   7             6 3 6            5 5 5
+--R                            - 965986560a b c  - 103783680a b c  - 12573792a b c
+--R                          + 
+--R                                    4 7 4          3 9 3         2 11 2
+--R                            3065040a b c  + 360855a b c  - 80190a b  c
+--R                          + 
+--R                                   13       15
+--R                            4455a b  c - 81b
+--R                       /
+--R                                          17 10                  16 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           15 4 8                  14 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          13 8 6                 12 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         11 12 4               10 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                       9 16 2             8 18            7 20
+--R                            6039797760a b  c  - 335544320a b  c + 8388608a b
+--R           /
+--R                               7 9               6 2 8              5 4 7
+--R                  110205266688a c  + 59201176320a b c  + 2178174240a b c
+--R                + 
+--R                               4 6 6            3 8 5            2 10 4
+--R                  - 1064864880a b c  - 46086165a b c  + 14656302a b  c
+--R                + 
+--R                             12 3         14 2
+--R                  - 786105a b  c  + 13365b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                         +-----------+
+--R                      2  |          2                 3 4+-+3
+--R         ((132a c + 3b )\|- 4a c + b   + 204a b c - 3b )\|c
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                         +-----------+
+--R                      2  |          2                 3 4+-+3
+--R         ((132a c + 3b )\|- 4a c + b   - 204a b c + 3b )\|c
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                         +-----------+
+--R                      2  |          2                 3 4+-+3
+--R         ((132a c + 3b )\|- 4a c + b   + 204a b c - 3b )\|c
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                         +-----------+
+--R                      2  |          2                 3 4+-+3
+--R         ((132a c + 3b )\|- 4a c + b   - 204a b c + 3b )\|c
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R  /
+--R                                                       +--------------------+3
+--R                                         +-----------+ |   +-----------+
+--R            3 2       2 2         4 4+-+ |          2 4|   |          2
+--R       (512a c  - 256a b c + 32a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+3
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 708
+
+--S 709 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 709
+
+)clear all
+
+--S 710 of 1057
+t0:=x^(1/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      +-+
+--R     \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 1057
+r0:=1/4*x^(3/2)*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/16*x^(3/2)*(5*b^4-45*a*b^2*c+52*a^2*c^2+b*c*(5*b^2-44*a*c)*x^2)/_
+   (a^2*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))+1/32*c^(1/4)*atan(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(5*b^3-44*a*b*c+(5*b^4-_
+   54*a*b^2*c+520*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)^2*_
+   (-b+sqrt(b^2-4*a*c))^(1/4))-1/32*c^(1/4)*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(5*b^3-44*a*b*c+(5*b^4-_
+   54*a*b^2*c+520*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)^2*_
+   (-b+sqrt(b^2-4*a*c))^(1/4))-1/32*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))*(5*b^4-54*a*b^2*c+520*a^2*c^2-b*(5*b^2-_
+   44*a*c)*sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)^(5/2)*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+1/32*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(5*b^4-54*a*b^2*c+520*a^2*c^2-b*(5*b^2-_
+   44*a*c)*sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)^(5/2)*(-b-_
+   sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                       3     3 2  8         2 2      4   6
+--R               (44a b c  - 5b c )x  + (88a b c  - 10b c)x
+--R             + 
+--R                   2   2        3      5  4       2 2         4  2      3
+--R               (88a b c  + 34a b c - 5b )x  + (88a b c - 10a b )x  + 44a b c
+--R             + 
+--R                   2 3
+--R               - 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4        2 3     4 2  8         2   3         3 2      5   6
+--R           (520a c  - 54a b c  + 5b c )x  + (1040a b c  - 108a b c  + 10b c)x
+--R         + 
+--R                 3 3       2 2 2        4      6  4
+--R           (1040a c  + 412a b c  - 44a b c + 5b )x
+--R         + 
+--R                 3   2       2 3         5  2       4 2      3 2      2 4
+--R           (1040a b c  - 108a b c + 10a b )x  + 520a c  - 54a b c + 5a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                 4+-+4+-+ +-+
+--R         4+-+4| |          2                  \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R                       3     3 2  8         2 2      4   6
+--R               (44a b c  - 5b c )x  + (88a b c  - 10b c)x
+--R             + 
+--R                   2   2        3      5  4       2 2         4  2      3
+--R               (88a b c  + 34a b c - 5b )x  + (88a b c - 10a b )x  + 44a b c
+--R             + 
+--R                   2 3
+--R               - 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4        2 3     4 2  8
+--R           (- 520a c  + 54a b c  - 5b c )x
+--R         + 
+--R                   2   3         3 2      5   6
+--R           (- 1040a b c  + 108a b c  - 10b c)x
+--R         + 
+--R                   3 3       2 2 2        4      6  4
+--R           (- 1040a c  - 412a b c  + 44a b c - 5b )x
+--R         + 
+--R                   3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 1040a b c  + 108a b c - 10a b )x  - 520a c  + 54a b c - 5a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                4+-+4+-+ +-+
+--R         4+-+4|   |          2                 \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R     + 
+--R                         3     3 2  8           2 2      4   6
+--R               (- 44a b c  + 5b c )x  + (- 88a b c  + 10b c)x
+--R             + 
+--R                     2   2        3      5  4         2 2         4  2      3
+--R               (- 88a b c  - 34a b c + 5b )x  + (- 88a b c + 10a b )x  - 44a b c
+--R             + 
+--R                 2 3
+--R               5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4        2 3     4 2  8
+--R           (- 520a c  + 54a b c  - 5b c )x
+--R         + 
+--R                   2   3         3 2      5   6
+--R           (- 1040a b c  + 108a b c  - 10b c)x
+--R         + 
+--R                   3 3       2 2 2        4      6  4
+--R           (- 1040a c  - 412a b c  + 44a b c - 5b )x
+--R         + 
+--R                   3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 1040a b c  + 108a b c - 10a b )x  - 520a c  + 54a b c - 5a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                4+-+4+-+ +-+
+--R         4+-+4| |          2                 \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R                         3     3 2  8           2 2      4   6
+--R               (- 44a b c  + 5b c )x  + (- 88a b c  + 10b c)x
+--R             + 
+--R                     2   2        3      5  4         2 2         4  2      3
+--R               (- 88a b c  - 34a b c + 5b )x  + (- 88a b c + 10a b )x  - 44a b c
+--R             + 
+--R                 2 3
+--R               5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4        2 3     4 2  8         2   3         3 2      5   6
+--R           (520a c  - 54a b c  + 5b c )x  + (1040a b c  - 108a b c  + 10b c)x
+--R         + 
+--R                 3 3       2 2 2        4      6  4
+--R           (1040a c  + 412a b c  - 44a b c + 5b )x
+--R         + 
+--R                 3   2       2 3         5  2       4 2      3 2      2 4
+--R           (1040a b c  - 108a b c + 10a b )x  + 520a c  - 54a b c + 5a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+               4+-+4+-+ +-+
+--R         4+-+4|   |          2                \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                         4| |          2
+--R                                         \|\|- 4a c + b   - b
+--R     + 
+--R                     3      3 2  7        2 3         2 2      4   5
+--R           (- 88a b c  + 10b c )x  + (104a c  - 178a b c  + 20b c)x
+--R         + 
+--R                 2   2        3       5  3        3 2       2 2         4
+--R           (- 16a b c  - 72a b c + 10b )x  + (168a c  - 138a b c + 18a b )x
+--R      *
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R         4+-+3 |          2  +-+4|   |          2      4| |          2
+--R         \|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R              4 4       3 2 3      2 4 2  8
+--R         (512a c  - 256a b c  + 32a b c )x
+--R       + 
+--R               4   3       3 3 2      2 5   6         5 3       3 4       2 6  4
+--R         (1024a b c  - 512a b c  + 64a b c)x  + (1024a c  - 192a b c + 32a b )x
+--R       + 
+--R               5   2       4 3       3 5  2       6 2       5 2       4 4
+--R         (1024a b c  - 512a b c + 64a b )x  + 512a c  - 256a b c + 32a b
+--R    *
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R       4+-+3 |          2 4|   |          2      4| |          2
+--R       \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4 4      3 2 3     2 4 2  8
+--R           (128a c  - 64a b c  + 8a b c )x
+--R         + 
+--R                4   3       3 3 2      2 5   6        5 3      3 4      2 6  4
+--R           (256a b c  - 128a b c  + 16a b c)x  + (256a c  - 48a b c + 8a b )x
+--R         + 
+--R                5   2       4 3       3 5  2       6 2      5 2      4 4
+--R           (256a b c  - 128a b c + 16a b )x  + 128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        19 10                  18 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        17 4 8                  16 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        15 8 6                 14 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      13 12 4                12 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         log
+--R                                                    30   21
+--R                      20909694312850215077203148800a  b c
+--R                    + 
+--R                                                      29 3 20
+--R                      - 88654289356061121618793988096a  b c
+--R                    + 
+--R                                                     28 5 19
+--R                      178279485455084035119410839552a  b c
+--R                    + 
+--R                                                       27 7 18
+--R                      - 226220588728140733800993783808a  b c
+--R                    + 
+--R                                                     26 9 17
+--R                      203288075225607220142266122240a  b c
+--R                    + 
+--R                                                       25 11 16
+--R                      - 137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                    24 13 15
+--R                      72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                      23 15 14
+--R                      - 31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                    22 17 13
+--R                      10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                     21 19 12
+--R                      - 3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                  20 21 11
+--R                      736367252945436299713576960a  b  c
+--R                    + 
+--R                                                    19 23 10
+--R                      - 146855086431888465522065408a  b  c
+--R                    + 
+--R                                                 18 25 9
+--R                      24514357049286602937860096a  b  c
+--R                    + 
+--R                                                  17 27 8
+--R                      - 3419555135133139467239424a  b  c
+--R                    + 
+--R                                               16 29 7
+--R                      396607010130838840934400a  b  c
+--R                    + 
+--R                                                15 31 6
+--R                      - 37900231252370805227520a  b  c
+--R                    + 
+--R                                             14 33 5
+--R                      2941012783016542470144a  b  c
+--R                    + 
+--R                                              13 35 4
+--R                      - 181196028606601494528a  b  c
+--R                    + 
+--R                                          12 37 3                      11 39 2
+--R                      8554782655504187392a  b  c  - 291694937290833920a  b  c
+--R                    + 
+--R                                       10 41                   9 43
+--R                      6418399127142400a  b  c - 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                               20 20
+--R                  - 10780113135500001280000000a  c
+--R                + 
+--R                                             19 2 19
+--R                  33170216754978435891200000a  b c
+--R                + 
+--R                                               18 4 18
+--R                  - 48254732478145911324672000a  b c
+--R                + 
+--R                                             17 6 17
+--R                  44198328970165215916195840a  b c
+--R                + 
+--R                                               16 8 16
+--R                  - 28637025254743177957474304a  b c
+--R                + 
+--R                                             15 10 15
+--R                  13979402138696627708231680a  b  c
+--R                + 
+--R                                              14 12 14
+--R                  - 5346206978427560872902656a  b  c
+--R                + 
+--R                                            13 14 13
+--R                  1643895353910618543357952a  b  c
+--R                + 
+--R                                             12 16 12
+--R                  - 413715047455607465443328a  b  c
+--R                + 
+--R                                          11 18 11
+--R                  86253810729242628980736a  b  c
+--R                + 
+--R                                            10 20 10
+--R                  - 15012088267021630832640a  b  c
+--R                + 
+--R                                         9 22 9                         8 24 8
+--R                  2189734309854853464064a b  c  - 267787636325308039168a b  c
+--R                + 
+--R                                       7 26 7                       6 28 6
+--R                  27364698683945418752a b  c  - 2318870299625390080a b  c
+--R                + 
+--R                                     5 30 5                    4 32 4
+--R                  160814019628236800a b  c  - 8936272936960000a b  c
+--R                + 
+--R                                  3 34 3                  2 36 2
+--R                  384642252800000a b  c  - 12109414400000a b  c
+--R                + 
+--R                                 38               40
+--R                  249856000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                          19 10                  18 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          17 4 8                  16 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          15 8 6                 14 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        13 12 4                12 14 3
+--R                           901943132160a  b  c  - 128849018880a  b  c
+--R                         + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               19 10                  18 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               17 4 8                  16 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               15 8 6                 14 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             13 12 4                12 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            11 16 2             10 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         9 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R            + 
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  4 4      3 2 3     2 4 2  8
+--R           (- 128a c  + 64a b c  - 8a b c )x
+--R         + 
+--R                  4   3       3 3 2      2 5   6
+--R           (- 256a b c  + 128a b c  - 16a b c)x
+--R         + 
+--R                  5 3      3 4      2 6  4          5   2       4 3       3 5  2
+--R           (- 256a c  + 48a b c - 8a b )x  + (- 256a b c  + 128a b c - 16a b )x
+--R         + 
+--R                 6 2      5 2      4 4
+--R           - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          19 10                  18 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          17 4 8                  16 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          15 8 6                 14 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        13 12 4                12 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         log
+--R                                                    30   21
+--R                      20909694312850215077203148800a  b c
+--R                    + 
+--R                                                      29 3 20
+--R                      - 88654289356061121618793988096a  b c
+--R                    + 
+--R                                                     28 5 19
+--R                      178279485455084035119410839552a  b c
+--R                    + 
+--R                                                       27 7 18
+--R                      - 226220588728140733800993783808a  b c
+--R                    + 
+--R                                                     26 9 17
+--R                      203288075225607220142266122240a  b c
+--R                    + 
+--R                                                       25 11 16
+--R                      - 137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                    24 13 15
+--R                      72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                      23 15 14
+--R                      - 31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                    22 17 13
+--R                      10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                     21 19 12
+--R                      - 3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                  20 21 11
+--R                      736367252945436299713576960a  b  c
+--R                    + 
+--R                                                    19 23 10
+--R                      - 146855086431888465522065408a  b  c
+--R                    + 
+--R                                                 18 25 9
+--R                      24514357049286602937860096a  b  c
+--R                    + 
+--R                                                  17 27 8
+--R                      - 3419555135133139467239424a  b  c
+--R                    + 
+--R                                               16 29 7
+--R                      396607010130838840934400a  b  c
+--R                    + 
+--R                                                15 31 6
+--R                      - 37900231252370805227520a  b  c
+--R                    + 
+--R                                             14 33 5
+--R                      2941012783016542470144a  b  c
+--R                    + 
+--R                                              13 35 4
+--R                      - 181196028606601494528a  b  c
+--R                    + 
+--R                                          12 37 3                      11 39 2
+--R                      8554782655504187392a  b  c  - 291694937290833920a  b  c
+--R                    + 
+--R                                       10 41                   9 43
+--R                      6418399127142400a  b  c - 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                             20 20
+--R                  10780113135500001280000000a  c
+--R                + 
+--R                                               19 2 19
+--R                  - 33170216754978435891200000a  b c
+--R                + 
+--R                                             18 4 18
+--R                  48254732478145911324672000a  b c
+--R                + 
+--R                                               17 6 17
+--R                  - 44198328970165215916195840a  b c
+--R                + 
+--R                                             16 8 16
+--R                  28637025254743177957474304a  b c
+--R                + 
+--R                                               15 10 15
+--R                  - 13979402138696627708231680a  b  c
+--R                + 
+--R                                            14 12 14
+--R                  5346206978427560872902656a  b  c
+--R                + 
+--R                                              13 14 13
+--R                  - 1643895353910618543357952a  b  c
+--R                + 
+--R                                           12 16 12
+--R                  413715047455607465443328a  b  c
+--R                + 
+--R                                            11 18 11
+--R                  - 86253810729242628980736a  b  c
+--R                + 
+--R                                          10 20 10
+--R                  15012088267021630832640a  b  c
+--R                + 
+--R                                           9 22 9                         8 24 8
+--R                  - 2189734309854853464064a b  c  + 267787636325308039168a b  c
+--R                + 
+--R                                         7 26 7                       6 28 6
+--R                  - 27364698683945418752a b  c  + 2318870299625390080a b  c
+--R                + 
+--R                                       5 30 5                    4 32 4
+--R                  - 160814019628236800a b  c  + 8936272936960000a b  c
+--R                + 
+--R                                    3 34 3                  2 36 2
+--R                  - 384642252800000a b  c  + 12109414400000a b  c
+--R                + 
+--R                                   38               40
+--R                  - 249856000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                            19 10                  18 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            17 4 8                  16 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            15 8 6                 14 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          13 12 4                12 14 3
+--R                           - 901943132160a  b  c  + 128849018880a  b  c
+--R                         + 
+--R                                         11 16 2             10 18
+--R                           - 12079595520a  b  c  + 671088640a  b  c
+--R                         + 
+--R                                      9 20
+--R                           - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 19 10                  18 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 17 4 8                  16 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 15 8 6                 14 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               13 12 4                12 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              11 16 2             10 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           9 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R            + 
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                4 4      3 2 3     2 4 2  8
+--R           (128a c  - 64a b c  + 8a b c )x
+--R         + 
+--R                4   3       3 3 2      2 5   6        5 3      3 4      2 6  4
+--R           (256a b c  - 128a b c  + 16a b c)x  + (256a c  - 48a b c + 8a b )x
+--R         + 
+--R                5   2       4 3       3 5  2       6 2      5 2      4 4
+--R           (256a b c  - 128a b c + 16a b )x  + 128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          19 10                  18 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          17 4 8                  16 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          15 8 6                 14 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        13 12 4                12 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         log
+--R                                                      30   21
+--R                      - 20909694312850215077203148800a  b c
+--R                    + 
+--R                                                    29 3 20
+--R                      88654289356061121618793988096a  b c
+--R                    + 
+--R                                                       28 5 19
+--R                      - 178279485455084035119410839552a  b c
+--R                    + 
+--R                                                     27 7 18
+--R                      226220588728140733800993783808a  b c
+--R                    + 
+--R                                                       26 9 17
+--R                      - 203288075225607220142266122240a  b c
+--R                    + 
+--R                                                     25 11 16
+--R                      137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                      24 13 15
+--R                      - 72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                    23 15 14
+--R                      31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                      22 17 13
+--R                      - 10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                   21 19 12
+--R                      3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                    20 21 11
+--R                      - 736367252945436299713576960a  b  c
+--R                    + 
+--R                                                  19 23 10
+--R                      146855086431888465522065408a  b  c
+--R                    + 
+--R                                                   18 25 9
+--R                      - 24514357049286602937860096a  b  c
+--R                    + 
+--R                                                17 27 8
+--R                      3419555135133139467239424a  b  c
+--R                    + 
+--R                                                 16 29 7
+--R                      - 396607010130838840934400a  b  c
+--R                    + 
+--R                                              15 31 6
+--R                      37900231252370805227520a  b  c
+--R                    + 
+--R                                               14 33 5
+--R                      - 2941012783016542470144a  b  c
+--R                    + 
+--R                                            13 35 4
+--R                      181196028606601494528a  b  c
+--R                    + 
+--R                                            12 37 3                      11 39 2
+--R                      - 8554782655504187392a  b  c  + 291694937290833920a  b  c
+--R                    + 
+--R                                         10 41                   9 43
+--R                      - 6418399127142400a  b  c + 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                               20 20
+--R                  - 10780113135500001280000000a  c
+--R                + 
+--R                                             19 2 19
+--R                  33170216754978435891200000a  b c
+--R                + 
+--R                                               18 4 18
+--R                  - 48254732478145911324672000a  b c
+--R                + 
+--R                                             17 6 17
+--R                  44198328970165215916195840a  b c
+--R                + 
+--R                                               16 8 16
+--R                  - 28637025254743177957474304a  b c
+--R                + 
+--R                                             15 10 15
+--R                  13979402138696627708231680a  b  c
+--R                + 
+--R                                              14 12 14
+--R                  - 5346206978427560872902656a  b  c
+--R                + 
+--R                                            13 14 13
+--R                  1643895353910618543357952a  b  c
+--R                + 
+--R                                             12 16 12
+--R                  - 413715047455607465443328a  b  c
+--R                + 
+--R                                          11 18 11
+--R                  86253810729242628980736a  b  c
+--R                + 
+--R                                            10 20 10
+--R                  - 15012088267021630832640a  b  c
+--R                + 
+--R                                         9 22 9                         8 24 8
+--R                  2189734309854853464064a b  c  - 267787636325308039168a b  c
+--R                + 
+--R                                       7 26 7                       6 28 6
+--R                  27364698683945418752a b  c  - 2318870299625390080a b  c
+--R                + 
+--R                                     5 30 5                    4 32 4
+--R                  160814019628236800a b  c  - 8936272936960000a b  c
+--R                + 
+--R                                  3 34 3                  2 36 2
+--R                  384642252800000a b  c  - 12109414400000a b  c
+--R                + 
+--R                                 38               40
+--R                  249856000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                            19 10                  18 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            17 4 8                  16 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            15 8 6                 14 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          13 12 4                12 14 3
+--R                           - 901943132160a  b  c  + 128849018880a  b  c
+--R                         + 
+--R                                         11 16 2             10 18
+--R                           - 12079595520a  b  c  + 671088640a  b  c
+--R                         + 
+--R                                      9 20
+--R                           - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 19 10                  18 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 17 4 8                  16 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 15 8 6                 14 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               13 12 4                12 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              11 16 2             10 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           9 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R            + 
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  4 4      3 2 3     2 4 2  8
+--R           (- 128a c  + 64a b c  - 8a b c )x
+--R         + 
+--R                  4   3       3 3 2      2 5   6
+--R           (- 256a b c  + 128a b c  - 16a b c)x
+--R         + 
+--R                  5 3      3 4      2 6  4          5   2       4 3       3 5  2
+--R           (- 256a c  + 48a b c - 8a b )x  + (- 256a b c  + 128a b c - 16a b )x
+--R         + 
+--R                 6 2      5 2      4 4
+--R           - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        19 10                  18 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        17 4 8                  16 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        15 8 6                 14 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      13 12 4                12 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         log
+--R                                                      30   21
+--R                      - 20909694312850215077203148800a  b c
+--R                    + 
+--R                                                    29 3 20
+--R                      88654289356061121618793988096a  b c
+--R                    + 
+--R                                                       28 5 19
+--R                      - 178279485455084035119410839552a  b c
+--R                    + 
+--R                                                     27 7 18
+--R                      226220588728140733800993783808a  b c
+--R                    + 
+--R                                                       26 9 17
+--R                      - 203288075225607220142266122240a  b c
+--R                    + 
+--R                                                     25 11 16
+--R                      137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                      24 13 15
+--R                      - 72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                    23 15 14
+--R                      31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                      22 17 13
+--R                      - 10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                   21 19 12
+--R                      3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                    20 21 11
+--R                      - 736367252945436299713576960a  b  c
+--R                    + 
+--R                                                  19 23 10
+--R                      146855086431888465522065408a  b  c
+--R                    + 
+--R                                                   18 25 9
+--R                      - 24514357049286602937860096a  b  c
+--R                    + 
+--R                                                17 27 8
+--R                      3419555135133139467239424a  b  c
+--R                    + 
+--R                                                 16 29 7
+--R                      - 396607010130838840934400a  b  c
+--R                    + 
+--R                                              15 31 6
+--R                      37900231252370805227520a  b  c
+--R                    + 
+--R                                               14 33 5
+--R                      - 2941012783016542470144a  b  c
+--R                    + 
+--R                                            13 35 4
+--R                      181196028606601494528a  b  c
+--R                    + 
+--R                                            12 37 3                      11 39 2
+--R                      - 8554782655504187392a  b  c  + 291694937290833920a  b  c
+--R                    + 
+--R                                         10 41                   9 43
+--R                      - 6418399127142400a  b  c + 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                             20 20
+--R                  10780113135500001280000000a  c
+--R                + 
+--R                                               19 2 19
+--R                  - 33170216754978435891200000a  b c
+--R                + 
+--R                                             18 4 18
+--R                  48254732478145911324672000a  b c
+--R                + 
+--R                                               17 6 17
+--R                  - 44198328970165215916195840a  b c
+--R                + 
+--R                                             16 8 16
+--R                  28637025254743177957474304a  b c
+--R                + 
+--R                                               15 10 15
+--R                  - 13979402138696627708231680a  b  c
+--R                + 
+--R                                            14 12 14
+--R                  5346206978427560872902656a  b  c
+--R                + 
+--R                                              13 14 13
+--R                  - 1643895353910618543357952a  b  c
+--R                + 
+--R                                           12 16 12
+--R                  413715047455607465443328a  b  c
+--R                + 
+--R                                            11 18 11
+--R                  - 86253810729242628980736a  b  c
+--R                + 
+--R                                          10 20 10
+--R                  15012088267021630832640a  b  c
+--R                + 
+--R                                           9 22 9                         8 24 8
+--R                  - 2189734309854853464064a b  c  + 267787636325308039168a b  c
+--R                + 
+--R                                         7 26 7                       6 28 6
+--R                  - 27364698683945418752a b  c  + 2318870299625390080a b  c
+--R                + 
+--R                                       5 30 5                    4 32 4
+--R                  - 160814019628236800a b  c  + 8936272936960000a b  c
+--R                + 
+--R                                    3 34 3                  2 36 2
+--R                  - 384642252800000a b  c  + 12109414400000a b  c
+--R                + 
+--R                                   38               40
+--R                  - 249856000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                          19 10                  18 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          17 4 8                  16 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          15 8 6                 14 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        13 12 4                12 14 3
+--R                           901943132160a  b  c  - 128849018880a  b  c
+--R                         + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               19 10                  18 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               17 4 8                  16 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               15 8 6                 14 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             13 12 4                12 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            11 16 2             10 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         9 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R            + 
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                4 4       3 2 3      2 4 2  8
+--R           (256a c  - 128a b c  + 16a b c )x
+--R         + 
+--R                4   3       3 3 2      2 5   6        5 3      3 4       2 6  4
+--R           (512a b c  - 256a b c  + 32a b c)x  + (512a c  - 96a b c + 16a b )x
+--R         + 
+--R                5   2       4 3       3 5  2       6 2       5 2       4 4
+--R           (512a b c  - 256a b c + 32a b )x  + 256a c  - 128a b c + 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        19 10                  18 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        17 4 8                  16 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        15 8 6                 14 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      13 12 4                12 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                    30   21
+--R                      20909694312850215077203148800a  b c
+--R                    + 
+--R                                                      29 3 20
+--R                      - 88654289356061121618793988096a  b c
+--R                    + 
+--R                                                     28 5 19
+--R                      178279485455084035119410839552a  b c
+--R                    + 
+--R                                                       27 7 18
+--R                      - 226220588728140733800993783808a  b c
+--R                    + 
+--R                                                     26 9 17
+--R                      203288075225607220142266122240a  b c
+--R                    + 
+--R                                                       25 11 16
+--R                      - 137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                    24 13 15
+--R                      72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                      23 15 14
+--R                      - 31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                    22 17 13
+--R                      10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                     21 19 12
+--R                      - 3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                  20 21 11
+--R                      736367252945436299713576960a  b  c
+--R                    + 
+--R                                                    19 23 10
+--R                      - 146855086431888465522065408a  b  c
+--R                    + 
+--R                                                 18 25 9
+--R                      24514357049286602937860096a  b  c
+--R                    + 
+--R                                                  17 27 8
+--R                      - 3419555135133139467239424a  b  c
+--R                    + 
+--R                                               16 29 7
+--R                      396607010130838840934400a  b  c
+--R                    + 
+--R                                                15 31 6
+--R                      - 37900231252370805227520a  b  c
+--R                    + 
+--R                                             14 33 5
+--R                      2941012783016542470144a  b  c
+--R                    + 
+--R                                              13 35 4
+--R                      - 181196028606601494528a  b  c
+--R                    + 
+--R                                          12 37 3                      11 39 2
+--R                      8554782655504187392a  b  c  - 291694937290833920a  b  c
+--R                    + 
+--R                                       10 41                   9 43
+--R                      6418399127142400a  b  c - 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                               20 20
+--R                  - 10780113135500001280000000a  c
+--R                + 
+--R                                             19 2 19
+--R                  33170216754978435891200000a  b c
+--R                + 
+--R                                               18 4 18
+--R                  - 48254732478145911324672000a  b c
+--R                + 
+--R                                             17 6 17
+--R                  44198328970165215916195840a  b c
+--R                + 
+--R                                               16 8 16
+--R                  - 28637025254743177957474304a  b c
+--R                + 
+--R                                             15 10 15
+--R                  13979402138696627708231680a  b  c
+--R                + 
+--R                                              14 12 14
+--R                  - 5346206978427560872902656a  b  c
+--R                + 
+--R                                            13 14 13
+--R                  1643895353910618543357952a  b  c
+--R                + 
+--R                                             12 16 12
+--R                  - 413715047455607465443328a  b  c
+--R                + 
+--R                                          11 18 11
+--R                  86253810729242628980736a  b  c
+--R                + 
+--R                                            10 20 10
+--R                  - 15012088267021630832640a  b  c
+--R                + 
+--R                                         9 22 9                         8 24 8
+--R                  2189734309854853464064a b  c  - 267787636325308039168a b  c
+--R                + 
+--R                                       7 26 7                       6 28 6
+--R                  27364698683945418752a b  c  - 2318870299625390080a b  c
+--R                + 
+--R                                     5 30 5                    4 32 4
+--R                  160814019628236800a b  c  - 8936272936960000a b  c
+--R                + 
+--R                                  3 34 3                  2 36 2
+--R                  384642252800000a b  c  - 12109414400000a b  c
+--R                + 
+--R                                 38               40
+--R                  249856000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                          19 10                  18 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          17 4 8                  16 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          15 8 6                 14 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        13 12 4                12 14 3
+--R                           901943132160a  b  c  - 128849018880a  b  c
+--R                         + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               19 10                  18 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               17 4 8                  16 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               15 8 6                 14 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             13 12 4                12 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            11 16 2             10 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         9 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R           /
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  4 4       3 2 3      2 4 2  8
+--R           (- 256a c  + 128a b c  - 16a b c )x
+--R         + 
+--R                  4   3       3 3 2      2 5   6
+--R           (- 512a b c  + 256a b c  - 32a b c)x
+--R         + 
+--R                  5 3      3 4       2 6  4
+--R           (- 512a c  + 96a b c - 16a b )x
+--R         + 
+--R                  5   2       4 3       3 5  2       6 2       5 2       4 4
+--R           (- 512a b c  + 256a b c - 32a b )x  - 256a c  + 128a b c - 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          19 10                  18 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          17 4 8                  16 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          15 8 6                 14 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        13 12 4                12 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                    30   21
+--R                      20909694312850215077203148800a  b c
+--R                    + 
+--R                                                      29 3 20
+--R                      - 88654289356061121618793988096a  b c
+--R                    + 
+--R                                                     28 5 19
+--R                      178279485455084035119410839552a  b c
+--R                    + 
+--R                                                       27 7 18
+--R                      - 226220588728140733800993783808a  b c
+--R                    + 
+--R                                                     26 9 17
+--R                      203288075225607220142266122240a  b c
+--R                    + 
+--R                                                       25 11 16
+--R                      - 137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                    24 13 15
+--R                      72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                      23 15 14
+--R                      - 31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                    22 17 13
+--R                      10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                     21 19 12
+--R                      - 3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                  20 21 11
+--R                      736367252945436299713576960a  b  c
+--R                    + 
+--R                                                    19 23 10
+--R                      - 146855086431888465522065408a  b  c
+--R                    + 
+--R                                                 18 25 9
+--R                      24514357049286602937860096a  b  c
+--R                    + 
+--R                                                  17 27 8
+--R                      - 3419555135133139467239424a  b  c
+--R                    + 
+--R                                               16 29 7
+--R                      396607010130838840934400a  b  c
+--R                    + 
+--R                                                15 31 6
+--R                      - 37900231252370805227520a  b  c
+--R                    + 
+--R                                             14 33 5
+--R                      2941012783016542470144a  b  c
+--R                    + 
+--R                                              13 35 4
+--R                      - 181196028606601494528a  b  c
+--R                    + 
+--R                                          12 37 3                      11 39 2
+--R                      8554782655504187392a  b  c  - 291694937290833920a  b  c
+--R                    + 
+--R                                       10 41                   9 43
+--R                      6418399127142400a  b  c - 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                             20 20
+--R                  10780113135500001280000000a  c
+--R                + 
+--R                                               19 2 19
+--R                  - 33170216754978435891200000a  b c
+--R                + 
+--R                                             18 4 18
+--R                  48254732478145911324672000a  b c
+--R                + 
+--R                                               17 6 17
+--R                  - 44198328970165215916195840a  b c
+--R                + 
+--R                                             16 8 16
+--R                  28637025254743177957474304a  b c
+--R                + 
+--R                                               15 10 15
+--R                  - 13979402138696627708231680a  b  c
+--R                + 
+--R                                            14 12 14
+--R                  5346206978427560872902656a  b  c
+--R                + 
+--R                                              13 14 13
+--R                  - 1643895353910618543357952a  b  c
+--R                + 
+--R                                           12 16 12
+--R                  413715047455607465443328a  b  c
+--R                + 
+--R                                            11 18 11
+--R                  - 86253810729242628980736a  b  c
+--R                + 
+--R                                          10 20 10
+--R                  15012088267021630832640a  b  c
+--R                + 
+--R                                           9 22 9                         8 24 8
+--R                  - 2189734309854853464064a b  c  + 267787636325308039168a b  c
+--R                + 
+--R                                         7 26 7                       6 28 6
+--R                  - 27364698683945418752a b  c  + 2318870299625390080a b  c
+--R                + 
+--R                                       5 30 5                    4 32 4
+--R                  - 160814019628236800a b  c  + 8936272936960000a b  c
+--R                + 
+--R                                    3 34 3                  2 36 2
+--R                  - 384642252800000a b  c  + 12109414400000a b  c
+--R                + 
+--R                                   38               40
+--R                  - 249856000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                            19 10                  18 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            17 4 8                  16 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            15 8 6                 14 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          13 12 4                12 14 3
+--R                           - 901943132160a  b  c  + 128849018880a  b  c
+--R                         + 
+--R                                         11 16 2             10 18
+--R                           - 12079595520a  b  c  + 671088640a  b  c
+--R                         + 
+--R                                      9 20
+--R                           - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 19 10                  18 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 17 4 8                  16 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 15 8 6                 14 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               13 12 4                12 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              11 16 2             10 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           9 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R           /
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                     3     3 2  7       2 3        2 2      4   5
+--R           (- 44a b c  + 5b c )x  + (52a c  - 89a b c  + 10b c)x
+--R         + 
+--R                2   2        3      5  3       3 2      2 2        4
+--R           (- 8a b c  - 36a b c + 5b )x  + (84a c  - 69a b c + 9a b )x
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R            4 4       3 2 3      2 4 2  8        4   3       3 3 2      2 5   6
+--R       (256a c  - 128a b c  + 16a b c )x  + (512a b c  - 256a b c  + 32a b c)x
+--R     + 
+--R            5 3      3 4       2 6  4        5   2       4 3       3 5  2
+--R       (512a c  - 96a b c + 16a b )x  + (512a b c  - 256a b c + 32a b )x
+--R     + 
+--R           6 2       5 2       4 4
+--R       256a c  - 128a b c + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 712
+
+--S 713 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +--------------------+
+--R                                            +-----------+ |   +-----------+
+--R              4 2       3 2       2 4 4+-+3 |          2 4|   |          2
+--R         (256a c  - 128a b c + 16a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        19 10                  18 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        17 4 8                  16 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        15 8 6                 14 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      13 12 4                12 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         log
+--R                                                    30   21
+--R                      20909694312850215077203148800a  b c
+--R                    + 
+--R                                                      29 3 20
+--R                      - 88654289356061121618793988096a  b c
+--R                    + 
+--R                                                     28 5 19
+--R                      178279485455084035119410839552a  b c
+--R                    + 
+--R                                                       27 7 18
+--R                      - 226220588728140733800993783808a  b c
+--R                    + 
+--R                                                     26 9 17
+--R                      203288075225607220142266122240a  b c
+--R                    + 
+--R                                                       25 11 16
+--R                      - 137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                    24 13 15
+--R                      72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                      23 15 14
+--R                      - 31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                    22 17 13
+--R                      10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                     21 19 12
+--R                      - 3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                  20 21 11
+--R                      736367252945436299713576960a  b  c
+--R                    + 
+--R                                                    19 23 10
+--R                      - 146855086431888465522065408a  b  c
+--R                    + 
+--R                                                 18 25 9
+--R                      24514357049286602937860096a  b  c
+--R                    + 
+--R                                                  17 27 8
+--R                      - 3419555135133139467239424a  b  c
+--R                    + 
+--R                                               16 29 7
+--R                      396607010130838840934400a  b  c
+--R                    + 
+--R                                                15 31 6
+--R                      - 37900231252370805227520a  b  c
+--R                    + 
+--R                                             14 33 5
+--R                      2941012783016542470144a  b  c
+--R                    + 
+--R                                              13 35 4
+--R                      - 181196028606601494528a  b  c
+--R                    + 
+--R                                          12 37 3                      11 39 2
+--R                      8554782655504187392a  b  c  - 291694937290833920a  b  c
+--R                    + 
+--R                                       10 41                   9 43
+--R                      6418399127142400a  b  c - 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                               20 20
+--R                  - 10780113135500001280000000a  c
+--R                + 
+--R                                             19 2 19
+--R                  33170216754978435891200000a  b c
+--R                + 
+--R                                               18 4 18
+--R                  - 48254732478145911324672000a  b c
+--R                + 
+--R                                             17 6 17
+--R                  44198328970165215916195840a  b c
+--R                + 
+--R                                               16 8 16
+--R                  - 28637025254743177957474304a  b c
+--R                + 
+--R                                             15 10 15
+--R                  13979402138696627708231680a  b  c
+--R                + 
+--R                                              14 12 14
+--R                  - 5346206978427560872902656a  b  c
+--R                + 
+--R                                            13 14 13
+--R                  1643895353910618543357952a  b  c
+--R                + 
+--R                                             12 16 12
+--R                  - 413715047455607465443328a  b  c
+--R                + 
+--R                                          11 18 11
+--R                  86253810729242628980736a  b  c
+--R                + 
+--R                                            10 20 10
+--R                  - 15012088267021630832640a  b  c
+--R                + 
+--R                                         9 22 9                         8 24 8
+--R                  2189734309854853464064a b  c  - 267787636325308039168a b  c
+--R                + 
+--R                                       7 26 7                       6 28 6
+--R                  27364698683945418752a b  c  - 2318870299625390080a b  c
+--R                + 
+--R                                     5 30 5                    4 32 4
+--R                  160814019628236800a b  c  - 8936272936960000a b  c
+--R                + 
+--R                                  3 34 3                  2 36 2
+--R                  384642252800000a b  c  - 12109414400000a b  c
+--R                + 
+--R                                 38               40
+--R                  249856000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                          19 10                  18 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          17 4 8                  16 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          15 8 6                 14 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        13 12 4                12 14 3
+--R                           901943132160a  b  c  - 128849018880a  b  c
+--R                         + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               19 10                  18 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               17 4 8                  16 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               15 8 6                 14 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             13 12 4                12 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            11 16 2             10 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         9 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R            + 
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                              +-----------+
+--R                4 2       3 2       2 4 4+-+3 |          2
+--R         (- 256a c  + 128a b c - 16a b )\|2  \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          19 10                  18 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          17 4 8                  16 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          15 8 6                 14 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        13 12 4                12 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         log
+--R                                                    30   21
+--R                      20909694312850215077203148800a  b c
+--R                    + 
+--R                                                      29 3 20
+--R                      - 88654289356061121618793988096a  b c
+--R                    + 
+--R                                                     28 5 19
+--R                      178279485455084035119410839552a  b c
+--R                    + 
+--R                                                       27 7 18
+--R                      - 226220588728140733800993783808a  b c
+--R                    + 
+--R                                                     26 9 17
+--R                      203288075225607220142266122240a  b c
+--R                    + 
+--R                                                       25 11 16
+--R                      - 137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                    24 13 15
+--R                      72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                      23 15 14
+--R                      - 31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                    22 17 13
+--R                      10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                     21 19 12
+--R                      - 3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                  20 21 11
+--R                      736367252945436299713576960a  b  c
+--R                    + 
+--R                                                    19 23 10
+--R                      - 146855086431888465522065408a  b  c
+--R                    + 
+--R                                                 18 25 9
+--R                      24514357049286602937860096a  b  c
+--R                    + 
+--R                                                  17 27 8
+--R                      - 3419555135133139467239424a  b  c
+--R                    + 
+--R                                               16 29 7
+--R                      396607010130838840934400a  b  c
+--R                    + 
+--R                                                15 31 6
+--R                      - 37900231252370805227520a  b  c
+--R                    + 
+--R                                             14 33 5
+--R                      2941012783016542470144a  b  c
+--R                    + 
+--R                                              13 35 4
+--R                      - 181196028606601494528a  b  c
+--R                    + 
+--R                                          12 37 3                      11 39 2
+--R                      8554782655504187392a  b  c  - 291694937290833920a  b  c
+--R                    + 
+--R                                       10 41                   9 43
+--R                      6418399127142400a  b  c - 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                             20 20
+--R                  10780113135500001280000000a  c
+--R                + 
+--R                                               19 2 19
+--R                  - 33170216754978435891200000a  b c
+--R                + 
+--R                                             18 4 18
+--R                  48254732478145911324672000a  b c
+--R                + 
+--R                                               17 6 17
+--R                  - 44198328970165215916195840a  b c
+--R                + 
+--R                                             16 8 16
+--R                  28637025254743177957474304a  b c
+--R                + 
+--R                                               15 10 15
+--R                  - 13979402138696627708231680a  b  c
+--R                + 
+--R                                            14 12 14
+--R                  5346206978427560872902656a  b  c
+--R                + 
+--R                                              13 14 13
+--R                  - 1643895353910618543357952a  b  c
+--R                + 
+--R                                           12 16 12
+--R                  413715047455607465443328a  b  c
+--R                + 
+--R                                            11 18 11
+--R                  - 86253810729242628980736a  b  c
+--R                + 
+--R                                          10 20 10
+--R                  15012088267021630832640a  b  c
+--R                + 
+--R                                           9 22 9                         8 24 8
+--R                  - 2189734309854853464064a b  c  + 267787636325308039168a b  c
+--R                + 
+--R                                         7 26 7                       6 28 6
+--R                  - 27364698683945418752a b  c  + 2318870299625390080a b  c
+--R                + 
+--R                                       5 30 5                    4 32 4
+--R                  - 160814019628236800a b  c  + 8936272936960000a b  c
+--R                + 
+--R                                    3 34 3                  2 36 2
+--R                  - 384642252800000a b  c  + 12109414400000a b  c
+--R                + 
+--R                                   38               40
+--R                  - 249856000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                            19 10                  18 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            17 4 8                  16 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            15 8 6                 14 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          13 12 4                12 14 3
+--R                           - 901943132160a  b  c  + 128849018880a  b  c
+--R                         + 
+--R                                         11 16 2             10 18
+--R                           - 12079595520a  b  c  + 671088640a  b  c
+--R                         + 
+--R                                      9 20
+--R                           - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 19 10                  18 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 17 4 8                  16 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 15 8 6                 14 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               13 12 4                12 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              11 16 2             10 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           9 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R            + 
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                          +--------------------+
+--R                                            +-----------+ |   +-----------+
+--R              4 2       3 2       2 4 4+-+3 |          2 4|   |          2
+--R         (256a c  - 128a b c + 16a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          19 10                  18 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          17 4 8                  16 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          15 8 6                 14 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        13 12 4                12 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         log
+--R                                                      30   21
+--R                      - 20909694312850215077203148800a  b c
+--R                    + 
+--R                                                    29 3 20
+--R                      88654289356061121618793988096a  b c
+--R                    + 
+--R                                                       28 5 19
+--R                      - 178279485455084035119410839552a  b c
+--R                    + 
+--R                                                     27 7 18
+--R                      226220588728140733800993783808a  b c
+--R                    + 
+--R                                                       26 9 17
+--R                      - 203288075225607220142266122240a  b c
+--R                    + 
+--R                                                     25 11 16
+--R                      137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                      24 13 15
+--R                      - 72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                    23 15 14
+--R                      31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                      22 17 13
+--R                      - 10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                   21 19 12
+--R                      3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                    20 21 11
+--R                      - 736367252945436299713576960a  b  c
+--R                    + 
+--R                                                  19 23 10
+--R                      146855086431888465522065408a  b  c
+--R                    + 
+--R                                                   18 25 9
+--R                      - 24514357049286602937860096a  b  c
+--R                    + 
+--R                                                17 27 8
+--R                      3419555135133139467239424a  b  c
+--R                    + 
+--R                                                 16 29 7
+--R                      - 396607010130838840934400a  b  c
+--R                    + 
+--R                                              15 31 6
+--R                      37900231252370805227520a  b  c
+--R                    + 
+--R                                               14 33 5
+--R                      - 2941012783016542470144a  b  c
+--R                    + 
+--R                                            13 35 4
+--R                      181196028606601494528a  b  c
+--R                    + 
+--R                                            12 37 3                      11 39 2
+--R                      - 8554782655504187392a  b  c  + 291694937290833920a  b  c
+--R                    + 
+--R                                         10 41                   9 43
+--R                      - 6418399127142400a  b  c + 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                               20 20
+--R                  - 10780113135500001280000000a  c
+--R                + 
+--R                                             19 2 19
+--R                  33170216754978435891200000a  b c
+--R                + 
+--R                                               18 4 18
+--R                  - 48254732478145911324672000a  b c
+--R                + 
+--R                                             17 6 17
+--R                  44198328970165215916195840a  b c
+--R                + 
+--R                                               16 8 16
+--R                  - 28637025254743177957474304a  b c
+--R                + 
+--R                                             15 10 15
+--R                  13979402138696627708231680a  b  c
+--R                + 
+--R                                              14 12 14
+--R                  - 5346206978427560872902656a  b  c
+--R                + 
+--R                                            13 14 13
+--R                  1643895353910618543357952a  b  c
+--R                + 
+--R                                             12 16 12
+--R                  - 413715047455607465443328a  b  c
+--R                + 
+--R                                          11 18 11
+--R                  86253810729242628980736a  b  c
+--R                + 
+--R                                            10 20 10
+--R                  - 15012088267021630832640a  b  c
+--R                + 
+--R                                         9 22 9                         8 24 8
+--R                  2189734309854853464064a b  c  - 267787636325308039168a b  c
+--R                + 
+--R                                       7 26 7                       6 28 6
+--R                  27364698683945418752a b  c  - 2318870299625390080a b  c
+--R                + 
+--R                                     5 30 5                    4 32 4
+--R                  160814019628236800a b  c  - 8936272936960000a b  c
+--R                + 
+--R                                  3 34 3                  2 36 2
+--R                  384642252800000a b  c  - 12109414400000a b  c
+--R                + 
+--R                                 38               40
+--R                  249856000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                            19 10                  18 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            17 4 8                  16 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            15 8 6                 14 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          13 12 4                12 14 3
+--R                           - 901943132160a  b  c  + 128849018880a  b  c
+--R                         + 
+--R                                         11 16 2             10 18
+--R                           - 12079595520a  b  c  + 671088640a  b  c
+--R                         + 
+--R                                      9 20
+--R                           - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 19 10                  18 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 17 4 8                  16 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 15 8 6                 14 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               13 12 4                12 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              11 16 2             10 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           9 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R            + 
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                              +-----------+
+--R                4 2       3 2       2 4 4+-+3 |          2
+--R         (- 256a c  + 128a b c - 16a b )\|2  \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        19 10                  18 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        17 4 8                  16 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        15 8 6                 14 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      13 12 4                12 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         log
+--R                                                      30   21
+--R                      - 20909694312850215077203148800a  b c
+--R                    + 
+--R                                                    29 3 20
+--R                      88654289356061121618793988096a  b c
+--R                    + 
+--R                                                       28 5 19
+--R                      - 178279485455084035119410839552a  b c
+--R                    + 
+--R                                                     27 7 18
+--R                      226220588728140733800993783808a  b c
+--R                    + 
+--R                                                       26 9 17
+--R                      - 203288075225607220142266122240a  b c
+--R                    + 
+--R                                                     25 11 16
+--R                      137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                      24 13 15
+--R                      - 72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                    23 15 14
+--R                      31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                      22 17 13
+--R                      - 10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                   21 19 12
+--R                      3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                    20 21 11
+--R                      - 736367252945436299713576960a  b  c
+--R                    + 
+--R                                                  19 23 10
+--R                      146855086431888465522065408a  b  c
+--R                    + 
+--R                                                   18 25 9
+--R                      - 24514357049286602937860096a  b  c
+--R                    + 
+--R                                                17 27 8
+--R                      3419555135133139467239424a  b  c
+--R                    + 
+--R                                                 16 29 7
+--R                      - 396607010130838840934400a  b  c
+--R                    + 
+--R                                              15 31 6
+--R                      37900231252370805227520a  b  c
+--R                    + 
+--R                                               14 33 5
+--R                      - 2941012783016542470144a  b  c
+--R                    + 
+--R                                            13 35 4
+--R                      181196028606601494528a  b  c
+--R                    + 
+--R                                            12 37 3                      11 39 2
+--R                      - 8554782655504187392a  b  c  + 291694937290833920a  b  c
+--R                    + 
+--R                                         10 41                   9 43
+--R                      - 6418399127142400a  b  c + 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                             20 20
+--R                  10780113135500001280000000a  c
+--R                + 
+--R                                               19 2 19
+--R                  - 33170216754978435891200000a  b c
+--R                + 
+--R                                             18 4 18
+--R                  48254732478145911324672000a  b c
+--R                + 
+--R                                               17 6 17
+--R                  - 44198328970165215916195840a  b c
+--R                + 
+--R                                             16 8 16
+--R                  28637025254743177957474304a  b c
+--R                + 
+--R                                               15 10 15
+--R                  - 13979402138696627708231680a  b  c
+--R                + 
+--R                                            14 12 14
+--R                  5346206978427560872902656a  b  c
+--R                + 
+--R                                              13 14 13
+--R                  - 1643895353910618543357952a  b  c
+--R                + 
+--R                                           12 16 12
+--R                  413715047455607465443328a  b  c
+--R                + 
+--R                                            11 18 11
+--R                  - 86253810729242628980736a  b  c
+--R                + 
+--R                                          10 20 10
+--R                  15012088267021630832640a  b  c
+--R                + 
+--R                                           9 22 9                         8 24 8
+--R                  - 2189734309854853464064a b  c  + 267787636325308039168a b  c
+--R                + 
+--R                                         7 26 7                       6 28 6
+--R                  - 27364698683945418752a b  c  + 2318870299625390080a b  c
+--R                + 
+--R                                       5 30 5                    4 32 4
+--R                  - 160814019628236800a b  c  + 8936272936960000a b  c
+--R                + 
+--R                                    3 34 3                  2 36 2
+--R                  - 384642252800000a b  c  + 12109414400000a b  c
+--R                + 
+--R                                   38               40
+--R                  - 249856000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                          19 10                  18 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          17 4 8                  16 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          15 8 6                 14 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        13 12 4                12 14 3
+--R                           901943132160a  b  c  - 128849018880a  b  c
+--R                         + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               19 10                  18 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               17 4 8                  16 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               15 8 6                 14 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             13 12 4                12 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            11 16 2             10 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         9 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R            + 
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                          +--------------------+
+--R                                            +-----------+ |   +-----------+
+--R              4 2       3 2       2 4 4+-+3 |          2 4|   |          2
+--R         (512a c  - 256a b c + 32a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        19 10                  18 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        17 4 8                  16 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        15 8 6                 14 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      13 12 4                12 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                    30   21
+--R                      20909694312850215077203148800a  b c
+--R                    + 
+--R                                                      29 3 20
+--R                      - 88654289356061121618793988096a  b c
+--R                    + 
+--R                                                     28 5 19
+--R                      178279485455084035119410839552a  b c
+--R                    + 
+--R                                                       27 7 18
+--R                      - 226220588728140733800993783808a  b c
+--R                    + 
+--R                                                     26 9 17
+--R                      203288075225607220142266122240a  b c
+--R                    + 
+--R                                                       25 11 16
+--R                      - 137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                    24 13 15
+--R                      72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                      23 15 14
+--R                      - 31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                    22 17 13
+--R                      10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                     21 19 12
+--R                      - 3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                  20 21 11
+--R                      736367252945436299713576960a  b  c
+--R                    + 
+--R                                                    19 23 10
+--R                      - 146855086431888465522065408a  b  c
+--R                    + 
+--R                                                 18 25 9
+--R                      24514357049286602937860096a  b  c
+--R                    + 
+--R                                                  17 27 8
+--R                      - 3419555135133139467239424a  b  c
+--R                    + 
+--R                                               16 29 7
+--R                      396607010130838840934400a  b  c
+--R                    + 
+--R                                                15 31 6
+--R                      - 37900231252370805227520a  b  c
+--R                    + 
+--R                                             14 33 5
+--R                      2941012783016542470144a  b  c
+--R                    + 
+--R                                              13 35 4
+--R                      - 181196028606601494528a  b  c
+--R                    + 
+--R                                          12 37 3                      11 39 2
+--R                      8554782655504187392a  b  c  - 291694937290833920a  b  c
+--R                    + 
+--R                                       10 41                   9 43
+--R                      6418399127142400a  b  c - 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                               20 20
+--R                  - 10780113135500001280000000a  c
+--R                + 
+--R                                             19 2 19
+--R                  33170216754978435891200000a  b c
+--R                + 
+--R                                               18 4 18
+--R                  - 48254732478145911324672000a  b c
+--R                + 
+--R                                             17 6 17
+--R                  44198328970165215916195840a  b c
+--R                + 
+--R                                               16 8 16
+--R                  - 28637025254743177957474304a  b c
+--R                + 
+--R                                             15 10 15
+--R                  13979402138696627708231680a  b  c
+--R                + 
+--R                                              14 12 14
+--R                  - 5346206978427560872902656a  b  c
+--R                + 
+--R                                            13 14 13
+--R                  1643895353910618543357952a  b  c
+--R                + 
+--R                                             12 16 12
+--R                  - 413715047455607465443328a  b  c
+--R                + 
+--R                                          11 18 11
+--R                  86253810729242628980736a  b  c
+--R                + 
+--R                                            10 20 10
+--R                  - 15012088267021630832640a  b  c
+--R                + 
+--R                                         9 22 9                         8 24 8
+--R                  2189734309854853464064a b  c  - 267787636325308039168a b  c
+--R                + 
+--R                                       7 26 7                       6 28 6
+--R                  27364698683945418752a b  c  - 2318870299625390080a b  c
+--R                + 
+--R                                     5 30 5                    4 32 4
+--R                  160814019628236800a b  c  - 8936272936960000a b  c
+--R                + 
+--R                                  3 34 3                  2 36 2
+--R                  384642252800000a b  c  - 12109414400000a b  c
+--R                + 
+--R                                 38               40
+--R                  249856000000a b  c - 2560000000b
+--R             *
+--R                ROOT
+--R                                          19 10                  18 2 9
+--R                           17592186044416a  c   - 43980465111040a  b c
+--R                         + 
+--R                                          17 4 8                  16 6 7
+--R                           49478023249920a  b c  - 32985348833280a  b c
+--R                         + 
+--R                                          15 8 6                 14 10 5
+--R                           14431090114560a  b c  - 4329327034368a  b  c
+--R                         + 
+--R                                        13 12 4                12 14 3
+--R                           901943132160a  b  c  - 128849018880a  b  c
+--R                         + 
+--R                                     11 16 2             10 18             9 20
+--R                         12079595520a  b  c  - 671088640a  b  c + 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               19 10                  18 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               17 4 8                  16 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               15 8 6                 14 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             13 12 4                12 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            11 16 2             10 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         9 20
+--R                                16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R           /
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                              +-----------+
+--R                4 2       3 2       2 4 4+-+3 |          2
+--R         (- 512a c  + 256a b c - 32a b )\|2  \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          19 10                  18 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          17 4 8                  16 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          15 8 6                 14 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        13 12 4                12 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     11 16 2             10 18             9 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a b
+--R                    *
+--R                       ROOT
+--R                                                  12 12
+--R                              - 81573072100000000a  c
+--R                            + 
+--R                                                11 2 11
+--R                              69448127892000000a  b c
+--R                            + 
+--R                                                  10 4 10
+--R                              - 31086945693180000a  b c
+--R                            + 
+--R                                               9 6 9                    8 8 8
+--R                              9269109639197200a b c  - 2023377890386401a b c
+--R                            + 
+--R                                              7 10 7                  6 12 6
+--R                              337483074473460a b  c  - 43904670504450a b  c
+--R                            + 
+--R                                            5 14 5                4 16 4
+--R                              4476152774250a b  c  - 354908559375a b  c
+--R                            + 
+--R                                          3 18 3             2 20 2
+--R                              21372793750a b  c  - 932859375a b  c
+--R                            + 
+--R                                         22           24
+--R                              26718750a b  c - 390625b
+--R                         /
+--R                                                       33 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          32 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        31 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          30 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        29 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         28 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       27 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         26 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      25 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       24 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    23 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     22 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  21 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   20 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                   8   8              7 3 7              6 5 6
+--R                     - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                   + 
+--R                               5 7 5            4 9 4           3 11 3
+--R                     536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                   + 
+--R                              2 13 2           15        17
+--R                     - 613275a b  c  + 27625a b  c - 625b
+--R                /
+--R                                   19 10                  18 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    17 4 8                  16 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   15 8 6                 14 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  13 12 4               12 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                11 16 2             10 18            9 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R      *
+--R         atan
+--R                                                    30   21
+--R                      20909694312850215077203148800a  b c
+--R                    + 
+--R                                                      29 3 20
+--R                      - 88654289356061121618793988096a  b c
+--R                    + 
+--R                                                     28 5 19
+--R                      178279485455084035119410839552a  b c
+--R                    + 
+--R                                                       27 7 18
+--R                      - 226220588728140733800993783808a  b c
+--R                    + 
+--R                                                     26 9 17
+--R                      203288075225607220142266122240a  b c
+--R                    + 
+--R                                                       25 11 16
+--R                      - 137641441962702939156192952320a  b  c
+--R                    + 
+--R                                                    24 13 15
+--R                      72936559662775677304650596352a  b  c
+--R                    + 
+--R                                                      23 15 14
+--R                      - 31015003597449054208942669824a  b  c
+--R                    + 
+--R                                                    22 17 13
+--R                      10765816028104349326692581376a  b  c
+--R                    + 
+--R                                                     21 19 12
+--R                      - 3086350118127750193023549440a  b  c
+--R                    + 
+--R                                                  20 21 11
+--R                      736367252945436299713576960a  b  c
+--R                    + 
+--R                                                    19 23 10
+--R                      - 146855086431888465522065408a  b  c
+--R                    + 
+--R                                                 18 25 9
+--R                      24514357049286602937860096a  b  c
+--R                    + 
+--R                                                  17 27 8
+--R                      - 3419555135133139467239424a  b  c
+--R                    + 
+--R                                               16 29 7
+--R                      396607010130838840934400a  b  c
+--R                    + 
+--R                                                15 31 6
+--R                      - 37900231252370805227520a  b  c
+--R                    + 
+--R                                             14 33 5
+--R                      2941012783016542470144a  b  c
+--R                    + 
+--R                                              13 35 4
+--R                      - 181196028606601494528a  b  c
+--R                    + 
+--R                                          12 37 3                      11 39 2
+--R                      8554782655504187392a  b  c  - 291694937290833920a  b  c
+--R                    + 
+--R                                       10 41                   9 43
+--R                      6418399127142400a  b  c - 68719476736000a b
+--R                 *
+--R                    ROOT
+--R                                               12 12                     11 2 11
+--R                           - 81573072100000000a  c   + 69448127892000000a  b c
+--R                         + 
+--R                                               10 4 10                    9 6 9
+--R                           - 31086945693180000a  b c   + 9269109639197200a b c
+--R                         + 
+--R                                              8 8 8                   7 10 7
+--R                           - 2023377890386401a b c  + 337483074473460a b  c
+--R                         + 
+--R                                            6 12 6                 5 14 5
+--R                           - 43904670504450a b  c  + 4476152774250a b  c
+--R                         + 
+--R                                          4 16 4               3 18 3
+--R                           - 354908559375a b  c  + 21372793750a b  c
+--R                         + 
+--R                                       2 20 2              22           24
+--R                           - 932859375a b  c  + 26718750a b  c - 390625b
+--R                      /
+--R                                                    33 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       32 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     31 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       30 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     29 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      28 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    27 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      26 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   25 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    24 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 23 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  22 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               21 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                20 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             19 28                    18 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                             20 20
+--R                  10780113135500001280000000a  c
+--R                + 
+--R                                               19 2 19
+--R                  - 33170216754978435891200000a  b c
+--R                + 
+--R                                             18 4 18
+--R                  48254732478145911324672000a  b c
+--R                + 
+--R                                               17 6 17
+--R                  - 44198328970165215916195840a  b c
+--R                + 
+--R                                             16 8 16
+--R                  28637025254743177957474304a  b c
+--R                + 
+--R                                               15 10 15
+--R                  - 13979402138696627708231680a  b  c
+--R                + 
+--R                                            14 12 14
+--R                  5346206978427560872902656a  b  c
+--R                + 
+--R                                              13 14 13
+--R                  - 1643895353910618543357952a  b  c
+--R                + 
+--R                                           12 16 12
+--R                  413715047455607465443328a  b  c
+--R                + 
+--R                                            11 18 11
+--R                  - 86253810729242628980736a  b  c
+--R                + 
+--R                                          10 20 10
+--R                  15012088267021630832640a  b  c
+--R                + 
+--R                                           9 22 9                         8 24 8
+--R                  - 2189734309854853464064a b  c  + 267787636325308039168a b  c
+--R                + 
+--R                                         7 26 7                       6 28 6
+--R                  - 27364698683945418752a b  c  + 2318870299625390080a b  c
+--R                + 
+--R                                       5 30 5                    4 32 4
+--R                  - 160814019628236800a b  c  + 8936272936960000a b  c
+--R                + 
+--R                                    3 34 3                  2 36 2
+--R                  - 384642252800000a b  c  + 12109414400000a b  c
+--R                + 
+--R                                   38               40
+--R                  - 249856000000a b  c + 2560000000b
+--R             *
+--R                ROOT
+--R                                            19 10                  18 2 9
+--R                           - 17592186044416a  c   + 43980465111040a  b c
+--R                         + 
+--R                                            17 4 8                  16 6 7
+--R                           - 49478023249920a  b c  + 32985348833280a  b c
+--R                         + 
+--R                                            15 8 6                 14 10 5
+--R                           - 14431090114560a  b c  + 4329327034368a  b  c
+--R                         + 
+--R                                          13 12 4                12 14 3
+--R                           - 901943132160a  b  c  + 128849018880a  b  c
+--R                         + 
+--R                                         11 16 2             10 18
+--R                           - 12079595520a  b  c  + 671088640a  b  c
+--R                         + 
+--R                                      9 20
+--R                           - 16777216a b
+--R                      *
+--R                         ROOT
+--R                                                    12 12
+--R                                - 81573072100000000a  c
+--R                              + 
+--R                                                  11 2 11
+--R                                69448127892000000a  b c
+--R                              + 
+--R                                                    10 4 10
+--R                                - 31086945693180000a  b c
+--R                              + 
+--R                                                 9 6 9                    8 8 8
+--R                                9269109639197200a b c  - 2023377890386401a b c
+--R                              + 
+--R                                                7 10 7                  6 12 6
+--R                                337483074473460a b  c  - 43904670504450a b  c
+--R                              + 
+--R                                              5 14 5                4 16 4
+--R                                4476152774250a b  c  - 354908559375a b  c
+--R                              + 
+--R                                            3 18 3             2 20 2
+--R                                21372793750a b  c  - 932859375a b  c
+--R                              + 
+--R                                           22           24
+--R                                26718750a b  c - 390625b
+--R                           /
+--R                                                         33 15
+--R                                302231454903657293676544a  c
+--R                              + 
+--R                                                            32 2 14
+--R                                - 1133367955888714851287040a  b c
+--R                              + 
+--R                                                          31 4 13
+--R                                1983393922805250989752320a  b c
+--R                              + 
+--R                                                            30 6 12
+--R                                - 2148676749705688572231680a  b c
+--R                              + 
+--R                                                          29 8 11
+--R                                1611507562279266429173760a  b c
+--R                              + 
+--R                                                           28 10 10
+--R                                - 886329159253596536045568a  b  c
+--R                              + 
+--R                                                         27 12 9
+--R                                369303816355665223352320a  b  c
+--R                              + 
+--R                                                           26 14 8
+--R                                - 118704798114320964648960a  b  c
+--R                              + 
+--R                                                        25 16 7
+--R                                29676199528580241162240a  b  c
+--R                              + 
+--R                                                         24 18 6
+--R                                - 5770372130557269114880a  b  c
+--R                              + 
+--R                                                      23 20 5
+--R                                865555819583590367232a  b  c
+--R                              + 
+--R                                                       22 22 4
+--R                                - 98358615861771632640a  b  c
+--R                              + 
+--R                                                    21 24 3
+--R                                8196551321814302720a  b  c
+--R                              + 
+--R                                                     20 26 2
+--R                                - 472877960873902080a  b  c
+--R                              + 
+--R                                                19 28                    18 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                     + 
+--R                                     8   8              7 3 7              6 5 6
+--R                       - 10756512000a b c  + 7037771520a b c  - 2435702880a b c
+--R                     + 
+--R                                 5 7 5            4 9 4           3 11 3
+--R                       536711760a b c  - 81147001a b c  + 8537230a b  c
+--R                     + 
+--R                                2 13 2           15        17
+--R                       - 613275a b  c  + 27625a b  c - 625b
+--R                  /
+--R                                     19 10                  18 2 9
+--R                       8796093022208a  c   - 21990232555520a  b c
+--R                     + 
+--R                                      17 4 8                  16 6 7
+--R                       24739011624960a  b c  - 16492674416640a  b c
+--R                     + 
+--R                                     15 8 6                 14 10 5
+--R                       7215545057280a  b c  - 2164663517184a  b  c
+--R                     + 
+--R                                    13 12 4               12 14 3
+--R                       450971566080a  b  c  - 64424509440a  b  c
+--R                     + 
+--R                                  11 16 2             10 18            9 20
+--R                       6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 19 10                  18 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 17 4 8                  16 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 15 8 6                 14 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               13 12 4                12 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              11 16 2             10 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           9 20
+--R                                - 16777216a b
+--R                           *
+--R                              ROOT
+--R                                                         12 12
+--R                                     - 81573072100000000a  c
+--R                                   + 
+--R                                                       11 2 11
+--R                                     69448127892000000a  b c
+--R                                   + 
+--R                                                         10 4 10
+--R                                     - 31086945693180000a  b c
+--R                                   + 
+--R                                                      9 6 9
+--R                                     9269109639197200a b c
+--R                                   + 
+--R                                                        8 8 8
+--R                                     - 2023377890386401a b c
+--R                                   + 
+--R                                                     7 10 7
+--R                                     337483074473460a b  c
+--R                                   + 
+--R                                                      6 12 6
+--R                                     - 43904670504450a b  c
+--R                                   + 
+--R                                                   5 14 5                4 16 4
+--R                                     4476152774250a b  c  - 354908559375a b  c
+--R                                   + 
+--R                                                 3 18 3             2 20 2
+--R                                     21372793750a b  c  - 932859375a b  c
+--R                                   + 
+--R                                                22           24
+--R                                     26718750a b  c - 390625b
+--R                                /
+--R                                                              33 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 32 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               31 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 30 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               29 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                28 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              27 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                26 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             25 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              24 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           23 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            22 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         21 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          20 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       19 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       18 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                          8   8              7 3 7
+--R                            - 10756512000a b c  + 7037771520a b c
+--R                          + 
+--R                                         6 5 6             5 7 5
+--R                            - 2435702880a b c  + 536711760a b c
+--R                          + 
+--R                                       4 9 4           3 11 3          2 13 2
+--R                            - 81147001a b c  + 8537230a b  c  - 613275a b  c
+--R                          + 
+--R                                    15        17
+--R                            27625a b  c - 625b
+--R                       /
+--R                                          19 10                  18 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           17 4 8                  16 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          15 8 6                 14 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         13 12 4               12 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     11 16 2             10 18            9 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a b
+--R           /
+--R                                          12 19
+--R                  88229434783360000000000a  c
+--R                + 
+--R                                            11 2 18
+--R                  - 84950849869516800000000a  b c
+--R                + 
+--R                                          10 4 17
+--R                  41805027038651136000000a  b c
+--R                + 
+--R                                            9 6 16
+--R                  - 13505696733854141440000a b c
+--R                + 
+--R                                         8 8 15                         7 10 14
+--R                  3159071123368832755200a b c   - 559916261075797553664a b  c
+--R                + 
+--R                                       6 12 13                       5 14 12
+--R                  76867448827494413760a b  c   - 8221868839772013600a b  c
+--R                + 
+--R                                     4 16 11                     3 18 10
+--R                  680342208645110625a b  c   - 42554881237806250a b  c
+--R                + 
+--R                                   2 20 9                    22 8
+--R                  1919784534159375a b  c  - 56551009734375a b  c
+--R                + 
+--R                               24 7
+--R                  843270390625b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                            +-----------+
+--R                         3  |          2        2 2        2      4 4+-+
+--R         ((- 44a b c + 5b )\|- 4a c + b   - 520a c  + 54a b c - 5b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R                         3  |          2        2 2        2      4 4+-+
+--R         ((- 44a b c + 5b )\|- 4a c + b   + 520a c  - 54a b c + 5b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                          +-----------+
+--R                       3  |          2        2 2        2      4 4+-+
+--R         ((44a b c - 5b )\|- 4a c + b   + 520a c  - 54a b c + 5b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                          +-----------+
+--R                       3  |          2        2 2        2      4 4+-+
+--R         ((44a b c - 5b )\|- 4a c + b   - 520a c  + 54a b c - 5b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R  /
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R            4 2       3 2       2 4 4+-+3 |          2 4|   |          2
+--R       (512a c  - 256a b c + 32a b )\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 714
+
+)clear all
+
+--S 715 of 1057
+t0:=1/(x^(1/2)*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          3 12       2 10        2     2   8              3  6
+--R         c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x
+--R       + 
+--R            2        2  4     2   2    3
+--R         (3a c + 3a b )x  + 3a b x  + a
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 715
+
+--S 716 of 1057
+r0:=-3/32*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (7*b^3-52*a*b*c+(-7*b^4+66*a*b^2*c-280*a^2*c^2)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*a^2*(b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(3/4))-3/32*c^(3/4)*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(7*b^3-_
+   52*a*b*c+(-7*b^4+66*a*b^2*c-280*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a^2*(b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(3/4))-3/32*c^(3/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(7*b^3-_
+   52*a*b*c+(7*b^4-66*a*b^2*c+280*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a^2*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))-3/32*c^(3/4)*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(7*b^3-_
+   52*a*b*c+(7*b^4-66*a*b^2*c+280*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a^2*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))+1/4*(b^2-2*a*c+b*c*x^2)*_
+   sqrt(x)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+1/16*(7*b^4-55*a*b^2*c+_
+   60*a^2*c^2+b*c*(7*b^2-52*a*c)*x^2)*sqrt(x)/(a^2*(b^2-4*a*c)^2*_
+   (a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                        3      3 2  8          2 2      4   6
+--R               (156a b c  - 21b c )x  + (312a b c  - 42b c)x
+--R             + 
+--R                    2   2         3       5  4        2 2         4  2
+--R               (312a b c  + 114a b c - 21b )x  + (312a b c - 42a b )x
+--R             + 
+--R                   3         2 3
+--R               156a b c - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4         2 3      4 2  8         2   3         3 2      5   6
+--R           (840a c  - 198a b c  + 21b c )x  + (1680a b c  - 396a b c  + 42b c)x
+--R         + 
+--R                 3 3       2 2 2         4       6  4
+--R           (1680a c  + 444a b c  - 156a b c + 21b )x
+--R         + 
+--R                 3   2       2 3         5  2       4 2       3 2       2 4
+--R           (1680a b c  - 396a b c + 42a b )x  + 840a c  - 198a b c + 21a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                  4+-+4+-+ +-+
+--R         4+-+3 4| |          2                   \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                        3      3 2  8          2 2      4   6
+--R               (156a b c  - 21b c )x  + (312a b c  - 42b c)x
+--R             + 
+--R                    2   2         3       5  4        2 2         4  2
+--R               (312a b c  + 114a b c - 21b )x  + (312a b c - 42a b )x
+--R             + 
+--R                   3         2 3
+--R               156a b c - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4         2 3      4 2  8
+--R           (- 840a c  + 198a b c  - 21b c )x
+--R         + 
+--R                   2   3         3 2      5   6
+--R           (- 1680a b c  + 396a b c  - 42b c)x
+--R         + 
+--R                   3 3       2 2 2         4       6  4
+--R           (- 1680a c  - 444a b c  + 156a b c - 21b )x
+--R         + 
+--R                   3   2       2 3         5  2       4 2       3 2       2 4
+--R           (- 1680a b c  + 396a b c - 42a b )x  - 840a c  + 198a b c - 21a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                  \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                        3      3 2  8          2 2      4   6
+--R               (156a b c  - 21b c )x  + (312a b c  - 42b c)x
+--R             + 
+--R                    2   2         3       5  4        2 2         4  2
+--R               (312a b c  + 114a b c - 21b )x  + (312a b c - 42a b )x
+--R             + 
+--R                   3         2 3
+--R               156a b c - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4         2 3      4 2  8         2   3         3 2      5   6
+--R           (840a c  - 198a b c  + 21b c )x  + (1680a b c  - 396a b c  + 42b c)x
+--R         + 
+--R                 3 3       2 2 2         4       6  4
+--R           (1680a c  + 444a b c  - 156a b c + 21b )x
+--R         + 
+--R                 3   2       2 3         5  2       4 2       3 2       2 4
+--R           (1680a b c  - 396a b c + 42a b )x  + 840a c  - 198a b c + 21a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4| |          2                  \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                        3      3 2  8          2 2      4   6
+--R               (156a b c  - 21b c )x  + (312a b c  - 42b c)x
+--R             + 
+--R                    2   2         3       5  4        2 2         4  2
+--R               (312a b c  + 114a b c - 21b )x  + (312a b c - 42a b )x
+--R             + 
+--R                   3         2 3
+--R               156a b c - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4         2 3      4 2  8
+--R           (- 840a c  + 198a b c  - 21b c )x
+--R         + 
+--R                   2   3         3 2      5   6
+--R           (- 1680a b c  + 396a b c  - 42b c)x
+--R         + 
+--R                   3 3       2 2 2         4       6  4
+--R           (- 1680a c  - 444a b c  + 156a b c - 21b )x
+--R         + 
+--R                   3   2       2 3         5  2       4 2       3 2       2 4
+--R           (- 1680a b c  + 396a b c - 42a b )x  - 840a c  + 198a b c - 21a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                 \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R     + 
+--R                      3      3 2  6        2 3         2 2      4   4
+--R           (- 104a b c  + 14b c )x  + (120a c  - 214a b c  + 28b c)x
+--R         + 
+--R                 2   2        3       5  2       3 2       2 2         4
+--R           (- 16a b c  - 88a b c + 14b )x  + 184a c  - 158a b c + 22a b
+--R      *
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2  +-+4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              4 4       3 2 3      2 4 2  8
+--R         (512a c  - 256a b c  + 32a b c )x
+--R       + 
+--R               4   3       3 3 2      2 5   6         5 3       3 4       2 6  4
+--R         (1024a b c  - 512a b c  + 64a b c)x  + (1024a c  - 192a b c + 32a b )x
+--R       + 
+--R               5   2       4 3       3 5  2       6 2       5 2       4 4
+--R         (1024a b c  - 512a b c + 64a b )x  + 512a c  - 256a b c + 32a b
+--R    *
+--R                          +--------------------+3  +------------------+3
+--R            +-----------+ |   +-----------+        | +-----------+
+--R       4+-+ |          2 4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4 4      3 2 3     2 4 2  8
+--R           (128a c  - 64a b c  + 8a b c )x
+--R         + 
+--R                4   3       3 3 2      2 5   6        5 3      3 4      2 6  4
+--R           (256a b c  - 128a b c  + 16a b c)x  + (256a c  - 48a b c + 8a b )x
+--R         + 
+--R                5   2       4 3       3 5  2       6 2      5 2      4 4
+--R           (256a b c  - 128a b c + 16a b )x  + 128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        21 10                  20 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        19 4 8                  18 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        17 8 6                 16 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      15 12 4                14 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                   13 16 2             12 18             11 20
+--R                       12079595520a  b  c  - 671088640a  b  c + 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         log
+--R                                        23   12                      22 3 11
+--R                      68679894317400064a  b c   - 192247409093378048a  b c
+--R                    + 
+--R                                         21 5 10                      20 7 9
+--R                      246501710854356992a  b c   - 191490945093468160a  b c
+--R                    + 
+--R                                         19 9 8                     18 11 7
+--R                      100407401848504320a  b c  - 37451565065306112a  b  c
+--R                    + 
+--R                                        17 13 6                    16 15 5
+--R                      10194122056925184a  b  c  - 2041380775919616a  b  c
+--R                    + 
+--R                                      15 17 4                  14 19 3
+--R                      298672025763840a  b  c  - 31159987732480a  b  c
+--R                    + 
+--R                                    13 21 2               12 23
+--R                      2202244481024a  b  c  - 94757715968a  b  c
+--R                    + 
+--R                                 11 25
+--R                      1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                  12 12                    11 2 11
+--R                  278807961600000a  c   - 1581011841024000a  b c
+--R                + 
+--R                                   10 4 10                    9 6 9
+--R                  2643438214287360a  b c   - 2321113064656896a b c
+--R                + 
+--R                                   8 8 8                   7 10 7
+--R                  1285608983143680a b c  - 488228627965824a b  c
+--R                + 
+--R                                  6 12 6                  5 14 5
+--R                  132491071988208a b  c  - 26139740936832a b  c
+--R                + 
+--R                                4 16 4                3 18 3
+--R                  3745326011616a b  c  - 381851139600a b  c
+--R                + 
+--R                              2 20 2                22             24
+--R                  26392960944a b  c  - 1113987168a b  c + 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               21 10                  20 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               19 4 8                  18 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               17 8 6                 16 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             15 12 4                14 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            13 16 2             12 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         11 20
+--R                                16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R            + 
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  4 4      3 2 3     2 4 2  8
+--R           (- 128a c  + 64a b c  - 8a b c )x
+--R         + 
+--R                  4   3       3 3 2      2 5   6
+--R           (- 256a b c  + 128a b c  - 16a b c)x
+--R         + 
+--R                  5 3      3 4      2 6  4          5   2       4 3       3 5  2
+--R           (- 256a c  + 48a b c - 8a b )x  + (- 256a b c  + 128a b c - 16a b )x
+--R         + 
+--R                 6 2      5 2      4 4
+--R           - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          21 10                  20 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          19 4 8                  18 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          17 8 6                 16 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        15 12 4                14 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     13 16 2             12 18             11 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         log
+--R                                        23   12                      22 3 11
+--R                      68679894317400064a  b c   - 192247409093378048a  b c
+--R                    + 
+--R                                         21 5 10                      20 7 9
+--R                      246501710854356992a  b c   - 191490945093468160a  b c
+--R                    + 
+--R                                         19 9 8                     18 11 7
+--R                      100407401848504320a  b c  - 37451565065306112a  b  c
+--R                    + 
+--R                                        17 13 6                    16 15 5
+--R                      10194122056925184a  b  c  - 2041380775919616a  b  c
+--R                    + 
+--R                                      15 17 4                  14 19 3
+--R                      298672025763840a  b  c  - 31159987732480a  b  c
+--R                    + 
+--R                                    13 21 2               12 23
+--R                      2202244481024a  b  c  - 94757715968a  b  c
+--R                    + 
+--R                                 11 25
+--R                      1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                    12 12                    11 2 11
+--R                  - 278807961600000a  c   + 1581011841024000a  b c
+--R                + 
+--R                                     10 4 10                    9 6 9
+--R                  - 2643438214287360a  b c   + 2321113064656896a b c
+--R                + 
+--R                                     8 8 8                   7 10 7
+--R                  - 1285608983143680a b c  + 488228627965824a b  c
+--R                + 
+--R                                    6 12 6                  5 14 5
+--R                  - 132491071988208a b  c  + 26139740936832a b  c
+--R                + 
+--R                                  4 16 4                3 18 3
+--R                  - 3745326011616a b  c  + 381851139600a b  c
+--R                + 
+--R                                2 20 2                22             24
+--R                  - 26392960944a b  c  + 1113987168a b  c - 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 21 10                  20 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 19 4 8                  18 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 17 8 6                 16 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               15 12 4                14 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              13 16 2             12 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           11 20
+--R                                - 16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R            + 
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                4 4      3 2 3     2 4 2  8
+--R           (128a c  - 64a b c  + 8a b c )x
+--R         + 
+--R                4   3       3 3 2      2 5   6        5 3      3 4      2 6  4
+--R           (256a b c  - 128a b c  + 16a b c)x  + (256a c  - 48a b c + 8a b )x
+--R         + 
+--R                5   2       4 3       3 5  2       6 2      5 2      4 4
+--R           (256a b c  - 128a b c + 16a b )x  + 128a c  - 64a b c + 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          21 10                  20 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          19 4 8                  18 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          17 8 6                 16 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        15 12 4                14 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     13 16 2             12 18             11 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         log
+--R                                          23   12                      22 3 11
+--R                      - 68679894317400064a  b c   + 192247409093378048a  b c
+--R                    + 
+--R                                           21 5 10                      20 7 9
+--R                      - 246501710854356992a  b c   + 191490945093468160a  b c
+--R                    + 
+--R                                           19 9 8                     18 11 7
+--R                      - 100407401848504320a  b c  + 37451565065306112a  b  c
+--R                    + 
+--R                                          17 13 6                    16 15 5
+--R                      - 10194122056925184a  b  c  + 2041380775919616a  b  c
+--R                    + 
+--R                                        15 17 4                  14 19 3
+--R                      - 298672025763840a  b  c  + 31159987732480a  b  c
+--R                    + 
+--R                                      13 21 2               12 23
+--R                      - 2202244481024a  b  c  + 94757715968a  b  c
+--R                    + 
+--R                                   11 25
+--R                      - 1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                  12 12                    11 2 11
+--R                  278807961600000a  c   - 1581011841024000a  b c
+--R                + 
+--R                                   10 4 10                    9 6 9
+--R                  2643438214287360a  b c   - 2321113064656896a b c
+--R                + 
+--R                                   8 8 8                   7 10 7
+--R                  1285608983143680a b c  - 488228627965824a b  c
+--R                + 
+--R                                  6 12 6                  5 14 5
+--R                  132491071988208a b  c  - 26139740936832a b  c
+--R                + 
+--R                                4 16 4                3 18 3
+--R                  3745326011616a b  c  - 381851139600a b  c
+--R                + 
+--R                              2 20 2                22             24
+--R                  26392960944a b  c  - 1113987168a b  c + 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 21 10                  20 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 19 4 8                  18 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 17 8 6                 16 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               15 12 4                14 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              13 16 2             12 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           11 20
+--R                                - 16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R            + 
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  4 4      3 2 3     2 4 2  8
+--R           (- 128a c  + 64a b c  - 8a b c )x
+--R         + 
+--R                  4   3       3 3 2      2 5   6
+--R           (- 256a b c  + 128a b c  - 16a b c)x
+--R         + 
+--R                  5 3      3 4      2 6  4          5   2       4 3       3 5  2
+--R           (- 256a c  + 48a b c - 8a b )x  + (- 256a b c  + 128a b c - 16a b )x
+--R         + 
+--R                 6 2      5 2      4 4
+--R           - 128a c  + 64a b c - 8a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        21 10                  20 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        19 4 8                  18 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        17 8 6                 16 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      15 12 4                14 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                   13 16 2             12 18             11 20
+--R                       12079595520a  b  c  - 671088640a  b  c + 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         log
+--R                                          23   12                      22 3 11
+--R                      - 68679894317400064a  b c   + 192247409093378048a  b c
+--R                    + 
+--R                                           21 5 10                      20 7 9
+--R                      - 246501710854356992a  b c   + 191490945093468160a  b c
+--R                    + 
+--R                                           19 9 8                     18 11 7
+--R                      - 100407401848504320a  b c  + 37451565065306112a  b  c
+--R                    + 
+--R                                          17 13 6                    16 15 5
+--R                      - 10194122056925184a  b  c  + 2041380775919616a  b  c
+--R                    + 
+--R                                        15 17 4                  14 19 3
+--R                      - 298672025763840a  b  c  + 31159987732480a  b  c
+--R                    + 
+--R                                      13 21 2               12 23
+--R                      - 2202244481024a  b  c  + 94757715968a  b  c
+--R                    + 
+--R                                   11 25
+--R                      - 1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                    12 12                    11 2 11
+--R                  - 278807961600000a  c   + 1581011841024000a  b c
+--R                + 
+--R                                     10 4 10                    9 6 9
+--R                  - 2643438214287360a  b c   + 2321113064656896a b c
+--R                + 
+--R                                     8 8 8                   7 10 7
+--R                  - 1285608983143680a b c  + 488228627965824a b  c
+--R                + 
+--R                                    6 12 6                  5 14 5
+--R                  - 132491071988208a b  c  + 26139740936832a b  c
+--R                + 
+--R                                  4 16 4                3 18 3
+--R                  - 3745326011616a b  c  + 381851139600a b  c
+--R                + 
+--R                                2 20 2                22             24
+--R                  - 26392960944a b  c  + 1113987168a b  c - 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               21 10                  20 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               19 4 8                  18 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               17 8 6                 16 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             15 12 4                14 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            13 16 2             12 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         11 20
+--R                                16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R            + 
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                  4 4       3 2 3      2 4 2  8
+--R           (- 256a c  + 128a b c  - 16a b c )x
+--R         + 
+--R                  4   3       3 3 2      2 5   6
+--R           (- 512a b c  + 256a b c  - 32a b c)x
+--R         + 
+--R                  5 3      3 4       2 6  4
+--R           (- 512a c  + 96a b c - 16a b )x
+--R         + 
+--R                  5   2       4 3       3 5  2       6 2       5 2       4 4
+--R           (- 512a b c  + 256a b c - 32a b )x  - 256a c  + 128a b c - 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        21 10                  20 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        19 4 8                  18 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        17 8 6                 16 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      15 12 4                14 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                   13 16 2             12 18             11 20
+--R                       12079595520a  b  c  - 671088640a  b  c + 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         atan
+--R                                        23   12                      22 3 11
+--R                      68679894317400064a  b c   - 192247409093378048a  b c
+--R                    + 
+--R                                         21 5 10                      20 7 9
+--R                      246501710854356992a  b c   - 191490945093468160a  b c
+--R                    + 
+--R                                         19 9 8                     18 11 7
+--R                      100407401848504320a  b c  - 37451565065306112a  b  c
+--R                    + 
+--R                                        17 13 6                    16 15 5
+--R                      10194122056925184a  b  c  - 2041380775919616a  b  c
+--R                    + 
+--R                                      15 17 4                  14 19 3
+--R                      298672025763840a  b  c  - 31159987732480a  b  c
+--R                    + 
+--R                                    13 21 2               12 23
+--R                      2202244481024a  b  c  - 94757715968a  b  c
+--R                    + 
+--R                                 11 25
+--R                      1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                  12 12                    11 2 11
+--R                  278807961600000a  c   - 1581011841024000a  b c
+--R                + 
+--R                                   10 4 10                    9 6 9
+--R                  2643438214287360a  b c   - 2321113064656896a b c
+--R                + 
+--R                                   8 8 8                   7 10 7
+--R                  1285608983143680a b c  - 488228627965824a b  c
+--R                + 
+--R                                  6 12 6                  5 14 5
+--R                  132491071988208a b  c  - 26139740936832a b  c
+--R                + 
+--R                                4 16 4                3 18 3
+--R                  3745326011616a b  c  - 381851139600a b  c
+--R                + 
+--R                              2 20 2                22             24
+--R                  26392960944a b  c  - 1113987168a b  c + 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               21 10                  20 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               19 4 8                  18 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               17 8 6                 16 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             15 12 4                14 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            13 16 2             12 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         11 20
+--R                                16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R           /
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                4 4       3 2 3      2 4 2  8
+--R           (256a c  - 128a b c  + 16a b c )x
+--R         + 
+--R                4   3       3 3 2      2 5   6        5 3      3 4       2 6  4
+--R           (512a b c  - 256a b c  + 32a b c)x  + (512a c  - 96a b c + 16a b )x
+--R         + 
+--R                5   2       4 3       3 5  2       6 2       5 2       4 4
+--R           (512a b c  - 256a b c + 32a b )x  + 256a c  - 128a b c + 16a b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          21 10                  20 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          19 4 8                  18 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          17 8 6                 16 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        15 12 4                14 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     13 16 2             12 18             11 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         atan
+--R                                        23   12                      22 3 11
+--R                      68679894317400064a  b c   - 192247409093378048a  b c
+--R                    + 
+--R                                         21 5 10                      20 7 9
+--R                      246501710854356992a  b c   - 191490945093468160a  b c
+--R                    + 
+--R                                         19 9 8                     18 11 7
+--R                      100407401848504320a  b c  - 37451565065306112a  b  c
+--R                    + 
+--R                                        17 13 6                    16 15 5
+--R                      10194122056925184a  b  c  - 2041380775919616a  b  c
+--R                    + 
+--R                                      15 17 4                  14 19 3
+--R                      298672025763840a  b  c  - 31159987732480a  b  c
+--R                    + 
+--R                                    13 21 2               12 23
+--R                      2202244481024a  b  c  - 94757715968a  b  c
+--R                    + 
+--R                                 11 25
+--R                      1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                    12 12                    11 2 11
+--R                  - 278807961600000a  c   + 1581011841024000a  b c
+--R                + 
+--R                                     10 4 10                    9 6 9
+--R                  - 2643438214287360a  b c   + 2321113064656896a b c
+--R                + 
+--R                                     8 8 8                   7 10 7
+--R                  - 1285608983143680a b c  + 488228627965824a b  c
+--R                + 
+--R                                    6 12 6                  5 14 5
+--R                  - 132491071988208a b  c  + 26139740936832a b  c
+--R                + 
+--R                                  4 16 4                3 18 3
+--R                  - 3745326011616a b  c  + 381851139600a b  c
+--R                + 
+--R                                2 20 2                22             24
+--R                  - 26392960944a b  c  + 1113987168a b  c - 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 21 10                  20 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 19 4 8                  18 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 17 8 6                 16 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               15 12 4                14 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              13 16 2             12 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           11 20
+--R                                - 16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R           /
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                     3     3 2  6       2 3         2 2      4   4
+--R           (- 52a b c  + 7b c )x  + (60a c  - 107a b c  + 14b c)x
+--R         + 
+--R                2   2        3      5  2      3 2      2 2         4
+--R           (- 8a b c  - 44a b c + 7b )x  + 92a c  - 79a b c + 11a b
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R            4 4       3 2 3      2 4 2  8        4   3       3 3 2      2 5   6
+--R       (256a c  - 128a b c  + 16a b c )x  + (512a b c  - 256a b c  + 32a b c)x
+--R     + 
+--R            5 3      3 4       2 6  4        5   2       4 3       3 5  2
+--R       (512a c  - 96a b c + 16a b )x  + (512a b c  - 256a b c + 32a b )x
+--R     + 
+--R           6 2       5 2       4 4
+--R       256a c  - 128a b c + 16a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 717
+
+--S 718 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                         +--------------------+3
+--R                                           +-----------+ |   +-----------+
+--R              4 2       3 2       2 4 4+-+ |          2 4|   |          2
+--R         (256a c  - 128a b c + 16a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        21 10                  20 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        19 4 8                  18 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        17 8 6                 16 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      15 12 4                14 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                   13 16 2             12 18             11 20
+--R                       12079595520a  b  c  - 671088640a  b  c + 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         log
+--R                                        23   12                      22 3 11
+--R                      68679894317400064a  b c   - 192247409093378048a  b c
+--R                    + 
+--R                                         21 5 10                      20 7 9
+--R                      246501710854356992a  b c   - 191490945093468160a  b c
+--R                    + 
+--R                                         19 9 8                     18 11 7
+--R                      100407401848504320a  b c  - 37451565065306112a  b  c
+--R                    + 
+--R                                        17 13 6                    16 15 5
+--R                      10194122056925184a  b  c  - 2041380775919616a  b  c
+--R                    + 
+--R                                      15 17 4                  14 19 3
+--R                      298672025763840a  b  c  - 31159987732480a  b  c
+--R                    + 
+--R                                    13 21 2               12 23
+--R                      2202244481024a  b  c  - 94757715968a  b  c
+--R                    + 
+--R                                 11 25
+--R                      1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                  12 12                    11 2 11
+--R                  278807961600000a  c   - 1581011841024000a  b c
+--R                + 
+--R                                   10 4 10                    9 6 9
+--R                  2643438214287360a  b c   - 2321113064656896a b c
+--R                + 
+--R                                   8 8 8                   7 10 7
+--R                  1285608983143680a b c  - 488228627965824a b  c
+--R                + 
+--R                                  6 12 6                  5 14 5
+--R                  132491071988208a b  c  - 26139740936832a b  c
+--R                + 
+--R                                4 16 4                3 18 3
+--R                  3745326011616a b  c  - 381851139600a b  c
+--R                + 
+--R                              2 20 2                22             24
+--R                  26392960944a b  c  - 1113987168a b  c + 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               21 10                  20 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               19 4 8                  18 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               17 8 6                 16 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             15 12 4                14 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            13 16 2             12 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         11 20
+--R                                16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R            + 
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +-----------+
+--R                4 2       3 2       2 4 4+-+ |          2
+--R         (- 256a c  + 128a b c - 16a b )\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          21 10                  20 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          19 4 8                  18 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          17 8 6                 16 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        15 12 4                14 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     13 16 2             12 18             11 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         log
+--R                                        23   12                      22 3 11
+--R                      68679894317400064a  b c   - 192247409093378048a  b c
+--R                    + 
+--R                                         21 5 10                      20 7 9
+--R                      246501710854356992a  b c   - 191490945093468160a  b c
+--R                    + 
+--R                                         19 9 8                     18 11 7
+--R                      100407401848504320a  b c  - 37451565065306112a  b  c
+--R                    + 
+--R                                        17 13 6                    16 15 5
+--R                      10194122056925184a  b  c  - 2041380775919616a  b  c
+--R                    + 
+--R                                      15 17 4                  14 19 3
+--R                      298672025763840a  b  c  - 31159987732480a  b  c
+--R                    + 
+--R                                    13 21 2               12 23
+--R                      2202244481024a  b  c  - 94757715968a  b  c
+--R                    + 
+--R                                 11 25
+--R                      1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                    12 12                    11 2 11
+--R                  - 278807961600000a  c   + 1581011841024000a  b c
+--R                + 
+--R                                     10 4 10                    9 6 9
+--R                  - 2643438214287360a  b c   + 2321113064656896a b c
+--R                + 
+--R                                     8 8 8                   7 10 7
+--R                  - 1285608983143680a b c  + 488228627965824a b  c
+--R                + 
+--R                                    6 12 6                  5 14 5
+--R                  - 132491071988208a b  c  + 26139740936832a b  c
+--R                + 
+--R                                  4 16 4                3 18 3
+--R                  - 3745326011616a b  c  + 381851139600a b  c
+--R                + 
+--R                                2 20 2                22             24
+--R                  - 26392960944a b  c  + 1113987168a b  c - 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 21 10                  20 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 19 4 8                  18 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 17 8 6                 16 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               15 12 4                14 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              13 16 2             12 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           11 20
+--R                                - 16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R            + 
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                         +--------------------+3
+--R                                           +-----------+ |   +-----------+
+--R              4 2       3 2       2 4 4+-+ |          2 4|   |          2
+--R         (256a c  - 128a b c + 16a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          21 10                  20 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          19 4 8                  18 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          17 8 6                 16 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        15 12 4                14 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     13 16 2             12 18             11 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         log
+--R                                          23   12                      22 3 11
+--R                      - 68679894317400064a  b c   + 192247409093378048a  b c
+--R                    + 
+--R                                           21 5 10                      20 7 9
+--R                      - 246501710854356992a  b c   + 191490945093468160a  b c
+--R                    + 
+--R                                           19 9 8                     18 11 7
+--R                      - 100407401848504320a  b c  + 37451565065306112a  b  c
+--R                    + 
+--R                                          17 13 6                    16 15 5
+--R                      - 10194122056925184a  b  c  + 2041380775919616a  b  c
+--R                    + 
+--R                                        15 17 4                  14 19 3
+--R                      - 298672025763840a  b  c  + 31159987732480a  b  c
+--R                    + 
+--R                                      13 21 2               12 23
+--R                      - 2202244481024a  b  c  + 94757715968a  b  c
+--R                    + 
+--R                                   11 25
+--R                      - 1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                  12 12                    11 2 11
+--R                  278807961600000a  c   - 1581011841024000a  b c
+--R                + 
+--R                                   10 4 10                    9 6 9
+--R                  2643438214287360a  b c   - 2321113064656896a b c
+--R                + 
+--R                                   8 8 8                   7 10 7
+--R                  1285608983143680a b c  - 488228627965824a b  c
+--R                + 
+--R                                  6 12 6                  5 14 5
+--R                  132491071988208a b  c  - 26139740936832a b  c
+--R                + 
+--R                                4 16 4                3 18 3
+--R                  3745326011616a b  c  - 381851139600a b  c
+--R                + 
+--R                              2 20 2                22             24
+--R                  26392960944a b  c  - 1113987168a b  c + 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 21 10                  20 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 19 4 8                  18 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 17 8 6                 16 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               15 12 4                14 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              13 16 2             12 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           11 20
+--R                                - 16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R            + 
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +-----------+
+--R                4 2       3 2       2 4 4+-+ |          2
+--R         (- 256a c  + 128a b c - 16a b )\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        21 10                  20 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        19 4 8                  18 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        17 8 6                 16 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      15 12 4                14 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                   13 16 2             12 18             11 20
+--R                       12079595520a  b  c  - 671088640a  b  c + 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         log
+--R                                          23   12                      22 3 11
+--R                      - 68679894317400064a  b c   + 192247409093378048a  b c
+--R                    + 
+--R                                           21 5 10                      20 7 9
+--R                      - 246501710854356992a  b c   + 191490945093468160a  b c
+--R                    + 
+--R                                           19 9 8                     18 11 7
+--R                      - 100407401848504320a  b c  + 37451565065306112a  b  c
+--R                    + 
+--R                                          17 13 6                    16 15 5
+--R                      - 10194122056925184a  b  c  + 2041380775919616a  b  c
+--R                    + 
+--R                                        15 17 4                  14 19 3
+--R                      - 298672025763840a  b  c  + 31159987732480a  b  c
+--R                    + 
+--R                                      13 21 2               12 23
+--R                      - 2202244481024a  b  c  + 94757715968a  b  c
+--R                    + 
+--R                                   11 25
+--R                      - 1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                    12 12                    11 2 11
+--R                  - 278807961600000a  c   + 1581011841024000a  b c
+--R                + 
+--R                                     10 4 10                    9 6 9
+--R                  - 2643438214287360a  b c   + 2321113064656896a b c
+--R                + 
+--R                                     8 8 8                   7 10 7
+--R                  - 1285608983143680a b c  + 488228627965824a b  c
+--R                + 
+--R                                    6 12 6                  5 14 5
+--R                  - 132491071988208a b  c  + 26139740936832a b  c
+--R                + 
+--R                                  4 16 4                3 18 3
+--R                  - 3745326011616a b  c  + 381851139600a b  c
+--R                + 
+--R                                2 20 2                22             24
+--R                  - 26392960944a b  c  + 1113987168a b  c - 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               21 10                  20 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               19 4 8                  18 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               17 8 6                 16 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             15 12 4                14 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            13 16 2             12 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         11 20
+--R                                16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R            + 
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                             +-----------+
+--R                4 2       3 2       2 4 4+-+ |          2
+--R         (- 512a c  + 256a b c - 32a b )\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                        21 10                  20 2 9
+--R                         17592186044416a  c   - 43980465111040a  b c
+--R                       + 
+--R                                        19 4 8                  18 6 7
+--R                         49478023249920a  b c  - 32985348833280a  b c
+--R                       + 
+--R                                        17 8 6                 16 10 5
+--R                         14431090114560a  b c  - 4329327034368a  b  c
+--R                       + 
+--R                                      15 12 4                14 14 3
+--R                         901943132160a  b  c  - 128849018880a  b  c
+--R                       + 
+--R                                   13 16 2             12 18             11 20
+--R                       12079595520a  b  c  - 671088640a  b  c + 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         atan
+--R                                        23   12                      22 3 11
+--R                      68679894317400064a  b c   - 192247409093378048a  b c
+--R                    + 
+--R                                         21 5 10                      20 7 9
+--R                      246501710854356992a  b c   - 191490945093468160a  b c
+--R                    + 
+--R                                         19 9 8                     18 11 7
+--R                      100407401848504320a  b c  - 37451565065306112a  b  c
+--R                    + 
+--R                                        17 13 6                    16 15 5
+--R                      10194122056925184a  b  c  - 2041380775919616a  b  c
+--R                    + 
+--R                                      15 17 4                  14 19 3
+--R                      298672025763840a  b  c  - 31159987732480a  b  c
+--R                    + 
+--R                                    13 21 2               12 23
+--R                      2202244481024a  b  c  - 94757715968a  b  c
+--R                    + 
+--R                                 11 25
+--R                      1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                  12 12                    11 2 11
+--R                  278807961600000a  c   - 1581011841024000a  b c
+--R                + 
+--R                                   10 4 10                    9 6 9
+--R                  2643438214287360a  b c   - 2321113064656896a b c
+--R                + 
+--R                                   8 8 8                   7 10 7
+--R                  1285608983143680a b c  - 488228627965824a b  c
+--R                + 
+--R                                  6 12 6                  5 14 5
+--R                  132491071988208a b  c  - 26139740936832a b  c
+--R                + 
+--R                                4 16 4                3 18 3
+--R                  3745326011616a b  c  - 381851139600a b  c
+--R                + 
+--R                              2 20 2                22             24
+--R                  26392960944a b  c  - 1113987168a b  c + 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                               21 10                  20 2 9
+--R                                17592186044416a  c   - 43980465111040a  b c
+--R                              + 
+--R                                               19 4 8                  18 6 7
+--R                                49478023249920a  b c  - 32985348833280a  b c
+--R                              + 
+--R                                               17 8 6                 16 10 5
+--R                                14431090114560a  b c  - 4329327034368a  b  c
+--R                              + 
+--R                                             15 12 4                14 14 3
+--R                                901943132160a  b  c  - 128849018880a  b  c
+--R                              + 
+--R                                            13 16 2             12 18
+--R                                12079595520a  b  c  - 671088640a  b  c
+--R                              + 
+--R                                         11 20
+--R                                16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R           /
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                                                         +--------------------+3
+--R                                           +-----------+ |   +-----------+
+--R              4 2       3 2       2 4 4+-+ |          2 4|   |          2
+--R         (512a c  - 256a b c + 32a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                                          21 10                  20 2 9
+--R                         - 17592186044416a  c   + 43980465111040a  b c
+--R                       + 
+--R                                          19 4 8                  18 6 7
+--R                         - 49478023249920a  b c  + 32985348833280a  b c
+--R                       + 
+--R                                          17 8 6                 16 10 5
+--R                         - 14431090114560a  b c  + 4329327034368a  b  c
+--R                       + 
+--R                                        15 12 4                14 14 3
+--R                         - 901943132160a  b  c  + 128849018880a  b  c
+--R                       + 
+--R                                     13 16 2             12 18             11 20
+--R                       - 12079595520a  b  c  + 671088640a  b  c - 16777216a  b
+--R                    *
+--R                       ROOT
+--R                                                    14 14
+--R                              - 3782285936100000000a  c
+--R                            + 
+--R                                                   13 2 13
+--R                              34034398264188000000a  b c
+--R                            + 
+--R                                                      12 4 12
+--R                              - 104228439048383580000a  b c
+--R                            + 
+--R                                                    11 6 11
+--R                              135198111334772782800a  b c
+--R                            + 
+--R                                                      10 8 10
+--R                              - 101237769721346037921a  b c
+--R                            + 
+--R                                                   9 10 9
+--R                              50260793241449690190a b  c
+--R                            + 
+--R                                                     8 12 8
+--R                              - 17750222587612840455a b  c
+--R                            + 
+--R                                                  7 14 7
+--R                              4629998473698035970a b  c
+--R                            + 
+--R                                                   6 16 6
+--R                              - 908315566540288515a b  c
+--R                            + 
+--R                                                 5 18 5
+--R                              134538458189906232a b  c
+--R                            + 
+--R                                                  4 20 4
+--R                              - 14902010306339940a b  c
+--R                            + 
+--R                                               3 22 3                  2 24 2
+--R                              1202512202300430a b  c  - 67081542709545a b  c
+--R                            + 
+--R                                              26                28
+--R                              2323404217890a b  c - 37822859361b
+--R                         /
+--R                                                       37 15
+--R                              302231454903657293676544a  c
+--R                            + 
+--R                                                          36 2 14
+--R                              - 1133367955888714851287040a  b c
+--R                            + 
+--R                                                        35 4 13
+--R                              1983393922805250989752320a  b c
+--R                            + 
+--R                                                          34 6 12
+--R                              - 2148676749705688572231680a  b c
+--R                            + 
+--R                                                        33 8 11
+--R                              1611507562279266429173760a  b c
+--R                            + 
+--R                                                         32 10 10
+--R                              - 886329159253596536045568a  b  c
+--R                            + 
+--R                                                       31 12 9
+--R                              369303816355665223352320a  b  c
+--R                            + 
+--R                                                         30 14 8
+--R                              - 118704798114320964648960a  b  c
+--R                            + 
+--R                                                      29 16 7
+--R                              29676199528580241162240a  b  c
+--R                            + 
+--R                                                       28 18 6
+--R                              - 5770372130557269114880a  b  c
+--R                            + 
+--R                                                    27 20 5
+--R                              865555819583590367232a  b  c
+--R                            + 
+--R                                                     26 22 4
+--R                              - 98358615861771632640a  b  c
+--R                            + 
+--R                                                  25 24 3
+--R                              8196551321814302720a  b  c
+--R                            + 
+--R                                                   24 26 2
+--R                              - 472877960873902080a  b  c
+--R                            + 
+--R                                                23 28                    22 30
+--R                              16888498602639360a  b  c - 281474976710656a  b
+--R                   + 
+--R                                  9   9                8 3 8
+--R                     185812704000a b c  - 402568911360a b c
+--R                   + 
+--R                                  7 5 7                6 7 6               5 9 5
+--R                     352721809440a b c  - 174123568080a b c  + 54613411083a b c
+--R                   + 
+--R                                   4 11 4              3 13 3             2 15 2
+--R                     - 11418094935a b  c  + 1602429885a b  c  - 146297340a b  c
+--R                   + 
+--R                               17           19
+--R                     7918155a b  c - 194481b
+--R                /
+--R                                   21 10                  20 2 9
+--R                     8796093022208a  c   - 21990232555520a  b c
+--R                   + 
+--R                                    19 4 8                  18 6 7
+--R                     24739011624960a  b c  - 16492674416640a  b c
+--R                   + 
+--R                                   17 8 6                 16 10 5
+--R                     7215545057280a  b c  - 2164663517184a  b  c
+--R                   + 
+--R                                  15 12 4               14 14 3
+--R                     450971566080a  b  c  - 64424509440a  b  c
+--R                   + 
+--R                                13 16 2             12 18            11 20
+--R                     6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R      *
+--R         atan
+--R                                        23   12                      22 3 11
+--R                      68679894317400064a  b c   - 192247409093378048a  b c
+--R                    + 
+--R                                         21 5 10                      20 7 9
+--R                      246501710854356992a  b c   - 191490945093468160a  b c
+--R                    + 
+--R                                         19 9 8                     18 11 7
+--R                      100407401848504320a  b c  - 37451565065306112a  b  c
+--R                    + 
+--R                                        17 13 6                    16 15 5
+--R                      10194122056925184a  b  c  - 2041380775919616a  b  c
+--R                    + 
+--R                                      15 17 4                  14 19 3
+--R                      298672025763840a  b  c  - 31159987732480a  b  c
+--R                    + 
+--R                                    13 21 2               12 23
+--R                      2202244481024a  b  c  - 94757715968a  b  c
+--R                    + 
+--R                                 11 25
+--R                      1879048192a  b
+--R                 *
+--R                    ROOT
+--R                                                 14 14
+--R                           - 3782285936100000000a  c
+--R                         + 
+--R                                                13 2 13
+--R                           34034398264188000000a  b c
+--R                         + 
+--R                                                   12 4 12
+--R                           - 104228439048383580000a  b c
+--R                         + 
+--R                                                 11 6 11
+--R                           135198111334772782800a  b c
+--R                         + 
+--R                                                   10 8 10
+--R                           - 101237769721346037921a  b c
+--R                         + 
+--R                                                9 10 9
+--R                           50260793241449690190a b  c
+--R                         + 
+--R                                                  8 12 8
+--R                           - 17750222587612840455a b  c
+--R                         + 
+--R                                               7 14 7
+--R                           4629998473698035970a b  c
+--R                         + 
+--R                                                6 16 6
+--R                           - 908315566540288515a b  c
+--R                         + 
+--R                                              5 18 5                     4 20 4
+--R                           134538458189906232a b  c  - 14902010306339940a b  c
+--R                         + 
+--R                                            3 22 3                  2 24 2
+--R                           1202512202300430a b  c  - 67081542709545a b  c
+--R                         + 
+--R                                           26                28
+--R                           2323404217890a b  c - 37822859361b
+--R                      /
+--R                                                    37 15
+--R                           302231454903657293676544a  c
+--R                         + 
+--R                                                       36 2 14
+--R                           - 1133367955888714851287040a  b c
+--R                         + 
+--R                                                     35 4 13
+--R                           1983393922805250989752320a  b c
+--R                         + 
+--R                                                       34 6 12
+--R                           - 2148676749705688572231680a  b c
+--R                         + 
+--R                                                     33 8 11
+--R                           1611507562279266429173760a  b c
+--R                         + 
+--R                                                      32 10 10
+--R                           - 886329159253596536045568a  b  c
+--R                         + 
+--R                                                    31 12 9
+--R                           369303816355665223352320a  b  c
+--R                         + 
+--R                                                      30 14 8
+--R                           - 118704798114320964648960a  b  c
+--R                         + 
+--R                                                   29 16 7
+--R                           29676199528580241162240a  b  c
+--R                         + 
+--R                                                    28 18 6
+--R                           - 5770372130557269114880a  b  c
+--R                         + 
+--R                                                 27 20 5
+--R                           865555819583590367232a  b  c
+--R                         + 
+--R                                                  26 22 4
+--R                           - 98358615861771632640a  b  c
+--R                         + 
+--R                                               25 24 3
+--R                           8196551321814302720a  b  c
+--R                         + 
+--R                                                24 26 2
+--R                           - 472877960873902080a  b  c
+--R                         + 
+--R                                             23 28                    22 30
+--R                           16888498602639360a  b  c - 281474976710656a  b
+--R                + 
+--R                                    12 12                    11 2 11
+--R                  - 278807961600000a  c   + 1581011841024000a  b c
+--R                + 
+--R                                     10 4 10                    9 6 9
+--R                  - 2643438214287360a  b c   + 2321113064656896a b c
+--R                + 
+--R                                     8 8 8                   7 10 7
+--R                  - 1285608983143680a b c  + 488228627965824a b  c
+--R                + 
+--R                                    6 12 6                  5 14 5
+--R                  - 132491071988208a b  c  + 26139740936832a b  c
+--R                + 
+--R                                  4 16 4                3 18 3
+--R                  - 3745326011616a b  c  + 381851139600a b  c
+--R                + 
+--R                                2 20 2                22             24
+--R                  - 26392960944a b  c  + 1113987168a b  c - 21781872b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                                 21 10                  20 2 9
+--R                                - 17592186044416a  c   + 43980465111040a  b c
+--R                              + 
+--R                                                 19 4 8                  18 6 7
+--R                                - 49478023249920a  b c  + 32985348833280a  b c
+--R                              + 
+--R                                                 17 8 6                 16 10 5
+--R                                - 14431090114560a  b c  + 4329327034368a  b  c
+--R                              + 
+--R                                               15 12 4                14 14 3
+--R                                - 901943132160a  b  c  + 128849018880a  b  c
+--R                              + 
+--R                                              13 16 2             12 18
+--R                                - 12079595520a  b  c  + 671088640a  b  c
+--R                              + 
+--R                                           11 20
+--R                                - 16777216a  b
+--R                           *
+--R                              ROOT
+--R                                                           14 14
+--R                                     - 3782285936100000000a  c
+--R                                   + 
+--R                                                          13 2 13
+--R                                     34034398264188000000a  b c
+--R                                   + 
+--R                                                             12 4 12
+--R                                     - 104228439048383580000a  b c
+--R                                   + 
+--R                                                           11 6 11
+--R                                     135198111334772782800a  b c
+--R                                   + 
+--R                                                             10 8 10
+--R                                     - 101237769721346037921a  b c
+--R                                   + 
+--R                                                          9 10 9
+--R                                     50260793241449690190a b  c
+--R                                   + 
+--R                                                            8 12 8
+--R                                     - 17750222587612840455a b  c
+--R                                   + 
+--R                                                         7 14 7
+--R                                     4629998473698035970a b  c
+--R                                   + 
+--R                                                          6 16 6
+--R                                     - 908315566540288515a b  c
+--R                                   + 
+--R                                                        5 18 5
+--R                                     134538458189906232a b  c
+--R                                   + 
+--R                                                         4 20 4
+--R                                     - 14902010306339940a b  c
+--R                                   + 
+--R                                                      3 22 3
+--R                                     1202512202300430a b  c
+--R                                   + 
+--R                                                      2 24 2
+--R                                     - 67081542709545a b  c
+--R                                   + 
+--R                                                     26                28
+--R                                     2323404217890a b  c - 37822859361b
+--R                                /
+--R                                                              37 15
+--R                                     302231454903657293676544a  c
+--R                                   + 
+--R                                                                 36 2 14
+--R                                     - 1133367955888714851287040a  b c
+--R                                   + 
+--R                                                               35 4 13
+--R                                     1983393922805250989752320a  b c
+--R                                   + 
+--R                                                                 34 6 12
+--R                                     - 2148676749705688572231680a  b c
+--R                                   + 
+--R                                                               33 8 11
+--R                                     1611507562279266429173760a  b c
+--R                                   + 
+--R                                                                32 10 10
+--R                                     - 886329159253596536045568a  b  c
+--R                                   + 
+--R                                                              31 12 9
+--R                                     369303816355665223352320a  b  c
+--R                                   + 
+--R                                                                30 14 8
+--R                                     - 118704798114320964648960a  b  c
+--R                                   + 
+--R                                                             29 16 7
+--R                                     29676199528580241162240a  b  c
+--R                                   + 
+--R                                                              28 18 6
+--R                                     - 5770372130557269114880a  b  c
+--R                                   + 
+--R                                                           27 20 5
+--R                                     865555819583590367232a  b  c
+--R                                   + 
+--R                                                            26 22 4
+--R                                     - 98358615861771632640a  b  c
+--R                                   + 
+--R                                                         25 24 3
+--R                                     8196551321814302720a  b  c
+--R                                   + 
+--R                                                          24 26 2
+--R                                     - 472877960873902080a  b  c
+--R                                   + 
+--R                                                       23 28
+--R                                     16888498602639360a  b  c
+--R                                   + 
+--R                                                       22 30
+--R                                     - 281474976710656a  b
+--R                          + 
+--R                                         9   9                8 3 8
+--R                            185812704000a b c  - 402568911360a b c
+--R                          + 
+--R                                         7 5 7                6 7 6
+--R                            352721809440a b c  - 174123568080a b c
+--R                          + 
+--R                                        5 9 5               4 11 4
+--R                            54613411083a b c  - 11418094935a b  c
+--R                          + 
+--R                                       3 13 3             2 15 2             17
+--R                            1602429885a b  c  - 146297340a b  c  + 7918155a b  c
+--R                          + 
+--R                                     19
+--R                            - 194481b
+--R                       /
+--R                                          21 10                  20 2 9
+--R                            8796093022208a  c   - 21990232555520a  b c
+--R                          + 
+--R                                           19 4 8                  18 6 7
+--R                            24739011624960a  b c  - 16492674416640a  b c
+--R                          + 
+--R                                          17 8 6                 16 10 5
+--R                            7215545057280a  b c  - 2164663517184a  b  c
+--R                          + 
+--R                                         15 12 4               14 14 3
+--R                            450971566080a  b  c  - 64424509440a  b  c
+--R                          + 
+--R                                     13 16 2             12 18            11 20
+--R                          6039797760a  b  c  - 335544320a  b  c + 8388608a  b
+--R           /
+--R                                  9 12                   8 2 11
+--R                  114354828000000a c   - 552637209600000a b c
+--R                + 
+--R                                  7 4 10                   6 6 9
+--R                  593666207316000a b c   - 319102597119888a b c
+--R                + 
+--R                                  5 8 8                  4 10 7
+--R                  104261197757355a b c  - 22250557395045a b  c
+--R                + 
+--R                                3 12 6                2 14 5
+--R                  3155206341105a b  c  - 289616104260a b  c
+--R                + 
+--R                                16 4             18 3
+--R                  15730206723a b  c  - 387989595b  c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                              +-----------+
+--R                           3  |          2        2 2         2       4 4+-+3
+--R         ((- 156a b c + 21b )\|- 4a c + b   - 840a c  + 198a b c - 21b )\|c
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                              +-----------+
+--R                           3  |          2        2 2         2       4 4+-+3
+--R         ((- 156a b c + 21b )\|- 4a c + b   + 840a c  - 198a b c + 21b )\|c
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                              +-----------+
+--R                           3  |          2        2 2         2       4 4+-+3
+--R         ((- 156a b c + 21b )\|- 4a c + b   - 840a c  + 198a b c - 21b )\|c
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                              +-----------+
+--R                           3  |          2        2 2         2       4 4+-+3
+--R         ((- 156a b c + 21b )\|- 4a c + b   + 840a c  - 198a b c + 21b )\|c
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R  /
+--R                                                       +--------------------+3
+--R                                         +-----------+ |   +-----------+
+--R            4 2       3 2       2 4 4+-+ |          2 4|   |          2
+--R       (512a c  - 256a b c + 32a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   - b
+--R    *
+--R        +------------------+3
+--R        | +-----------+
+--R       4| |          2
+--R       \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 719
+
+)clear all
+
+--S 720 of 1057
+t0:=(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R        7 7         6 6         2      5 5         3         4 4
+--R     c e x  + 7c d e x  + (21c d  + b)e x  + (35c d  + 5b d)e x
+--R   + 
+--R           4        2      3 3         5        3         2 2
+--R     (35c d  + 10b d  + a)e x  + (21c d  + 10b d  + 3a d)e x
+--R   + 
+--R          6       4       2          7      5      3
+--R     (7c d  + 5b d  + 3a d )e x + c d  + b d  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 720
+
+--S 721 of 1057
+r0:=1/4*a*(d+e*x)^4/e+1/6*b*(d+e*x)^6/e+1/8*c*(d+e*x)^8/e
+--R 
+--R
+--R   (2)
+--R       1    8 8        7 7    7    2   1    6 6        3        5 5
+--R       - c e x  + c d e x  + (- c d  + - b)e x  + (7c d  + b d)e x
+--R       8                      2        6
+--R     + 
+--R        35    4   5    2   1    4 4        5   10    3        3 3
+--R       (-- c d  + - b d  + - a)e x  + (7c d  + -- b d  + a d)e x
+--R         4        2        4                    3
+--R     + 
+--R        7    6   5    4   3    2  2 2       7      5      3       1    8
+--R       (- c d  + - b d  + - a d )e x  + (c d  + b d  + a d )e x + - c d
+--R        2        2        2                                       8
+--R     + 
+--R       1    6   1    4
+--R       - b d  + - a d
+--R       6        4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 721
+
+--S 722 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    7 8        6 7    7    2   1    5 6        3        4 5
+--R     - c e x  + c d e x  + (- c d  + - b)e x  + (7c d  + b d)e x
+--R     8                      2        6
+--R   + 
+--R      35    4   5    2   1    3 4        5   10    3        2 3
+--R     (-- c d  + - b d  + - a)e x  + (7c d  + -- b d  + a d)e x
+--R       4        2        4                    3
+--R   + 
+--R      7    6   5    4   3    2    2       7      5      3
+--R     (- c d  + - b d  + - a d )e x  + (c d  + b d  + a d )x
+--R      2        2        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 722
+
+--S 723 of 1057
+m0:=a0-r0
+--R 
+--R
+--R          1    8   1    6   1    4
+--R        - - c d  - - b d  - - a d
+--R          8        6        4
+--R   (4)  --------------------------
+--R                     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 723
+
+--S 724 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 724
+
+)clear all
+
+--S 725 of 1057
+t0:=(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      2 11 11      2   10 10       2 2         9 9        2 3            8 8
+--R     c e  x   + 11c d e  x   + (55c d  + 2b c)e x  + (165c d  + 18b c d)e x
+--R   + 
+--R          2 4          2           2  7 7
+--R     (330c d  + 72b c d  + 2a c + b )e x
+--R   + 
+--R          2 5           3              2    6 6
+--R     (462c d  + 168b c d  + (14a c + 7b )d)e x
+--R   + 
+--R          2 6           4               2  2         5 5
+--R     (462c d  + 252b c d  + (42a c + 21b )d  + 2a b)e x
+--R   + 
+--R          2 7           5               2  3            4 4
+--R     (330c d  + 252b c d  + (70a c + 35b )d  + 10a b d)e x
+--R   + 
+--R          2 8           6               2  4          2    2  3 3
+--R     (165c d  + 168b c d  + (70a c + 35b )d  + 20a b d  + a )e x
+--R   + 
+--R         2 9          7               2  5          3     2   2 2
+--R     (55c d  + 72b c d  + (42a c + 21b )d  + 20a b d  + 3a d)e x
+--R   + 
+--R         2 10          8              2  6          4     2 2        2 11
+--R     (11c d   + 18b c d  + (14a c + 7b )d  + 10a b d  + 3a d )e x + c d
+--R   + 
+--R           9            2  7         5    2 3
+--R     2b c d  + (2a c + b )d  + 2a b d  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 725
+
+--S 726 of 1057
+r0:=1/4*a^2*(d+e*x)^4/e+1/3*a*b*(d+e*x)^6/e+1/8*(b^2+2*a*c)*(d+e*x)^8/e+_
+   1/5*b*c*(d+e*x)^10/e+1/12*c^2*(d+e*x)^12/e
+--R 
+--R
+--R   (2)
+--R        1  2 12 12    2   11 11    11  2 2   1      10 10
+--R       -- c e  x   + c d e  x   + (-- c d  + - b c)e  x
+--R       12                           2        5
+--R     + 
+--R        55  2 3           9 9    165  2 4         2   1       1  2  8 8
+--R       (-- c d  + 2b c d)e x  + (--- c d  + 9b c d  + - a c + - b )e x
+--R         3                        4                   4       8
+--R     + 
+--R           2 5          3            2    7 7
+--R       (66c d  + 24b c d  + (2a c + b )d)e x
+--R     + 
+--R           2 6          4           7  2  2   1      6 6
+--R       (77c d  + 42b c d  + (7a c + - b )d  + - a b)e x
+--R                                    2         3
+--R     + 
+--R           2 7   252      5              2  3           5 5
+--R       (66c d  + --- b c d  + (14a c + 7b )d  + 2a b d)e x
+--R                  5
+--R     + 
+--R        165  2 8          6    35       35  2  4         2   1  2  4 4
+--R       (--- c d  + 42b c d  + (-- a c + -- b )d  + 5a b d  + - a )e x
+--R         4                      2        4                   4
+--R     + 
+--R        55  2 9          7              2  5   20      3    2   3 3
+--R       (-- c d  + 24b c d  + (14a c + 7b )d  + -- a b d  + a d)e x
+--R         3                                      3
+--R     + 
+--R        11  2 10         8           7  2  6         4   3  2 2  2 2
+--R       (-- c d   + 9b c d  + (7a c + - b )d  + 5a b d  + - a d )e x
+--R         2                           2                   2
+--R     + 
+--R         2 11         9            2  7         5    2 3        1  2 12
+--R       (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )e x + -- c d
+--R                                                               12
+--R     + 
+--R       1      10    1       1  2  8   1      6   1  2 4
+--R       - b c d   + (- a c + - b )d  + - a b d  + - a d
+--R       5            4       8         3          4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 726
+
+--S 727 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  2 11 12    2   10 11    11  2 2   1      9 10    55  2 3           8 9
+--R     -- c e  x   + c d e  x   + (-- c d  + - b c)e x   + (-- c d  + 2b c d)e x
+--R     12                           2        5               3
+--R   + 
+--R      165  2 4         2   1       1  2  7 8
+--R     (--- c d  + 9b c d  + - a c + - b )e x
+--R       4                   4       8
+--R   + 
+--R         2 5          3            2    6 7
+--R     (66c d  + 24b c d  + (2a c + b )d)e x
+--R   + 
+--R         2 6          4           7  2  2   1      5 6
+--R     (77c d  + 42b c d  + (7a c + - b )d  + - a b)e x
+--R                                  2         3
+--R   + 
+--R         2 7   252      5              2  3           4 5
+--R     (66c d  + --- b c d  + (14a c + 7b )d  + 2a b d)e x
+--R                5
+--R   + 
+--R      165  2 8          6    35       35  2  4         2   1  2  3 4
+--R     (--- c d  + 42b c d  + (-- a c + -- b )d  + 5a b d  + - a )e x
+--R       4                      2        4                   4
+--R   + 
+--R      55  2 9          7              2  5   20      3    2   2 3
+--R     (-- c d  + 24b c d  + (14a c + 7b )d  + -- a b d  + a d)e x
+--R       3                                      3
+--R   + 
+--R      11  2 10         8           7  2  6         4   3  2 2    2
+--R     (-- c d   + 9b c d  + (7a c + - b )d  + 5a b d  + - a d )e x
+--R       2                           2                   2
+--R   + 
+--R       2 11         9            2  7         5    2 3
+--R     (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 727
+
+--S 728 of 1057
+m0:=a0-r0
+--R 
+--R
+--R           1  2 12   1      10      1       1  2  8   1      6   1  2 4
+--R        - -- c d   - - b c d   + (- - a c - - b )d  - - a b d  - - a d
+--R          12         5              4       8         3          4
+--R   (4)  ---------------------------------------------------------------
+--R                                       e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 728
+
+--S 729 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 729
+
+)clear all
+
+--S 730 of 1057
+t0:=(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      3 15 15      3   14 14        3 2       2  13 13
+--R     c e  x   + 15c d e  x   + (105c d  + 3b c )e  x
+--R   + 
+--R          3 3        2   12 12         3 4         2 2       2     2   11 11
+--R     (455c d  + 39b c d)e  x   + (1365c d  + 234b c d  + 3a c  + 3b c)e  x
+--R   + 
+--R           3 5         2 3         2      2     10 10
+--R     (3003c d  + 858b c d  + (33a c  + 33b c)d)e  x
+--R   + 
+--R           3 6          2 4          2       2   2             3  9 9
+--R     (5005c d  + 2145b c d  + (165a c  + 165b c)d  + 6a b c + b )e x
+--R   + 
+--R           3 7          2 5          2       2   3                3    8 8
+--R     (6435c d  + 3861b c d  + (495a c  + 495b c)d  + (54a b c + 9b )d)e x
+--R   + 
+--R              3 8          2 6          2       2   4                  3  2
+--R         6435c d  + 5148b c d  + (990a c  + 990b c)d  + (216a b c + 36b )d
+--R       + 
+--R           2        2
+--R         3a c + 3a b
+--R    *
+--R        7 7
+--R       e x
+--R   + 
+--R              3 9          2 7           2        2   5                  3  3
+--R         5005c d  + 5148b c d  + (1386a c  + 1386b c)d  + (504a b c + 84b )d
+--R       + 
+--R             2         2
+--R         (21a c + 21a b )d
+--R    *
+--R        6 6
+--R       e x
+--R   + 
+--R              3 10          2 8           2        2   6                   3  4
+--R         3003c d   + 3861b c d  + (1386a c  + 1386b c)d  + (756a b c + 126b )d
+--R       + 
+--R             2         2  2     2
+--R         (63a c + 63a b )d  + 3a b
+--R    *
+--R        5 5
+--R       e x
+--R   + 
+--R              3 11          2 9          2       2   7                   3  5
+--R         1365c d   + 2145b c d  + (990a c  + 990b c)d  + (756a b c + 126b )d
+--R       + 
+--R              2          2  3      2
+--R         (105a c + 105a b )d  + 15a b d
+--R    *
+--R        4 4
+--R       e x
+--R   + 
+--R             3 12         2 10          2       2   8                  3  6
+--R         455c d   + 858b c d   + (495a c  + 495b c)d  + (504a b c + 84b )d
+--R       + 
+--R              2          2  4      2   2    3
+--R         (105a c + 105a b )d  + 30a b d  + a
+--R    *
+--R        3 3
+--R       e x
+--R   + 
+--R             3 13         2 11          2       2   9                  3  7
+--R         105c d   + 234b c d   + (165a c  + 165b c)d  + (216a b c + 36b )d
+--R       + 
+--R             2         2  5      2   3     3
+--R         (63a c + 63a b )d  + 30a b d  + 3a d
+--R    *
+--R        2 2
+--R       e x
+--R   + 
+--R            3 14        2 12         2      2   10                3  8
+--R         15c d   + 39b c d   + (33a c  + 33b c)d   + (54a b c + 9b )d
+--R       + 
+--R             2         2  6      2   4     3 2
+--R         (21a c + 21a b )d  + 15a b d  + 3a d
+--R    *
+--R       e x
+--R   + 
+--R      3 15       2 13        2     2   11              3  9      2        2  7
+--R     c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d  + (3a c + 3a b )d
+--R   + 
+--R       2   5    3 3
+--R     3a b d  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 730
+
+--S 731 of 1057
+r0:=1/4*a^3*(d+e*x)^4/e+1/2*a^2*b*(d+e*x)^6/e+3/8*a*(b^2+a*c)*(d+e*x)^8/e+_
+   1/10*b*(b^2+6*a*c)*(d+e*x)^10/e+1/4*c*(b^2+a*c)*(d+e*x)^12/e+_
+   3/14*b*c^2*(d+e*x)^14/e+1/16*c^3*(d+e*x)^16/e
+--R 
+--R
+--R   (2)
+--R        1  3 16 16    3   15 15    15  3 2    3    2  14 14
+--R       -- c e  x   + c d e  x   + (-- c d  + -- b c )e  x
+--R       16                           2        14
+--R     + 
+--R           3 3       2   13 13    455  3 4   39    2 2   1    2   1  2   12 12
+--R       (35c d  + 3b c d)e  x   + (--- c d  + -- b c d  + - a c  + - b c)e  x
+--R                                   4          2          4        4
+--R     + 
+--R            3 5        2 3        2     2     11 11
+--R       (273c d  + 78b c d  + (3a c  + 3b c)d)e  x
+--R     + 
+--R        1001  3 6   429    2 4    33    2   33  2   2   3          1  3  10 10
+--R       (---- c d  + --- b c d  + (-- a c  + -- b c)d  + - a b c + -- b )e  x
+--R          2          2             2         2          5         10
+--R     + 
+--R            3 7         2 5         2      2   3              3    9 9
+--R       (715c d  + 429b c d  + (55a c  + 55b c)d  + (6a b c + b )d)e x
+--R     + 
+--R           6435  3 8   1287    2 6    495    2   495  2   4              9  3  2
+--R           ---- c d  + ---- b c d  + (--- a c  + --- b c)d  + (27a b c + - b )d
+--R             8           2             4          4                      2
+--R         + 
+--R           3  2    3    2
+--R           - a c + - a b
+--R           8       8
+--R      *
+--R          8 8
+--R         e x
+--R     + 
+--R               3 9   5148    2 7          2       2   5                 3  3
+--R           715c d  + ---- b c d  + (198a c  + 198b c)d  + (72a b c + 12b )d
+--R                       7
+--R         + 
+--R              2        2
+--R           (3a c + 3a b )d
+--R      *
+--R          7 7
+--R         e x
+--R     + 
+--R           1001  3 10   1287    2 8          2       2   6                  3  4
+--R           ---- c d   + ---- b c d  + (231a c  + 231b c)d  + (126a b c + 21b )d
+--R             2            2
+--R         + 
+--R            21  2    21    2  2   1  2
+--R           (-- a c + -- a b )d  + - a b
+--R             2        2           2
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R               3 11         2 9          2       2   7    756         126  3  5
+--R           273c d   + 429b c d  + (198a c  + 198b c)d  + (--- a b c + --- b )d
+--R                                                           5           5
+--R         + 
+--R               2         2  3     2
+--R           (21a c + 21a b )d  + 3a b d
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R           455  3 12   429    2 10    495    2   495  2   8
+--R           --- c d   + --- b c d   + (--- a c  + --- b c)d
+--R            4           2              4          4
+--R         + 
+--R                          3  6    105  2    105    2  4   15  2   2   1  3
+--R           (126a b c + 21b )d  + (--- a c + --- a b )d  + -- a b d  + - a
+--R                                   4         4             2          4
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R              3 13        2 11         2      2   9                 3  7
+--R           35c d   + 78b c d   + (55a c  + 55b c)d  + (72a b c + 12b )d
+--R         + 
+--R               2         2  5      2   3    3
+--R           (21a c + 21a b )d  + 10a b d  + a d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R           15  3 14   39    2 12    33    2   33  2   10              9  3  8
+--R           -- c d   + -- b c d   + (-- a c  + -- b c)d   + (27a b c + - b )d
+--R            2          2             2         2                      2
+--R         + 
+--R            21  2    21    2  6   15  2   4   3  3 2
+--R           (-- a c + -- a b )d  + -- a b d  + - a d
+--R             2        2            2          2
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R            3 15       2 13        2     2   11              3  9
+--R           c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R         + 
+--R              2        2  7     2   5    3 3
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R         e x
+--R     + 
+--R        1  3 16    3    2 14    1    2   1  2   12    3          1  3  10
+--R       -- c d   + -- b c d   + (- a c  + - b c)d   + (- a b c + -- b )d
+--R       16         14            4        4            5         10
+--R     + 
+--R        3  2    3    2  8   1  2   6   1  3 4
+--R       (- a c + - a b )d  + - a b d  + - a d
+--R        8       8           2          4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 731
+
+--S 732 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3 15 16    3   14 15    15  3 2    3    2  13 14
+--R     -- c e  x   + c d e  x   + (-- c d  + -- b c )e  x
+--R     16                           2        14
+--R   + 
+--R         3 3       2   12 13    455  3 4   39    2 2   1    2   1  2   11 12
+--R     (35c d  + 3b c d)e  x   + (--- c d  + -- b c d  + - a c  + - b c)e  x
+--R                                 4          2          4        4
+--R   + 
+--R          3 5        2 3        2     2     10 11
+--R     (273c d  + 78b c d  + (3a c  + 3b c)d)e  x
+--R   + 
+--R      1001  3 6   429    2 4    33    2   33  2   2   3          1  3  9 10
+--R     (---- c d  + --- b c d  + (-- a c  + -- b c)d  + - a b c + -- b )e x
+--R        2          2             2         2          5         10
+--R   + 
+--R          3 7         2 5         2      2   3              3    8 9
+--R     (715c d  + 429b c d  + (55a c  + 55b c)d  + (6a b c + b )d)e x
+--R   + 
+--R         6435  3 8   1287    2 6    495    2   495  2   4              9  3  2
+--R         ---- c d  + ---- b c d  + (--- a c  + --- b c)d  + (27a b c + - b )d
+--R           8           2             4          4                      2
+--R       + 
+--R         3  2    3    2
+--R         - a c + - a b
+--R         8       8
+--R    *
+--R        7 8
+--R       e x
+--R   + 
+--R             3 9   5148    2 7          2       2   5                 3  3
+--R         715c d  + ---- b c d  + (198a c  + 198b c)d  + (72a b c + 12b )d
+--R                     7
+--R       + 
+--R            2        2
+--R         (3a c + 3a b )d
+--R    *
+--R        6 7
+--R       e x
+--R   + 
+--R         1001  3 10   1287    2 8          2       2   6                  3  4
+--R         ---- c d   + ---- b c d  + (231a c  + 231b c)d  + (126a b c + 21b )d
+--R           2            2
+--R       + 
+--R          21  2    21    2  2   1  2
+--R         (-- a c + -- a b )d  + - a b
+--R           2        2           2
+--R    *
+--R        5 6
+--R       e x
+--R   + 
+--R             3 11         2 9          2       2   7    756         126  3  5
+--R         273c d   + 429b c d  + (198a c  + 198b c)d  + (--- a b c + --- b )d
+--R                                                         5           5
+--R       + 
+--R             2         2  3     2
+--R         (21a c + 21a b )d  + 3a b d
+--R    *
+--R        4 5
+--R       e x
+--R   + 
+--R         455  3 12   429    2 10    495    2   495  2   8                  3  6
+--R         --- c d   + --- b c d   + (--- a c  + --- b c)d  + (126a b c + 21b )d
+--R          4           2              4          4
+--R       + 
+--R          105  2    105    2  4   15  2   2   1  3
+--R         (--- a c + --- a b )d  + -- a b d  + - a
+--R           4         4             2          4
+--R    *
+--R        3 4
+--R       e x
+--R   + 
+--R            3 13        2 11         2      2   9                 3  7
+--R         35c d   + 78b c d   + (55a c  + 55b c)d  + (72a b c + 12b )d
+--R       + 
+--R             2         2  5      2   3    3
+--R         (21a c + 21a b )d  + 10a b d  + a d
+--R    *
+--R        2 3
+--R       e x
+--R   + 
+--R         15  3 14   39    2 12    33    2   33  2   10              9  3  8
+--R         -- c d   + -- b c d   + (-- a c  + -- b c)d   + (27a b c + - b )d
+--R          2          2             2         2                      2
+--R       + 
+--R          21  2    21    2  6   15  2   4   3  3 2
+--R         (-- a c + -- a b )d  + -- a b d  + - a d
+--R           2        2            2          2
+--R    *
+--R          2
+--R       e x
+--R   + 
+--R          3 15       2 13        2     2   11              3  9
+--R         c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R       + 
+--R            2        2  7     2   5    3 3
+--R         (3a c + 3a b )d  + 3a b d  + a d
+--R    *
+--R       x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 732
+
+--S 733 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          1  3 16    3    2 14      1    2   1  2   12      3          1  3  10
+--R       - -- c d   - -- b c d   + (- - a c  - - b c)d   + (- - a b c - -- b )d
+--R         16         14              4        4              5         10
+--R     + 
+--R          3  2    3    2  8   1  2   6   1  3 4
+--R       (- - a c - - a b )d  - - a b d  - - a d
+--R          8       8           2          4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 733
+
+--S 734 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 734
+
+)clear all
+
+--S 735 of 1057
+t0:=(d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R        7 3 7         6 3 6         2      5 3 5         3         4 3 4
+--R     c e f x  + 7c d e f x  + (21c d  + b)e f x  + (35c d  + 5b d)e f x
+--R   + 
+--R           4        2      3 3 3         5        3         2 3 2
+--R     (35c d  + 10b d  + a)e f x  + (21c d  + 10b d  + 3a d)e f x
+--R   + 
+--R          6       4       2    3        7      5      3  3
+--R     (7c d  + 5b d  + 3a d )e f x + (c d  + b d  + a d )f
+--R                                                    Type: Polynomial(Integer)
+--E 735
+
+--S 736 of 1057
+r0:=1/4*a*f^3*(d+e*x)^4/e+1/6*b*f^3*(d+e*x)^6/e+1/8*c*f^3*(d+e*x)^8/e
+--R 
+--R
+--R   (2)
+--R       1    8 3 8        7 3 7    7    2   1    6 3 6        3        5 3 5
+--R       - c e f x  + c d e f x  + (- c d  + - b)e f x  + (7c d  + b d)e f x
+--R       8                          2        6
+--R     + 
+--R        35    4   5    2   1    4 3 4        5   10    3        3 3 3
+--R       (-- c d  + - b d  + - a)e f x  + (7c d  + -- b d  + a d)e f x
+--R         4        2        4                      3
+--R     + 
+--R        7    6   5    4   3    2  2 3 2       7      5      3    3
+--R       (- c d  + - b d  + - a d )e f x  + (c d  + b d  + a d )e f x
+--R        2        2        2
+--R     + 
+--R        1    8   1    6   1    4  3
+--R       (- c d  + - b d  + - a d )f
+--R        8        6        4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 736
+
+--S 737 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    7 3 8        6 3 7    7    2   1    5 3 6        3        4 3 5
+--R     - c e f x  + c d e f x  + (- c d  + - b)e f x  + (7c d  + b d)e f x
+--R     8                          2        6
+--R   + 
+--R      35    4   5    2   1    3 3 4        5   10    3        2 3 3
+--R     (-- c d  + - b d  + - a)e f x  + (7c d  + -- b d  + a d)e f x
+--R       4        2        4                      3
+--R   + 
+--R      7    6   5    4   3    2    3 2       7      5      3  3
+--R     (- c d  + - b d  + - a d )e f x  + (c d  + b d  + a d )f x
+--R      2        2        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 737
+
+--S 738 of 1057
+m0:=a0-r0
+--R 
+--R
+--R           1    8   1    6   1    4  3
+--R        (- - c d  - - b d  - - a d )f
+--R           8        6        4
+--R   (4)  ------------------------------
+--R                       e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 738
+
+--S 739 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 739
+
+)clear all
+
+--S 740 of 1057
+t0:=(d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      2 11 3 11      2   10 3 10       2 2         9 3 9
+--R     c e  f x   + 11c d e  f x   + (55c d  + 2b c)e f x
+--R   + 
+--R          2 3            8 3 8        2 4          2           2  7 3 7
+--R     (165c d  + 18b c d)e f x  + (330c d  + 72b c d  + 2a c + b )e f x
+--R   + 
+--R          2 5           3              2    6 3 6
+--R     (462c d  + 168b c d  + (14a c + 7b )d)e f x
+--R   + 
+--R          2 6           4               2  2         5 3 5
+--R     (462c d  + 252b c d  + (42a c + 21b )d  + 2a b)e f x
+--R   + 
+--R          2 7           5               2  3            4 3 4
+--R     (330c d  + 252b c d  + (70a c + 35b )d  + 10a b d)e f x
+--R   + 
+--R          2 8           6               2  4          2    2  3 3 3
+--R     (165c d  + 168b c d  + (70a c + 35b )d  + 20a b d  + a )e f x
+--R   + 
+--R         2 9          7               2  5          3     2   2 3 2
+--R     (55c d  + 72b c d  + (42a c + 21b )d  + 20a b d  + 3a d)e f x
+--R   + 
+--R         2 10          8              2  6          4     2 2    3
+--R     (11c d   + 18b c d  + (14a c + 7b )d  + 10a b d  + 3a d )e f x
+--R   + 
+--R       2 11         9            2  7         5    2 3  3
+--R     (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )f
+--R                                                    Type: Polynomial(Integer)
+--E 740
+
+--S 741 of 1057
+r0:=1/4*a^2*f^3*(d+e*x)^4/e+1/3*a*b*f^3*(d+e*x)^6/e+1/8*(b^2+2*a*c)*f^3*_
+   (d+e*x)^8/e+1/5*b*c*f^3*(d+e*x)^10/e+1/12*c^2*f^3*(d+e*x)^12/e
+--R 
+--R
+--R   (2)
+--R        1  2 12 3 12    2   11 3 11    11  2 2   1      10 3 10
+--R       -- c e  f x   + c d e  f x   + (-- c d  + - b c)e  f x
+--R       12                               2        5
+--R     + 
+--R        55  2 3           9 3 9    165  2 4         2   1       1  2  8 3 8
+--R       (-- c d  + 2b c d)e f x  + (--- c d  + 9b c d  + - a c + - b )e f x
+--R         3                          4                   4       8
+--R     + 
+--R           2 5          3            2    7 3 7
+--R       (66c d  + 24b c d  + (2a c + b )d)e f x
+--R     + 
+--R           2 6          4           7  2  2   1      6 3 6
+--R       (77c d  + 42b c d  + (7a c + - b )d  + - a b)e f x
+--R                                    2         3
+--R     + 
+--R           2 7   252      5              2  3           5 3 5
+--R       (66c d  + --- b c d  + (14a c + 7b )d  + 2a b d)e f x
+--R                  5
+--R     + 
+--R        165  2 8          6    35       35  2  4         2   1  2  4 3 4
+--R       (--- c d  + 42b c d  + (-- a c + -- b )d  + 5a b d  + - a )e f x
+--R         4                      2        4                   4
+--R     + 
+--R        55  2 9          7              2  5   20      3    2   3 3 3
+--R       (-- c d  + 24b c d  + (14a c + 7b )d  + -- a b d  + a d)e f x
+--R         3                                      3
+--R     + 
+--R        11  2 10         8           7  2  6         4   3  2 2  2 3 2
+--R       (-- c d   + 9b c d  + (7a c + - b )d  + 5a b d  + - a d )e f x
+--R         2                           2                   2
+--R     + 
+--R         2 11         9            2  7         5    2 3    3
+--R       (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )e f x
+--R     + 
+--R         1  2 12   1      10    1       1  2  8   1      6   1  2 4  3
+--R       (-- c d   + - b c d   + (- a c + - b )d  + - a b d  + - a d )f
+--R        12         5            4       8         3          4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 741
+
+--S 742 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  2 11 3 12    2   10 3 11    11  2 2   1      9 3 10
+--R     -- c e  f x   + c d e  f x   + (-- c d  + - b c)e f x
+--R     12                               2        5
+--R   + 
+--R      55  2 3           8 3 9    165  2 4         2   1       1  2  7 3 8
+--R     (-- c d  + 2b c d)e f x  + (--- c d  + 9b c d  + - a c + - b )e f x
+--R       3                          4                   4       8
+--R   + 
+--R         2 5          3            2    6 3 7
+--R     (66c d  + 24b c d  + (2a c + b )d)e f x
+--R   + 
+--R         2 6          4           7  2  2   1      5 3 6
+--R     (77c d  + 42b c d  + (7a c + - b )d  + - a b)e f x
+--R                                  2         3
+--R   + 
+--R         2 7   252      5              2  3           4 3 5
+--R     (66c d  + --- b c d  + (14a c + 7b )d  + 2a b d)e f x
+--R                5
+--R   + 
+--R      165  2 8          6    35       35  2  4         2   1  2  3 3 4
+--R     (--- c d  + 42b c d  + (-- a c + -- b )d  + 5a b d  + - a )e f x
+--R       4                      2        4                   4
+--R   + 
+--R      55  2 9          7              2  5   20      3    2   2 3 3
+--R     (-- c d  + 24b c d  + (14a c + 7b )d  + -- a b d  + a d)e f x
+--R       3                                      3
+--R   + 
+--R      11  2 10         8           7  2  6         4   3  2 2    3 2
+--R     (-- c d   + 9b c d  + (7a c + - b )d  + 5a b d  + - a d )e f x
+--R       2                           2                   2
+--R   + 
+--R       2 11         9            2  7         5    2 3  3
+--R     (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )f x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 742
+
+--S 743 of 1057
+m0:=a0-r0
+--R 
+--R
+--R            1  2 12   1      10      1       1  2  8   1      6   1  2 4  3
+--R        (- -- c d   - - b c d   + (- - a c - - b )d  - - a b d  - - a d )f
+--R           12         5              4       8         3          4
+--R   (4)  -------------------------------------------------------------------
+--R                                         e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 743
+
+--S 744 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 744
+
+)clear all
+
+--S 745 of 1057
+t0:=(d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      3 15 3 15      3   14 3 14        3 2       2  13 3 13
+--R     c e  f x   + 15c d e  f x   + (105c d  + 3b c )e  f x
+--R   + 
+--R          3 3        2   12 3 12         3 4         2 2       2     2   11 3 11
+--R     (455c d  + 39b c d)e  f x   + (1365c d  + 234b c d  + 3a c  + 3b c)e  f x
+--R   + 
+--R           3 5         2 3         2      2     10 3 10
+--R     (3003c d  + 858b c d  + (33a c  + 33b c)d)e  f x
+--R   + 
+--R           3 6          2 4          2       2   2             3  9 3 9
+--R     (5005c d  + 2145b c d  + (165a c  + 165b c)d  + 6a b c + b )e f x
+--R   + 
+--R           3 7          2 5          2       2   3                3    8 3 8
+--R     (6435c d  + 3861b c d  + (495a c  + 495b c)d  + (54a b c + 9b )d)e f x
+--R   + 
+--R              3 8          2 6          2       2   4                  3  2
+--R         6435c d  + 5148b c d  + (990a c  + 990b c)d  + (216a b c + 36b )d
+--R       + 
+--R           2        2
+--R         3a c + 3a b
+--R    *
+--R        7 3 7
+--R       e f x
+--R   + 
+--R              3 9          2 7           2        2   5                  3  3
+--R         5005c d  + 5148b c d  + (1386a c  + 1386b c)d  + (504a b c + 84b )d
+--R       + 
+--R             2         2
+--R         (21a c + 21a b )d
+--R    *
+--R        6 3 6
+--R       e f x
+--R   + 
+--R              3 10          2 8           2        2   6                   3  4
+--R         3003c d   + 3861b c d  + (1386a c  + 1386b c)d  + (756a b c + 126b )d
+--R       + 
+--R             2         2  2     2
+--R         (63a c + 63a b )d  + 3a b
+--R    *
+--R        5 3 5
+--R       e f x
+--R   + 
+--R              3 11          2 9          2       2   7                   3  5
+--R         1365c d   + 2145b c d  + (990a c  + 990b c)d  + (756a b c + 126b )d
+--R       + 
+--R              2          2  3      2
+--R         (105a c + 105a b )d  + 15a b d
+--R    *
+--R        4 3 4
+--R       e f x
+--R   + 
+--R             3 12         2 10          2       2   8                  3  6
+--R         455c d   + 858b c d   + (495a c  + 495b c)d  + (504a b c + 84b )d
+--R       + 
+--R              2          2  4      2   2    3
+--R         (105a c + 105a b )d  + 30a b d  + a
+--R    *
+--R        3 3 3
+--R       e f x
+--R   + 
+--R             3 13         2 11          2       2   9                  3  7
+--R         105c d   + 234b c d   + (165a c  + 165b c)d  + (216a b c + 36b )d
+--R       + 
+--R             2         2  5      2   3     3
+--R         (63a c + 63a b )d  + 30a b d  + 3a d
+--R    *
+--R        2 3 2
+--R       e f x
+--R   + 
+--R            3 14        2 12         2      2   10                3  8
+--R         15c d   + 39b c d   + (33a c  + 33b c)d   + (54a b c + 9b )d
+--R       + 
+--R             2         2  6      2   4     3 2
+--R         (21a c + 21a b )d  + 15a b d  + 3a d
+--R    *
+--R          3
+--R       e f x
+--R   + 
+--R          3 15       2 13        2     2   11              3  9
+--R         c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R       + 
+--R            2        2  7     2   5    3 3
+--R         (3a c + 3a b )d  + 3a b d  + a d
+--R    *
+--R        3
+--R       f
+--R                                                    Type: Polynomial(Integer)
+--E 745
+
+--S 746 of 1057
+r0:=1/4*a^3*f^3*(d+e*x)^4/e+1/2*a^2*b*f^3*(d+e*x)^6/e+3/8*a*(b^2+a*c)*f^3*_
+   (d+e*x)^8/e+1/10*b*(b^2+6*a*c)*f^3*(d+e*x)^10/e+1/4*c*(b^2+a*c)*f^3*_
+   (d+e*x)^12/e+3/14*b*c^2*f^3*(d+e*x)^14/e+1/16*c^3*f^3*(d+e*x)^16/e
+--R 
+--R
+--R   (2)
+--R        1  3 16 3 16    3   15 3 15    15  3 2    3    2  14 3 14
+--R       -- c e  f x   + c d e  f x   + (-- c d  + -- b c )e  f x
+--R       16                               2        14
+--R     + 
+--R           3 3       2   13 3 13
+--R       (35c d  + 3b c d)e  f x
+--R     + 
+--R        455  3 4   39    2 2   1    2   1  2   12 3 12
+--R       (--- c d  + -- b c d  + - a c  + - b c)e  f x
+--R         4          2          4        4
+--R     + 
+--R            3 5        2 3        2     2     11 3 11
+--R       (273c d  + 78b c d  + (3a c  + 3b c)d)e  f x
+--R     + 
+--R        1001  3 6   429    2 4    33    2   33  2   2   3          1  3  10 3 10
+--R       (---- c d  + --- b c d  + (-- a c  + -- b c)d  + - a b c + -- b )e  f x
+--R          2          2             2         2          5         10
+--R     + 
+--R            3 7         2 5         2      2   3              3    9 3 9
+--R       (715c d  + 429b c d  + (55a c  + 55b c)d  + (6a b c + b )d)e f x
+--R     + 
+--R           6435  3 8   1287    2 6    495    2   495  2   4              9  3  2
+--R           ---- c d  + ---- b c d  + (--- a c  + --- b c)d  + (27a b c + - b )d
+--R             8           2             4          4                      2
+--R         + 
+--R           3  2    3    2
+--R           - a c + - a b
+--R           8       8
+--R      *
+--R          8 3 8
+--R         e f x
+--R     + 
+--R               3 9   5148    2 7          2       2   5                 3  3
+--R           715c d  + ---- b c d  + (198a c  + 198b c)d  + (72a b c + 12b )d
+--R                       7
+--R         + 
+--R              2        2
+--R           (3a c + 3a b )d
+--R      *
+--R          7 3 7
+--R         e f x
+--R     + 
+--R           1001  3 10   1287    2 8          2       2   6                  3  4
+--R           ---- c d   + ---- b c d  + (231a c  + 231b c)d  + (126a b c + 21b )d
+--R             2            2
+--R         + 
+--R            21  2    21    2  2   1  2
+--R           (-- a c + -- a b )d  + - a b
+--R             2        2           2
+--R      *
+--R          6 3 6
+--R         e f x
+--R     + 
+--R               3 11         2 9          2       2   7    756         126  3  5
+--R           273c d   + 429b c d  + (198a c  + 198b c)d  + (--- a b c + --- b )d
+--R                                                           5           5
+--R         + 
+--R               2         2  3     2
+--R           (21a c + 21a b )d  + 3a b d
+--R      *
+--R          5 3 5
+--R         e f x
+--R     + 
+--R           455  3 12   429    2 10    495    2   495  2   8
+--R           --- c d   + --- b c d   + (--- a c  + --- b c)d
+--R            4           2              4          4
+--R         + 
+--R                          3  6    105  2    105    2  4   15  2   2   1  3
+--R           (126a b c + 21b )d  + (--- a c + --- a b )d  + -- a b d  + - a
+--R                                   4         4             2          4
+--R      *
+--R          4 3 4
+--R         e f x
+--R     + 
+--R              3 13        2 11         2      2   9                 3  7
+--R           35c d   + 78b c d   + (55a c  + 55b c)d  + (72a b c + 12b )d
+--R         + 
+--R               2         2  5      2   3    3
+--R           (21a c + 21a b )d  + 10a b d  + a d
+--R      *
+--R          3 3 3
+--R         e f x
+--R     + 
+--R           15  3 14   39    2 12    33    2   33  2   10              9  3  8
+--R           -- c d   + -- b c d   + (-- a c  + -- b c)d   + (27a b c + - b )d
+--R            2          2             2         2                      2
+--R         + 
+--R            21  2    21    2  6   15  2   4   3  3 2
+--R           (-- a c + -- a b )d  + -- a b d  + - a d
+--R             2        2            2          2
+--R      *
+--R          2 3 2
+--R         e f x
+--R     + 
+--R            3 15       2 13        2     2   11              3  9
+--R           c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R         + 
+--R              2        2  7     2   5    3 3
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R            3
+--R         e f x
+--R     + 
+--R            1  3 16    3    2 14    1    2   1  2   12    3          1  3  10
+--R           -- c d   + -- b c d   + (- a c  + - b c)d   + (- a b c + -- b )d
+--R           16         14            4        4            5         10
+--R         + 
+--R            3  2    3    2  8   1  2   6   1  3 4
+--R           (- a c + - a b )d  + - a b d  + - a d
+--R            8       8           2          4
+--R      *
+--R          3
+--R         f
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 746
+
+--S 747 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3 15 3 16    3   14 3 15    15  3 2    3    2  13 3 14
+--R     -- c e  f x   + c d e  f x   + (-- c d  + -- b c )e  f x
+--R     16                               2        14
+--R   + 
+--R         3 3       2   12 3 13    455  3 4   39    2 2   1    2   1  2   11 3 12
+--R     (35c d  + 3b c d)e  f x   + (--- c d  + -- b c d  + - a c  + - b c)e  f x
+--R                                   4          2          4        4
+--R   + 
+--R          3 5        2 3        2     2     10 3 11
+--R     (273c d  + 78b c d  + (3a c  + 3b c)d)e  f x
+--R   + 
+--R      1001  3 6   429    2 4    33    2   33  2   2   3          1  3  9 3 10
+--R     (---- c d  + --- b c d  + (-- a c  + -- b c)d  + - a b c + -- b )e f x
+--R        2          2             2         2          5         10
+--R   + 
+--R          3 7         2 5         2      2   3              3    8 3 9
+--R     (715c d  + 429b c d  + (55a c  + 55b c)d  + (6a b c + b )d)e f x
+--R   + 
+--R         6435  3 8   1287    2 6    495    2   495  2   4              9  3  2
+--R         ---- c d  + ---- b c d  + (--- a c  + --- b c)d  + (27a b c + - b )d
+--R           8           2             4          4                      2
+--R       + 
+--R         3  2    3    2
+--R         - a c + - a b
+--R         8       8
+--R    *
+--R        7 3 8
+--R       e f x
+--R   + 
+--R             3 9   5148    2 7          2       2   5                 3  3
+--R         715c d  + ---- b c d  + (198a c  + 198b c)d  + (72a b c + 12b )d
+--R                     7
+--R       + 
+--R            2        2
+--R         (3a c + 3a b )d
+--R    *
+--R        6 3 7
+--R       e f x
+--R   + 
+--R         1001  3 10   1287    2 8          2       2   6                  3  4
+--R         ---- c d   + ---- b c d  + (231a c  + 231b c)d  + (126a b c + 21b )d
+--R           2            2
+--R       + 
+--R          21  2    21    2  2   1  2
+--R         (-- a c + -- a b )d  + - a b
+--R           2        2           2
+--R    *
+--R        5 3 6
+--R       e f x
+--R   + 
+--R             3 11         2 9          2       2   7    756         126  3  5
+--R         273c d   + 429b c d  + (198a c  + 198b c)d  + (--- a b c + --- b )d
+--R                                                         5           5
+--R       + 
+--R             2         2  3     2
+--R         (21a c + 21a b )d  + 3a b d
+--R    *
+--R        4 3 5
+--R       e f x
+--R   + 
+--R         455  3 12   429    2 10    495    2   495  2   8                  3  6
+--R         --- c d   + --- b c d   + (--- a c  + --- b c)d  + (126a b c + 21b )d
+--R          4           2              4          4
+--R       + 
+--R          105  2    105    2  4   15  2   2   1  3
+--R         (--- a c + --- a b )d  + -- a b d  + - a
+--R           4         4             2          4
+--R    *
+--R        3 3 4
+--R       e f x
+--R   + 
+--R            3 13        2 11         2      2   9                 3  7
+--R         35c d   + 78b c d   + (55a c  + 55b c)d  + (72a b c + 12b )d
+--R       + 
+--R             2         2  5      2   3    3
+--R         (21a c + 21a b )d  + 10a b d  + a d
+--R    *
+--R        2 3 3
+--R       e f x
+--R   + 
+--R         15  3 14   39    2 12    33    2   33  2   10              9  3  8
+--R         -- c d   + -- b c d   + (-- a c  + -- b c)d   + (27a b c + - b )d
+--R          2          2             2         2                      2
+--R       + 
+--R          21  2    21    2  6   15  2   4   3  3 2
+--R         (-- a c + -- a b )d  + -- a b d  + - a d
+--R           2        2            2          2
+--R    *
+--R          3 2
+--R       e f x
+--R   + 
+--R          3 15       2 13        2     2   11              3  9
+--R         c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R       + 
+--R            2        2  7     2   5    3 3
+--R         (3a c + 3a b )d  + 3a b d  + a d
+--R    *
+--R        3
+--R       f x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 747
+
+--S 748 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            1  3 16    3    2 14      1    2   1  2   12
+--R         - -- c d   - -- b c d   + (- - a c  - - b c)d
+--R           16         14              4        4
+--R       + 
+--R            3          1  3  10      3  2    3    2  8   1  2   6   1  3 4
+--R         (- - a b c - -- b )d   + (- - a c - - a b )d  - - a b d  - - a d
+--R            5         10             8       8           2          4
+--R    *
+--R        3
+--R       f
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 748
+
+--S 749 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 749
+
+)clear all
+
+--S 750 of 1057
+t0:=(d+e*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                      4 4       3 3     2 2 2     3       4
+--R                     e x  + 4d e x  + 6d e x  + 4d e x + d
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 750
+
+--S 751 of 1057
+r0:=x/c-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+(-b^2+_
+   2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R              +-----------+              | +-----------+
+--R              |          2            2  | |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R              +-----------+              |   +-----------+
+--R              |          2            2  |   |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R       e x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R         +-+ |          2  +-+ |   |          2       | |          2
+--R     c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-------------------------------------------------------+
+--R           |                   +--------------------+
+--R           |                   |   2 2       2     4
+--R           |      4     2 3  2 |- a c  + 2a b c - b               3
+--R           |(16a c  - 4b c )e  |--------------------  - 3a b c + b
+--R           |                   |       7      2 6  4
+--R           |                  \| (64a c  - 16b c )e
+--R         c |-------------------------------------------------------
+--R           |                        4     2 3  2
+--R          \|                   (8a c  - 2b c )e
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                          4     3 3  3 |- a c  + 2a b c - b
+--R                  (16a b c  - 4b c )e  |--------------------
+--R                                       |       7      2 6  4
+--R                                      \| (64a c  - 16b c )e
+--R                + 
+--R                       2 2       2     4
+--R                  (- 4a c  + 5a b c - b )e
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |      4     2 3  2 |- a c  + 2a b c - b               3
+--R                 |(16a c  - 4b c )e  |--------------------  - 3a b c + b
+--R                 |                   |       7      2 6  4
+--R                 |                  \| (64a c  - 16b c )e
+--R                 |-------------------------------------------------------
+--R                 |                        4     2 3  2
+--R                \|                   (8a c  - 2b c )e
+--R            + 
+--R                 2        2          2        2
+--R              (2a c - 2a b )e x + (2a c - 2a b )d
+--R     + 
+--R       -
+--R              +---------------------------------------------------------+
+--R              |                     +--------------------+
+--R              |                     |   2 2       2     4
+--R              |        4     2 3  2 |- a c  + 2a b c - b               3
+--R              |(- 16a c  + 4b c )e  |--------------------  - 3a b c + b
+--R              |                     |       7      2 6  4
+--R              |                    \| (64a c  - 16b c )e
+--R            c |---------------------------------------------------------
+--R              |                         4     2 3  2
+--R             \|                    (8a c  - 2b c )e
+--R         *
+--R            log
+--R                                          +--------------------+
+--R                                          |   2 2       2     4
+--R                             4     3 3  3 |- a c  + 2a b c - b
+--R                     (16a b c  - 4b c )e  |--------------------
+--R                                          |       7      2 6  4
+--R                                         \| (64a c  - 16b c )e
+--R                   + 
+--R                        2 2       2     4
+--R                     (4a c  - 5a b c + b )e
+--R                *
+--R                    +---------------------------------------------------------+
+--R                    |                     +--------------------+
+--R                    |                     |   2 2       2     4
+--R                    |        4     2 3  2 |- a c  + 2a b c - b               3
+--R                    |(- 16a c  + 4b c )e  |--------------------  - 3a b c + b
+--R                    |                     |       7      2 6  4
+--R                    |                    \| (64a c  - 16b c )e
+--R                    |---------------------------------------------------------
+--R                    |                         4     2 3  2
+--R                   \|                    (8a c  - 2b c )e
+--R               + 
+--R                    2        2          2        2
+--R                 (2a c - 2a b )e x + (2a c - 2a b )d
+--R     + 
+--R           +---------------------------------------------------------+
+--R           |                     +--------------------+
+--R           |                     |   2 2       2     4
+--R           |        4     2 3  2 |- a c  + 2a b c - b               3
+--R           |(- 16a c  + 4b c )e  |--------------------  - 3a b c + b
+--R           |                     |       7      2 6  4
+--R           |                    \| (64a c  - 16b c )e
+--R         c |---------------------------------------------------------
+--R           |                         4     2 3  2
+--R          \|                    (8a c  - 2b c )e
+--R      *
+--R         log
+--R                                         +--------------------+
+--R                                         |   2 2       2     4
+--R                            4     3 3  3 |- a c  + 2a b c - b
+--R                  (- 16a b c  + 4b c )e  |--------------------
+--R                                         |       7      2 6  4
+--R                                        \| (64a c  - 16b c )e
+--R                + 
+--R                       2 2       2     4
+--R                  (- 4a c  + 5a b c - b )e
+--R             *
+--R                 +---------------------------------------------------------+
+--R                 |                     +--------------------+
+--R                 |                     |   2 2       2     4
+--R                 |        4     2 3  2 |- a c  + 2a b c - b               3
+--R                 |(- 16a c  + 4b c )e  |--------------------  - 3a b c + b
+--R                 |                     |       7      2 6  4
+--R                 |                    \| (64a c  - 16b c )e
+--R                 |---------------------------------------------------------
+--R                 |                         4     2 3  2
+--R                \|                    (8a c  - 2b c )e
+--R            + 
+--R                 2        2          2        2
+--R              (2a c - 2a b )e x + (2a c - 2a b )d
+--R     + 
+--R       -
+--R              +-------------------------------------------------------+
+--R              |                   +--------------------+
+--R              |                   |   2 2       2     4
+--R              |      4     2 3  2 |- a c  + 2a b c - b               3
+--R              |(16a c  - 4b c )e  |--------------------  - 3a b c + b
+--R              |                   |       7      2 6  4
+--R              |                  \| (64a c  - 16b c )e
+--R            c |-------------------------------------------------------
+--R              |                        4     2 3  2
+--R             \|                   (8a c  - 2b c )e
+--R         *
+--R            log
+--R                                            +--------------------+
+--R                                            |   2 2       2     4
+--R                               4     3 3  3 |- a c  + 2a b c - b
+--R                     (- 16a b c  + 4b c )e  |--------------------
+--R                                            |       7      2 6  4
+--R                                           \| (64a c  - 16b c )e
+--R                   + 
+--R                        2 2       2     4
+--R                     (4a c  - 5a b c + b )e
+--R                *
+--R                    +-------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |      4     2 3  2 |- a c  + 2a b c - b               3
+--R                    |(16a c  - 4b c )e  |--------------------  - 3a b c + b
+--R                    |                   |       7      2 6  4
+--R                    |                  \| (64a c  - 16b c )e
+--R                    |-------------------------------------------------------
+--R                    |                        4     2 3  2
+--R                   \|                   (8a c  - 2b c )e
+--R               + 
+--R                    2        2          2        2
+--R                 (2a c - 2a b )e x + (2a c - 2a b )d
+--R     + 
+--R       2x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 752
+
+--S 753 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   +--------------------+ +------------------+
+--R                 +-----------+     |   +-----------+      | +-----------+
+--R             +-+ |          2  +-+ |   |          2       | |          2
+--R         c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +-------------------------------------------------------+
+--R          |                   +--------------------+
+--R          |                   |   2 2       2     4
+--R          |      4     2 3  2 |- a c  + 2a b c - b               3
+--R          |(16a c  - 4b c )e  |--------------------  - 3a b c + b
+--R          |                   |       7      2 6  4
+--R          |                  \| (64a c  - 16b c )e
+--R          |-------------------------------------------------------
+--R          |                        4     2 3  2
+--R         \|                   (8a c  - 2b c )e
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                          4     3 3  3 |- a c  + 2a b c - b
+--R                  (16a b c  - 4b c )e  |--------------------
+--R                                       |       7      2 6  4
+--R                                      \| (64a c  - 16b c )e
+--R                + 
+--R                       2 2       2     4
+--R                  (- 4a c  + 5a b c - b )e
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |      4     2 3  2 |- a c  + 2a b c - b               3
+--R                 |(16a c  - 4b c )e  |--------------------  - 3a b c + b
+--R                 |                   |       7      2 6  4
+--R                 |                  \| (64a c  - 16b c )e
+--R                 |-------------------------------------------------------
+--R                 |                        4     2 3  2
+--R                \|                   (8a c  - 2b c )e
+--R            + 
+--R                 2        2          2        2
+--R              (2a c - 2a b )e x + (2a c - 2a b )d
+--R     + 
+--R       -
+--R                    +-----------+
+--R                +-+ |          2  +-+
+--R            c e\|2 \|- 4a c + b  \|c
+--R         *
+--R             +---------------------------------------------------------+
+--R             |                     +--------------------+
+--R             |                     |   2 2       2     4
+--R             |        4     2 3  2 |- a c  + 2a b c - b               3
+--R             |(- 16a c  + 4b c )e  |--------------------  - 3a b c + b
+--R             |                     |       7      2 6  4
+--R             |                    \| (64a c  - 16b c )e
+--R             |---------------------------------------------------------
+--R             |                         4     2 3  2
+--R            \|                    (8a c  - 2b c )e
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                          +--------------------+
+--R                                          |   2 2       2     4
+--R                             4     3 3  3 |- a c  + 2a b c - b
+--R                     (16a b c  - 4b c )e  |--------------------
+--R                                          |       7      2 6  4
+--R                                         \| (64a c  - 16b c )e
+--R                   + 
+--R                        2 2       2     4
+--R                     (4a c  - 5a b c + b )e
+--R                *
+--R                    +---------------------------------------------------------+
+--R                    |                     +--------------------+
+--R                    |                     |   2 2       2     4
+--R                    |        4     2 3  2 |- a c  + 2a b c - b               3
+--R                    |(- 16a c  + 4b c )e  |--------------------  - 3a b c + b
+--R                    |                     |       7      2 6  4
+--R                    |                    \| (64a c  - 16b c )e
+--R                    |---------------------------------------------------------
+--R                    |                         4     2 3  2
+--R                   \|                    (8a c  - 2b c )e
+--R               + 
+--R                    2        2          2        2
+--R                 (2a c - 2a b )e x + (2a c - 2a b )d
+--R     + 
+--R                 +-----------+
+--R             +-+ |          2  +-+
+--R         c e\|2 \|- 4a c + b  \|c
+--R      *
+--R          +---------------------------------------------------------+
+--R          |                     +--------------------+
+--R          |                     |   2 2       2     4
+--R          |        4     2 3  2 |- a c  + 2a b c - b               3
+--R          |(- 16a c  + 4b c )e  |--------------------  - 3a b c + b
+--R          |                     |       7      2 6  4
+--R          |                    \| (64a c  - 16b c )e
+--R          |---------------------------------------------------------
+--R          |                         4     2 3  2
+--R         \|                    (8a c  - 2b c )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                         +--------------------+
+--R                                         |   2 2       2     4
+--R                            4     3 3  3 |- a c  + 2a b c - b
+--R                  (- 16a b c  + 4b c )e  |--------------------
+--R                                         |       7      2 6  4
+--R                                        \| (64a c  - 16b c )e
+--R                + 
+--R                       2 2       2     4
+--R                  (- 4a c  + 5a b c - b )e
+--R             *
+--R                 +---------------------------------------------------------+
+--R                 |                     +--------------------+
+--R                 |                     |   2 2       2     4
+--R                 |        4     2 3  2 |- a c  + 2a b c - b               3
+--R                 |(- 16a c  + 4b c )e  |--------------------  - 3a b c + b
+--R                 |                     |       7      2 6  4
+--R                 |                    \| (64a c  - 16b c )e
+--R                 |---------------------------------------------------------
+--R                 |                         4     2 3  2
+--R                \|                    (8a c  - 2b c )e
+--R            + 
+--R                 2        2          2        2
+--R              (2a c - 2a b )e x + (2a c - 2a b )d
+--R     + 
+--R       -
+--R                                      +--------------------+
+--R                    +-----------+     |   +-----------+
+--R                +-+ |          2  +-+ |   |          2
+--R            c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R             +-------------------------------------------------------+
+--R             |                   +--------------------+
+--R             |                   |   2 2       2     4
+--R             |      4     2 3  2 |- a c  + 2a b c - b               3
+--R             |(16a c  - 4b c )e  |--------------------  - 3a b c + b
+--R             |                   |       7      2 6  4
+--R             |                  \| (64a c  - 16b c )e
+--R             |-------------------------------------------------------
+--R             |                        4     2 3  2
+--R            \|                   (8a c  - 2b c )e
+--R         *
+--R            log
+--R                                            +--------------------+
+--R                                            |   2 2       2     4
+--R                               4     3 3  3 |- a c  + 2a b c - b
+--R                     (- 16a b c  + 4b c )e  |--------------------
+--R                                            |       7      2 6  4
+--R                                           \| (64a c  - 16b c )e
+--R                   + 
+--R                        2 2       2     4
+--R                     (4a c  - 5a b c + b )e
+--R                *
+--R                    +-------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |      4     2 3  2 |- a c  + 2a b c - b               3
+--R                    |(16a c  - 4b c )e  |--------------------  - 3a b c + b
+--R                    |                   |       7      2 6  4
+--R                    |                  \| (64a c  - 16b c )e
+--R                    |-------------------------------------------------------
+--R                    |                        4     2 3  2
+--R                   \|                   (8a c  - 2b c )e
+--R               + 
+--R                    2        2          2        2
+--R                 (2a c - 2a b )e x + (2a c - 2a b )d
+--R     + 
+--R                                         +------------------+
+--R             +-----------+               | +-----------+
+--R             |          2             2  | |          2
+--R         (2b\|- 4a c + b   + 4a c - 2b )\|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R             +-----------+               |   +-----------+
+--R             |          2             2  |   |          2
+--R         (2b\|- 4a c + b   - 4a c + 2b )\|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R     2c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 753
+
+--S 754 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 754
+
+)clear all
+
+--S 755 of 1057
+t0:=(d+e*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                           3 3       2 2     2       3
+--R                          e x  + 3d e x  + 3d e x + d
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 755
+
+--S 756 of 1057
+r0:=1/4*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(c*e)+1/2*b*atanh((b+2*c*(d+e*x)^2)/_
+   sqrt(b^2-4*a*c))/(c*e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    2 2                  2
+--R                2c e x  + 4c d e x + 2c d  + b
+--R       2b atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R     + 
+--R         log
+--R                 4 4         3 3        2      2 2        3                 4
+--R              c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R            + 
+--R                 2
+--R              b d  + a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     4c e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R           log
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R            +-----------+
+--R            |          2
+--R       4c e\|- 4a c + b
+--R     ,
+--R
+--R                                                    +---------+
+--R                        2 2                  2      |        2
+--R                   (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         - 2b atan(--------------------------------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R           log
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R            +---------+
+--R            |        2
+--R       4c e\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 757
+
+--S 758 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                      2 2                  2
+--R                  2c e x  + 4c d e x + 2c d  + b
+--R       - 2b atanh(------------------------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     4c e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 758
+
+--S 759 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+          2 2                  2
+--R           |        2       2c e x  + 4c d e x + 2c d  + b
+--R       - b\|4a c - b  atanh(------------------------------)
+--R                                     +-----------+
+--R                                     |          2
+--R                                    \|- 4a c + b
+--R     + 
+--R                                                              +---------+
+--R           +-----------+          2 2                  2      |        2
+--R           |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(--------------------------------------------)
+--R                                                       2
+--R                                               4a c - b
+--R  /
+--R          +-----------+ +---------+
+--R          |          2  |        2
+--R     2c e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 760
+
+--S 761 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 761
+
+)clear all
+
+--S 762 of 1057
+t0:=(d+e*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                                2 2             2
+--R                               e x  + 2d e x + d
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 762
+
+--S 763 of 1057
+r0:=-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(b-sqrt(b^2-_
+   4*a*c))/(e*sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))/(e*sqrt(2)*_
+   sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +--------------------+
+--R          |   +-----------+                       +-+ +-+
+--R          |   |          2              (e x + d)\|2 \|c
+--R       - \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                      |   |          2
+--R                                     \|- \|- 4a c + b   + b
+--R     + 
+--R        +------------------+
+--R        | +-----------+                      +-+ +-+
+--R        | |          2             (e x + d)\|2 \|c
+--R       \|\|- 4a c + b   + b atan(---------------------)
+--R                                  +------------------+
+--R                                  | +-----------+
+--R                                  | |          2
+--R                                 \|\|- 4a c + b   + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     e\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 763
+
+--S 764 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +---------------------------------------------+
+--R          |                  +---------------------+
+--R          |      2     2   2 |           1
+--R          |(16a c  - 4b c)e  |- -------------------  + b
+--R          |                  |        3      2 2  4
+--R          |                 \|  (64a c  - 16b c )e
+--R          |---------------------------------------------
+--R          |                    2     2   2
+--R         \|               (8a c  - 2b c)e
+--R      *
+--R         log
+--R                                  +---------------------+
+--R                      2     2   3 |           1
+--R                (16a c  - 4b c)e  |- -------------------
+--R                                  |        3      2 2  4
+--R                                 \|  (64a c  - 16b c )e
+--R             *
+--R                 +---------------------------------------------+
+--R                 |                  +---------------------+
+--R                 |      2     2   2 |           1
+--R                 |(16a c  - 4b c)e  |- -------------------  + b
+--R                 |                  |        3      2 2  4
+--R                 |                 \|  (64a c  - 16b c )e
+--R                 |---------------------------------------------
+--R                 |                    2     2   2
+--R                \|               (8a c  - 2b c)e
+--R            + 
+--R              e x + d
+--R     + 
+--R       -
+--R             +-----------------------------------------------+
+--R             |                    +---------------------+
+--R             |        2     2   2 |           1
+--R             |(- 16a c  + 4b c)e  |- -------------------  + b
+--R             |                    |        3      2 2  4
+--R             |                   \|  (64a c  - 16b c )e
+--R             |-----------------------------------------------
+--R             |                     2     2   2
+--R            \|                (8a c  - 2b c)e
+--R         *
+--R            log
+--R                                     +---------------------+
+--R                         2     2   3 |           1
+--R                   (16a c  - 4b c)e  |- -------------------
+--R                                     |        3      2 2  4
+--R                                    \|  (64a c  - 16b c )e
+--R                *
+--R                    +-----------------------------------------------+
+--R                    |                    +---------------------+
+--R                    |        2     2   2 |           1
+--R                    |(- 16a c  + 4b c)e  |- -------------------  + b
+--R                    |                    |        3      2 2  4
+--R                    |                   \|  (64a c  - 16b c )e
+--R                    |-----------------------------------------------
+--R                    |                     2     2   2
+--R                   \|                (8a c  - 2b c)e
+--R               + 
+--R                 e x + d
+--R     + 
+--R          +-----------------------------------------------+
+--R          |                    +---------------------+
+--R          |        2     2   2 |           1
+--R          |(- 16a c  + 4b c)e  |- -------------------  + b
+--R          |                    |        3      2 2  4
+--R          |                   \|  (64a c  - 16b c )e
+--R          |-----------------------------------------------
+--R          |                     2     2   2
+--R         \|                (8a c  - 2b c)e
+--R      *
+--R         log
+--R                                    +---------------------+
+--R                        2     2   3 |           1
+--R                (- 16a c  + 4b c)e  |- -------------------
+--R                                    |        3      2 2  4
+--R                                   \|  (64a c  - 16b c )e
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |                    +---------------------+
+--R                 |        2     2   2 |           1
+--R                 |(- 16a c  + 4b c)e  |- -------------------  + b
+--R                 |                    |        3      2 2  4
+--R                 |                   \|  (64a c  - 16b c )e
+--R                 |-----------------------------------------------
+--R                 |                     2     2   2
+--R                \|                (8a c  - 2b c)e
+--R            + 
+--R              e x + d
+--R     + 
+--R       -
+--R             +---------------------------------------------+
+--R             |                  +---------------------+
+--R             |      2     2   2 |           1
+--R             |(16a c  - 4b c)e  |- -------------------  + b
+--R             |                  |        3      2 2  4
+--R             |                 \|  (64a c  - 16b c )e
+--R             |---------------------------------------------
+--R             |                    2     2   2
+--R            \|               (8a c  - 2b c)e
+--R         *
+--R            log
+--R                                       +---------------------+
+--R                           2     2   3 |           1
+--R                   (- 16a c  + 4b c)e  |- -------------------
+--R                                       |        3      2 2  4
+--R                                      \|  (64a c  - 16b c )e
+--R                *
+--R                    +---------------------------------------------+
+--R                    |                  +---------------------+
+--R                    |      2     2   2 |           1
+--R                    |(16a c  - 4b c)e  |- -------------------  + b
+--R                    |                  |        3      2 2  4
+--R                    |                 \|  (64a c  - 16b c )e
+--R                    |---------------------------------------------
+--R                    |                    2     2   2
+--R                   \|               (8a c  - 2b c)e
+--R               + 
+--R                 e x + d
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 764
+
+--S 765 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +---------------------------------------------+
+--R                                 |                  +---------------------+
+--R                                 |      2     2   2 |           1
+--R                                 |(16a c  - 4b c)e  |- -------------------  + b
+--R               +-----------+     |                  |        3      2 2  4
+--R           +-+ |          2  +-+ |                 \|  (64a c  - 16b c )e
+--R         e\|2 \|- 4a c + b  \|c  |---------------------------------------------
+--R                                 |                    2     2   2
+--R                                \|               (8a c  - 2b c)e
+--R      *
+--R         log
+--R                                  +---------------------+
+--R                      2     2   3 |           1
+--R                (16a c  - 4b c)e  |- -------------------
+--R                                  |        3      2 2  4
+--R                                 \|  (64a c  - 16b c )e
+--R             *
+--R                 +---------------------------------------------+
+--R                 |                  +---------------------+
+--R                 |      2     2   2 |           1
+--R                 |(16a c  - 4b c)e  |- -------------------  + b
+--R                 |                  |        3      2 2  4
+--R                 |                 \|  (64a c  - 16b c )e
+--R                 |---------------------------------------------
+--R                 |                    2     2   2
+--R                \|               (8a c  - 2b c)e
+--R            + 
+--R              e x + d
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            e\|2 \|- 4a c + b  \|c
+--R         *
+--R             +-----------------------------------------------+
+--R             |                    +---------------------+
+--R             |        2     2   2 |           1
+--R             |(- 16a c  + 4b c)e  |- -------------------  + b
+--R             |                    |        3      2 2  4
+--R             |                   \|  (64a c  - 16b c )e
+--R             |-----------------------------------------------
+--R             |                     2     2   2
+--R            \|                (8a c  - 2b c)e
+--R         *
+--R            log
+--R                                     +---------------------+
+--R                         2     2   3 |           1
+--R                   (16a c  - 4b c)e  |- -------------------
+--R                                     |        3      2 2  4
+--R                                    \|  (64a c  - 16b c )e
+--R                *
+--R                    +-----------------------------------------------+
+--R                    |                    +---------------------+
+--R                    |        2     2   2 |           1
+--R                    |(- 16a c  + 4b c)e  |- -------------------  + b
+--R                    |                    |        3      2 2  4
+--R                    |                   \|  (64a c  - 16b c )e
+--R                    |-----------------------------------------------
+--R                    |                     2     2   2
+--R                   \|                (8a c  - 2b c)e
+--R               + 
+--R                 e x + d
+--R     + 
+--R               +-----------+
+--R           +-+ |          2  +-+
+--R         e\|2 \|- 4a c + b  \|c
+--R      *
+--R          +-----------------------------------------------+
+--R          |                    +---------------------+
+--R          |        2     2   2 |           1
+--R          |(- 16a c  + 4b c)e  |- -------------------  + b
+--R          |                    |        3      2 2  4
+--R          |                   \|  (64a c  - 16b c )e
+--R          |-----------------------------------------------
+--R          |                     2     2   2
+--R         \|                (8a c  - 2b c)e
+--R      *
+--R         log
+--R                                    +---------------------+
+--R                        2     2   3 |           1
+--R                (- 16a c  + 4b c)e  |- -------------------
+--R                                    |        3      2 2  4
+--R                                   \|  (64a c  - 16b c )e
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |                    +---------------------+
+--R                 |        2     2   2 |           1
+--R                 |(- 16a c  + 4b c)e  |- -------------------  + b
+--R                 |                    |        3      2 2  4
+--R                 |                   \|  (64a c  - 16b c )e
+--R                 |-----------------------------------------------
+--R                 |                     2     2   2
+--R                \|                (8a c  - 2b c)e
+--R            + 
+--R              e x + d
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            e\|2 \|- 4a c + b  \|c
+--R         *
+--R             +---------------------------------------------+
+--R             |                  +---------------------+
+--R             |      2     2   2 |           1
+--R             |(16a c  - 4b c)e  |- -------------------  + b
+--R             |                  |        3      2 2  4
+--R             |                 \|  (64a c  - 16b c )e
+--R             |---------------------------------------------
+--R             |                    2     2   2
+--R            \|               (8a c  - 2b c)e
+--R         *
+--R            log
+--R                                       +---------------------+
+--R                           2     2   3 |           1
+--R                   (- 16a c  + 4b c)e  |- -------------------
+--R                                       |        3      2 2  4
+--R                                      \|  (64a c  - 16b c )e
+--R                *
+--R                    +---------------------------------------------+
+--R                    |                  +---------------------+
+--R                    |      2     2   2 |           1
+--R                    |(16a c  - 4b c)e  |- -------------------  + b
+--R                    |                  |        3      2 2  4
+--R                    |                 \|  (64a c  - 16b c )e
+--R                    |---------------------------------------------
+--R                    |                    2     2   2
+--R                   \|               (8a c  - 2b c)e
+--R               + 
+--R                 e x + d
+--R     + 
+--R         +--------------------+
+--R         |   +-----------+                       +-+ +-+
+--R         |   |          2              (e x + d)\|2 \|c
+--R       2\|- \|- 4a c + b   + b atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                     |   |          2
+--R                                    \|- \|- 4a c + b   + b
+--R     + 
+--R           +------------------+
+--R           | +-----------+                      +-+ +-+
+--R           | |          2             (e x + d)\|2 \|c
+--R       - 2\|\|- 4a c + b   + b atan(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                     | |          2
+--R                                    \|\|- 4a c + b   + b
+--R  /
+--R            +-----------+
+--R        +-+ |          2  +-+
+--R     2e\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 765
+
+--S 766 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 766
+
+)clear all
+
+--S 767 of 1057
+t0:=(d+e*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                                     e x + d
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 767
+
+--S 768 of 1057
+r0:=-atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                    2 2                  2
+--R                2c e x  + 4c d e x + 2c d  + b
+--R          atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R   (2)  - -------------------------------------
+--R                       +-----------+
+--R                       |          2
+--R                     e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 768
+
+--S 769 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                    2 4 4     2   3 3       2 2         2 2
+--R                  2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                + 
+--R                     2 3                  2 4         2           2
+--R                  (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R             *
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R            + 
+--R                   2     2   2 2         2     2               2     2   2
+--R              (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R                 4 4         3 3        2      2 2        3                 4
+--R              c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R            + 
+--R                 2
+--R              b d  + a
+--R    /
+--R          +-----------+
+--R          |          2
+--R       2e\|- 4a c + b
+--R     ,
+--R                                          +---------+
+--R              2 2                  2      |        2
+--R         (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R    atan(--------------------------------------------)
+--R                                   2
+--R                           4a c - b
+--R    --------------------------------------------------]
+--R                         +---------+
+--R                         |        2
+--R                       e\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 769
+
+--S 770 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                    2 4 4     2   3 3       2 2         2 2
+--R                  2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                + 
+--R                     2 3                  2 4         2           2
+--R                  (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R             *
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R            + 
+--R                   2     2   2 2         2     2               2     2   2
+--R              (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R                 4 4         3 3        2      2 2        3                 4
+--R              c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R            + 
+--R                 2
+--R              b d  + a
+--R     + 
+--R                  2 2                  2
+--R              2c e x  + 4c d e x + 2c d  + b
+--R       2atanh(------------------------------)
+--R                       +-----------+
+--R                       |          2
+--R                      \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     2e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 770
+
+--S 771 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 771
+
+--S 772 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        +---------+          2 2                  2
+--R        |        2       2c e x  + 4c d e x + 2c d  + b
+--R       \|4a c - b  atanh(------------------------------)
+--R                                  +-----------+
+--R                                  |          2
+--R                                 \|- 4a c + b
+--R     + 
+--R                                                           +---------+
+--R        +-----------+          2 2                  2      |        2
+--R        |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       \|- 4a c + b  atan(--------------------------------------------)
+--R                                                    2
+--R                                            4a c - b
+--R  /
+--R       +-----------+ +---------+
+--R       |          2  |        2
+--R     e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 773
+
+)clear all
+
+--S 774 of 1057
+t0:=1/((d+e*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          5 5         4 4         2      3 3         3         2 2
+--R       c e x  + 5c d e x  + (10c d  + b)e x  + (10c d  + 3b d)e x
+--R     + 
+--R            4       2              5      3
+--R       (5c d  + 3b d  + a)e x + c d  + b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 774
+
+--S 775 of 1057
+r0:=log(d+e*x)/(a*e)-1/4*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a*e)+_
+   1/2*b*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(a*e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    2 2                  2
+--R                2c e x  + 4c d e x + 2c d  + b
+--R       2b atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R     + 
+--R           -
+--R              log
+--R                      4 4         3 3        2      2 2        3
+--R                   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                 + 
+--R                      4      2
+--R                   c d  + b d  + a
+--R         + 
+--R           4log(e x + d)
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     4a e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 775
+
+--S 776 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R             -
+--R                log
+--R                        4 4         3 3        2      2 2        3
+--R                     c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                   + 
+--R                        4      2
+--R                     c d  + b d  + a
+--R           + 
+--R             4log(e x + d)
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R            +-----------+
+--R            |          2
+--R       4a e\|- 4a c + b
+--R     ,
+--R
+--R                                                    +---------+
+--R                        2 2                  2      |        2
+--R                   (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         - 2b atan(--------------------------------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R             -
+--R                log
+--R                        4 4         3 3        2      2 2        3
+--R                     c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                   + 
+--R                        4      2
+--R                     c d  + b d  + a
+--R           + 
+--R             4log(e x + d)
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R            +---------+
+--R            |        2
+--R       4a e\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 776
+
+--S 777 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                      2 2                  2
+--R                  2c e x  + 4c d e x + 2c d  + b
+--R       - 2b atanh(------------------------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     4a e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 778
+
+--S 779 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+          2 2                  2
+--R           |        2       2c e x  + 4c d e x + 2c d  + b
+--R       - b\|4a c - b  atanh(------------------------------)
+--R                                     +-----------+
+--R                                     |          2
+--R                                    \|- 4a c + b
+--R     + 
+--R                                                              +---------+
+--R           +-----------+          2 2                  2      |        2
+--R           |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(--------------------------------------------)
+--R                                                       2
+--R                                               4a c - b
+--R  /
+--R          +-----------+ +---------+
+--R          |          2  |        2
+--R     2a e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 780
+
+)clear all
+
+--S 781 of 1057
+t0:=1/((d+e*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          6 6         5 5         2      4 4         3         3 3
+--R       c e x  + 6c d e x  + (15c d  + b)e x  + (20c d  + 4b d)e x
+--R     + 
+--R           4       2      2 2        5       3                 6      4      2
+--R     (15c d  + 6b d  + a)e x  + (6c d  + 4b d  + 2a d)e x + c d  + b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 781
+
+--S 782 of 1057
+r0:=(-1)/(a*e*(d+e*x))-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(1+b/sqrt(b^2-4*a*c))/(a*e*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(1-b/sqrt(b^2-4*a*c))/(a*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                       +------------------+
+--R                      +-----------+                    | +-----------+
+--R                      |          2                 +-+ | |          2
+--R         ((- e x - d)\|- 4a c + b   - b e x - b d)\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                       +--------------------+
+--R                      +-----------+                    |   +-----------+
+--R                      |          2                 +-+ |   |          2
+--R         ((- e x - d)\|- 4a c + b   + b e x + b d)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R       - \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R           2           +-+ |          2  |   |          2
+--R       (a e x + a d e)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2
+--R         (- a e x - a d e)
+--R      *
+--R          +------------------------------------------------------+
+--R          |                  +--------------------+
+--R          |                  |   2 2       2     4
+--R          |    4      3 2  2 |- a c  + 2a b c - b               3
+--R          |(16a c - 4a b )e  |--------------------  - 3a b c + b
+--R          |                  |     7       6 2  4
+--R          |                 \| (64a c - 16a b )e
+--R          |------------------------------------------------------
+--R          |                      4      3 2  2
+--R         \|                   (8a c - 2a b )e
+--R      *
+--R         log
+--R                                               +--------------------+
+--R                                               |   2 2       2     4
+--R                      5 2      4 2      3 4  3 |- a c  + 2a b c - b
+--R                  (32a c  - 24a b c + 4a b )e  |--------------------
+--R                                               |     7       6 2  4
+--R                                              \| (64a c - 16a b )e
+--R                + 
+--R                     2   2       3     5
+--R                  (4a b c  - 5a b c + b )e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                  +--------------------+
+--R                 |                  |   2 2       2     4
+--R                 |    4      3 2  2 |- a c  + 2a b c - b               3
+--R                 |(16a c - 4a b )e  |--------------------  - 3a b c + b
+--R                 |                  |     7       6 2  4
+--R                 |                 \| (64a c - 16a b )e
+--R                 |------------------------------------------------------
+--R                 |                      4      3 2  2
+--R                \|                   (8a c - 2a b )e
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R             2
+--R         (a e x + a d e)
+--R      *
+--R          +--------------------------------------------------------+
+--R          |                    +--------------------+
+--R          |                    |   2 2       2     4
+--R          |      4      3 2  2 |- a c  + 2a b c - b               3
+--R          |(- 16a c + 4a b )e  |--------------------  - 3a b c + b
+--R          |                    |     7       6 2  4
+--R          |                   \| (64a c - 16a b )e
+--R          |--------------------------------------------------------
+--R          |                       4      3 2  2
+--R         \|                    (8a c - 2a b )e
+--R      *
+--R         log
+--R                                               +--------------------+
+--R                                               |   2 2       2     4
+--R                      5 2      4 2      3 4  3 |- a c  + 2a b c - b
+--R                  (32a c  - 24a b c + 4a b )e  |--------------------
+--R                                               |     7       6 2  4
+--R                                              \| (64a c - 16a b )e
+--R                + 
+--R                       2   2       3     5
+--R                  (- 4a b c  + 5a b c - b )e
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |                    +--------------------+
+--R                 |                    |   2 2       2     4
+--R                 |      4      3 2  2 |- a c  + 2a b c - b               3
+--R                 |(- 16a c + 4a b )e  |--------------------  - 3a b c + b
+--R                 |                    |     7       6 2  4
+--R                 |                   \| (64a c - 16a b )e
+--R                 |--------------------------------------------------------
+--R                 |                       4      3 2  2
+--R                \|                    (8a c - 2a b )e
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R               2
+--R         (- a e x - a d e)
+--R      *
+--R          +--------------------------------------------------------+
+--R          |                    +--------------------+
+--R          |                    |   2 2       2     4
+--R          |      4      3 2  2 |- a c  + 2a b c - b               3
+--R          |(- 16a c + 4a b )e  |--------------------  - 3a b c + b
+--R          |                    |     7       6 2  4
+--R          |                   \| (64a c - 16a b )e
+--R          |--------------------------------------------------------
+--R          |                       4      3 2  2
+--R         \|                    (8a c - 2a b )e
+--R      *
+--R         log
+--R                                                 +--------------------+
+--R                                                 |   2 2       2     4
+--R                        5 2      4 2      3 4  3 |- a c  + 2a b c - b
+--R                  (- 32a c  + 24a b c - 4a b )e  |--------------------
+--R                                                 |     7       6 2  4
+--R                                                \| (64a c - 16a b )e
+--R                + 
+--R                     2   2       3     5
+--R                  (4a b c  - 5a b c + b )e
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |                    +--------------------+
+--R                 |                    |   2 2       2     4
+--R                 |      4      3 2  2 |- a c  + 2a b c - b               3
+--R                 |(- 16a c + 4a b )e  |--------------------  - 3a b c + b
+--R                 |                    |     7       6 2  4
+--R                 |                   \| (64a c - 16a b )e
+--R                 |--------------------------------------------------------
+--R                 |                       4      3 2  2
+--R                \|                    (8a c - 2a b )e
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R             2
+--R         (a e x + a d e)
+--R      *
+--R          +------------------------------------------------------+
+--R          |                  +--------------------+
+--R          |                  |   2 2       2     4
+--R          |    4      3 2  2 |- a c  + 2a b c - b               3
+--R          |(16a c - 4a b )e  |--------------------  - 3a b c + b
+--R          |                  |     7       6 2  4
+--R          |                 \| (64a c - 16a b )e
+--R          |------------------------------------------------------
+--R          |                      4      3 2  2
+--R         \|                   (8a c - 2a b )e
+--R      *
+--R         log
+--R                                                 +--------------------+
+--R                                                 |   2 2       2     4
+--R                        5 2      4 2      3 4  3 |- a c  + 2a b c - b
+--R                  (- 32a c  + 24a b c - 4a b )e  |--------------------
+--R                                                 |     7       6 2  4
+--R                                                \| (64a c - 16a b )e
+--R                + 
+--R                       2   2       3     5
+--R                  (- 4a b c  + 5a b c - b )e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                  +--------------------+
+--R                 |                  |   2 2       2     4
+--R                 |    4      3 2  2 |- a c  + 2a b c - b               3
+--R                 |(16a c - 4a b )e  |--------------------  - 3a b c + b
+--R                 |                  |     7       6 2  4
+--R                 |                 \| (64a c - 16a b )e
+--R                 |------------------------------------------------------
+--R                 |                      4      3 2  2
+--R                \|                   (8a c - 2a b )e
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R       - 2
+--R  /
+--R         2
+--R     2a e x + 2a d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 783
+
+--S 784 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R                +-+ |          2  |   |          2       | |          2
+--R            a e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +------------------------------------------------------+
+--R             |                  +--------------------+
+--R             |                  |   2 2       2     4
+--R             |    4      3 2  2 |- a c  + 2a b c - b               3
+--R             |(16a c - 4a b )e  |--------------------  - 3a b c + b
+--R             |                  |     7       6 2  4
+--R             |                 \| (64a c - 16a b )e
+--R             |------------------------------------------------------
+--R             |                      4      3 2  2
+--R            \|                   (8a c - 2a b )e
+--R         *
+--R            log
+--R                                                  +--------------------+
+--R                                                  |   2 2       2     4
+--R                         5 2      4 2      3 4  3 |- a c  + 2a b c - b
+--R                     (32a c  - 24a b c + 4a b )e  |--------------------
+--R                                                  |     7       6 2  4
+--R                                                 \| (64a c - 16a b )e
+--R                   + 
+--R                        2   2       3     5
+--R                     (4a b c  - 5a b c + b )e
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                  +--------------------+
+--R                    |                  |   2 2       2     4
+--R                    |    4      3 2  2 |- a c  + 2a b c - b               3
+--R                    |(16a c - 4a b )e  |--------------------  - 3a b c + b
+--R                    |                  |     7       6 2  4
+--R                    |                 \| (64a c - 16a b )e
+--R                    |------------------------------------------------------
+--R                    |                      4      3 2  2
+--R                   \|                   (8a c - 2a b )e
+--R               + 
+--R                      3     2 2            3     2 2
+--R                 (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R                 +-----------+
+--R             +-+ |          2
+--R         a e\|2 \|- 4a c + b
+--R      *
+--R          +--------------------------------------------------------+
+--R          |                    +--------------------+
+--R          |                    |   2 2       2     4
+--R          |      4      3 2  2 |- a c  + 2a b c - b               3
+--R          |(- 16a c + 4a b )e  |--------------------  - 3a b c + b
+--R          |                    |     7       6 2  4
+--R          |                   \| (64a c - 16a b )e
+--R          |--------------------------------------------------------
+--R          |                       4      3 2  2
+--R         \|                    (8a c - 2a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                               +--------------------+
+--R                                               |   2 2       2     4
+--R                      5 2      4 2      3 4  3 |- a c  + 2a b c - b
+--R                  (32a c  - 24a b c + 4a b )e  |--------------------
+--R                                               |     7       6 2  4
+--R                                              \| (64a c - 16a b )e
+--R                + 
+--R                       2   2       3     5
+--R                  (- 4a b c  + 5a b c - b )e
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |                    +--------------------+
+--R                 |                    |   2 2       2     4
+--R                 |      4      3 2  2 |- a c  + 2a b c - b               3
+--R                 |(- 16a c + 4a b )e  |--------------------  - 3a b c + b
+--R                 |                    |     7       6 2  4
+--R                 |                   \| (64a c - 16a b )e
+--R                 |--------------------------------------------------------
+--R                 |                       4      3 2  2
+--R                \|                    (8a c - 2a b )e
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R       -
+--R                    +-----------+
+--R                +-+ |          2
+--R            a e\|2 \|- 4a c + b
+--R         *
+--R             +--------------------------------------------------------+
+--R             |                    +--------------------+
+--R             |                    |   2 2       2     4
+--R             |      4      3 2  2 |- a c  + 2a b c - b               3
+--R             |(- 16a c + 4a b )e  |--------------------  - 3a b c + b
+--R             |                    |     7       6 2  4
+--R             |                   \| (64a c - 16a b )e
+--R             |--------------------------------------------------------
+--R             |                       4      3 2  2
+--R            \|                    (8a c - 2a b )e
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                                    +--------------------+
+--R                                                    |   2 2       2     4
+--R                           5 2      4 2      3 4  3 |- a c  + 2a b c - b
+--R                     (- 32a c  + 24a b c - 4a b )e  |--------------------
+--R                                                    |     7       6 2  4
+--R                                                   \| (64a c - 16a b )e
+--R                   + 
+--R                        2   2       3     5
+--R                     (4a b c  - 5a b c + b )e
+--R                *
+--R                    +--------------------------------------------------------+
+--R                    |                    +--------------------+
+--R                    |                    |   2 2       2     4
+--R                    |      4      3 2  2 |- a c  + 2a b c - b               3
+--R                    |(- 16a c + 4a b )e  |--------------------  - 3a b c + b
+--R                    |                    |     7       6 2  4
+--R                    |                   \| (64a c - 16a b )e
+--R                    |--------------------------------------------------------
+--R                    |                       4      3 2  2
+--R                   \|                    (8a c - 2a b )e
+--R               + 
+--R                      3     2 2            3     2 2
+--R                 (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R             +-+ |          2  |   |          2       | |          2
+--R         a e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +------------------------------------------------------+
+--R          |                  +--------------------+
+--R          |                  |   2 2       2     4
+--R          |    4      3 2  2 |- a c  + 2a b c - b               3
+--R          |(16a c - 4a b )e  |--------------------  - 3a b c + b
+--R          |                  |     7       6 2  4
+--R          |                 \| (64a c - 16a b )e
+--R          |------------------------------------------------------
+--R          |                      4      3 2  2
+--R         \|                   (8a c - 2a b )e
+--R      *
+--R         log
+--R                                                 +--------------------+
+--R                                                 |   2 2       2     4
+--R                        5 2      4 2      3 4  3 |- a c  + 2a b c - b
+--R                  (- 32a c  + 24a b c - 4a b )e  |--------------------
+--R                                                 |     7       6 2  4
+--R                                                \| (64a c - 16a b )e
+--R                + 
+--R                       2   2       3     5
+--R                  (- 4a b c  + 5a b c - b )e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                  +--------------------+
+--R                 |                  |   2 2       2     4
+--R                 |    4      3 2  2 |- a c  + 2a b c - b               3
+--R                 |(16a c - 4a b )e  |--------------------  - 3a b c + b
+--R                 |                  |     7       6 2  4
+--R                 |                 \| (64a c - 16a b )e
+--R                 |------------------------------------------------------
+--R                 |                      4      3 2  2
+--R                \|                   (8a c - 2a b )e
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R                                    +------------------+
+--R            +-----------+           | +-----------+
+--R            |          2        +-+ | |          2
+--R         (2\|- 4a c + b   + 2b)\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                    +--------------------+
+--R            +-----------+           |   +-----------+
+--R            |          2        +-+ |   |          2
+--R         (2\|- 4a c + b   - 2b)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R     2a e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 785
+
+)clear all
+
+--S 786 of 1057
+t0:=1/((d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          7 7         6 6         2      5 5         3         4 4
+--R       c e x  + 7c d e x  + (21c d  + b)e x  + (35c d  + 5b d)e x
+--R     + 
+--R             4        2      3 3         5        3         2 2
+--R       (35c d  + 10b d  + a)e x  + (21c d  + 10b d  + 3a d)e x
+--R     + 
+--R            6       4       2          7      5      3
+--R       (7c d  + 5b d  + 3a d )e x + c d  + b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 786
+
+--S 787 of 1057
+r0:=(-1/2)/(a*e*(d+e*x)^2)-b*log(d+e*x)/(a^2*e)+1/4*b*log(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)/(a^2*e)-1/2*(b^2-2*a*c)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-_
+   4*a*c))/(a^2*e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    2  2 2             2                   2  2
+--R         ((4a c - 2b )e x  + (8a c - 4b )d e x + (4a c - 2b )d )
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                 2 2                 2
+--R             (b e x  + 2b d e x + b d )
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                  2 2                  2
+--R           (- 4b e x  - 8b d e x - 4b d )log(e x + d) - 2a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                   +-----------+
+--R        2 3 2     2   2      2 2   |          2
+--R     (4a e x  + 8a d e x + 4a d e)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     2  2 2             2                  2  2
+--R           ((2a c - b )e x  + (4a c - 2b )d e x + (2a c - b )d )
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                   2 2                 2
+--R               (b e x  + 2b d e x + b d )
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                    2 2                  2
+--R             (- 4b e x  - 8b d e x - 4b d )log(e x + d) - 2a
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                     +-----------+
+--R          2 3 2     2   2      2 2   |          2
+--R       (4a e x  + 8a d e x + 4a d e)\|- 4a c + b
+--R     ,
+--R
+--R                        2  2 2               2                     2  2
+--R           ((- 4a c + 2b )e x  + (- 8a c + 4b )d e x + (- 4a c + 2b )d )
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                   2 2                 2
+--R               (b e x  + 2b d e x + b d )
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                    2 2                  2
+--R             (- 4b e x  - 8b d e x - 4b d )log(e x + d) - 2a
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                     +---------+
+--R          2 3 2     2   2      2 2   |        2
+--R       (4a e x  + 8a d e x + 4a d e)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 788
+
+--S 789 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                               2 2                  2
+--R                   2       2c e x  + 4c d e x + 2c d  + b
+--R       (- 4a c + 2b )atanh(------------------------------)
+--R                                    +-----------+
+--R                                    |          2
+--R                                   \|- 4a c + b
+--R  /
+--R          +-----------+
+--R       2  |          2
+--R     4a e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 790
+
+--S 791 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+          2 2                  2
+--R                  2  |        2       2c e x  + 4c d e x + 2c d  + b
+--R       (- 2a c + b )\|4a c - b  atanh(------------------------------)
+--R                                               +-----------+
+--R                                               |          2
+--R                                              \|- 4a c + b
+--R     + 
+--R                       +-----------+
+--R                    2  |          2
+--R         (- 2a c + b )\|- 4a c + b
+--R      *
+--R                                               +---------+
+--R                   2 2                  2      |        2
+--R              (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R  /
+--R          +-----------+ +---------+
+--R       2  |          2  |        2
+--R     2a e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 792
+
+)clear all
+
+--S 793 of 1057
+t0:=1/((d+e*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          8 8         7 7         2      6 6         3         5 5
+--R       c e x  + 8c d e x  + (28c d  + b)e x  + (56c d  + 6b d)e x
+--R     + 
+--R             4        2      4 4         5        3         3 3
+--R       (70c d  + 15b d  + a)e x  + (56c d  + 20b d  + 4a d)e x
+--R     + 
+--R             6        4       2  2 2        7       5       3          8      6
+--R       (28c d  + 15b d  + 6a d )e x  + (8c d  + 6b d  + 4a d )e x + c d  + b d
+--R     + 
+--R          4
+--R       a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 793
+
+--S 794 of 1057
+r0:=(-1/3)/(a*e*(d+e*x)^3)+b/(a^2*e*(d+e*x))+atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(a^2*_
+   e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(a^2*e*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                    +-----------+
+--R                3 3         2 2       2          3  |          2
+--R           (3b e x  + 9b d e x  + 9b d e x + 3b d )\|- 4a c + b
+--R         + 
+--R                       2  3 3                2    2 2                2  2
+--R           (- 6a c + 3b )e x  + (- 18a c + 9b )d e x  + (- 18a c + 9b )d e x
+--R         + 
+--R                       2  3
+--R           (- 6a c + 3b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                                    +-----------+
+--R                3 3         2 2       2          3  |          2
+--R           (3b e x  + 9b d e x  + 9b d e x + 3b d )\|- 4a c + b
+--R         + 
+--R                     2  3 3              2    2 2              2  2
+--R           (6a c - 3b )e x  + (18a c - 9b )d e x  + (18a c - 9b )d e x
+--R         + 
+--R                     2  3
+--R           (6a c - 3b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                              +-----------+
+--R              2 2                  2      +-+ |          2
+--R         (3b e x  + 6b d e x + 3b d  - a)\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                     +-----------+
+--R          2 4 3     2   3 2     2 2 2      2 3   +-+ |          2
+--R       (3a e x  + 9a d e x  + 9a d e x + 3a d e)\|2 \|- 4a c + b
+--R    *
+--R        +--------------------+ +------------------+
+--R        |   +-----------+      | +-----------+
+--R        |   |          2       | |          2
+--R       \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 4 3     2   3 2     2 2 2      2 3
+--R         (- 3a e x  - 9a d e x  - 9a d e x - 3a d e)
+--R      *
+--R         ROOT
+--R                                  +-----------------------------------------+
+--R                                  |   4 4     3 2 3      2 4 2       6     8
+--R                    6      5 2  2 |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (16a c - 4a b )e  |-----------------------------------------
+--R                                  |               11       10 2  4
+--R                                 \|           (64a  c - 16a  b )e
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2
+--R              (8a c - 2a b )e
+--R      *
+--R         log
+--R                        7   2      6 3      5 5  3
+--R                    (48a b c  - 28a b c + 4a b )e
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |               11       10 2  4
+--R                    \|           (64a  c - 16a  b )e
+--R                + 
+--R                     4 4      3 2 3      2 4 2       6     8
+--R                  (4a c  - 17a b c  + 20a b c  - 8a b c + b )e
+--R             *
+--R                ROOT
+--R                             6      5 2  2
+--R                         (16a c - 4a b )e
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |               11       10 2  4
+--R                         \|           (64a  c - 16a  b )e
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2
+--R                     (8a c - 2a b )e
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R            2 4 3     2   3 2     2 2 2      2 3
+--R         (3a e x  + 9a d e x  + 9a d e x + 3a d e)
+--R      *
+--R         ROOT
+--R                                    +-----------------------------------------+
+--R                                    |   4 4     3 2 3      2 4 2       6     8
+--R                      6      5 2  2 |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (- 16a c + 4a b )e  |-----------------------------------------
+--R                                    |               11       10 2  4
+--R                                   \|           (64a  c - 16a  b )e
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2
+--R              (8a c - 2a b )e
+--R      *
+--R         log
+--R                        7   2      6 3      5 5  3
+--R                    (48a b c  - 28a b c + 4a b )e
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |               11       10 2  4
+--R                    \|           (64a  c - 16a  b )e
+--R                + 
+--R                       4 4      3 2 3      2 4 2       6     8
+--R                  (- 4a c  + 17a b c  - 20a b c  + 8a b c - b )e
+--R             *
+--R                ROOT
+--R                               6      5 2  2
+--R                         (- 16a c + 4a b )e
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |               11       10 2  4
+--R                         \|           (64a  c - 16a  b )e
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2
+--R                     (8a c - 2a b )e
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R              2 4 3     2   3 2     2 2 2      2 3
+--R         (- 3a e x  - 9a d e x  - 9a d e x - 3a d e)
+--R      *
+--R         ROOT
+--R                                    +-----------------------------------------+
+--R                                    |   4 4     3 2 3      2 4 2       6     8
+--R                      6      5 2  2 |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (- 16a c + 4a b )e  |-----------------------------------------
+--R                                    |               11       10 2  4
+--R                                   \|           (64a  c - 16a  b )e
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2
+--R              (8a c - 2a b )e
+--R      *
+--R         log
+--R                          7   2      6 3      5 5  3
+--R                    (- 48a b c  + 28a b c - 4a b )e
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |               11       10 2  4
+--R                    \|           (64a  c - 16a  b )e
+--R                + 
+--R                     4 4      3 2 3      2 4 2       6     8
+--R                  (4a c  - 17a b c  + 20a b c  - 8a b c + b )e
+--R             *
+--R                ROOT
+--R                               6      5 2  2
+--R                         (- 16a c + 4a b )e
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |               11       10 2  4
+--R                         \|           (64a  c - 16a  b )e
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2
+--R                     (8a c - 2a b )e
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R            2 4 3     2   3 2     2 2 2      2 3
+--R         (3a e x  + 9a d e x  + 9a d e x + 3a d e)
+--R      *
+--R         ROOT
+--R                                  +-----------------------------------------+
+--R                                  |   4 4     3 2 3      2 4 2       6     8
+--R                    6      5 2  2 |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (16a c - 4a b )e  |-----------------------------------------
+--R                                  |               11       10 2  4
+--R                                 \|           (64a  c - 16a  b )e
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2
+--R              (8a c - 2a b )e
+--R      *
+--R         log
+--R                          7   2      6 3      5 5  3
+--R                    (- 48a b c  + 28a b c - 4a b )e
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |               11       10 2  4
+--R                    \|           (64a  c - 16a  b )e
+--R                + 
+--R                       4 4      3 2 3      2 4 2       6     8
+--R                  (- 4a c  + 17a b c  - 20a b c  + 8a b c - b )e
+--R             *
+--R                ROOT
+--R                             6      5 2  2
+--R                         (16a c - 4a b )e
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |               11       10 2  4
+--R                         \|           (64a  c - 16a  b )e
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2
+--R                     (8a c - 2a b )e
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R           2 2                   2
+--R       6b e x  + 12b d e x + 6b d  - 2a
+--R  /
+--R       2 4 3      2   3 2      2 2 2      2 3
+--R     6a e x  + 18a d e x  + 18a d e x + 6a d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 795
+
+--S 796 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R             2  +-+ |          2  |   |          2       | |          2
+--R            a e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                     +-----------------------------------------+
+--R                                     |   4 4     3 2 3      2 4 2       6     8
+--R                       6      5 2  2 |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   (16a c - 4a b )e  |-----------------------------------------
+--R                                     |               11       10 2  4
+--R                                    \|           (64a  c - 16a  b )e
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                    6      5 2  2
+--R                 (8a c - 2a b )e
+--R         *
+--R            log
+--R                           7   2      6 3      5 5  3
+--R                       (48a b c  - 28a b c + 4a b )e
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |               11       10 2  4
+--R                       \|           (64a  c - 16a  b )e
+--R                   + 
+--R                        4 4      3 2 3      2 4 2       6     8
+--R                     (4a c  - 17a b c  + 20a b c  - 8a b c + b )e
+--R                *
+--R                   ROOT
+--R                                6      5 2  2
+--R                            (16a c - 4a b )e
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |               11       10 2  4
+--R                            \|           (64a  c - 16a  b )e
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                           6      5 2  2
+--R                        (8a c - 2a b )e
+--R               + 
+--R                    2 5       2 4     4 3          2 5       2 4     4 3
+--R                 (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R                 +-----------+
+--R          2  +-+ |          2
+--R         a e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                                    +-----------------------------------------+
+--R                                    |   4 4     3 2 3      2 4 2       6     8
+--R                      6      5 2  2 |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (- 16a c + 4a b )e  |-----------------------------------------
+--R                                    |               11       10 2  4
+--R                                   \|           (64a  c - 16a  b )e
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2
+--R              (8a c - 2a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                        7   2      6 3      5 5  3
+--R                    (48a b c  - 28a b c + 4a b )e
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |               11       10 2  4
+--R                    \|           (64a  c - 16a  b )e
+--R                + 
+--R                       4 4      3 2 3      2 4 2       6     8
+--R                  (- 4a c  + 17a b c  - 20a b c  + 8a b c - b )e
+--R             *
+--R                ROOT
+--R                               6      5 2  2
+--R                         (- 16a c + 4a b )e
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |               11       10 2  4
+--R                         \|           (64a  c - 16a  b )e
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2
+--R                     (8a c - 2a b )e
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R       -
+--R                    +-----------+
+--R             2  +-+ |          2
+--R            a e\|2 \|- 4a c + b
+--R         *
+--R            ROOT
+--R                           6      5 2  2
+--R                     (- 16a c + 4a b )e
+--R                  *
+--R                      +-----------------------------------------+
+--R                      |   4 4     3 2 3      2 4 2       6     8
+--R                      |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                      |-----------------------------------------
+--R                      |               11       10 2  4
+--R                     \|           (64a  c - 16a  b )e
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                    6      5 2  2
+--R                 (8a c - 2a b )e
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                             7   2      6 3      5 5  3
+--R                       (- 48a b c  + 28a b c - 4a b )e
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |               11       10 2  4
+--R                       \|           (64a  c - 16a  b )e
+--R                   + 
+--R                        4 4      3 2 3      2 4 2       6     8
+--R                     (4a c  - 17a b c  + 20a b c  - 8a b c + b )e
+--R                *
+--R                   ROOT
+--R                                  6      5 2  2
+--R                            (- 16a c + 4a b )e
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |               11       10 2  4
+--R                            \|           (64a  c - 16a  b )e
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                           6      5 2  2
+--R                        (8a c - 2a b )e
+--R               + 
+--R                    2 5       2 4     4 3          2 5       2 4     4 3
+--R                 (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R          2  +-+ |          2  |   |          2       | |          2
+--R         a e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                  +-----------------------------------------+
+--R                                  |   4 4     3 2 3      2 4 2       6     8
+--R                    6      5 2  2 |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (16a c - 4a b )e  |-----------------------------------------
+--R                                  |               11       10 2  4
+--R                                 \|           (64a  c - 16a  b )e
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2
+--R              (8a c - 2a b )e
+--R      *
+--R         log
+--R                          7   2      6 3      5 5  3
+--R                    (- 48a b c  + 28a b c - 4a b )e
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |               11       10 2  4
+--R                    \|           (64a  c - 16a  b )e
+--R                + 
+--R                       4 4      3 2 3      2 4 2       6     8
+--R                  (- 4a c  + 17a b c  - 20a b c  + 8a b c - b )e
+--R             *
+--R                ROOT
+--R                             6      5 2  2
+--R                         (16a c - 4a b )e
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |               11       10 2  4
+--R                         \|           (64a  c - 16a  b )e
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2
+--R                     (8a c - 2a b )e
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R                                               +------------------+
+--R               +-----------+                   | +-----------+
+--R               |          2             2  +-+ | |          2
+--R         (- 2b\|- 4a c + b   + 4a c - 2b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                               +--------------------+
+--R               +-----------+                   |   +-----------+
+--R               |          2             2  +-+ |   |          2
+--R         (- 2b\|- 4a c + b   - 4a c + 2b )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R       2  +-+ |          2  |   |          2       | |          2
+--R     2a e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 797
+
+)clear all
+
+--S 798 of 1057
+t0:=(d+e*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      4 4       3 3     2 2 2     3       4
+--R     e x  + 4d e x  + 6d e x  + 4d e x + d
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 798
+
+--S 799 of 1057
+r0:=1/2*(d+e*x)*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+(-b^2-_
+   4*a*c)/sqrt(b^2-4*a*c))/((b^2-4*a*c)*e*sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-_
+   4*a*c)))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^2+_
+   4*a*c+b*sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e*sqrt(2)*sqrt(c)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2    2   4 4         2     2     3 3
+--R           (4a c  + b c)e x  + (16a c  + 4b c)d e x
+--R         + 
+--R                  2     2   2             3  2 2
+--R           ((24a c  + 6b c)d  + 4a b c + b )e x
+--R         + 
+--R                  2     2   3               3              2    2   4
+--R           ((16a c  + 4b c)d  + (8a b c + 2b )d)e x + (4a c  + b c)d
+--R         + 
+--R                      3  2     2       2
+--R           (4a b c + b )d  + 4a c + a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                       +-+ +-+
+--R          | |          2              (e x + d)\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2    2   4 4           2     2     3 3
+--R           (- 4a c  - b c)e x  + (- 16a c  - 4b c)d e x
+--R         + 
+--R                    2     2   2             3  2 2
+--R           ((- 24a c  - 6b c)d  - 4a b c - b )e x
+--R         + 
+--R                    2     2   3                 3                2    2   4
+--R           ((- 16a c  - 4b c)d  + (- 8a b c - 2b )d)e x + (- 4a c  - b c)d
+--R         + 
+--R                        3  2     2       2
+--R           (- 4a b c - b )d  - 4a c - a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R               3 3         2 2          2               3         +-+
+--R         (- b e x  - 3b d e x  + (- 3b d  - 2a)e x - b d  - 2a d)\|2
+--R      *
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R          |          2  +-+ |   |          2       | |          2
+--R         \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 799
+
+--S 800 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2    2   5 4         2     2     4 3
+--R           (4a c  - b c)e x  + (16a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2             3  3 2
+--R           ((24a c  - 6b c)d  + 4a b c - b )e x
+--R         + 
+--R                  2     2   3               3    2
+--R           ((16a c  - 4b c)d  + (8a b c - 2b )d)e x
+--R         + 
+--R                 2    2   4              3  2     2       2
+--R           ((4a c  - b c)d  + (4a b c - b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6   2
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           1
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7   3
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           1
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                      2 2        2      4
+--R                  (32a c  - 16a b c + 2b )e
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6   2
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           1
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2                 2
+--R              (4a c + 3b )e x + (4a c + 3b )d
+--R     + 
+--R                  2    2   5 4           2     2     4 3
+--R           (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2             3  3 2
+--R           ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R         + 
+--R                    2     2   3                 3    2
+--R           ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R         + 
+--R                   2    2   4                3  2     2       2
+--R           ((- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6   2
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           1
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7   3
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           1
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                        2 2        2      4
+--R                  (- 32a c  + 16a b c - 2b )e
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6   2
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           1
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2                 2
+--R              (4a c + 3b )e x + (4a c + 3b )d
+--R     + 
+--R                2    2   5 4         2     2     4 3
+--R           (4a c  - b c)e x  + (16a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2             3  3 2
+--R           ((24a c  - 6b c)d  + 4a b c - b )e x
+--R         + 
+--R                  2     2   3               3    2
+--R           ((16a c  - 4b c)d  + (8a b c - 2b )d)e x
+--R         + 
+--R                 2    2   4              3  2     2       2
+--R           ((4a c  - b c)d  + (4a b c - b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6   2
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           1
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7   3
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           1
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                      2 2        2      4
+--R                  (32a c  - 16a b c + 2b )e
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6   2
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           1
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2                 2
+--R              (4a c + 3b )e x + (4a c + 3b )d
+--R     + 
+--R                  2    2   5 4           2     2     4 3
+--R           (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2             3  3 2
+--R           ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R         + 
+--R                    2     2   3                 3    2
+--R           ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R         + 
+--R                   2    2   4                3  2     2       2
+--R           ((- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6   2
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           1
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7   3
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           1
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                        2 2        2      4
+--R                  (- 32a c  + 16a b c - 2b )e
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6   2
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           1
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2                 2
+--R              (4a c + 3b )e x + (4a c + 3b )d
+--R     + 
+--R            3 3         2 2          2               3
+--R       - b e x  - 3b d e x  + (- 3b d  - 2a)e x - b d  - 2a d
+--R  /
+--R            2     2   5 4         2     2     4 3
+--R       (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R     + 
+--R              2      2   2              3  3 2
+--R       ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R     + 
+--R              2     2   3                3    2
+--R       ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R     + 
+--R             2     2   4               3  2     2        2
+--R       ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R                                         Type: Union(Expression(Integer),...)
+--E 800
+
+--S 801 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +--------------------+
+--R                          +-----------+     |   +-----------+
+--R                  2   +-+ |          2  +-+ |   |          2
+--R         (4a c - b )e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6   2
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           1
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7   3
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           1
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                      2 2        2      4
+--R                  (32a c  - 16a b c + 2b )e
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6   2
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           1
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2                 2
+--R              (4a c + 3b )e x + (4a c + 3b )d
+--R     + 
+--R                            +-----------+
+--R                    2   +-+ |          2  +-+
+--R         (- 4a c + b )e\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6   2
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           1
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7   3
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           1
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                        2 2        2      4
+--R                  (- 32a c  + 16a b c - 2b )e
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6   2
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           1
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2                 2
+--R              (4a c + 3b )e x + (4a c + 3b )d
+--R     + 
+--R                          +-----------+
+--R                  2   +-+ |          2  +-+
+--R         (4a c - b )e\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6   2
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           1
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7   3
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           1
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                      2 2        2      4
+--R                  (32a c  - 16a b c + 2b )e
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6   2
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           1
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2                 2
+--R              (4a c + 3b )e x + (4a c + 3b )d
+--R     + 
+--R                                              +--------------------+
+--R                            +-----------+     |   +-----------+
+--R                    2   +-+ |          2  +-+ |   |          2
+--R         (- 4a c + b )e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6   2
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           1
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7   3
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           1
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                        2 2        2      4
+--R                  (- 32a c  + 16a b c - 2b )e
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6   2
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           1
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2                 2
+--R              (4a c + 3b )e x + (4a c + 3b )d
+--R     + 
+--R                                       +------------------+
+--R            +-----------+              | +-----------+
+--R            |          2            2  | |          2
+--R         (b\|- 4a c + b   - 4a c - b )\|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                       +--------------------+
+--R            +-----------+              |   +-----------+
+--R            |          2            2  |   |          2
+--R         (b\|- 4a c + b   + 4a c + b )\|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                           +--------------------+
+--R                         +-----------+     |   +-----------+
+--R                 2   +-+ |          2  +-+ |   |          2
+--R       (8a c - 2b )e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 801
+
+--S 802 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 802
+
+)clear all
+
+--S 803 of 1057
+t0:=(d+e*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      3 3       2 2     2       3
+--R     e x  + 3d e x  + 3d e x + d
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 803
+
+--S 804 of 1057
+r0:=1/2*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   b*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e)
+--R 
+--R
+--R   (2)
+--R                 4 4           3 3           2     2  2 2          3     2
+--R           2b c e x  + 8b c d e x  + (12b c d  + 2b )e x  + (8b c d  + 4b d)e x
+--R         + 
+--R                 4     2 2
+--R           2b c d  + 2b d  + 2a b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                         +-----------+
+--R             2 2                 2       |          2
+--R       (- b e x  - 2b d e x - b d  - 2a)\|- 4a c + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  4 4           3 3          2    2  2 2          3     2
+--R             b c e x  + 4b c d e x  + (6b c d  + b )e x  + (4b c d  + 2b d)e x
+--R           + 
+--R                  4    2 2
+--R             b c d  + b d  + a b
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                                           +-----------+
+--R               2 2                 2       |          2
+--R         (- b e x  - 2b d e x - b d  - 2a)\|- 4a c + b
+--R    /
+--R                2     2   5 4         2     2     4 3
+--R           (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R         + 
+--R                  2      2   2              3  3 2
+--R           ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R         + 
+--R                  2     2   3                3    2
+--R           ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R         + 
+--R                 2     2   4               3  2     2        2
+--R           ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                     4 4           3 3             2     2  2 2
+--R             - 2b c e x  - 8b c d e x  + (- 12b c d  - 2b )e x
+--R           + 
+--R                      3     2              4     2 2
+--R             (- 8b c d  - 4b d)e x - 2b c d  - 2b d  - 2a b
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                                           +---------+
+--R               2 2                 2       |        2
+--R         (- b e x  - 2b d e x - b d  - 2a)\|4a c - b
+--R    /
+--R                2     2   5 4         2     2     4 3
+--R           (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R         + 
+--R                  2      2   2              3  3 2
+--R           ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R         + 
+--R                  2     2   3                3    2
+--R           ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R         + 
+--R                 2     2   4               3  2     2        2
+--R           ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 805
+
+--S 806 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                      2 2                  2
+--R                  2c e x  + 4c d e x + 2c d  + b
+--R       - 2b atanh(------------------------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R                   +-----------+
+--R               2   |          2
+--R     (8a c - 2b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+          2 2                  2
+--R           |        2       2c e x  + 4c d e x + 2c d  + b
+--R       - b\|4a c - b  atanh(------------------------------)
+--R                                     +-----------+
+--R                                     |          2
+--R                                    \|- 4a c + b
+--R     + 
+--R                                                              +---------+
+--R           +-----------+          2 2                  2      |        2
+--R           |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(--------------------------------------------)
+--R                                                       2
+--R                                               4a c - b
+--R  /
+--R                  +-----------+ +---------+
+--R              2   |          2  |        2
+--R     (4a c - b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 808
+
+--S 809 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 809
+
+)clear all
+
+--S 810 of 1057
+t0:=(d+e*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      2 2             2
+--R     e x  + 2d e x + d
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 810
+
+--S 811 of 1057
+r0:=-1/2*(d+e*x)*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+_
+   e*x)^4))+atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (2*b-sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(2*b+sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                   4 4         3 3         2       2 2        3
+--R               2c e x  + 8c d e x  + (12c d  + 2b)e x  + (8c d  + 4b d)e x
+--R             + 
+--R                   4       2
+--R               2c d  + 2b d  + 2a
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   4 4            3 3             2     2  2 2
+--R           - 4b c e x  - 16b c d e x  + (- 24b c d  - 4b )e x
+--R         + 
+--R                     3     2              4     2 2
+--R           (- 16b c d  - 8b d)e x - 4b c d  - 4b d  - 4a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                   4 4         3 3         2       2 2        3
+--R               2c e x  + 8c d e x  + (12c d  + 2b)e x  + (8c d  + 4b d)e x
+--R             + 
+--R                   4       2
+--R               2c d  + 2b d  + 2a
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 4 4            3 3           2     2  2 2
+--R           4b c e x  + 16b c d e x  + (24b c d  + 4b )e x
+--R         + 
+--R                   3     2              4     2 2
+--R           (16b c d  + 8b d)e x + 4b c d  + 4b d  + 4a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                                                  +-----------+
+--R              3 3         2 2        2               3        +-+ |          2
+--R         (2c e x  + 6c d e x  + (6c d  + b)e x + 2c d  + b d)\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2    2   5 4         2     2     4 3
+--R           (4a c  - b c)e x  + (16a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2             3  3 2
+--R           ((24a c  - 6b c)d  + 4a b c - b )e x
+--R         + 
+--R                  2     2   3               3    2
+--R           ((16a c  - 4b c)d  + (8a b c - 2b )d)e x
+--R         + 
+--R                 2    2   4              3  2     2       2
+--R           ((4a c  - b c)d  + (4a b c - b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                          1
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8  3
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                          1
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                        2   2       3     5
+--R                  (- 16a b c  + 8a b c - b )e
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                          1
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2             2     2
+--R              (4a c  + 3b c)e x + (4a c  + 3b c)d
+--R     + 
+--R                  2    2   5 4           2     2     4 3
+--R           (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2             3  3 2
+--R           ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R         + 
+--R                    2     2   3                 3    2
+--R           ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R         + 
+--R                   2    2   4                3  2     2       2
+--R           ((- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                          1
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8  3
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                          1
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                      2   2       3     5
+--R                  (16a b c  - 8a b c + b )e
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                          1
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2             2     2
+--R              (4a c  + 3b c)e x + (4a c  + 3b c)d
+--R     + 
+--R                2    2   5 4         2     2     4 3
+--R           (4a c  - b c)e x  + (16a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2             3  3 2
+--R           ((24a c  - 6b c)d  + 4a b c - b )e x
+--R         + 
+--R                  2     2   3               3    2
+--R           ((16a c  - 4b c)d  + (8a b c - 2b )d)e x
+--R         + 
+--R                 2    2   4              3  2     2       2
+--R           ((4a c  - b c)d  + (4a b c - b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                          1
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8  3
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                          1
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                        2   2       3     5
+--R                  (- 16a b c  + 8a b c - b )e
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                          1
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2             2     2
+--R              (4a c  + 3b c)e x + (4a c  + 3b c)d
+--R     + 
+--R                  2    2   5 4           2     2     4 3
+--R           (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2             3  3 2
+--R           ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R         + 
+--R                    2     2   3                 3    2
+--R           ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R         + 
+--R                   2    2   4                3  2     2       2
+--R           ((- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                          1
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8  3
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                          1
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                      2   2       3     5
+--R                  (16a b c  - 8a b c + b )e
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                          1
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2             2     2
+--R              (4a c  + 3b c)e x + (4a c  + 3b c)d
+--R     + 
+--R           3 3         2 2        2               3
+--R       2c e x  + 6c d e x  + (6c d  + b)e x + 2c d  + b d
+--R  /
+--R            2     2   5 4         2     2     4 3
+--R       (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R     + 
+--R              2      2   2              3  3 2
+--R       ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R     + 
+--R              2     2   3                3    2
+--R       ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R     + 
+--R             2     2   4               3  2     2        2
+--R       ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R                                         Type: Union(Expression(Integer),...)
+--E 812
+
+--S 813 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R                  2   +-+ |          2  |   |          2
+--R         (4a c - b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                          1
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8  3
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                          1
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                        2   2       3     5
+--R                  (- 16a b c  + 8a b c - b )e
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                          1
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2             2     2
+--R              (4a c  + 3b c)e x + (4a c  + 3b c)d
+--R     + 
+--R                            +-----------+
+--R                    2   +-+ |          2
+--R         (- 4a c + b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                          1
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8  3
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                          1
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                      2   2       3     5
+--R                  (16a b c  - 8a b c + b )e
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                          1
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2             2     2
+--R              (4a c  + 3b c)e x + (4a c  + 3b c)d
+--R     + 
+--R                          +-----------+
+--R                  2   +-+ |          2
+--R         (4a c - b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                          1
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8  3
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                          1
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                        2   2       3     5
+--R                  (- 16a b c  + 8a b c - b )e
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                          1
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2             2     2
+--R              (4a c  + 3b c)e x + (4a c  + 3b c)d
+--R     + 
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R                    2   +-+ |          2  |   |          2
+--R         (- 4a c + b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                          1
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8  3
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                          1
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                      2   2       3     5
+--R                  (16a b c  - 8a b c + b )e
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                          1
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2             2     2
+--R              (4a c  + 3b c)e x + (4a c  + 3b c)d
+--R     + 
+--R                                      +------------------+
+--R              +-----------+           | +-----------+
+--R              |          2        +-+ | |          2
+--R         (- 2\|- 4a c + b   + 4b)\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                      +--------------------+
+--R              +-----------+           |   +-----------+
+--R              |          2        +-+ |   |          2
+--R         (- 2\|- 4a c + b   - 4b)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                     +--------------------+ +------------------+
+--R                       +-----------+ |   +-----------+      | +-----------+
+--R               2   +-+ |          2  |   |          2       | |          2
+--R     (8a c - 2b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 813
+
+--S 814 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 814
+
+)clear all
+
+--S 815 of 1057
+t0:=(d+e*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R     e x + d
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 815
+
+--S 816 of 1057
+r0:=1/2*(-b-2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   2*c*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e)
+--R 
+--R
+--R   (2)
+--R               2 4 4      2   3 3         2 2         2 2
+--R           - 4c e x  - 16c d e x  + (- 24c d  - 4b c)e x
+--R         + 
+--R                 2 3                  2 4         2
+--R           (- 16c d  - 8b c d)e x - 4c d  - 4b c d  - 4a c
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                        +-----------+
+--R            2 2                  2      |          2
+--R       (2c e x  + 4c d e x + 2c d  + b)\|- 4a c + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               2 4 4     2   3 3       2 2         2 2      2 3
+--R             2c e x  + 8c d e x  + (12c d  + 2b c)e x  + (8c d  + 4b c d)e x
+--R           + 
+--R               2 4         2
+--R             2c d  + 2b c d  + 2a c
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                       2     2   2 2         2     2               2     2   2
+--R                  (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                                          +-----------+
+--R              2 2                  2      |          2
+--R         (2c e x  + 4c d e x + 2c d  + b)\|- 4a c + b
+--R    /
+--R                2     2   5 4         2     2     4 3
+--R           (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R         + 
+--R                  2      2   2              3  3 2
+--R           ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R         + 
+--R                  2     2   3                3    2
+--R           ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R         + 
+--R                 2     2   4               3  2     2        2
+--R           ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R               2 4 4      2   3 3       2 2         2 2       2 3
+--R             4c e x  + 16c d e x  + (24c d  + 4b c)e x  + (16c d  + 8b c d)e x
+--R           + 
+--R               2 4         2
+--R             4c d  + 4b c d  + 4a c
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                                          +---------+
+--R              2 2                  2      |        2
+--R         (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R    /
+--R                2     2   5 4         2     2     4 3
+--R           (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R         + 
+--R                  2      2   2              3  3 2
+--R           ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R         + 
+--R                  2     2   3                3    2
+--R           ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R         + 
+--R                 2     2   4               3  2     2        2
+--R           ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 817
+
+--S 818 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         c
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                     2     2   2 2         2     2               2     2   2
+--R                (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                    2 2                  2
+--R                2c e x  + 4c d e x + 2c d  + b
+--R       2c atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R  /
+--R                  +-----------+
+--R              2   |          2
+--R     (4a c - b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 818
+
+--S 819 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +---------+          2 2                  2
+--R          |        2       2c e x  + 4c d e x + 2c d  + b
+--R       2c\|4a c - b  atanh(------------------------------)
+--R                                    +-----------+
+--R                                    |          2
+--R                                   \|- 4a c + b
+--R     + 
+--R                                                             +---------+
+--R          +-----------+          2 2                  2      |        2
+--R          |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       2c\|- 4a c + b  atan(--------------------------------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R                  +-----------+ +---------+
+--R              2   |          2  |        2
+--R     (4a c - b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 820
+
+--S 821 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 821
+
+)clear all
+
+--S 822 of 1057
+t0:=1/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 822
+
+--S 823 of 1057
+r0:=1/2*(d+e*x)*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(b+(b^2-12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*e*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(b+(-b^2+12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-_
+   4*a*c)*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2    2   4 4         2     2     3 3
+--R           (12a c  - b c)e x  + (48a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2              3  2 2
+--R           ((72a c  - 6b c)d  + 12a b c - b )e x
+--R         + 
+--R                  2     2   3                3               2    2   4
+--R           ((48a c  - 4b c)d  + (24a b c - 2b )d)e x + (12a c  - b c)d
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c - b )d  + 12a c - a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2    2   4 4           2     2     3 3
+--R           (- 12a c  + b c)e x  + (- 48a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2              3  2 2
+--R           ((- 72a c  + 6b c)d  - 12a b c + b )e x
+--R         + 
+--R                    2     2   3                  3                 2    2   4
+--R           ((- 48a c  + 4b c)d  + (- 24a b c + 2b )d)e x + (- 12a c  + b c)d
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c + b )d  - 12a c + a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  3 3           2 2            2           2            3
+--R           - b c e x  - 3b c d e x  + (- 3b c d  + 2a c - b )e x - b c d
+--R         + 
+--R                    2
+--R           (2a c - b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            2 2       2   5 4       2 2       2     4 3
+--R         (8a c  - 2a b c)e x  + (32a c  - 8a b c)d e x
+--R       + 
+--R              2 2        2   2     2          3  3 2
+--R         ((48a c  - 12a b c)d  + 8a b c - 2a b )e x
+--R       + 
+--R              2 2       2   3       2          3    2
+--R         ((32a c  - 8a b c)d  + (16a b c - 4a b )d)e x
+--R       + 
+--R             2 2       2   4      2          3  2     3      2 2
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + 8a c - 2a b )e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 823
+
+--S 824 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 2      2   5 4       2 2       2     4 3
+--R           (4a c  - a b c)e x  + (16a c  - 4a b c)d e x
+--R         + 
+--R                2 2       2   2     2         3  3 2
+--R           ((24a c  - 6a b c)d  + 4a b c - a b )e x
+--R         + 
+--R                2 2       2   3      2          3    2
+--R           ((16a c  - 4a b c)d  + (8a b c - 2a b )d)e x
+--R         + 
+--R               2 2      2   4      2         3  2     3     2 2
+--R           ((4a c  - a b c)d  + (4a b c - a b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9  3
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )e
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |                  2 2        2     4
+--R                     |             - 81a c  + 18a b c - b
+--R                     |-------------------------------------------------
+--R                     |       9 3         8 2 2        7 4        6 6  4
+--R                    \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                       4 4       3 2 3       2 4 2        6     8
+--R                  (864a c  - 672a b c  + 190a b c  - 23a b c + b )e
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                2 2      2   5 4         2 2       2     4 3
+--R           (- 4a c  + a b c)e x  + (- 16a c  + 4a b c)d e x
+--R         + 
+--R                  2 2       2   2     2         3  3 2
+--R           ((- 24a c  + 6a b c)d  - 4a b c + a b )e x
+--R         + 
+--R                  2 2       2   3        2          3    2
+--R           ((- 16a c  + 4a b c)d  + (- 8a b c + 2a b )d)e x
+--R         + 
+--R                 2 2      2   4        2         3  2     3     2 2
+--R           ((- 4a c  + a b c)d  + (- 4a b c + a b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9  3
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )e
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |                  2 2        2     4
+--R                     |             - 81a c  + 18a b c - b
+--R                     |-------------------------------------------------
+--R                     |       9 3         8 2 2        7 4        6 6  4
+--R                    \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                         4 4       3 2 3       2 4 2        6     8
+--R                  (- 864a c  + 672a b c  - 190a b c  + 23a b c - b )e
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R              2 2      2   5 4       2 2       2     4 3
+--R           (4a c  - a b c)e x  + (16a c  - 4a b c)d e x
+--R         + 
+--R                2 2       2   2     2         3  3 2
+--R           ((24a c  - 6a b c)d  + 4a b c - a b )e x
+--R         + 
+--R                2 2       2   3      2          3    2
+--R           ((16a c  - 4a b c)d  + (8a b c - 2a b )d)e x
+--R         + 
+--R               2 2      2   4      2         3  2     3     2 2
+--R           ((4a c  - a b c)d  + (4a b c - a b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                       +-------------------------------------------------+
+--R                       |                  2 2        2     4
+--R                     3 |             - 81a c  + 18a b c - b
+--R                    e  |-------------------------------------------------
+--R                       |       9 3         8 2 2        7 4        6 6  4
+--R                      \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                       4 4       3 2 3       2 4 2        6     8
+--R                  (864a c  - 672a b c  + 190a b c  - 23a b c + b )e
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                2 2      2   5 4         2 2       2     4 3
+--R           (- 4a c  + a b c)e x  + (- 16a c  + 4a b c)d e x
+--R         + 
+--R                  2 2       2   2     2         3  3 2
+--R           ((- 24a c  + 6a b c)d  - 4a b c + a b )e x
+--R         + 
+--R                  2 2       2   3        2          3    2
+--R           ((- 16a c  + 4a b c)d  + (- 8a b c + 2a b )d)e x
+--R         + 
+--R                 2 2      2   4        2         3  2     3     2 2
+--R           ((- 4a c  + a b c)d  + (- 4a b c + a b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                       +-------------------------------------------------+
+--R                       |                  2 2        2     4
+--R                     3 |             - 81a c  + 18a b c - b
+--R                    e  |-------------------------------------------------
+--R                       |       9 3         8 2 2        7 4        6 6  4
+--R                      \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                         4 4       3 2 3       2 4 2        6     8
+--R                  (- 864a c  + 672a b c  - 190a b c  + 23a b c - b )e
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R              3 3           2 2            2           2            3
+--R       - b c e x  - 3b c d e x  + (- 3b c d  + 2a c - b )e x - b c d
+--R     + 
+--R                2
+--R       (2a c - b )d
+--R  /
+--R          2 2       2   5 4       2 2       2     4 3
+--R       (8a c  - 2a b c)e x  + (32a c  - 8a b c)d e x
+--R     + 
+--R            2 2        2   2     2          3  3 2
+--R       ((48a c  - 12a b c)d  + 8a b c - 2a b )e x
+--R     + 
+--R            2 2       2   3       2          3    2
+--R       ((32a c  - 8a b c)d  + (16a b c - 4a b )d)e x
+--R     + 
+--R           2 2       2   4      2          3  2     3      2 2
+--R       ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + 8a c - 2a b )e
+--R                                         Type: Union(Expression(Integer),...)
+--E 824
+
+--S 825 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R            2       2   +-+ |          2  |   |          2
+--R         (4a c - a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9  3
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )e
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |                  2 2        2     4
+--R                     |             - 81a c  + 18a b c - b
+--R                     |-------------------------------------------------
+--R                     |       9 3         8 2 2        7 4        6 6  4
+--R                    \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                       4 4       3 2 3       2 4 2        6     8
+--R                  (864a c  - 672a b c  + 190a b c  - 23a b c + b )e
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                              +-----------+
+--R              2       2   +-+ |          2
+--R         (- 4a c + a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9  3
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )e
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |                  2 2        2     4
+--R                     |             - 81a c  + 18a b c - b
+--R                     |-------------------------------------------------
+--R                     |       9 3         8 2 2        7 4        6 6  4
+--R                    \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                         4 4       3 2 3       2 4 2        6     8
+--R                  (- 864a c  + 672a b c  - 190a b c  + 23a b c - b )e
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                            +-----------+
+--R            2       2   +-+ |          2
+--R         (4a c - a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                       +-------------------------------------------------+
+--R                       |                  2 2        2     4
+--R                     3 |             - 81a c  + 18a b c - b
+--R                    e  |-------------------------------------------------
+--R                       |       9 3         8 2 2        7 4        6 6  4
+--R                      \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                       4 4       3 2 3       2 4 2        6     8
+--R                  (864a c  - 672a b c  + 190a b c  - 23a b c + b )e
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                                            +--------------------+
+--R                              +-----------+ |   +-----------+
+--R              2       2   +-+ |          2  |   |          2
+--R         (- 4a c + a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                       +-------------------------------------------------+
+--R                       |                  2 2        2     4
+--R                     3 |             - 81a c  + 18a b c - b
+--R                    e  |-------------------------------------------------
+--R                       |       9 3         8 2 2        7 4        6 6  4
+--R                      \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                         4 4       3 2 3       2 4 2        6     8
+--R                  (- 864a c  + 672a b c  - 190a b c  + 23a b c - b )e
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                                            +------------------+
+--R            +-----------+                   | +-----------+
+--R            |          2             2  +-+ | |          2
+--R         (b\|- 4a c + b   - 12a c + b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R            +-----------+                   |   +-----------+
+--R            |          2             2  +-+ |   |          2
+--R         (b\|- 4a c + b   + 12a c - b )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R          2        2   +-+ |          2  |   |          2
+--R       (8a c - 2a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 825
+
+--S 826 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 826
+
+)clear all
+
+--S 827 of 1057
+t0:=1/((d+e*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 9 9     2   8 8       2 2         7 7       2 3            6 6
+--R       c e x  + 9c d e x  + (36c d  + 2b c)e x  + (84c d  + 14b c d)e x
+--R     + 
+--R            2 4          2           2  5 5
+--R       (126c d  + 42b c d  + 2a c + b )e x
+--R     + 
+--R            2 5          3              2    4 4
+--R       (126c d  + 70b c d  + (10a c + 5b )d)e x
+--R     + 
+--R           2 6          4               2  2         3 3
+--R       (84c d  + 70b c d  + (20a c + 10b )d  + 2a b)e x
+--R     + 
+--R           2 7          5               2  3           2 2
+--R       (36c d  + 42b c d  + (20a c + 10b )d  + 6a b d)e x
+--R     + 
+--R          2 8          6              2  4         2    2        2 9         7
+--R       (9c d  + 14b c d  + (10a c + 5b )d  + 6a b d  + a )e x + c d  + 2b c d
+--R     + 
+--R                2  5         3    2
+--R       (2a c + b )d  + 2a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 827
+
+--S 828 of 1057
+r0:=1/2*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+1/2*b*(b^2-6*a*c)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-_
+   4*a*c))/(a^2*(b^2-4*a*c)^(3/2)*e)+log(d+e*x)/(a^2*e)-1/4*log(a+b*_
+   (d+e*x)^2+c*(d+e*x)^4)/(a^2*e)
+--R 
+--R
+--R   (2)
+--R                   2     3   4 4           2     3     3 3
+--R           (12a b c  - 2b c)e x  + (48a b c  - 8b c)d e x
+--R         + 
+--R                    2      3   2        2      4  2 2
+--R           ((72a b c  - 12b c)d  + 12a b c - 2b )e x
+--R         + 
+--R                    2     3   3         2      4                 2     3   4
+--R           ((48a b c  - 8b c)d  + (24a b c - 4b )d)e x + (12a b c  - 2b c)d
+--R         + 
+--R                 2      4  2      2          3
+--R           (12a b c - 2b )d  + 12a b c - 2a b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                      2    2   4 4           2     2     3 3
+--R               (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R             + 
+--R                        2     2   2             3  2 2
+--R               ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R             + 
+--R                        2     2   3                 3                2    2   4
+--R               ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x + (- 4a c  + b c)d
+--R             + 
+--R                            3  2     2       2
+--R               (- 4a b c + b )d  - 4a c + a b
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                     2     2   4 4         2      2     3 3
+--R               (16a c  - 4b c)e x  + (64a c  - 16b c)d e x
+--R             + 
+--R                      2      2   2               3  2 2
+--R               ((96a c  - 24b c)d  + 16a b c - 4b )e x
+--R             + 
+--R                      2      2   3                3               2     2   4
+--R               ((64a c  - 16b c)d  + (32a b c - 8b )d)e x + (16a c  - 4b c)d
+--R             + 
+--R                            3  2      2        2
+--R               (16a b c - 4b )d  + 16a c - 4a b
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                     2 2                          2     2        2
+--R           - 2a b c e x  - 4a b c d e x - 2a b c d  + 4a c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             3 2     2 2   5 4       3 2      2 2     4 3
+--R         (16a c  - 4a b c)e x  + (64a c  - 16a b c)d e x
+--R       + 
+--R              3 2      2 2   2      3        2 3  3 2
+--R         ((96a c  - 24a b c)d  + 16a b c - 4a b )e x
+--R       + 
+--R              3 2      2 2   3       3        2 3    2
+--R         ((64a c  - 16a b c)d  + (32a b c - 8a b )d)e x
+--R       + 
+--R              3 2     2 2   4       3        2 3  2      4      3 2
+--R         ((16a c  - 4a b c)d  + (16a b c - 4a b )d  + 16a c - 4a b )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 828
+
+--S 829 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2    3   4 4           2     3     3 3
+--R             (6a b c  - b c)e x  + (24a b c  - 4b c)d e x
+--R           + 
+--R                      2     3   2       2     4  2 2
+--R             ((36a b c  - 6b c)d  + 6a b c - b )e x
+--R           + 
+--R                      2     3   3         2      4                2    3   4
+--R             ((24a b c  - 4b c)d  + (12a b c - 2b )d)e x + (6a b c  - b c)d
+--R           + 
+--R                  2     4  2     2         3
+--R             (6a b c - b )d  + 6a b c - a b
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                        2    2   4 4           2     2     3 3
+--R                 (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R               + 
+--R                          2     2   2             3  2 2
+--R                 ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R               + 
+--R                          2     2   3                 3
+--R                 ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R               + 
+--R                        2    2   4                3  2     2       2
+--R                 (- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                       2     2   4 4         2      2     3 3
+--R                 (16a c  - 4b c)e x  + (64a c  - 16b c)d e x
+--R               + 
+--R                        2      2   2               3  2 2
+--R                 ((96a c  - 24b c)d  + 16a b c - 4b )e x
+--R               + 
+--R                        2      2   3                3               2     2   4
+--R                 ((64a c  - 16b c)d  + (32a b c - 8b )d)e x + (16a c  - 4b c)d
+--R               + 
+--R                              3  2      2        2
+--R                 (16a b c - 4b )d  + 16a c - 4a b
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                       2 2                          2     2        2
+--R             - 2a b c e x  - 4a b c d e x - 2a b c d  + 4a c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               3 2     2 2   5 4       3 2      2 2     4 3
+--R           (16a c  - 4a b c)e x  + (64a c  - 16a b c)d e x
+--R         + 
+--R                3 2      2 2   2      3        2 3  3 2
+--R           ((96a c  - 24a b c)d  + 16a b c - 4a b )e x
+--R         + 
+--R                3 2      2 2   3       3        2 3    2
+--R           ((64a c  - 16a b c)d  + (32a b c - 8a b )d)e x
+--R         + 
+--R                3 2     2 2   4       3        2 3  2      4      3 2
+--R           ((16a c  - 4a b c)d  + (16a b c - 4a b )d  + 16a c - 4a b )e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                       2     3   4 4             2     3     3 3
+--R             (- 12a b c  + 2b c)e x  + (- 48a b c  + 8b c)d e x
+--R           + 
+--R                        2      3   2        2      4  2 2
+--R             ((- 72a b c  + 12b c)d  - 12a b c + 2b )e x
+--R           + 
+--R                        2     3   3           2      4
+--R             ((- 48a b c  + 8b c)d  + (- 24a b c + 4b )d)e x
+--R           + 
+--R                       2     3   4           2      4  2      2          3
+--R             (- 12a b c  + 2b c)d  + (- 12a b c + 2b )d  - 12a b c + 2a b
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                        2    2   4 4           2     2     3 3
+--R                 (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R               + 
+--R                          2     2   2             3  2 2
+--R                 ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R               + 
+--R                          2     2   3                 3
+--R                 ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R               + 
+--R                        2    2   4                3  2     2       2
+--R                 (- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                       2     2   4 4         2      2     3 3
+--R                 (16a c  - 4b c)e x  + (64a c  - 16b c)d e x
+--R               + 
+--R                        2      2   2               3  2 2
+--R                 ((96a c  - 24b c)d  + 16a b c - 4b )e x
+--R               + 
+--R                        2      2   3                3               2     2   4
+--R                 ((64a c  - 16b c)d  + (32a b c - 8b )d)e x + (16a c  - 4b c)d
+--R               + 
+--R                              3  2      2        2
+--R                 (16a b c - 4b )d  + 16a c - 4a b
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                       2 2                          2     2        2
+--R             - 2a b c e x  - 4a b c d e x - 2a b c d  + 4a c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               3 2     2 2   5 4       3 2      2 2     4 3
+--R           (16a c  - 4a b c)e x  + (64a c  - 16a b c)d e x
+--R         + 
+--R                3 2      2 2   2      3        2 3  3 2
+--R           ((96a c  - 24a b c)d  + 16a b c - 4a b )e x
+--R         + 
+--R                3 2      2 2   3       3        2 3    2
+--R           ((64a c  - 16a b c)d  + (32a b c - 8a b )d)e x
+--R         + 
+--R                3 2     2 2   4       3        2 3  2      4      3 2
+--R           ((16a c  - 4a b c)d  + (16a b c - 4a b )d  + 16a c - 4a b )e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 829
+
+--S 830 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (6a b c - b )
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                                  2 2                  2
+--R                      3       2c e x  + 4c d e x + 2c d  + b
+--R       (- 12a b c + 2b )atanh(------------------------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R  /
+--R                      +-----------+
+--R         3      2 2   |          2
+--R     (16a c - 4a b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 830
+
+--S 831 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+          2 2                  2
+--R                    3  |        2       2c e x  + 4c d e x + 2c d  + b
+--R       (- 6a b c + b )\|4a c - b  atanh(------------------------------)
+--R                                                 +-----------+
+--R                                                 |          2
+--R                                                \|- 4a c + b
+--R     + 
+--R                         +-----------+
+--R                      3  |          2
+--R         (- 6a b c + b )\|- 4a c + b
+--R      *
+--R                                               +---------+
+--R                   2 2                  2      |        2
+--R              (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R  /
+--R                     +-----------+ +---------+
+--R        3      2 2   |          2  |        2
+--R     (8a c - 2a b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 833
+
+)clear all
+
+--S 834 of 1057
+t0:=1/((d+e*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 10 10      2   9 9       2 2         8 8        2 3            7 7
+--R       c e  x   + 10c d e x  + (45c d  + 2b c)e x  + (120c d  + 16b c d)e x
+--R     + 
+--R            2 4          2           2  6 6
+--R       (210c d  + 56b c d  + 2a c + b )e x
+--R     + 
+--R            2 5           3              2    5 5
+--R       (252c d  + 112b c d  + (12a c + 6b )d)e x
+--R     + 
+--R            2 6           4               2  2         4 4
+--R       (210c d  + 140b c d  + (30a c + 15b )d  + 2a b)e x
+--R     + 
+--R            2 7           5               2  3           3 3
+--R       (120c d  + 112b c d  + (40a c + 20b )d  + 8a b d)e x
+--R     + 
+--R           2 8          6               2  4          2    2  2 2
+--R       (45c d  + 56b c d  + (30a c + 15b )d  + 12a b d  + a )e x
+--R     + 
+--R           2 9          7              2  5         3     2         2 10
+--R       (10c d  + 16b c d  + (12a c + 6b )d  + 8a b d  + 2a d)e x + c d
+--R     + 
+--R             8            2  6         4    2 2
+--R       2b c d  + (2a c + b )d  + 2a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 834
+
+--S 835 of 1057
+r0:=1/2*(-3*b^2+10*a*c)/(a^2*(b^2-4*a*c)*e*(d+e*x))+1/2*(b^2-2*a*c+b*c*_
+   (d+e*x)^2)/(a*(b^2-4*a*c)*e*(d+e*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (3*b^2-10*a*c+b*(3*b^2-16*a*c)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*e*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2-10*a*c+(-3*b^3+16*a*b*c)/_
+   sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       2     2   5 5           2      2     4 4
+--R               (- 10a c  + 3b c)e x  + (- 50a c  + 15b c)d e x
+--R             + 
+--R                         2      2   2               3  3 3
+--R               ((- 100a c  + 30b c)d  - 10a b c + 3b )e x
+--R             + 
+--R                         2      2   3                  3    2 2
+--R               ((- 100a c  + 30b c)d  + (- 30a b c + 9b )d)e x
+--R             + 
+--R                        2      2   4                  3  2      2        2
+--R               ((- 50a c  + 15b c)d  + (- 30a b c + 9b )d  - 10a c + 3a b )e x
+--R             + 
+--R                       2     2   5                  3  3         2        2
+--R               (- 10a c  + 3b c)d  + (- 10a b c + 3b )d  + (- 10a c + 3a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   5 5             2      3     4 4
+--R           (- 16a b c  + 3b c)e x  + (- 80a b c  + 15b c)d e x
+--R         + 
+--R                       2      3   2        2      4  3 3
+--R           ((- 160a b c  + 30b c)d  - 16a b c + 3b )e x
+--R         + 
+--R                       2      3   3           2      4    2 2
+--R           ((- 160a b c  + 30b c)d  + (- 48a b c + 9b )d)e x
+--R         + 
+--R                      2      3   4           2      4  2      2          3
+--R           ((- 80a b c  + 15b c)d  + (- 48a b c + 9b )d  - 16a b c + 3a b )e x
+--R         + 
+--R                     2     3   5           2      4  3         2          3
+--R           (- 16a b c  + 3b c)d  + (- 16a b c + 3b )d  + (- 16a b c + 3a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                       2     2   5 5           2      2     4 4
+--R               (- 10a c  + 3b c)e x  + (- 50a c  + 15b c)d e x
+--R             + 
+--R                         2      2   2               3  3 3
+--R               ((- 100a c  + 30b c)d  - 10a b c + 3b )e x
+--R             + 
+--R                         2      2   3                  3    2 2
+--R               ((- 100a c  + 30b c)d  + (- 30a b c + 9b )d)e x
+--R             + 
+--R                        2      2   4                  3  2      2        2
+--R               ((- 50a c  + 15b c)d  + (- 30a b c + 9b )d  - 10a c + 3a b )e x
+--R             + 
+--R                       2     2   5                  3  3         2        2
+--R               (- 10a c  + 3b c)d  + (- 10a b c + 3b )d  + (- 10a c + 3a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   5 5           2      3     4 4
+--R           (16a b c  - 3b c)e x  + (80a b c  - 15b c)d e x
+--R         + 
+--R                     2      3   2        2      4  3 3
+--R           ((160a b c  - 30b c)d  + 16a b c - 3b )e x
+--R         + 
+--R                     2      3   3         2      4    2 2
+--R           ((160a b c  - 30b c)d  + (48a b c - 9b )d)e x
+--R         + 
+--R                    2      3   4         2      4  2      2          3
+--R           ((80a b c  - 15b c)d  + (48a b c - 9b )d  + 16a b c - 3a b )e x
+--R         + 
+--R                   2     3   5         2      4  3       2          3
+--R           (16a b c  - 3b c)d  + (16a b c - 3b )d  + (16a b c - 3a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2     2   4 4           2      2     3 3
+--R           (- 10a c  + 3b c)e x  + (- 40a c  + 12b c)d e x
+--R         + 
+--R                    2      2   2               3  2 2
+--R           ((- 60a c  + 18b c)d  - 11a b c + 3b )e x
+--R         + 
+--R                    2      2   3                  3                 2     2   4
+--R           ((- 40a c  + 12b c)d  + (- 22a b c + 6b )d)e x + (- 10a c  + 3b c)d
+--R         + 
+--R                          3  2     2        2
+--R           (- 11a b c + 3b )d  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            3 2     2 2   6 5       3 2      2 2     5 4
+--R         (8a c  - 2a b c)e x  + (40a c  - 10a b c)d e x
+--R       + 
+--R              3 2      2 2   2     3        2 3  4 3
+--R         ((80a c  - 20a b c)d  + 8a b c - 2a b )e x
+--R       + 
+--R              3 2      2 2   3       3        2 3    3 2
+--R         ((80a c  - 20a b c)d  + (24a b c - 6a b )d)e x
+--R       + 
+--R              3 2      2 2   4       3        2 3  2     4      3 2  2
+--R         ((40a c  - 10a b c)d  + (24a b c - 6a b )d  + 8a c - 2a b )e x
+--R       + 
+--R             3 2     2 2   5      3        2 3  3      4      3 2
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d)e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 835
+
+--S 836 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 2    2 2   6 5         3 2     2 2     5 4
+--R           (- 4a c  + a b c)e x  + (- 20a c  + 5a b c)d e x
+--R         + 
+--R                  3 2      2 2   2     3       2 3  4 3
+--R           ((- 40a c  + 10a b c)d  - 4a b c + a b )e x
+--R         + 
+--R                  3 2      2 2   3         3        2 3    3 2
+--R           ((- 40a c  + 10a b c)d  + (- 12a b c + 3a b )d)e x
+--R         + 
+--R                  3 2     2 2   4         3        2 3  2     4     3 2  2
+--R           ((- 20a c  + 5a b c)d  + (- 12a b c + 3a b )d  - 4a c + a b )e x
+--R         + 
+--R                 3 2    2 2   5        3       2 3  3        4     3 2
+--R           ((- 4a c  + a b c)d  + (- 4a b c + a b )d  + (- 4a c + a b )d)e
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                       +-----------------------------------------------------+
+--R                       |      4 4        3 2 3        2 4 2         6       8
+--R                     3 |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                    e  |-----------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                      5200a b c  - 14408a b c  + 10549a b c  - 3330a b c
+--R                    + 
+--R                            9       11
+--R                      486a b c - 27b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |       13 3         12 2 2        11 4        10 6  4
+--R                       \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R              3 2    2 2   6 5       3 2     2 2     5 4
+--R           (4a c  - a b c)e x  + (20a c  - 5a b c)d e x
+--R         + 
+--R                3 2      2 2   2     3       2 3  4 3
+--R           ((40a c  - 10a b c)d  + 4a b c - a b )e x
+--R         + 
+--R                3 2      2 2   3       3        2 3    3 2
+--R           ((40a c  - 10a b c)d  + (12a b c - 3a b )d)e x
+--R         + 
+--R                3 2     2 2   4       3        2 3  2     4     3 2  2
+--R           ((20a c  - 5a b c)d  + (12a b c - 3a b )d  + 4a c - a b )e x
+--R         + 
+--R               3 2    2 2   5      3       2 3  3      4     3 2
+--R           ((4a c  - a b c)d  + (4a b c - a b )d  + (4a c - a b )d)e
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                       +-----------------------------------------------------+
+--R                       |      4 4        3 2 3        2 4 2         6       8
+--R                     3 |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                    e  |-----------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                    + 
+--R                              9       11
+--R                      - 486a b c + 27b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |       13 3         12 2 2        11 4        10 6  4
+--R                       \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R                3 2    2 2   6 5         3 2     2 2     5 4
+--R           (- 4a c  + a b c)e x  + (- 20a c  + 5a b c)d e x
+--R         + 
+--R                  3 2      2 2   2     3       2 3  4 3
+--R           ((- 40a c  + 10a b c)d  - 4a b c + a b )e x
+--R         + 
+--R                  3 2      2 2   3         3        2 3    3 2
+--R           ((- 40a c  + 10a b c)d  + (- 12a b c + 3a b )d)e x
+--R         + 
+--R                  3 2     2 2   4         3        2 3  2     4     3 2  2
+--R           ((- 20a c  + 5a b c)d  + (- 12a b c + 3a b )d  - 4a c + a b )e x
+--R         + 
+--R                 3 2    2 2   5        3       2 3  3        4     3 2
+--R           ((- 4a c  + a b c)d  + (- 4a b c + a b )d  + (- 4a c + a b )d)e
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                       +-----------------------------------------------------+
+--R                       |      4 4        3 2 3        2 4 2         6       8
+--R                     3 |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                    e  |-----------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                      5200a b c  - 14408a b c  + 10549a b c  - 3330a b c
+--R                    + 
+--R                            9       11
+--R                      486a b c - 27b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |       13 3         12 2 2        11 4        10 6  4
+--R                       \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R              3 2    2 2   6 5       3 2     2 2     5 4
+--R           (4a c  - a b c)e x  + (20a c  - 5a b c)d e x
+--R         + 
+--R                3 2      2 2   2     3       2 3  4 3
+--R           ((40a c  - 10a b c)d  + 4a b c - a b )e x
+--R         + 
+--R                3 2      2 2   3       3        2 3    3 2
+--R           ((40a c  - 10a b c)d  + (12a b c - 3a b )d)e x
+--R         + 
+--R                3 2     2 2   4       3        2 3  2     4     3 2  2
+--R           ((20a c  - 5a b c)d  + (12a b c - 3a b )d  + 4a c - a b )e x
+--R         + 
+--R               3 2    2 2   5      3       2 3  3      4     3 2
+--R           ((4a c  - a b c)d  + (4a b c - a b )d  + (4a c - a b )d)e
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                       +-----------------------------------------------------+
+--R                       |      4 4        3 2 3        2 4 2         6       8
+--R                     3 |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                    e  |-----------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                    + 
+--R                              9       11
+--R                      - 486a b c + 27b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |       13 3         12 2 2        11 4        10 6  4
+--R                       \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R               2     2   4 4           2      2     3 3
+--R       (- 10a c  + 3b c)e x  + (- 40a c  + 12b c)d e x
+--R     + 
+--R                2      2   2               3  2 2
+--R       ((- 60a c  + 18b c)d  - 11a b c + 3b )e x
+--R     + 
+--R                2      2   3                  3                 2     2   4
+--R       ((- 40a c  + 12b c)d  + (- 22a b c + 6b )d)e x + (- 10a c  + 3b c)d
+--R     + 
+--R                      3  2     2        2
+--R       (- 11a b c + 3b )d  - 8a c + 2a b
+--R  /
+--R          3 2     2 2   6 5       3 2      2 2     5 4
+--R       (8a c  - 2a b c)e x  + (40a c  - 10a b c)d e x
+--R     + 
+--R            3 2      2 2   2     3        2 3  4 3
+--R       ((80a c  - 20a b c)d  + 8a b c - 2a b )e x
+--R     + 
+--R            3 2      2 2   3       3        2 3    3 2
+--R       ((80a c  - 20a b c)d  + (24a b c - 6a b )d)e x
+--R     + 
+--R            3 2      2 2   4       3        2 3  2     4      3 2  2
+--R       ((40a c  - 10a b c)d  + (24a b c - 6a b )d  + 8a c - 2a b )e x
+--R     + 
+--R           3 2     2 2   5      3        2 3  3      4      3 2
+--R       ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d)e
+--R                                         Type: Union(Expression(Integer),...)
+--E 836
+
+--S 837 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +--------------------+
+--R                              +-----------+ |   +-----------+
+--R              3     2 2   +-+ |          2  |   |          2
+--R         (- 4a c + a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                       +-----------------------------------------------------+
+--R                       |      4 4        3 2 3        2 4 2         6       8
+--R                     3 |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                    e  |-----------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                      5200a b c  - 14408a b c  + 10549a b c  - 3330a b c
+--R                    + 
+--R                            9       11
+--R                      486a b c - 27b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |       13 3         12 2 2        11 4        10 6  4
+--R                       \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R                            +-----------+
+--R            3     2 2   +-+ |          2
+--R         (4a c - a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                       +-----------------------------------------------------+
+--R                       |      4 4        3 2 3        2 4 2         6       8
+--R                     3 |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                    e  |-----------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                    + 
+--R                              9       11
+--R                      - 486a b c + 27b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |       13 3         12 2 2        11 4        10 6  4
+--R                       \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R                              +-----------+
+--R              3     2 2   +-+ |          2
+--R         (- 4a c + a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                       +-----------------------------------------------------+
+--R                       |      4 4        3 2 3        2 4 2         6       8
+--R                     3 |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                    e  |-----------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                      5200a b c  - 14408a b c  + 10549a b c  - 3330a b c
+--R                    + 
+--R                            9       11
+--R                      486a b c - 27b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |       13 3         12 2 2        11 4        10 6  4
+--R                       \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R            3     2 2   +-+ |          2  |   |          2
+--R         (4a c - a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                       +-----------------------------------------------------+
+--R                       |      4 4        3 2 3        2 4 2         6       8
+--R                     3 |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                    e  |-----------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                    + 
+--R                              9       11
+--R                      - 486a b c + 27b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |       13 3         12 2 2        11 4        10 6  4
+--R                       \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R                                                           +------------------+
+--R                        +-----------+                      | +-----------+
+--R                     2  |          2                3  +-+ | |          2
+--R         ((10a c - 3b )\|- 4a c + b   + 16a b c - 3b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                        +-----------+
+--R                     2  |          2                3  +-+
+--R         ((10a c - 3b )\|- 4a c + b   - 16a b c + 3b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R          3      2 2   +-+ |          2  |   |          2
+--R       (8a c - 2a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 838
+
+)clear all
+
+--S 839 of 1057
+t0:=1/((d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 11 11      2   10 10       2 2         9 9        2 3            8 8
+--R       c e  x   + 11c d e  x   + (55c d  + 2b c)e x  + (165c d  + 18b c d)e x
+--R     + 
+--R            2 4          2           2  7 7
+--R       (330c d  + 72b c d  + 2a c + b )e x
+--R     + 
+--R            2 5           3              2    6 6
+--R       (462c d  + 168b c d  + (14a c + 7b )d)e x
+--R     + 
+--R            2 6           4               2  2         5 5
+--R       (462c d  + 252b c d  + (42a c + 21b )d  + 2a b)e x
+--R     + 
+--R            2 7           5               2  3            4 4
+--R       (330c d  + 252b c d  + (70a c + 35b )d  + 10a b d)e x
+--R     + 
+--R            2 8           6               2  4          2    2  3 3
+--R       (165c d  + 168b c d  + (70a c + 35b )d  + 20a b d  + a )e x
+--R     + 
+--R           2 9          7               2  5          3     2   2 2
+--R       (55c d  + 72b c d  + (42a c + 21b )d  + 20a b d  + 3a d)e x
+--R     + 
+--R           2 10          8              2  6          4     2 2        2 11
+--R       (11c d   + 18b c d  + (14a c + 7b )d  + 10a b d  + 3a d )e x + c d
+--R     + 
+--R             9            2  7         5    2 3
+--R       2b c d  + (2a c + b )d  + 2a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 839
+
+--S 840 of 1057
+r0:=(-b^2+3*a*c)/(a^2*(b^2-4*a*c)*e*(d+e*x)^2)+1/2*(b^2-2*a*c+b*c*_
+   (d+e*x)^2)/(a*(b^2-4*a*c)*e*(d+e*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   (b^4-6*a*b^2*c+6*a^2*c^2)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/_
+   (a^3*(b^2-4*a*c)^(3/2)*e)-2*b*log(d+e*x)/(a^3*e)+1/2*b*log(a+b*_
+   (d+e*x)^2+c*(d+e*x)^4)/(a^3*e)
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   6 6       2 3        2 2      4     5 5
+--R           (12a c  - 12a b c  + 2b c)e x  + (72a c  - 72a b c  + 12b c)d e x
+--R         + 
+--R                 2 3         2 2      4   2      2   2        3      5  4 4
+--R           ((180a c  - 180a b c  + 30b c)d  + 12a b c  - 12a b c + 2b )e x
+--R         + 
+--R                 2 3         2 2      4   3       2   2        3      5    3 3
+--R           ((240a c  - 240a b c  + 40b c)d  + (48a b c  - 48a b c + 8b )d)e x
+--R         + 
+--R                    2 3         2 2      4   4       2   2        3       5  2
+--R               (180a c  - 180a b c  + 30b c)d  + (72a b c  - 72a b c + 12b )d
+--R             + 
+--R                  3 2      2 2        4
+--R               12a c  - 12a b c + 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                   2 3        2 2      4   5       2   2        3      5  3
+--R               (72a c  - 72a b c  + 12b c)d  + (48a b c  - 48a b c + 8b )d
+--R             + 
+--R                   3 2      2 2        4
+--R               (24a c  - 24a b c + 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2 3        2 2     4   6       2   2        3      5  4
+--R           (12a c  - 12a b c  + 2b c)d  + (12a b c  - 12a b c + 2b )d
+--R         + 
+--R               3 2      2 2        4  2
+--R           (12a c  - 12a b c + 2a b )d
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                      2    3   6 6           2     3     5 5
+--R               (4a b c  - b c)e x  + (24a b c  - 6b c)d e x
+--R             + 
+--R                        2      3   2       2     4  4 4
+--R               ((60a b c  - 15b c)d  + 4a b c - b )e x
+--R             + 
+--R                        2      3   3         2      4    3 3
+--R               ((80a b c  - 20b c)d  + (16a b c - 4b )d)e x
+--R             + 
+--R                        2      3   4         2      4  2     2         3  2 2
+--R               ((60a b c  - 15b c)d  + (24a b c - 6b )d  + 4a b c - a b )e x
+--R             + 
+--R                        2     3   5         2      4  3      2          3
+--R               ((24a b c  - 6b c)d  + (16a b c - 4b )d  + (8a b c - 2a b )d)e x
+--R             + 
+--R                      2    3   6        2     4  4      2         3  2
+--R               (4a b c  - b c)d  + (4a b c - b )d  + (4a b c - a b )d
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                         2     3   6 6             2      3     5 5
+--R               (- 16a b c  + 4b c)e x  + (- 96a b c  + 24b c)d e x
+--R             + 
+--R                           2      3   2        2      4  4 4
+--R               ((- 240a b c  + 60b c)d  - 16a b c + 4b )e x
+--R             + 
+--R                           2      3   3           2       4    3 3
+--R               ((- 320a b c  + 80b c)d  + (- 64a b c + 16b )d)e x
+--R             + 
+--R                              2      3   4           2       4  2      2
+--R                   (- 240a b c  + 60b c)d  + (- 96a b c + 24b )d  - 16a b c
+--R                 + 
+--R                       3
+--R                   4a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                             2      3   5           2       4  3
+--R                   (- 96a b c  + 24b c)d  + (- 64a b c + 16b )d
+--R                 + 
+--R                         2          3
+--R                   (- 32a b c + 8a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2     3   6           2      4  4         2          3  2
+--R             (- 16a b c  + 4b c)d  + (- 16a b c + 4b )d  + (- 16a b c + 4a b )d
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                2 2       2   4 4         2 2       2     3 3
+--R           (- 6a c  + 2a b c)e x  + (- 24a c  + 8a b c)d e x
+--R         + 
+--R                  2 2        2   2     2          3  2 2
+--R           ((- 36a c  + 12a b c)d  - 7a b c + 2a b )e x
+--R         + 
+--R                  2 2       2   3         2          3
+--R           ((- 24a c  + 8a b c)d  + (- 14a b c + 4a b )d)e x
+--R         + 
+--R                2 2       2   4        2          3  2     3     2 2
+--R           (- 6a c  + 2a b c)d  + (- 7a b c + 2a b )d  - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            4 2     3 2   7 6       4 2      3 2     6 5
+--R         (8a c  - 2a b c)e x  + (48a c  - 12a b c)d e x
+--R       + 
+--R               4 2      3 2   2     4        3 3  5 4
+--R         ((120a c  - 30a b c)d  + 8a b c - 2a b )e x
+--R       + 
+--R               4 2      3 2   3       4        3 3    4 3
+--R         ((160a c  - 40a b c)d  + (32a b c - 8a b )d)e x
+--R       + 
+--R               4 2      3 2   4       4         3 3  2     5      4 2  3 2
+--R         ((120a c  - 30a b c)d  + (48a b c - 12a b )d  + 8a c - 2a b )e x
+--R       + 
+--R              4 2      3 2   5       4        3 3  3       5      4 2    2
+--R         ((48a c  - 12a b c)d  + (32a b c - 8a b )d  + (16a c - 4a b )d)e x
+--R       + 
+--R             4 2     3 2   6      4        3 3  4      5      4 2  2
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 840
+
+--S 841 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3       2 2    4   6 6       2 3        2 2     4     5 5
+--R             (6a c  - 6a b c  + b c)e x  + (36a c  - 36a b c  + 6b c)d e x
+--R           + 
+--R                  2 3        2 2      4   2     2   2       3     5  4 4
+--R             ((90a c  - 90a b c  + 15b c)d  + 6a b c  - 6a b c + b )e x
+--R           + 
+--R                   2 3         2 2      4   3       2   2        3      5    3 3
+--R             ((120a c  - 120a b c  + 20b c)d  + (24a b c  - 24a b c + 4b )d)e x
+--R           + 
+--R                     2 3        2 2      4   4       2   2        3      5  2
+--R                 (90a c  - 90a b c  + 15b c)d  + (36a b c  - 36a b c + 6b )d
+--R               + 
+--R                   3 2     2 2       4
+--R                 6a c  - 6a b c + a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                     2 3        2 2     4   5       2   2        3      5  3
+--R                 (36a c  - 36a b c  + 6b c)d  + (24a b c  - 24a b c + 4b )d
+--R               + 
+--R                     3 2      2 2        4
+--R                 (12a c  - 12a b c + 2a b )d
+--R            *
+--R               e x
+--R           + 
+--R                2 3       2 2    4   6      2   2       3     5  4
+--R             (6a c  - 6a b c  + b c)d  + (6a b c  - 6a b c + b )d
+--R           + 
+--R                3 2     2 2       4  2
+--R             (6a c  - 6a b c + a b )d
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                        2    3   6 6           2     3     5 5
+--R                 (4a b c  - b c)e x  + (24a b c  - 6b c)d e x
+--R               + 
+--R                          2      3   2       2     4  4 4
+--R                 ((60a b c  - 15b c)d  + 4a b c - b )e x
+--R               + 
+--R                          2      3   3         2      4    3 3
+--R                 ((80a b c  - 20b c)d  + (16a b c - 4b )d)e x
+--R               + 
+--R                          2      3   4         2      4  2     2         3  2 2
+--R                 ((60a b c  - 15b c)d  + (24a b c - 6b )d  + 4a b c - a b )e x
+--R               + 
+--R                            2     3   5         2      4  3      2          3
+--R                   ((24a b c  - 6b c)d  + (16a b c - 4b )d  + (8a b c - 2a b )d)
+--R                *
+--R                   e x
+--R               + 
+--R                        2    3   6        2     4  4      2         3  2
+--R                 (4a b c  - b c)d  + (4a b c - b )d  + (4a b c - a b )d
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                           2     3   6 6             2      3     5 5
+--R                 (- 16a b c  + 4b c)e x  + (- 96a b c  + 24b c)d e x
+--R               + 
+--R                             2      3   2        2      4  4 4
+--R                 ((- 240a b c  + 60b c)d  - 16a b c + 4b )e x
+--R               + 
+--R                             2      3   3           2       4    3 3
+--R                 ((- 320a b c  + 80b c)d  + (- 64a b c + 16b )d)e x
+--R               + 
+--R                                2      3   4           2       4  2      2
+--R                     (- 240a b c  + 60b c)d  + (- 96a b c + 24b )d  - 16a b c
+--R                   + 
+--R                         3
+--R                     4a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                               2      3   5           2       4  3
+--R                     (- 96a b c  + 24b c)d  + (- 64a b c + 16b )d
+--R                   + 
+--R                           2          3
+--R                     (- 32a b c + 8a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)d  + (- 16a b c + 4b )d
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )d
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                  2 2       2   4 4         2 2       2     3 3
+--R             (- 6a c  + 2a b c)e x  + (- 24a c  + 8a b c)d e x
+--R           + 
+--R                    2 2        2   2     2          3  2 2
+--R             ((- 36a c  + 12a b c)d  - 7a b c + 2a b )e x
+--R           + 
+--R                    2 2       2   3         2          3
+--R             ((- 24a c  + 8a b c)d  + (- 14a b c + 4a b )d)e x
+--R           + 
+--R                  2 2       2   4        2          3  2     3     2 2
+--R             (- 6a c  + 2a b c)d  + (- 7a b c + 2a b )d  - 4a c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R              4 2     3 2   7 6       4 2      3 2     6 5
+--R           (8a c  - 2a b c)e x  + (48a c  - 12a b c)d e x
+--R         + 
+--R                 4 2      3 2   2     4        3 3  5 4
+--R           ((120a c  - 30a b c)d  + 8a b c - 2a b )e x
+--R         + 
+--R                 4 2      3 2   3       4        3 3    4 3
+--R           ((160a c  - 40a b c)d  + (32a b c - 8a b )d)e x
+--R         + 
+--R                 4 2      3 2   4       4         3 3  2     5      4 2  3 2
+--R           ((120a c  - 30a b c)d  + (48a b c - 12a b )d  + 8a c - 2a b )e x
+--R         + 
+--R                4 2      3 2   5       4        3 3  3       5      4 2    2
+--R           ((48a c  - 12a b c)d  + (32a b c - 8a b )d  + (16a c - 4a b )d)e x
+--R         + 
+--R               4 2     3 2   6      4        3 3  4      5      4 2  2
+--R           ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d )e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2 3        2 2     4   6 6
+--R             (- 12a c  + 12a b c  - 2b c)e x
+--R           + 
+--R                   2 3        2 2      4     5 5
+--R             (- 72a c  + 72a b c  - 12b c)d e x
+--R           + 
+--R                     2 3         2 2      4   2      2   2        3      5  4 4
+--R             ((- 180a c  + 180a b c  - 30b c)d  - 12a b c  + 12a b c - 2b )e x
+--R           + 
+--R                          2 3         2 2      4   3
+--R                   (- 240a c  + 240a b c  - 40b c)d
+--R                 + 
+--R                         2   2        3      5
+--R                   (- 48a b c  + 48a b c - 8b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                        2 3         2 2      4   4
+--R                 (- 180a c  + 180a b c  - 30b c)d
+--R               + 
+--R                       2   2        3       5  2      3 2      2 2        4
+--R                 (- 72a b c  + 72a b c - 12b )d  - 12a c  + 12a b c - 2a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                       2 3        2 2      4   5
+--R                 (- 72a c  + 72a b c  - 12b c)d
+--R               + 
+--R                       2   2        3      5  3         3 2      2 2        4
+--R                 (- 48a b c  + 48a b c - 8b )d  + (- 24a c  + 24a b c - 4a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   2 3        2 2     4   6         2   2        3      5  4
+--R             (- 12a c  + 12a b c  - 2b c)d  + (- 12a b c  + 12a b c - 2b )d
+--R           + 
+--R                   3 2      2 2        4  2
+--R             (- 12a c  + 12a b c - 2a b )d
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                        2    3   6 6           2     3     5 5
+--R                 (4a b c  - b c)e x  + (24a b c  - 6b c)d e x
+--R               + 
+--R                          2      3   2       2     4  4 4
+--R                 ((60a b c  - 15b c)d  + 4a b c - b )e x
+--R               + 
+--R                          2      3   3         2      4    3 3
+--R                 ((80a b c  - 20b c)d  + (16a b c - 4b )d)e x
+--R               + 
+--R                          2      3   4         2      4  2     2         3  2 2
+--R                 ((60a b c  - 15b c)d  + (24a b c - 6b )d  + 4a b c - a b )e x
+--R               + 
+--R                            2     3   5         2      4  3      2          3
+--R                   ((24a b c  - 6b c)d  + (16a b c - 4b )d  + (8a b c - 2a b )d)
+--R                *
+--R                   e x
+--R               + 
+--R                        2    3   6        2     4  4      2         3  2
+--R                 (4a b c  - b c)d  + (4a b c - b )d  + (4a b c - a b )d
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                           2     3   6 6             2      3     5 5
+--R                 (- 16a b c  + 4b c)e x  + (- 96a b c  + 24b c)d e x
+--R               + 
+--R                             2      3   2        2      4  4 4
+--R                 ((- 240a b c  + 60b c)d  - 16a b c + 4b )e x
+--R               + 
+--R                             2      3   3           2       4    3 3
+--R                 ((- 320a b c  + 80b c)d  + (- 64a b c + 16b )d)e x
+--R               + 
+--R                                2      3   4           2       4  2      2
+--R                     (- 240a b c  + 60b c)d  + (- 96a b c + 24b )d  - 16a b c
+--R                   + 
+--R                         3
+--R                     4a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                               2      3   5           2       4  3
+--R                     (- 96a b c  + 24b c)d  + (- 64a b c + 16b )d
+--R                   + 
+--R                           2          3
+--R                     (- 32a b c + 8a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)d  + (- 16a b c + 4b )d
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )d
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                  2 2       2   4 4         2 2       2     3 3
+--R             (- 6a c  + 2a b c)e x  + (- 24a c  + 8a b c)d e x
+--R           + 
+--R                    2 2        2   2     2          3  2 2
+--R             ((- 36a c  + 12a b c)d  - 7a b c + 2a b )e x
+--R           + 
+--R                    2 2       2   3         2          3
+--R             ((- 24a c  + 8a b c)d  + (- 14a b c + 4a b )d)e x
+--R           + 
+--R                  2 2       2   4        2          3  2     3     2 2
+--R             (- 6a c  + 2a b c)d  + (- 7a b c + 2a b )d  - 4a c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R              4 2     3 2   7 6       4 2      3 2     6 5
+--R           (8a c  - 2a b c)e x  + (48a c  - 12a b c)d e x
+--R         + 
+--R                 4 2      3 2   2     4        3 3  5 4
+--R           ((120a c  - 30a b c)d  + 8a b c - 2a b )e x
+--R         + 
+--R                 4 2      3 2   3       4        3 3    4 3
+--R           ((160a c  - 40a b c)d  + (32a b c - 8a b )d)e x
+--R         + 
+--R                 4 2      3 2   4       4         3 3  2     5      4 2  3 2
+--R           ((120a c  - 30a b c)d  + (48a b c - 12a b )d  + 8a c - 2a b )e x
+--R         + 
+--R                4 2      3 2   5       4        3 3  3       5      4 2    2
+--R           ((48a c  - 12a b c)d  + (32a b c - 8a b )d  + (16a c - 4a b )d)e x
+--R         + 
+--R               4 2     3 2   6      4        3 3  4      5      4 2  2
+--R           ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d )e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 841
+
+--S 842 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (6a c  - 6a b c + b )
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                                           2 2                  2
+--R             2 2        2      4       2c e x  + 4c d e x + 2c d  + b
+--R       (- 12a c  + 12a b c - 2b )atanh(------------------------------)
+--R                                                +-----------+
+--R                                                |          2
+--R                                               \|- 4a c + b
+--R  /
+--R                     +-----------+
+--R        4      3 2   |          2
+--R     (8a c - 2a b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 843
+
+--S 844 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                               +---------+          2 2                  2
+--R            2 2       2     4  |        2       2c e x  + 4c d e x + 2c d  + b
+--R       (- 6a c  + 6a b c - b )\|4a c - b  atanh(------------------------------)
+--R                                                         +-----------+
+--R                                                         |          2
+--R                                                        \|- 4a c + b
+--R     + 
+--R                                 +-----------+
+--R              2 2       2     4  |          2
+--R         (- 6a c  + 6a b c - b )\|- 4a c + b
+--R      *
+--R                                               +---------+
+--R                   2 2                  2      |        2
+--R              (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R        4     3 2   |          2  |        2
+--R     (4a c - a b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 844
+
+--S 845 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 845
+
+)clear all
+
+--S 846 of 1057
+t0:=1/((d+e*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 12 12      2   11 11       2 2         10 10        2 3            9 9
+--R       c e  x   + 12c d e  x   + (66c d  + 2b c)e  x   + (220c d  + 20b c d)e x
+--R     + 
+--R            2 4          2           2  8 8
+--R       (495c d  + 90b c d  + 2a c + b )e x
+--R     + 
+--R            2 5           3              2    7 7
+--R       (792c d  + 240b c d  + (16a c + 8b )d)e x
+--R     + 
+--R            2 6           4               2  2         6 6
+--R       (924c d  + 420b c d  + (56a c + 28b )d  + 2a b)e x
+--R     + 
+--R            2 7           5                2  3            5 5
+--R       (792c d  + 504b c d  + (112a c + 56b )d  + 12a b d)e x
+--R     + 
+--R            2 8           6                2  4          2    2  4 4
+--R       (495c d  + 420b c d  + (140a c + 70b )d  + 30a b d  + a )e x
+--R     + 
+--R            2 9           7                2  5          3     2   3 3
+--R       (220c d  + 240b c d  + (112a c + 56b )d  + 40a b d  + 4a d)e x
+--R     + 
+--R           2 10          8               2  6          4     2 2  2 2
+--R       (66c d   + 90b c d  + (56a c + 28b )d  + 30a b d  + 6a d )e x
+--R     + 
+--R           2 11          9              2  7          5     2 3        2 12
+--R       (12c d   + 20b c d  + (16a c + 8b )d  + 12a b d  + 4a d )e x + c d
+--R     + 
+--R             10            2  8         6    2 4
+--R       2b c d   + (2a c + b )d  + 2a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 846
+
+--S 847 of 1057
+r0:=1/6*(-5*b^2+14*a*c)/(a^2*(b^2-4*a*c)*e*(d+e*x)^3)+1/2*b*(5*b^2-19*a*c)/_
+   (a^3*(b^2-4*a*c)*e*(d+e*x))+1/2*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*_
+   e*(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4))+1/2*atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(5*b^3-19*a*b*c+(5*b^4-_
+   29*a*b^2*c+28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*e*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(5*b^3-19*a*b*c+(-5*b^4+29*a*b^2*c-_
+   28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*e*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       2      3   7 7            2       3     6 6
+--R               (57a b c  - 15b c)e x  + (399a b c  - 105b c)d e x
+--R             + 
+--R                          2       3   2        2       4  5 5
+--R               ((1197a b c  - 315b c)d  + 57a b c - 15b )e x
+--R             + 
+--R                          2       3   3          2       4    4 4
+--R               ((1995a b c  - 525b c)d  + (285a b c - 75b )d)e x
+--R             + 
+--R                             2       3   4          2        4  2      2
+--R                   (1995a b c  - 525b c)d  + (570a b c - 150b )d  + 57a b c
+--R                 + 
+--R                          3
+--R                   - 15a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                             2       3   5          2        4  3
+--R                   (1197a b c  - 315b c)d  + (570a b c - 150b )d
+--R                 + 
+--R                        2           3
+--R                   (171a b c - 45a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                            2       3   6          2       4  4
+--R                   (399a b c  - 105b c)d  + (285a b c - 75b )d
+--R                 + 
+--R                        2           3  2
+--R                   (171a b c - 45a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2      3   7         2       4  5       2           3  3
+--R               (57a b c  - 15b c)d  + (57a b c - 15b )d  + (57a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 3        2 2      4   7 7
+--R           (- 84a c  + 87a b c  - 15b c)e x
+--R         + 
+--R                  2 3         2 2       4     6 6
+--R           (- 588a c  + 609a b c  - 105b c)d e x
+--R         + 
+--R                      2 3          2 2       4   2      2   2        3       5
+--R             ((- 1764a c  + 1827a b c  - 315b c)d  - 84a b c  + 87a b c - 15b )
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   3
+--R               (- 2940a c  + 3045a b c  - 525b c)d
+--R             + 
+--R                      2   2         3       5
+--R               (- 420a b c  + 435a b c - 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   4
+--R               (- 2940a c  + 3045a b c  - 525b c)d
+--R             + 
+--R                      2   2         3        5  2      3 2      2 2         4
+--R               (- 840a b c  + 870a b c - 150b )d  - 84a c  + 87a b c - 15a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   5
+--R               (- 1764a c  + 1827a b c  - 315b c)d
+--R             + 
+--R                      2   2         3        5  3
+--R               (- 840a b c  + 870a b c - 150b )d
+--R             + 
+--R                      3 2       2 2         4
+--R               (- 252a c  + 261a b c - 45a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      2 3         2 2       4   6
+--R               (- 588a c  + 609a b c  - 105b c)d
+--R             + 
+--R                      2   2         3       5  4
+--R               (- 420a b c  + 435a b c - 75b )d
+--R             + 
+--R                      3 2       2 2         4  2
+--R               (- 252a c  + 261a b c - 45a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2 3        2 2      4   7         2   2        3       5  5
+--R           (- 84a c  + 87a b c  - 15b c)d  + (- 84a b c  + 87a b c - 15b )d
+--R         + 
+--R                 3 2      2 2         4  3
+--R           (- 84a c  + 87a b c - 15a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                       2      3   7 7            2       3     6 6
+--R               (57a b c  - 15b c)e x  + (399a b c  - 105b c)d e x
+--R             + 
+--R                          2       3   2        2       4  5 5
+--R               ((1197a b c  - 315b c)d  + 57a b c - 15b )e x
+--R             + 
+--R                          2       3   3          2       4    4 4
+--R               ((1995a b c  - 525b c)d  + (285a b c - 75b )d)e x
+--R             + 
+--R                             2       3   4          2        4  2      2
+--R                   (1995a b c  - 525b c)d  + (570a b c - 150b )d  + 57a b c
+--R                 + 
+--R                          3
+--R                   - 15a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                             2       3   5          2        4  3
+--R                   (1197a b c  - 315b c)d  + (570a b c - 150b )d
+--R                 + 
+--R                        2           3
+--R                   (171a b c - 45a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                            2       3   6          2       4  4
+--R                   (399a b c  - 105b c)d  + (285a b c - 75b )d
+--R                 + 
+--R                        2           3  2
+--R                   (171a b c - 45a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2      3   7         2       4  5       2           3  3
+--R               (57a b c  - 15b c)d  + (57a b c - 15b )d  + (57a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 3        2 2      4   7 7
+--R           (84a c  - 87a b c  + 15b c)e x
+--R         + 
+--R                2 3         2 2       4     6 6
+--R           (588a c  - 609a b c  + 105b c)d e x
+--R         + 
+--R                  2 3          2 2       4   2      2   2        3       5  5 5
+--R           ((1764a c  - 1827a b c  + 315b c)d  + 84a b c  - 87a b c + 15b )e x
+--R         + 
+--R                       2 3          2 2       4   3
+--R                 (2940a c  - 3045a b c  + 525b c)d
+--R               + 
+--R                      2   2         3       5
+--R                 (420a b c  - 435a b c + 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2 3          2 2       4   4
+--R               (2940a c  - 3045a b c  + 525b c)d
+--R             + 
+--R                    2   2         3        5  2      3 2      2 2         4
+--R               (840a b c  - 870a b c + 150b )d  + 84a c  - 87a b c + 15a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2 3          2 2       4   5
+--R               (1764a c  - 1827a b c  + 315b c)d
+--R             + 
+--R                  2   2         3        5  3        3 2       2 2         4
+--R             (840a b c  - 870a b c + 150b )d  + (252a c  - 261a b c + 45a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                    2 3         2 2       4   6
+--R               (588a c  - 609a b c  + 105b c)d
+--R             + 
+--R                  2   2         3       5  4        3 2       2 2         4  2
+--R             (420a b c  - 435a b c + 75b )d  + (252a c  - 261a b c + 45a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2 3        2 2      4   7       2   2        3       5  5
+--R           (84a c  - 87a b c  + 15b c)d  + (84a b c  - 87a b c + 15b )d
+--R         + 
+--R               3 2      2 2         4  3
+--R           (84a c  - 87a b c + 15a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2      3   6 6            2      3     5 5
+--R           (57a b c  - 15b c)e x  + (342a b c  - 90b c)d e x
+--R         + 
+--R                     2       3   2      2 2        2       4  4 4
+--R           ((855a b c  - 225b c)d  - 14a c  + 62a b c - 15b )e x
+--R         + 
+--R                      2       3   3         2 2         2       4    3 3
+--R           ((1140a b c  - 300b c)d  + (- 56a c  + 248a b c - 60b )d)e x
+--R         + 
+--R                        2       3   4         2 2         2       4  2      2
+--R               (855a b c  - 225b c)d  + (- 84a c  + 372a b c - 90b )d  + 40a b c
+--R             + 
+--R                      3
+--R               - 10a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        2      3   5         2 2         2       4  3
+--R               (342a b c  - 90b c)d  + (- 56a c  + 248a b c - 60b )d
+--R             + 
+--R                   2           3
+--R               (80a b c - 20a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   2      3   6         2 2        2       4  4
+--R           (57a b c  - 15b c)d  + (- 14a c  + 62a b c - 15b )d
+--R         + 
+--R               2           3  2     3      2 2
+--R           (40a b c - 10a b )d  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R             4 2     3 2   8 7        4 2      3 2     7 6
+--R         (24a c  - 6a b c)e x  + (168a c  - 42a b c)d e x
+--R       + 
+--R               4 2       3 2   2      4        3 3  6 5
+--R         ((504a c  - 126a b c)d  + 24a b c - 6a b )e x
+--R       + 
+--R               4 2       3 2   3        4         3 3    5 4
+--R         ((840a c  - 210a b c)d  + (120a b c - 30a b )d)e x
+--R       + 
+--R               4 2       3 2   4        4         3 3  2      5      4 2  4 3
+--R         ((840a c  - 210a b c)d  + (240a b c - 60a b )d  + 24a c - 6a b )e x
+--R       + 
+--R                 4 2       3 2   5        4         3 3  3       5       4 2
+--R           ((504a c  - 126a b c)d  + (240a b c - 60a b )d  + (72a c - 18a b )d)
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R               4 2      3 2   6        4         3 3  4       5       4 2  2  2
+--R         ((168a c  - 42a b c)d  + (120a b c - 30a b )d  + (72a c - 18a b )d )e x
+--R       + 
+--R              4 2     3 2   7       4        3 3  5       5      4 2  3
+--R         ((24a c  - 6a b c)d  + (24a b c - 6a b )d  + (24a c - 6a b )d )e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 4 2     3 2   8 7         4 2      3 2     7 6
+--R           (- 12a c  + 3a b c)e x  + (- 84a c  + 21a b c)d e x
+--R         + 
+--R                   4 2      3 2   2      4        3 3  6 5
+--R           ((- 252a c  + 63a b c)d  - 12a b c + 3a b )e x
+--R         + 
+--R                   4 2       3 2   3         4         3 3    5 4
+--R           ((- 420a c  + 105a b c)d  + (- 60a b c + 15a b )d)e x
+--R         + 
+--R                        4 2       3 2   4          4         3 3  2      5
+--R                 (- 420a c  + 105a b c)d  + (- 120a b c + 30a b )d  - 12a c
+--R               + 
+--R                   4 2
+--R                 3a b
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                      4 2      3 2   5          4         3 3  3
+--R               (- 252a c  + 63a b c)d  + (- 120a b c + 30a b )d
+--R             + 
+--R                     5      4 2
+--R               (- 36a c + 9a b )d
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                     4 2      3 2   6         4         3 3  4
+--R               (- 84a c  + 21a b c)d  + (- 60a b c + 15a b )d
+--R             + 
+--R                     5      4 2  2
+--R               (- 36a c + 9a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                4 2     3 2   7         4        3 3  5         5      4 2  3
+--R         ((- 12a c  + 3a b c)d  + (- 12a b c + 3a b )d  + (- 12a c + 3a b )d )e
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6  2
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                17 3         16 2 2        15 4        14 6  4
+--R                         (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                            7 7         6 2 6          5 4 5          4 6 4
+--R                      10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                    + 
+--R                            3 8 3         2 10 2          12        14
+--R                      75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6  2
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R               4 2     3 2   8 7       4 2      3 2     7 6
+--R           (12a c  - 3a b c)e x  + (84a c  - 21a b c)d e x
+--R         + 
+--R                 4 2      3 2   2      4        3 3  6 5
+--R           ((252a c  - 63a b c)d  + 12a b c - 3a b )e x
+--R         + 
+--R                 4 2       3 2   3       4         3 3    5 4
+--R           ((420a c  - 105a b c)d  + (60a b c - 15a b )d)e x
+--R         + 
+--R                 4 2       3 2   4        4         3 3  2      5      4 2  4 3
+--R           ((420a c  - 105a b c)d  + (120a b c - 30a b )d  + 12a c - 3a b )e x
+--R         + 
+--R                   4 2      3 2   5        4         3 3  3       5      4 2
+--R             ((252a c  - 63a b c)d  + (120a b c - 30a b )d  + (36a c - 9a b )d)
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                4 2      3 2   6       4         3 3  4       5      4 2  2  2
+--R           ((84a c  - 21a b c)d  + (60a b c - 15a b )d  + (36a c - 9a b )d )e x
+--R         + 
+--R                4 2     3 2   7       4        3 3  5       5      4 2  3
+--R           ((12a c  - 3a b c)d  + (12a b c - 3a b )d  + (12a c - 3a b )d )e
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6  2
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                17 3         16 2 2        15 4        14 6  4
+--R                         (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                              7 7         6 2 6          5 4 5          4 6 4
+--R                      - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                    + 
+--R                              3 8 3         2 10 2          12        14
+--R                      - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6  2
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R                 4 2     3 2   8 7         4 2      3 2     7 6
+--R           (- 12a c  + 3a b c)e x  + (- 84a c  + 21a b c)d e x
+--R         + 
+--R                   4 2      3 2   2      4        3 3  6 5
+--R           ((- 252a c  + 63a b c)d  - 12a b c + 3a b )e x
+--R         + 
+--R                   4 2       3 2   3         4         3 3    5 4
+--R           ((- 420a c  + 105a b c)d  + (- 60a b c + 15a b )d)e x
+--R         + 
+--R                        4 2       3 2   4          4         3 3  2      5
+--R                 (- 420a c  + 105a b c)d  + (- 120a b c + 30a b )d  - 12a c
+--R               + 
+--R                   4 2
+--R                 3a b
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                      4 2      3 2   5          4         3 3  3
+--R               (- 252a c  + 63a b c)d  + (- 120a b c + 30a b )d
+--R             + 
+--R                     5      4 2
+--R               (- 36a c + 9a b )d
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                     4 2      3 2   6         4         3 3  4
+--R               (- 84a c  + 21a b c)d  + (- 60a b c + 15a b )d
+--R             + 
+--R                     5      4 2  2
+--R               (- 36a c + 9a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                4 2     3 2   7         4        3 3  5         5      4 2  3
+--R         ((- 12a c  + 3a b c)d  + (- 12a b c + 3a b )d  + (- 12a c + 3a b )d )e
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6  2
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                17 3         16 2 2        15 4        14 6  4
+--R                         (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                            7 7         6 2 6          5 4 5          4 6 4
+--R                      10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                    + 
+--R                            3 8 3         2 10 2          12        14
+--R                      75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6  2
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R               4 2     3 2   8 7       4 2      3 2     7 6
+--R           (12a c  - 3a b c)e x  + (84a c  - 21a b c)d e x
+--R         + 
+--R                 4 2      3 2   2      4        3 3  6 5
+--R           ((252a c  - 63a b c)d  + 12a b c - 3a b )e x
+--R         + 
+--R                 4 2       3 2   3       4         3 3    5 4
+--R           ((420a c  - 105a b c)d  + (60a b c - 15a b )d)e x
+--R         + 
+--R                 4 2       3 2   4        4         3 3  2      5      4 2  4 3
+--R           ((420a c  - 105a b c)d  + (120a b c - 30a b )d  + 12a c - 3a b )e x
+--R         + 
+--R                   4 2      3 2   5        4         3 3  3       5      4 2
+--R             ((252a c  - 63a b c)d  + (120a b c - 30a b )d  + (36a c - 9a b )d)
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                4 2      3 2   6       4         3 3  4       5      4 2  2  2
+--R           ((84a c  - 21a b c)d  + (60a b c - 15a b )d  + (36a c - 9a b )d )e x
+--R         + 
+--R                4 2     3 2   7       4        3 3  5       5      4 2  3
+--R           ((12a c  - 3a b c)d  + (12a b c - 3a b )d  + (12a c - 3a b )d )e
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6  2
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                17 3         16 2 2        15 4        14 6  4
+--R                         (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                              7 7         6 2 6          5 4 5          4 6 4
+--R                      - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                    + 
+--R                              3 8 3         2 10 2          12        14
+--R                      - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6  2
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R               2      3   6 6            2      3     5 5
+--R       (57a b c  - 15b c)e x  + (342a b c  - 90b c)d e x
+--R     + 
+--R                 2       3   2      2 2        2       4  4 4
+--R       ((855a b c  - 225b c)d  - 14a c  + 62a b c - 15b )e x
+--R     + 
+--R                  2       3   3         2 2         2       4    3 3
+--R       ((1140a b c  - 300b c)d  + (- 56a c  + 248a b c - 60b )d)e x
+--R     + 
+--R                    2       3   4         2 2         2       4  2      2
+--R           (855a b c  - 225b c)d  + (- 84a c  + 372a b c - 90b )d  + 40a b c
+--R         + 
+--R                  3
+--R           - 10a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R                    2      3   5         2 2         2       4  3
+--R           (342a b c  - 90b c)d  + (- 56a c  + 248a b c - 60b )d
+--R         + 
+--R               2           3
+--R           (80a b c - 20a b )d
+--R      *
+--R         e x
+--R     + 
+--R               2      3   6         2 2        2       4  4
+--R       (57a b c  - 15b c)d  + (- 14a c  + 62a b c - 15b )d
+--R     + 
+--R           2           3  2     3      2 2
+--R       (40a b c - 10a b )d  - 8a c + 2a b
+--R  /
+--R           4 2     3 2   8 7        4 2      3 2     7 6
+--R       (24a c  - 6a b c)e x  + (168a c  - 42a b c)d e x
+--R     + 
+--R             4 2       3 2   2      4        3 3  6 5
+--R       ((504a c  - 126a b c)d  + 24a b c - 6a b )e x
+--R     + 
+--R             4 2       3 2   3        4         3 3    5 4
+--R       ((840a c  - 210a b c)d  + (120a b c - 30a b )d)e x
+--R     + 
+--R             4 2       3 2   4        4         3 3  2      5      4 2  4 3
+--R       ((840a c  - 210a b c)d  + (240a b c - 60a b )d  + 24a c - 6a b )e x
+--R     + 
+--R             4 2       3 2   5        4         3 3  3       5       4 2    3 2
+--R       ((504a c  - 126a b c)d  + (240a b c - 60a b )d  + (72a c - 18a b )d)e x
+--R     + 
+--R             4 2      3 2   6        4         3 3  4       5       4 2  2  2
+--R       ((168a c  - 42a b c)d  + (120a b c - 30a b )d  + (72a c - 18a b )d )e x
+--R     + 
+--R            4 2     3 2   7       4        3 3  5       5      4 2  3
+--R       ((24a c  - 6a b c)d  + (24a b c - 6a b )d  + (24a c - 6a b )d )e
+--R                                         Type: Union(Expression(Integer),...)
+--E 848
+
+--S 849 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +--------------------+
+--R                              +-----------+ |   +-----------+
+--R              4     3 2   +-+ |          2  |   |          2
+--R         (- 4a c + a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6  2
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                17 3         16 2 2        15 4        14 6  4
+--R                         (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                            7 7         6 2 6          5 4 5          4 6 4
+--R                      10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                    + 
+--R                            3 8 3         2 10 2          12        14
+--R                      75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6  2
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R                            +-----------+
+--R            4     3 2   +-+ |          2
+--R         (4a c - a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6  2
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                17 3         16 2 2        15 4        14 6  4
+--R                         (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                              7 7         6 2 6          5 4 5          4 6 4
+--R                      - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                    + 
+--R                              3 8 3         2 10 2          12        14
+--R                      - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6  2
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R                              +-----------+
+--R              4     3 2   +-+ |          2
+--R         (- 4a c + a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6  2
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                17 3         16 2 2        15 4        14 6  4
+--R                         (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                            7 7         6 2 6          5 4 5          4 6 4
+--R                      10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                    + 
+--R                            3 8 3         2 10 2          12        14
+--R                      75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6  2
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R            4     3 2   +-+ |          2  |   |          2
+--R         (4a c - a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6  2
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                17 3         16 2 2        15 4        14 6  4
+--R                         (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                + 
+--R                              7 7         6 2 6          5 4 5          4 6 4
+--R                      - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                    + 
+--R                              3 8 3         2 10 2          12        14
+--R                      - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6  2
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4  +-+
+--R         ((- 19a b c + 5b )\|- 4a c + b   + 28a c  - 29a b c + 5b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                       +-+ +-+
+--R          | |          2              (e x + d)\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4  +-+
+--R         ((- 19a b c + 5b )\|- 4a c + b   - 28a c  + 29a b c - 5b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R          4      3 2   +-+ |          2  |   |          2
+--R       (8a c - 2a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 849
+
+--S 850 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 850
+
+)clear all
+
+--S 851 of 1057
+t0:=(d+e*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      4 4       3 3     2 2 2     3       4
+--R     e x  + 4d e x  + 6d e x  + 4d e x + d
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 851
+
+--S 852 of 1057
+r0:=1/4*(d+e*x)*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*_
+   (d+e*x)^4)^2)-1/8*(d+e*x)*(7*b^2-4*a*c+12*b*c*(d+e*x)^2)/((b^2-4*a*c)^2*_
+   e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+3/4*atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2+4*a*c-2*b*sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)^(5/2)*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-3/4*atan((d+e*x)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2+4*a*c+2*b*_
+   sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2 8 8        2   7 7            2 2      2   6 6
+--R               - 12b c e x  - 96b c d e x  + (- 336b c d  - 24b c)e x
+--R             + 
+--R                        2 3       2     5 5
+--R               (- 672b c d  - 144b c d)e x
+--R             + 
+--R                        2 4       2   2                3  4 4
+--R               (- 840b c d  - 360b c d  - 24a b c - 12b )e x
+--R             + 
+--R                        2 5       2   3                   3    3 3
+--R               (- 672b c d  - 480b c d  + (- 96a b c - 48b )d)e x
+--R             + 
+--R                        2 6       2   4                    3  2        2  2 2
+--R               (- 336b c d  - 360b c d  + (- 144a b c - 72b )d  - 24a b )e x
+--R             + 
+--R                       2 7       2   5                   3  3        2
+--R               (- 96b c d  - 144b c d  + (- 96a b c - 48b )d  - 48a b d)e x
+--R             + 
+--R                      2 8      2   6                   3  4        2 2      2
+--R               - 12b c d  - 24b c d  + (- 24a b c - 12b )d  - 24a b d  - 12a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8 8          3       2 2    7 7
+--R           (24a c  + 18b c )e x  + (192a c  + 144b c )d e x
+--R         + 
+--R                   3       2 2  2          2      3   6 6
+--R           ((672a c  + 504b c )d  + 48a b c  + 36b c)e x
+--R         + 
+--R                    3        2 2  3            2       3     5 5
+--R           ((1344a c  + 1008b c )d  + (288a b c  + 216b c)d)e x
+--R         + 
+--R                       3        2 2  4            2       3   2      2 2
+--R               (1680a c  + 1260b c )d  + (720a b c  + 540b c)d  + 48a c
+--R             + 
+--R                    2       4
+--R               60a b c + 18b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       3        2 2  5            2       3   3
+--R               (1344a c  + 1008b c )d  + (960a b c  + 720b c)d
+--R             + 
+--R                    2 2         2       4
+--R               (192a c  + 240a b c + 72b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      3       2 2  6            2       3   4
+--R               (672a c  + 504b c )d  + (720a b c  + 540b c)d
+--R             + 
+--R                    2 2         2        4  2      2           3
+--R               (288a c  + 360a b c + 108b )d  + 48a b c + 36a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3       2 2  7            2       3   5
+--R               (192a c  + 144b c )d  + (288a b c  + 216b c)d
+--R             + 
+--R                    2 2         2       4  3       2           3
+--R               (192a c  + 240a b c + 72b )d  + (96a b c + 72a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 3      2 2  8           2      3   6
+--R           (24a c  + 18b c )d  + (48a b c  + 36b c)d
+--R         + 
+--R               2 2        2       4  4       2           3  2      3       2 2
+--R           (48a c  + 60a b c + 18b )d  + (48a b c + 36a b )d  + 24a c + 18a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2 8 8        2   7 7            2 2      2   6 6
+--R               - 12b c e x  - 96b c d e x  + (- 336b c d  - 24b c)e x
+--R             + 
+--R                        2 3       2     5 5
+--R               (- 672b c d  - 144b c d)e x
+--R             + 
+--R                        2 4       2   2                3  4 4
+--R               (- 840b c d  - 360b c d  - 24a b c - 12b )e x
+--R             + 
+--R                        2 5       2   3                   3    3 3
+--R               (- 672b c d  - 480b c d  + (- 96a b c - 48b )d)e x
+--R             + 
+--R                        2 6       2   4                    3  2        2  2 2
+--R               (- 336b c d  - 360b c d  + (- 144a b c - 72b )d  - 24a b )e x
+--R             + 
+--R                       2 7       2   5                   3  3        2
+--R               (- 96b c d  - 144b c d  + (- 96a b c - 48b )d  - 48a b d)e x
+--R             + 
+--R                      2 8      2   6                   3  4        2 2      2
+--R               - 12b c d  - 24b c d  + (- 24a b c - 12b )d  - 24a b d  - 12a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8 8            3       2 2    7 7
+--R           (- 24a c  - 18b c )e x  + (- 192a c  - 144b c )d e x
+--R         + 
+--R                     3       2 2  2          2      3   6 6
+--R           ((- 672a c  - 504b c )d  - 48a b c  - 36b c)e x
+--R         + 
+--R                      3        2 2  3              2       3     5 5
+--R           ((- 1344a c  - 1008b c )d  + (- 288a b c  - 216b c)d)e x
+--R         + 
+--R                         3        2 2  4              2       3   2      2 2
+--R               (- 1680a c  - 1260b c )d  + (- 720a b c  - 540b c)d  - 48a c
+--R             + 
+--R                      2       4
+--R               - 60a b c - 18b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                         3        2 2  5              2       3   3
+--R               (- 1344a c  - 1008b c )d  + (- 960a b c  - 720b c)d
+--R             + 
+--R                      2 2         2       4
+--R               (- 192a c  - 240a b c - 72b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                        3       2 2  6              2       3   4
+--R               (- 672a c  - 504b c )d  + (- 720a b c  - 540b c)d
+--R             + 
+--R                      2 2         2        4  2      2           3
+--R               (- 288a c  - 360a b c - 108b )d  - 48a b c - 36a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        3       2 2  7              2       3   5
+--R               (- 192a c  - 144b c )d  + (- 288a b c  - 216b c)d
+--R             + 
+--R                      2 2         2       4  3         2           3
+--R               (- 192a c  - 240a b c - 72b )d  + (- 96a b c - 72a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   3      2 2  8             2      3   6
+--R           (- 24a c  - 18b c )d  + (- 48a b c  - 36b c)d
+--R         + 
+--R               2 2        2       4  4         2           3  2      3       2 2
+--R         (- 48a c  - 60a b c - 18b )d  + (- 48a b c - 36a b )d  - 24a c - 18a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 7 7        2   6 6            2 2       2      2   5 5
+--R           - 12b c e x  - 84b c d e x  + (- 252b c d  + 4a c  - 19b c)e x
+--R         + 
+--R                    2 3         2      2     4 4
+--R           (- 420b c d  + (20a c  - 95b c)d)e x
+--R         + 
+--R                    2 4         2       2   2               3  3 3
+--R           (- 420b c d  + (40a c  - 190b c)d  - 16a b c - 5b )e x
+--R         + 
+--R                    2 5         2       2   3                   3    2 2
+--R           (- 252b c d  + (40a c  - 190b c)d  + (- 48a b c - 15b )d)e x
+--R         + 
+--R                      2 6         2      2   4                   3  2      2
+--R               - 84b c d  + (20a c  - 95b c)d  + (- 48a b c - 15b )d  - 12a c
+--R             + 
+--R                     2
+--R               - 3a b
+--R          *
+--R             e x
+--R         + 
+--R                  2 7        2      2   5                  3  3
+--R           - 12b c d  + (4a c  - 19b c)d  + (- 16a b c - 5b )d
+--R         + 
+--R                 2        2
+--R           (- 12a c - 3a b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 4        2 3     4 2  9 8
+--R         (128a c  - 64a b c  + 8b c )e x
+--R       + 
+--R               2 4         2 3      4 2    8 7
+--R         (1024a c  - 512a b c  + 64b c )d e x
+--R       + 
+--R                  2 4          2 3       4 2  2       2   3         3 2      5
+--R           ((3584a c  - 1792a b c  + 224b c )d  + 256a b c  - 128a b c  + 16b c)
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (7168a c  - 3584a b c  + 448b c )d
+--R           + 
+--R                   2   3         3 2      5
+--R             (1536a b c  - 768a b c  + 96b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (8960a c  - 4480a b c  + 560b c )d
+--R           + 
+--R                   2   3          3 2       5   2       3 3        4      6
+--R             (3840a b c  - 1920a b c  + 240b c)d  + 256a c  - 48a b c + 8b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (7168a c  - 3584a b c  + 448b c )d
+--R           + 
+--R                 2   3          3 2       5   3         3 3         4       6
+--R           (5120a b c  - 2560a b c  + 320b c)d  + (1024a c  - 192a b c + 32b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  6
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   4
+--R             (3840a b c  - 1920a b c  + 240b c)d
+--R           + 
+--R                   3 3         4       6  2       3   2       2 3         5
+--R             (1536a c  - 288a b c + 48b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   2 4         2 3      4 2  7
+--R             (1024a c  - 512a b c  + 64b c )d
+--R           + 
+--R                   2   3         3 2      5   5         3 3         4       6  3
+--R             (1536a b c  - 768a b c  + 96b c)d  + (1024a c  - 192a b c + 32b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  2 4        2 3     4 2  8        2   3         3 2      5   6
+--R             (128a c  - 64a b c  + 8b c )d  + (256a b c  - 128a b c  + 16b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2       2 3         5  2
+--R             (256a c  - 48a b c + 8b )d  + (256a b c  - 128a b c + 16a b )d
+--R           + 
+--R                 4 2      3 2      2 4
+--R             128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 852
+
+--S 853 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                            6 5           5 2 4           4 4 3          3 6 2
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                          2 8           10
+--R                    46080a b c - 2304a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                        4 4       3 2 3        6      8
+--R                  (1024a c  - 512a b c  + 32a b c - 4b )e
+--R             *
+--R                ROOT
+--R                                   6 5           5 2 4           4 4 3
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    3 6 2         2 8           10
+--R                           - 368640a b c  + 46080a b c - 2304a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                  2 3         2 2      4            2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)e x + (48a c  + 120a b c  + 15b c)d
+--R     + 
+--R                 2 4        2 3     4 2  9 8
+--R           (- 64a c  + 32a b c  - 4b c )e x
+--R         + 
+--R                  2 4         2 3      4 2    8 7
+--R           (- 512a c  + 256a b c  - 32b c )d e x
+--R         + 
+--R                         2 4         2 3       4 2  2       2   3        3 2
+--R                 (- 1792a c  + 896a b c  - 112b c )d  - 128a b c  + 64a b c
+--R               + 
+--R                     5
+--R                 - 8b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  3
+--R               (- 3584a c  + 1792a b c  - 224b c )d
+--R             + 
+--R                      2   3         3 2      5
+--R               (- 768a b c  + 384a b c  - 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  4
+--R               (- 4480a c  + 2240a b c  - 280b c )d
+--R             + 
+--R                       2   3         3 2       5   2       3 3        4      6
+--R               (- 1920a b c  + 960a b c  - 120b c)d  - 128a c  + 24a b c - 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  5
+--R               (- 3584a c  + 1792a b c  - 224b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 2560a b c  + 1280a b c  - 160b c)d
+--R             + 
+--R                      3 3        4       6
+--R               (- 512a c  + 96a b c - 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       2 4         2 3       4 2  6
+--R               (- 1792a c  + 896a b c  - 112b c )d
+--R             + 
+--R                       2   3         3 2       5   4
+--R               (- 1920a b c  + 960a b c  - 120b c)d
+--R             + 
+--R                      3 3         4       6  2       3   2      2 3        5
+--R               (- 768a c  + 144a b c - 24b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      2 4         2 3      4 2  7
+--R               (- 512a c  + 256a b c  - 32b c )d
+--R             + 
+--R                      2   3         3 2      5   5
+--R               (- 768a b c  + 384a b c  - 48b c)d
+--R             + 
+--R                    3 3        4       6  3          3   2       2 3         5
+--R             (- 512a c  + 96a b c - 16b )d  + (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     2 4        2 3     4 2  8
+--R               (- 64a c  + 32a b c  - 4b c )d
+--R             + 
+--R                      2   3        3 2     5   6          3 3        4      6  4
+--R               (- 128a b c  + 64a b c  - 8b c)d  + (- 128a c  + 24a b c - 4b )d
+--R             + 
+--R                      3   2      2 3        5  2      4 2      3 2      2 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                              6 5           5 2 4           4 4 3          3 6 2
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                            2 8           10
+--R                    - 46080a b c + 2304a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                          4 4       3 2 3        6      8
+--R                  (- 1024a c  + 512a b c  - 32a b c + 4b )e
+--R             *
+--R                ROOT
+--R                                     6 5           5 2 4           4 4 3
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  3 6 2         2 8           10
+--R                           368640a b c  - 46080a b c + 2304a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                  2 3         2 2      4            2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)e x + (48a c  + 120a b c  + 15b c)d
+--R     + 
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                              6 5           5 2 4           4 4 3          3 6 2
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                            2 8           10
+--R                    - 46080a b c + 2304a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                        4 4       3 2 3        6      8
+--R                  (1024a c  - 512a b c  + 32a b c - 4b )e
+--R             *
+--R                ROOT
+--R                                     6 5           5 2 4           4 4 3
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  3 6 2         2 8           10
+--R                           368640a b c  - 46080a b c + 2304a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                  2 3         2 2      4            2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)e x + (48a c  + 120a b c  + 15b c)d
+--R     + 
+--R                 2 4        2 3     4 2  9 8
+--R           (- 64a c  + 32a b c  - 4b c )e x
+--R         + 
+--R                  2 4         2 3      4 2    8 7
+--R           (- 512a c  + 256a b c  - 32b c )d e x
+--R         + 
+--R                         2 4         2 3       4 2  2       2   3        3 2
+--R                 (- 1792a c  + 896a b c  - 112b c )d  - 128a b c  + 64a b c
+--R               + 
+--R                     5
+--R                 - 8b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  3
+--R               (- 3584a c  + 1792a b c  - 224b c )d
+--R             + 
+--R                      2   3         3 2      5
+--R               (- 768a b c  + 384a b c  - 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  4
+--R               (- 4480a c  + 2240a b c  - 280b c )d
+--R             + 
+--R                       2   3         3 2       5   2       3 3        4      6
+--R               (- 1920a b c  + 960a b c  - 120b c)d  - 128a c  + 24a b c - 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  5
+--R               (- 3584a c  + 1792a b c  - 224b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 2560a b c  + 1280a b c  - 160b c)d
+--R             + 
+--R                      3 3        4       6
+--R               (- 512a c  + 96a b c - 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       2 4         2 3       4 2  6
+--R               (- 1792a c  + 896a b c  - 112b c )d
+--R             + 
+--R                       2   3         3 2       5   4
+--R               (- 1920a b c  + 960a b c  - 120b c)d
+--R             + 
+--R                      3 3         4       6  2       3   2      2 3        5
+--R               (- 768a c  + 144a b c - 24b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      2 4         2 3      4 2  7
+--R               (- 512a c  + 256a b c  - 32b c )d
+--R             + 
+--R                      2   3         3 2      5   5
+--R               (- 768a b c  + 384a b c  - 48b c)d
+--R             + 
+--R                    3 3        4       6  3          3   2       2 3         5
+--R             (- 512a c  + 96a b c - 16b )d  + (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     2 4        2 3     4 2  8
+--R               (- 64a c  + 32a b c  - 4b c )d
+--R             + 
+--R                      2   3        3 2     5   6          3 3        4      6  4
+--R               (- 128a b c  + 64a b c  - 8b c)d  + (- 128a c  + 24a b c - 4b )d
+--R             + 
+--R                      3   2      2 3        5  2      4 2      3 2      2 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                            6 5           5 2 4           4 4 3          3 6 2
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                          2 8           10
+--R                    46080a b c - 2304a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                          4 4       3 2 3        6      8
+--R                  (- 1024a c  + 512a b c  - 32a b c + 4b )e
+--R             *
+--R                ROOT
+--R                                   6 5           5 2 4           4 4 3
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    3 6 2         2 8           10
+--R                           - 368640a b c  + 46080a b c - 2304a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                  2 3         2 2      4            2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)e x + (48a c  + 120a b c  + 15b c)d
+--R     + 
+--R              2 7 7        2   6 6            2 2       2      2   5 5
+--R       - 12b c e x  - 84b c d e x  + (- 252b c d  + 4a c  - 19b c)e x
+--R     + 
+--R                2 3         2      2     4 4
+--R       (- 420b c d  + (20a c  - 95b c)d)e x
+--R     + 
+--R                2 4         2       2   2               3  3 3
+--R       (- 420b c d  + (40a c  - 190b c)d  - 16a b c - 5b )e x
+--R     + 
+--R                2 5         2       2   3                   3    2 2
+--R       (- 252b c d  + (40a c  - 190b c)d  + (- 48a b c - 15b )d)e x
+--R     + 
+--R                    2 6         2      2   4                   3  2      2
+--R             - 84b c d  + (20a c  - 95b c)d  + (- 48a b c - 15b )d  - 12a c
+--R           + 
+--R                   2
+--R             - 3a b
+--R      *
+--R         e x
+--R     + 
+--R            2 7        2      2   5                  3  3         2        2
+--R     - 12b c d  + (4a c  - 19b c)d  + (- 16a b c - 5b )d  + (- 12a c - 3a b )d
+--R  /
+--R            2 4        2 3     4 2  9 8         2 4         2 3      4 2    8 7
+--R       (128a c  - 64a b c  + 8b c )e x  + (1024a c  - 512a b c  + 64b c )d e x
+--R     + 
+--R              2 4          2 3       4 2  2       2   3         3 2      5   7 6
+--R       ((3584a c  - 1792a b c  + 224b c )d  + 256a b c  - 128a b c  + 16b c)e x
+--R     + 
+--R                   2 4          2 3       4 2  3
+--R             (7168a c  - 3584a b c  + 448b c )d
+--R           + 
+--R                   2   3         3 2      5
+--R             (1536a b c  - 768a b c  + 96b c)d
+--R      *
+--R          6 5
+--R         e x
+--R     + 
+--R                 2 4          2 3       4 2  4
+--R           (8960a c  - 4480a b c  + 560b c )d
+--R         + 
+--R                 2   3          3 2       5   2       3 3        4      6
+--R           (3840a b c  - 1920a b c  + 240b c)d  + 256a c  - 48a b c + 8b
+--R      *
+--R          5 4
+--R         e x
+--R     + 
+--R                 2 4          2 3       4 2  5
+--R           (7168a c  - 3584a b c  + 448b c )d
+--R         + 
+--R                 2   3          3 2       5   3         3 3         4       6
+--R           (5120a b c  - 2560a b c  + 320b c)d  + (1024a c  - 192a b c + 32b )d
+--R      *
+--R          4 3
+--R         e x
+--R     + 
+--R                 2 4          2 3       4 2  6
+--R           (3584a c  - 1792a b c  + 224b c )d
+--R         + 
+--R                 2   3          3 2       5   4         3 3         4       6  2
+--R           (3840a b c  - 1920a b c  + 240b c)d  + (1536a c  - 288a b c + 48b )d
+--R         + 
+--R               3   2       2 3         5
+--R           256a b c  - 128a b c + 16a b
+--R      *
+--R          3 2
+--R         e x
+--R     + 
+--R                 2 4         2 3      4 2  7
+--R           (1024a c  - 512a b c  + 64b c )d
+--R         + 
+--R                 2   3         3 2      5   5         3 3         4       6  3
+--R           (1536a b c  - 768a b c  + 96b c)d  + (1024a c  - 192a b c + 32b )d
+--R         + 
+--R                3   2       2 3         5
+--R           (512a b c  - 256a b c + 32a b )d
+--R      *
+--R          2
+--R         e x
+--R     + 
+--R                2 4        2 3     4 2  8        2   3         3 2      5   6
+--R           (128a c  - 64a b c  + 8b c )d  + (256a b c  - 128a b c  + 16b c)d
+--R         + 
+--R                3 3        4      6  4        3   2       2 3         5  2
+--R           (256a c  - 48a b c + 8b )d  + (256a b c  - 128a b c + 16a b )d
+--R         + 
+--R               4 2      3 2      2 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R         e
+--R                                         Type: Union(Expression(Integer),...)
+--E 853
+
+--S 854 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R             2 2        2      4   +-+ |          2  |   |          2
+--R         (32a c  - 16a b c + 2b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                            6 5           5 2 4           4 4 3          3 6 2
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                          2 8           10
+--R                    46080a b c - 2304a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                        4 4       3 2 3        6      8
+--R                  (1024a c  - 512a b c  + 32a b c - 4b )e
+--R             *
+--R                ROOT
+--R                                   6 5           5 2 4           4 4 3
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    3 6 2         2 8           10
+--R                           - 368640a b c  + 46080a b c - 2304a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                  2 3         2 2      4            2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)e x + (48a c  + 120a b c  + 15b c)d
+--R     + 
+--R                                         +-----------+
+--R               2 2        2      4   +-+ |          2
+--R         (- 32a c  + 16a b c - 2b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                              6 5           5 2 4           4 4 3          3 6 2
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                            2 8           10
+--R                    - 46080a b c + 2304a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                          4 4       3 2 3        6      8
+--R                  (- 1024a c  + 512a b c  - 32a b c + 4b )e
+--R             *
+--R                ROOT
+--R                                     6 5           5 2 4           4 4 3
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  3 6 2         2 8           10
+--R                           368640a b c  - 46080a b c + 2304a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                  2 3         2 2      4            2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)e x + (48a c  + 120a b c  + 15b c)d
+--R     + 
+--R                                       +-----------+
+--R             2 2        2      4   +-+ |          2
+--R         (32a c  - 16a b c + 2b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                              6 5           5 2 4           4 4 3          3 6 2
+--R                    - 2359296a c  + 2949120a b c  - 1474560a b c  + 368640a b c
+--R                  + 
+--R                            2 8           10
+--R                    - 46080a b c + 2304a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                        4 4       3 2 3        6      8
+--R                  (1024a c  - 512a b c  + 32a b c - 4b )e
+--R             *
+--R                ROOT
+--R                                     6 5           5 2 4           4 4 3
+--R                           - 2359296a c  + 2949120a b c  - 1474560a b c
+--R                         + 
+--R                                  3 6 2         2 8           10
+--R                           368640a b c  - 46080a b c + 2304a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                  2 3         2 2      4            2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)e x + (48a c  + 120a b c  + 15b c)d
+--R     + 
+--R                                                       +--------------------+
+--R                                         +-----------+ |   +-----------+
+--R               2 2        2      4   +-+ |          2  |   |          2
+--R         (- 32a c  + 16a b c - 2b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                            6 5           5 2 4           4 4 3          3 6 2
+--R                    2359296a c  - 2949120a b c  + 1474560a b c  - 368640a b c
+--R                  + 
+--R                          2 8           10
+--R                    46080a b c - 2304a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                          1
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                    2   2         3      5
+--R                720a b c  + 360a b c + 9b
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                            1
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                          4 4       3 2 3        6      8
+--R                  (- 1024a c  + 512a b c  - 32a b c + 4b )e
+--R             *
+--R                ROOT
+--R                                   6 5           5 2 4           4 4 3
+--R                           2359296a c  - 2949120a b c  + 1474560a b c
+--R                         + 
+--R                                    3 6 2         2 8           10
+--R                           - 368640a b c  + 46080a b c - 2304a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                 1
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                           2   2         3      5
+--R                       720a b c  + 360a b c + 9b
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                  2 3         2 2      4            2 3         2 2      4
+--R              (48a c  + 120a b c  + 15b c)e x + (48a c  + 120a b c  + 15b c)d
+--R     + 
+--R                                              +------------------+
+--R             +-----------+                    | +-----------+
+--R             |          2              2  +-+ | |          2
+--R         (6b\|- 4a c + b   - 12a c - 9b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                              +--------------------+
+--R             +-----------+                    |   +-----------+
+--R             |          2              2  +-+ |   |          2
+--R         (6b\|- 4a c + b   + 12a c + 9b )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                                   +--------------------+
+--R                                     +-----------+ |   +-----------+
+--R           2 2        2      4   +-+ |          2  |   |          2
+--R       (64a c  - 32a b c + 4b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 854
+
+--S 855 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 855
+
+)clear all
+
+--S 856 of 1057
+t0:=(d+e*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      3 3       2 2     2       3
+--R     e x  + 3d e x  + 3d e x + d
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 856
+
+--S 857 of 1057
+r0:=1/4*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)-_
+   3/4*b*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   3*b*c*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e)
+--R 
+--R
+--R   (2)
+--R                3 8 8        3   7 7          3 2      2 2  6 6
+--R           12b c e x  + 96b c d e x  + (336b c d  + 24b c )e x
+--R         + 
+--R                  3 3       2 2   5 5
+--R           (672b c d  + 144b c d)e x
+--R         + 
+--R                  3 4       2 2 2          2      3   4 4
+--R           (840b c d  + 360b c d  + 24a b c  + 12b c)e x
+--R         + 
+--R                  3 5       2 2 3           2      3     3 3
+--R           (672b c d  + 480b c d  + (96a b c  + 48b c)d)e x
+--R         + 
+--R                  3 6       2 2 4            2      3   2        2   2 2
+--R           (336b c d  + 360b c d  + (144a b c  + 72b c)d  + 24a b c)e x
+--R         + 
+--R                 3 7       2 2 5           2      3   3        2
+--R           (96b c d  + 144b c d  + (96a b c  + 48b c)d  + 48a b c d)e x
+--R         + 
+--R                3 8      2 2 6           2      3   4        2   2      2
+--R           12b c d  + 24b c d  + (24a b c  + 12b c)d  + 24a b c d  + 12a b c
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                 2 6 6        2   5 5           2 2     2   4 4
+--R           - 6b c e x  - 36b c d e x  + (- 90b c d  - 9b c)e x
+--R         + 
+--R                    2 3      2     3 3
+--R           (- 120b c d  - 36b c d)e x
+--R         + 
+--R                   2 4      2   2               3  2 2
+--R           (- 90b c d  - 54b c d  - 10a b c - 2b )e x
+--R         + 
+--R                   2 5      2   3                  3             2 6     2   4
+--R           (- 36b c d  - 36b c d  + (- 20a b c - 4b )d)e x - 6b c d  - 9b c d
+--R         + 
+--R                          3  2     2       2
+--R           (- 10a b c - 2b )d  - 8a c - a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  9 8        2 4         2 3      4 2    8 7
+--R         (64a c  - 32a b c  + 4b c )e x  + (512a c  - 256a b c  + 32b c )d e x
+--R       + 
+--R                2 4         2 3       4 2  2       2   3        3 2     5   7 6
+--R         ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                  2   3         3 2      5
+--R             (768a b c  - 384a b c  + 48b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (4480a c  - 2240a b c  + 280b c )d
+--R           + 
+--R                   2   3         3 2       5   2       3 3        4      6
+--R             (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4         2 3       4 2  6
+--R             (1792a c  - 896a b c  + 112b c )d
+--R           + 
+--R                   2   3         3 2       5   4        3 3         4       6  2
+--R             (1920a b c  - 960a b c  + 120b c)d  + (768a c  - 144a b c + 24b )d
+--R           + 
+--R                 3   2      2 3        5
+--R             128a b c  - 64a b c + 8a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  2 4         2 3      4 2  7
+--R             (512a c  - 256a b c  + 32b c )d
+--R           + 
+--R                  2   3         3 2      5   5        3 3        4       6  3
+--R             (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 2 4        2 3     4 2  8        2   3        3 2     5   6
+--R             (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2      2 3        5  2
+--R             (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                4 2      3 2      2 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3 8 8        3   7 7          3 2      2 2  6 6
+--R             6b c e x  + 48b c d e x  + (168b c d  + 12b c )e x
+--R           + 
+--R                    3 3      2 2   5 5
+--R             (336b c d  + 72b c d)e x
+--R           + 
+--R                    3 4       2 2 2          2     3   4 4
+--R             (420b c d  + 180b c d  + 12a b c  + 6b c)e x
+--R           + 
+--R                    3 5       2 2 3           2      3     3 3
+--R             (336b c d  + 240b c d  + (48a b c  + 24b c)d)e x
+--R           + 
+--R                    3 6       2 2 4           2      3   2        2   2 2
+--R             (168b c d  + 180b c d  + (72a b c  + 36b c)d  + 12a b c)e x
+--R           + 
+--R                   3 7      2 2 5           2      3   3        2
+--R             (48b c d  + 72b c d  + (48a b c  + 24b c)d  + 24a b c d)e x
+--R           + 
+--R                 3 8      2 2 6           2     3   4        2   2     2
+--R             6b c d  + 12b c d  + (12a b c  + 6b c)d  + 12a b c d  + 6a b c
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                   2 6 6        2   5 5           2 2     2   4 4
+--R             - 6b c e x  - 36b c d e x  + (- 90b c d  - 9b c)e x
+--R           + 
+--R                      2 3      2     3 3
+--R             (- 120b c d  - 36b c d)e x
+--R           + 
+--R                     2 4      2   2               3  2 2
+--R             (- 90b c d  - 54b c d  - 10a b c - 2b )e x
+--R           + 
+--R                     2 5      2   3                  3             2 6     2   4
+--R             (- 36b c d  - 36b c d  + (- 20a b c - 4b )d)e x - 6b c d  - 9b c d
+--R           + 
+--R                            3  2     2       2
+--R             (- 10a b c - 2b )d  - 8a c - a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    3 8 8        3   7 7            3 2      2 2  6 6
+--R             - 12b c e x  - 96b c d e x  + (- 336b c d  - 24b c )e x
+--R           + 
+--R                      3 3       2 2   5 5
+--R             (- 672b c d  - 144b c d)e x
+--R           + 
+--R                      3 4       2 2 2          2      3   4 4
+--R             (- 840b c d  - 360b c d  - 24a b c  - 12b c)e x
+--R           + 
+--R                      3 5       2 2 3             2      3     3 3
+--R             (- 672b c d  - 480b c d  + (- 96a b c  - 48b c)d)e x
+--R           + 
+--R                      3 6       2 2 4              2      3   2        2   2 2
+--R             (- 336b c d  - 360b c d  + (- 144a b c  - 72b c)d  - 24a b c)e x
+--R           + 
+--R                     3 7       2 2 5             2      3   3        2
+--R             (- 96b c d  - 144b c d  + (- 96a b c  - 48b c)d  - 48a b c d)e x
+--R           + 
+--R                  3 8      2 2 6             2      3   4        2   2      2
+--R           - 12b c d  - 24b c d  + (- 24a b c  - 12b c)d  - 24a b c d  - 12a b c
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                   2 6 6        2   5 5           2 2     2   4 4
+--R             - 6b c e x  - 36b c d e x  + (- 90b c d  - 9b c)e x
+--R           + 
+--R                      2 3      2     3 3
+--R             (- 120b c d  - 36b c d)e x
+--R           + 
+--R                     2 4      2   2               3  2 2
+--R             (- 90b c d  - 54b c d  - 10a b c - 2b )e x
+--R           + 
+--R                     2 5      2   3                  3             2 6     2   4
+--R             (- 36b c d  - 36b c d  + (- 20a b c - 4b )d)e x - 6b c d  - 9b c d
+--R           + 
+--R                            3  2     2       2
+--R             (- 10a b c - 2b )d  - 8a c - a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 858
+
+--S 859 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         3b c
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                        2 2                  2
+--R                    2c e x  + 4c d e x + 2c d  + b
+--R       - 6b c atanh(------------------------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R  /
+--R                               +-----------+
+--R         2 2        2      4   |          2
+--R     (32a c  - 16a b c + 2b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 859
+
+--S 860 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 860
+
+--S 861 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              +---------+          2 2                  2
+--R              |        2       2c e x  + 4c d e x + 2c d  + b
+--R       - 3b c\|4a c - b  atanh(------------------------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                                                                 +---------+
+--R              +-----------+          2 2                  2      |        2
+--R              |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       - 3b c\|- 4a c + b  atan(--------------------------------------------)
+--R                                                          2
+--R                                                  4a c - b
+--R  /
+--R                             +-----------+ +---------+
+--R         2 2       2     4   |          2  |        2
+--R     (16a c  - 8a b c + b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 861
+
+--S 862 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 862
+
+)clear all
+
+--S 863 of 1057
+t0:=(d+e*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      2 2             2
+--R     e x  + 2d e x + d
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 863
+
+--S 864 of 1057
+r0:=-1/4*(d+e*x)*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+_
+   e*x)^4)^2)+1/8*(d+e*x)*(b*(b^2+8*a*c)+c*(b^2+20*a*c)*(d+e*x)^2)/(a*_
+   (b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+1/8*atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b^2+20*a*c+b*(b^2-52*a*c)/_
+   sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   1/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (b^2+20*a*c-b*(b^2-52*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*e*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     3    2 2  8 8          3     2 2    7 7
+--R               (20a c  + b c )e x  + (160a c  + 8b c )d e x
+--R             + 
+--R                       3      2 2  2          2     3   6 6
+--R               ((560a c  + 28b c )d  + 40a b c  + 2b c)e x
+--R             + 
+--R                        3      2 2  3            2      3     5 5
+--R               ((1120a c  + 56b c )d  + (240a b c  + 12b c)d)e x
+--R             + 
+--R                           3      2 2  4            2      3   2      2 2
+--R                   (1400a c  + 70b c )d  + (600a b c  + 30b c)d  + 40a c
+--R                 + 
+--R                        2     4
+--R                   22a b c + b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           3      2 2  5            2      3   3
+--R                   (1120a c  + 56b c )d  + (800a b c  + 40b c)d
+--R                 + 
+--R                        2 2        2      4
+--R                   (160a c  + 88a b c + 4b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          3      2 2  6            2      3   4
+--R                   (560a c  + 28b c )d  + (600a b c  + 30b c)d
+--R                 + 
+--R                        2 2         2      4  2      2          3
+--R                   (240a c  + 132a b c + 6b )d  + 40a b c + 2a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          3     2 2  7            2      3   5
+--R                   (160a c  + 8b c )d  + (240a b c  + 12b c)d
+--R                 + 
+--R                        2 2        2      4  3       2          3
+--R                   (160a c  + 88a b c + 4b )d  + (80a b c + 4a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     3    2 2  8           2     3   6
+--R               (20a c  + b c )d  + (40a b c  + 2b c)d
+--R             + 
+--R                   2 2        2     4  4       2          3  2      3     2 2
+--R               (40a c  + 22a b c + b )d  + (40a b c + 2a b )d  + 20a c + a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     3    3 2  8 8              3     3 2    7 7
+--R           (- 52a b c  + b c )e x  + (- 416a b c  + 8b c )d e x
+--R         + 
+--R                        3      3 2  2         2 2     4   6 6
+--R           ((- 1456a b c  + 28b c )d  - 104a b c  + 2b c)e x
+--R         + 
+--R                        3      3 2  3            2 2      4     5 5
+--R           ((- 2912a b c  + 56b c )d  + (- 624a b c  + 12b c)d)e x
+--R         + 
+--R                           3      3 2  4             2 2      4   2       2   2
+--R               (- 3640a b c  + 70b c )d  + (- 1560a b c  + 30b c)d  - 104a b c
+--R             + 
+--R                      3     5
+--R               - 50a b c + b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                           3      3 2  5             2 2      4   3
+--R               (- 2912a b c  + 56b c )d  + (- 2080a b c  + 40b c)d
+--R             + 
+--R                      2   2         3      5
+--R               (- 416a b c  - 200a b c + 4b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                           3      3 2  6             2 2      4   4
+--R               (- 1456a b c  + 28b c )d  + (- 1560a b c  + 30b c)d
+--R             + 
+--R                      2   2         3      5  2       2 2        4
+--R               (- 624a b c  - 300a b c + 6b )d  - 104a b c + 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                          3     3 2  7            2 2      4   5
+--R               (- 416a b c  + 8b c )d  + (- 624a b c  + 12b c)d
+--R             + 
+--R                      2   2         3      5  3          2 2        4
+--R               (- 416a b c  - 200a b c + 4b )d  + (- 208a b c + 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R                     3    3 2  8            2 2     4   6
+--R           (- 52a b c  + b c )d  + (- 104a b c  + 2b c)d
+--R         + 
+--R                  2   2        3     5  4          2 2        4  2      3
+--R           (- 104a b c  - 50a b c + b )d  + (- 104a b c + 2a b )d  - 52a b c
+--R         + 
+--R            2 3
+--R           a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     3    2 2  8 8          3     2 2    7 7
+--R               (20a c  + b c )e x  + (160a c  + 8b c )d e x
+--R             + 
+--R                       3      2 2  2          2     3   6 6
+--R               ((560a c  + 28b c )d  + 40a b c  + 2b c)e x
+--R             + 
+--R                        3      2 2  3            2      3     5 5
+--R               ((1120a c  + 56b c )d  + (240a b c  + 12b c)d)e x
+--R             + 
+--R                           3      2 2  4            2      3   2      2 2
+--R                   (1400a c  + 70b c )d  + (600a b c  + 30b c)d  + 40a c
+--R                 + 
+--R                        2     4
+--R                   22a b c + b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           3      2 2  5            2      3   3
+--R                   (1120a c  + 56b c )d  + (800a b c  + 40b c)d
+--R                 + 
+--R                        2 2        2      4
+--R                   (160a c  + 88a b c + 4b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          3      2 2  6            2      3   4
+--R                   (560a c  + 28b c )d  + (600a b c  + 30b c)d
+--R                 + 
+--R                        2 2         2      4  2      2          3
+--R                   (240a c  + 132a b c + 6b )d  + 40a b c + 2a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          3     2 2  7            2      3   5
+--R                   (160a c  + 8b c )d  + (240a b c  + 12b c)d
+--R                 + 
+--R                        2 2        2      4  3       2          3
+--R                   (160a c  + 88a b c + 4b )d  + (80a b c + 4a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     3    2 2  8           2     3   6
+--R               (20a c  + b c )d  + (40a b c  + 2b c)d
+--R             + 
+--R                   2 2        2     4  4       2          3  2      3     2 2
+--R               (40a c  + 22a b c + b )d  + (40a b c + 2a b )d  + 20a c + a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3    3 2  8 8            3     3 2    7 7
+--R           (52a b c  - b c )e x  + (416a b c  - 8b c )d e x
+--R         + 
+--R                      3      3 2  2         2 2     4   6 6
+--R           ((1456a b c  - 28b c )d  + 104a b c  - 2b c)e x
+--R         + 
+--R                      3      3 2  3          2 2      4     5 5
+--R           ((2912a b c  - 56b c )d  + (624a b c  - 12b c)d)e x
+--R         + 
+--R                         3      3 2  4           2 2      4   2       2   2
+--R               (3640a b c  - 70b c )d  + (1560a b c  - 30b c)d  + 104a b c
+--R             + 
+--R                    3     5
+--R               50a b c - b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                         3      3 2  5           2 2      4   3
+--R               (2912a b c  - 56b c )d  + (2080a b c  - 40b c)d
+--R             + 
+--R                    2   2         3      5
+--R               (416a b c  + 200a b c - 4b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                         3      3 2  6           2 2      4   4
+--R               (1456a b c  - 28b c )d  + (1560a b c  - 30b c)d
+--R             + 
+--R                    2   2         3      5  2       2 2        4
+--R               (624a b c  + 300a b c - 6b )d  + 104a b c - 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        3     3 2  7          2 2      4   5
+--R               (416a b c  - 8b c )d  + (624a b c  - 12b c)d
+--R             + 
+--R                    2   2         3      5  3        2 2        4
+--R               (416a b c  + 200a b c - 4b )d  + (208a b c - 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   3    3 2  8          2 2     4   6
+--R           (52a b c  - b c )d  + (104a b c  - 2b c)d
+--R         + 
+--R                2   2        3     5  4        2 2        4  2      3       2 3
+--R           (104a b c  + 50a b c - b )d  + (104a b c - 2a b )d  + 52a b c - a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 3    2 2  7 7          3     2 2    6 6
+--R           (20a c  + b c )e x  + (140a c  + 7b c )d e x
+--R         + 
+--R                   3      2 2  2          2     3   5 5
+--R           ((420a c  + 21b c )d  + 28a b c  + 2b c)e x
+--R         + 
+--R                   3      2 2  3            2      3     4 4
+--R           ((700a c  + 35b c )d  + (140a b c  + 10b c)d)e x
+--R         + 
+--R                        3      2 2  4            2      3   2      2 2       2
+--R                 (700a c  + 35b c )d  + (280a b c  + 20b c)d  + 36a c  + 5a b c
+--R               + 
+--R                  4
+--R                 b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      3      2 2  5            2      3   3
+--R               (420a c  + 21b c )d  + (280a b c  + 20b c)d
+--R             + 
+--R                    2 2        2      4
+--R               (108a c  + 15a b c + 3b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3     2 2  6            2      3   4
+--R               (140a c  + 7b c )d  + (140a b c  + 10b c)d
+--R             + 
+--R                    2 2        2      4  2      2         3
+--R               (108a c  + 15a b c + 3b )d  + 16a b c - a b
+--R          *
+--R             e x
+--R         + 
+--R                 3    2 2  7           2     3   5       2 2       2     4  3
+--R           (20a c  + b c )d  + (28a b c  + 2b c)d  + (36a c  + 5a b c + b )d
+--R         + 
+--R               2         3
+--R           (16a b c - a b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              3 4      2 2 3       4 2  9 8
+--R         (128a c  - 64a b c  + 8a b c )e x
+--R       + 
+--R               3 4       2 2 3        4 2    8 7
+--R         (1024a c  - 512a b c  + 64a b c )d e x
+--R       + 
+--R                   3 4        2 2 3         4 2  2       3   3       2 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                  5
+--R             16a b c
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  3
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   3   3       2 3 2        5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  4
+--R             (8960a c  - 4480a b c  + 560a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   2       4 3      2 4        6
+--R             (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  5
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   3
+--R             (5120a b c  - 2560a b c  + 320a b c)d
+--R           + 
+--R                   4 3       2 4         6
+--R             (1024a c  - 192a b c + 32a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  6
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   4
+--R             (3840a b c  - 1920a b c  + 240a b c)d
+--R           + 
+--R                   4 3       2 4         6  2       4   2       3 3       2 5
+--R             (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   3 4       2 2 3        4 2  7
+--R             (1024a c  - 512a b c  + 64a b c )d
+--R           + 
+--R                   3   3       2 3 2        5   5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R           + 
+--R                 4 3       2 4         6  3        4   2       3 3       2 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  3 4      2 2 3       4 2  8
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  3   3       2 3 2        5   6        4 3      2 4        6  4
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  4   2       3 3       2 5  2       5 2      4 2      3 4
+--R             (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 864
+
+--S 865 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 4      2 2 3       4 2  9 8
+--R           (64a c  - 32a b c  + 4a b c )e x
+--R         + 
+--R                3 4       2 2 3        4 2    8 7
+--R           (512a c  - 256a b c  + 32a b c )d e x
+--R         + 
+--R                     3 4       2 2 3         4 2  2       3   3      2 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                   5
+--R               8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    3   3       2 3 2        5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   3   3       2 3 2         5   2       4 3      2 4        6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     3   3        2 3 2         5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    4 3      2 4         6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     3 4       2 2 3         4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     3   3       2 3 2         5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    4 3       2 4         6  2       4   2      3 3      2 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    3 4       2 2 3        4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    3   3       2 3 2        5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  4 3      2 4         6  3        4   2       3 3       2 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   3 4      2 2 3       4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    3   3      2 3 2       5   6        4 3      2 4        6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    4   2      3 3      2 5  2      5 2      4 2      3 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               5   5         4 3 4         3 5 3        2 7 2
+--R                      - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                    + 
+--R                              9      11
+--R                      - 212a b c + 4b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d
+--R     + 
+--R                 3 4      2 2 3       4 2  9 8
+--R           (- 64a c  + 32a b c  - 4a b c )e x
+--R         + 
+--R                  3 4       2 2 3        4 2    8 7
+--R           (- 512a c  + 256a b c  - 32a b c )d e x
+--R         + 
+--R                       3 4       2 2 3         4 2  2       3   3      2 3 2
+--R               (- 1792a c  + 896a b c  - 112a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                     5
+--R               - 8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  3
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                      3   3       2 3 2        5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  4
+--R               (- 4480a c  + 2240a b c  - 280a b c )d
+--R             + 
+--R                     3   3       2 3 2         5   2       4 3      2 4        6
+--R             (- 1920a b c  + 960a b c  - 120a b c)d  - 128a c  + 24a b c - 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  5
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   3
+--R               (- 2560a b c  + 1280a b c  - 160a b c)d
+--R             + 
+--R                      4 3      2 4         6
+--R               (- 512a c  + 96a b c - 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       3 4       2 2 3         4 2  6
+--R               (- 1792a c  + 896a b c  - 112a b c )d
+--R             + 
+--R                       3   3       2 3 2         5   4
+--R               (- 1920a b c  + 960a b c  - 120a b c)d
+--R             + 
+--R                      4 3       2 4         6  2       4   2      3 3      2 5
+--R               (- 768a c  + 144a b c - 24a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      3 4       2 2 3        4 2  7
+--R               (- 512a c  + 256a b c  - 32a b c )d
+--R             + 
+--R                      3   3       2 3 2        5   5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R             + 
+--R                      4 3      2 4         6  3
+--R               (- 512a c  + 96a b c - 16a b )d
+--R             + 
+--R                      4   2       3 3       2 5
+--R               (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     3 4      2 2 3       4 2  8
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      3   3      2 3 2       5   6
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      4 3      2 4        6  4
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                      4   2      3 3      2 5  2      5 2      4 2      3 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                    + 
+--R                            9      11
+--R                      212a b c - 4b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d
+--R     + 
+--R               3 4      2 2 3       4 2  9 8
+--R           (64a c  - 32a b c  + 4a b c )e x
+--R         + 
+--R                3 4       2 2 3        4 2    8 7
+--R           (512a c  - 256a b c  + 32a b c )d e x
+--R         + 
+--R                     3 4       2 2 3         4 2  2       3   3      2 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                   5
+--R               8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    3   3       2 3 2        5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   3   3       2 3 2         5   2       4 3      2 4        6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     3   3        2 3 2         5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    4 3      2 4         6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     3 4       2 2 3         4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     3   3       2 3 2         5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    4 3       2 4         6  2       4   2      3 3      2 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    3 4       2 2 3        4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    3   3       2 3 2        5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  4 3      2 4         6  3        4   2       3 3       2 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   3 4      2 2 3       4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    3   3      2 3 2       5   6        4 3      2 4        6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    4   2      3 3      2 5  2      5 2      4 2      3 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               5   5         4 3 4         3 5 3        2 7 2
+--R                      - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                    + 
+--R                              9      11
+--R                      - 212a b c + 4b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d
+--R     + 
+--R                 3 4      2 2 3       4 2  9 8
+--R           (- 64a c  + 32a b c  - 4a b c )e x
+--R         + 
+--R                  3 4       2 2 3        4 2    8 7
+--R           (- 512a c  + 256a b c  - 32a b c )d e x
+--R         + 
+--R                       3 4       2 2 3         4 2  2       3   3      2 3 2
+--R               (- 1792a c  + 896a b c  - 112a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                     5
+--R               - 8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  3
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                      3   3       2 3 2        5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  4
+--R               (- 4480a c  + 2240a b c  - 280a b c )d
+--R             + 
+--R                     3   3       2 3 2         5   2       4 3      2 4        6
+--R             (- 1920a b c  + 960a b c  - 120a b c)d  - 128a c  + 24a b c - 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  5
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   3
+--R               (- 2560a b c  + 1280a b c  - 160a b c)d
+--R             + 
+--R                      4 3      2 4         6
+--R               (- 512a c  + 96a b c - 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       3 4       2 2 3         4 2  6
+--R               (- 1792a c  + 896a b c  - 112a b c )d
+--R             + 
+--R                       3   3       2 3 2         5   4
+--R               (- 1920a b c  + 960a b c  - 120a b c)d
+--R             + 
+--R                      4 3       2 4         6  2       4   2      3 3      2 5
+--R               (- 768a c  + 144a b c - 24a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      3 4       2 2 3        4 2  7
+--R               (- 512a c  + 256a b c  - 32a b c )d
+--R             + 
+--R                      3   3       2 3 2        5   5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R             + 
+--R                      4 3      2 4         6  3
+--R               (- 512a c  + 96a b c - 16a b )d
+--R             + 
+--R                      4   2       3 3       2 5
+--R               (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     3 4      2 2 3       4 2  8
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      3   3      2 3 2       5   6
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      4 3      2 4        6  4
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                      4   2      3 3      2 5  2      5 2      4 2      3 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                    + 
+--R                            9      11
+--R                      212a b c - 4b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d
+--R     + 
+--R             3    2 2  7 7          3     2 2    6 6
+--R       (20a c  + b c )e x  + (140a c  + 7b c )d e x
+--R     + 
+--R               3      2 2  2          2     3   5 5
+--R       ((420a c  + 21b c )d  + 28a b c  + 2b c)e x
+--R     + 
+--R               3      2 2  3            2      3     4 4
+--R       ((700a c  + 35b c )d  + (140a b c  + 10b c)d)e x
+--R     + 
+--R               3      2 2  4            2      3   2      2 2       2     4  3 3
+--R       ((700a c  + 35b c )d  + (280a b c  + 20b c)d  + 36a c  + 5a b c + b )e x
+--R     + 
+--R                  3      2 2  5            2      3   3
+--R           (420a c  + 21b c )d  + (280a b c  + 20b c)d
+--R         + 
+--R                2 2        2      4
+--R           (108a c  + 15a b c + 3b )d
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R                  3     2 2  6            2      3   4
+--R           (140a c  + 7b c )d  + (140a b c  + 10b c)d
+--R         + 
+--R                2 2        2      4  2      2         3
+--R           (108a c  + 15a b c + 3b )d  + 16a b c - a b
+--R      *
+--R         e x
+--R     + 
+--R             3    2 2  7           2     3   5       2 2       2     4  3
+--R       (20a c  + b c )d  + (28a b c  + 2b c)d  + (36a c  + 5a b c + b )d
+--R     + 
+--R           2         3
+--R       (16a b c - a b )d
+--R  /
+--R            3 4      2 2 3       4 2  9 8
+--R       (128a c  - 64a b c  + 8a b c )e x
+--R     + 
+--R             3 4       2 2 3        4 2    8 7
+--R       (1024a c  - 512a b c  + 64a b c )d e x
+--R     + 
+--R                   3 4        2 2 3         4 2  2       3   3       2 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                  5
+--R             16a b c
+--R      *
+--R          7 6
+--R         e x
+--R     + 
+--R                 3 4        2 2 3         4 2  3
+--R           (7168a c  - 3584a b c  + 448a b c )d
+--R         + 
+--R                 3   3       2 3 2        5
+--R           (1536a b c  - 768a b c  + 96a b c)d
+--R      *
+--R          6 5
+--R         e x
+--R     + 
+--R                 3 4        2 2 3         4 2  4
+--R           (8960a c  - 4480a b c  + 560a b c )d
+--R         + 
+--R                 3   3        2 3 2         5   2       4 3      2 4        6
+--R           (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R      *
+--R          5 4
+--R         e x
+--R     + 
+--R                 3 4        2 2 3         4 2  5
+--R           (7168a c  - 3584a b c  + 448a b c )d
+--R         + 
+--R                 3   3        2 3 2         5   3
+--R           (5120a b c  - 2560a b c  + 320a b c)d
+--R         + 
+--R                 4 3       2 4         6
+--R           (1024a c  - 192a b c + 32a b )d
+--R      *
+--R          4 3
+--R         e x
+--R     + 
+--R                 3 4        2 2 3         4 2  6
+--R           (3584a c  - 1792a b c  + 224a b c )d
+--R         + 
+--R                 3   3        2 3 2         5   4
+--R           (3840a b c  - 1920a b c  + 240a b c)d
+--R         + 
+--R                 4 3       2 4         6  2       4   2       3 3       2 5
+--R           (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R      *
+--R          3 2
+--R         e x
+--R     + 
+--R                 3 4       2 2 3        4 2  7
+--R           (1024a c  - 512a b c  + 64a b c )d
+--R         + 
+--R                 3   3       2 3 2        5   5
+--R           (1536a b c  - 768a b c  + 96a b c)d
+--R         + 
+--R                 4 3       2 4         6  3        4   2       3 3       2 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R      *
+--R          2
+--R         e x
+--R     + 
+--R                3 4      2 2 3       4 2  8
+--R           (128a c  - 64a b c  + 8a b c )d
+--R         + 
+--R                3   3       2 3 2        5   6        4 3      2 4        6  4
+--R           (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R      *
+--R         e
+--R                                         Type: Union(Expression(Integer),...)
+--E 865
+
+--S 866 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                       +--------------------+
+--R                                         +-----------+ |   +-----------+
+--R             3 2      2 2        4   +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               5   5         4 3 4         3 5 3        2 7 2
+--R                      - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                    + 
+--R                              9      11
+--R                      - 212a b c + 4b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d
+--R     + 
+--R                                           +-----------+
+--R               3 2      2 2        4   +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                    + 
+--R                            9      11
+--R                      212a b c - 4b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d
+--R     + 
+--R                                         +-----------+
+--R             3 2      2 2        4   +-+ |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               5   5         4 3 4         3 5 3        2 7 2
+--R                      - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                    + 
+--R                              9      11
+--R                      - 212a b c + 4b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d
+--R     + 
+--R                                                         +--------------------+
+--R                                           +-----------+ |   +-----------+
+--R               3 2      2 2        4   +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                             2 2        2     4
+--R                       - 625a c  + 50a b c - b
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                     3   3       2 3 2        5     7
+--R                1680a b c  + 280a b c  - 35a b c + b
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                               2 2        2     4
+--R                         - 625a c  + 50a b c - b
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                    + 
+--R                            9      11
+--R                      212a b c - 4b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                    2 2        2     4
+--R                              - 625a c  + 50a b c - b
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                            3   3       2 3 2        5     7
+--R                       1680a b c  + 280a b c  - 35a b c + b
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d
+--R     + 
+--R                                                           +------------------+
+--R                         +-----------+                     | +-----------+
+--R                      2  |          2               3  +-+ | |          2
+--R         ((- 20a c - b )\|- 4a c + b   + 52a b c - b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                         +-----------+
+--R                      2  |          2               3  +-+
+--R         ((- 20a c - b )\|- 4a c + b   - 52a b c + b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R            3 2      2 2        4   +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 867
+
+)clear all
+
+--S 868 of 1057
+t0:=(d+e*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R     e x + d
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 868
+
+--S 869 of 1057
+r0:=1/4*(-b-2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)+_
+   3/2*c*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   6*c^2*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e)
+--R 
+--R
+--R   (2)
+--R                4 8 8       4   7 7          4 2        3  6 6
+--R           - 24c e x  - 192c d e x  + (- 672c d  - 48b c )e x
+--R         + 
+--R                   4 3         3   5 5
+--R           (- 1344c d  - 288b c d)e x
+--R         + 
+--R                   4 4         3 2        3      2 2  4 4
+--R           (- 1680c d  - 720b c d  - 48a c  - 24b c )e x
+--R         + 
+--R                   4 5         3 3            3      2 2    3 3
+--R           (- 1344c d  - 960b c d  + (- 192a c  - 96b c )d)e x
+--R         + 
+--R                  4 6         3 4            3       2 2  2          2  2 2
+--R           (- 672c d  - 720b c d  + (- 288a c  - 144b c )d  - 48a b c )e x
+--R         + 
+--R                  4 7         3 5            3      2 2  3          2
+--R           (- 192c d  - 288b c d  + (- 192a c  - 96b c )d  - 96a b c d)e x
+--R         + 
+--R                4 8        3 6           3      2 2  4          2 2      2 2
+--R           - 24c d  - 48b c d  + (- 48a c  - 24b c )d  - 48a b c d  - 24a c
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R              3 6 6      3   5 5        3 2        2  4 4
+--R           12c e x  + 72c d e x  + (180c d  + 18b c )e x
+--R         + 
+--R                3 3        2   3 3        3 4         2 2        2     2   2 2
+--R           (240c d  + 72b c d)e x  + (180c d  + 108b c d  + 20a c  + 4b c)e x
+--R         + 
+--R               3 5        2 3         2     2             3 6        2 4
+--R           (72c d  + 72b c d  + (40a c  + 8b c)d)e x + 12c d  + 18b c d
+--R         + 
+--R                 2     2   2              3
+--R           (20a c  + 4b c)d  + 10a b c - b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  9 8        2 4         2 3      4 2    8 7
+--R         (64a c  - 32a b c  + 4b c )e x  + (512a c  - 256a b c  + 32b c )d e x
+--R       + 
+--R                2 4         2 3       4 2  2       2   3        3 2     5   7 6
+--R         ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                  2   3         3 2      5
+--R             (768a b c  - 384a b c  + 48b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (4480a c  - 2240a b c  + 280b c )d
+--R           + 
+--R                   2   3         3 2       5   2       3 3        4      6
+--R             (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4         2 3       4 2  6
+--R             (1792a c  - 896a b c  + 112b c )d
+--R           + 
+--R                   2   3         3 2       5   4        3 3         4       6  2
+--R             (1920a b c  - 960a b c  + 120b c)d  + (768a c  - 144a b c + 24b )d
+--R           + 
+--R                 3   2      2 3        5
+--R             128a b c  - 64a b c + 8a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  2 4         2 3      4 2  7
+--R             (512a c  - 256a b c  + 32b c )d
+--R           + 
+--R                  2   3         3 2      5   5        3 3        4       6  3
+--R             (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 2 4        2 3     4 2  8        2   3        3 2     5   6
+--R             (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2      2 3        5  2
+--R             (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                4 2      3 2      2 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 869
+
+--S 870 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                4 8 8      4   7 7        4 2        3  6 6
+--R             12c e x  + 96c d e x  + (336c d  + 24b c )e x
+--R           + 
+--R                  4 3         3   5 5
+--R             (672c d  + 144b c d)e x
+--R           + 
+--R                  4 4         3 2        3      2 2  4 4
+--R             (840c d  + 360b c d  + 24a c  + 12b c )e x
+--R           + 
+--R                  4 5         3 3         3      2 2    3 3
+--R             (672c d  + 480b c d  + (96a c  + 48b c )d)e x
+--R           + 
+--R                  4 6         3 4          3      2 2  2          2  2 2
+--R             (336c d  + 360b c d  + (144a c  + 72b c )d  + 24a b c )e x
+--R           + 
+--R                 4 7         3 5         3      2 2  3          2           4 8
+--R             (96c d  + 144b c d  + (96a c  + 48b c )d  + 48a b c d)e x + 12c d
+--R           + 
+--R                  3 6         3      2 2  4          2 2      2 2
+--R             24b c d  + (24a c  + 12b c )d  + 24a b c d  + 12a c
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                       2     2   2 2         2     2               2     2   2
+--R                  (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                3 6 6      3   5 5        3 2        2  4 4
+--R             12c e x  + 72c d e x  + (180c d  + 18b c )e x
+--R           + 
+--R                  3 3        2   3 3        3 4         2 2        2     2   2 2
+--R             (240c d  + 72b c d)e x  + (180c d  + 108b c d  + 20a c  + 4b c)e x
+--R           + 
+--R                 3 5        2 3         2     2             3 6        2 4
+--R             (72c d  + 72b c d  + (40a c  + 8b c)d)e x + 12c d  + 18b c d
+--R           + 
+--R                   2     2   2              3
+--R             (20a c  + 4b c)d  + 10a b c - b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                4 8 8       4   7 7        4 2        3  6 6
+--R             24c e x  + 192c d e x  + (672c d  + 48b c )e x
+--R           + 
+--R                   4 3         3   5 5
+--R             (1344c d  + 288b c d)e x
+--R           + 
+--R                   4 4         3 2        3      2 2  4 4
+--R             (1680c d  + 720b c d  + 48a c  + 24b c )e x
+--R           + 
+--R                   4 5         3 3          3      2 2    3 3
+--R             (1344c d  + 960b c d  + (192a c  + 96b c )d)e x
+--R           + 
+--R                  4 6         3 4          3       2 2  2          2  2 2
+--R             (672c d  + 720b c d  + (288a c  + 144b c )d  + 48a b c )e x
+--R           + 
+--R                  4 7         3 5          3      2 2  3          2
+--R             (192c d  + 288b c d  + (192a c  + 96b c )d  + 96a b c d)e x
+--R           + 
+--R                4 8        3 6         3      2 2  4          2 2      2 2
+--R             24c d  + 48b c d  + (48a c  + 24b c )d  + 48a b c d  + 24a c
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                3 6 6      3   5 5        3 2        2  4 4
+--R             12c e x  + 72c d e x  + (180c d  + 18b c )e x
+--R           + 
+--R                  3 3        2   3 3        3 4         2 2        2     2   2 2
+--R             (240c d  + 72b c d)e x  + (180c d  + 108b c d  + 20a c  + 4b c)e x
+--R           + 
+--R                 3 5        2 3         2     2             3 6        2 4
+--R             (72c d  + 72b c d  + (40a c  + 8b c)d)e x + 12c d  + 18b c d
+--R           + 
+--R                   2     2   2              3
+--R             (20a c  + 4b c)d  + 10a b c - b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 870
+
+--S 871 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           2
+--R         3c
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                     2     2   2 2         2     2               2     2   2
+--R                (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                    2 2                  2
+--R         2      2c e x  + 4c d e x + 2c d  + b
+--R       6c atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R  /
+--R                             +-----------+
+--R         2 2       2     4   |          2
+--R     (16a c  - 8a b c + b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 871
+
+--S 872 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+          2 2                  2
+--R         2 |        2       2c e x  + 4c d e x + 2c d  + b
+--R       6c \|4a c - b  atanh(------------------------------)
+--R                                     +-----------+
+--R                                     |          2
+--R                                    \|- 4a c + b
+--R     + 
+--R                                                              +---------+
+--R           +-----------+          2 2                  2      |        2
+--R         2 |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       6c \|- 4a c + b  atan(--------------------------------------------)
+--R                                                       2
+--R                                               4a c - b
+--R  /
+--R                             +-----------+ +---------+
+--R         2 2       2     4   |          2  |        2
+--R     (16a c  - 8a b c + b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 873
+
+--S 874 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 874
+
+)clear all
+
+--S 875 of 1057
+t0:=1/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 875
+
+--S 876 of 1057
+r0:=1/4*(d+e*x)*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/8*(d+e*x)*((b^2-7*a*c)*(3*b^2-4*a*c)+3*b*c*(b^2-8*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (b^3-8*a*b*c+(b^4-10*a*b^2*c+56*a^2*c^2)/sqrt(b^2-4*a*c))/(a^2*_
+   (b^2-4*a*c)^2*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+3/8*atan((d+e*x)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b^3-8*a*b*c+(-b^4+_
+   10*a*b^2*c-56*a^2*c^2)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^2*e*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                         3     3 2  8 8              3      3 2    7 7
+--R               (- 24a b c  + 3b c )e x  + (- 192a b c  + 24b c )d e x
+--R             + 
+--R                           3      3 2  2        2 2     4   6 6
+--R               ((- 672a b c  + 84b c )d  - 48a b c  + 6b c)e x
+--R             + 
+--R                            3       3 2  3            2 2      4     5 5
+--R               ((- 1344a b c  + 168b c )d  + (- 288a b c  + 36b c)d)e x
+--R             + 
+--R                               3       3 2  4            2 2      4   2
+--R                   (- 1680a b c  + 210b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                        2   2        3      5
+--R                   - 48a b c  - 18a b c + 3b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                               3       3 2  5            2 2       4   3
+--R                   (- 1344a b c  + 168b c )d  + (- 960a b c  + 120b c)d
+--R                 + 
+--R                          2   2        3       5
+--R                   (- 192a b c  - 72a b c + 12b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                              3      3 2  6            2 2      4   4
+--R                   (- 672a b c  + 84b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                          2   2         3       5  2      2 2        4
+--R                   (- 288a b c  - 108a b c + 18b )d  - 48a b c + 6a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                              3      3 2  7            2 2      4   5
+--R                   (- 192a b c  + 24b c )d  + (- 288a b c  + 36b c)d
+--R                 + 
+--R                          2   2        3       5  3         2 2         4
+--R                   (- 192a b c  - 72a b c + 12b )d  + (- 96a b c + 12a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )d  + (- 48a b c  + 6b c)d
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )d  + (- 48a b c + 6a b )d  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4        2 3     4 2  8 8
+--R           (168a c  - 30a b c  + 3b c )e x
+--R         + 
+--R                 2 4         2 3      4 2    7 7
+--R           (1344a c  - 240a b c  + 24b c )d e x
+--R         + 
+--R                  2 4         2 3      4 2  2       2   3        3 2     5   6 6
+--R           ((4704a c  - 840a b c  + 84b c )d  + 336a b c  - 60a b c  + 6b c)e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (9408a c  - 1680a b c  + 168b c )d
+--R             + 
+--R                     2   3         3 2      5
+--R               (2016a b c  - 360a b c  + 36b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      2 4          2 3       4 2  4
+--R               (11760a c  - 2100a b c  + 210b c )d
+--R             + 
+--R                     2   3         3 2      5   2       3 3       2 2 2
+--R               (5040a b c  - 900a b c  + 90b c)d  + 336a c  + 108a b c
+--R             + 
+--R                      4      6
+--R               - 24a b c + 3b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (9408a c  - 1680a b c  + 168b c )d
+--R             + 
+--R                     2   3          3 2       5   3
+--R               (6720a b c  - 1200a b c  + 120b c)d
+--R             + 
+--R                     3 3       2 2 2        4       6
+--R               (1344a c  + 432a b c  - 96a b c + 12b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2 4         2 3      4 2  6
+--R               (4704a c  - 840a b c  + 84b c )d
+--R             + 
+--R                     2   3         3 2      5   4
+--R               (5040a b c  - 900a b c  + 90b c)d
+--R             + 
+--R                     3 3       2 2 2         4       6  2       3   2      2 3
+--R               (2016a c  + 648a b c  - 144a b c + 18b )d  + 336a b c  - 60a b c
+--R             + 
+--R                   5
+--R               6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2 4         2 3      4 2  7
+--R               (1344a c  - 240a b c  + 24b c )d
+--R             + 
+--R                     2   3         3 2      5   5
+--R               (2016a b c  - 360a b c  + 36b c)d
+--R             + 
+--R                     3 3       2 2 2        4       6  3
+--R               (1344a c  + 432a b c  - 96a b c + 12b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (672a b c  - 120a b c + 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (168a c  - 30a b c  + 3b c )d  + (336a b c  - 60a b c  + 6b c)d
+--R         + 
+--R                3 3       2 2 2        4      6  4
+--R           (336a c  + 108a b c  - 24a b c + 3b )d
+--R         + 
+--R                3   2      2 3        5  2       4 2      3 2      2 4
+--R           (336a b c  - 60a b c + 6a b )d  + 168a c  - 30a b c + 3a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                         3     3 2  8 8              3      3 2    7 7
+--R               (- 24a b c  + 3b c )e x  + (- 192a b c  + 24b c )d e x
+--R             + 
+--R                           3      3 2  2        2 2     4   6 6
+--R               ((- 672a b c  + 84b c )d  - 48a b c  + 6b c)e x
+--R             + 
+--R                            3       3 2  3            2 2      4     5 5
+--R               ((- 1344a b c  + 168b c )d  + (- 288a b c  + 36b c)d)e x
+--R             + 
+--R                               3       3 2  4            2 2      4   2
+--R                   (- 1680a b c  + 210b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                        2   2        3      5
+--R                   - 48a b c  - 18a b c + 3b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                               3       3 2  5            2 2       4   3
+--R                   (- 1344a b c  + 168b c )d  + (- 960a b c  + 120b c)d
+--R                 + 
+--R                          2   2        3       5
+--R                   (- 192a b c  - 72a b c + 12b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                              3      3 2  6            2 2      4   4
+--R                   (- 672a b c  + 84b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                          2   2         3       5  2      2 2        4
+--R                   (- 288a b c  - 108a b c + 18b )d  - 48a b c + 6a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                              3      3 2  7            2 2      4   5
+--R                   (- 192a b c  + 24b c )d  + (- 288a b c  + 36b c)d
+--R                 + 
+--R                          2   2        3       5  3         2 2         4
+--R                   (- 192a b c  - 72a b c + 12b )d  + (- 96a b c + 12a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )d  + (- 48a b c  + 6b c)d
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )d  + (- 48a b c + 6a b )d  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4        2 3     4 2  8 8
+--R           (- 168a c  + 30a b c  - 3b c )e x
+--R         + 
+--R                   2 4         2 3      4 2    7 7
+--R           (- 1344a c  + 240a b c  - 24b c )d e x
+--R         + 
+--R                      2 4         2 3      4 2  2       2   3        3 2     5
+--R             ((- 4704a c  + 840a b c  - 84b c )d  - 336a b c  + 60a b c  - 6b c)
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  3
+--R               (- 9408a c  + 1680a b c  - 168b c )d
+--R             + 
+--R                       2   3         3 2      5
+--R               (- 2016a b c  + 360a b c  - 36b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  4
+--R               (- 11760a c  + 2100a b c  - 210b c )d
+--R             + 
+--R                       2   3         3 2      5   2       3 3       2 2 2
+--R               (- 5040a b c  + 900a b c  - 90b c)d  - 336a c  - 108a b c
+--R             + 
+--R                    4      6
+--R               24a b c - 3b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  5
+--R               (- 9408a c  + 1680a b c  - 168b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 6720a b c  + 1200a b c  - 120b c)d
+--R             + 
+--R                       3 3       2 2 2        4       6
+--R               (- 1344a c  - 432a b c  + 96a b c - 12b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 4         2 3      4 2  6
+--R               (- 4704a c  + 840a b c  - 84b c )d
+--R             + 
+--R                       2   3         3 2      5   4
+--R               (- 5040a b c  + 900a b c  - 90b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  2       3   2
+--R               (- 2016a c  - 648a b c  + 144a b c - 18b )d  - 336a b c
+--R             + 
+--R                  2 3        5
+--R               60a b c - 6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2 4         2 3      4 2  7
+--R               (- 1344a c  + 240a b c  - 24b c )d
+--R             + 
+--R                       2   3         3 2      5   5
+--R               (- 2016a b c  + 360a b c  - 36b c)d
+--R             + 
+--R                       3 3       2 2 2        4       6  3
+--R               (- 1344a c  - 432a b c  + 96a b c - 12b )d
+--R             + 
+--R                      3   2       2 3         5
+--R               (- 672a b c  + 120a b c - 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                  2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 168a c  + 30a b c  - 3b c )d  + (- 336a b c  + 60a b c  - 6b c)d
+--R         + 
+--R                  3 3       2 2 2        4      6  4
+--R           (- 336a c  - 108a b c  + 24a b c - 3b )d
+--R         + 
+--R                  3   2      2 3        5  2       4 2      3 2      2 4
+--R           (- 336a b c  + 60a b c - 6a b )d  - 168a c  + 30a b c - 3a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                     3     3 2  7 7              3      3 2    6 6
+--R           (- 24a b c  + 3b c )e x  + (- 168a b c  + 21b c )d e x
+--R         + 
+--R                       3      3 2  2      2 3        2 2     4   5 5
+--R           ((- 504a b c  + 63b c )d  + 28a c  - 49a b c  + 6b c)e x
+--R         + 
+--R                       3       3 2  3        2 3         2 2      4     4 4
+--R           ((- 840a b c  + 105b c )d  + (140a c  - 245a b c  + 30b c)d)e x
+--R         + 
+--R                          3       3 2  4        2 3         2 2      4   2
+--R               (- 840a b c  + 105b c )d  + (280a c  - 490a b c  + 60b c)d
+--R             + 
+--R                   2   2        3      5
+--R               - 4a b c  - 20a b c + 3b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                          3      3 2  5        2 3         2 2      4   3
+--R               (- 504a b c  + 63b c )d  + (280a c  - 490a b c  + 60b c)d
+--R             + 
+--R                     2   2        3      5
+--R               (- 12a b c  - 60a b c + 9b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                          3      3 2  6        2 3         2 2      4   4
+--R               (- 168a b c  + 21b c )d  + (140a c  - 245a b c  + 30b c)d
+--R             + 
+--R                     2   2        3      5  2      3 2      2 2        4
+--R               (- 12a b c  - 60a b c + 9b )d  + 44a c  - 37a b c + 5a b
+--R          *
+--R             e x
+--R         + 
+--R                     3     3 2  7       2 3        2 2     4   5
+--R           (- 24a b c  + 3b c )d  + (28a c  - 49a b c  + 6b c)d
+--R         + 
+--R                2   2        3      5  3       3 2      2 2        4
+--R           (- 4a b c  - 20a b c + 3b )d  + (44a c  - 37a b c + 5a b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              4 4      3 2 3     2 4 2  9 8
+--R         (128a c  - 64a b c  + 8a b c )e x
+--R       + 
+--R               4 4       3 2 3      2 4 2    8 7
+--R         (1024a c  - 512a b c  + 64a b c )d e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  2       4   3       3 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                2 5
+--R             16a b c
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  3
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   4   3       3 3 2      2 5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  4
+--R             (8960a c  - 4480a b c  + 560a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   2       5 3      3 4      2 6
+--R             (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  5
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   3
+--R             (5120a b c  - 2560a b c  + 320a b c)d
+--R           + 
+--R                   5 3       3 4       2 6
+--R             (1024a c  - 192a b c + 32a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  6
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   4
+--R             (3840a b c  - 1920a b c  + 240a b c)d
+--R           + 
+--R                   5 3       3 4       2 6  2       5   2       4 3       3 5
+--R             (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   4 4       3 2 3      2 4 2  7
+--R             (1024a c  - 512a b c  + 64a b c )d
+--R           + 
+--R                   4   3       3 3 2      2 5   5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R           + 
+--R                 5 3       3 4       2 6  3        5   2       4 3       3 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  4 4      3 2 3     2 4 2  8
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  4   3       3 3 2      2 5   6        5 3      3 4      2 6  4
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  5   2       4 3       3 5  2       6 2      5 2      4 4
+--R             (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 876
+
+--S 877 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 4      3 2 3     2 4 2  9 8
+--R           (64a c  - 32a b c  + 4a b c )e x
+--R         + 
+--R                4 4       3 2 3      2 4 2    8 7
+--R           (512a c  - 256a b c  + 32a b c )d e x
+--R         + 
+--R                     4 4       3 2 3       2 4 2  2       4   3      3 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 2 5
+--R               8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    4   3       3 3 2      2 5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   4   3       3 3 2       2 5   2       5 3      3 4      2 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     4   3        3 3 2       2 5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    5 3      3 4       2 6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     4 4       3 2 3       2 4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     4   3       3 3 2       2 5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    5 3       3 4       2 6  2       5   2      4 3      3 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    4 4       3 2 3      2 4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    4   3       3 3 2      2 5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  5 3      3 4       2 6  3        5   2       4 3       3 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   4 4      3 2 3     2 4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    4   3      3 3 2     2 5   6        5 3      3 4      2 6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    5   2      4 3      3 5  2      6 2      5 2      4 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                              7 7           6 2 6           5 4 5          4 6 4
+--R                      3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                    + 
+--R                             3 8 3         2 10 2          12       14
+--R                      139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                 4 4      3 2 3     2 4 2  9 8
+--R           (- 64a c  + 32a b c  - 4a b c )e x
+--R         + 
+--R                  4 4       3 2 3      2 4 2    8 7
+--R           (- 512a c  + 256a b c  - 32a b c )d e x
+--R         + 
+--R                       4 4       3 2 3       2 4 2  2       4   3      3 3 2
+--R               (- 1792a c  + 896a b c  - 112a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                   2 5
+--R               - 8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  3
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                      4   3       3 3 2      2 5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  4
+--R               (- 4480a c  + 2240a b c  - 280a b c )d
+--R             + 
+--R                     4   3       3 3 2       2 5   2       5 3      3 4      2 6
+--R             (- 1920a b c  + 960a b c  - 120a b c)d  - 128a c  + 24a b c - 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  5
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                       4   3        3 3 2       2 5   3
+--R               (- 2560a b c  + 1280a b c  - 160a b c)d
+--R             + 
+--R                      5 3      3 4       2 6
+--R               (- 512a c  + 96a b c - 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       4 4       3 2 3       2 4 2  6
+--R               (- 1792a c  + 896a b c  - 112a b c )d
+--R             + 
+--R                       4   3       3 3 2       2 5   4
+--R               (- 1920a b c  + 960a b c  - 120a b c)d
+--R             + 
+--R                      5 3       3 4       2 6  2       5   2      4 3      3 5
+--R               (- 768a c  + 144a b c - 24a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      4 4       3 2 3      2 4 2  7
+--R               (- 512a c  + 256a b c  - 32a b c )d
+--R             + 
+--R                      4   3       3 3 2      2 5   5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R             + 
+--R                      5 3      3 4       2 6  3
+--R               (- 512a c  + 96a b c - 16a b )d
+--R             + 
+--R                      5   2       4 3       3 5
+--R               (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     4 4      3 2 3     2 4 2  8
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      4   3      3 3 2     2 5   6
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      5 3      3 4      2 6  4
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                      5   2      4 3      3 5  2      6 2      5 2      4 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                7 7           6 2 6           5 4 5
+--R                      - 3161088a c  + 4096512a b c  - 2292480a b c
+--R                    + 
+--R                             4 6 4          3 8 3         2 10 2          12
+--R                      723168a b c  - 139860a b c  + 16704a b  c  - 1152a b  c
+--R                    + 
+--R                         14
+--R                      36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R               4 4      3 2 3     2 4 2  9 8
+--R           (64a c  - 32a b c  + 4a b c )e x
+--R         + 
+--R                4 4       3 2 3      2 4 2    8 7
+--R           (512a c  - 256a b c  + 32a b c )d e x
+--R         + 
+--R                     4 4       3 2 3       2 4 2  2       4   3      3 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 2 5
+--R               8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    4   3       3 3 2      2 5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   4   3       3 3 2       2 5   2       5 3      3 4      2 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     4   3        3 3 2       2 5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    5 3      3 4       2 6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     4 4       3 2 3       2 4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     4   3       3 3 2       2 5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    5 3       3 4       2 6  2       5   2      4 3      3 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    4 4       3 2 3      2 4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    4   3       3 3 2      2 5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  5 3      3 4       2 6  3        5   2       4 3       3 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   4 4      3 2 3     2 4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    4   3      3 3 2     2 5   6        5 3      3 4      2 6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    5   2      4 3      3 5  2      6 2      5 2      4 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                              7 7           6 2 6           5 4 5          4 6 4
+--R                      3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                    + 
+--R                             3 8 3         2 10 2          12       14
+--R                      139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                 4 4      3 2 3     2 4 2  9 8
+--R           (- 64a c  + 32a b c  - 4a b c )e x
+--R         + 
+--R                  4 4       3 2 3      2 4 2    8 7
+--R           (- 512a c  + 256a b c  - 32a b c )d e x
+--R         + 
+--R                       4 4       3 2 3       2 4 2  2       4   3      3 3 2
+--R               (- 1792a c  + 896a b c  - 112a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                   2 5
+--R               - 8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  3
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                      4   3       3 3 2      2 5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  4
+--R               (- 4480a c  + 2240a b c  - 280a b c )d
+--R             + 
+--R                     4   3       3 3 2       2 5   2       5 3      3 4      2 6
+--R             (- 1920a b c  + 960a b c  - 120a b c)d  - 128a c  + 24a b c - 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  5
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                       4   3        3 3 2       2 5   3
+--R               (- 2560a b c  + 1280a b c  - 160a b c)d
+--R             + 
+--R                      5 3      3 4       2 6
+--R               (- 512a c  + 96a b c - 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       4 4       3 2 3       2 4 2  6
+--R               (- 1792a c  + 896a b c  - 112a b c )d
+--R             + 
+--R                       4   3       3 3 2       2 5   4
+--R               (- 1920a b c  + 960a b c  - 120a b c)d
+--R             + 
+--R                      5 3       3 4       2 6  2       5   2      4 3      3 5
+--R               (- 768a c  + 144a b c - 24a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      4 4       3 2 3      2 4 2  7
+--R               (- 512a c  + 256a b c  - 32a b c )d
+--R             + 
+--R                      4   3       3 3 2      2 5   5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R             + 
+--R                      5 3      3 4       2 6  3
+--R               (- 512a c  + 96a b c - 16a b )d
+--R             + 
+--R                      5   2       4 3       3 5
+--R               (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     4 4      3 2 3     2 4 2  8
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      4   3      3 3 2     2 5   6
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      5 3      3 4      2 6  4
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                      5   2      4 3      3 5  2      6 2      5 2      4 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                7 7           6 2 6           5 4 5
+--R                      - 3161088a c  + 4096512a b c  - 2292480a b c
+--R                    + 
+--R                             4 6 4          3 8 3         2 10 2          12
+--R                      723168a b c  - 139860a b c  + 16704a b  c  - 1152a b  c
+--R                    + 
+--R                         14
+--R                      36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                 3     3 2  7 7              3      3 2    6 6
+--R       (- 24a b c  + 3b c )e x  + (- 168a b c  + 21b c )d e x
+--R     + 
+--R                   3      3 2  2      2 3        2 2     4   5 5
+--R       ((- 504a b c  + 63b c )d  + 28a c  - 49a b c  + 6b c)e x
+--R     + 
+--R                   3       3 2  3        2 3         2 2      4     4 4
+--R       ((- 840a b c  + 105b c )d  + (140a c  - 245a b c  + 30b c)d)e x
+--R     + 
+--R                      3       3 2  4        2 3         2 2      4   2     2   2
+--R           (- 840a b c  + 105b c )d  + (280a c  - 490a b c  + 60b c)d  - 4a b c
+--R         + 
+--R                  3      5
+--R           - 20a b c + 3b
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R                      3      3 2  5        2 3         2 2      4   3
+--R           (- 504a b c  + 63b c )d  + (280a c  - 490a b c  + 60b c)d
+--R         + 
+--R                 2   2        3      5
+--R           (- 12a b c  - 60a b c + 9b )d
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R                      3      3 2  6        2 3         2 2      4   4
+--R           (- 168a b c  + 21b c )d  + (140a c  - 245a b c  + 30b c)d
+--R         + 
+--R                 2   2        3      5  2      3 2      2 2        4
+--R           (- 12a b c  - 60a b c + 9b )d  + 44a c  - 37a b c + 5a b
+--R      *
+--R         e x
+--R     + 
+--R                 3     3 2  7       2 3        2 2     4   5
+--R       (- 24a b c  + 3b c )d  + (28a c  - 49a b c  + 6b c)d
+--R     + 
+--R            2   2        3      5  3       3 2      2 2        4
+--R       (- 4a b c  - 20a b c + 3b )d  + (44a c  - 37a b c + 5a b )d
+--R  /
+--R            4 4      3 2 3     2 4 2  9 8
+--R       (128a c  - 64a b c  + 8a b c )e x
+--R     + 
+--R             4 4       3 2 3      2 4 2    8 7
+--R       (1024a c  - 512a b c  + 64a b c )d e x
+--R     + 
+--R                   4 4        3 2 3       2 4 2  2       4   3       3 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                2 5
+--R             16a b c
+--R      *
+--R          7 6
+--R         e x
+--R     + 
+--R                 4 4        3 2 3       2 4 2  3
+--R           (7168a c  - 3584a b c  + 448a b c )d
+--R         + 
+--R                 4   3       3 3 2      2 5
+--R           (1536a b c  - 768a b c  + 96a b c)d
+--R      *
+--R          6 5
+--R         e x
+--R     + 
+--R                 4 4        3 2 3       2 4 2  4
+--R           (8960a c  - 4480a b c  + 560a b c )d
+--R         + 
+--R                 4   3        3 3 2       2 5   2       5 3      3 4      2 6
+--R           (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R      *
+--R          5 4
+--R         e x
+--R     + 
+--R                 4 4        3 2 3       2 4 2  5
+--R           (7168a c  - 3584a b c  + 448a b c )d
+--R         + 
+--R                 4   3        3 3 2       2 5   3
+--R           (5120a b c  - 2560a b c  + 320a b c)d
+--R         + 
+--R                 5 3       3 4       2 6
+--R           (1024a c  - 192a b c + 32a b )d
+--R      *
+--R          4 3
+--R         e x
+--R     + 
+--R                 4 4        3 2 3       2 4 2  6
+--R           (3584a c  - 1792a b c  + 224a b c )d
+--R         + 
+--R                 4   3        3 3 2       2 5   4
+--R           (3840a b c  - 1920a b c  + 240a b c)d
+--R         + 
+--R                 5 3       3 4       2 6  2       5   2       4 3       3 5
+--R           (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R      *
+--R          3 2
+--R         e x
+--R     + 
+--R                 4 4       3 2 3      2 4 2  7
+--R           (1024a c  - 512a b c  + 64a b c )d
+--R         + 
+--R                 4   3       3 3 2      2 5   5
+--R           (1536a b c  - 768a b c  + 96a b c)d
+--R         + 
+--R                 5 3       3 4       2 6  3        5   2       4 3       3 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R      *
+--R          2
+--R         e x
+--R     + 
+--R                4 4      3 2 3     2 4 2  8
+--R           (128a c  - 64a b c  + 8a b c )d
+--R         + 
+--R                4   3       3 3 2      2 5   6        5 3      3 4      2 6  4
+--R           (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R         + 
+--R                5   2       4 3       3 5  2       6 2      5 2      4 4
+--R           (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R      *
+--R         e
+--R                                         Type: Union(Expression(Integer),...)
+--E 877
+
+--S 878 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                       +--------------------+
+--R                                         +-----------+ |   +-----------+
+--R             4 2      3 2      2 4   +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                              7 7           6 2 6           5 4 5          4 6 4
+--R                      3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                    + 
+--R                             3 8 3         2 10 2          12       14
+--R                      139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                                           +-----------+
+--R               4 2      3 2      2 4   +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                7 7           6 2 6           5 4 5
+--R                      - 3161088a c  + 4096512a b c  - 2292480a b c
+--R                    + 
+--R                             4 6 4          3 8 3         2 10 2          12
+--R                      723168a b c  - 139860a b c  + 16704a b  c  - 1152a b  c
+--R                    + 
+--R                         14
+--R                      36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                                         +-----------+
+--R             4 2      3 2      2 4   +-+ |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                              7 7           6 2 6           5 4 5          4 6 4
+--R                      3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                    + 
+--R                             3 8 3         2 10 2          12       14
+--R                      139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                                                         +--------------------+
+--R                                           +-----------+ |   +-----------+
+--R               4 2      3 2      2 4   +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                7 7           6 2 6           5 4 5
+--R                      - 3161088a c  + 4096512a b c  - 2292480a b c
+--R                    + 
+--R                             4 6 4          3 8 3         2 10 2          12
+--R                      723168a b c  - 139860a b c  + 16704a b  c  - 1152a b  c
+--R                    + 
+--R                         14
+--R                      36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                          +-----------+
+--R                       3  |          2        2 2        2      4  +-+
+--R         ((24a b c - 3b )\|- 4a c + b   - 168a c  + 30a b c - 3b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                       +-+ +-+
+--R          | |          2              (e x + d)\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                       3  |          2        2 2        2      4  +-+
+--R         ((24a b c - 3b )\|- 4a c + b   + 168a c  - 30a b c + 3b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R            4 2      3 2      2 4   +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 878
+
+--S 879 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 879
+
+)clear all
+
+--S 880 of 1057
+t0:=1/((d+e*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 13 13      3   12 12       3 2       2  11 11
+--R       c e  x   + 13c d e  x   + (78c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   10 10        3 4         2 2       2     2   9 9
+--R       (286c d  + 33b c d)e  x   + (715c d  + 165b c d  + 3a c  + 3b c)e x
+--R     + 
+--R             3 5         2 3         2      2     8 8
+--R       (1287c d  + 495b c d  + (27a c  + 27b c)d)e x
+--R     + 
+--R             3 6         2 4          2       2   2             3  7 7
+--R       (1716c d  + 990b c d  + (108a c  + 108b c)d  + 6a b c + b )e x
+--R     + 
+--R             3 7          2 5          2       2   3                3    6 6
+--R       (1716c d  + 1386b c d  + (252a c  + 252b c)d  + (42a b c + 7b )d)e x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           1287c d  + 1386b c d  + (378a c  + 378b c)d  + (126a b c + 21b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           715c d  + 990b c d  + (378a c  + 378b c)d  + (210a b c + 35b )d
+--R         + 
+--R               2         2
+--R           (15a c + 15a b )d
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 10         2 8          2       2   6                  3  4
+--R           286c d   + 495b c d  + (252a c  + 252b c)d  + (210a b c + 35b )d
+--R         + 
+--R               2         2  2     2
+--R           (30a c + 30a b )d  + 3a b
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 11         2 9          2       2   7                  3  5
+--R           78c d   + 165b c d  + (108a c  + 108b c)d  + (126a b c + 21b )d
+--R         + 
+--R               2         2  3     2
+--R           (30a c + 30a b )d  + 9a b d
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 12        2 10         2      2   8                3  6
+--R           13c d   + 33b c d   + (27a c  + 27b c)d  + (42a b c + 7b )d
+--R         + 
+--R               2         2  4     2   2    3
+--R           (15a c + 15a b )d  + 9a b d  + a
+--R      *
+--R         e x
+--R     + 
+--R        3 13       2 11        2     2   9              3  7      2        2  5
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   3    3
+--R       3a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 880
+
+--S 881 of 1057
+r0:=1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/4*(2*b^4-15*a*b^2*c+16*a^2*c^2+2*b*c*(b^2-7*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+1/2*b*_
+   (b^4-10*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/_
+   (a^3*(b^2-4*a*c)^(5/2)*e)+log(d+e*x)/(a^3*e)-1/4*log(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)/(a^3*e)
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  8 8
+--R           (60a b c  - 20a b c  + 2b c )e x
+--R         + 
+--R                2   4         3 3      5 2    7 7
+--R           (480a b c  - 160a b c  + 16b c )d e x
+--R         + 
+--R                    2   4         3 3      5 2  2       2 2 3        4 2     6
+--R             ((1680a b c  - 560a b c  + 56b c )d  + 120a b c  - 40a b c  + 4b c)
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  3
+--R               (3360a b c  - 1120a b c  + 112b c )d
+--R             + 
+--R                    2 2 3         4 2      6
+--R               (720a b c  - 240a b c  + 24b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  4
+--R               (4200a b c  - 1400a b c  + 140b c )d
+--R             + 
+--R                     2 2 3         4 2      6   2       3   3      2 3 2
+--R               (1800a b c  - 600a b c  + 60b c)d  + 120a b c  + 20a b c
+--R             + 
+--R                      5      7
+--R               - 16a b c + 2b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  5
+--R               (3360a b c  - 1120a b c  + 112b c )d
+--R             + 
+--R                     2 2 3         4 2      6   3
+--R               (2400a b c  - 800a b c  + 80b c)d
+--R             + 
+--R                    3   3      2 3 2        5      7
+--R               (480a b c  + 80a b c  - 64a b c + 8b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2   4         3 3      5 2  6
+--R               (1680a b c  - 560a b c  + 56b c )d
+--R             + 
+--R                     2 2 3         4 2      6   4
+--R               (1800a b c  - 600a b c  + 60b c)d
+--R             + 
+--R                    3   3       2 3 2        5       7  2       3 2 2      2 4
+--R               (720a b c  + 120a b c  - 96a b c + 12b )d  + 120a b c  - 40a b c
+--R             + 
+--R                   6
+--R               4a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                    2   4         3 3      5 2  7
+--R               (480a b c  - 160a b c  + 16b c )d
+--R             + 
+--R                    2 2 3         4 2      6   5
+--R               (720a b c  - 240a b c  + 24b c)d
+--R             + 
+--R                    3   3      2 3 2        5      7  3
+--R               (480a b c  + 80a b c  - 64a b c + 8b )d
+--R             + 
+--R                    3 2 2      2 4        6
+--R               (240a b c  - 80a b c + 8a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2   4        3 3     5 2  8        2 2 3        4 2     6   6
+--R           (60a b c  - 20a b c  + 2b c )d  + (120a b c  - 40a b c  + 4b c)d
+--R         + 
+--R                3   3      2 3 2        5      7  4
+--R           (120a b c  + 20a b c  - 16a b c + 2b )d
+--R         + 
+--R                3 2 2      2 4        6  2      4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )d  + 60a b c  - 20a b c + 2a b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                     2 4       2 3    4 2  8 8
+--R               (- 16a c  + 8a b c  - b c )e x
+--R             + 
+--R                      2 4        2 3     4 2    7 7
+--R               (- 128a c  + 64a b c  - 8b c )d e x
+--R             + 
+--R                            2 4         2 3      4 2  2      2   3        3 2
+--R                     (- 448a c  + 224a b c  - 28b c )d  - 32a b c  + 16a b c
+--R                   + 
+--R                         5
+--R                     - 2b c
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  3
+--R                   (- 896a c  + 448a b c  - 56b c )d
+--R                 + 
+--R                          2   3        3 2      5
+--R                   (- 192a b c  + 96a b c  - 12b c)d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2 4         2 3      4 2  4
+--R                   (- 1120a c  + 560a b c  - 70b c )d
+--R                 + 
+--R                          2   3         3 2      5   2      3 3       4     6
+--R                   (- 480a b c  + 240a b c  - 30b c)d  - 32a c  + 6a b c - b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  5
+--R                   (- 896a c  + 448a b c  - 56b c )d
+--R                 + 
+--R                          2   3         3 2      5   3
+--R                   (- 640a b c  + 320a b c  - 40b c)d
+--R                 + 
+--R                          3 3        4      6
+--R                   (- 128a c  + 24a b c - 4b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  6
+--R                   (- 448a c  + 224a b c  - 28b c )d
+--R                 + 
+--R                          2   3         3 2      5   4
+--R                   (- 480a b c  + 240a b c  - 30b c)d
+--R                 + 
+--R                          3 3        4      6  2      3   2      2 3        5
+--R                   (- 192a c  + 36a b c - 6b )d  - 32a b c  + 16a b c - 2a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2 4        2 3     4 2  7
+--R                   (- 128a c  + 64a b c  - 8b c )d
+--R                 + 
+--R                          2   3        3 2      5   5
+--R                   (- 192a b c  + 96a b c  - 12b c)d
+--R                 + 
+--R                        3 3        4      6  3         3   2      2 3        5
+--R                 (- 128a c  + 24a b c - 4b )d  + (- 64a b c  + 32a b c - 4a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2 4       2 3    4 2  8         2   3        3 2     5   6
+--R               (- 16a c  + 8a b c  - b c )d  + (- 32a b c  + 16a b c  - 2b c)d
+--R             + 
+--R                     3 3       4     6  4         3   2      2 3        5  2
+--R               (- 32a c  + 6a b c - b )d  + (- 32a b c  + 16a b c - 2a b )d
+--R             + 
+--R                    4 2     3 2     2 4
+--R               - 16a c  + 8a b c - a b
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                   2 4        2 3     4 2  8 8
+--R               (64a c  - 32a b c  + 4b c )e x
+--R             + 
+--R                    2 4         2 3      4 2    7 7
+--R               (512a c  - 256a b c  + 32b c )d e x
+--R             + 
+--R                         2 4         2 3       4 2  2       2   3        3 2
+--R                   (1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c
+--R                 + 
+--R                     5
+--R                   8b c
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  3
+--R                   (3584a c  - 1792a b c  + 224b c )d
+--R                 + 
+--R                        2   3         3 2      5
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  4
+--R                   (4480a c  - 2240a b c  + 280b c )d
+--R                 + 
+--R                       2   3         3 2       5   2       3 3        4      6
+--R                 (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  5
+--R                   (3584a c  - 1792a b c  + 224b c )d
+--R                 + 
+--R                         2   3          3 2       5   3
+--R                   (2560a b c  - 1280a b c  + 160b c)d
+--R                 + 
+--R                        3 3        4       6
+--R                   (512a c  - 96a b c + 16b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                         2 4         2 3       4 2  6
+--R                   (1792a c  - 896a b c  + 112b c )d
+--R                 + 
+--R                         2   3         3 2       5   4
+--R                   (1920a b c  - 960a b c  + 120b c)d
+--R                 + 
+--R                        3 3         4       6  2       3   2      2 3        5
+--R                   (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                        2 4         2 3      4 2  7
+--R                   (512a c  - 256a b c  + 32b c )d
+--R                 + 
+--R                        2   3         3 2      5   5
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R                 + 
+--R                      3 3        4       6  3        3   2       2 3         5
+--R                 (512a c  - 96a b c + 16b )d  + (256a b c  - 128a b c + 16a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                 2   3       3 2  6 6         2   3        3 2    5 5
+--R           (- 14a b c  + 2a b c )e x  + (- 84a b c  + 12a b c )d e x
+--R         + 
+--R                   2   3        3 2  2      3 3      2 2 2       4   4 4
+--R           ((- 210a b c  + 30a b c )d  + 16a c  - 29a b c  + 4a b c)e x
+--R         + 
+--R                   2   3        3 2  3       3 3       2 2 2        4     3 3
+--R           ((- 280a b c  + 40a b c )d  + (64a c  - 116a b c  + 16a b c)d)e x
+--R         + 
+--R                      2   3        3 2  4       3 3       2 2 2        4   2
+--R               (- 210a b c  + 30a b c )d  + (96a c  - 174a b c  + 24a b c)d
+--R             + 
+--R                   3   2      2 3        5
+--R               - 2a b c  - 12a b c + 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2   3        3 2  5       3 3       2 2 2        4   3
+--R               (- 84a b c  + 12a b c )d  + (64a c  - 116a b c  + 16a b c)d
+--R             + 
+--R                    3   2      2 3        5
+--R               (- 4a b c  - 24a b c + 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2   3       3 2  6       3 3      2 2 2       4   4
+--R           (- 14a b c  + 2a b c )d  + (16a c  - 29a b c  + 4a b c)d
+--R         + 
+--R                3   2      2 3        5  2      4 2      3 2      2 4
+--R           (- 2a b c  - 12a b c + 2a b )d  + 24a c  - 21a b c + 3a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             5 4      4 2 3     3 4 2  9 8
+--R         (64a c  - 32a b c  + 4a b c )e x
+--R       + 
+--R              5 4       4 2 3      3 4 2    8 7
+--R         (512a c  - 256a b c  + 32a b c )d e x
+--R       + 
+--R                     5 4       4 2 3       3 4 2  2       5   3      4 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  3
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  4
+--R             (4480a c  - 2240a b c  + 280a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   2       6 3      4 4      3 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  5
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   3
+--R             (2560a b c  - 1280a b c  + 160a b c)d
+--R           + 
+--R                  6 3      4 4       3 6
+--R             (512a c  - 96a b c + 16a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   5 4       4 2 3       3 4 2  6
+--R             (1792a c  - 896a b c  + 112a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   4
+--R             (1920a b c  - 960a b c  + 120a b c)d
+--R           + 
+--R                  6 3       4 4       3 6  2       6   2      5 3      4 5
+--R             (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  5 4       4 2 3      3 4 2  7
+--R             (512a c  - 256a b c  + 32a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5   5
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R           + 
+--R                  6 3      4 4       3 6  3        6   2       5 3       4 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R             (64a c  - 32a b c  + 4a b c )d  + (128a b c  - 64a b c  + 8a b c)d
+--R           + 
+--R                  6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R             (128a c  - 24a b c + 4a b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                7 2      6 2      5 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 881
+
+--S 882 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   4        3 3    5 2  8 8
+--R             (30a b c  - 10a b c  + b c )e x
+--R           + 
+--R                  2   4        3 3     5 2    7 7
+--R             (240a b c  - 80a b c  + 8b c )d e x
+--R           + 
+--R                     2   4         3 3      5 2  2      2 2 3        4 2     6
+--R               ((840a b c  - 280a b c  + 28b c )d  + 60a b c  - 20a b c  + 2b c)
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                       2   4         3 3      5 2  3
+--R                 (1680a b c  - 560a b c  + 56b c )d
+--R               + 
+--R                      2 2 3         4 2      6
+--R                 (360a b c  - 120a b c  + 12b c)d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                       2   4         3 3      5 2  4
+--R                 (2100a b c  - 700a b c  + 70b c )d
+--R               + 
+--R                      2 2 3         4 2      6   2      3   3      2 3 2
+--R                 (900a b c  - 300a b c  + 30b c)d  + 60a b c  + 10a b c
+--R               + 
+--R                       5     7
+--R                 - 8a b c + b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                       2   4         3 3      5 2  5
+--R                 (1680a b c  - 560a b c  + 56b c )d
+--R               + 
+--R                       2 2 3         4 2      6   3
+--R                 (1200a b c  - 400a b c  + 40b c)d
+--R               + 
+--R                      3   3      2 3 2        5      7
+--R                 (240a b c  + 40a b c  - 32a b c + 4b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                      2   4         3 3      5 2  6
+--R                 (840a b c  - 280a b c  + 28b c )d
+--R               + 
+--R                      2 2 3         4 2      6   4
+--R                 (900a b c  - 300a b c  + 30b c)d
+--R               + 
+--R                      3   3      2 3 2        5      7  2      3 2 2      2 4
+--R                 (360a b c  + 60a b c  - 48a b c + 6b )d  + 60a b c  - 20a b c
+--R               + 
+--R                     6
+--R                 2a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                      2   4        3 3     5 2  7
+--R                 (240a b c  - 80a b c  + 8b c )d
+--R               + 
+--R                      2 2 3         4 2      6   5
+--R                 (360a b c  - 120a b c  + 12b c)d
+--R               + 
+--R                      3   3      2 3 2        5      7  3
+--R                 (240a b c  + 40a b c  - 32a b c + 4b )d
+--R               + 
+--R                      3 2 2      2 4        6
+--R                 (120a b c  - 40a b c + 4a b )d
+--R            *
+--R               e x
+--R           + 
+--R                 2   4        3 3    5 2  8       2 2 3        4 2     6   6
+--R             (30a b c  - 10a b c  + b c )d  + (60a b c  - 20a b c  + 2b c)d
+--R           + 
+--R                 3   3      2 3 2       5     7  4
+--R             (60a b c  + 10a b c  - 8a b c + b )d
+--R           + 
+--R                 3 2 2      2 4        6  2      4   2      3 3     2 5
+--R             (60a b c  - 20a b c + 2a b )d  + 30a b c  - 10a b c + a b
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                       2 4       2 3    4 2  8 8
+--R                 (- 16a c  + 8a b c  - b c )e x
+--R               + 
+--R                        2 4        2 3     4 2    7 7
+--R                 (- 128a c  + 64a b c  - 8b c )d e x
+--R               + 
+--R                            2 4         2 3      4 2  2      2   3        3 2
+--R                     (- 448a c  + 224a b c  - 28b c )d  - 32a b c  + 16a b c
+--R                   + 
+--R                         5
+--R                     - 2b c
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  3
+--R                     (- 896a c  + 448a b c  - 56b c )d
+--R                   + 
+--R                            2   3        3 2      5
+--R                     (- 192a b c  + 96a b c  - 12b c)d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                             2 4         2 3      4 2  4
+--R                     (- 1120a c  + 560a b c  - 70b c )d
+--R                   + 
+--R                            2   3         3 2      5   2      3 3       4     6
+--R                     (- 480a b c  + 240a b c  - 30b c)d  - 32a c  + 6a b c - b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  5
+--R                     (- 896a c  + 448a b c  - 56b c )d
+--R                   + 
+--R                            2   3         3 2      5   3
+--R                     (- 640a b c  + 320a b c  - 40b c)d
+--R                   + 
+--R                            3 3        4      6
+--R                     (- 128a c  + 24a b c - 4b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  6
+--R                     (- 448a c  + 224a b c  - 28b c )d
+--R                   + 
+--R                            2   3         3 2      5   4
+--R                     (- 480a b c  + 240a b c  - 30b c)d
+--R                   + 
+--R                            3 3        4      6  2      3   2      2 3        5
+--R                     (- 192a c  + 36a b c - 6b )d  - 32a b c  + 16a b c - 2a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                            2 4        2 3     4 2  7
+--R                     (- 128a c  + 64a b c  - 8b c )d
+--R                   + 
+--R                            2   3        3 2      5   5
+--R                     (- 192a b c  + 96a b c  - 12b c)d
+--R                   + 
+--R                            3 3        4      6  3
+--R                     (- 128a c  + 24a b c - 4b )d
+--R                   + 
+--R                           3   2      2 3        5
+--R                     (- 64a b c  + 32a b c - 4a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                       2 4       2 3    4 2  8
+--R                 (- 16a c  + 8a b c  - b c )d
+--R               + 
+--R                       2   3        3 2     5   6         3 3       4     6  4
+--R                 (- 32a b c  + 16a b c  - 2b c)d  + (- 32a c  + 6a b c - b )d
+--R               + 
+--R                       3   2      2 3        5  2      4 2     3 2     2 4
+--R                 (- 32a b c  + 16a b c - 2a b )d  - 16a c  + 8a b c - a b
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                     2 4        2 3     4 2  8 8
+--R                 (64a c  - 32a b c  + 4b c )e x
+--R               + 
+--R                      2 4         2 3      4 2    7 7
+--R                 (512a c  - 256a b c  + 32b c )d e x
+--R               + 
+--R                           2 4         2 3       4 2  2       2   3        3 2
+--R                     (1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c
+--R                   + 
+--R                       5
+--R                     8b c
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  3
+--R                     (3584a c  - 1792a b c  + 224b c )d
+--R                   + 
+--R                          2   3         3 2      5
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  4
+--R                     (4480a c  - 2240a b c  + 280b c )d
+--R                   + 
+--R                         2   3         3 2       5   2       3 3        4      6
+--R                   (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  5
+--R                     (3584a c  - 1792a b c  + 224b c )d
+--R                   + 
+--R                           2   3          3 2       5   3
+--R                     (2560a b c  - 1280a b c  + 160b c)d
+--R                   + 
+--R                          3 3        4       6
+--R                     (512a c  - 96a b c + 16b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                           2 4         2 3       4 2  6
+--R                     (1792a c  - 896a b c  + 112b c )d
+--R                   + 
+--R                           2   3         3 2       5   4
+--R                     (1920a b c  - 960a b c  + 120b c)d
+--R                   + 
+--R                        3 3         4       6  2       3   2      2 3        5
+--R                   (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                          2 4         2 3      4 2  7
+--R                     (512a c  - 256a b c  + 32b c )d
+--R                   + 
+--R                          2   3         3 2      5   5
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                   + 
+--R                          3 3        4       6  3
+--R                     (512a c  - 96a b c + 16b )d
+--R                   + 
+--R                          3   2       2 3         5
+--R                     (256a b c  - 128a b c + 16a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                     2 4        2 3     4 2  8        2   3        3 2     5   6
+--R                 (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R               + 
+--R                      3 3        4      6  4        3   2      2 3        5  2
+--R                 (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R               + 
+--R                    4 2      3 2      2 4
+--R                 64a c  - 32a b c + 4a b
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                   2   3       3 2  6 6         2   3        3 2    5 5
+--R             (- 14a b c  + 2a b c )e x  + (- 84a b c  + 12a b c )d e x
+--R           + 
+--R                     2   3        3 2  2      3 3      2 2 2       4   4 4
+--R             ((- 210a b c  + 30a b c )d  + 16a c  - 29a b c  + 4a b c)e x
+--R           + 
+--R                     2   3        3 2  3       3 3       2 2 2        4     3 3
+--R             ((- 280a b c  + 40a b c )d  + (64a c  - 116a b c  + 16a b c)d)e x
+--R           + 
+--R                        2   3        3 2  4       3 3       2 2 2        4   2
+--R                 (- 210a b c  + 30a b c )d  + (96a c  - 174a b c  + 24a b c)d
+--R               + 
+--R                     3   2      2 3        5
+--R                 - 2a b c  - 12a b c + 2a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                       2   3        3 2  5       3 3       2 2 2        4   3
+--R                 (- 84a b c  + 12a b c )d  + (64a c  - 116a b c  + 16a b c)d
+--R               + 
+--R                      3   2      2 3        5
+--R                 (- 4a b c  - 24a b c + 4a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   2   3       3 2  6       3 3      2 2 2       4   4
+--R             (- 14a b c  + 2a b c )d  + (16a c  - 29a b c  + 4a b c)d
+--R           + 
+--R                  3   2      2 3        5  2      4 2      3 2      2 4
+--R             (- 2a b c  - 12a b c + 2a b )d  + 24a c  - 21a b c + 3a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               5 4      4 2 3     3 4 2  9 8
+--R           (64a c  - 32a b c  + 4a b c )e x
+--R         + 
+--R                5 4       4 2 3      3 4 2    8 7
+--R           (512a c  - 256a b c  + 32a b c )d e x
+--R         + 
+--R                     5 4       4 2 3       3 4 2  2       5   3      4 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   5   3       4 3 2       3 5   2       6 3      4 4      3 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    6 3      4 4       3 6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     5 4       4 2 3       3 4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     5   3       4 3 2       3 5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    5 4       4 2 3      3 4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  6 3      4 4       3 6  3        6   2       5 3       4 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   5 4      4 2 3     3 4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    5   3      4 3 2     3 5   6        6 3      4 4      3 6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  2      7 2      6 2      5 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2   4        3 3     5 2  8 8
+--R             (- 60a b c  + 20a b c  - 2b c )e x
+--R           + 
+--R                    2   4         3 3      5 2    7 7
+--R             (- 480a b c  + 160a b c  - 16b c )d e x
+--R           + 
+--R                         2   4         3 3      5 2  2       2 2 3        4 2
+--R                 (- 1680a b c  + 560a b c  - 56b c )d  - 120a b c  + 40a b c
+--R               + 
+--R                     6
+--R                 - 4b c
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                         2   4          3 3       5 2  3
+--R                 (- 3360a b c  + 1120a b c  - 112b c )d
+--R               + 
+--R                        2 2 3         4 2      6
+--R                 (- 720a b c  + 240a b c  - 24b c)d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                         2   4          3 3       5 2  4
+--R                 (- 4200a b c  + 1400a b c  - 140b c )d
+--R               + 
+--R                         2 2 3         4 2      6   2       3   3      2 3 2
+--R                 (- 1800a b c  + 600a b c  - 60b c)d  - 120a b c  - 20a b c
+--R               + 
+--R                      5      7
+--R                 16a b c - 2b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                         2   4          3 3       5 2  5
+--R                 (- 3360a b c  + 1120a b c  - 112b c )d
+--R               + 
+--R                         2 2 3         4 2      6   3
+--R                 (- 2400a b c  + 800a b c  - 80b c)d
+--R               + 
+--R                        3   3      2 3 2        5      7
+--R                 (- 480a b c  - 80a b c  + 64a b c - 8b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                         2   4         3 3      5 2  6
+--R                 (- 1680a b c  + 560a b c  - 56b c )d
+--R               + 
+--R                         2 2 3         4 2      6   4
+--R                 (- 1800a b c  + 600a b c  - 60b c)d
+--R               + 
+--R                        3   3       2 3 2        5       7  2       3 2 2
+--R                 (- 720a b c  - 120a b c  + 96a b c - 12b )d  - 120a b c
+--R               + 
+--R                    2 4        6
+--R                 40a b c - 4a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                        2   4         3 3      5 2  7
+--R                 (- 480a b c  + 160a b c  - 16b c )d
+--R               + 
+--R                        2 2 3         4 2      6   5
+--R                 (- 720a b c  + 240a b c  - 24b c)d
+--R               + 
+--R                        3   3      2 3 2        5      7  3
+--R                 (- 480a b c  - 80a b c  + 64a b c - 8b )d
+--R               + 
+--R                        3 2 2      2 4        6
+--R                 (- 240a b c  + 80a b c - 8a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   2   4        3 3     5 2  8
+--R             (- 60a b c  + 20a b c  - 2b c )d
+--R           + 
+--R                    2 2 3        4 2     6   6
+--R             (- 120a b c  + 40a b c  - 4b c)d
+--R           + 
+--R                    3   3      2 3 2        5      7  4
+--R             (- 120a b c  - 20a b c  + 16a b c - 2b )d
+--R           + 
+--R                    3 2 2      2 4        6  2      4   2      3 3      2 5
+--R             (- 120a b c  + 40a b c - 4a b )d  - 60a b c  + 20a b c - 2a b
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                       2 4       2 3    4 2  8 8
+--R                 (- 16a c  + 8a b c  - b c )e x
+--R               + 
+--R                        2 4        2 3     4 2    7 7
+--R                 (- 128a c  + 64a b c  - 8b c )d e x
+--R               + 
+--R                            2 4         2 3      4 2  2      2   3        3 2
+--R                     (- 448a c  + 224a b c  - 28b c )d  - 32a b c  + 16a b c
+--R                   + 
+--R                         5
+--R                     - 2b c
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  3
+--R                     (- 896a c  + 448a b c  - 56b c )d
+--R                   + 
+--R                            2   3        3 2      5
+--R                     (- 192a b c  + 96a b c  - 12b c)d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                             2 4         2 3      4 2  4
+--R                     (- 1120a c  + 560a b c  - 70b c )d
+--R                   + 
+--R                            2   3         3 2      5   2      3 3       4     6
+--R                     (- 480a b c  + 240a b c  - 30b c)d  - 32a c  + 6a b c - b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  5
+--R                     (- 896a c  + 448a b c  - 56b c )d
+--R                   + 
+--R                            2   3         3 2      5   3
+--R                     (- 640a b c  + 320a b c  - 40b c)d
+--R                   + 
+--R                            3 3        4      6
+--R                     (- 128a c  + 24a b c - 4b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  6
+--R                     (- 448a c  + 224a b c  - 28b c )d
+--R                   + 
+--R                            2   3         3 2      5   4
+--R                     (- 480a b c  + 240a b c  - 30b c)d
+--R                   + 
+--R                            3 3        4      6  2      3   2      2 3        5
+--R                     (- 192a c  + 36a b c - 6b )d  - 32a b c  + 16a b c - 2a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                            2 4        2 3     4 2  7
+--R                     (- 128a c  + 64a b c  - 8b c )d
+--R                   + 
+--R                            2   3        3 2      5   5
+--R                     (- 192a b c  + 96a b c  - 12b c)d
+--R                   + 
+--R                            3 3        4      6  3
+--R                     (- 128a c  + 24a b c - 4b )d
+--R                   + 
+--R                           3   2      2 3        5
+--R                     (- 64a b c  + 32a b c - 4a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                       2 4       2 3    4 2  8
+--R                 (- 16a c  + 8a b c  - b c )d
+--R               + 
+--R                       2   3        3 2     5   6         3 3       4     6  4
+--R                 (- 32a b c  + 16a b c  - 2b c)d  + (- 32a c  + 6a b c - b )d
+--R               + 
+--R                       3   2      2 3        5  2      4 2     3 2     2 4
+--R                 (- 32a b c  + 16a b c - 2a b )d  - 16a c  + 8a b c - a b
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                     2 4        2 3     4 2  8 8
+--R                 (64a c  - 32a b c  + 4b c )e x
+--R               + 
+--R                      2 4         2 3      4 2    7 7
+--R                 (512a c  - 256a b c  + 32b c )d e x
+--R               + 
+--R                           2 4         2 3       4 2  2       2   3        3 2
+--R                     (1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c
+--R                   + 
+--R                       5
+--R                     8b c
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  3
+--R                     (3584a c  - 1792a b c  + 224b c )d
+--R                   + 
+--R                          2   3         3 2      5
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  4
+--R                     (4480a c  - 2240a b c  + 280b c )d
+--R                   + 
+--R                         2   3         3 2       5   2       3 3        4      6
+--R                   (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  5
+--R                     (3584a c  - 1792a b c  + 224b c )d
+--R                   + 
+--R                           2   3          3 2       5   3
+--R                     (2560a b c  - 1280a b c  + 160b c)d
+--R                   + 
+--R                          3 3        4       6
+--R                     (512a c  - 96a b c + 16b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                           2 4         2 3       4 2  6
+--R                     (1792a c  - 896a b c  + 112b c )d
+--R                   + 
+--R                           2   3         3 2       5   4
+--R                     (1920a b c  - 960a b c  + 120b c)d
+--R                   + 
+--R                        3 3         4       6  2       3   2      2 3        5
+--R                   (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                          2 4         2 3      4 2  7
+--R                     (512a c  - 256a b c  + 32b c )d
+--R                   + 
+--R                          2   3         3 2      5   5
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                   + 
+--R                          3 3        4       6  3
+--R                     (512a c  - 96a b c + 16b )d
+--R                   + 
+--R                          3   2       2 3         5
+--R                     (256a b c  - 128a b c + 16a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                     2 4        2 3     4 2  8        2   3        3 2     5   6
+--R                 (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R               + 
+--R                      3 3        4      6  4        3   2      2 3        5  2
+--R                 (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R               + 
+--R                    4 2      3 2      2 4
+--R                 64a c  - 32a b c + 4a b
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                   2   3       3 2  6 6         2   3        3 2    5 5
+--R             (- 14a b c  + 2a b c )e x  + (- 84a b c  + 12a b c )d e x
+--R           + 
+--R                     2   3        3 2  2      3 3      2 2 2       4   4 4
+--R             ((- 210a b c  + 30a b c )d  + 16a c  - 29a b c  + 4a b c)e x
+--R           + 
+--R                     2   3        3 2  3       3 3       2 2 2        4     3 3
+--R             ((- 280a b c  + 40a b c )d  + (64a c  - 116a b c  + 16a b c)d)e x
+--R           + 
+--R                        2   3        3 2  4       3 3       2 2 2        4   2
+--R                 (- 210a b c  + 30a b c )d  + (96a c  - 174a b c  + 24a b c)d
+--R               + 
+--R                     3   2      2 3        5
+--R                 - 2a b c  - 12a b c + 2a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                       2   3        3 2  5       3 3       2 2 2        4   3
+--R                 (- 84a b c  + 12a b c )d  + (64a c  - 116a b c  + 16a b c)d
+--R               + 
+--R                      3   2      2 3        5
+--R                 (- 4a b c  - 24a b c + 4a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   2   3       3 2  6       3 3      2 2 2       4   4
+--R             (- 14a b c  + 2a b c )d  + (16a c  - 29a b c  + 4a b c)d
+--R           + 
+--R                  3   2      2 3        5  2      4 2      3 2      2 4
+--R             (- 2a b c  - 12a b c + 2a b )d  + 24a c  - 21a b c + 3a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               5 4      4 2 3     3 4 2  9 8
+--R           (64a c  - 32a b c  + 4a b c )e x
+--R         + 
+--R                5 4       4 2 3      3 4 2    8 7
+--R           (512a c  - 256a b c  + 32a b c )d e x
+--R         + 
+--R                     5 4       4 2 3       3 4 2  2       5   3      4 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   5   3       4 3 2       3 5   2       6 3      4 4      3 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    6 3      4 4       3 6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     5 4       4 2 3       3 4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     5   3       4 3 2       3 5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    5 4       4 2 3      3 4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  6 3      4 4       3 6  3        6   2       5 3       4 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   5 4      4 2 3     3 4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    5   3      4 3 2     3 5   6        6 3      4 4      3 6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  2      7 2      6 2      5 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 882
+
+--S 883 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2   2        3     5
+--R         (30a b c  - 10a b c + b )
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                                             2 2                  2
+--R             2   2        3      5       2c e x  + 4c d e x + 2c d  + b
+--R       (- 60a b c  + 20a b c - 2b )atanh(------------------------------)
+--R                                                  +-----------+
+--R                                                  |          2
+--R                                                 \|- 4a c + b
+--R  /
+--R                                 +-----------+
+--R         5 2      4 2      3 4   |          2
+--R     (64a c  - 32a b c + 4a b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 883
+
+--S 884 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 884
+
+--S 885 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                     +---------+
+--R               2   2        3     5  |        2
+--R         (- 30a b c  + 10a b c - b )\|4a c - b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                     +-----------+
+--R               2   2        3     5  |          2
+--R         (- 30a b c  + 10a b c - b )\|- 4a c + b
+--R      *
+--R                                               +---------+
+--R                   2 2                  2      |        2
+--R              (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R  /
+--R                                 +-----------+ +---------+
+--R         5 2      4 2      3 4   |          2  |        2
+--R     (32a c  - 16a b c + 2a b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 885
+
+--S 886 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 886
+
+)clear all
+
+--S 887 of 1057
+t0:=1/((d+e*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 14 14      3   13 13       3 2       2  12 12
+--R       c e  x   + 14c d e  x   + (91c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   11 11         3 4         2 2       2     2   10 10
+--R       (364c d  + 36b c d)e  x   + (1001c d  + 198b c d  + 3a c  + 3b c)e  x
+--R     + 
+--R             3 5         2 3         2      2     9 9
+--R       (2002c d  + 660b c d  + (30a c  + 30b c)d)e x
+--R     + 
+--R             3 6          2 4          2       2   2             3  8 8
+--R       (3003c d  + 1485b c d  + (135a c  + 135b c)d  + 6a b c + b )e x
+--R     + 
+--R             3 7          2 5          2       2   3                3    7 7
+--R       (3432c d  + 2376b c d  + (360a c  + 360b c)d  + (48a b c + 8b )d)e x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           3003c d  + 2772b c d  + (630a c  + 630b c)d  + (168a b c + 28b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R                3 9          2 7          2       2   5                  3  3
+--R           2002c d  + 2376b c d  + (756a c  + 756b c)d  + (336a b c + 56b )d
+--R         + 
+--R               2         2
+--R           (18a c + 18a b )d
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R                3 10          2 8          2       2   6                  3  4
+--R           1001c d   + 1485b c d  + (630a c  + 630b c)d  + (420a b c + 70b )d
+--R         + 
+--R               2         2  2     2
+--R           (45a c + 45a b )d  + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 11         2 9          2       2   7                  3  5
+--R           364c d   + 660b c d  + (360a c  + 360b c)d  + (336a b c + 56b )d
+--R         + 
+--R               2         2  3      2
+--R           (60a c + 60a b )d  + 12a b d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 12         2 10          2       2   8                  3  6
+--R           91c d   + 198b c d   + (135a c  + 135b c)d  + (168a b c + 28b )d
+--R         + 
+--R               2         2  4      2   2    3
+--R           (45a c + 45a b )d  + 18a b d  + a
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 13        2 11         2      2   9                3  7
+--R           14c d   + 36b c d   + (30a c  + 30b c)d  + (48a b c + 8b )d
+--R         + 
+--R               2         2  5      2   3     3
+--R           (18a c + 18a b )d  + 12a b d  + 2a d
+--R      *
+--R         e x
+--R     + 
+--R        3 14       2 12        2     2   10              3  8      2        2  6
+--R       c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   4    3 2
+--R       3a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 887
+
+--S 888 of 1057
+r0:=-3/8*(5*b^2-12*a*c)*(b^2-5*a*c)/(a^3*(b^2-4*a*c)^2*e*(d+e*x))+_
+   1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(d+e*x)*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/8*(5*b^4-35*a*b^2*c+36*a^2*c^2+b*c*(5*b^2-32*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(d+e*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   ((5*b^2-12*a*c)*(b^2-5*a*c)+b*(5*b^4-47*a*b^2*c+124*a^2*c^2)/sqrt(b^2-_
+   4*a*c))/(a^3*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   ((5*b^2-12*a*c)*(b^2-5*a*c)+(-5*b^5+47*a*b^3*c-124*a^2*b*c^2)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2 4         2 3      4 2  9 9
+--R               (- 180a c  + 111a b c  - 15b c )e x
+--R             + 
+--R                       2 4         2 3       4 2    8 8
+--R               (- 1620a c  + 999a b c  - 135b c )d e x
+--R             + 
+--R                           2 4          2 3       4 2  2       2   3         3 2
+--R                   (- 6480a c  + 3996a b c  - 540b c )d  - 360a b c  + 222a b c
+--R                 + 
+--R                        5
+--R                   - 30b c
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  3
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                           2   3          3 2       5
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  4
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                           2   3          3 2       5   2       3 3      2 2 2
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d  - 360a c  + 42a b c
+--R                 + 
+--R                        4       6
+--R                   81a b c - 15b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  5
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                            2   3          3 2        5   3
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  6
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                            2   3          3 2        5   4
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  2       3   2
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d  - 360a b c
+--R                 + 
+--R                       2 3         5
+--R                   222a b c - 30a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2 4          2 3       4 2  7
+--R                   (- 6480a c  + 3996a b c  - 540b c )d
+--R                 + 
+--R                           2   3          3 2       5   5
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  3
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d
+--R                 + 
+--R                           3   2       2 3         5
+--R                   (- 1080a b c  + 666a b c - 90a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2 4         2 3       4 2  8
+--R                   (- 1620a c  + 999a b c  - 135b c )d
+--R                 + 
+--R                           2   3          3 2       5   6
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6  4
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R                 + 
+--R                           3   2       2 3         5  2       4 2       3 2
+--R                   (- 1080a b c  + 666a b c - 90a b )d  - 180a c  + 111a b c
+--R                 + 
+--R                        2 4
+--R                   - 15a b
+--R              *
+--R                 e x
+--R             + 
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )d
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)d
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )d
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )d
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2   4         3 3      5 2  9 9
+--R           (- 372a b c  + 141a b c  - 15b c )e x
+--R         + 
+--R                   2   4          3 3       5 2    8 8
+--R           (- 3348a b c  + 1269a b c  - 135b c )d e x
+--R         + 
+--R                        2   4          3 3       5 2  2       2 2 3         4 2
+--R               (- 13392a b c  + 5076a b c  - 540b c )d  - 744a b c  + 282a b c
+--R             + 
+--R                    6
+--R               - 30b c
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  3
+--R               (- 31248a b c  + 11844a b c  - 1260b c )d
+--R             + 
+--R                       2 2 3          4 2       6
+--R               (- 5208a b c  + 1974a b c  - 210b c)d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  4
+--R               (- 46872a b c  + 17766a b c  - 1890b c )d
+--R             + 
+--R                        2 2 3          4 2       6   2       3   3      2 3 2
+--R               (- 15624a b c  + 5922a b c  - 630b c)d  - 744a b c  - 90a b c
+--R             + 
+--R                     5       7
+--R               111a b c - 15b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  5
+--R               (- 46872a b c  + 17766a b c  - 1890b c )d
+--R             + 
+--R                        2 2 3          4 2        6   3
+--R               (- 26040a b c  + 9870a b c  - 1050b c)d
+--R             + 
+--R                       3   3       2 3 2         5       7
+--R               (- 3720a b c  - 450a b c  + 555a b c - 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  6
+--R               (- 31248a b c  + 11844a b c  - 1260b c )d
+--R             + 
+--R                        2 2 3          4 2        6   4
+--R               (- 26040a b c  + 9870a b c  - 1050b c)d
+--R             + 
+--R                       3   3       2 3 2          5        7  2       3 2 2
+--R               (- 7440a b c  - 900a b c  + 1110a b c - 150b )d  - 744a b c
+--R             + 
+--R                   2 4         6
+--R               282a b c - 30a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                        2   4          3 3       5 2  7
+--R               (- 13392a b c  + 5076a b c  - 540b c )d
+--R             + 
+--R                        2 2 3          4 2       6   5
+--R               (- 15624a b c  + 5922a b c  - 630b c)d
+--R             + 
+--R                       3   3       2 3 2          5        7  3
+--R               (- 7440a b c  - 900a b c  + 1110a b c - 150b )d
+--R             + 
+--R                       3 2 2       2 4         6
+--R               (- 2232a b c  + 846a b c - 90a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2   4          3 3       5 2  8
+--R               (- 3348a b c  + 1269a b c  - 135b c )d
+--R             + 
+--R                       2 2 3          4 2       6   6
+--R               (- 5208a b c  + 1974a b c  - 210b c)d
+--R             + 
+--R                       3   3       2 3 2         5       7  4
+--R               (- 3720a b c  - 450a b c  + 555a b c - 75b )d
+--R             + 
+--R                       3 2 2       2 4         6  2       4   2       3 3
+--R               (- 2232a b c  + 846a b c - 90a b )d  - 372a b c  + 141a b c
+--R             + 
+--R                    2 5
+--R               - 15a b
+--R          *
+--R             e x
+--R         + 
+--R                  2   4         3 3      5 2  9
+--R           (- 372a b c  + 141a b c  - 15b c )d
+--R         + 
+--R                  2 2 3         4 2      6   7
+--R           (- 744a b c  + 282a b c  - 30b c)d
+--R         + 
+--R                  3   3      2 3 2         5       7  5
+--R           (- 744a b c  - 90a b c  + 111a b c - 15b )d
+--R         + 
+--R                  3 2 2       2 4         6  3
+--R           (- 744a b c  + 282a b c - 30a b )d
+--R         + 
+--R                  4   2       3 3       2 5
+--R           (- 372a b c  + 141a b c - 15a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2 4         2 3      4 2  9 9
+--R               (- 180a c  + 111a b c  - 15b c )e x
+--R             + 
+--R                       2 4         2 3       4 2    8 8
+--R               (- 1620a c  + 999a b c  - 135b c )d e x
+--R             + 
+--R                           2 4          2 3       4 2  2       2   3         3 2
+--R                   (- 6480a c  + 3996a b c  - 540b c )d  - 360a b c  + 222a b c
+--R                 + 
+--R                        5
+--R                   - 30b c
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  3
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                           2   3          3 2       5
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  4
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                           2   3          3 2       5   2       3 3      2 2 2
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d  - 360a c  + 42a b c
+--R                 + 
+--R                        4       6
+--R                   81a b c - 15b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  5
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                            2   3          3 2        5   3
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  6
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                            2   3          3 2        5   4
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  2       3   2
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d  - 360a b c
+--R                 + 
+--R                       2 3         5
+--R                   222a b c - 30a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2 4          2 3       4 2  7
+--R                   (- 6480a c  + 3996a b c  - 540b c )d
+--R                 + 
+--R                           2   3          3 2       5   5
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  3
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d
+--R                 + 
+--R                           3   2       2 3         5
+--R                   (- 1080a b c  + 666a b c - 90a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2 4         2 3       4 2  8
+--R                   (- 1620a c  + 999a b c  - 135b c )d
+--R                 + 
+--R                           2   3          3 2       5   6
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6  4
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R                 + 
+--R                           3   2       2 3         5  2       4 2       3 2
+--R                   (- 1080a b c  + 666a b c - 90a b )d  - 180a c  + 111a b c
+--R                 + 
+--R                        2 4
+--R                   - 15a b
+--R              *
+--R                 e x
+--R             + 
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )d
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)d
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )d
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )d
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2   4         3 3      5 2  9 9
+--R           (372a b c  - 141a b c  + 15b c )e x
+--R         + 
+--R                 2   4          3 3       5 2    8 8
+--R           (3348a b c  - 1269a b c  + 135b c )d e x
+--R         + 
+--R                      2   4          3 3       5 2  2       2 2 3         4 2
+--R               (13392a b c  - 5076a b c  + 540b c )d  + 744a b c  - 282a b c
+--R             + 
+--R                  6
+--R               30b c
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  3
+--R               (31248a b c  - 11844a b c  + 1260b c )d
+--R             + 
+--R                     2 2 3          4 2       6
+--R               (5208a b c  - 1974a b c  + 210b c)d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  4
+--R               (46872a b c  - 17766a b c  + 1890b c )d
+--R             + 
+--R                      2 2 3          4 2       6   2       3   3      2 3 2
+--R               (15624a b c  - 5922a b c  + 630b c)d  + 744a b c  + 90a b c
+--R             + 
+--R                       5       7
+--R               - 111a b c + 15b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  5
+--R               (46872a b c  - 17766a b c  + 1890b c )d
+--R             + 
+--R                      2 2 3          4 2        6   3
+--R               (26040a b c  - 9870a b c  + 1050b c)d
+--R             + 
+--R                     3   3       2 3 2         5       7
+--R               (3720a b c  + 450a b c  - 555a b c + 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  6
+--R               (31248a b c  - 11844a b c  + 1260b c )d
+--R             + 
+--R                      2 2 3          4 2        6   4
+--R               (26040a b c  - 9870a b c  + 1050b c)d
+--R             + 
+--R                     3   3       2 3 2          5        7  2       3 2 2
+--R               (7440a b c  + 900a b c  - 1110a b c + 150b )d  + 744a b c
+--R             + 
+--R                     2 4         6
+--R               - 282a b c + 30a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      2   4          3 3       5 2  7
+--R               (13392a b c  - 5076a b c  + 540b c )d
+--R             + 
+--R                      2 2 3          4 2       6   5
+--R               (15624a b c  - 5922a b c  + 630b c)d
+--R             + 
+--R                     3   3       2 3 2          5        7  3
+--R               (7440a b c  + 900a b c  - 1110a b c + 150b )d
+--R             + 
+--R                     3 2 2       2 4         6
+--R               (2232a b c  - 846a b c + 90a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  8
+--R               (3348a b c  - 1269a b c  + 135b c )d
+--R             + 
+--R                     2 2 3          4 2       6   6
+--R               (5208a b c  - 1974a b c  + 210b c)d
+--R             + 
+--R                     3   3       2 3 2         5       7  4
+--R               (3720a b c  + 450a b c  - 555a b c + 75b )d
+--R             + 
+--R                   3 2 2       2 4         6  2       4   2       3 3       2 5
+--R             (2232a b c  - 846a b c + 90a b )d  + 372a b c  - 141a b c + 15a b
+--R          *
+--R             e x
+--R         + 
+--R                2   4         3 3      5 2  9
+--R           (372a b c  - 141a b c  + 15b c )d
+--R         + 
+--R                2 2 3         4 2      6   7
+--R           (744a b c  - 282a b c  + 30b c)d
+--R         + 
+--R                3   3      2 3 2         5       7  5
+--R           (744a b c  + 90a b c  - 111a b c + 15b )d
+--R         + 
+--R                3 2 2       2 4         6  3        4   2       3 3       2 5
+--R           (744a b c  - 282a b c + 30a b )d  + (372a b c  - 141a b c + 15a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 4         2 3      4 2  8 8
+--R           (- 180a c  + 111a b c  - 15b c )e x
+--R         + 
+--R                   2 4         2 3       4 2    7 7
+--R           (- 1440a c  + 888a b c  - 120b c )d e x
+--R         + 
+--R                       2 4          2 3       4 2  2       2   3         3 2
+--R               (- 5040a c  + 3108a b c  - 420b c )d  - 392a b c  + 227a b c
+--R             + 
+--R                    5
+--R               - 30b c
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  3
+--R               (- 10080a c  + 6216a b c  - 840b c )d
+--R             + 
+--R                       2   3          3 2       5
+--R               (- 2352a b c  + 1362a b c  - 180b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2 4          2 3        4 2  4
+--R               (- 12600a c  + 7770a b c  - 1050b c )d
+--R             + 
+--R                       2   3          3 2       5   2       3 3      2 2 2
+--R               (- 5880a b c  + 3405a b c  - 450b c)d  - 324a c  - 25a b c
+--R             + 
+--R                    4       6
+--R               91a b c - 15b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  5
+--R               (- 10080a c  + 6216a b c  - 840b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 7840a b c  + 4540a b c  - 600b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6
+--R               (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  6
+--R               (- 5040a c  + 3108a b c  - 420b c )d
+--R             + 
+--R                       2   3          3 2       5   4
+--R               (- 5880a b c  + 3405a b c  - 450b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  2       3   2
+--R               (- 1944a c  - 150a b c  + 546a b c - 90b )d  - 364a b c
+--R             + 
+--R                   2 3         5
+--R               194a b c - 25a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2 4         2 3       4 2  7
+--R               (- 1440a c  + 888a b c  - 120b c )d
+--R             + 
+--R                       2   3          3 2       5   5
+--R               (- 2352a b c  + 1362a b c  - 180b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  3
+--R               (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R             + 
+--R                      3   2       2 3         5
+--R               (- 728a b c  + 388a b c - 50a b )d
+--R          *
+--R             e x
+--R         + 
+--R                  2 4         2 3      4 2  8
+--R           (- 180a c  + 111a b c  - 15b c )d
+--R         + 
+--R                  2   3         3 2      5   6
+--R           (- 392a b c  + 227a b c  - 30b c)d
+--R         + 
+--R                  3 3      2 2 2        4       6  4
+--R           (- 324a c  - 25a b c  + 91a b c - 15b )d
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 364a b c  + 194a b c - 25a b )d  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              5 4      4 2 3     3 4 2  10 9
+--R         (128a c  - 64a b c  + 8a b c )e  x
+--R       + 
+--R               5 4       4 2 3      3 4 2    9 8
+--R         (1152a c  - 576a b c  + 72a b c )d e x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  2       5   3       4 3 2
+--R             (4608a c  - 2304a b c  + 288a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                3 5
+--R             16a b c
+--R        *
+--R            8 7
+--R           e x
+--R       + 
+--R                    5 4        4 2 3       3 4 2  3
+--R             (10752a c  - 5376a b c  + 672a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5
+--R             (1792a b c  - 896a b c  + 112a b c)d
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                    5 4        4 2 3        3 4 2  4
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   2       6 3      4 4      3 6
+--R             (5376a b c  - 2688a b c  + 336a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                    5 4        4 2 3        3 4 2  5
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   3
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   6 3       4 4       3 6
+--R             (1280a c  - 240a b c + 40a b )d
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                    5 4        4 2 3       3 4 2  6
+--R             (10752a c  - 5376a b c  + 672a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   4
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   6 3       4 4       3 6  2       6   2       5 3       4 5
+--R             (2560a c  - 480a b c + 80a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  7
+--R             (4608a c  - 2304a b c  + 288a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   5
+--R             (5376a b c  - 2688a b c  + 336a b c)d
+--R           + 
+--R                 6 3       4 4       3 6  3        6   2       5 3       4 5
+--R           (2560a c  - 480a b c + 80a b )d  + (768a b c  - 384a b c + 48a b )d
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   5 4       4 2 3      3 4 2  8
+--R             (1152a c  - 576a b c  + 72a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   6
+--R             (1792a b c  - 896a b c  + 112a b c)d
+--R           + 
+--R                   6 3       4 4       3 6  4
+--R             (1280a c  - 240a b c + 40a b )d
+--R           + 
+--R                  6   2       5 3       4 5  2       7 2      6 2      5 4
+--R             (768a b c  - 384a b c + 48a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  5 4      4 2 3     3 4 2  9
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5   7        6 3      4 4      3 6  5
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  6   2       5 3       4 5  3        7 2      6 2      5 4
+--R             (256a b c  - 128a b c + 16a b )d  + (128a c  - 64a b c + 8a b )d
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 888
+
+--S 889 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 5 4      4 2 3     3 4 2  10 9
+--R           (- 64a c  + 32a b c  - 4a b c )e  x
+--R         + 
+--R                  5 4       4 2 3      3 4 2    9 8
+--R           (- 576a c  + 288a b c  - 36a b c )d e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  2       5   3      4 3 2
+--R               (- 2304a c  + 1152a b c  - 144a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                   3 5
+--R               - 8a b c
+--R          *
+--R              8 7
+--R             e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  3
+--R               (- 5376a c  + 2688a b c  - 336a b c )d
+--R             + 
+--R                      5   3       4 3 2      3 5
+--R               (- 896a b c  + 448a b c  - 56a b c)d
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  4
+--R               (- 8064a c  + 4032a b c  - 504a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   2       6 3      4 4
+--R               (- 2688a b c  + 1344a b c  - 168a b c)d  - 128a c  + 24a b c
+--R             + 
+--R                   3 6
+--R               - 4a b
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  5
+--R               (- 8064a c  + 4032a b c  - 504a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   3
+--R               (- 4480a b c  + 2240a b c  - 280a b c)d
+--R             + 
+--R                      6 3       4 4       3 6
+--R               (- 640a c  + 120a b c - 20a b )d
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  6
+--R               (- 5376a c  + 2688a b c  - 336a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   4
+--R               (- 4480a b c  + 2240a b c  - 280a b c)d
+--R             + 
+--R                       6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (- 1280a c  + 240a b c - 40a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  7
+--R               (- 2304a c  + 1152a b c  - 144a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   5
+--R               (- 2688a b c  + 1344a b c  - 168a b c)d
+--R             + 
+--R                       6 3       4 4       3 6  3
+--R               (- 1280a c  + 240a b c - 40a b )d
+--R             + 
+--R                      6   2       5 3       4 5
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      5 4       4 2 3      3 4 2  8
+--R               (- 576a c  + 288a b c  - 36a b c )d
+--R             + 
+--R                      5   3       4 3 2      3 5   6
+--R               (- 896a b c  + 448a b c  - 56a b c)d
+--R             + 
+--R                      6 3       4 4       3 6  4
+--R               (- 640a c  + 120a b c - 20a b )d
+--R             + 
+--R                      6   2       5 3       4 5  2      7 2      6 2      5 4
+--R               (- 384a b c  + 192a b c - 24a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     5 4      4 2 3     3 4 2  9
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      5   3      4 3 2     3 5   7
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      6 3      4 4      3 6  5
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  3         7 2      6 2      5 4
+--R             (- 128a b c  + 64a b c - 8a b )d  + (- 64a c  + 32a b c - 4a b )d
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               8   8             7 3 7             6 5 6
+--R                      47692800a b c  - 204648192a b c  + 257282496a b c
+--R                    + 
+--R                                  5 7 5            4 9 4            3 11 3
+--R                      - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                    + 
+--R                              2 13 2            15         17
+--R                      1776960a b  c  - 135900a b  c + 4500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R               5 4      4 2 3     3 4 2  10 9
+--R           (64a c  - 32a b c  + 4a b c )e  x
+--R         + 
+--R                5 4       4 2 3      3 4 2    9 8
+--R           (576a c  - 288a b c  + 36a b c )d e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  2       5   3      4 3 2
+--R               (2304a c  - 1152a b c  + 144a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R          *
+--R              8 7
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  3
+--R               (5376a c  - 2688a b c  + 336a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5
+--R               (896a b c  - 448a b c  + 56a b c)d
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  4
+--R               (8064a c  - 4032a b c  + 504a b c )d
+--R             + 
+--R                   5   3        4 3 2       3 5   2       6 3      4 4      3 6
+--R             (2688a b c  - 1344a b c  + 168a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  5
+--R               (8064a c  - 4032a b c  + 504a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   3
+--R               (4480a b c  - 2240a b c  + 280a b c)d
+--R             + 
+--R                    6 3       4 4       3 6
+--R               (640a c  - 120a b c + 20a b )d
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  6
+--R               (5376a c  - 2688a b c  + 336a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   4
+--R               (4480a b c  - 2240a b c  + 280a b c)d
+--R             + 
+--R                     6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (1280a c  - 240a b c + 40a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  7
+--R               (2304a c  - 1152a b c  + 144a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   5
+--R               (2688a b c  - 1344a b c  + 168a b c)d
+--R             + 
+--R                   6 3       4 4       3 6  3        6   2       5 3       4 5
+--R             (1280a c  - 240a b c + 40a b )d  + (384a b c  - 192a b c + 24a b )d
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    5 4       4 2 3      3 4 2  8
+--R               (576a c  - 288a b c  + 36a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5   6
+--R               (896a b c  - 448a b c  + 56a b c)d
+--R             + 
+--R                    6 3       4 4       3 6  4
+--R               (640a c  - 120a b c + 20a b )d
+--R             + 
+--R                    6   2       5 3       4 5  2      7 2      6 2      5 4
+--R               (384a b c  - 192a b c + 24a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   5 4      4 2 3     3 4 2  9
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    5   3      4 3 2     3 5   7        6 3      4 4      3 6  5
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  3       7 2      6 2      5 4
+--R               (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                 8   8             7 3 7             6 5 6
+--R                      - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                    + 
+--R                                5 7 5            4 9 4            3 11 3
+--R                      160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                    + 
+--R                                2 13 2            15         17
+--R                      - 1776960a b  c  + 135900a b  c - 4500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R                 5 4      4 2 3     3 4 2  10 9
+--R           (- 64a c  + 32a b c  - 4a b c )e  x
+--R         + 
+--R                  5 4       4 2 3      3 4 2    9 8
+--R           (- 576a c  + 288a b c  - 36a b c )d e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  2       5   3      4 3 2
+--R               (- 2304a c  + 1152a b c  - 144a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                   3 5
+--R               - 8a b c
+--R          *
+--R              8 7
+--R             e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  3
+--R               (- 5376a c  + 2688a b c  - 336a b c )d
+--R             + 
+--R                      5   3       4 3 2      3 5
+--R               (- 896a b c  + 448a b c  - 56a b c)d
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  4
+--R               (- 8064a c  + 4032a b c  - 504a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   2       6 3      4 4
+--R               (- 2688a b c  + 1344a b c  - 168a b c)d  - 128a c  + 24a b c
+--R             + 
+--R                   3 6
+--R               - 4a b
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  5
+--R               (- 8064a c  + 4032a b c  - 504a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   3
+--R               (- 4480a b c  + 2240a b c  - 280a b c)d
+--R             + 
+--R                      6 3       4 4       3 6
+--R               (- 640a c  + 120a b c - 20a b )d
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  6
+--R               (- 5376a c  + 2688a b c  - 336a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   4
+--R               (- 4480a b c  + 2240a b c  - 280a b c)d
+--R             + 
+--R                       6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (- 1280a c  + 240a b c - 40a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  7
+--R               (- 2304a c  + 1152a b c  - 144a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   5
+--R               (- 2688a b c  + 1344a b c  - 168a b c)d
+--R             + 
+--R                       6 3       4 4       3 6  3
+--R               (- 1280a c  + 240a b c - 40a b )d
+--R             + 
+--R                      6   2       5 3       4 5
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      5 4       4 2 3      3 4 2  8
+--R               (- 576a c  + 288a b c  - 36a b c )d
+--R             + 
+--R                      5   3       4 3 2      3 5   6
+--R               (- 896a b c  + 448a b c  - 56a b c)d
+--R             + 
+--R                      6 3       4 4       3 6  4
+--R               (- 640a c  + 120a b c - 20a b )d
+--R             + 
+--R                      6   2       5 3       4 5  2      7 2      6 2      5 4
+--R               (- 384a b c  + 192a b c - 24a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     5 4      4 2 3     3 4 2  9
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      5   3      4 3 2     3 5   7
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      6 3      4 4      3 6  5
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  3         7 2      6 2      5 4
+--R             (- 128a b c  + 64a b c - 8a b )d  + (- 64a c  + 32a b c - 4a b )d
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               8   8             7 3 7             6 5 6
+--R                      47692800a b c  - 204648192a b c  + 257282496a b c
+--R                    + 
+--R                                  5 7 5            4 9 4            3 11 3
+--R                      - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                    + 
+--R                              2 13 2            15         17
+--R                      1776960a b  c  - 135900a b  c + 4500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R               5 4      4 2 3     3 4 2  10 9
+--R           (64a c  - 32a b c  + 4a b c )e  x
+--R         + 
+--R                5 4       4 2 3      3 4 2    9 8
+--R           (576a c  - 288a b c  + 36a b c )d e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  2       5   3      4 3 2
+--R               (2304a c  - 1152a b c  + 144a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R          *
+--R              8 7
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  3
+--R               (5376a c  - 2688a b c  + 336a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5
+--R               (896a b c  - 448a b c  + 56a b c)d
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  4
+--R               (8064a c  - 4032a b c  + 504a b c )d
+--R             + 
+--R                   5   3        4 3 2       3 5   2       6 3      4 4      3 6
+--R             (2688a b c  - 1344a b c  + 168a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  5
+--R               (8064a c  - 4032a b c  + 504a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   3
+--R               (4480a b c  - 2240a b c  + 280a b c)d
+--R             + 
+--R                    6 3       4 4       3 6
+--R               (640a c  - 120a b c + 20a b )d
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  6
+--R               (5376a c  - 2688a b c  + 336a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   4
+--R               (4480a b c  - 2240a b c  + 280a b c)d
+--R             + 
+--R                     6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (1280a c  - 240a b c + 40a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  7
+--R               (2304a c  - 1152a b c  + 144a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   5
+--R               (2688a b c  - 1344a b c  + 168a b c)d
+--R             + 
+--R                   6 3       4 4       3 6  3        6   2       5 3       4 5
+--R             (1280a c  - 240a b c + 40a b )d  + (384a b c  - 192a b c + 24a b )d
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    5 4       4 2 3      3 4 2  8
+--R               (576a c  - 288a b c  + 36a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5   6
+--R               (896a b c  - 448a b c  + 56a b c)d
+--R             + 
+--R                    6 3       4 4       3 6  4
+--R               (640a c  - 120a b c + 20a b )d
+--R             + 
+--R                    6   2       5 3       4 5  2      7 2      6 2      5 4
+--R               (384a b c  - 192a b c + 24a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   5 4      4 2 3     3 4 2  9
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    5   3      4 3 2     3 5   7        6 3      4 4      3 6  5
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  3       7 2      6 2      5 4
+--R               (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                 8   8             7 3 7             6 5 6
+--R                      - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                    + 
+--R                                5 7 5            4 9 4            3 11 3
+--R                      160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                    + 
+--R                                2 13 2            15         17
+--R                      - 1776960a b  c  + 135900a b  c - 4500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R              2 4         2 3      4 2  8 8
+--R       (- 180a c  + 111a b c  - 15b c )e x
+--R     + 
+--R               2 4         2 3       4 2    7 7
+--R       (- 1440a c  + 888a b c  - 120b c )d e x
+--R     + 
+--R                  2 4          2 3       4 2  2       2   3         3 2      5
+--R         ((- 5040a c  + 3108a b c  - 420b c )d  - 392a b c  + 227a b c  - 30b c)
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R                    2 4          2 3       4 2  3
+--R           (- 10080a c  + 6216a b c  - 840b c )d
+--R         + 
+--R                   2   3          3 2       5
+--R           (- 2352a b c  + 1362a b c  - 180b c)d
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R                    2 4          2 3        4 2  4
+--R           (- 12600a c  + 7770a b c  - 1050b c )d
+--R         + 
+--R                   2   3          3 2       5   2       3 3      2 2 2        4
+--R           (- 5880a b c  + 3405a b c  - 450b c)d  - 324a c  - 25a b c  + 91a b c
+--R         + 
+--R                6
+--R           - 15b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R                    2 4          2 3       4 2  5
+--R           (- 10080a c  + 6216a b c  - 840b c )d
+--R         + 
+--R                   2   3          3 2       5   3
+--R           (- 7840a b c  + 4540a b c  - 600b c)d
+--R         + 
+--R                   3 3       2 2 2         4       6
+--R           (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R                   2 4          2 3       4 2  6
+--R           (- 5040a c  + 3108a b c  - 420b c )d
+--R         + 
+--R                   2   3          3 2       5   4
+--R           (- 5880a b c  + 3405a b c  - 450b c)d
+--R         + 
+--R                   3 3       2 2 2         4       6  2       3   2       2 3
+--R           (- 1944a c  - 150a b c  + 546a b c - 90b )d  - 364a b c  + 194a b c
+--R         + 
+--R                  5
+--R           - 25a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R                   2 4         2 3       4 2  7
+--R           (- 1440a c  + 888a b c  - 120b c )d
+--R         + 
+--R                   2   3          3 2       5   5
+--R           (- 2352a b c  + 1362a b c  - 180b c)d
+--R         + 
+--R                   3 3       2 2 2         4       6  3
+--R           (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R         + 
+--R                  3   2       2 3         5
+--R           (- 728a b c  + 388a b c - 50a b )d
+--R      *
+--R         e x
+--R     + 
+--R              2 4         2 3      4 2  8          2   3         3 2      5   6
+--R       (- 180a c  + 111a b c  - 15b c )d  + (- 392a b c  + 227a b c  - 30b c)d
+--R     + 
+--R              3 3      2 2 2        4       6  4
+--R       (- 324a c  - 25a b c  + 91a b c - 15b )d
+--R     + 
+--R              3   2       2 3         5  2       4 2      3 2      2 4
+--R       (- 364a b c  + 194a b c - 25a b )d  - 128a c  + 64a b c - 8a b
+--R  /
+--R            5 4      4 2 3     3 4 2  10 9
+--R       (128a c  - 64a b c  + 8a b c )e  x
+--R     + 
+--R             5 4       4 2 3      3 4 2    9 8
+--R       (1152a c  - 576a b c  + 72a b c )d e x
+--R     + 
+--R                   5 4        4 2 3       3 4 2  2       5   3       4 3 2
+--R             (4608a c  - 2304a b c  + 288a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                3 5
+--R             16a b c
+--R      *
+--R          8 7
+--R         e x
+--R     + 
+--R                  5 4        4 2 3       3 4 2  3
+--R           (10752a c  - 5376a b c  + 672a b c )d
+--R         + 
+--R                 5   3       4 3 2       3 5
+--R           (1792a b c  - 896a b c  + 112a b c)d
+--R      *
+--R          7 6
+--R         e x
+--R     + 
+--R                  5 4        4 2 3        3 4 2  4
+--R           (16128a c  - 8064a b c  + 1008a b c )d
+--R         + 
+--R                 5   3        4 3 2       3 5   2       6 3      4 4      3 6
+--R           (5376a b c  - 2688a b c  + 336a b c)d  + 256a c  - 48a b c + 8a b
+--R      *
+--R          6 5
+--R         e x
+--R     + 
+--R                  5 4        4 2 3        3 4 2  5
+--R           (16128a c  - 8064a b c  + 1008a b c )d
+--R         + 
+--R                 5   3        4 3 2       3 5   3
+--R           (8960a b c  - 4480a b c  + 560a b c)d
+--R         + 
+--R                 6 3       4 4       3 6
+--R           (1280a c  - 240a b c + 40a b )d
+--R      *
+--R          5 4
+--R         e x
+--R     + 
+--R                  5 4        4 2 3       3 4 2  6
+--R           (10752a c  - 5376a b c  + 672a b c )d
+--R         + 
+--R                 5   3        4 3 2       3 5   4
+--R           (8960a b c  - 4480a b c  + 560a b c)d
+--R         + 
+--R                 6 3       4 4       3 6  2       6   2       5 3       4 5
+--R           (2560a c  - 480a b c + 80a b )d  + 256a b c  - 128a b c + 16a b
+--R      *
+--R          4 3
+--R         e x
+--R     + 
+--R                 5 4        4 2 3       3 4 2  7
+--R           (4608a c  - 2304a b c  + 288a b c )d
+--R         + 
+--R                 5   3        4 3 2       3 5   5
+--R           (5376a b c  - 2688a b c  + 336a b c)d
+--R         + 
+--R                 6 3       4 4       3 6  3        6   2       5 3       4 5
+--R           (2560a c  - 480a b c + 80a b )d  + (768a b c  - 384a b c + 48a b )d
+--R      *
+--R          3 2
+--R         e x
+--R     + 
+--R                 5 4       4 2 3      3 4 2  8
+--R           (1152a c  - 576a b c  + 72a b c )d
+--R         + 
+--R                 5   3       4 3 2       3 5   6
+--R           (1792a b c  - 896a b c  + 112a b c)d
+--R         + 
+--R                 6 3       4 4       3 6  4        6   2       5 3       4 5  2
+--R           (1280a c  - 240a b c + 40a b )d  + (768a b c  - 384a b c + 48a b )d
+--R         + 
+--R               7 2      6 2      5 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R          2
+--R         e x
+--R     + 
+--R                5 4      4 2 3     3 4 2  9
+--R           (128a c  - 64a b c  + 8a b c )d
+--R         + 
+--R                5   3       4 3 2      3 5   7        6 3      4 4      3 6  5
+--R           (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R         + 
+--R                6   2       5 3       4 5  3        7 2      6 2      5 4
+--R           (256a b c  - 128a b c + 16a b )d  + (128a c  - 64a b c + 8a b )d
+--R      *
+--R         e
+--R                                         Type: Union(Expression(Integer),...)
+--E 889
+
+--S 890 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                         +--------------------+
+--R                                           +-----------+ |   +-----------+
+--R               5 2      4 2      3 4   +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               8   8             7 3 7             6 5 6
+--R                      47692800a b c  - 204648192a b c  + 257282496a b c
+--R                    + 
+--R                                  5 7 5            4 9 4            3 11 3
+--R                      - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                    + 
+--R                              2 13 2            15         17
+--R                      1776960a b  c  - 135900a b  c + 4500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R                                         +-----------+
+--R             5 2      4 2      3 4   +-+ |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                 8   8             7 3 7             6 5 6
+--R                      - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                    + 
+--R                                5 7 5            4 9 4            3 11 3
+--R                      160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                    + 
+--R                                2 13 2            15         17
+--R                      - 1776960a b  c  + 135900a b  c - 4500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R                                           +-----------+
+--R               5 2      4 2      3 4   +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               8   8             7 3 7             6 5 6
+--R                      47692800a b c  - 204648192a b c  + 257282496a b c
+--R                    + 
+--R                                  5 7 5            4 9 4            3 11 3
+--R                      - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                    + 
+--R                              2 13 2            15         17
+--R                      1776960a b  c  - 135900a b  c + 4500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R                                                       +--------------------+
+--R                                         +-----------+ |   +-----------+
+--R             5 2      4 2      3 4   +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                 8   8             7 3 7             6 5 6
+--R                      - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                    + 
+--R                                5 7 5            4 9 4            3 11 3
+--R                      160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                    + 
+--R                                2 13 2            15         17
+--R                      - 1776960a b  c  + 135900a b  c - 4500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R                                         +-----------+
+--R                  2 2         2       4  |          2        2   2         3
+--R             (180a c  - 111a b c + 15b )\|- 4a c + b   + 372a b c  - 141a b c
+--R           + 
+--R                5
+--R             15b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +-----------+
+--R                  2 2         2       4  |          2        2   2         3
+--R             (180a c  - 111a b c + 15b )\|- 4a c + b   - 372a b c  + 141a b c
+--R           + 
+--R                  5
+--R             - 15b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R            5 2      4 2      3 4   +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 890
+
+--S 891 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 891
+
+)clear all
+
+--S 892 of 1057
+t0:=1/((d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 15 15      3   14 14        3 2       2  13 13
+--R       c e  x   + 15c d e  x   + (105c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   12 12         3 4         2 2       2     2   11 11
+--R       (455c d  + 39b c d)e  x   + (1365c d  + 234b c d  + 3a c  + 3b c)e  x
+--R     + 
+--R             3 5         2 3         2      2     10 10
+--R       (3003c d  + 858b c d  + (33a c  + 33b c)d)e  x
+--R     + 
+--R             3 6          2 4          2       2   2             3  9 9
+--R       (5005c d  + 2145b c d  + (165a c  + 165b c)d  + 6a b c + b )e x
+--R     + 
+--R             3 7          2 5          2       2   3                3    8 8
+--R       (6435c d  + 3861b c d  + (495a c  + 495b c)d  + (54a b c + 9b )d)e x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           6435c d  + 5148b c d  + (990a c  + 990b c)d  + (216a b c + 36b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          7 7
+--R         e x
+--R     + 
+--R                3 9          2 7           2        2   5                  3  3
+--R           5005c d  + 5148b c d  + (1386a c  + 1386b c)d  + (504a b c + 84b )d
+--R         + 
+--R               2         2
+--R           (21a c + 21a b )d
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R                3 10          2 8           2        2   6
+--R           3003c d   + 3861b c d  + (1386a c  + 1386b c)d
+--R         + 
+--R                           3  4       2         2  2     2
+--R           (756a b c + 126b )d  + (63a c + 63a b )d  + 3a b
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R                3 11          2 9          2       2   7                   3  5
+--R           1365c d   + 2145b c d  + (990a c  + 990b c)d  + (756a b c + 126b )d
+--R         + 
+--R                2          2  3      2
+--R           (105a c + 105a b )d  + 15a b d
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 12         2 10          2       2   8                  3  6
+--R           455c d   + 858b c d   + (495a c  + 495b c)d  + (504a b c + 84b )d
+--R         + 
+--R                2          2  4      2   2    3
+--R           (105a c + 105a b )d  + 30a b d  + a
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R               3 13         2 11          2       2   9                  3  7
+--R           105c d   + 234b c d   + (165a c  + 165b c)d  + (216a b c + 36b )d
+--R         + 
+--R               2         2  5      2   3     3
+--R           (63a c + 63a b )d  + 30a b d  + 3a d
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 14        2 12         2      2   10                3  8
+--R           15c d   + 39b c d   + (33a c  + 33b c)d   + (54a b c + 9b )d
+--R         + 
+--R               2         2  6      2   4     3 2
+--R           (21a c + 21a b )d  + 15a b d  + 3a d
+--R      *
+--R         e x
+--R     + 
+--R        3 15       2 13        2     2   11              3  9      2        2  7
+--R       c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   5    3 3
+--R       3a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 892
+
+--S 893 of 1057
+r0:=-3/2*(b^4-7*a*b^2*c+10*a^2*c^2)/(a^3*(b^2-4*a*c)^2*e*(d+e*x)^2)+_
+   1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(d+e*x)^2*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/4*(3*b^4-20*a*b^2*c+20*a^2*c^2+3*b*c*(b^2-6*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(d+e*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   3/2*(b^6-10*a*b^4*c+30*a^2*b^2*c^2-20*a^3*c^3)*atanh((b+2*c*(d+e*x)^2)/_
+   sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(5/2)*e)-3*b*log(d+e*x)/(a^4*e)+_
+   3/4*b*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a^4*e)
+--R 
+--R
+--R   (2)
+--R                3 5       2 2 4        4 3     6 2  10 10
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )e  x
+--R         + 
+--R                 3 5        2 2 4         4 3      6 2    9 9
+--R           (1200a c  - 1800a b c  + 600a b c  - 60b c )d e x
+--R         + 
+--R                     3 5        2 2 4          4 3       6 2  2       3   4
+--R               (5400a c  - 8100a b c  + 2700a b c  - 270b c )d  + 240a b c
+--R             + 
+--R                     2 3 3         5 2      7
+--R               - 360a b c  + 120a b c  - 12b c
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                      3 5         2 2 4          4 3       6 2  3
+--R               (14400a c  - 21600a b c  + 7200a b c  - 720b c )d
+--R             + 
+--R                     3   4        2 3 3         5 2      7
+--R               (1920a b c  - 2880a b c  + 960a b c  - 96b c)d
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  4
+--R               (25200a c  - 37800a b c  + 12600a b c  - 1260b c )d
+--R             + 
+--R                     3   4         2 3 3          5 2       7   2       4 4
+--R               (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d  + 240a c
+--R             + 
+--R                     3 2 3      2 4 2        6      8
+--R               - 240a b c  - 60a b c  + 48a b c - 6b
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  5
+--R               (30240a c  - 45360a b c  + 15120a b c  - 1512b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   3
+--R               (13440a b c  - 20160a b c  + 6720a b c  - 672b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8
+--R               (1440a c  - 1440a b c  - 360a b c  + 288a b c - 36b )d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  6
+--R               (25200a c  - 37800a b c  + 12600a b c  - 1260b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   4
+--R               (16800a b c  - 25200a b c  + 8400a b c  - 840b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  2
+--R               (3600a c  - 3600a b c  - 900a b c  + 720a b c - 90b )d
+--R             + 
+--R                   4   3       3 3 2       2 5         7
+--R               240a b c  - 360a b c  + 120a b c - 12a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                      3 5         2 2 4          4 3       6 2  7
+--R               (14400a c  - 21600a b c  + 7200a b c  - 720b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   5
+--R               (13440a b c  - 20160a b c  + 6720a b c  - 672b c)d
+--R             + 
+--R                     4 4        3 2 3        2 4 2         6        8  3
+--R               (4800a c  - 4800a b c  - 1200a b c  + 960a b c - 120b )d
+--R             + 
+--R                    4   3        3 3 2       2 5         7
+--R               (960a b c  - 1440a b c  + 480a b c - 48a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     3 5        2 2 4          4 3       6 2  8
+--R               (5400a c  - 8100a b c  + 2700a b c  - 270b c )d
+--R             + 
+--R                     3   4         2 3 3          5 2       7   6
+--R               (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  4
+--R               (3600a c  - 3600a b c  - 900a b c  + 720a b c - 90b )d
+--R             + 
+--R                     4   3        3 3 2       2 5         7  2       5 3
+--R               (1440a b c  - 2160a b c  + 720a b c - 72a b )d  + 120a c
+--R             + 
+--R                     4 2 2      3 4      2 6
+--R               - 180a b c  + 60a b c - 6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     3 5        2 2 4         4 3      6 2  9
+--R               (1200a c  - 1800a b c  + 600a b c  - 60b c )d
+--R             + 
+--R                     3   4        2 3 3         5 2      7   7
+--R               (1920a b c  - 2880a b c  + 960a b c  - 96b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  5
+--R               (1440a c  - 1440a b c  - 360a b c  + 288a b c - 36b )d
+--R             + 
+--R                    4   3        3 3 2       2 5         7  3
+--R               (960a b c  - 1440a b c  + 480a b c - 48a b )d
+--R             + 
+--R                    5 3       4 2 2       3 4       2 6
+--R               (240a c  - 360a b c  + 120a b c - 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                3 5       2 2 4        4 3     6 2  10
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )d
+--R         + 
+--R                3   4       2 3 3         5 2      7   8
+--R           (240a b c  - 360a b c  + 120a b c  - 12b c)d
+--R         + 
+--R                4 4       3 2 3      2 4 2        6      8  6
+--R           (240a c  - 240a b c  - 60a b c  + 48a b c - 6b )d
+--R         + 
+--R                4   3       3 3 2       2 5         7  4
+--R           (240a b c  - 360a b c  + 120a b c - 12a b )d
+--R         + 
+--R                5 3       4 2 2      3 4      2 6  2
+--R           (120a c  - 180a b c  + 60a b c - 6a b )d
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                   2   4        3 3     5 2  10 10
+--R               (48a b c  - 24a b c  + 3b c )e  x
+--R             + 
+--R                    2   4         3 3      5 2    9 9
+--R               (480a b c  - 240a b c  + 30b c )d e x
+--R             + 
+--R                         2   4          3 3       5 2  2      2 2 3        4 2
+--R                   (2160a b c  - 1080a b c  + 135b c )d  + 96a b c  - 48a b c
+--R                 + 
+--R                     6
+--R                   6b c
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  3
+--R                   (5760a b c  - 2880a b c  + 360b c )d
+--R                 + 
+--R                        2 2 3         4 2      6
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  4
+--R                   (10080a b c  - 5040a b c  + 630b c )d
+--R                 + 
+--R                       2 2 3          4 2       6   2      3   3        5      7
+--R                 (2688a b c  - 1344a b c  + 168b c)d  + 96a b c  - 18a b c + 3b
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  5
+--R                   (12096a b c  - 6048a b c  + 756b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   3
+--R                   (5376a b c  - 2688a b c  + 336b c)d
+--R                 + 
+--R                        3   3         5       7
+--R                   (576a b c  - 108a b c + 18b )d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  6
+--R                   (10080a b c  - 5040a b c  + 630b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   4
+--R                   (6720a b c  - 3360a b c  + 420b c)d
+--R                 + 
+--R                       3   3         5       7  2      3 2 2      2 4        6
+--R                 (1440a b c  - 270a b c + 45b )d  + 96a b c  - 48a b c + 6a b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  7
+--R                   (5760a b c  - 2880a b c  + 360b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   5
+--R                   (5376a b c  - 2688a b c  + 336b c)d
+--R                 + 
+--R                         3   3         5       7  3
+--R                   (1920a b c  - 360a b c + 60b )d
+--R                 + 
+--R                        3 2 2       2 4         6
+--R                   (384a b c  - 192a b c + 24a b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  8
+--R                   (2160a b c  - 1080a b c  + 135b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   6
+--R                   (2688a b c  - 1344a b c  + 168b c)d
+--R                 + 
+--R                         3   3         5       7  4
+--R                   (1440a b c  - 270a b c + 45b )d
+--R                 + 
+--R                      3 2 2       2 4         6  2      4   2      3 3      2 5
+--R                 (576a b c  - 288a b c + 36a b )d  + 48a b c  - 24a b c + 3a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                        2   4         3 3      5 2  9
+--R                   (480a b c  - 240a b c  + 30b c )d
+--R                 + 
+--R                        2 2 3         4 2      6   7
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R                 + 
+--R                        3   3         5       7  5
+--R                   (576a b c  - 108a b c + 18b )d
+--R                 + 
+--R                        3 2 2       2 4         6  3
+--R                   (384a b c  - 192a b c + 24a b )d
+--R                 + 
+--R                       4   2      3 3      2 5
+--R                   (96a b c  - 48a b c + 6a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                   2   4        3 3     5 2  10       2 2 3        4 2     6   8
+--R               (48a b c  - 24a b c  + 3b c )d   + (96a b c  - 48a b c  + 6b c)d
+--R             + 
+--R                   3   3        5      7  6       3 2 2      2 4        6  4
+--R               (96a b c  - 18a b c + 3b )d  + (96a b c  - 48a b c + 6a b )d
+--R             + 
+--R                   4   2      3 3      2 5  2
+--R               (48a b c  - 24a b c + 3a b )d
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                      2   4        3 3      5 2  10 10
+--R               (- 192a b c  + 96a b c  - 12b c )e  x
+--R             + 
+--R                       2   4         3 3       5 2    9 9
+--R               (- 1920a b c  + 960a b c  - 120b c )d e x
+--R             + 
+--R                           2   4          3 3       5 2  2       2 2 3
+--R                   (- 8640a b c  + 4320a b c  - 540b c )d  - 384a b c
+--R                 + 
+--R                         4 2      6
+--R                   192a b c  - 24b c
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  3
+--R                   (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                 + 
+--R                           2 2 3          4 2       6
+--R                   (- 3072a b c  + 1536a b c  - 192b c)d
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  4
+--R                   (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                 + 
+--R                            2 2 3          4 2       6   2       3   3        5
+--R                   (- 10752a b c  + 5376a b c  - 672b c)d  - 384a b c  + 72a b c
+--R                 + 
+--R                        7
+--R                   - 12b
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  5
+--R                   (- 48384a b c  + 24192a b c  - 3024b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   3
+--R                   (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                 + 
+--R                           3   3         5       7
+--R                   (- 2304a b c  + 432a b c - 72b )d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  6
+--R                   (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   4
+--R                   (- 26880a b c  + 13440a b c  - 1680b c)d
+--R                 + 
+--R                           3   3          5        7  2       3 2 2       2 4
+--R                   (- 5760a b c  + 1080a b c - 180b )d  - 384a b c  + 192a b c
+--R                 + 
+--R                          6
+--R                   - 24a b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  7
+--R                   (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   5
+--R                   (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                 + 
+--R                           3   3          5        7  3
+--R                   (- 7680a b c  + 1440a b c - 240b )d
+--R                 + 
+--R                           3 2 2       2 4         6
+--R                   (- 1536a b c  + 768a b c - 96a b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2   4          3 3       5 2  8
+--R                   (- 8640a b c  + 4320a b c  - 540b c )d
+--R                 + 
+--R                            2 2 3          4 2       6   6
+--R                   (- 10752a b c  + 5376a b c  - 672b c)d
+--R                 + 
+--R                           3   3          5        7  4
+--R                   (- 5760a b c  + 1080a b c - 180b )d
+--R                 + 
+--R                           3 2 2        2 4          6  2       4   2      3 3
+--R                   (- 2304a b c  + 1152a b c - 144a b )d  - 192a b c  + 96a b c
+--R                 + 
+--R                        2 5
+--R                   - 12a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2   4         3 3       5 2  9
+--R                   (- 1920a b c  + 960a b c  - 120b c )d
+--R                 + 
+--R                           2 2 3          4 2       6   7
+--R                   (- 3072a b c  + 1536a b c  - 192b c)d
+--R                 + 
+--R                           3   3         5       7  5
+--R                   (- 2304a b c  + 432a b c - 72b )d
+--R                 + 
+--R                           3 2 2       2 4         6  3
+--R                   (- 1536a b c  + 768a b c - 96a b )d
+--R                 + 
+--R                          4   2       3 3       2 5
+--R                   (- 384a b c  + 192a b c - 24a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                      2   4        3 3      5 2  10
+--R               (- 192a b c  + 96a b c  - 12b c )d
+--R             + 
+--R                      2 2 3         4 2      6   8
+--R               (- 384a b c  + 192a b c  - 24b c)d
+--R             + 
+--R                      3   3        5       7  6
+--R               (- 384a b c  + 72a b c - 12b )d
+--R             + 
+--R                      3 2 2       2 4         6  4
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R             + 
+--R                      4   2      3 3       2 5  2
+--R               (- 192a b c  + 96a b c - 12a b )d
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                 3 4      2 2 3       4 2  8 8
+--R           (- 60a c  + 42a b c  - 6a b c )e x
+--R         + 
+--R                  3 4       2 2 3        4 2    7 7
+--R           (- 480a c  + 336a b c  - 48a b c )d e x
+--R         + 
+--R                       3 4        2 2 3         4 2  2       3   3      2 3 2
+--R               (- 1680a c  + 1176a b c  - 168a b c )d  - 138a b c  + 87a b c
+--R             + 
+--R                      5
+--R               - 12a b c
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  3
+--R               (- 3360a c  + 2352a b c  - 336a b c )d
+--R             + 
+--R                      3   3       2 3 2        5
+--R               (- 828a b c  + 522a b c  - 72a b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  4
+--R               (- 4200a c  + 2940a b c  - 420a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   2       4 3      3 2 2
+--R               (- 2070a b c  + 1305a b c  - 180a b c)d  - 100a c  - 14a b c
+--R             + 
+--R                  2 4        6
+--R               36a b c - 6a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  5
+--R               (- 3360a c  + 2352a b c  - 336a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   3
+--R               (- 2760a b c  + 1740a b c  - 240a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6
+--R               (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  6
+--R               (- 1680a c  + 1176a b c  - 168a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   4
+--R               (- 2070a b c  + 1305a b c  - 180a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6  2       4   2
+--R               (- 600a c  - 84a b c  + 216a b c - 36a b )d  - 122a b c
+--R             + 
+--R                  3 3      2 5
+--R               68a b c - 9a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3 4       2 2 3        4 2  7
+--R               (- 480a c  + 336a b c  - 48a b c )d
+--R             + 
+--R                      3   3       2 3 2        5   5
+--R               (- 828a b c  + 522a b c  - 72a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6  3
+--R               (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R             + 
+--R                      4   2       3 3       2 5
+--R               (- 244a b c  + 136a b c - 18a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 3 4      2 2 3       4 2  8
+--R           (- 60a c  + 42a b c  - 6a b c )d
+--R         + 
+--R                  3   3      2 3 2        5   6
+--R           (- 138a b c  + 87a b c  - 12a b c)d
+--R         + 
+--R                  4 3      3 2 2      2 4        6  4
+--R           (- 100a c  - 14a b c  + 36a b c - 6a b )d
+--R         + 
+--R                  4   2      3 3      2 5  2      5 2      4 2      3 4
+--R           (- 122a b c  + 68a b c - 9a b )d  - 32a c  + 16a b c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             6 4      5 2 3     4 4 2  11 10
+--R         (64a c  - 32a b c  + 4a b c )e  x
+--R       + 
+--R              6 4       5 2 3      4 4 2    10 9
+--R         (640a c  - 320a b c  + 40a b c )d e  x
+--R       + 
+--R                     6 4        5 2 3       4 4 2  2       6   3      5 3 2
+--R               (2880a c  - 1440a b c  + 180a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 4 5
+--R               8a b c
+--R        *
+--R            9 8
+--R           e x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  3
+--R             (7680a c  - 3840a b c  + 480a b c )d
+--R           + 
+--R                   6   3       5 3 2      4 5
+--R             (1024a b c  - 512a b c  + 64a b c)d
+--R        *
+--R            8 7
+--R           e x
+--R       + 
+--R                    6 4        5 2 3       4 4 2  4
+--R             (13440a c  - 6720a b c  + 840a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   2       7 3      5 4      4 6
+--R             (3584a b c  - 1792a b c  + 224a b c)d  + 128a c  - 24a b c + 4a b
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                    6 4        5 2 3        4 4 2  5
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   3
+--R             (7168a b c  - 3584a b c  + 448a b c)d
+--R           + 
+--R                  7 3       5 4       4 6
+--R             (768a c  - 144a b c + 24a b )d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                    6 4        5 2 3       4 4 2  6
+--R             (13440a c  - 6720a b c  + 840a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   4
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   7 3       5 4       4 6  2       7   2      6 3      5 5
+--R             (1920a c  - 360a b c + 60a b )d  + 128a b c  - 64a b c + 8a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  7
+--R             (7680a c  - 3840a b c  + 480a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   5
+--R             (7168a b c  - 3584a b c  + 448a b c)d
+--R           + 
+--R                 7 3       5 4       4 6  3        7   2       6 3       5 5
+--R           (2560a c  - 480a b c + 80a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  8
+--R             (2880a c  - 1440a b c  + 180a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   6
+--R             (3584a b c  - 1792a b c  + 224a b c)d
+--R           + 
+--R                   7 3       5 4       4 6  4
+--R             (1920a c  - 360a b c + 60a b )d
+--R           + 
+--R                  7   2       6 3       5 5  2      8 2      7 2      6 4
+--R             (768a b c  - 384a b c + 48a b )d  + 64a c  - 32a b c + 4a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  6 4       5 2 3      4 4 2  9
+--R             (640a c  - 320a b c  + 40a b c )d
+--R           + 
+--R                   6   3       5 3 2      4 5   7
+--R             (1024a b c  - 512a b c  + 64a b c)d
+--R           + 
+--R                  7 3       5 4       4 6  5        7   2       6 3       5 5  3
+--R             (768a c  - 144a b c + 24a b )d  + (512a b c  - 256a b c + 32a b )d
+--R           + 
+--R                  8 2      7 2      6 4
+--R             (128a c  - 64a b c + 8a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 6 4      5 2 3     4 4 2  10
+--R             (64a c  - 32a b c  + 4a b c )d
+--R           + 
+--R                  6   3      5 3 2     4 5   8        7 3      5 4      4 6  6
+--R             (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R           + 
+--R                  7   2      6 3      5 5  4       8 2      7 2      6 4  2
+--R             (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 893
+
+--S 894 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3 5      2 2 4        4 3     6 2  10 10
+--R             (60a c  - 90a b c  + 30a b c  - 3b c )e  x
+--R           + 
+--R                  3 5       2 2 4         4 3      6 2    9 9
+--R             (600a c  - 900a b c  + 300a b c  - 30b c )d e x
+--R           + 
+--R                       3 5        2 2 4          4 3       6 2  2       3   4
+--R                 (2700a c  - 4050a b c  + 1350a b c  - 135b c )d  + 120a b c
+--R               + 
+--R                       2 3 3        5 2     7
+--R                 - 180a b c  + 60a b c  - 6b c
+--R            *
+--R                8 8
+--R               e x
+--R           + 
+--R                       3 5         2 2 4          4 3       6 2  3
+--R                 (7200a c  - 10800a b c  + 3600a b c  - 360b c )d
+--R               + 
+--R                      3   4        2 3 3         5 2      7
+--R                 (960a b c  - 1440a b c  + 480a b c  - 48b c)d
+--R            *
+--R                7 7
+--R               e x
+--R           + 
+--R                        3 5         2 2 4          4 3       6 2  4
+--R                 (12600a c  - 18900a b c  + 6300a b c  - 630b c )d
+--R               + 
+--R                       3   4        2 3 3          5 2       7   2       4 4
+--R                 (3360a b c  - 5040a b c  + 1680a b c  - 168b c)d  + 120a c
+--R               + 
+--R                       3 2 3      2 4 2        6      8
+--R                 - 120a b c  - 30a b c  + 24a b c - 3b
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                        3 5         2 2 4          4 3       6 2  5
+--R                 (15120a c  - 22680a b c  + 7560a b c  - 756b c )d
+--R               + 
+--R                       3   4         2 3 3          5 2       7   3
+--R                 (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d
+--R               + 
+--R                      4 4       3 2 3       2 4 2         6       8
+--R                 (720a c  - 720a b c  - 180a b c  + 144a b c - 18b )d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                        3 5         2 2 4          4 3       6 2  6
+--R                 (12600a c  - 18900a b c  + 6300a b c  - 630b c )d
+--R               + 
+--R                       3   4         2 3 3          5 2       7   4
+--R                 (8400a b c  - 12600a b c  + 4200a b c  - 420b c)d
+--R               + 
+--R                       4 4        3 2 3       2 4 2         6       8  2
+--R                 (1800a c  - 1800a b c  - 450a b c  + 360a b c - 45b )d
+--R               + 
+--R                     4   3       3 3 2      2 5        7
+--R                 120a b c  - 180a b c  + 60a b c - 6a b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                       3 5         2 2 4          4 3       6 2  7
+--R                 (7200a c  - 10800a b c  + 3600a b c  - 360b c )d
+--R               + 
+--R                       3   4         2 3 3          5 2       7   5
+--R                 (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d
+--R               + 
+--R                       4 4        3 2 3       2 4 2         6       8  3
+--R                 (2400a c  - 2400a b c  - 600a b c  + 480a b c - 60b )d
+--R               + 
+--R                      4   3       3 3 2       2 5         7
+--R                 (480a b c  - 720a b c  + 240a b c - 24a b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                       3 5        2 2 4          4 3       6 2  8
+--R                 (2700a c  - 4050a b c  + 1350a b c  - 135b c )d
+--R               + 
+--R                       3   4        2 3 3          5 2       7   6
+--R                 (3360a b c  - 5040a b c  + 1680a b c  - 168b c)d
+--R               + 
+--R                       4 4        3 2 3       2 4 2         6       8  4
+--R                 (1800a c  - 1800a b c  - 450a b c  + 360a b c - 45b )d
+--R               + 
+--R                      4   3        3 3 2       2 5         7  2      5 3
+--R                 (720a b c  - 1080a b c  + 360a b c - 36a b )d  + 60a c
+--R               + 
+--R                      4 2 2      3 4      2 6
+--R                 - 90a b c  + 30a b c - 3a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                      3 5       2 2 4         4 3      6 2  9
+--R                 (600a c  - 900a b c  + 300a b c  - 30b c )d
+--R               + 
+--R                      3   4        2 3 3         5 2      7   7
+--R                 (960a b c  - 1440a b c  + 480a b c  - 48b c)d
+--R               + 
+--R                      4 4       3 2 3       2 4 2         6       8  5
+--R                 (720a c  - 720a b c  - 180a b c  + 144a b c - 18b )d
+--R               + 
+--R                      4   3       3 3 2       2 5         7  3
+--R                 (480a b c  - 720a b c  + 240a b c - 24a b )d
+--R               + 
+--R                      5 3       4 2 2      3 4      2 6
+--R                 (120a c  - 180a b c  + 60a b c - 6a b )d
+--R            *
+--R               e x
+--R           + 
+--R                 3 5      2 2 4        4 3     6 2  10
+--R             (60a c  - 90a b c  + 30a b c  - 3b c )d
+--R           + 
+--R                  3   4       2 3 3        5 2     7   8
+--R             (120a b c  - 180a b c  + 60a b c  - 6b c)d
+--R           + 
+--R                  4 4       3 2 3      2 4 2        6      8  6
+--R             (120a c  - 120a b c  - 30a b c  + 24a b c - 3b )d
+--R           + 
+--R                  4   3       3 3 2      2 5        7  4
+--R             (120a b c  - 180a b c  + 60a b c - 6a b )d
+--R           + 
+--R                 5 3      4 2 2      3 4      2 6  2
+--R             (60a c  - 90a b c  + 30a b c - 3a b )d
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                     2   4        3 3     5 2  10 10
+--R                 (48a b c  - 24a b c  + 3b c )e  x
+--R               + 
+--R                      2   4         3 3      5 2    9 9
+--R                 (480a b c  - 240a b c  + 30b c )d e x
+--R               + 
+--R                           2   4          3 3       5 2  2      2 2 3        4 2
+--R                     (2160a b c  - 1080a b c  + 135b c )d  + 96a b c  - 48a b c
+--R                   + 
+--R                       6
+--R                     6b c
+--R                *
+--R                    8 8
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  3
+--R                     (5760a b c  - 2880a b c  + 360b c )d
+--R                   + 
+--R                          2 2 3         4 2      6
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                *
+--R                    7 7
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  4
+--R                     (10080a b c  - 5040a b c  + 630b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   2      3   3        5
+--R                     (2688a b c  - 1344a b c  + 168b c)d  + 96a b c  - 18a b c
+--R                   + 
+--R                       7
+--R                     3b
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  5
+--R                     (12096a b c  - 6048a b c  + 756b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   3
+--R                     (5376a b c  - 2688a b c  + 336b c)d
+--R                   + 
+--R                          3   3         5       7
+--R                     (576a b c  - 108a b c + 18b )d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  6
+--R                     (10080a b c  - 5040a b c  + 630b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   4
+--R                     (6720a b c  - 3360a b c  + 420b c)d
+--R                   + 
+--R                         3   3         5       7  2      3 2 2      2 4        6
+--R                   (1440a b c  - 270a b c + 45b )d  + 96a b c  - 48a b c + 6a b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  7
+--R                     (5760a b c  - 2880a b c  + 360b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   5
+--R                     (5376a b c  - 2688a b c  + 336b c)d
+--R                   + 
+--R                           3   3         5       7  3
+--R                     (1920a b c  - 360a b c + 60b )d
+--R                   + 
+--R                          3 2 2       2 4         6
+--R                     (384a b c  - 192a b c + 24a b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  8
+--R                     (2160a b c  - 1080a b c  + 135b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   6
+--R                     (2688a b c  - 1344a b c  + 168b c)d
+--R                   + 
+--R                           3   3         5       7  4
+--R                     (1440a b c  - 270a b c + 45b )d
+--R                   + 
+--R                          3 2 2       2 4         6  2      4   2      3 3
+--R                     (576a b c  - 288a b c + 36a b )d  + 48a b c  - 24a b c
+--R                   + 
+--R                       2 5
+--R                     3a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                          2   4         3 3      5 2  9
+--R                     (480a b c  - 240a b c  + 30b c )d
+--R                   + 
+--R                          2 2 3         4 2      6   7
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                   + 
+--R                          3   3         5       7  5
+--R                     (576a b c  - 108a b c + 18b )d
+--R                   + 
+--R                          3 2 2       2 4         6  3
+--R                     (384a b c  - 192a b c + 24a b )d
+--R                   + 
+--R                         4   2      3 3      2 5
+--R                     (96a b c  - 48a b c + 6a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                     2   4        3 3     5 2  10
+--R                 (48a b c  - 24a b c  + 3b c )d
+--R               + 
+--R                     2 2 3        4 2     6   8       3   3        5      7  6
+--R                 (96a b c  - 48a b c  + 6b c)d  + (96a b c  - 18a b c + 3b )d
+--R               + 
+--R                   3 2 2      2 4        6  4       4   2      3 3      2 5  2
+--R               (96a b c  - 48a b c + 6a b )d  + (48a b c  - 24a b c + 3a b )d
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                        2   4        3 3      5 2  10 10
+--R                 (- 192a b c  + 96a b c  - 12b c )e  x
+--R               + 
+--R                         2   4         3 3       5 2    9 9
+--R                 (- 1920a b c  + 960a b c  - 120b c )d e x
+--R               + 
+--R                             2   4          3 3       5 2  2       2 2 3
+--R                     (- 8640a b c  + 4320a b c  - 540b c )d  - 384a b c
+--R                   + 
+--R                           4 2      6
+--R                     192a b c  - 24b c
+--R                *
+--R                    8 8
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  3
+--R                     (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                   + 
+--R                             2 2 3          4 2       6
+--R                     (- 3072a b c  + 1536a b c  - 192b c)d
+--R                *
+--R                    7 7
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  4
+--R                     (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                   + 
+--R                              2 2 3          4 2       6   2       3   3
+--R                     (- 10752a b c  + 5376a b c  - 672b c)d  - 384a b c
+--R                   + 
+--R                          5       7
+--R                     72a b c - 12b
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  5
+--R                     (- 48384a b c  + 24192a b c  - 3024b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   3
+--R                     (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                   + 
+--R                             3   3         5       7
+--R                     (- 2304a b c  + 432a b c - 72b )d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  6
+--R                     (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   4
+--R                     (- 26880a b c  + 13440a b c  - 1680b c)d
+--R                   + 
+--R                             3   3          5        7  2       3 2 2       2 4
+--R                     (- 5760a b c  + 1080a b c - 180b )d  - 384a b c  + 192a b c
+--R                   + 
+--R                            6
+--R                     - 24a b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  7
+--R                     (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   5
+--R                     (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                   + 
+--R                             3   3          5        7  3
+--R                     (- 7680a b c  + 1440a b c - 240b )d
+--R                   + 
+--R                             3 2 2       2 4         6
+--R                     (- 1536a b c  + 768a b c - 96a b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                             2   4          3 3       5 2  8
+--R                     (- 8640a b c  + 4320a b c  - 540b c )d
+--R                   + 
+--R                              2 2 3          4 2       6   6
+--R                     (- 10752a b c  + 5376a b c  - 672b c)d
+--R                   + 
+--R                             3   3          5        7  4
+--R                     (- 5760a b c  + 1080a b c - 180b )d
+--R                   + 
+--R                             3 2 2        2 4          6  2       4   2
+--R                     (- 2304a b c  + 1152a b c - 144a b )d  - 192a b c
+--R                   + 
+--R                        3 3       2 5
+--R                     96a b c - 12a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                             2   4         3 3       5 2  9
+--R                     (- 1920a b c  + 960a b c  - 120b c )d
+--R                   + 
+--R                             2 2 3          4 2       6   7
+--R                     (- 3072a b c  + 1536a b c  - 192b c)d
+--R                   + 
+--R                             3   3         5       7  5
+--R                     (- 2304a b c  + 432a b c - 72b )d
+--R                   + 
+--R                             3 2 2       2 4         6  3
+--R                     (- 1536a b c  + 768a b c - 96a b )d
+--R                   + 
+--R                            4   2       3 3       2 5
+--R                     (- 384a b c  + 192a b c - 24a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                        2   4        3 3      5 2  10
+--R                 (- 192a b c  + 96a b c  - 12b c )d
+--R               + 
+--R                        2 2 3         4 2      6   8
+--R                 (- 384a b c  + 192a b c  - 24b c)d
+--R               + 
+--R                        3   3        5       7  6
+--R                 (- 384a b c  + 72a b c - 12b )d
+--R               + 
+--R                        3 2 2       2 4         6  4
+--R                 (- 384a b c  + 192a b c - 24a b )d
+--R               + 
+--R                        4   2      3 3       2 5  2
+--R                 (- 192a b c  + 96a b c - 12a b )d
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                   3 4      2 2 3       4 2  8 8
+--R             (- 60a c  + 42a b c  - 6a b c )e x
+--R           + 
+--R                    3 4       2 2 3        4 2    7 7
+--R             (- 480a c  + 336a b c  - 48a b c )d e x
+--R           + 
+--R                         3 4        2 2 3         4 2  2       3   3      2 3 2
+--R                 (- 1680a c  + 1176a b c  - 168a b c )d  - 138a b c  + 87a b c
+--R               + 
+--R                        5
+--R                 - 12a b c
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  3
+--R                 (- 3360a c  + 2352a b c  - 336a b c )d
+--R               + 
+--R                        3   3       2 3 2        5
+--R                 (- 828a b c  + 522a b c  - 72a b c)d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  4
+--R                 (- 4200a c  + 2940a b c  - 420a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   2       4 3      3 2 2
+--R                 (- 2070a b c  + 1305a b c  - 180a b c)d  - 100a c  - 14a b c
+--R               + 
+--R                    2 4        6
+--R                 36a b c - 6a b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  5
+--R                 (- 3360a c  + 2352a b c  - 336a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   3
+--R                 (- 2760a b c  + 1740a b c  - 240a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6
+--R                 (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  6
+--R                 (- 1680a c  + 1176a b c  - 168a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   4
+--R                 (- 2070a b c  + 1305a b c  - 180a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6  2       4   2
+--R                 (- 600a c  - 84a b c  + 216a b c - 36a b )d  - 122a b c
+--R               + 
+--R                    3 3      2 5
+--R                 68a b c - 9a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                        3 4       2 2 3        4 2  7
+--R                 (- 480a c  + 336a b c  - 48a b c )d
+--R               + 
+--R                        3   3       2 3 2        5   5
+--R                 (- 828a b c  + 522a b c  - 72a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6  3
+--R                 (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R               + 
+--R                        4   2       3 3       2 5
+--R                 (- 244a b c  + 136a b c - 18a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   3 4      2 2 3       4 2  8
+--R             (- 60a c  + 42a b c  - 6a b c )d
+--R           + 
+--R                    3   3      2 3 2        5   6
+--R             (- 138a b c  + 87a b c  - 12a b c)d
+--R           + 
+--R                    4 3      3 2 2      2 4        6  4
+--R             (- 100a c  - 14a b c  + 36a b c - 6a b )d
+--R           + 
+--R                    4   2      3 3      2 5  2      5 2      4 2      3 4
+--R             (- 122a b c  + 68a b c - 9a b )d  - 32a c  + 16a b c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               6 4      5 2 3     4 4 2  11 10
+--R           (64a c  - 32a b c  + 4a b c )e  x
+--R         + 
+--R                6 4       5 2 3      4 4 2    10 9
+--R           (640a c  - 320a b c  + 40a b c )d e  x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  2       6   3      5 3 2
+--R               (2880a c  - 1440a b c  + 180a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 4 5
+--R               8a b c
+--R          *
+--R              9 8
+--R             e x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  3
+--R               (7680a c  - 3840a b c  + 480a b c )d
+--R             + 
+--R                     6   3       5 3 2      4 5
+--R               (1024a b c  - 512a b c  + 64a b c)d
+--R          *
+--R              8 7
+--R             e x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  4
+--R               (13440a c  - 6720a b c  + 840a b c )d
+--R             + 
+--R                   6   3        5 3 2       4 5   2       7 3      5 4      4 6
+--R             (3584a b c  - 1792a b c  + 224a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                      6 4        5 2 3        4 4 2  5
+--R               (16128a c  - 8064a b c  + 1008a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   3
+--R               (7168a b c  - 3584a b c  + 448a b c)d
+--R             + 
+--R                    7 3       5 4       4 6
+--R               (768a c  - 144a b c + 24a b )d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  6
+--R               (13440a c  - 6720a b c  + 840a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   4
+--R               (8960a b c  - 4480a b c  + 560a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  2       7   2      6 3      5 5
+--R               (1920a c  - 360a b c + 60a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  7
+--R               (7680a c  - 3840a b c  + 480a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   5
+--R               (7168a b c  - 3584a b c  + 448a b c)d
+--R             + 
+--R                   7 3       5 4       4 6  3        7   2       6 3       5 5
+--R             (2560a c  - 480a b c + 80a b )d  + (512a b c  - 256a b c + 32a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  8
+--R               (2880a c  - 1440a b c  + 180a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   6
+--R               (3584a b c  - 1792a b c  + 224a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  4
+--R               (1920a c  - 360a b c + 60a b )d
+--R             + 
+--R                    7   2       6 3       5 5  2      8 2      7 2      6 4
+--R               (768a b c  - 384a b c + 48a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    6 4       5 2 3      4 4 2  9
+--R               (640a c  - 320a b c  + 40a b c )d
+--R             + 
+--R                     6   3       5 3 2      4 5   7
+--R               (1024a b c  - 512a b c  + 64a b c)d
+--R             + 
+--R                    7 3       5 4       4 6  5
+--R               (768a c  - 144a b c + 24a b )d
+--R             + 
+--R                    7   2       6 3       5 5  3        8 2      7 2      6 4
+--R               (512a b c  - 256a b c + 32a b )d  + (128a c  - 64a b c + 8a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   6 4      5 2 3     4 4 2  10
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    6   3      5 3 2     4 5   8        7 3      5 4      4 6  6
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    7   2      6 3      5 5  4       8 2      7 2      6 4  2
+--R               (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R          *
+--R             e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    3 5       2 2 4        4 3     6 2  10 10
+--R             (- 120a c  + 180a b c  - 60a b c  + 6b c )e  x
+--R           + 
+--R                     3 5        2 2 4         4 3      6 2    9 9
+--R             (- 1200a c  + 1800a b c  - 600a b c  + 60b c )d e x
+--R           + 
+--R                         3 5        2 2 4          4 3       6 2  2       3   4
+--R                 (- 5400a c  + 8100a b c  - 2700a b c  + 270b c )d  - 240a b c
+--R               + 
+--R                     2 3 3         5 2      7
+--R                 360a b c  - 120a b c  + 12b c
+--R            *
+--R                8 8
+--R               e x
+--R           + 
+--R                          3 5         2 2 4          4 3       6 2  3
+--R                 (- 14400a c  + 21600a b c  - 7200a b c  + 720b c )d
+--R               + 
+--R                         3   4        2 3 3         5 2      7
+--R                 (- 1920a b c  + 2880a b c  - 960a b c  + 96b c)d
+--R            *
+--R                7 7
+--R               e x
+--R           + 
+--R                          3 5         2 2 4           4 3        6 2  4
+--R                 (- 25200a c  + 37800a b c  - 12600a b c  + 1260b c )d
+--R               + 
+--R                         3   4         2 3 3          5 2       7   2       4 4
+--R                 (- 6720a b c  + 10080a b c  - 3360a b c  + 336b c)d  - 240a c
+--R               + 
+--R                     3 2 3      2 4 2        6      8
+--R                 240a b c  + 60a b c  - 48a b c + 6b
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                          3 5         2 2 4           4 3        6 2  5
+--R                 (- 30240a c  + 45360a b c  - 15120a b c  + 1512b c )d
+--R               + 
+--R                          3   4         2 3 3          5 2       7   3
+--R                 (- 13440a b c  + 20160a b c  - 6720a b c  + 672b c)d
+--R               + 
+--R                         4 4        3 2 3       2 4 2         6       8
+--R                 (- 1440a c  + 1440a b c  + 360a b c  - 288a b c + 36b )d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                          3 5         2 2 4           4 3        6 2  6
+--R                 (- 25200a c  + 37800a b c  - 12600a b c  + 1260b c )d
+--R               + 
+--R                          3   4         2 3 3          5 2       7   4
+--R                 (- 16800a b c  + 25200a b c  - 8400a b c  + 840b c)d
+--R               + 
+--R                         4 4        3 2 3       2 4 2         6       8  2
+--R                 (- 3600a c  + 3600a b c  + 900a b c  - 720a b c + 90b )d
+--R               + 
+--R                       4   3       3 3 2       2 5         7
+--R                 - 240a b c  + 360a b c  - 120a b c + 12a b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                          3 5         2 2 4          4 3       6 2  7
+--R                 (- 14400a c  + 21600a b c  - 7200a b c  + 720b c )d
+--R               + 
+--R                          3   4         2 3 3          5 2       7   5
+--R                 (- 13440a b c  + 20160a b c  - 6720a b c  + 672b c)d
+--R               + 
+--R                         4 4        3 2 3        2 4 2         6        8  3
+--R                 (- 4800a c  + 4800a b c  + 1200a b c  - 960a b c + 120b )d
+--R               + 
+--R                        4   3        3 3 2       2 5         7
+--R                 (- 960a b c  + 1440a b c  - 480a b c + 48a b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                         3 5        2 2 4          4 3       6 2  8
+--R                 (- 5400a c  + 8100a b c  - 2700a b c  + 270b c )d
+--R               + 
+--R                         3   4         2 3 3          5 2       7   6
+--R                 (- 6720a b c  + 10080a b c  - 3360a b c  + 336b c)d
+--R               + 
+--R                         4 4        3 2 3       2 4 2         6       8  4
+--R                 (- 3600a c  + 3600a b c  + 900a b c  - 720a b c + 90b )d
+--R               + 
+--R                         4   3        3 3 2       2 5         7  2       5 3
+--R                 (- 1440a b c  + 2160a b c  - 720a b c + 72a b )d  - 120a c
+--R               + 
+--R                     4 2 2      3 4      2 6
+--R                 180a b c  - 60a b c + 6a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                         3 5        2 2 4         4 3      6 2  9
+--R                 (- 1200a c  + 1800a b c  - 600a b c  + 60b c )d
+--R               + 
+--R                         3   4        2 3 3         5 2      7   7
+--R                 (- 1920a b c  + 2880a b c  - 960a b c  + 96b c)d
+--R               + 
+--R                         4 4        3 2 3       2 4 2         6       8  5
+--R                 (- 1440a c  + 1440a b c  + 360a b c  - 288a b c + 36b )d
+--R               + 
+--R                        4   3        3 3 2       2 5         7  3
+--R                 (- 960a b c  + 1440a b c  - 480a b c + 48a b )d
+--R               + 
+--R                        5 3       4 2 2       3 4       2 6
+--R                 (- 240a c  + 360a b c  - 120a b c + 12a b )d
+--R            *
+--R               e x
+--R           + 
+--R                    3 5       2 2 4        4 3     6 2  10
+--R             (- 120a c  + 180a b c  - 60a b c  + 6b c )d
+--R           + 
+--R                    3   4       2 3 3         5 2      7   8
+--R             (- 240a b c  + 360a b c  - 120a b c  + 12b c)d
+--R           + 
+--R                    4 4       3 2 3      2 4 2        6      8  6
+--R             (- 240a c  + 240a b c  + 60a b c  - 48a b c + 6b )d
+--R           + 
+--R                    4   3       3 3 2       2 5         7  4
+--R             (- 240a b c  + 360a b c  - 120a b c + 12a b )d
+--R           + 
+--R                    5 3       4 2 2      3 4      2 6  2
+--R             (- 120a c  + 180a b c  - 60a b c + 6a b )d
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                     2   4        3 3     5 2  10 10
+--R                 (48a b c  - 24a b c  + 3b c )e  x
+--R               + 
+--R                      2   4         3 3      5 2    9 9
+--R                 (480a b c  - 240a b c  + 30b c )d e x
+--R               + 
+--R                           2   4          3 3       5 2  2      2 2 3        4 2
+--R                     (2160a b c  - 1080a b c  + 135b c )d  + 96a b c  - 48a b c
+--R                   + 
+--R                       6
+--R                     6b c
+--R                *
+--R                    8 8
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  3
+--R                     (5760a b c  - 2880a b c  + 360b c )d
+--R                   + 
+--R                          2 2 3         4 2      6
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                *
+--R                    7 7
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  4
+--R                     (10080a b c  - 5040a b c  + 630b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   2      3   3        5
+--R                     (2688a b c  - 1344a b c  + 168b c)d  + 96a b c  - 18a b c
+--R                   + 
+--R                       7
+--R                     3b
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  5
+--R                     (12096a b c  - 6048a b c  + 756b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   3
+--R                     (5376a b c  - 2688a b c  + 336b c)d
+--R                   + 
+--R                          3   3         5       7
+--R                     (576a b c  - 108a b c + 18b )d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  6
+--R                     (10080a b c  - 5040a b c  + 630b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   4
+--R                     (6720a b c  - 3360a b c  + 420b c)d
+--R                   + 
+--R                         3   3         5       7  2      3 2 2      2 4        6
+--R                   (1440a b c  - 270a b c + 45b )d  + 96a b c  - 48a b c + 6a b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  7
+--R                     (5760a b c  - 2880a b c  + 360b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   5
+--R                     (5376a b c  - 2688a b c  + 336b c)d
+--R                   + 
+--R                           3   3         5       7  3
+--R                     (1920a b c  - 360a b c + 60b )d
+--R                   + 
+--R                          3 2 2       2 4         6
+--R                     (384a b c  - 192a b c + 24a b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  8
+--R                     (2160a b c  - 1080a b c  + 135b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   6
+--R                     (2688a b c  - 1344a b c  + 168b c)d
+--R                   + 
+--R                           3   3         5       7  4
+--R                     (1440a b c  - 270a b c + 45b )d
+--R                   + 
+--R                          3 2 2       2 4         6  2      4   2      3 3
+--R                     (576a b c  - 288a b c + 36a b )d  + 48a b c  - 24a b c
+--R                   + 
+--R                       2 5
+--R                     3a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                          2   4         3 3      5 2  9
+--R                     (480a b c  - 240a b c  + 30b c )d
+--R                   + 
+--R                          2 2 3         4 2      6   7
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                   + 
+--R                          3   3         5       7  5
+--R                     (576a b c  - 108a b c + 18b )d
+--R                   + 
+--R                          3 2 2       2 4         6  3
+--R                     (384a b c  - 192a b c + 24a b )d
+--R                   + 
+--R                         4   2      3 3      2 5
+--R                     (96a b c  - 48a b c + 6a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                     2   4        3 3     5 2  10
+--R                 (48a b c  - 24a b c  + 3b c )d
+--R               + 
+--R                     2 2 3        4 2     6   8       3   3        5      7  6
+--R                 (96a b c  - 48a b c  + 6b c)d  + (96a b c  - 18a b c + 3b )d
+--R               + 
+--R                   3 2 2      2 4        6  4       4   2      3 3      2 5  2
+--R               (96a b c  - 48a b c + 6a b )d  + (48a b c  - 24a b c + 3a b )d
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                        2   4        3 3      5 2  10 10
+--R                 (- 192a b c  + 96a b c  - 12b c )e  x
+--R               + 
+--R                         2   4         3 3       5 2    9 9
+--R                 (- 1920a b c  + 960a b c  - 120b c )d e x
+--R               + 
+--R                             2   4          3 3       5 2  2       2 2 3
+--R                     (- 8640a b c  + 4320a b c  - 540b c )d  - 384a b c
+--R                   + 
+--R                           4 2      6
+--R                     192a b c  - 24b c
+--R                *
+--R                    8 8
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  3
+--R                     (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                   + 
+--R                             2 2 3          4 2       6
+--R                     (- 3072a b c  + 1536a b c  - 192b c)d
+--R                *
+--R                    7 7
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  4
+--R                     (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                   + 
+--R                              2 2 3          4 2       6   2       3   3
+--R                     (- 10752a b c  + 5376a b c  - 672b c)d  - 384a b c
+--R                   + 
+--R                          5       7
+--R                     72a b c - 12b
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  5
+--R                     (- 48384a b c  + 24192a b c  - 3024b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   3
+--R                     (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                   + 
+--R                             3   3         5       7
+--R                     (- 2304a b c  + 432a b c - 72b )d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  6
+--R                     (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   4
+--R                     (- 26880a b c  + 13440a b c  - 1680b c)d
+--R                   + 
+--R                             3   3          5        7  2       3 2 2       2 4
+--R                     (- 5760a b c  + 1080a b c - 180b )d  - 384a b c  + 192a b c
+--R                   + 
+--R                            6
+--R                     - 24a b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  7
+--R                     (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   5
+--R                     (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                   + 
+--R                             3   3          5        7  3
+--R                     (- 7680a b c  + 1440a b c - 240b )d
+--R                   + 
+--R                             3 2 2       2 4         6
+--R                     (- 1536a b c  + 768a b c - 96a b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                             2   4          3 3       5 2  8
+--R                     (- 8640a b c  + 4320a b c  - 540b c )d
+--R                   + 
+--R                              2 2 3          4 2       6   6
+--R                     (- 10752a b c  + 5376a b c  - 672b c)d
+--R                   + 
+--R                             3   3          5        7  4
+--R                     (- 5760a b c  + 1080a b c - 180b )d
+--R                   + 
+--R                             3 2 2        2 4          6  2       4   2
+--R                     (- 2304a b c  + 1152a b c - 144a b )d  - 192a b c
+--R                   + 
+--R                        3 3       2 5
+--R                     96a b c - 12a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                             2   4         3 3       5 2  9
+--R                     (- 1920a b c  + 960a b c  - 120b c )d
+--R                   + 
+--R                             2 2 3          4 2       6   7
+--R                     (- 3072a b c  + 1536a b c  - 192b c)d
+--R                   + 
+--R                             3   3         5       7  5
+--R                     (- 2304a b c  + 432a b c - 72b )d
+--R                   + 
+--R                             3 2 2       2 4         6  3
+--R                     (- 1536a b c  + 768a b c - 96a b )d
+--R                   + 
+--R                            4   2       3 3       2 5
+--R                     (- 384a b c  + 192a b c - 24a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                        2   4        3 3      5 2  10
+--R                 (- 192a b c  + 96a b c  - 12b c )d
+--R               + 
+--R                        2 2 3         4 2      6   8
+--R                 (- 384a b c  + 192a b c  - 24b c)d
+--R               + 
+--R                        3   3        5       7  6
+--R                 (- 384a b c  + 72a b c - 12b )d
+--R               + 
+--R                        3 2 2       2 4         6  4
+--R                 (- 384a b c  + 192a b c - 24a b )d
+--R               + 
+--R                        4   2      3 3       2 5  2
+--R                 (- 192a b c  + 96a b c - 12a b )d
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                   3 4      2 2 3       4 2  8 8
+--R             (- 60a c  + 42a b c  - 6a b c )e x
+--R           + 
+--R                    3 4       2 2 3        4 2    7 7
+--R             (- 480a c  + 336a b c  - 48a b c )d e x
+--R           + 
+--R                         3 4        2 2 3         4 2  2       3   3      2 3 2
+--R                 (- 1680a c  + 1176a b c  - 168a b c )d  - 138a b c  + 87a b c
+--R               + 
+--R                        5
+--R                 - 12a b c
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  3
+--R                 (- 3360a c  + 2352a b c  - 336a b c )d
+--R               + 
+--R                        3   3       2 3 2        5
+--R                 (- 828a b c  + 522a b c  - 72a b c)d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  4
+--R                 (- 4200a c  + 2940a b c  - 420a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   2       4 3      3 2 2
+--R                 (- 2070a b c  + 1305a b c  - 180a b c)d  - 100a c  - 14a b c
+--R               + 
+--R                    2 4        6
+--R                 36a b c - 6a b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  5
+--R                 (- 3360a c  + 2352a b c  - 336a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   3
+--R                 (- 2760a b c  + 1740a b c  - 240a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6
+--R                 (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  6
+--R                 (- 1680a c  + 1176a b c  - 168a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   4
+--R                 (- 2070a b c  + 1305a b c  - 180a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6  2       4   2
+--R                 (- 600a c  - 84a b c  + 216a b c - 36a b )d  - 122a b c
+--R               + 
+--R                    3 3      2 5
+--R                 68a b c - 9a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                        3 4       2 2 3        4 2  7
+--R                 (- 480a c  + 336a b c  - 48a b c )d
+--R               + 
+--R                        3   3       2 3 2        5   5
+--R                 (- 828a b c  + 522a b c  - 72a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6  3
+--R                 (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R               + 
+--R                        4   2       3 3       2 5
+--R                 (- 244a b c  + 136a b c - 18a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   3 4      2 2 3       4 2  8
+--R             (- 60a c  + 42a b c  - 6a b c )d
+--R           + 
+--R                    3   3      2 3 2        5   6
+--R             (- 138a b c  + 87a b c  - 12a b c)d
+--R           + 
+--R                    4 3      3 2 2      2 4        6  4
+--R             (- 100a c  - 14a b c  + 36a b c - 6a b )d
+--R           + 
+--R                    4   2      3 3      2 5  2      5 2      4 2      3 4
+--R             (- 122a b c  + 68a b c - 9a b )d  - 32a c  + 16a b c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               6 4      5 2 3     4 4 2  11 10
+--R           (64a c  - 32a b c  + 4a b c )e  x
+--R         + 
+--R                6 4       5 2 3      4 4 2    10 9
+--R           (640a c  - 320a b c  + 40a b c )d e  x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  2       6   3      5 3 2
+--R               (2880a c  - 1440a b c  + 180a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 4 5
+--R               8a b c
+--R          *
+--R              9 8
+--R             e x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  3
+--R               (7680a c  - 3840a b c  + 480a b c )d
+--R             + 
+--R                     6   3       5 3 2      4 5
+--R               (1024a b c  - 512a b c  + 64a b c)d
+--R          *
+--R              8 7
+--R             e x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  4
+--R               (13440a c  - 6720a b c  + 840a b c )d
+--R             + 
+--R                   6   3        5 3 2       4 5   2       7 3      5 4      4 6
+--R             (3584a b c  - 1792a b c  + 224a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                      6 4        5 2 3        4 4 2  5
+--R               (16128a c  - 8064a b c  + 1008a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   3
+--R               (7168a b c  - 3584a b c  + 448a b c)d
+--R             + 
+--R                    7 3       5 4       4 6
+--R               (768a c  - 144a b c + 24a b )d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  6
+--R               (13440a c  - 6720a b c  + 840a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   4
+--R               (8960a b c  - 4480a b c  + 560a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  2       7   2      6 3      5 5
+--R               (1920a c  - 360a b c + 60a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  7
+--R               (7680a c  - 3840a b c  + 480a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   5
+--R               (7168a b c  - 3584a b c  + 448a b c)d
+--R             + 
+--R                   7 3       5 4       4 6  3        7   2       6 3       5 5
+--R             (2560a c  - 480a b c + 80a b )d  + (512a b c  - 256a b c + 32a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  8
+--R               (2880a c  - 1440a b c  + 180a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   6
+--R               (3584a b c  - 1792a b c  + 224a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  4
+--R               (1920a c  - 360a b c + 60a b )d
+--R             + 
+--R                    7   2       6 3       5 5  2      8 2      7 2      6 4
+--R               (768a b c  - 384a b c + 48a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    6 4       5 2 3      4 4 2  9
+--R               (640a c  - 320a b c  + 40a b c )d
+--R             + 
+--R                     6   3       5 3 2      4 5   7
+--R               (1024a b c  - 512a b c  + 64a b c)d
+--R             + 
+--R                    7 3       5 4       4 6  5
+--R               (768a c  - 144a b c + 24a b )d
+--R             + 
+--R                    7   2       6 3       5 5  3        8 2      7 2      6 4
+--R               (512a b c  - 256a b c + 32a b )d  + (128a c  - 64a b c + 8a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   6 4      5 2 3     4 4 2  10
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    6   3      5 3 2     4 5   8        7 3      5 4      4 6  6
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    7   2      6 3      5 5  4       8 2      7 2      6 4  2
+--R               (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R          *
+--R             e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 894
+
+--S 895 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             3 3      2 2 2        4      6
+--R         (60a c  - 90a b c  + 30a b c - 3b )
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                3 3       2 2 2        4      6
+--R         (- 120a c  + 180a b c  - 60a b c + 6b )
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R  /
+--R                                 +-----------+
+--R         6 2      5 2      4 4   |          2
+--R     (64a c  - 32a b c + 4a b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 895
+
+--S 896 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 896
+
+--S 897 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                               +---------+
+--R               3 3      2 2 2        4      6  |        2
+--R         (- 60a c  + 90a b c  - 30a b c + 3b )\|4a c - b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                               +-----------+
+--R               3 3      2 2 2        4      6  |          2
+--R         (- 60a c  + 90a b c  - 30a b c + 3b )\|- 4a c + b
+--R      *
+--R                                               +---------+
+--R                   2 2                  2      |        2
+--R              (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R  /
+--R                                 +-----------+ +---------+
+--R         6 2      5 2      4 4   |          2  |        2
+--R     (32a c  - 16a b c + 2a b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 897
+
+--S 898 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 898
+
+)clear all
+
+--S 899 of 1057
+t0:=1/((d+e*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 16 16      3   15 15        3 2       2  14 14
+--R       c e  x   + 16c d e  x   + (120c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   13 13         3 4         2 2       2     2   12 12
+--R       (560c d  + 42b c d)e  x   + (1820c d  + 273b c d  + 3a c  + 3b c)e  x
+--R     + 
+--R             3 5          2 3         2      2     11 11
+--R       (4368c d  + 1092b c d  + (36a c  + 36b c)d)e  x
+--R     + 
+--R             3 6          2 4          2       2   2             3  10 10
+--R       (8008c d  + 3003b c d  + (198a c  + 198b c)d  + 6a b c + b )e  x
+--R     + 
+--R              3 7          2 5          2       2   3                 3    9 9
+--R       (11440c d  + 6006b c d  + (660a c  + 660b c)d  + (60a b c + 10b )d)e x
+--R     + 
+--R                 3 8          2 6           2        2   4                  3  2
+--R           12870c d  + 9009b c d  + (1485a c  + 1485b c)d  + (270a b c + 45b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          8 8
+--R         e x
+--R     + 
+--R                 3 9           2 7           2        2   5
+--R           11440c d  + 10296b c d  + (2376a c  + 2376b c)d
+--R         + 
+--R                           3  3       2         2
+--R           (720a b c + 120b )d  + (24a c + 24a b )d
+--R      *
+--R          7 7
+--R         e x
+--R     + 
+--R                3 10          2 8           2        2   6
+--R           8008c d   + 9009b c d  + (2772a c  + 2772b c)d
+--R         + 
+--R                            3  4       2         2  2     2
+--R           (1260a b c + 210b )d  + (84a c + 84a b )d  + 3a b
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R                3 11          2 9           2        2   7
+--R           4368c d   + 6006b c d  + (2376a c  + 2376b c)d
+--R         + 
+--R                            3  5        2          2  3      2
+--R           (1512a b c + 252b )d  + (168a c + 168a b )d  + 18a b d
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R                3 12          2 10           2        2   8
+--R           1820c d   + 3003b c d   + (1485a c  + 1485b c)d
+--R         + 
+--R                            3  6        2          2  4      2   2    3
+--R           (1260a b c + 210b )d  + (210a c + 210a b )d  + 45a b d  + a
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 13          2 11          2       2   9                   3  7
+--R           560c d   + 1092b c d   + (660a c  + 660b c)d  + (720a b c + 120b )d
+--R         + 
+--R                2          2  5      2   3     3
+--R           (168a c + 168a b )d  + 60a b d  + 4a d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R               3 14         2 12          2       2   10                  3  8
+--R           120c d   + 273b c d   + (198a c  + 198b c)d   + (270a b c + 45b )d
+--R         + 
+--R               2         2  6      2   4     3 2
+--R           (84a c + 84a b )d  + 45a b d  + 6a d
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 15        2 13         2      2   11                 3  9
+--R           16c d   + 42b c d   + (36a c  + 36b c)d   + (60a b c + 10b )d
+--R         + 
+--R               2         2  7      2   5     3 3
+--R           (24a c + 24a b )d  + 18a b d  + 4a d
+--R      *
+--R         e x
+--R     + 
+--R        3 16       2 14        2     2   12              3  10
+--R       c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R     + 
+--R          2        2  8     2   6    3 4
+--R       (3a c + 3a b )d  + 3a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 899
+
+--S 900 of 1057
+r0:=1/24*(-35*b^4+235*a*b^2*c-308*a^2*c^2)/(a^3*(b^2-4*a*c)^2*e*(d+e*x)^3)+_
+   1/8*b*(35*b^4-270*a*b^2*c+508*a^2*c^2)/(a^4*(b^2-4*a*c)^2*e*(d+e*x))+_
+   1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(d+e*x)^3*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/8*(7*b^4-45*a*b^2*c+44*a^2*c^2+b*c*(7*b^2-40*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   1/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (35*b^5-270*a*b^3*c+508*a^2*b*c^2+(35*b^6-340*a*b^4*c+978*a^2*b^2*c^2-_
+   616*a^3*c^3)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))+1/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(35*b^5-270*a*b^3*c+508*a^2*b*c^2+(-35*b^6+340*a*b^4*c-_
+   978*a^2*b^2*c^2+616*a^3*c^3)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^2*e*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     2   4         3 3       5 2  11 11
+--R               (1524a b c  - 810a b c  + 105b c )e  x
+--R             + 
+--R                      2   4          3 3        5 2    10 10
+--R               (16764a b c  - 8910a b c  + 1155b c )d e  x
+--R             + 
+--R                          2   4           3 3        5 2  2        2 2 3
+--R                   (83820a b c  - 44550a b c  + 5775b c )d  + 3048a b c
+--R                 + 
+--R                            4 2       6
+--R                   - 1620a b c  + 210b c
+--R              *
+--R                  9 9
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  3
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                          2 2 3           4 2        6
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  4
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   2        3   3
+--R                   (109728a b c  - 58320a b c  + 7560b c)d  + 3048a b c
+--R                 + 
+--R                        2 3 2         5        7
+--R                   - 96a b c  - 600a b c + 105b
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  5
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   3
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  6
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   4
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  2
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                        3 2 2        2 4          6
+--R                   3048a b c  - 1620a b c + 210a b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  7
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   5
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  3
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2        2 4           6
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  8
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   6
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  4
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2         2 4           6  2        4   2
+--R                   (30480a b c  - 16200a b c + 2100a b )d  + 1524a b c
+--R                 + 
+--R                         3 3        2 5
+--R                   - 810a b c + 105a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2   4           3 3        5 2  9
+--R                   (83820a b c  - 44550a b c  + 5775b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   7
+--R                   (109728a b c  - 58320a b c  + 7560b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  5
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                          3 2 2         2 4           6  3
+--R                   (30480a b c  - 16200a b c + 2100a b )d
+--R                 + 
+--R                         4   2        3 3        2 5
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2   4          3 3        5 2  10
+--R                   (16764a b c  - 8910a b c  + 1155b c )d
+--R                 + 
+--R                          2 2 3           4 2        6   8
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7  6
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R                 + 
+--R                          3 2 2        2 4           6  4
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R                 + 
+--R                         4   2        3 3        2 5  2
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )d
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)d
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )d
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )d
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3 5        2 2 4          4 3       6 2  11 11
+--R           (- 1848a c  + 2934a b c  - 1020a b c  + 105b c )e  x
+--R         + 
+--R                    3 5         2 2 4           4 3        6 2    10 10
+--R           (- 20328a c  + 32274a b c  - 11220a b c  + 1155b c )d e  x
+--R         + 
+--R                         3 5          2 2 4           4 3        6 2  2
+--R               (- 101640a c  + 161370a b c  - 56100a b c  + 5775b c )d
+--R             + 
+--R                      3   4        2 3 3          5 2       7
+--R               - 3696a b c  + 5868a b c  - 2040a b c  + 210b c
+--R          *
+--R              9 9
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  3
+--R               (- 304920a c  + 484110a b c  - 168300a b c  + 17325b c )d
+--R             + 
+--R                        3   4         2 3 3           5 2        7
+--R               (- 33264a b c  + 52812a b c  - 18360a b c  + 1890b c)d
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  4
+--R               (- 609840a c  + 968220a b c  - 336600a b c  + 34650b c )d
+--R             + 
+--R                         3   4          2 3 3           5 2        7   2
+--R               (- 133056a b c  + 211248a b c  - 73440a b c  + 7560b c)d
+--R             + 
+--R                      4 4        3 2 3       2 4 2         6        8
+--R               - 3696a c  + 4020a b c  + 894a b c  - 810a b c + 105b
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                         3 5           2 2 4            4 3         6 2  5
+--R               (- 853776a c  + 1355508a b c  - 471240a b c  + 48510b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   3
+--R               (- 310464a b c  + 492912a b c  - 171360a b c  + 17640b c)d
+--R             + 
+--R                        4 4         3 2 3        2 4 2          6        8
+--R               (- 25872a c  + 28140a b c  + 6258a b c  - 5670a b c + 735b )d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                         3 5           2 2 4            4 3         6 2  6
+--R               (- 853776a c  + 1355508a b c  - 471240a b c  + 48510b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   4
+--R               (- 465696a b c  + 739368a b c  - 257040a b c  + 26460b c)d
+--R             + 
+--R                        4 4         3 2 3         2 4 2           6         8  2
+--R               (- 77616a c  + 84420a b c  + 18774a b c  - 17010a b c + 2205b )d
+--R             + 
+--R                      4   3        3 3 2        2 5          7
+--R               - 3696a b c  + 5868a b c  - 2040a b c + 210a b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  7
+--R               (- 609840a c  + 968220a b c  - 336600a b c  + 34650b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   5
+--R               (- 465696a b c  + 739368a b c  - 257040a b c  + 26460b c)d
+--R             + 
+--R                              4 4          3 2 3         2 4 2           6
+--R                     - 129360a c  + 140700a b c  + 31290a b c  - 28350a b c
+--R                   + 
+--R                          8
+--R                     3675b
+--R              *
+--R                  3
+--R                 d
+--R             + 
+--R                        4   3         3 3 2         2 5           7
+--R               (- 18480a b c  + 29340a b c  - 10200a b c + 1050a b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  8
+--R               (- 304920a c  + 484110a b c  - 168300a b c  + 17325b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   6
+--R               (- 310464a b c  + 492912a b c  - 171360a b c  + 17640b c)d
+--R             + 
+--R                              4 4          3 2 3         2 4 2           6
+--R                     - 129360a c  + 140700a b c  + 31290a b c  - 28350a b c
+--R                   + 
+--R                          8
+--R                     3675b
+--R              *
+--R                  4
+--R                 d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  2
+--R               (- 36960a b c  + 58680a b c  - 20400a b c + 2100a b )d
+--R             + 
+--R                      5 3        4 2 2        3 4        2 6
+--R               - 1848a c  + 2934a b c  - 1020a b c + 105a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                         3 5          2 2 4           4 3        6 2  9
+--R               (- 101640a c  + 161370a b c  - 56100a b c  + 5775b c )d
+--R             + 
+--R                         3   4          2 3 3           5 2        7   7
+--R               (- 133056a b c  + 211248a b c  - 73440a b c  + 7560b c)d
+--R             + 
+--R                        4 4         3 2 3         2 4 2           6         8  5
+--R               (- 77616a c  + 84420a b c  + 18774a b c  - 17010a b c + 2205b )d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  3
+--R               (- 36960a b c  + 58680a b c  - 20400a b c + 2100a b )d
+--R             + 
+--R                       5 3        4 2 2        3 4        2 6
+--R               (- 5544a c  + 8802a b c  - 3060a b c + 315a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        3 5         2 2 4           4 3        6 2  10
+--R               (- 20328a c  + 32274a b c  - 11220a b c  + 1155b c )d
+--R             + 
+--R                        3   4         2 3 3           5 2        7   8
+--R               (- 33264a b c  + 52812a b c  - 18360a b c  + 1890b c)d
+--R             + 
+--R                        4 4         3 2 3        2 4 2          6        8  6
+--R               (- 25872a c  + 28140a b c  + 6258a b c  - 5670a b c + 735b )d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  4
+--R               (- 18480a b c  + 29340a b c  - 10200a b c + 1050a b )d
+--R             + 
+--R                       5 3        4 2 2        3 4        2 6  2
+--R               (- 5544a c  + 8802a b c  - 3060a b c + 315a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   3 5        2 2 4          4 3       6 2  11
+--R           (- 1848a c  + 2934a b c  - 1020a b c  + 105b c )d
+--R         + 
+--R                   3   4        2 3 3          5 2       7   9
+--R           (- 3696a b c  + 5868a b c  - 2040a b c  + 210b c)d
+--R         + 
+--R                   4 4        3 2 3       2 4 2         6        8  7
+--R           (- 3696a c  + 4020a b c  + 894a b c  - 810a b c + 105b )d
+--R         + 
+--R                   4   3        3 3 2        2 5          7  5
+--R           (- 3696a b c  + 5868a b c  - 2040a b c + 210a b )d
+--R         + 
+--R                   5 3        4 2 2        3 4        2 6  3
+--R           (- 1848a c  + 2934a b c  - 1020a b c + 105a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     2   4         3 3       5 2  11 11
+--R               (1524a b c  - 810a b c  + 105b c )e  x
+--R             + 
+--R                      2   4          3 3        5 2    10 10
+--R               (16764a b c  - 8910a b c  + 1155b c )d e  x
+--R             + 
+--R                          2   4           3 3        5 2  2        2 2 3
+--R                   (83820a b c  - 44550a b c  + 5775b c )d  + 3048a b c
+--R                 + 
+--R                            4 2       6
+--R                   - 1620a b c  + 210b c
+--R              *
+--R                  9 9
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  3
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                          2 2 3           4 2        6
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  4
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   2        3   3
+--R                   (109728a b c  - 58320a b c  + 7560b c)d  + 3048a b c
+--R                 + 
+--R                        2 3 2         5        7
+--R                   - 96a b c  - 600a b c + 105b
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  5
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   3
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  6
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   4
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  2
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                        3 2 2        2 4          6
+--R                   3048a b c  - 1620a b c + 210a b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  7
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   5
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  3
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2        2 4           6
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  8
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   6
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  4
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2         2 4           6  2        4   2
+--R                   (30480a b c  - 16200a b c + 2100a b )d  + 1524a b c
+--R                 + 
+--R                         3 3        2 5
+--R                   - 810a b c + 105a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2   4           3 3        5 2  9
+--R                   (83820a b c  - 44550a b c  + 5775b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   7
+--R                   (109728a b c  - 58320a b c  + 7560b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  5
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                          3 2 2         2 4           6  3
+--R                   (30480a b c  - 16200a b c + 2100a b )d
+--R                 + 
+--R                         4   2        3 3        2 5
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2   4          3 3        5 2  10
+--R                   (16764a b c  - 8910a b c  + 1155b c )d
+--R                 + 
+--R                          2 2 3           4 2        6   8
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7  6
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R                 + 
+--R                          3 2 2        2 4           6  4
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R                 + 
+--R                         4   2        3 3        2 5  2
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )d
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)d
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )d
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )d
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3 5        2 2 4          4 3       6 2  11 11
+--R           (1848a c  - 2934a b c  + 1020a b c  - 105b c )e  x
+--R         + 
+--R                  3 5         2 2 4           4 3        6 2    10 10
+--R           (20328a c  - 32274a b c  + 11220a b c  - 1155b c )d e  x
+--R         + 
+--R                       3 5          2 2 4           4 3        6 2  2
+--R               (101640a c  - 161370a b c  + 56100a b c  - 5775b c )d
+--R             + 
+--R                    3   4        2 3 3          5 2       7
+--R               3696a b c  - 5868a b c  + 2040a b c  - 210b c
+--R          *
+--R              9 9
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  3
+--R               (304920a c  - 484110a b c  + 168300a b c  - 17325b c )d
+--R             + 
+--R                      3   4         2 3 3           5 2        7
+--R               (33264a b c  - 52812a b c  + 18360a b c  - 1890b c)d
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  4
+--R               (609840a c  - 968220a b c  + 336600a b c  - 34650b c )d
+--R             + 
+--R                       3   4          2 3 3           5 2        7   2
+--R               (133056a b c  - 211248a b c  + 73440a b c  - 7560b c)d
+--R             + 
+--R                    4 4        3 2 3       2 4 2         6        8
+--R               3696a c  - 4020a b c  - 894a b c  + 810a b c - 105b
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                       3 5           2 2 4            4 3         6 2  5
+--R               (853776a c  - 1355508a b c  + 471240a b c  - 48510b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   3
+--R               (310464a b c  - 492912a b c  + 171360a b c  - 17640b c)d
+--R             + 
+--R                      4 4         3 2 3        2 4 2          6        8
+--R               (25872a c  - 28140a b c  - 6258a b c  + 5670a b c - 735b )d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       3 5           2 2 4            4 3         6 2  6
+--R               (853776a c  - 1355508a b c  + 471240a b c  - 48510b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   4
+--R               (465696a b c  - 739368a b c  + 257040a b c  - 26460b c)d
+--R             + 
+--R                      4 4         3 2 3         2 4 2           6         8  2
+--R               (77616a c  - 84420a b c  - 18774a b c  + 17010a b c - 2205b )d
+--R             + 
+--R                    4   3        3 3 2        2 5          7
+--R               3696a b c  - 5868a b c  + 2040a b c - 210a b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  7
+--R               (609840a c  - 968220a b c  + 336600a b c  - 34650b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   5
+--R               (465696a b c  - 739368a b c  + 257040a b c  - 26460b c)d
+--R             + 
+--R                       4 4          3 2 3         2 4 2           6         8  3
+--R               (129360a c  - 140700a b c  - 31290a b c  + 28350a b c - 3675b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7
+--R               (18480a b c  - 29340a b c  + 10200a b c - 1050a b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  8
+--R               (304920a c  - 484110a b c  + 168300a b c  - 17325b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   6
+--R               (310464a b c  - 492912a b c  + 171360a b c  - 17640b c)d
+--R             + 
+--R                       4 4          3 2 3         2 4 2           6         8  4
+--R               (129360a c  - 140700a b c  - 31290a b c  + 28350a b c - 3675b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  2        5 3
+--R               (36960a b c  - 58680a b c  + 20400a b c - 2100a b )d  + 1848a c
+--R             + 
+--R                      4 2 2        3 4        2 6
+--R               - 2934a b c  + 1020a b c - 105a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       3 5          2 2 4           4 3        6 2  9
+--R               (101640a c  - 161370a b c  + 56100a b c  - 5775b c )d
+--R             + 
+--R                       3   4          2 3 3           5 2        7   7
+--R               (133056a b c  - 211248a b c  + 73440a b c  - 7560b c)d
+--R             + 
+--R                      4 4         3 2 3         2 4 2           6         8  5
+--R               (77616a c  - 84420a b c  - 18774a b c  + 17010a b c - 2205b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  3
+--R               (36960a b c  - 58680a b c  + 20400a b c - 2100a b )d
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6
+--R               (5544a c  - 8802a b c  + 3060a b c - 315a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  10
+--R               (20328a c  - 32274a b c  + 11220a b c  - 1155b c )d
+--R             + 
+--R                      3   4         2 3 3           5 2        7   8
+--R               (33264a b c  - 52812a b c  + 18360a b c  - 1890b c)d
+--R             + 
+--R                      4 4         3 2 3        2 4 2          6        8  6
+--R               (25872a c  - 28140a b c  - 6258a b c  + 5670a b c - 735b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  4
+--R               (18480a b c  - 29340a b c  + 10200a b c - 1050a b )d
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6  2
+--R               (5544a c  - 8802a b c  + 3060a b c - 315a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 3 5        2 2 4          4 3       6 2  11
+--R           (1848a c  - 2934a b c  + 1020a b c  - 105b c )d
+--R         + 
+--R                 3   4        2 3 3          5 2       7   9
+--R           (3696a b c  - 5868a b c  + 2040a b c  - 210b c)d
+--R         + 
+--R                 4 4        3 2 3       2 4 2         6        8  7
+--R           (3696a c  - 4020a b c  - 894a b c  + 810a b c - 105b )d
+--R         + 
+--R                 4   3        3 3 2        2 5          7  5
+--R           (3696a b c  - 5868a b c  + 2040a b c - 210a b )d
+--R         + 
+--R                 5 3        4 2 2        3 4        2 6  3
+--R           (1848a c  - 2934a b c  + 1020a b c - 105a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 2   4         3 3       5 2  10 10
+--R           (1524a b c  - 810a b c  + 105b c )e  x
+--R         + 
+--R                  2   4          3 3        5 2    9 9
+--R           (15240a b c  - 8100a b c  + 1050b c )d e x
+--R         + 
+--R                      2   4           3 3        5 2  2       3 4        2 2 3
+--R               (68580a b c  - 36450a b c  + 4725b c )d  - 308a c  + 3283a b c
+--R             + 
+--R                        4 2       6
+--R               - 1655a b c  + 210b c
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                       2   4           3 3         5 2  3
+--R               (182880a b c  - 97200a b c  + 12600b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6
+--R               (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  4
+--R               (320040a b c  - 170100a b c  + 22050b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   2        3   3
+--R               (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d  + 2312a b c
+--R             + 
+--R                   2 3 2         5        7
+--R               395a b c  - 670a b c + 105b
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  5
+--R               (384048a b c  - 204120a b c  + 26460b c )d
+--R             + 
+--R                        3 4          2 2 3           4 2         6   3
+--R               (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R             + 
+--R                      3   3        2 3 2          5        7
+--R               (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  6
+--R               (320040a b c  - 170100a b c  + 22050b c )d
+--R             + 
+--R                        3 4          2 2 3            4 2         6   4
+--R               (- 21560a c  + 229810a b c  - 115850a b c  + 14700b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  2       4 3
+--R               (34680a b c  + 5925a b c  - 10050a b c + 1575b )d  - 484a c
+--R             + 
+--R                    3 2 2        2 4          6
+--R               2955a b c  - 1413a b c + 175a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2   4           3 3         5 2  7
+--R               (182880a b c  - 97200a b c  + 12600b c )d
+--R             + 
+--R                        3 4          2 2 3           4 2         6   5
+--R               (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  3
+--R               (46240a b c  + 7900a b c  - 13400a b c + 2100b )d
+--R             + 
+--R                       4 3         3 2 2        2 4          6
+--R               (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  8
+--R               (68580a b c  - 36450a b c  + 4725b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   6
+--R               (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  4
+--R               (34680a b c  + 5925a b c  - 10050a b c + 1575b )d
+--R             + 
+--R                       4 3         3 2 2        2 4           6  2       4   2
+--R               (- 2904a c  + 17730a b c  - 8478a b c + 1050a b )d  + 896a b c
+--R             + 
+--R                     3 3       2 5
+--R               - 448a b c + 56a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      2   4          3 3        5 2  9
+--R               (15240a b c  - 8100a b c  + 1050b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   7
+--R               (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R             + 
+--R                      3   3        2 3 2          5        7  5
+--R               (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R             + 
+--R                       4 3         3 2 2        2 4          6  3
+--R               (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R             + 
+--R                     4   2       3 3        2 5
+--R               (1792a b c  - 896a b c + 112a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2   4         3 3       5 2  10
+--R           (1524a b c  - 810a b c  + 105b c )d
+--R         + 
+--R                  3 4        2 2 3          4 2       6   8
+--R           (- 308a c  + 3283a b c  - 1655a b c  + 210b c)d
+--R         + 
+--R                 3   3       2 3 2         5        7  6
+--R           (2312a b c  + 395a b c  - 670a b c + 105b )d
+--R         + 
+--R                  4 3        3 2 2        2 4          6  4
+--R           (- 484a c  + 2955a b c  - 1413a b c + 175a b )d
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (896a b c  - 448a b c + 56a b )d  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              6 4       5 2 3      4 4 2  12 11
+--R         (384a c  - 192a b c  + 24a b c )e  x
+--R       + 
+--R               6 4        5 2 3       4 4 2    11 10
+--R         (4224a c  - 2112a b c  + 264a b c )d e  x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  2       6   3       5 3 2
+--R             (21120a c  - 10560a b c  + 1320a b c )d  + 768a b c  - 384a b c
+--R           + 
+--R                4 5
+--R             48a b c
+--R        *
+--R            10 9
+--R           e  x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  3
+--R             (63360a c  - 31680a b c  + 3960a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5
+--R             (6912a b c  - 3456a b c  + 432a b c)d
+--R        *
+--R            9 8
+--R           e x
+--R       + 
+--R                     6 4         5 2 3        4 4 2  4
+--R             (126720a c  - 63360a b c  + 7920a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   2       7 3       5 4
+--R             (27648a b c  - 13824a b c  + 1728a b c)d  + 768a c  - 144a b c
+--R           + 
+--R                4 6
+--R             24a b
+--R        *
+--R            8 7
+--R           e x
+--R       + 
+--R                     6 4         5 2 3         4 4 2  5
+--R             (177408a c  - 88704a b c  + 11088a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   3
+--R             (64512a b c  - 32256a b c  + 4032a b c)d
+--R           + 
+--R                   7 3        5 4        4 6
+--R             (5376a c  - 1008a b c + 168a b )d
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                     6 4         5 2 3         4 4 2  6
+--R             (177408a c  - 88704a b c  + 11088a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   4
+--R             (96768a b c  - 48384a b c  + 6048a b c)d
+--R           + 
+--R                  7 3        5 4        4 6  2       7   2       6 3       5 5
+--R           (16128a c  - 3024a b c + 504a b )d  + 768a b c  - 384a b c + 48a b
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                     6 4         5 2 3        4 4 2  7
+--R             (126720a c  - 63360a b c  + 7920a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   5
+--R             (96768a b c  - 48384a b c  + 6048a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  3
+--R             (26880a c  - 5040a b c + 840a b )d
+--R           + 
+--R                   7   2        6 3        5 5
+--R             (3840a b c  - 1920a b c + 240a b )d
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  8
+--R             (63360a c  - 31680a b c  + 3960a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   6
+--R             (64512a b c  - 32256a b c  + 4032a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  4
+--R             (26880a c  - 5040a b c + 840a b )d
+--R           + 
+--R                   7   2        6 3        5 5  2       8 2       7 2       6 4
+--R             (7680a b c  - 3840a b c + 480a b )d  + 384a c  - 192a b c + 24a b
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  9
+--R             (21120a c  - 10560a b c  + 1320a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   7
+--R             (27648a b c  - 13824a b c  + 1728a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  5
+--R             (16128a c  - 3024a b c + 504a b )d
+--R           + 
+--R                   7   2        6 3        5 5  3
+--R             (7680a b c  - 3840a b c + 480a b )d
+--R           + 
+--R                   8 2       7 2       6 4
+--R             (1152a c  - 576a b c + 72a b )d
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  10
+--R             (4224a c  - 2112a b c  + 264a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   8
+--R             (6912a b c  - 3456a b c  + 432a b c)d
+--R           + 
+--R                   7 3        5 4        4 6  6
+--R             (5376a c  - 1008a b c + 168a b )d
+--R           + 
+--R                   7   2        6 3        5 5  4
+--R             (3840a b c  - 1920a b c + 240a b )d
+--R           + 
+--R                   8 2       7 2       6 4  2
+--R             (1152a c  - 576a b c + 72a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  6 4       5 2 3      4 4 2  11
+--R             (384a c  - 192a b c  + 24a b c )d
+--R           + 
+--R                  6   3       5 3 2      4 5   9
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R           + 
+--R                  7 3       5 4       4 6  7        7   2       6 3       5 5  5
+--R             (768a c  - 144a b c + 24a b )d  + (768a b c  - 384a b c + 48a b )d
+--R           + 
+--R                  8 2       7 2       6 4  3
+--R             (384a c  - 192a b c + 24a b )d
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 900
+
+--S 901 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  6 4      5 2 3      4 4 2  12 11
+--R           (- 192a c  + 96a b c  - 12a b c )e  x
+--R         + 
+--R                   6 4        5 2 3       4 4 2    11 10
+--R           (- 2112a c  + 1056a b c  - 132a b c )d e  x
+--R         + 
+--R                        6 4        5 2 3       4 4 2  2       6   3       5 3 2
+--R               (- 10560a c  + 5280a b c  - 660a b c )d  - 384a b c  + 192a b c
+--R             + 
+--R                    4 5
+--R               - 24a b c
+--R          *
+--R              10 9
+--R             e  x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  3
+--R               (- 31680a c  + 15840a b c  - 1980a b c )d
+--R             + 
+--R                       6   3        5 3 2       4 5
+--R               (- 3456a b c  + 1728a b c  - 216a b c)d
+--R          *
+--R              9 8
+--R             e x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  4
+--R               (- 63360a c  + 31680a b c  - 3960a b c )d
+--R             + 
+--R                        6   3        5 3 2       4 5   2       7 3      5 4
+--R               (- 13824a b c  + 6912a b c  - 864a b c)d  - 384a c  + 72a b c
+--R             + 
+--R                    4 6
+--R               - 12a b
+--R          *
+--R              8 7
+--R             e x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  5
+--R               (- 88704a c  + 44352a b c  - 5544a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   3
+--R               (- 32256a b c  + 16128a b c  - 2016a b c)d
+--R             + 
+--R                       7 3       5 4       4 6
+--R               (- 2688a c  + 504a b c - 84a b )d
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  6
+--R               (- 88704a c  + 44352a b c  - 5544a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   4
+--R               (- 48384a b c  + 24192a b c  - 3024a b c)d
+--R             + 
+--R                       7 3        5 4        4 6  2       7   2       6 3
+--R               (- 8064a c  + 1512a b c - 252a b )d  - 384a b c  + 192a b c
+--R             + 
+--R                    5 5
+--R               - 24a b
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  7
+--R               (- 63360a c  + 31680a b c  - 3960a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   5
+--R               (- 48384a b c  + 24192a b c  - 3024a b c)d
+--R             + 
+--R                        7 3        5 4        4 6  3
+--R               (- 13440a c  + 2520a b c - 420a b )d
+--R             + 
+--R                       7   2       6 3        5 5
+--R               (- 1920a b c  + 960a b c - 120a b )d
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  8
+--R               (- 31680a c  + 15840a b c  - 1980a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   6
+--R               (- 32256a b c  + 16128a b c  - 2016a b c)d
+--R             + 
+--R                        7 3        5 4        4 6  4
+--R               (- 13440a c  + 2520a b c - 420a b )d
+--R             + 
+--R                     7   2        6 3        5 5  2       8 2      7 2       6 4
+--R             (- 3840a b c  + 1920a b c - 240a b )d  - 192a c  + 96a b c - 12a b
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                        6 4        5 2 3       4 4 2  9
+--R               (- 10560a c  + 5280a b c  - 660a b c )d
+--R             + 
+--R                        6   3        5 3 2       4 5   7
+--R               (- 13824a b c  + 6912a b c  - 864a b c)d
+--R             + 
+--R                       7 3        5 4        4 6  5
+--R               (- 8064a c  + 1512a b c - 252a b )d
+--R             + 
+--R                       7   2        6 3        5 5  3
+--R               (- 3840a b c  + 1920a b c - 240a b )d
+--R             + 
+--R                      8 2       7 2       6 4
+--R               (- 576a c  + 288a b c - 36a b )d
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                       6 4        5 2 3       4 4 2  10
+--R               (- 2112a c  + 1056a b c  - 132a b c )d
+--R             + 
+--R                       6   3        5 3 2       4 5   8
+--R               (- 3456a b c  + 1728a b c  - 216a b c)d
+--R             + 
+--R                       7 3       5 4       4 6  6
+--R               (- 2688a c  + 504a b c - 84a b )d
+--R             + 
+--R                       7   2       6 3        5 5  4
+--R               (- 1920a b c  + 960a b c - 120a b )d
+--R             + 
+--R                      8 2       7 2       6 4  2
+--R               (- 576a c  + 288a b c - 36a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                      6 4      5 2 3      4 4 2  11
+--R               (- 192a c  + 96a b c  - 12a b c )d
+--R             + 
+--R                      6   3       5 3 2      4 5   9
+--R               (- 384a b c  + 192a b c  - 24a b c)d
+--R             + 
+--R                      7 3      5 4       4 6  7
+--R               (- 384a c  + 72a b c - 12a b )d
+--R             + 
+--R                      7   2       6 3       5 5  5
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R             + 
+--R                      8 2      7 2       6 4  3
+--R               (- 192a c  + 96a b c - 12a b )d
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                10 10              9 2 9               8 4 8
+--R                      467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                    + 
+--R                                    7 6 7               6 8 6
+--R                      - 21970145504a b c  + 17711314348a b c
+--R                    + 
+--R                                   5 10 5              4 12 4             3 14 3
+--R                      - 8747324300a b  c  + 2769618280a b  c  - 566790200a b  c
+--R                    + 
+--R                               2 16 2             18           20
+--R                      72753100a b  c  - 5341000a b  c + 171500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                6 4      5 2 3      4 4 2  12 11
+--R           (192a c  - 96a b c  + 12a b c )e  x
+--R         + 
+--R                 6 4        5 2 3       4 4 2    11 10
+--R           (2112a c  - 1056a b c  + 132a b c )d e  x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  2       6   3       5 3 2
+--R               (10560a c  - 5280a b c  + 660a b c )d  + 384a b c  - 192a b c
+--R             + 
+--R                  4 5
+--R               24a b c
+--R          *
+--R              10 9
+--R             e  x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  3
+--R               (31680a c  - 15840a b c  + 1980a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5
+--R               (3456a b c  - 1728a b c  + 216a b c)d
+--R          *
+--R              9 8
+--R             e x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  4
+--R               (63360a c  - 31680a b c  + 3960a b c )d
+--R             + 
+--R                      6   3        5 3 2       4 5   2       7 3      5 4
+--R               (13824a b c  - 6912a b c  + 864a b c)d  + 384a c  - 72a b c
+--R             + 
+--R                  4 6
+--R               12a b
+--R          *
+--R              8 7
+--R             e x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  5
+--R               (88704a c  - 44352a b c  + 5544a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   3
+--R               (32256a b c  - 16128a b c  + 2016a b c)d
+--R             + 
+--R                     7 3       5 4       4 6
+--R               (2688a c  - 504a b c + 84a b )d
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  6
+--R               (88704a c  - 44352a b c  + 5544a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   4
+--R               (48384a b c  - 24192a b c  + 3024a b c)d
+--R             + 
+--R                   7 3        5 4        4 6  2       7   2       6 3       5 5
+--R             (8064a c  - 1512a b c + 252a b )d  + 384a b c  - 192a b c + 24a b
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  7
+--R               (63360a c  - 31680a b c  + 3960a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   5
+--R               (48384a b c  - 24192a b c  + 3024a b c)d
+--R             + 
+--R                      7 3        5 4        4 6  3
+--R               (13440a c  - 2520a b c + 420a b )d
+--R             + 
+--R                     7   2       6 3        5 5
+--R               (1920a b c  - 960a b c + 120a b )d
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  8
+--R               (31680a c  - 15840a b c  + 1980a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   6
+--R               (32256a b c  - 16128a b c  + 2016a b c)d
+--R             + 
+--R                      7 3        5 4        4 6  4
+--R               (13440a c  - 2520a b c + 420a b )d
+--R             + 
+--R                   7   2        6 3        5 5  2       8 2      7 2       6 4
+--R             (3840a b c  - 1920a b c + 240a b )d  + 192a c  - 96a b c + 12a b
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  9
+--R               (10560a c  - 5280a b c  + 660a b c )d
+--R             + 
+--R                      6   3        5 3 2       4 5   7
+--R               (13824a b c  - 6912a b c  + 864a b c)d
+--R             + 
+--R                     7 3        5 4        4 6  5
+--R               (8064a c  - 1512a b c + 252a b )d
+--R             + 
+--R                     7   2        6 3        5 5  3
+--R               (3840a b c  - 1920a b c + 240a b )d
+--R             + 
+--R                    8 2       7 2       6 4
+--R               (576a c  - 288a b c + 36a b )d
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  10
+--R               (2112a c  - 1056a b c  + 132a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   8
+--R               (3456a b c  - 1728a b c  + 216a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  6
+--R               (2688a c  - 504a b c + 84a b )d
+--R             + 
+--R                     7   2       6 3        5 5  4
+--R               (1920a b c  - 960a b c + 120a b )d
+--R             + 
+--R                    8 2       7 2       6 4  2
+--R               (576a c  - 288a b c + 36a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                    6 4      5 2 3      4 4 2  11
+--R               (192a c  - 96a b c  + 12a b c )d
+--R             + 
+--R                    6   3       5 3 2      4 5   9
+--R               (384a b c  - 192a b c  + 24a b c)d
+--R             + 
+--R                    7 3      5 4       4 6  7
+--R               (384a c  - 72a b c + 12a b )d
+--R             + 
+--R                  7   2       6 3       5 5  5        8 2      7 2       6 4  3
+--R             (384a b c  - 192a b c + 24a b )d  + (192a c  - 96a b c + 12a b )d
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                  10 10              9 2 9               8 4 8
+--R                      - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                    + 
+--R                                  7 6 7               6 8 6              5 10 5
+--R                      21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                    + 
+--R                                   4 12 4             3 14 3            2 16 2
+--R                      - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                    + 
+--R                                18           20
+--R                      5341000a b  c - 171500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                  6 4      5 2 3      4 4 2  12 11
+--R           (- 192a c  + 96a b c  - 12a b c )e  x
+--R         + 
+--R                   6 4        5 2 3       4 4 2    11 10
+--R           (- 2112a c  + 1056a b c  - 132a b c )d e  x
+--R         + 
+--R                        6 4        5 2 3       4 4 2  2       6   3       5 3 2
+--R               (- 10560a c  + 5280a b c  - 660a b c )d  - 384a b c  + 192a b c
+--R             + 
+--R                    4 5
+--R               - 24a b c
+--R          *
+--R              10 9
+--R             e  x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  3
+--R               (- 31680a c  + 15840a b c  - 1980a b c )d
+--R             + 
+--R                       6   3        5 3 2       4 5
+--R               (- 3456a b c  + 1728a b c  - 216a b c)d
+--R          *
+--R              9 8
+--R             e x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  4
+--R               (- 63360a c  + 31680a b c  - 3960a b c )d
+--R             + 
+--R                        6   3        5 3 2       4 5   2       7 3      5 4
+--R               (- 13824a b c  + 6912a b c  - 864a b c)d  - 384a c  + 72a b c
+--R             + 
+--R                    4 6
+--R               - 12a b
+--R          *
+--R              8 7
+--R             e x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  5
+--R               (- 88704a c  + 44352a b c  - 5544a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   3
+--R               (- 32256a b c  + 16128a b c  - 2016a b c)d
+--R             + 
+--R                       7 3       5 4       4 6
+--R               (- 2688a c  + 504a b c - 84a b )d
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  6
+--R               (- 88704a c  + 44352a b c  - 5544a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   4
+--R               (- 48384a b c  + 24192a b c  - 3024a b c)d
+--R             + 
+--R                       7 3        5 4        4 6  2       7   2       6 3
+--R               (- 8064a c  + 1512a b c - 252a b )d  - 384a b c  + 192a b c
+--R             + 
+--R                    5 5
+--R               - 24a b
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  7
+--R               (- 63360a c  + 31680a b c  - 3960a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   5
+--R               (- 48384a b c  + 24192a b c  - 3024a b c)d
+--R             + 
+--R                        7 3        5 4        4 6  3
+--R               (- 13440a c  + 2520a b c - 420a b )d
+--R             + 
+--R                       7   2       6 3        5 5
+--R               (- 1920a b c  + 960a b c - 120a b )d
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  8
+--R               (- 31680a c  + 15840a b c  - 1980a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   6
+--R               (- 32256a b c  + 16128a b c  - 2016a b c)d
+--R             + 
+--R                        7 3        5 4        4 6  4
+--R               (- 13440a c  + 2520a b c - 420a b )d
+--R             + 
+--R                     7   2        6 3        5 5  2       8 2      7 2       6 4
+--R             (- 3840a b c  + 1920a b c - 240a b )d  - 192a c  + 96a b c - 12a b
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                        6 4        5 2 3       4 4 2  9
+--R               (- 10560a c  + 5280a b c  - 660a b c )d
+--R             + 
+--R                        6   3        5 3 2       4 5   7
+--R               (- 13824a b c  + 6912a b c  - 864a b c)d
+--R             + 
+--R                       7 3        5 4        4 6  5
+--R               (- 8064a c  + 1512a b c - 252a b )d
+--R             + 
+--R                       7   2        6 3        5 5  3
+--R               (- 3840a b c  + 1920a b c - 240a b )d
+--R             + 
+--R                      8 2       7 2       6 4
+--R               (- 576a c  + 288a b c - 36a b )d
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                       6 4        5 2 3       4 4 2  10
+--R               (- 2112a c  + 1056a b c  - 132a b c )d
+--R             + 
+--R                       6   3        5 3 2       4 5   8
+--R               (- 3456a b c  + 1728a b c  - 216a b c)d
+--R             + 
+--R                       7 3       5 4       4 6  6
+--R               (- 2688a c  + 504a b c - 84a b )d
+--R             + 
+--R                       7   2       6 3        5 5  4
+--R               (- 1920a b c  + 960a b c - 120a b )d
+--R             + 
+--R                      8 2       7 2       6 4  2
+--R               (- 576a c  + 288a b c - 36a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                      6 4      5 2 3      4 4 2  11
+--R               (- 192a c  + 96a b c  - 12a b c )d
+--R             + 
+--R                      6   3       5 3 2      4 5   9
+--R               (- 384a b c  + 192a b c  - 24a b c)d
+--R             + 
+--R                      7 3      5 4       4 6  7
+--R               (- 384a c  + 72a b c - 12a b )d
+--R             + 
+--R                      7   2       6 3       5 5  5
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R             + 
+--R                      8 2      7 2       6 4  3
+--R               (- 192a c  + 96a b c - 12a b )d
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                10 10              9 2 9               8 4 8
+--R                      467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                    + 
+--R                                    7 6 7               6 8 6
+--R                      - 21970145504a b c  + 17711314348a b c
+--R                    + 
+--R                                   5 10 5              4 12 4             3 14 3
+--R                      - 8747324300a b  c  + 2769618280a b  c  - 566790200a b  c
+--R                    + 
+--R                               2 16 2             18           20
+--R                      72753100a b  c  - 5341000a b  c + 171500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                6 4      5 2 3      4 4 2  12 11
+--R           (192a c  - 96a b c  + 12a b c )e  x
+--R         + 
+--R                 6 4        5 2 3       4 4 2    11 10
+--R           (2112a c  - 1056a b c  + 132a b c )d e  x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  2       6   3       5 3 2
+--R               (10560a c  - 5280a b c  + 660a b c )d  + 384a b c  - 192a b c
+--R             + 
+--R                  4 5
+--R               24a b c
+--R          *
+--R              10 9
+--R             e  x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  3
+--R               (31680a c  - 15840a b c  + 1980a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5
+--R               (3456a b c  - 1728a b c  + 216a b c)d
+--R          *
+--R              9 8
+--R             e x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  4
+--R               (63360a c  - 31680a b c  + 3960a b c )d
+--R             + 
+--R                      6   3        5 3 2       4 5   2       7 3      5 4
+--R               (13824a b c  - 6912a b c  + 864a b c)d  + 384a c  - 72a b c
+--R             + 
+--R                  4 6
+--R               12a b
+--R          *
+--R              8 7
+--R             e x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  5
+--R               (88704a c  - 44352a b c  + 5544a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   3
+--R               (32256a b c  - 16128a b c  + 2016a b c)d
+--R             + 
+--R                     7 3       5 4       4 6
+--R               (2688a c  - 504a b c + 84a b )d
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  6
+--R               (88704a c  - 44352a b c  + 5544a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   4
+--R               (48384a b c  - 24192a b c  + 3024a b c)d
+--R             + 
+--R                   7 3        5 4        4 6  2       7   2       6 3       5 5
+--R             (8064a c  - 1512a b c + 252a b )d  + 384a b c  - 192a b c + 24a b
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  7
+--R               (63360a c  - 31680a b c  + 3960a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   5
+--R               (48384a b c  - 24192a b c  + 3024a b c)d
+--R             + 
+--R                      7 3        5 4        4 6  3
+--R               (13440a c  - 2520a b c + 420a b )d
+--R             + 
+--R                     7   2       6 3        5 5
+--R               (1920a b c  - 960a b c + 120a b )d
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  8
+--R               (31680a c  - 15840a b c  + 1980a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   6
+--R               (32256a b c  - 16128a b c  + 2016a b c)d
+--R             + 
+--R                      7 3        5 4        4 6  4
+--R               (13440a c  - 2520a b c + 420a b )d
+--R             + 
+--R                   7   2        6 3        5 5  2       8 2      7 2       6 4
+--R             (3840a b c  - 1920a b c + 240a b )d  + 192a c  - 96a b c + 12a b
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  9
+--R               (10560a c  - 5280a b c  + 660a b c )d
+--R             + 
+--R                      6   3        5 3 2       4 5   7
+--R               (13824a b c  - 6912a b c  + 864a b c)d
+--R             + 
+--R                     7 3        5 4        4 6  5
+--R               (8064a c  - 1512a b c + 252a b )d
+--R             + 
+--R                     7   2        6 3        5 5  3
+--R               (3840a b c  - 1920a b c + 240a b )d
+--R             + 
+--R                    8 2       7 2       6 4
+--R               (576a c  - 288a b c + 36a b )d
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  10
+--R               (2112a c  - 1056a b c  + 132a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   8
+--R               (3456a b c  - 1728a b c  + 216a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  6
+--R               (2688a c  - 504a b c + 84a b )d
+--R             + 
+--R                     7   2       6 3        5 5  4
+--R               (1920a b c  - 960a b c + 120a b )d
+--R             + 
+--R                    8 2       7 2       6 4  2
+--R               (576a c  - 288a b c + 36a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                    6 4      5 2 3      4 4 2  11
+--R               (192a c  - 96a b c  + 12a b c )d
+--R             + 
+--R                    6   3       5 3 2      4 5   9
+--R               (384a b c  - 192a b c  + 24a b c)d
+--R             + 
+--R                    7 3      5 4       4 6  7
+--R               (384a c  - 72a b c + 12a b )d
+--R             + 
+--R                  7   2       6 3       5 5  5        8 2      7 2       6 4  3
+--R             (384a b c  - 192a b c + 24a b )d  + (192a c  - 96a b c + 12a b )d
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                  10 10              9 2 9               8 4 8
+--R                      - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                    + 
+--R                                  7 6 7               6 8 6              5 10 5
+--R                      21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                    + 
+--R                                   4 12 4             3 14 3            2 16 2
+--R                      - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                    + 
+--R                                18           20
+--R                      5341000a b  c - 171500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R             2   4         3 3       5 2  10 10
+--R       (1524a b c  - 810a b c  + 105b c )e  x
+--R     + 
+--R              2   4          3 3        5 2    9 9
+--R       (15240a b c  - 8100a b c  + 1050b c )d e x
+--R     + 
+--R                  2   4           3 3        5 2  2       3 4        2 2 3
+--R           (68580a b c  - 36450a b c  + 4725b c )d  - 308a c  + 3283a b c
+--R         + 
+--R                    4 2       6
+--R           - 1655a b c  + 210b c
+--R      *
+--R          8 8
+--R         e x
+--R     + 
+--R                   2   4           3 3         5 2  3
+--R           (182880a b c  - 97200a b c  + 12600b c )d
+--R         + 
+--R                   3 4         2 2 3           4 2        6
+--R           (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R      *
+--R          7 7
+--R         e x
+--R     + 
+--R                   2   4            3 3         5 2  4
+--R           (320040a b c  - 170100a b c  + 22050b c )d
+--R         + 
+--R                   3 4         2 2 3           4 2        6   2        3   3
+--R           (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d  + 2312a b c
+--R         + 
+--R               2 3 2         5        7
+--R           395a b c  - 670a b c + 105b
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R                   2   4            3 3         5 2  5
+--R           (384048a b c  - 204120a b c  + 26460b c )d
+--R         + 
+--R                    3 4          2 2 3           4 2         6   3
+--R           (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R         + 
+--R                  3   3        2 3 2          5        7
+--R           (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R                   2   4            3 3         5 2  6
+--R           (320040a b c  - 170100a b c  + 22050b c )d
+--R         + 
+--R                    3 4          2 2 3            4 2         6   4
+--R           (- 21560a c  + 229810a b c  - 115850a b c  + 14700b c)d
+--R         + 
+--R                  3   3        2 3 2           5         7  2       4 3
+--R           (34680a b c  + 5925a b c  - 10050a b c + 1575b )d  - 484a c
+--R         + 
+--R                3 2 2        2 4          6
+--R           2955a b c  - 1413a b c + 175a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R                   2   4           3 3         5 2  7
+--R           (182880a b c  - 97200a b c  + 12600b c )d
+--R         + 
+--R                    3 4          2 2 3           4 2         6   5
+--R           (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R         + 
+--R                  3   3        2 3 2           5         7  3
+--R           (46240a b c  + 7900a b c  - 13400a b c + 2100b )d
+--R         + 
+--R                   4 3         3 2 2        2 4          6
+--R           (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R                  2   4           3 3        5 2  8
+--R           (68580a b c  - 36450a b c  + 4725b c )d
+--R         + 
+--R                   3 4         2 2 3           4 2        6   6
+--R           (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d
+--R         + 
+--R                  3   3        2 3 2           5         7  4
+--R           (34680a b c  + 5925a b c  - 10050a b c + 1575b )d
+--R         + 
+--R                   4 3         3 2 2        2 4           6  2       4   2
+--R           (- 2904a c  + 17730a b c  - 8478a b c + 1050a b )d  + 896a b c
+--R         + 
+--R                 3 3       2 5
+--R           - 448a b c + 56a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R                  2   4          3 3        5 2  9
+--R           (15240a b c  - 8100a b c  + 1050b c )d
+--R         + 
+--R                   3 4         2 2 3           4 2        6   7
+--R           (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R         + 
+--R                  3   3        2 3 2          5        7  5
+--R           (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R         + 
+--R                   4 3         3 2 2        2 4          6  3
+--R           (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R         + 
+--R                 4   2       3 3        2 5
+--R           (1792a b c  - 896a b c + 112a b )d
+--R      *
+--R         e x
+--R     + 
+--R             2   4         3 3       5 2  10
+--R       (1524a b c  - 810a b c  + 105b c )d
+--R     + 
+--R              3 4        2 2 3          4 2       6   8
+--R       (- 308a c  + 3283a b c  - 1655a b c  + 210b c)d
+--R     + 
+--R             3   3       2 3 2         5        7  6
+--R       (2312a b c  + 395a b c  - 670a b c + 105b )d
+--R     + 
+--R              4 3        3 2 2        2 4          6  4
+--R       (- 484a c  + 2955a b c  - 1413a b c + 175a b )d
+--R     + 
+--R            4   2       3 3       2 5  2       5 2      4 2      3 4
+--R       (896a b c  - 448a b c + 56a b )d  - 128a c  + 64a b c - 8a b
+--R  /
+--R            6 4       5 2 3      4 4 2  12 11
+--R       (384a c  - 192a b c  + 24a b c )e  x
+--R     + 
+--R             6 4        5 2 3       4 4 2    11 10
+--R       (4224a c  - 2112a b c  + 264a b c )d e  x
+--R     + 
+--R                  6 4         5 2 3        4 4 2  2       6   3       5 3 2
+--R           (21120a c  - 10560a b c  + 1320a b c )d  + 768a b c  - 384a b c
+--R         + 
+--R              4 5
+--R           48a b c
+--R      *
+--R          10 9
+--R         e  x
+--R     + 
+--R                  6 4         5 2 3        4 4 2  3
+--R           (63360a c  - 31680a b c  + 3960a b c )d
+--R         + 
+--R                 6   3        5 3 2       4 5
+--R           (6912a b c  - 3456a b c  + 432a b c)d
+--R      *
+--R          9 8
+--R         e x
+--R     + 
+--R                   6 4         5 2 3        4 4 2  4
+--R           (126720a c  - 63360a b c  + 7920a b c )d
+--R         + 
+--R                6   3         5 3 2        4 5   2       7 3       5 4       4 6
+--R         (27648a b c  - 13824a b c  + 1728a b c)d  + 768a c  - 144a b c + 24a b
+--R      *
+--R          8 7
+--R         e x
+--R     + 
+--R                   6 4         5 2 3         4 4 2  5
+--R           (177408a c  - 88704a b c  + 11088a b c )d
+--R         + 
+--R                  6   3         5 3 2        4 5   3
+--R           (64512a b c  - 32256a b c  + 4032a b c)d
+--R         + 
+--R                 7 3        5 4        4 6
+--R           (5376a c  - 1008a b c + 168a b )d
+--R      *
+--R          7 6
+--R         e x
+--R     + 
+--R                   6 4         5 2 3         4 4 2  6
+--R           (177408a c  - 88704a b c  + 11088a b c )d
+--R         + 
+--R                  6   3         5 3 2        4 5   4
+--R           (96768a b c  - 48384a b c  + 6048a b c)d
+--R         + 
+--R                  7 3        5 4        4 6  2       7   2       6 3       5 5
+--R           (16128a c  - 3024a b c + 504a b )d  + 768a b c  - 384a b c + 48a b
+--R      *
+--R          6 5
+--R         e x
+--R     + 
+--R                   6 4         5 2 3        4 4 2  7
+--R           (126720a c  - 63360a b c  + 7920a b c )d
+--R         + 
+--R                  6   3         5 3 2        4 5   5
+--R           (96768a b c  - 48384a b c  + 6048a b c)d
+--R         + 
+--R                  7 3        5 4        4 6  3
+--R           (26880a c  - 5040a b c + 840a b )d
+--R         + 
+--R                 7   2        6 3        5 5
+--R           (3840a b c  - 1920a b c + 240a b )d
+--R      *
+--R          5 4
+--R         e x
+--R     + 
+--R                  6 4         5 2 3        4 4 2  8
+--R           (63360a c  - 31680a b c  + 3960a b c )d
+--R         + 
+--R                  6   3         5 3 2        4 5   6
+--R           (64512a b c  - 32256a b c  + 4032a b c)d
+--R         + 
+--R                  7 3        5 4        4 6  4
+--R           (26880a c  - 5040a b c + 840a b )d
+--R         + 
+--R                 7   2        6 3        5 5  2       8 2       7 2       6 4
+--R           (7680a b c  - 3840a b c + 480a b )d  + 384a c  - 192a b c + 24a b
+--R      *
+--R          4 3
+--R         e x
+--R     + 
+--R                  6 4         5 2 3        4 4 2  9
+--R           (21120a c  - 10560a b c  + 1320a b c )d
+--R         + 
+--R                  6   3         5 3 2        4 5   7
+--R           (27648a b c  - 13824a b c  + 1728a b c)d
+--R         + 
+--R                  7 3        5 4        4 6  5
+--R           (16128a c  - 3024a b c + 504a b )d
+--R         + 
+--R               7   2        6 3        5 5  3         8 2       7 2       6 4
+--R         (7680a b c  - 3840a b c + 480a b )d  + (1152a c  - 576a b c + 72a b )d
+--R      *
+--R          3 2
+--R         e x
+--R     + 
+--R                 6 4        5 2 3       4 4 2  10
+--R           (4224a c  - 2112a b c  + 264a b c )d
+--R         + 
+--R                 6   3        5 3 2       4 5   8
+--R           (6912a b c  - 3456a b c  + 432a b c)d
+--R         + 
+--R                 7 3        5 4        4 6  6
+--R           (5376a c  - 1008a b c + 168a b )d
+--R         + 
+--R               7   2        6 3        5 5  4         8 2       7 2       6 4  2
+--R         (3840a b c  - 1920a b c + 240a b )d  + (1152a c  - 576a b c + 72a b )d
+--R      *
+--R          2
+--R         e x
+--R     + 
+--R                6 4       5 2 3      4 4 2  11
+--R           (384a c  - 192a b c  + 24a b c )d
+--R         + 
+--R                6   3       5 3 2      4 5   9        7 3       5 4       4 6  7
+--R           (768a b c  - 384a b c  + 48a b c)d  + (768a c  - 144a b c + 24a b )d
+--R         + 
+--R                7   2       6 3       5 5  5        8 2       7 2       6 4  3
+--R           (768a b c  - 384a b c + 48a b )d  + (384a c  - 192a b c + 24a b )d
+--R      *
+--R         e
+--R                                         Type: Union(Expression(Integer),...)
+--E 901
+
+--S 902 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                         +--------------------+
+--R                                           +-----------+ |   +-----------+
+--R               6 2      5 2      4 4   +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                10 10              9 2 9               8 4 8
+--R                      467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                    + 
+--R                                    7 6 7               6 8 6
+--R                      - 21970145504a b c  + 17711314348a b c
+--R                    + 
+--R                                   5 10 5              4 12 4             3 14 3
+--R                      - 8747324300a b  c  + 2769618280a b  c  - 566790200a b  c
+--R                    + 
+--R                               2 16 2             18           20
+--R                      72753100a b  c  - 5341000a b  c + 171500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                                         +-----------+
+--R             6 2      5 2      4 4   +-+ |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                  10 10              9 2 9               8 4 8
+--R                      - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                    + 
+--R                                  7 6 7               6 8 6              5 10 5
+--R                      21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                    + 
+--R                                   4 12 4             3 14 3            2 16 2
+--R                      - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                    + 
+--R                                18           20
+--R                      5341000a b  c - 171500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                                           +-----------+
+--R               6 2      5 2      4 4   +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                10 10              9 2 9               8 4 8
+--R                      467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                    + 
+--R                                    7 6 7               6 8 6
+--R                      - 21970145504a b c  + 17711314348a b c
+--R                    + 
+--R                                   5 10 5              4 12 4             3 14 3
+--R                      - 8747324300a b  c  + 2769618280a b  c  - 566790200a b  c
+--R                    + 
+--R                               2 16 2             18           20
+--R                      72753100a b  c  - 5341000a b  c + 171500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                                                       +--------------------+
+--R                                         +-----------+ |   +-----------+
+--R             6 2      5 2      4 4   +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                  10 10              9 2 9               8 4 8
+--R                      - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                    + 
+--R                                  7 6 7               6 8 6              5 10 5
+--R                      21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                    + 
+--R                                   4 12 4             3 14 3            2 16 2
+--R                      - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                    + 
+--R                                18           20
+--R                      5341000a b  c - 171500b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                                           +-----------+
+--R                  2   2         3       5  |          2        3 3       2 2 2
+--R           (- 508a b c  + 270a b c - 35b )\|- 4a c + b   + 616a c  - 978a b c
+--R         + 
+--R                 4       6
+--R           340a b c - 35b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                           +-----------+
+--R                  2   2         3       5  |          2        3 3       2 2 2
+--R           (- 508a b c  + 270a b c - 35b )\|- 4a c + b   - 616a c  + 978a b c
+--R         + 
+--R                   4       6
+--R           - 340a b c + 35b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R            6 2      5 2      4 4   +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 902
+
+--S 903 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 903
+
+)clear all
+
+--S 904 of 1057
+t0:=(d*f+e*f*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                 4 4 4       3 4 3     2 2 4 2     3   4     4 4
+--R                e f x  + 4d e f x  + 6d e f x  + 4d e f x + d f
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 904
+
+--S 905 of 1057
+r0:=f^4*x/c-f^4*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*e*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))-f^4*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                  +------------------+
+--R                 +-----------+                    | +-----------+
+--R               4 |          2               2  4  | |          2
+--R         (- b f \|- 4a c + b   + (- 2a c + b )f )\|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                +--------------------+
+--R                 +-----------+                  |   +-----------+
+--R               4 |          2             2  4  |   |          2
+--R         (- b f \|- 4a c + b   + (2a c - b )f )\|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                   +--------------------+ +------------------+
+--R                 +-----------+     |   +-----------+      | +-----------+
+--R          4  +-+ |          2  +-+ |   |          2       | |          2
+--R       e f x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R         +-+ |          2  +-+ |   |          2       | |          2
+--R     c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 905
+
+--S 906 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +------------------------------------------------------------------+
+--R           |                   +-------------------------+
+--R           |                   |    2 2       2     4  16
+--R           |      4     2 3  2 |(- a c  + 2a b c - b )f                   3  8
+--R           |(16a c  - 4b c )e  |-------------------------  + (- 3a b c + b )f
+--R           |                   |         7      2 6  4
+--R           |                  \|   (64a c  - 16b c )e
+--R         c |------------------------------------------------------------------
+--R           |                              4     2 3  2
+--R          \|                         (8a c  - 2b c )e
+--R      *
+--R         log
+--R                                       +-------------------------+
+--R                                       |    2 2       2     4  16
+--R                          4     3 3  3 |(- a c  + 2a b c - b )f
+--R                  (16a b c  - 4b c )e  |-------------------------
+--R                                       |         7      2 6  4
+--R                                      \|   (64a c  - 16b c )e
+--R                + 
+--R                       2 2       2     4    8
+--R                  (- 4a c  + 5a b c - b )e f
+--R             *
+--R                ROOT
+--R                                          +-------------------------+
+--R                                          |    2 2       2     4  16
+--R                             4     2 3  2 |(- a c  + 2a b c - b )f
+--R                       (16a c  - 4b c )e  |-------------------------
+--R                                          |         7      2 6  4
+--R                                         \|   (64a c  - 16b c )e
+--R                     + 
+--R                                    3  8
+--R                       (- 3a b c + b )f
+--R                  /
+--R                          4     2 3  2
+--R                     (8a c  - 2b c )e
+--R            + 
+--R                 2        2    12       2        2    12
+--R              (2a c - 2a b )e f  x + (2a c - 2a b )d f
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                                        +-------------------------+
+--R                                        |    2 2       2     4  16
+--R                           4     2 3  2 |(- a c  + 2a b c - b )f
+--R                   (- 16a c  + 4b c )e  |-------------------------
+--R                                        |         7      2 6  4
+--R                                       \|   (64a c  - 16b c )e
+--R                 + 
+--R                                3  8
+--R                   (- 3a b c + b )f
+--R              /
+--R                      4     2 3  2
+--R                 (8a c  - 2b c )e
+--R         *
+--R            log
+--R                                          +-------------------------+
+--R                                          |    2 2       2     4  16
+--R                             4     3 3  3 |(- a c  + 2a b c - b )f
+--R                     (16a b c  - 4b c )e  |-------------------------
+--R                                          |         7      2 6  4
+--R                                         \|   (64a c  - 16b c )e
+--R                   + 
+--R                        2 2       2     4    8
+--R                     (4a c  - 5a b c + b )e f
+--R                *
+--R                   ROOT
+--R                                               +-------------------------+
+--R                                               |    2 2       2     4  16
+--R                                  4     2 3  2 |(- a c  + 2a b c - b )f
+--R                          (- 16a c  + 4b c )e  |-------------------------
+--R                                               |         7      2 6  4
+--R                                              \|   (64a c  - 16b c )e
+--R                        + 
+--R                                       3  8
+--R                          (- 3a b c + b )f
+--R                     /
+--R                             4     2 3  2
+--R                        (8a c  - 2b c )e
+--R               + 
+--R                    2        2    12       2        2    12
+--R                 (2a c - 2a b )e f  x + (2a c - 2a b )d f
+--R     + 
+--R         c
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |                     +-------------------------+
+--R          |                     |    2 2       2     4  16
+--R          |        4     2 3  2 |(- a c  + 2a b c - b )f                   3  8
+--R          |(- 16a c  + 4b c )e  |-------------------------  + (- 3a b c + b )f
+--R          |                     |         7      2 6  4
+--R          |                    \|   (64a c  - 16b c )e
+--R          |--------------------------------------------------------------------
+--R          |                               4     2 3  2
+--R         \|                          (8a c  - 2b c )e
+--R      *
+--R         log
+--R                                         +-------------------------+
+--R                                         |    2 2       2     4  16
+--R                            4     3 3  3 |(- a c  + 2a b c - b )f
+--R                  (- 16a b c  + 4b c )e  |-------------------------
+--R                                         |         7      2 6  4
+--R                                        \|   (64a c  - 16b c )e
+--R                + 
+--R                       2 2       2     4    8
+--R                  (- 4a c  + 5a b c - b )e f
+--R             *
+--R                ROOT
+--R                                            +-------------------------+
+--R                                            |    2 2       2     4  16
+--R                               4     2 3  2 |(- a c  + 2a b c - b )f
+--R                       (- 16a c  + 4b c )e  |-------------------------
+--R                                            |         7      2 6  4
+--R                                           \|   (64a c  - 16b c )e
+--R                     + 
+--R                                    3  8
+--R                       (- 3a b c + b )f
+--R                  /
+--R                          4     2 3  2
+--R                     (8a c  - 2b c )e
+--R            + 
+--R                 2        2    12       2        2    12
+--R              (2a c - 2a b )e f  x + (2a c - 2a b )d f
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                                      +-------------------------+
+--R                                      |    2 2       2     4  16
+--R                         4     2 3  2 |(- a c  + 2a b c - b )f
+--R                   (16a c  - 4b c )e  |-------------------------
+--R                                      |         7      2 6  4
+--R                                     \|   (64a c  - 16b c )e
+--R                 + 
+--R                                3  8
+--R                   (- 3a b c + b )f
+--R              /
+--R                      4     2 3  2
+--R                 (8a c  - 2b c )e
+--R         *
+--R            log
+--R                                            +-------------------------+
+--R                                            |    2 2       2     4  16
+--R                               4     3 3  3 |(- a c  + 2a b c - b )f
+--R                     (- 16a b c  + 4b c )e  |-------------------------
+--R                                            |         7      2 6  4
+--R                                           \|   (64a c  - 16b c )e
+--R                   + 
+--R                        2 2       2     4    8
+--R                     (4a c  - 5a b c + b )e f
+--R                *
+--R                   ROOT
+--R                                             +-------------------------+
+--R                                             |    2 2       2     4  16
+--R                                4     2 3  2 |(- a c  + 2a b c - b )f
+--R                          (16a c  - 4b c )e  |-------------------------
+--R                                             |         7      2 6  4
+--R                                            \|   (64a c  - 16b c )e
+--R                        + 
+--R                                       3  8
+--R                          (- 3a b c + b )f
+--R                     /
+--R                             4     2 3  2
+--R                        (8a c  - 2b c )e
+--R               + 
+--R                    2        2    12       2        2    12
+--R                 (2a c - 2a b )e f  x + (2a c - 2a b )d f
+--R     + 
+--R         4
+--R       2f x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 906
+
+--S 907 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   +--------------------+
+--R                 +-----------+     |   +-----------+
+--R             +-+ |          2  +-+ |   |          2
+--R         c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------------------------------------------------------+
+--R          |                   +-------------------------+
+--R          |                   |    2 2       2     4  16
+--R          |      4     2 3  2 |(- a c  + 2a b c - b )f                   3  8
+--R          |(16a c  - 4b c )e  |-------------------------  + (- 3a b c + b )f
+--R          |                   |         7      2 6  4
+--R          |                  \|   (64a c  - 16b c )e
+--R          |------------------------------------------------------------------
+--R          |                              4     2 3  2
+--R         \|                         (8a c  - 2b c )e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                       +-------------------------+
+--R                                       |    2 2       2     4  16
+--R                          4     3 3  3 |(- a c  + 2a b c - b )f
+--R                  (16a b c  - 4b c )e  |-------------------------
+--R                                       |         7      2 6  4
+--R                                      \|   (64a c  - 16b c )e
+--R                + 
+--R                       2 2       2     4    8
+--R                  (- 4a c  + 5a b c - b )e f
+--R             *
+--R                ROOT
+--R                                          +-------------------------+
+--R                                          |    2 2       2     4  16
+--R                             4     2 3  2 |(- a c  + 2a b c - b )f
+--R                       (16a c  - 4b c )e  |-------------------------
+--R                                          |         7      2 6  4
+--R                                         \|   (64a c  - 16b c )e
+--R                     + 
+--R                                    3  8
+--R                       (- 3a b c + b )f
+--R                  /
+--R                          4     2 3  2
+--R                     (8a c  - 2b c )e
+--R            + 
+--R                 2        2    12       2        2    12
+--R              (2a c - 2a b )e f  x + (2a c - 2a b )d f
+--R     + 
+--R       -
+--R                                      +--------------------+
+--R                    +-----------+     |   +-----------+
+--R                +-+ |          2  +-+ |   |          2
+--R            c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                        +-------------------------+
+--R                                        |    2 2       2     4  16
+--R                           4     2 3  2 |(- a c  + 2a b c - b )f
+--R                   (- 16a c  + 4b c )e  |-------------------------
+--R                                        |         7      2 6  4
+--R                                       \|   (64a c  - 16b c )e
+--R                 + 
+--R                                3  8
+--R                   (- 3a b c + b )f
+--R              /
+--R                      4     2 3  2
+--R                 (8a c  - 2b c )e
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                          +-------------------------+
+--R                                          |    2 2       2     4  16
+--R                             4     3 3  3 |(- a c  + 2a b c - b )f
+--R                     (16a b c  - 4b c )e  |-------------------------
+--R                                          |         7      2 6  4
+--R                                         \|   (64a c  - 16b c )e
+--R                   + 
+--R                        2 2       2     4    8
+--R                     (4a c  - 5a b c + b )e f
+--R                *
+--R                   ROOT
+--R                                               +-------------------------+
+--R                                               |    2 2       2     4  16
+--R                                  4     2 3  2 |(- a c  + 2a b c - b )f
+--R                          (- 16a c  + 4b c )e  |-------------------------
+--R                                               |         7      2 6  4
+--R                                              \|   (64a c  - 16b c )e
+--R                        + 
+--R                                       3  8
+--R                          (- 3a b c + b )f
+--R                     /
+--R                             4     2 3  2
+--R                        (8a c  - 2b c )e
+--R               + 
+--R                    2        2    12       2        2    12
+--R                 (2a c - 2a b )e f  x + (2a c - 2a b )d f
+--R     + 
+--R                                   +--------------------+
+--R                 +-----------+     |   +-----------+
+--R             +-+ |          2  +-+ |   |          2
+--R         c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |                     +-------------------------+
+--R          |                     |    2 2       2     4  16
+--R          |        4     2 3  2 |(- a c  + 2a b c - b )f                   3  8
+--R          |(- 16a c  + 4b c )e  |-------------------------  + (- 3a b c + b )f
+--R          |                     |         7      2 6  4
+--R          |                    \|   (64a c  - 16b c )e
+--R          |--------------------------------------------------------------------
+--R          |                               4     2 3  2
+--R         \|                          (8a c  - 2b c )e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                         +-------------------------+
+--R                                         |    2 2       2     4  16
+--R                            4     3 3  3 |(- a c  + 2a b c - b )f
+--R                  (- 16a b c  + 4b c )e  |-------------------------
+--R                                         |         7      2 6  4
+--R                                        \|   (64a c  - 16b c )e
+--R                + 
+--R                       2 2       2     4    8
+--R                  (- 4a c  + 5a b c - b )e f
+--R             *
+--R                ROOT
+--R                                            +-------------------------+
+--R                                            |    2 2       2     4  16
+--R                               4     2 3  2 |(- a c  + 2a b c - b )f
+--R                       (- 16a c  + 4b c )e  |-------------------------
+--R                                            |         7      2 6  4
+--R                                           \|   (64a c  - 16b c )e
+--R                     + 
+--R                                    3  8
+--R                       (- 3a b c + b )f
+--R                  /
+--R                          4     2 3  2
+--R                     (8a c  - 2b c )e
+--R            + 
+--R                 2        2    12       2        2    12
+--R              (2a c - 2a b )e f  x + (2a c - 2a b )d f
+--R     + 
+--R       -
+--R                                      +--------------------+
+--R                    +-----------+     |   +-----------+
+--R                +-+ |          2  +-+ |   |          2
+--R            c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                      +-------------------------+
+--R                                      |    2 2       2     4  16
+--R                         4     2 3  2 |(- a c  + 2a b c - b )f
+--R                   (16a c  - 4b c )e  |-------------------------
+--R                                      |         7      2 6  4
+--R                                     \|   (64a c  - 16b c )e
+--R                 + 
+--R                                3  8
+--R                   (- 3a b c + b )f
+--R              /
+--R                      4     2 3  2
+--R                 (8a c  - 2b c )e
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                            +-------------------------+
+--R                                            |    2 2       2     4  16
+--R                               4     3 3  3 |(- a c  + 2a b c - b )f
+--R                     (- 16a b c  + 4b c )e  |-------------------------
+--R                                            |         7      2 6  4
+--R                                           \|   (64a c  - 16b c )e
+--R                   + 
+--R                        2 2       2     4    8
+--R                     (4a c  - 5a b c + b )e f
+--R                *
+--R                   ROOT
+--R                                             +-------------------------+
+--R                                             |    2 2       2     4  16
+--R                                4     2 3  2 |(- a c  + 2a b c - b )f
+--R                          (16a c  - 4b c )e  |-------------------------
+--R                                             |         7      2 6  4
+--R                                            \|   (64a c  - 16b c )e
+--R                        + 
+--R                                       3  8
+--R                          (- 3a b c + b )f
+--R                     /
+--R                             4     2 3  2
+--R                        (8a c  - 2b c )e
+--R               + 
+--R                    2        2    12       2        2    12
+--R                 (2a c - 2a b )e f  x + (2a c - 2a b )d f
+--R     + 
+--R                                                +------------------+
+--R                +-----------+                   | +-----------+
+--R              4 |          2              2  4  | |          2
+--R         (2b f \|- 4a c + b   + (4a c - 2b )f )\|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                  +--------------------+
+--R                +-----------+                     |   +-----------+
+--R              4 |          2                2  4  |   |          2
+--R         (2b f \|- 4a c + b   + (- 4a c + 2b )f )\|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R     2c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 907
+
+--S 908 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 908
+
+)clear all
+
+--S 909 of 1057
+t0:=(d*f+e*f*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                       3 3 3       2 3 2     2   3     3 3
+--R                      e f x  + 3d e f x  + 3d e f x + d f
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 909
+
+--S 910 of 1057
+r0:=1/4*f^3*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(c*e)+_
+   1/2*b*f^3*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(c*e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                      2 2                  2
+--R           3      2c e x  + 4c d e x + 2c d  + b
+--R       2b f atanh(------------------------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R     + 
+--R          3
+--R         f
+--R      *
+--R         log
+--R                 4 4         3 3        2      2 2        3                 4
+--R              c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R            + 
+--R                 2
+--R              b d  + a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     4c e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 910
+
+--S 911 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              3
+--R           b f
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R            3
+--R           f
+--R        *
+--R           log
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R            +-----------+
+--R            |          2
+--R       4c e\|- 4a c + b
+--R     ,
+--R
+--R                                                      +---------+
+--R                          2 2                  2      |        2
+--R               3     (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         - 2b f atan(--------------------------------------------)
+--R                                               2
+--R                                       4a c - b
+--R       + 
+--R            3
+--R           f
+--R        *
+--R           log
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R            +---------+
+--R            |        2
+--R       4c e\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 911
+
+--S 912 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            3
+--R         b f
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                        2 2                  2
+--R             3      2c e x  + 4c d e x + 2c d  + b
+--R       - 2b f atanh(------------------------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     4c e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 912
+
+--S 913 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 913
+
+--S 914 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              +---------+          2 2                  2
+--R            3 |        2       2c e x  + 4c d e x + 2c d  + b
+--R       - b f \|4a c - b  atanh(------------------------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                                                                 +---------+
+--R              +-----------+          2 2                  2      |        2
+--R            3 |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       - b f \|- 4a c + b  atan(--------------------------------------------)
+--R                                                          2
+--R                                                  4a c - b
+--R  /
+--R          +-----------+ +---------+
+--R          |          2  |        2
+--R     2c e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 914
+
+--S 915 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 915
+
+)clear all
+
+--S 916 of 1057
+t0:=(d*f+e*f*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                             2 2 2         2     2 2
+--R                            e f x  + 2d e f x + d f
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 916
+
+--S 917 of 1057
+r0:=-f^2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(b-_
+   sqrt(b^2-4*a*c))/(e*sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+f^2*atan((d+e*x)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))/_
+   (e*sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R            +--------------------+
+--R            |   +-----------+                       +-+ +-+
+--R          2 |   |          2              (e x + d)\|2 \|c
+--R       - f \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                      +-+ +-+
+--R        2 | |          2             (e x + d)\|2 \|c
+--R       f \|\|- 4a c + b   + b atan(---------------------)
+--R                                    +------------------+
+--R                                    | +-----------+
+--R                                    | |          2
+--R                                   \|\|- 4a c + b   + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     e\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 917
+
+--S 918 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +------------------------------------------------+
+--R          |                  +---------------------+
+--R          |                  |            8
+--R          |      2     2   2 |           f                4
+--R          |(16a c  - 4b c)e  |- -------------------  + b f
+--R          |                  |        3      2 2  4
+--R          |                 \|  (64a c  - 16b c )e
+--R          |------------------------------------------------
+--R          |                     2     2   2
+--R         \|                (8a c  - 2b c)e
+--R      *
+--R         log
+--R                                  +---------------------+
+--R                                  |            8
+--R                      2     2   3 |           f
+--R                (16a c  - 4b c)e  |- -------------------
+--R                                  |        3      2 2  4
+--R                                 \|  (64a c  - 16b c )e
+--R             *
+--R                 +------------------------------------------------+
+--R                 |                  +---------------------+
+--R                 |                  |            8
+--R                 |      2     2   2 |           f                4
+--R                 |(16a c  - 4b c)e  |- -------------------  + b f
+--R                 |                  |        3      2 2  4
+--R                 |                 \|  (64a c  - 16b c )e
+--R                 |------------------------------------------------
+--R                 |                     2     2   2
+--R                \|                (8a c  - 2b c)e
+--R            + 
+--R                 6       6
+--R              e f x + d f
+--R     + 
+--R       -
+--R             +--------------------------------------------------+
+--R             |                    +---------------------+
+--R             |                    |            8
+--R             |        2     2   2 |           f                4
+--R             |(- 16a c  + 4b c)e  |- -------------------  + b f
+--R             |                    |        3      2 2  4
+--R             |                   \|  (64a c  - 16b c )e
+--R             |--------------------------------------------------
+--R             |                      2     2   2
+--R            \|                 (8a c  - 2b c)e
+--R         *
+--R            log
+--R                                     +---------------------+
+--R                                     |            8
+--R                         2     2   3 |           f
+--R                   (16a c  - 4b c)e  |- -------------------
+--R                                     |        3      2 2  4
+--R                                    \|  (64a c  - 16b c )e
+--R                *
+--R                    +--------------------------------------------------+
+--R                    |                    +---------------------+
+--R                    |                    |            8
+--R                    |        2     2   2 |           f                4
+--R                    |(- 16a c  + 4b c)e  |- -------------------  + b f
+--R                    |                    |        3      2 2  4
+--R                    |                   \|  (64a c  - 16b c )e
+--R                    |--------------------------------------------------
+--R                    |                      2     2   2
+--R                   \|                 (8a c  - 2b c)e
+--R               + 
+--R                    6       6
+--R                 e f x + d f
+--R     + 
+--R          +--------------------------------------------------+
+--R          |                    +---------------------+
+--R          |                    |            8
+--R          |        2     2   2 |           f                4
+--R          |(- 16a c  + 4b c)e  |- -------------------  + b f
+--R          |                    |        3      2 2  4
+--R          |                   \|  (64a c  - 16b c )e
+--R          |--------------------------------------------------
+--R          |                      2     2   2
+--R         \|                 (8a c  - 2b c)e
+--R      *
+--R         log
+--R                                    +---------------------+
+--R                                    |            8
+--R                        2     2   3 |           f
+--R                (- 16a c  + 4b c)e  |- -------------------
+--R                                    |        3      2 2  4
+--R                                   \|  (64a c  - 16b c )e
+--R             *
+--R                 +--------------------------------------------------+
+--R                 |                    +---------------------+
+--R                 |                    |            8
+--R                 |        2     2   2 |           f                4
+--R                 |(- 16a c  + 4b c)e  |- -------------------  + b f
+--R                 |                    |        3      2 2  4
+--R                 |                   \|  (64a c  - 16b c )e
+--R                 |--------------------------------------------------
+--R                 |                      2     2   2
+--R                \|                 (8a c  - 2b c)e
+--R            + 
+--R                 6       6
+--R              e f x + d f
+--R     + 
+--R       -
+--R             +------------------------------------------------+
+--R             |                  +---------------------+
+--R             |                  |            8
+--R             |      2     2   2 |           f                4
+--R             |(16a c  - 4b c)e  |- -------------------  + b f
+--R             |                  |        3      2 2  4
+--R             |                 \|  (64a c  - 16b c )e
+--R             |------------------------------------------------
+--R             |                     2     2   2
+--R            \|                (8a c  - 2b c)e
+--R         *
+--R            log
+--R                                       +---------------------+
+--R                                       |            8
+--R                           2     2   3 |           f
+--R                   (- 16a c  + 4b c)e  |- -------------------
+--R                                       |        3      2 2  4
+--R                                      \|  (64a c  - 16b c )e
+--R                *
+--R                    +------------------------------------------------+
+--R                    |                  +---------------------+
+--R                    |                  |            8
+--R                    |      2     2   2 |           f                4
+--R                    |(16a c  - 4b c)e  |- -------------------  + b f
+--R                    |                  |        3      2 2  4
+--R                    |                 \|  (64a c  - 16b c )e
+--R                    |------------------------------------------------
+--R                    |                     2     2   2
+--R                   \|                (8a c  - 2b c)e
+--R               + 
+--R                    6       6
+--R                 e f x + d f
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 918
+
+--S 919 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-----------+
+--R           +-+ |          2  +-+
+--R         e\|2 \|- 4a c + b  \|c
+--R      *
+--R          +------------------------------------------------+
+--R          |                  +---------------------+
+--R          |                  |            8
+--R          |      2     2   2 |           f                4
+--R          |(16a c  - 4b c)e  |- -------------------  + b f
+--R          |                  |        3      2 2  4
+--R          |                 \|  (64a c  - 16b c )e
+--R          |------------------------------------------------
+--R          |                     2     2   2
+--R         \|                (8a c  - 2b c)e
+--R      *
+--R         log
+--R                                  +---------------------+
+--R                                  |            8
+--R                      2     2   3 |           f
+--R                (16a c  - 4b c)e  |- -------------------
+--R                                  |        3      2 2  4
+--R                                 \|  (64a c  - 16b c )e
+--R             *
+--R                 +------------------------------------------------+
+--R                 |                  +---------------------+
+--R                 |                  |            8
+--R                 |      2     2   2 |           f                4
+--R                 |(16a c  - 4b c)e  |- -------------------  + b f
+--R                 |                  |        3      2 2  4
+--R                 |                 \|  (64a c  - 16b c )e
+--R                 |------------------------------------------------
+--R                 |                     2     2   2
+--R                \|                (8a c  - 2b c)e
+--R            + 
+--R                 6       6
+--R              e f x + d f
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            e\|2 \|- 4a c + b  \|c
+--R         *
+--R             +--------------------------------------------------+
+--R             |                    +---------------------+
+--R             |                    |            8
+--R             |        2     2   2 |           f                4
+--R             |(- 16a c  + 4b c)e  |- -------------------  + b f
+--R             |                    |        3      2 2  4
+--R             |                   \|  (64a c  - 16b c )e
+--R             |--------------------------------------------------
+--R             |                      2     2   2
+--R            \|                 (8a c  - 2b c)e
+--R         *
+--R            log
+--R                                     +---------------------+
+--R                                     |            8
+--R                         2     2   3 |           f
+--R                   (16a c  - 4b c)e  |- -------------------
+--R                                     |        3      2 2  4
+--R                                    \|  (64a c  - 16b c )e
+--R                *
+--R                    +--------------------------------------------------+
+--R                    |                    +---------------------+
+--R                    |                    |            8
+--R                    |        2     2   2 |           f                4
+--R                    |(- 16a c  + 4b c)e  |- -------------------  + b f
+--R                    |                    |        3      2 2  4
+--R                    |                   \|  (64a c  - 16b c )e
+--R                    |--------------------------------------------------
+--R                    |                      2     2   2
+--R                   \|                 (8a c  - 2b c)e
+--R               + 
+--R                    6       6
+--R                 e f x + d f
+--R     + 
+--R               +-----------+
+--R           +-+ |          2  +-+
+--R         e\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------------------------------------+
+--R          |                    +---------------------+
+--R          |                    |            8
+--R          |        2     2   2 |           f                4
+--R          |(- 16a c  + 4b c)e  |- -------------------  + b f
+--R          |                    |        3      2 2  4
+--R          |                   \|  (64a c  - 16b c )e
+--R          |--------------------------------------------------
+--R          |                      2     2   2
+--R         \|                 (8a c  - 2b c)e
+--R      *
+--R         log
+--R                                    +---------------------+
+--R                                    |            8
+--R                        2     2   3 |           f
+--R                (- 16a c  + 4b c)e  |- -------------------
+--R                                    |        3      2 2  4
+--R                                   \|  (64a c  - 16b c )e
+--R             *
+--R                 +--------------------------------------------------+
+--R                 |                    +---------------------+
+--R                 |                    |            8
+--R                 |        2     2   2 |           f                4
+--R                 |(- 16a c  + 4b c)e  |- -------------------  + b f
+--R                 |                    |        3      2 2  4
+--R                 |                   \|  (64a c  - 16b c )e
+--R                 |--------------------------------------------------
+--R                 |                      2     2   2
+--R                \|                 (8a c  - 2b c)e
+--R            + 
+--R                 6       6
+--R              e f x + d f
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            e\|2 \|- 4a c + b  \|c
+--R         *
+--R             +------------------------------------------------+
+--R             |                  +---------------------+
+--R             |                  |            8
+--R             |      2     2   2 |           f                4
+--R             |(16a c  - 4b c)e  |- -------------------  + b f
+--R             |                  |        3      2 2  4
+--R             |                 \|  (64a c  - 16b c )e
+--R             |------------------------------------------------
+--R             |                     2     2   2
+--R            \|                (8a c  - 2b c)e
+--R         *
+--R            log
+--R                                       +---------------------+
+--R                                       |            8
+--R                           2     2   3 |           f
+--R                   (- 16a c  + 4b c)e  |- -------------------
+--R                                       |        3      2 2  4
+--R                                      \|  (64a c  - 16b c )e
+--R                *
+--R                    +------------------------------------------------+
+--R                    |                  +---------------------+
+--R                    |                  |            8
+--R                    |      2     2   2 |           f                4
+--R                    |(16a c  - 4b c)e  |- -------------------  + b f
+--R                    |                  |        3      2 2  4
+--R                    |                 \|  (64a c  - 16b c )e
+--R                    |------------------------------------------------
+--R                    |                     2     2   2
+--R                   \|                (8a c  - 2b c)e
+--R               + 
+--R                    6       6
+--R                 e f x + d f
+--R     + 
+--R           +--------------------+
+--R           |   +-----------+                       +-+ +-+
+--R         2 |   |          2              (e x + d)\|2 \|c
+--R       2f \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                       +--------------------+
+--R                                       |   +-----------+
+--R                                       |   |          2
+--R                                      \|- \|- 4a c + b   + b
+--R     + 
+--R             +------------------+
+--R             | +-----------+                      +-+ +-+
+--R           2 | |          2             (e x + d)\|2 \|c
+--R       - 2f \|\|- 4a c + b   + b atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                       | |          2
+--R                                      \|\|- 4a c + b   + b
+--R  /
+--R            +-----------+
+--R        +-+ |          2  +-+
+--R     2e\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 919
+
+--S 920 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 920
+
+)clear all
+
+--S 921 of 1057
+t0:=(d*f+e*f*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                                   e f x + d f
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 921
+
+--S 922 of 1057
+r0:=-f*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                      2 2                  2
+--R                  2c e x  + 4c d e x + 2c d  + b
+--R          f atanh(------------------------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R   (2)  - ---------------------------------------
+--R                        +-----------+
+--R                        |          2
+--R                      e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R         f
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                     2     2   2 2         2     2               2     2   2
+--R                (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R    /
+--R          +-----------+
+--R          |          2
+--R       2e\|- 4a c + b
+--R     ,
+--R                                            +---------+
+--R                2 2                  2      |        2
+--R           (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R    f atan(--------------------------------------------)
+--R                                     2
+--R                             4a c - b
+--R    ----------------------------------------------------]
+--R                          +---------+
+--R                          |        2
+--R                        e\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 923
+
+--S 924 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         f
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                     2     2   2 2         2     2               2     2   2
+--R                (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                    2 2                  2
+--R                2c e x  + 4c d e x + 2c d  + b
+--R       2f atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     2e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 924
+
+--S 925 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 925
+
+--S 926 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R         +---------+          2 2                  2
+--R         |        2       2c e x  + 4c d e x + 2c d  + b
+--R       f\|4a c - b  atanh(------------------------------)
+--R                                   +-----------+
+--R                                   |          2
+--R                                  \|- 4a c + b
+--R     + 
+--R                                                            +---------+
+--R         +-----------+          2 2                  2      |        2
+--R         |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       f\|- 4a c + b  atan(--------------------------------------------)
+--R                                                     2
+--R                                             4a c - b
+--R  /
+--R       +-----------+ +---------+
+--R       |          2  |        2
+--R     e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 926
+
+--S 927 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 927
+
+)clear all
+
+--S 928 of 1057
+t0:=1/((d*f+e*f*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          5   5         4   4         2      3   3         3         2   2
+--R       c e f x  + 5c d e f x  + (10c d  + b)e f x  + (10c d  + 3b d)e f x
+--R     + 
+--R            4       2                 5      3
+--R       (5c d  + 3b d  + a)e f x + (c d  + b d  + a d)f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 928
+
+--S 929 of 1057
+r0:=log(d+e*x)/(a*e*f)-1/4*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a*e*f)+_
+   1/2*b*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(a*e*f*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    2 2                  2
+--R                2c e x  + 4c d e x + 2c d  + b
+--R       2b atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R     + 
+--R           -
+--R              log
+--R                      4 4         3 3        2      2 2        3
+--R                   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                 + 
+--R                      4      2
+--R                   c d  + b d  + a
+--R         + 
+--R           4log(e x + d)
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            +-----------+
+--R            |          2
+--R     4a e f\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 929
+
+--S 930 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R             -
+--R                log
+--R                        4 4         3 3        2      2 2        3
+--R                     c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                   + 
+--R                        4      2
+--R                     c d  + b d  + a
+--R           + 
+--R             4log(e x + d)
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R              +-----------+
+--R              |          2
+--R       4a e f\|- 4a c + b
+--R     ,
+--R
+--R                                                    +---------+
+--R                        2 2                  2      |        2
+--R                   (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         - 2b atan(--------------------------------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R             -
+--R                log
+--R                        4 4         3 3        2      2 2        3
+--R                     c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                   + 
+--R                        4      2
+--R                     c d  + b d  + a
+--R           + 
+--R             4log(e x + d)
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R              +---------+
+--R              |        2
+--R       4a e f\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 930
+
+--S 931 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                      2 2                  2
+--R                  2c e x  + 4c d e x + 2c d  + b
+--R       - 2b atanh(------------------------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R            +-----------+
+--R            |          2
+--R     4a e f\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 931
+
+--S 932 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 932
+
+--S 933 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+          2 2                  2
+--R           |        2       2c e x  + 4c d e x + 2c d  + b
+--R       - b\|4a c - b  atanh(------------------------------)
+--R                                     +-----------+
+--R                                     |          2
+--R                                    \|- 4a c + b
+--R     + 
+--R                                                              +---------+
+--R           +-----------+          2 2                  2      |        2
+--R           |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(--------------------------------------------)
+--R                                                       2
+--R                                               4a c - b
+--R  /
+--R            +-----------+ +---------+
+--R            |          2  |        2
+--R     2a e f\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 933
+
+--S 934 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 934
+
+)clear all
+
+--S 935 of 1057
+t0:=1/((d*f+e*f*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          6 2 6         5 2 5         2      4 2 4         3         3 2 3
+--R       c e f x  + 6c d e f x  + (15c d  + b)e f x  + (20c d  + 4b d)e f x
+--R     + 
+--R             4       2      2 2 2        5       3           2
+--R       (15c d  + 6b d  + a)e f x  + (6c d  + 4b d  + 2a d)e f x
+--R     + 
+--R           6      4      2  2
+--R       (c d  + b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 935
+
+--S 936 of 1057
+r0:=(-1)/(a*e*f^2*(d+e*x))-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(1+b/sqrt(b^2-4*a*c))/(a*e*f^2*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(1-b/sqrt(b^2-4*a*c))/(a*e*f^2*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                       +------------------+
+--R                      +-----------+                    | +-----------+
+--R                      |          2                 +-+ | |          2
+--R         ((- e x - d)\|- 4a c + b   - b e x - b d)\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                       +--------------------+
+--R                      +-----------+                    |   +-----------+
+--R                      |          2                 +-+ |   |          2
+--R         ((- e x - d)\|- 4a c + b   + b e x + b d)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R       - \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                              +--------------------+
+--R                                +-----------+ |   +-----------+
+--R           2 2           2  +-+ |          2  |   |          2
+--R       (a e f x + a d e f )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 936
+
+--S 937 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 2           2
+--R         (- a e f x - a d e f )
+--R      *
+--R          +--------------------------------------------------------+
+--R          |                    +--------------------+
+--R          |                    |   2 2       2     4
+--R          |    4      3 2  2 4 |- a c  + 2a b c - b               3
+--R          |(16a c - 4a b )e f  |--------------------  - 3a b c + b
+--R          |                    |    7       6 2  4 8
+--R          |                   \|(64a c - 16a b )e f
+--R          |--------------------------------------------------------
+--R          |                      4      3 2  2 4
+--R         \|                   (8a c - 2a b )e f
+--R      *
+--R         log
+--R                                                 +--------------------+
+--R                                                 |   2 2       2     4
+--R                      5 2      4 2      3 4  3 6 |- a c  + 2a b c - b
+--R                  (32a c  - 24a b c + 4a b )e f  |--------------------
+--R                                                 |    7       6 2  4 8
+--R                                                \|(64a c - 16a b )e f
+--R                + 
+--R                     2   2       3     5    2
+--R                  (4a b c  - 5a b c + b )e f
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |                    +--------------------+
+--R                 |                    |   2 2       2     4
+--R                 |    4      3 2  2 4 |- a c  + 2a b c - b               3
+--R                 |(16a c - 4a b )e f  |--------------------  - 3a b c + b
+--R                 |                    |    7       6 2  4 8
+--R                 |                   \|(64a c - 16a b )e f
+--R                 |--------------------------------------------------------
+--R                 |                      4      3 2  2 4
+--R                \|                   (8a c - 2a b )e f
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R             2 2           2
+--R         (a e f x + a d e f )
+--R      *
+--R          +----------------------------------------------------------+
+--R          |                      +--------------------+
+--R          |                      |   2 2       2     4
+--R          |      4      3 2  2 4 |- a c  + 2a b c - b               3
+--R          |(- 16a c + 4a b )e f  |--------------------  - 3a b c + b
+--R          |                      |    7       6 2  4 8
+--R          |                     \|(64a c - 16a b )e f
+--R          |----------------------------------------------------------
+--R          |                       4      3 2  2 4
+--R         \|                    (8a c - 2a b )e f
+--R      *
+--R         log
+--R                                                 +--------------------+
+--R                                                 |   2 2       2     4
+--R                      5 2      4 2      3 4  3 6 |- a c  + 2a b c - b
+--R                  (32a c  - 24a b c + 4a b )e f  |--------------------
+--R                                                 |    7       6 2  4 8
+--R                                                \|(64a c - 16a b )e f
+--R                + 
+--R                       2   2       3     5    2
+--R                  (- 4a b c  + 5a b c - b )e f
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |                      +--------------------+
+--R                 |                      |   2 2       2     4
+--R                 |      4      3 2  2 4 |- a c  + 2a b c - b               3
+--R                 |(- 16a c + 4a b )e f  |--------------------  - 3a b c + b
+--R                 |                      |    7       6 2  4 8
+--R                 |                     \|(64a c - 16a b )e f
+--R                 |----------------------------------------------------------
+--R                 |                       4      3 2  2 4
+--R                \|                    (8a c - 2a b )e f
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R               2 2           2
+--R         (- a e f x - a d e f )
+--R      *
+--R          +----------------------------------------------------------+
+--R          |                      +--------------------+
+--R          |                      |   2 2       2     4
+--R          |      4      3 2  2 4 |- a c  + 2a b c - b               3
+--R          |(- 16a c + 4a b )e f  |--------------------  - 3a b c + b
+--R          |                      |    7       6 2  4 8
+--R          |                     \|(64a c - 16a b )e f
+--R          |----------------------------------------------------------
+--R          |                       4      3 2  2 4
+--R         \|                    (8a c - 2a b )e f
+--R      *
+--R         log
+--R                                                   +--------------------+
+--R                                                   |   2 2       2     4
+--R                        5 2      4 2      3 4  3 6 |- a c  + 2a b c - b
+--R                  (- 32a c  + 24a b c - 4a b )e f  |--------------------
+--R                                                   |    7       6 2  4 8
+--R                                                  \|(64a c - 16a b )e f
+--R                + 
+--R                     2   2       3     5    2
+--R                  (4a b c  - 5a b c + b )e f
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |                      +--------------------+
+--R                 |                      |   2 2       2     4
+--R                 |      4      3 2  2 4 |- a c  + 2a b c - b               3
+--R                 |(- 16a c + 4a b )e f  |--------------------  - 3a b c + b
+--R                 |                      |    7       6 2  4 8
+--R                 |                     \|(64a c - 16a b )e f
+--R                 |----------------------------------------------------------
+--R                 |                       4      3 2  2 4
+--R                \|                    (8a c - 2a b )e f
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R             2 2           2
+--R         (a e f x + a d e f )
+--R      *
+--R          +--------------------------------------------------------+
+--R          |                    +--------------------+
+--R          |                    |   2 2       2     4
+--R          |    4      3 2  2 4 |- a c  + 2a b c - b               3
+--R          |(16a c - 4a b )e f  |--------------------  - 3a b c + b
+--R          |                    |    7       6 2  4 8
+--R          |                   \|(64a c - 16a b )e f
+--R          |--------------------------------------------------------
+--R          |                      4      3 2  2 4
+--R         \|                   (8a c - 2a b )e f
+--R      *
+--R         log
+--R                                                   +--------------------+
+--R                                                   |   2 2       2     4
+--R                        5 2      4 2      3 4  3 6 |- a c  + 2a b c - b
+--R                  (- 32a c  + 24a b c - 4a b )e f  |--------------------
+--R                                                   |    7       6 2  4 8
+--R                                                  \|(64a c - 16a b )e f
+--R                + 
+--R                       2   2       3     5    2
+--R                  (- 4a b c  + 5a b c - b )e f
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |                    +--------------------+
+--R                 |                    |   2 2       2     4
+--R                 |    4      3 2  2 4 |- a c  + 2a b c - b               3
+--R                 |(16a c - 4a b )e f  |--------------------  - 3a b c + b
+--R                 |                    |    7       6 2  4 8
+--R                 |                   \|(64a c - 16a b )e f
+--R                 |--------------------------------------------------------
+--R                 |                      4      3 2  2 4
+--R                \|                   (8a c - 2a b )e f
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R       - 2
+--R  /
+--R         2 2            2
+--R     2a e f x + 2a d e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 937
+
+--S 938 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                     +--------------------+ +------------------+
+--R                       +-----------+ |   +-----------+      | +-----------+
+--R                 2 +-+ |          2  |   |          2       | |          2
+--R            a e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +--------------------------------------------------------+
+--R             |                    +--------------------+
+--R             |                    |   2 2       2     4
+--R             |    4      3 2  2 4 |- a c  + 2a b c - b               3
+--R             |(16a c - 4a b )e f  |--------------------  - 3a b c + b
+--R             |                    |    7       6 2  4 8
+--R             |                   \|(64a c - 16a b )e f
+--R             |--------------------------------------------------------
+--R             |                      4      3 2  2 4
+--R            \|                   (8a c - 2a b )e f
+--R         *
+--R            log
+--R                                                    +--------------------+
+--R                                                    |   2 2       2     4
+--R                         5 2      4 2      3 4  3 6 |- a c  + 2a b c - b
+--R                     (32a c  - 24a b c + 4a b )e f  |--------------------
+--R                                                    |    7       6 2  4 8
+--R                                                   \|(64a c - 16a b )e f
+--R                   + 
+--R                        2   2       3     5    2
+--R                     (4a b c  - 5a b c + b )e f
+--R                *
+--R                    +--------------------------------------------------------+
+--R                    |                    +--------------------+
+--R                    |                    |   2 2       2     4
+--R                    |    4      3 2  2 4 |- a c  + 2a b c - b               3
+--R                    |(16a c - 4a b )e f  |--------------------  - 3a b c + b
+--R                    |                    |    7       6 2  4 8
+--R                    |                   \|(64a c - 16a b )e f
+--R                    |--------------------------------------------------------
+--R                    |                      4      3 2  2 4
+--R                   \|                   (8a c - 2a b )e f
+--R               + 
+--R                      3     2 2            3     2 2
+--R                 (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R                    +-----------+
+--R              2 +-+ |          2
+--R         a e f \|2 \|- 4a c + b
+--R      *
+--R          +----------------------------------------------------------+
+--R          |                      +--------------------+
+--R          |                      |   2 2       2     4
+--R          |      4      3 2  2 4 |- a c  + 2a b c - b               3
+--R          |(- 16a c + 4a b )e f  |--------------------  - 3a b c + b
+--R          |                      |    7       6 2  4 8
+--R          |                     \|(64a c - 16a b )e f
+--R          |----------------------------------------------------------
+--R          |                       4      3 2  2 4
+--R         \|                    (8a c - 2a b )e f
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                                 +--------------------+
+--R                                                 |   2 2       2     4
+--R                      5 2      4 2      3 4  3 6 |- a c  + 2a b c - b
+--R                  (32a c  - 24a b c + 4a b )e f  |--------------------
+--R                                                 |    7       6 2  4 8
+--R                                                \|(64a c - 16a b )e f
+--R                + 
+--R                       2   2       3     5    2
+--R                  (- 4a b c  + 5a b c - b )e f
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |                      +--------------------+
+--R                 |                      |   2 2       2     4
+--R                 |      4      3 2  2 4 |- a c  + 2a b c - b               3
+--R                 |(- 16a c + 4a b )e f  |--------------------  - 3a b c + b
+--R                 |                      |    7       6 2  4 8
+--R                 |                     \|(64a c - 16a b )e f
+--R                 |----------------------------------------------------------
+--R                 |                       4      3 2  2 4
+--R                \|                    (8a c - 2a b )e f
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R       -
+--R                       +-----------+
+--R                 2 +-+ |          2
+--R            a e f \|2 \|- 4a c + b
+--R         *
+--R             +----------------------------------------------------------+
+--R             |                      +--------------------+
+--R             |                      |   2 2       2     4
+--R             |      4      3 2  2 4 |- a c  + 2a b c - b               3
+--R             |(- 16a c + 4a b )e f  |--------------------  - 3a b c + b
+--R             |                      |    7       6 2  4 8
+--R             |                     \|(64a c - 16a b )e f
+--R             |----------------------------------------------------------
+--R             |                       4      3 2  2 4
+--R            \|                    (8a c - 2a b )e f
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                                      +--------------------+
+--R                                                      |   2 2       2     4
+--R                           5 2      4 2      3 4  3 6 |- a c  + 2a b c - b
+--R                     (- 32a c  + 24a b c - 4a b )e f  |--------------------
+--R                                                      |    7       6 2  4 8
+--R                                                     \|(64a c - 16a b )e f
+--R                   + 
+--R                        2   2       3     5    2
+--R                     (4a b c  - 5a b c + b )e f
+--R                *
+--R                  +----------------------------------------------------------+
+--R                  |                      +--------------------+
+--R                  |                      |   2 2       2     4
+--R                  |      4      3 2  2 4 |- a c  + 2a b c - b               3
+--R                  |(- 16a c + 4a b )e f  |--------------------  - 3a b c + b
+--R                  |                      |    7       6 2  4 8
+--R                  |                     \|(64a c - 16a b )e f
+--R                  |----------------------------------------------------------
+--R                  |                       4      3 2  2 4
+--R                 \|                    (8a c - 2a b )e f
+--R               + 
+--R                      3     2 2            3     2 2
+--R                 (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              2 +-+ |          2  |   |          2       | |          2
+--R         a e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +--------------------------------------------------------+
+--R          |                    +--------------------+
+--R          |                    |   2 2       2     4
+--R          |    4      3 2  2 4 |- a c  + 2a b c - b               3
+--R          |(16a c - 4a b )e f  |--------------------  - 3a b c + b
+--R          |                    |    7       6 2  4 8
+--R          |                   \|(64a c - 16a b )e f
+--R          |--------------------------------------------------------
+--R          |                      4      3 2  2 4
+--R         \|                   (8a c - 2a b )e f
+--R      *
+--R         log
+--R                                                   +--------------------+
+--R                                                   |   2 2       2     4
+--R                        5 2      4 2      3 4  3 6 |- a c  + 2a b c - b
+--R                  (- 32a c  + 24a b c - 4a b )e f  |--------------------
+--R                                                   |    7       6 2  4 8
+--R                                                  \|(64a c - 16a b )e f
+--R                + 
+--R                       2   2       3     5    2
+--R                  (- 4a b c  + 5a b c - b )e f
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |                    +--------------------+
+--R                 |                    |   2 2       2     4
+--R                 |    4      3 2  2 4 |- a c  + 2a b c - b               3
+--R                 |(16a c - 4a b )e f  |--------------------  - 3a b c + b
+--R                 |                    |    7       6 2  4 8
+--R                 |                   \|(64a c - 16a b )e f
+--R                 |--------------------------------------------------------
+--R                 |                      4      3 2  2 4
+--R                \|                   (8a c - 2a b )e f
+--R            + 
+--R                   3     2 2            3     2 2
+--R              (2a c  - 2b c )e x + (2a c  - 2b c )d
+--R     + 
+--R                                    +------------------+
+--R            +-----------+           | +-----------+
+--R            |          2        +-+ | |          2
+--R         (2\|- 4a c + b   + 2b)\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                    +--------------------+
+--R            +-----------+           |   +-----------+
+--R            |          2        +-+ |   |          2
+--R         (2\|- 4a c + b   - 2b)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           2 +-+ |          2  |   |          2       | |          2
+--R     2a e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 938
+
+--S 939 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 939
+
+)clear all
+
+--S 940 of 1057
+t0:=1/((d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          7 3 7         6 3 6         2      5 3 5         3         4 3 4
+--R       c e f x  + 7c d e f x  + (21c d  + b)e f x  + (35c d  + 5b d)e f x
+--R     + 
+--R             4        2      3 3 3         5        3         2 3 2
+--R       (35c d  + 10b d  + a)e f x  + (21c d  + 10b d  + 3a d)e f x
+--R     + 
+--R            6       4       2    3        7      5      3  3
+--R       (7c d  + 5b d  + 3a d )e f x + (c d  + b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 940
+
+--S 941 of 1057
+r0:=(-1/2)/(a*e*f^3*(d+e*x)^2)-b*log(d+e*x)/(a^2*e*f^3)+_
+   1/4*b*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a^2*e*f^3)-1/2*(b^2-2*a*c)*_
+   atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(a^2*e*f^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    2  2 2             2                   2  2
+--R         ((4a c - 2b )e x  + (8a c - 4b )d e x + (4a c - 2b )d )
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                 2 2                 2
+--R             (b e x  + 2b d e x + b d )
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                  2 2                  2
+--R           (- 4b e x  - 8b d e x - 4b d )log(e x + d) - 2a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                          +-----------+
+--R        2 3 3 2     2   2 3      2 2   3  |          2
+--R     (4a e f x  + 8a d e f x + 4a d e f )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 941
+
+--S 942 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     2  2 2             2                  2  2
+--R           ((2a c - b )e x  + (4a c - 2b )d e x + (2a c - b )d )
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                   2 2                 2
+--R               (b e x  + 2b d e x + b d )
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                    2 2                  2
+--R             (- 4b e x  - 8b d e x - 4b d )log(e x + d) - 2a
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                            +-----------+
+--R          2 3 3 2     2   2 3      2 2   3  |          2
+--R       (4a e f x  + 8a d e f x + 4a d e f )\|- 4a c + b
+--R     ,
+--R
+--R                        2  2 2               2                     2  2
+--R           ((- 4a c + 2b )e x  + (- 8a c + 4b )d e x + (- 4a c + 2b )d )
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                   2 2                 2
+--R               (b e x  + 2b d e x + b d )
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                    2 2                  2
+--R             (- 4b e x  - 8b d e x - 4b d )log(e x + d) - 2a
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                            +---------+
+--R          2 3 3 2     2   2 3      2 2   3  |        2
+--R       (4a e f x  + 8a d e f x + 4a d e f )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 942
+
+--S 943 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                               2 2                  2
+--R                   2       2c e x  + 4c d e x + 2c d  + b
+--R       (- 4a c + 2b )atanh(------------------------------)
+--R                                    +-----------+
+--R                                    |          2
+--R                                   \|- 4a c + b
+--R  /
+--R             +-----------+
+--R       2   3 |          2
+--R     4a e f \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 943
+
+--S 944 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 944
+
+--S 945 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+          2 2                  2
+--R                  2  |        2       2c e x  + 4c d e x + 2c d  + b
+--R       (- 2a c + b )\|4a c - b  atanh(------------------------------)
+--R                                               +-----------+
+--R                                               |          2
+--R                                              \|- 4a c + b
+--R     + 
+--R                       +-----------+
+--R                    2  |          2
+--R         (- 2a c + b )\|- 4a c + b
+--R      *
+--R                                               +---------+
+--R                   2 2                  2      |        2
+--R              (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R  /
+--R             +-----------+ +---------+
+--R       2   3 |          2  |        2
+--R     2a e f \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 945
+
+--S 946 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 946
+
+)clear all
+
+--S 947 of 1057
+t0:=1/((d*f+e*f*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          8 4 8         7 4 7         2      6 4 6         3         5 4 5
+--R       c e f x  + 8c d e f x  + (28c d  + b)e f x  + (56c d  + 6b d)e f x
+--R     + 
+--R             4        2      4 4 4         5        3         3 4 3
+--R       (70c d  + 15b d  + a)e f x  + (56c d  + 20b d  + 4a d)e f x
+--R     + 
+--R             6        4       2  2 4 2        7       5       3    4
+--R       (28c d  + 15b d  + 6a d )e f x  + (8c d  + 6b d  + 4a d )e f x
+--R     + 
+--R           8      6      4  4
+--R       (c d  + b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 947
+
+--S 948 of 1057
+r0:=(-1/3)/(a*e*f^4*(d+e*x)^3)+b/(a^2*e*f^4*(d+e*x))+atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/_
+   (a^2*e*f^4*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/_
+   (a^2*e*f^4*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                    +-----------+
+--R                3 3         2 2       2          3  |          2
+--R           (3b e x  + 9b d e x  + 9b d e x + 3b d )\|- 4a c + b
+--R         + 
+--R                       2  3 3                2    2 2                2  2
+--R           (- 6a c + 3b )e x  + (- 18a c + 9b )d e x  + (- 18a c + 9b )d e x
+--R         + 
+--R                       2  3
+--R           (- 6a c + 3b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                                    +-----------+
+--R                3 3         2 2       2          3  |          2
+--R           (3b e x  + 9b d e x  + 9b d e x + 3b d )\|- 4a c + b
+--R         + 
+--R                     2  3 3              2    2 2              2  2
+--R           (6a c - 3b )e x  + (18a c - 9b )d e x  + (18a c - 9b )d e x
+--R         + 
+--R                     2  3
+--R           (6a c - 3b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                              +-----------+
+--R              2 2                  2      +-+ |          2
+--R         (3b e x  + 6b d e x + 3b d  - a)\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                              +-----------+
+--R          2 4 4 3     2   3 4 2     2 2 2 4      2 3   4  +-+ |          2
+--R       (3a e f x  + 9a d e f x  + 9a d e f x + 3a d e f )\|2 \|- 4a c + b
+--R    *
+--R        +--------------------+ +------------------+
+--R        |   +-----------+      | +-----------+
+--R        |   |          2       | |          2
+--R       \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 948
+
+--S 949 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 4 4 3     2   3 4 2     2 2 2 4      2 3   4
+--R         (- 3a e f x  - 9a d e f x  - 9a d e f x - 3a d e f )
+--R      *
+--R         ROOT
+--R                                    +-----------------------------------------+
+--R                                    |   4 4     3 2 3      2 4 2       6     8
+--R                    6      5 2  2 8 |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (16a c - 4a b )e f  |-----------------------------------------
+--R                                    |             11       10 2  4 16
+--R                                   \|         (64a  c - 16a  b )e f
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2 8
+--R              (8a c - 2a b )e f
+--R      *
+--R         log
+--R                        7   2      6 3      5 5  3 12
+--R                    (48a b c  - 28a b c + 4a b )e f
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |             11       10 2  4 16
+--R                    \|         (64a  c - 16a  b )e f
+--R                + 
+--R                     4 4      3 2 3      2 4 2       6     8    4
+--R                  (4a c  - 17a b c  + 20a b c  - 8a b c + b )e f
+--R             *
+--R                ROOT
+--R                             6      5 2  2 8
+--R                         (16a c - 4a b )e f
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |             11       10 2  4 16
+--R                         \|         (64a  c - 16a  b )e f
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2 8
+--R                     (8a c - 2a b )e f
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R            2 4 4 3     2   3 4 2     2 2 2 4      2 3   4
+--R         (3a e f x  + 9a d e f x  + 9a d e f x + 3a d e f )
+--R      *
+--R         ROOT
+--R                        6      5 2  2 8
+--R                  (- 16a c + 4a b )e f
+--R               *
+--R                   +-----------------------------------------+
+--R                   |   4 4     3 2 3      2 4 2       6     8
+--R                   |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |-----------------------------------------
+--R                   |             11       10 2  4 16
+--R                  \|         (64a  c - 16a  b )e f
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2 8
+--R              (8a c - 2a b )e f
+--R      *
+--R         log
+--R                        7   2      6 3      5 5  3 12
+--R                    (48a b c  - 28a b c + 4a b )e f
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |             11       10 2  4 16
+--R                    \|         (64a  c - 16a  b )e f
+--R                + 
+--R                       4 4      3 2 3      2 4 2       6     8    4
+--R                  (- 4a c  + 17a b c  - 20a b c  + 8a b c - b )e f
+--R             *
+--R                ROOT
+--R                               6      5 2  2 8
+--R                         (- 16a c + 4a b )e f
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |             11       10 2  4 16
+--R                         \|         (64a  c - 16a  b )e f
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2 8
+--R                     (8a c - 2a b )e f
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R              2 4 4 3     2   3 4 2     2 2 2 4      2 3   4
+--R         (- 3a e f x  - 9a d e f x  - 9a d e f x - 3a d e f )
+--R      *
+--R         ROOT
+--R                        6      5 2  2 8
+--R                  (- 16a c + 4a b )e f
+--R               *
+--R                   +-----------------------------------------+
+--R                   |   4 4     3 2 3      2 4 2       6     8
+--R                   |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |-----------------------------------------
+--R                   |             11       10 2  4 16
+--R                  \|         (64a  c - 16a  b )e f
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2 8
+--R              (8a c - 2a b )e f
+--R      *
+--R         log
+--R                          7   2      6 3      5 5  3 12
+--R                    (- 48a b c  + 28a b c - 4a b )e f
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |             11       10 2  4 16
+--R                    \|         (64a  c - 16a  b )e f
+--R                + 
+--R                     4 4      3 2 3      2 4 2       6     8    4
+--R                  (4a c  - 17a b c  + 20a b c  - 8a b c + b )e f
+--R             *
+--R                ROOT
+--R                               6      5 2  2 8
+--R                         (- 16a c + 4a b )e f
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |             11       10 2  4 16
+--R                         \|         (64a  c - 16a  b )e f
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2 8
+--R                     (8a c - 2a b )e f
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R            2 4 4 3     2   3 4 2     2 2 2 4      2 3   4
+--R         (3a e f x  + 9a d e f x  + 9a d e f x + 3a d e f )
+--R      *
+--R         ROOT
+--R                                    +-----------------------------------------+
+--R                                    |   4 4     3 2 3      2 4 2       6     8
+--R                    6      5 2  2 8 |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (16a c - 4a b )e f  |-----------------------------------------
+--R                                    |             11       10 2  4 16
+--R                                   \|         (64a  c - 16a  b )e f
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2 8
+--R              (8a c - 2a b )e f
+--R      *
+--R         log
+--R                          7   2      6 3      5 5  3 12
+--R                    (- 48a b c  + 28a b c - 4a b )e f
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |             11       10 2  4 16
+--R                    \|         (64a  c - 16a  b )e f
+--R                + 
+--R                       4 4      3 2 3      2 4 2       6     8    4
+--R                  (- 4a c  + 17a b c  - 20a b c  + 8a b c - b )e f
+--R             *
+--R                ROOT
+--R                             6      5 2  2 8
+--R                         (16a c - 4a b )e f
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |             11       10 2  4 16
+--R                         \|         (64a  c - 16a  b )e f
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2 8
+--R                     (8a c - 2a b )e f
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R           2 2                   2
+--R       6b e x  + 12b d e x + 6b d  - 2a
+--R  /
+--R       2 4 4 3      2   3 4 2      2 2 2 4      2 3   4
+--R     6a e f x  + 18a d e f x  + 18a d e f x + 6a d e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 949
+
+--S 950 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                     +--------------------+ +------------------+
+--R                       +-----------+ |   +-----------+      | +-----------+
+--R             2   4 +-+ |          2  |   |          2       | |          2
+--R            a e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                         6      5 2  2 8
+--R                     (16a c - 4a b )e f
+--R                  *
+--R                      +-----------------------------------------+
+--R                      |   4 4     3 2 3      2 4 2       6     8
+--R                      |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                      |-----------------------------------------
+--R                      |             11       10 2  4 16
+--R                     \|         (64a  c - 16a  b )e f
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                    6      5 2  2 8
+--R                 (8a c - 2a b )e f
+--R         *
+--R            log
+--R                           7   2      6 3      5 5  3 12
+--R                       (48a b c  - 28a b c + 4a b )e f
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |             11       10 2  4 16
+--R                       \|         (64a  c - 16a  b )e f
+--R                   + 
+--R                        4 4      3 2 3      2 4 2       6     8    4
+--R                     (4a c  - 17a b c  + 20a b c  - 8a b c + b )e f
+--R                *
+--R                   ROOT
+--R                                6      5 2  2 8
+--R                            (16a c - 4a b )e f
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |             11       10 2  4 16
+--R                            \|         (64a  c - 16a  b )e f
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                           6      5 2  2 8
+--R                        (8a c - 2a b )e f
+--R               + 
+--R                    2 5       2 4     4 3          2 5       2 4     4 3
+--R                 (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R                    +-----------+
+--R          2   4 +-+ |          2
+--R         a e f \|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                        6      5 2  2 8
+--R                  (- 16a c + 4a b )e f
+--R               *
+--R                   +-----------------------------------------+
+--R                   |   4 4     3 2 3      2 4 2       6     8
+--R                   |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |-----------------------------------------
+--R                   |             11       10 2  4 16
+--R                  \|         (64a  c - 16a  b )e f
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2 8
+--R              (8a c - 2a b )e f
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                        7   2      6 3      5 5  3 12
+--R                    (48a b c  - 28a b c + 4a b )e f
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |             11       10 2  4 16
+--R                    \|         (64a  c - 16a  b )e f
+--R                + 
+--R                       4 4      3 2 3      2 4 2       6     8    4
+--R                  (- 4a c  + 17a b c  - 20a b c  + 8a b c - b )e f
+--R             *
+--R                ROOT
+--R                               6      5 2  2 8
+--R                         (- 16a c + 4a b )e f
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |             11       10 2  4 16
+--R                         \|         (64a  c - 16a  b )e f
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2 8
+--R                     (8a c - 2a b )e f
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R       -
+--R                       +-----------+
+--R             2   4 +-+ |          2
+--R            a e f \|2 \|- 4a c + b
+--R         *
+--R            ROOT
+--R                           6      5 2  2 8
+--R                     (- 16a c + 4a b )e f
+--R                  *
+--R                      +-----------------------------------------+
+--R                      |   4 4     3 2 3      2 4 2       6     8
+--R                      |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                      |-----------------------------------------
+--R                      |             11       10 2  4 16
+--R                     \|         (64a  c - 16a  b )e f
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                    6      5 2  2 8
+--R                 (8a c - 2a b )e f
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                             7   2      6 3      5 5  3 12
+--R                       (- 48a b c  + 28a b c - 4a b )e f
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |             11       10 2  4 16
+--R                       \|         (64a  c - 16a  b )e f
+--R                   + 
+--R                        4 4      3 2 3      2 4 2       6     8    4
+--R                     (4a c  - 17a b c  + 20a b c  - 8a b c + b )e f
+--R                *
+--R                   ROOT
+--R                                  6      5 2  2 8
+--R                            (- 16a c + 4a b )e f
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |             11       10 2  4 16
+--R                            \|         (64a  c - 16a  b )e f
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                           6      5 2  2 8
+--R                        (8a c - 2a b )e f
+--R               + 
+--R                    2 5       2 4     4 3          2 5       2 4     4 3
+--R                 (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R          2   4 +-+ |          2  |   |          2       | |          2
+--R         a e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                    +-----------------------------------------+
+--R                                    |   4 4     3 2 3      2 4 2       6     8
+--R                    6      5 2  2 8 |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (16a c - 4a b )e f  |-----------------------------------------
+--R                                    |             11       10 2  4 16
+--R                                   \|         (64a  c - 16a  b )e f
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                 6      5 2  2 8
+--R              (8a c - 2a b )e f
+--R      *
+--R         log
+--R                          7   2      6 3      5 5  3 12
+--R                    (- 48a b c  + 28a b c - 4a b )e f
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |             11       10 2  4 16
+--R                    \|         (64a  c - 16a  b )e f
+--R                + 
+--R                       4 4      3 2 3      2 4 2       6     8    4
+--R                  (- 4a c  + 17a b c  - 20a b c  + 8a b c - b )e f
+--R             *
+--R                ROOT
+--R                             6      5 2  2 8
+--R                         (16a c - 4a b )e f
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |             11       10 2  4 16
+--R                         \|         (64a  c - 16a  b )e f
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                        6      5 2  2 8
+--R                     (8a c - 2a b )e f
+--R            + 
+--R                 2 5       2 4     4 3          2 5       2 4     4 3
+--R              (2a c  - 6a b c  + 2b c )e x + (2a c  - 6a b c  + 2b c )d
+--R     + 
+--R                                               +------------------+
+--R               +-----------+                   | +-----------+
+--R               |          2             2  +-+ | |          2
+--R         (- 2b\|- 4a c + b   + 4a c - 2b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                               +--------------------+
+--R               +-----------+                   |   +-----------+
+--R               |          2             2  +-+ |   |          2
+--R         (- 2b\|- 4a c + b   - 4a c + 2b )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R       2   4 +-+ |          2  |   |          2       | |          2
+--R     2a e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 950
+
+--S 951 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 951
+
+)clear all
+
+--S 952 of 1057
+t0:=(d*f+e*f*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      4 4 4       3 4 3     2 2 4 2     3   4     4 4
+--R     e f x  + 4d e f x  + 6d e f x  + 4d e f x + d f
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 952
+
+--S 953 of 1057
+r0:=1/2*f^4*(d+e*x)*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+1/2*f^4*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*(b+(-b^2-4*a*c)/sqrt(b^2-4*a*c))/((b^2-4*a*c)*e*sqrt(2)*_
+   sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*f^4*atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*(b^2+4*a*c+b*sqrt(b^2-4*a*c))/((b^2-_
+   4*a*c)^(3/2)*e*sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      4 4 4           3 4 3            2    2  2 4 2
+--R               - b c e f x  - 4b c d e f x  + (- 6b c d  - b )e f x
+--R             + 
+--R                        3     2     4            4    2 2        4
+--R               (- 4b c d  - 2b d)e f x + (- b c d  - b d  - a b)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2    2   4 4 4         2     2     3 4 3
+--R           (4a c  + b c)e f x  + (16a c  + 4b c)d e f x
+--R         + 
+--R                  2     2   2             3  2 4 2
+--R           ((24a c  + 6b c)d  + 4a b c + b )e f x
+--R         + 
+--R                  2     2   3               3      4
+--R           ((16a c  + 4b c)d  + (8a b c + 2b )d)e f x
+--R         + 
+--R                 2    2   4              3  2     2       2  4
+--R           ((4a c  + b c)d  + (4a b c + b )d  + 4a c + a b )f
+--R      *
+--R          +------------------+
+--R          | +-----------+                       +-+ +-+
+--R          | |          2              (e x + d)\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                      4 4 4           3 4 3            2    2  2 4 2
+--R               - b c e f x  - 4b c d e f x  + (- 6b c d  - b )e f x
+--R             + 
+--R                        3     2     4            4    2 2        4
+--R               (- 4b c d  - 2b d)e f x + (- b c d  - b d  - a b)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2    2   4 4 4           2     2     3 4 3
+--R           (- 4a c  - b c)e f x  + (- 16a c  - 4b c)d e f x
+--R         + 
+--R                    2     2   2             3  2 4 2
+--R           ((- 24a c  - 6b c)d  - 4a b c - b )e f x
+--R         + 
+--R                    2     2   3                 3      4
+--R           ((- 16a c  - 4b c)d  + (- 8a b c - 2b )d)e f x
+--R         + 
+--R                   2    2   4                3  2     2       2  4
+--R           ((- 4a c  - b c)d  + (- 4a b c - b )d  - 4a c - a b )f
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R               3 4 3         2 4 2          2         4          3         4
+--R         (- b e f x  - 3b d e f x  + (- 3b d  - 2a)e f x + (- b d  - 2a d)f )
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 953
+
+--S 954 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2    2   5 4         2     2     4 3
+--R           (4a c  - b c)e x  + (16a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2             3  3 2
+--R           ((24a c  - 6b c)d  + 4a b c - b )e x
+--R         + 
+--R                  2     2   3               3    2
+--R           ((16a c  - 4b c)d  + (8a b c - 2b )d)e x
+--R         + 
+--R                 2    2   4              3  2     2       2
+--R           ((4a c  - b c)d  + (4a b c - b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6   2
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           16
+--R                   |                          f
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                            3  8
+--R                (12a b c + b )f
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7   3
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           16
+--R                     |                          f
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                      2 2        2      4    8
+--R                  (32a c  - 16a b c + 2b )e f
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6   2
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           16
+--R                        |                          f
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                   3  8
+--R                       (12a b c + b )f
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2    12              2    12
+--R              (4a c + 3b )e f  x + (4a c + 3b )d f
+--R     + 
+--R                  2    2   5 4           2     2     4 3
+--R           (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2             3  3 2
+--R           ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R         + 
+--R                    2     2   3                 3    2
+--R           ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R         + 
+--R                   2    2   4                3  2     2       2
+--R           ((- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6   2
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           16
+--R                   |                          f
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                            3  8
+--R                (12a b c + b )f
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7   3
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           16
+--R                     |                          f
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                        2 2        2      4    8
+--R                  (- 32a c  + 16a b c - 2b )e f
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6   2
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           16
+--R                        |                          f
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                   3  8
+--R                       (12a b c + b )f
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2    12              2    12
+--R              (4a c + 3b )e f  x + (4a c + 3b )d f
+--R     + 
+--R                2    2   5 4         2     2     4 3
+--R           (4a c  - b c)e x  + (16a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2             3  3 2
+--R           ((24a c  - 6b c)d  + 4a b c - b )e x
+--R         + 
+--R                  2     2   3               3    2
+--R           ((16a c  - 4b c)d  + (8a b c - 2b )d)e x
+--R         + 
+--R                 2    2   4              3  2     2       2
+--R           ((4a c  - b c)d  + (4a b c - b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6   2
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           16
+--R                   |                          f
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                            3  8
+--R                (12a b c + b )f
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7   3
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           16
+--R                     |                          f
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                      2 2        2      4    8
+--R                  (32a c  - 16a b c + 2b )e f
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6   2
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           16
+--R                        |                          f
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                   3  8
+--R                       (12a b c + b )f
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2    12              2    12
+--R              (4a c + 3b )e f  x + (4a c + 3b )d f
+--R     + 
+--R                  2    2   5 4           2     2     4 3
+--R           (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2             3  3 2
+--R           ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R         + 
+--R                    2     2   3                 3    2
+--R           ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R         + 
+--R                   2    2   4                3  2     2       2
+--R           ((- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6   2
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           16
+--R                   |                          f
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                            3  8
+--R                (12a b c + b )f
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7   3
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           16
+--R                     |                          f
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                        2 2        2      4    8
+--R                  (- 32a c  + 16a b c - 2b )e f
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6   2
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           16
+--R                        |                          f
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                   3  8
+--R                       (12a b c + b )f
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2    12              2    12
+--R              (4a c + 3b )e f  x + (4a c + 3b )d f
+--R     + 
+--R            3 4 3         2 4 2          2         4          3         4
+--R       - b e f x  - 3b d e f x  + (- 3b d  - 2a)e f x + (- b d  - 2a d)f
+--R  /
+--R            2     2   5 4         2     2     4 3
+--R       (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R     + 
+--R              2      2   2              3  3 2
+--R       ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R     + 
+--R              2     2   3                3    2
+--R       ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R     + 
+--R             2     2   4               3  2     2        2
+--R       ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R                                         Type: Union(Expression(Integer),...)
+--E 954
+
+--S 955 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +--------------------+
+--R                          +-----------+     |   +-----------+
+--R                  2   +-+ |          2  +-+ |   |          2
+--R         (4a c - b )e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6   2
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           16
+--R                   |                          f
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                            3  8
+--R                (12a b c + b )f
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7   3
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           16
+--R                     |                          f
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                      2 2        2      4    8
+--R                  (32a c  - 16a b c + 2b )e f
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6   2
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           16
+--R                        |                          f
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                   3  8
+--R                       (12a b c + b )f
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2    12              2    12
+--R              (4a c + 3b )e f  x + (4a c + 3b )d f
+--R     + 
+--R                                              +--------------------+
+--R                            +-----------+     |   +-----------+
+--R                    2   +-+ |          2  +-+ |   |          2
+--R         (- 4a c + b )e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6   2
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           16
+--R                   |                          f
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                            3  8
+--R                (12a b c + b )f
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7   3
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           16
+--R                     |                          f
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                        2 2        2      4    8
+--R                  (- 32a c  + 16a b c - 2b )e f
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6   2
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           16
+--R                        |                          f
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                   3  8
+--R                       (12a b c + b )f
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2    12              2    12
+--R              (4a c + 3b )e f  x + (4a c + 3b )d f
+--R     + 
+--R                                            +--------------------+
+--R                          +-----------+     |   +-----------+
+--R                  2   +-+ |          2  +-+ |   |          2
+--R         (4a c - b )e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6   2
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           16
+--R                   |                          f
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                            3  8
+--R                (12a b c + b )f
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7   3
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           16
+--R                     |                          f
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                      2 2        2      4    8
+--R                  (32a c  - 16a b c + 2b )e f
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6   2
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           16
+--R                        |                          f
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                   3  8
+--R                       (12a b c + b )f
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2    12              2    12
+--R              (4a c + 3b )e f  x + (4a c + 3b )d f
+--R     + 
+--R                                              +--------------------+
+--R                            +-----------+     |   +-----------+
+--R                    2   +-+ |          2  +-+ |   |          2
+--R         (- 4a c + b )e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6   2
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                           16
+--R                   |                          f
+--R                   |- --------------------------------------------------
+--R                   |         3 5         2 2 4          4 3       6 2  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R              + 
+--R                            3  8
+--R                (12a b c + b )f
+--R           /
+--R                   3 4       2 2 3        4 2     6   2
+--R              (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7   3
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |                           16
+--R                     |                          f
+--R                     |- --------------------------------------------------
+--R                     |         3 5         2 2 4          4 3       6 2  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                + 
+--R                        2 2        2      4    8
+--R                  (- 32a c  + 16a b c - 2b )e f
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6   2
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)e
+--R                      *
+--R                        +----------------------------------------------------+
+--R                        |                           16
+--R                        |                          f
+--R                        |- --------------------------------------------------
+--R                        |         3 5         2 2 4          4 3       6 2  4
+--R                       \|  (16384a c  - 12288a b c  + 3072a b c  - 256b c )e
+--R                     + 
+--R                                   3  8
+--R                       (12a b c + b )f
+--R                  /
+--R                          3 4       2 2 3        4 2     6   2
+--R                     (512a c  - 384a b c  + 96a b c  - 8b c)e
+--R            + 
+--R                        2    12              2    12
+--R              (4a c + 3b )e f  x + (4a c + 3b )d f
+--R     + 
+--R                                                +------------------+
+--R               +-----------+                    | +-----------+
+--R             4 |          2               2  4  | |          2
+--R         (b f \|- 4a c + b   + (- 4a c - b )f )\|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                              +--------------------+
+--R               +-----------+                  |   +-----------+
+--R             4 |          2             2  4  |   |          2
+--R         (b f \|- 4a c + b   + (4a c + b )f )\|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                           +--------------------+
+--R                         +-----------+     |   +-----------+
+--R                 2   +-+ |          2  +-+ |   |          2
+--R       (8a c - 2b )e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 955
+
+--S 956 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 956
+
+)clear all
+
+--S 957 of 1057
+t0:=(d*f+e*f*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      3 3 3       2 3 2     2   3     3 3
+--R     e f x  + 3d e f x  + 3d e f x + d f
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 957
+
+--S 958 of 1057
+r0:=1/2*f^3*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   b*f^3*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e)
+--R 
+--R
+--R   (2)
+--R                 4 3 4           3 3 3           2     2  2 3 2
+--R           2b c e f x  + 8b c d e f x  + (12b c d  + 2b )e f x
+--R         + 
+--R                  3     2     3           4     2 2         3
+--R           (8b c d  + 4b d)e f x + (2b c d  + 2b d  + 2a b)f
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                                   +-----------+
+--R             2 3 2           3          2       3  |          2
+--R       (- b e f x  - 2b d e f x + (- b d  - 2a)f )\|- 4a c + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 958
+
+--S 959 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  4 3 4           3 3 3          2    2  2 3 2
+--R             b c e f x  + 4b c d e f x  + (6b c d  + b )e f x
+--R           + 
+--R                    3     2     3          4    2 2        3
+--R             (4b c d  + 2b d)e f x + (b c d  + b d  + a b)f
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                                                     +-----------+
+--R               2 3 2           3          2       3  |          2
+--R         (- b e f x  - 2b d e f x + (- b d  - 2a)f )\|- 4a c + b
+--R    /
+--R                2     2   5 4         2     2     4 3
+--R           (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R         + 
+--R                  2      2   2              3  3 2
+--R           ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R         + 
+--R                  2     2   3                3    2
+--R           ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R         + 
+--R                 2     2   4               3  2     2        2
+--R           ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                     4 3 4           3 3 3             2     2  2 3 2
+--R             - 2b c e f x  - 8b c d e f x  + (- 12b c d  - 2b )e f x
+--R           + 
+--R                      3     2     3             4     2 2         3
+--R             (- 8b c d  - 4b d)e f x + (- 2b c d  - 2b d  - 2a b)f
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                                                     +---------+
+--R               2 3 2           3          2       3  |        2
+--R         (- b e f x  - 2b d e f x + (- b d  - 2a)f )\|4a c - b
+--R    /
+--R                2     2   5 4         2     2     4 3
+--R           (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R         + 
+--R                  2      2   2              3  3 2
+--R           ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R         + 
+--R                  2     2   3                3    2
+--R           ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R         + 
+--R                 2     2   4               3  2     2        2
+--R           ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 959
+
+--S 960 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            3
+--R         b f
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                        2 2                  2
+--R             3      2c e x  + 4c d e x + 2c d  + b
+--R       - 2b f atanh(------------------------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R  /
+--R                   +-----------+
+--R               2   |          2
+--R     (8a c - 2b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 960
+
+--S 961 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 961
+
+--S 962 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              +---------+          2 2                  2
+--R            3 |        2       2c e x  + 4c d e x + 2c d  + b
+--R       - b f \|4a c - b  atanh(------------------------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                                                                 +---------+
+--R              +-----------+          2 2                  2      |        2
+--R            3 |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       - b f \|- 4a c + b  atan(--------------------------------------------)
+--R                                                          2
+--R                                                  4a c - b
+--R  /
+--R                  +-----------+ +---------+
+--R              2   |          2  |        2
+--R     (4a c - b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 963
+
+)clear all
+
+--S 964 of 1057
+t0:=(d*f+e*f*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      2 2 2         2     2 2
+--R     e f x  + 2d e f x + d f
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 964
+
+--S 965 of 1057
+r0:=-1/2*f^2*(d+e*x)*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+f^2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(2*b-sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-f^2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(2*b+sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                   4 2 4         3 2 3         2       2 2 2
+--R               2c e f x  + 8c d e f x  + (12c d  + 2b)e f x
+--R             + 
+--R                    3           2         4       2       2
+--R               (8c d  + 4b d)e f x + (2c d  + 2b d  + 2a)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   4 2 4            3 2 3             2     2  2 2 2
+--R           - 4b c e f x  - 16b c d e f x  + (- 24b c d  - 4b )e f x
+--R         + 
+--R                     3     2     2             4     2 2         2
+--R           (- 16b c d  - 8b d)e f x + (- 4b c d  - 4b d  - 4a b)f
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                   4 2 4         3 2 3         2       2 2 2
+--R               2c e f x  + 8c d e f x  + (12c d  + 2b)e f x
+--R             + 
+--R                    3           2         4       2       2
+--R               (8c d  + 4b d)e f x + (2c d  + 2b d  + 2a)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 4 2 4            3 2 3           2     2  2 2 2
+--R           4b c e f x  + 16b c d e f x  + (24b c d  + 4b )e f x
+--R         + 
+--R                   3     2     2           4     2 2         2
+--R           (16b c d  + 8b d)e f x + (4b c d  + 4b d  + 4a b)f
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R              3 2 3         2 2 2        2        2         3        2  +-+
+--R         (2c e f x  + 6c d e f x  + (6c d  + b)e f x + (2c d  + b d)f )\|2
+--R      *
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2  |   |          2       | |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 965
+
+--S 966 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2    2   5 4         2     2     4 3
+--R           (4a c  - b c)e x  + (16a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2             3  3 2
+--R           ((24a c  - 6b c)d  + 4a b c - b )e x
+--R         + 
+--R                  2     2   3               3    2
+--R           ((16a c  - 4b c)d  + (8a b c - 2b )d)e x
+--R         + 
+--R                 2    2   4              3  2     2       2
+--R           ((4a c  - b c)d  + (4a b c - b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                           8
+--R                   |                          f
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                            3  4
+--R                (12a b c + b )f
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8  3
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                           8
+--R                     |                          f
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                        2   2       3     5    4
+--R                  (- 16a b c  + 8a b c - b )e f
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                           8
+--R                          |                          f
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                   3  4
+--R                       (12a b c + b )f
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2     6         2     2     6
+--R              (4a c  + 3b c)e f x + (4a c  + 3b c)d f
+--R     + 
+--R                  2    2   5 4           2     2     4 3
+--R           (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2             3  3 2
+--R           ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R         + 
+--R                    2     2   3                 3    2
+--R           ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R         + 
+--R                   2    2   4                3  2     2       2
+--R           ((- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                           8
+--R                   |                          f
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                            3  4
+--R                (12a b c + b )f
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8  3
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                           8
+--R                     |                          f
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                      2   2       3     5    4
+--R                  (16a b c  - 8a b c + b )e f
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                           8
+--R                          |                          f
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                   3  4
+--R                       (12a b c + b )f
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2     6         2     2     6
+--R              (4a c  + 3b c)e f x + (4a c  + 3b c)d f
+--R     + 
+--R                2    2   5 4         2     2     4 3
+--R           (4a c  - b c)e x  + (16a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2             3  3 2
+--R           ((24a c  - 6b c)d  + 4a b c - b )e x
+--R         + 
+--R                  2     2   3               3    2
+--R           ((16a c  - 4b c)d  + (8a b c - 2b )d)e x
+--R         + 
+--R                 2    2   4              3  2     2       2
+--R           ((4a c  - b c)d  + (4a b c - b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                           8
+--R                   |                          f
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                            3  4
+--R                (12a b c + b )f
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8  3
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                           8
+--R                     |                          f
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                        2   2       3     5    4
+--R                  (- 16a b c  + 8a b c - b )e f
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                           8
+--R                          |                          f
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                   3  4
+--R                       (12a b c + b )f
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2     6         2     2     6
+--R              (4a c  + 3b c)e f x + (4a c  + 3b c)d f
+--R     + 
+--R                  2    2   5 4           2     2     4 3
+--R           (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2             3  3 2
+--R           ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R         + 
+--R                    2     2   3                 3    2
+--R           ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R         + 
+--R                   2    2   4                3  2     2       2
+--R           ((- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                           8
+--R                   |                          f
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                            3  4
+--R                (12a b c + b )f
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8  3
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                           8
+--R                     |                          f
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                      2   2       3     5    4
+--R                  (16a b c  - 8a b c + b )e f
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                           8
+--R                          |                          f
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                   3  4
+--R                       (12a b c + b )f
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2     6         2     2     6
+--R              (4a c  + 3b c)e f x + (4a c  + 3b c)d f
+--R     + 
+--R           3 2 3         2 2 2        2        2         3        2
+--R       2c e f x  + 6c d e f x  + (6c d  + b)e f x + (2c d  + b d)f
+--R  /
+--R            2     2   5 4         2     2     4 3
+--R       (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R     + 
+--R              2      2   2              3  3 2
+--R       ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R     + 
+--R              2     2   3                3    2
+--R       ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R     + 
+--R             2     2   4               3  2     2        2
+--R       ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R                                         Type: Union(Expression(Integer),...)
+--E 966
+
+--S 967 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R                  2   +-+ |          2  |   |          2
+--R         (4a c - b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                           8
+--R                   |                          f
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                            3  4
+--R                (12a b c + b )f
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8  3
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                           8
+--R                     |                          f
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                        2   2       3     5    4
+--R                  (- 16a b c  + 8a b c - b )e f
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                           8
+--R                          |                          f
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                   3  4
+--R                       (12a b c + b )f
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2     6         2     2     6
+--R              (4a c  + 3b c)e f x + (4a c  + 3b c)d f
+--R     + 
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R                    2   +-+ |          2  |   |          2
+--R         (- 4a c + b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                           8
+--R                   |                          f
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                            3  4
+--R                (12a b c + b )f
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8  3
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                           8
+--R                     |                          f
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                      2   2       3     5    4
+--R                  (16a b c  - 8a b c + b )e f
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                           8
+--R                          |                          f
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                   3  4
+--R                       (12a b c + b )f
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2     6         2     2     6
+--R              (4a c  + 3b c)e f x + (4a c  + 3b c)d f
+--R     + 
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R                  2   +-+ |          2  |   |          2
+--R         (4a c - b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                           8
+--R                   |                          f
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                            3  4
+--R                (12a b c + b )f
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8  3
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                           8
+--R                     |                          f
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                        2   2       3     5    4
+--R                  (- 16a b c  + 8a b c - b )e f
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                           8
+--R                          |                          f
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                   3  4
+--R                       (12a b c + b )f
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2     6         2     2     6
+--R              (4a c  + 3b c)e f x + (4a c  + 3b c)d f
+--R     + 
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R                    2   +-+ |          2  |   |          2
+--R         (- 4a c + b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +---------------------------------------------------+
+--R                   |                           8
+--R                   |                          f
+--R                   |- -------------------------------------------------
+--R                   |         5 3         4 2 2        3 4        2 6  4
+--R                  \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                            3  4
+--R                (12a b c + b )f
+--R           /
+--R                   4 3       3 2 2      2 4        6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8  3
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )e
+--R                 *
+--R                     +---------------------------------------------------+
+--R                     |                           8
+--R                     |                          f
+--R                     |- -------------------------------------------------
+--R                     |         5 3         4 2 2        3 4        2 6  4
+--R                    \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                      2   2       3     5    4
+--R                  (16a b c  - 8a b c + b )e f
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +---------------------------------------------------+
+--R                          |                           8
+--R                          |                          f
+--R                          |- -------------------------------------------------
+--R                          |         5 3         4 2 2        3 4        2 6  4
+--R                         \|  (16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                                   3  4
+--R                       (12a b c + b )f
+--R                  /
+--R                          4 3       3 2 2      2 4        6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2     2     6         2     2     6
+--R              (4a c  + 3b c)e f x + (4a c  + 3b c)d f
+--R     + 
+--R                                           +------------------+
+--R                +-----------+              | +-----------+
+--R              2 |          2        2  +-+ | |          2
+--R         (- 2f \|- 4a c + b   + 4b f )\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                           +--------------------+
+--R                +-----------+              |   +-----------+
+--R              2 |          2        2  +-+ |   |          2
+--R         (- 2f \|- 4a c + b   - 4b f )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                     +--------------------+ +------------------+
+--R                       +-----------+ |   +-----------+      | +-----------+
+--R               2   +-+ |          2  |   |          2       | |          2
+--R     (8a c - 2b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 967
+
+--S 968 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 968
+
+)clear all
+
+--S 969 of 1057
+t0:=(d*f+e*f*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R     e f x + d f
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 969
+
+--S 970 of 1057
+r0:=-1/2*f*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   2*c*f*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e)
+--R 
+--R
+--R   (2)
+--R               2 4   4      2   3   3         2 2         2   2
+--R           - 4c e f x  - 16c d e f x  + (- 24c d  - 4b c)e f x
+--R         + 
+--R                 2 3                       2 4         2
+--R           (- 16c d  - 8b c d)e f x + (- 4c d  - 4b c d  - 4a c)f
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                               +-----------+
+--R            2   2                     2        |          2
+--R       (2c e f x  + 4c d e f x + (2c d  + b)f)\|- 4a c + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 970
+
+--S 971 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               2 4   4     2   3   3       2 2         2   2
+--R             2c e f x  + 8c d e f x  + (12c d  + 2b c)e f x
+--R           + 
+--R                2 3                     2 4         2
+--R             (8c d  + 4b c d)e f x + (2c d  + 2b c d  + 2a c)f
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                       2     2   2 2         2     2               2     2   2
+--R                  (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                                                 +-----------+
+--R              2   2                     2        |          2
+--R         (2c e f x  + 4c d e f x + (2c d  + b)f)\|- 4a c + b
+--R    /
+--R                2     2   5 4         2     2     4 3
+--R           (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R         + 
+--R                  2      2   2              3  3 2
+--R           ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R         + 
+--R                  2     2   3                3    2
+--R           ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R         + 
+--R                 2     2   4               3  2     2        2
+--R           ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R               2 4   4      2   3   3       2 2         2   2
+--R             4c e f x  + 16c d e f x  + (24c d  + 4b c)e f x
+--R           + 
+--R                 2 3                     2 4         2
+--R             (16c d  + 8b c d)e f x + (4c d  + 4b c d  + 4a c)f
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                                                 +---------+
+--R              2   2                     2        |        2
+--R         (2c e f x  + 4c d e f x + (2c d  + b)f)\|4a c - b
+--R    /
+--R                2     2   5 4         2     2     4 3
+--R           (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R         + 
+--R                  2      2   2              3  3 2
+--R           ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R         + 
+--R                  2     2   3                3    2
+--R           ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R         + 
+--R                 2     2   4               3  2     2        2
+--R           ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 971
+
+--S 972 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         c f
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                     2     2   2 2         2     2               2     2   2
+--R                (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                      2 2                  2
+--R                  2c e x  + 4c d e x + 2c d  + b
+--R       2c f atanh(------------------------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R                  +-----------+
+--R              2   |          2
+--R     (4a c - b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 972
+
+--S 973 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 973
+
+--S 974 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            +---------+          2 2                  2
+--R            |        2       2c e x  + 4c d e x + 2c d  + b
+--R       2c f\|4a c - b  atanh(------------------------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R            +-----------+          2 2                  2      |        2
+--R            |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       2c f\|- 4a c + b  atan(--------------------------------------------)
+--R                                                        2
+--R                                                4a c - b
+--R  /
+--R                  +-----------+ +---------+
+--R              2   |          2  |        2
+--R     (4a c - b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 974
+
+--S 975 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 975
+
+)clear all
+
+--S 976 of 1057
+t0:=1/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 976
+
+--S 977 of 1057
+r0:=1/2*(d+e*x)*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(b+(b^2-12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*e*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(b+(-b^2+12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*e*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2    2   4 4         2     2     3 3
+--R           (12a c  - b c)e x  + (48a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2              3  2 2
+--R           ((72a c  - 6b c)d  + 12a b c - b )e x
+--R         + 
+--R                  2     2   3                3               2    2   4
+--R           ((48a c  - 4b c)d  + (24a b c - 2b )d)e x + (12a c  - b c)d
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c - b )d  + 12a c - a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2    2   4 4           2     2     3 3
+--R           (- 12a c  + b c)e x  + (- 48a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2              3  2 2
+--R           ((- 72a c  + 6b c)d  - 12a b c + b )e x
+--R         + 
+--R                    2     2   3                  3                 2    2   4
+--R           ((- 48a c  + 4b c)d  + (- 24a b c + 2b )d)e x + (- 12a c  + b c)d
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c + b )d  - 12a c + a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  3 3           2 2            2           2            3
+--R           - b c e x  - 3b c d e x  + (- 3b c d  + 2a c - b )e x - b c d
+--R         + 
+--R                    2
+--R           (2a c - b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            2 2       2   5 4       2 2       2     4 3
+--R         (8a c  - 2a b c)e x  + (32a c  - 8a b c)d e x
+--R       + 
+--R              2 2        2   2     2          3  3 2
+--R         ((48a c  - 12a b c)d  + 8a b c - 2a b )e x
+--R       + 
+--R              2 2       2   3       2          3    2
+--R         ((32a c  - 8a b c)d  + (16a b c - 4a b )d)e x
+--R       + 
+--R             2 2       2   4      2          3  2     3      2 2
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + 8a c - 2a b )e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 2      2   5 4       2 2       2     4 3
+--R           (4a c  - a b c)e x  + (16a c  - 4a b c)d e x
+--R         + 
+--R                2 2       2   2     2         3  3 2
+--R           ((24a c  - 6a b c)d  + 4a b c - a b )e x
+--R         + 
+--R                2 2       2   3      2          3    2
+--R           ((16a c  - 4a b c)d  + (8a b c - 2a b )d)e x
+--R         + 
+--R               2 2      2   4      2         3  2     3     2 2
+--R           ((4a c  - a b c)d  + (4a b c - a b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9  3
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )e
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |                  2 2        2     4
+--R                     |             - 81a c  + 18a b c - b
+--R                     |-------------------------------------------------
+--R                     |       9 3         8 2 2        7 4        6 6  4
+--R                    \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                       4 4       3 2 3       2 4 2        6     8
+--R                  (864a c  - 672a b c  + 190a b c  - 23a b c + b )e
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                2 2      2   5 4         2 2       2     4 3
+--R           (- 4a c  + a b c)e x  + (- 16a c  + 4a b c)d e x
+--R         + 
+--R                  2 2       2   2     2         3  3 2
+--R           ((- 24a c  + 6a b c)d  - 4a b c + a b )e x
+--R         + 
+--R                  2 2       2   3        2          3    2
+--R           ((- 16a c  + 4a b c)d  + (- 8a b c + 2a b )d)e x
+--R         + 
+--R                 2 2      2   4        2         3  2     3     2 2
+--R           ((- 4a c  + a b c)d  + (- 4a b c + a b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9  3
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )e
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |                  2 2        2     4
+--R                     |             - 81a c  + 18a b c - b
+--R                     |-------------------------------------------------
+--R                     |       9 3         8 2 2        7 4        6 6  4
+--R                    \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                         4 4       3 2 3       2 4 2        6     8
+--R                  (- 864a c  + 672a b c  - 190a b c  + 23a b c - b )e
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R              2 2      2   5 4       2 2       2     4 3
+--R           (4a c  - a b c)e x  + (16a c  - 4a b c)d e x
+--R         + 
+--R                2 2       2   2     2         3  3 2
+--R           ((24a c  - 6a b c)d  + 4a b c - a b )e x
+--R         + 
+--R                2 2       2   3      2          3    2
+--R           ((16a c  - 4a b c)d  + (8a b c - 2a b )d)e x
+--R         + 
+--R               2 2      2   4      2         3  2     3     2 2
+--R           ((4a c  - a b c)d  + (4a b c - a b )d  + 4a c - a b )e
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                       +-------------------------------------------------+
+--R                       |                  2 2        2     4
+--R                     3 |             - 81a c  + 18a b c - b
+--R                    e  |-------------------------------------------------
+--R                       |       9 3         8 2 2        7 4        6 6  4
+--R                      \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                       4 4       3 2 3       2 4 2        6     8
+--R                  (864a c  - 672a b c  + 190a b c  - 23a b c + b )e
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                2 2      2   5 4         2 2       2     4 3
+--R           (- 4a c  + a b c)e x  + (- 16a c  + 4a b c)d e x
+--R         + 
+--R                  2 2       2   2     2         3  3 2
+--R           ((- 24a c  + 6a b c)d  - 4a b c + a b )e x
+--R         + 
+--R                  2 2       2   3        2          3    2
+--R           ((- 16a c  + 4a b c)d  + (- 8a b c + 2a b )d)e x
+--R         + 
+--R                 2 2      2   4        2         3  2     3     2 2
+--R           ((- 4a c  + a b c)d  + (- 4a b c + a b )d  - 4a c + a b )e
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                       +-------------------------------------------------+
+--R                       |                  2 2        2     4
+--R                     3 |             - 81a c  + 18a b c - b
+--R                    e  |-------------------------------------------------
+--R                       |       9 3         8 2 2        7 4        6 6  4
+--R                      \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                         4 4       3 2 3       2 4 2        6     8
+--R                  (- 864a c  + 672a b c  - 190a b c  + 23a b c - b )e
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R              3 3           2 2            2           2            3
+--R       - b c e x  - 3b c d e x  + (- 3b c d  + 2a c - b )e x - b c d
+--R     + 
+--R                2
+--R       (2a c - b )d
+--R  /
+--R          2 2       2   5 4       2 2       2     4 3
+--R       (8a c  - 2a b c)e x  + (32a c  - 8a b c)d e x
+--R     + 
+--R            2 2        2   2     2          3  3 2
+--R       ((48a c  - 12a b c)d  + 8a b c - 2a b )e x
+--R     + 
+--R            2 2       2   3       2          3    2
+--R       ((32a c  - 8a b c)d  + (16a b c - 4a b )d)e x
+--R     + 
+--R           2 2       2   4      2          3  2     3      2 2
+--R       ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + 8a c - 2a b )e
+--R                                         Type: Union(Expression(Integer),...)
+--E 978
+
+--S 979 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R            2       2   +-+ |          2  |   |          2
+--R         (4a c - a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9  3
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )e
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |                  2 2        2     4
+--R                     |             - 81a c  + 18a b c - b
+--R                     |-------------------------------------------------
+--R                     |       9 3         8 2 2        7 4        6 6  4
+--R                    \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                       4 4       3 2 3       2 4 2        6     8
+--R                  (864a c  - 672a b c  + 190a b c  - 23a b c + b )e
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                              +-----------+
+--R              2       2   +-+ |          2
+--R         (- 4a c + a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9  3
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )e
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |                  2 2        2     4
+--R                     |             - 81a c  + 18a b c - b
+--R                     |-------------------------------------------------
+--R                     |       9 3         8 2 2        7 4        6 6  4
+--R                    \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                         4 4       3 2 3       2 4 2        6     8
+--R                  (- 864a c  + 672a b c  - 190a b c  + 23a b c - b )e
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                            +-----------+
+--R            2       2   +-+ |          2
+--R         (4a c - a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6  2
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                       +-------------------------------------------------+
+--R                       |                  2 2        2     4
+--R                     3 |             - 81a c  + 18a b c - b
+--R                    e  |-------------------------------------------------
+--R                       |       9 3         8 2 2        7 4        6 6  4
+--R                      \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                       4 4       3 2 3       2 4 2        6     8
+--R                  (864a c  - 672a b c  + 190a b c  - 23a b c + b )e
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6  2
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                                            +--------------------+
+--R                              +-----------+ |   +-----------+
+--R              2       2   +-+ |          2  |   |          2
+--R         (- 4a c + a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6  2
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  2 2        2     4
+--R                   |             - 81a c  + 18a b c - b
+--R                   |-------------------------------------------------
+--R                   |       9 3         8 2 2        7 4        6 6  4
+--R                  \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                   6 3       5 2 2      4 4      3 6  2
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                       +-------------------------------------------------+
+--R                       |                  2 2        2     4
+--R                     3 |             - 81a c  + 18a b c - b
+--R                    e  |-------------------------------------------------
+--R                       |       9 3         8 2 2        7 4        6 6  4
+--R                      \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                + 
+--R                         4 4       3 2 3       2 4 2        6     8
+--R                  (- 864a c  + 672a b c  - 190a b c  + 23a b c - b )e
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6  2
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |                  2 2        2     4
+--R                          |             - 81a c  + 18a b c - b
+--R                          |-------------------------------------------------
+--R                          |       9 3         8 2 2        7 4        6 6  4
+--R                         \|(16384a c  - 12288a b c  + 3072a b c - 256a b )e
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                          6 3       5 2 2      4 4      3 6  2
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e
+--R            + 
+--R                   2 4        2 3     4 2            2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )e x + (324a c  - 81a b c  + 5b c )d
+--R     + 
+--R                                            +------------------+
+--R            +-----------+                   | +-----------+
+--R            |          2             2  +-+ | |          2
+--R         (b\|- 4a c + b   - 12a c + b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R            +-----------+                   |   +-----------+
+--R            |          2             2  +-+ |   |          2
+--R         (b\|- 4a c + b   + 12a c - b )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R          2        2   +-+ |          2  |   |          2
+--R       (8a c - 2a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 979
+
+--S 980 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 980
+
+)clear all
+
+--S 981 of 1057
+t0:=1/((d*f+e*f*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 9   9     2   8   8       2 2         7   7       2 3            6   6
+--R       c e f x  + 9c d e f x  + (36c d  + 2b c)e f x  + (84c d  + 14b c d)e f x
+--R     + 
+--R            2 4          2           2  5   5
+--R       (126c d  + 42b c d  + 2a c + b )e f x
+--R     + 
+--R            2 5          3              2    4   4
+--R       (126c d  + 70b c d  + (10a c + 5b )d)e f x
+--R     + 
+--R           2 6          4               2  2         3   3
+--R       (84c d  + 70b c d  + (20a c + 10b )d  + 2a b)e f x
+--R     + 
+--R           2 7          5               2  3           2   2
+--R       (36c d  + 42b c d  + (20a c + 10b )d  + 6a b d)e f x
+--R     + 
+--R          2 8          6              2  4         2    2
+--R       (9c d  + 14b c d  + (10a c + 5b )d  + 6a b d  + a )e f x
+--R     + 
+--R         2 9         7            2  5         3    2
+--R       (c d  + 2b c d  + (2a c + b )d  + 2a b d  + a d)f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 981
+
+--S 982 of 1057
+r0:=1/2*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+1/2*b*(b^2-6*a*c)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-_
+   4*a*c))/(a^2*(b^2-4*a*c)^(3/2)*e*f)+log(d+e*x)/(a^2*e*f)-_
+   1/4*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a^2*e*f)
+--R 
+--R
+--R   (2)
+--R                   2     3   4 4           2     3     3 3
+--R           (12a b c  - 2b c)e x  + (48a b c  - 8b c)d e x
+--R         + 
+--R                    2      3   2        2      4  2 2
+--R           ((72a b c  - 12b c)d  + 12a b c - 2b )e x
+--R         + 
+--R                    2     3   3         2      4                 2     3   4
+--R           ((48a b c  - 8b c)d  + (24a b c - 4b )d)e x + (12a b c  - 2b c)d
+--R         + 
+--R                 2      4  2      2          3
+--R           (12a b c - 2b )d  + 12a b c - 2a b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                      2    2   4 4           2     2     3 3
+--R               (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R             + 
+--R                        2     2   2             3  2 2
+--R               ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R             + 
+--R                        2     2   3                 3                2    2   4
+--R               ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x + (- 4a c  + b c)d
+--R             + 
+--R                            3  2     2       2
+--R               (- 4a b c + b )d  - 4a c + a b
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                     2     2   4 4         2      2     3 3
+--R               (16a c  - 4b c)e x  + (64a c  - 16b c)d e x
+--R             + 
+--R                      2      2   2               3  2 2
+--R               ((96a c  - 24b c)d  + 16a b c - 4b )e x
+--R             + 
+--R                      2      2   3                3               2     2   4
+--R               ((64a c  - 16b c)d  + (32a b c - 8b )d)e x + (16a c  - 4b c)d
+--R             + 
+--R                            3  2      2        2
+--R               (16a b c - 4b )d  + 16a c - 4a b
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                     2 2                          2     2        2
+--R           - 2a b c e x  - 4a b c d e x - 2a b c d  + 4a c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             3 2     2 2   5   4       3 2      2 2     4   3
+--R         (16a c  - 4a b c)e f x  + (64a c  - 16a b c)d e f x
+--R       + 
+--R              3 2      2 2   2      3        2 3  3   2
+--R         ((96a c  - 24a b c)d  + 16a b c - 4a b )e f x
+--R       + 
+--R              3 2      2 2   3       3        2 3    2
+--R         ((64a c  - 16a b c)d  + (32a b c - 8a b )d)e f x
+--R       + 
+--R              3 2     2 2   4       3        2 3  2      4      3 2
+--R         ((16a c  - 4a b c)d  + (16a b c - 4a b )d  + 16a c - 4a b )e f
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 982
+
+--S 983 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2    3   4 4           2     3     3 3
+--R             (6a b c  - b c)e x  + (24a b c  - 4b c)d e x
+--R           + 
+--R                      2     3   2       2     4  2 2
+--R             ((36a b c  - 6b c)d  + 6a b c - b )e x
+--R           + 
+--R                      2     3   3         2      4                2    3   4
+--R             ((24a b c  - 4b c)d  + (12a b c - 2b )d)e x + (6a b c  - b c)d
+--R           + 
+--R                  2     4  2     2         3
+--R             (6a b c - b )d  + 6a b c - a b
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                        2    2   4 4           2     2     3 3
+--R                 (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R               + 
+--R                          2     2   2             3  2 2
+--R                 ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R               + 
+--R                          2     2   3                 3
+--R                 ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R               + 
+--R                        2    2   4                3  2     2       2
+--R                 (- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                       2     2   4 4         2      2     3 3
+--R                 (16a c  - 4b c)e x  + (64a c  - 16b c)d e x
+--R               + 
+--R                        2      2   2               3  2 2
+--R                 ((96a c  - 24b c)d  + 16a b c - 4b )e x
+--R               + 
+--R                        2      2   3                3               2     2   4
+--R                 ((64a c  - 16b c)d  + (32a b c - 8b )d)e x + (16a c  - 4b c)d
+--R               + 
+--R                              3  2      2        2
+--R                 (16a b c - 4b )d  + 16a c - 4a b
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                       2 2                          2     2        2
+--R             - 2a b c e x  - 4a b c d e x - 2a b c d  + 4a c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               3 2     2 2   5   4       3 2      2 2     4   3
+--R           (16a c  - 4a b c)e f x  + (64a c  - 16a b c)d e f x
+--R         + 
+--R                3 2      2 2   2      3        2 3  3   2
+--R           ((96a c  - 24a b c)d  + 16a b c - 4a b )e f x
+--R         + 
+--R                3 2      2 2   3       3        2 3    2
+--R           ((64a c  - 16a b c)d  + (32a b c - 8a b )d)e f x
+--R         + 
+--R                3 2     2 2   4       3        2 3  2      4      3 2
+--R           ((16a c  - 4a b c)d  + (16a b c - 4a b )d  + 16a c - 4a b )e f
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                       2     3   4 4             2     3     3 3
+--R             (- 12a b c  + 2b c)e x  + (- 48a b c  + 8b c)d e x
+--R           + 
+--R                        2      3   2        2      4  2 2
+--R             ((- 72a b c  + 12b c)d  - 12a b c + 2b )e x
+--R           + 
+--R                        2     3   3           2      4
+--R             ((- 48a b c  + 8b c)d  + (- 24a b c + 4b )d)e x
+--R           + 
+--R                       2     3   4           2      4  2      2          3
+--R             (- 12a b c  + 2b c)d  + (- 12a b c + 2b )d  - 12a b c + 2a b
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                        2    2   4 4           2     2     3 3
+--R                 (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R               + 
+--R                          2     2   2             3  2 2
+--R                 ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R               + 
+--R                          2     2   3                 3
+--R                 ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x
+--R               + 
+--R                        2    2   4                3  2     2       2
+--R                 (- 4a c  + b c)d  + (- 4a b c + b )d  - 4a c + a b
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                       2     2   4 4         2      2     3 3
+--R                 (16a c  - 4b c)e x  + (64a c  - 16b c)d e x
+--R               + 
+--R                        2      2   2               3  2 2
+--R                 ((96a c  - 24b c)d  + 16a b c - 4b )e x
+--R               + 
+--R                        2      2   3                3               2     2   4
+--R                 ((64a c  - 16b c)d  + (32a b c - 8b )d)e x + (16a c  - 4b c)d
+--R               + 
+--R                              3  2      2        2
+--R                 (16a b c - 4b )d  + 16a c - 4a b
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                       2 2                          2     2        2
+--R             - 2a b c e x  - 4a b c d e x - 2a b c d  + 4a c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               3 2     2 2   5   4       3 2      2 2     4   3
+--R           (16a c  - 4a b c)e f x  + (64a c  - 16a b c)d e f x
+--R         + 
+--R                3 2      2 2   2      3        2 3  3   2
+--R           ((96a c  - 24a b c)d  + 16a b c - 4a b )e f x
+--R         + 
+--R                3 2      2 2   3       3        2 3    2
+--R           ((64a c  - 16a b c)d  + (32a b c - 8a b )d)e f x
+--R         + 
+--R                3 2     2 2   4       3        2 3  2      4      3 2
+--R           ((16a c  - 4a b c)d  + (16a b c - 4a b )d  + 16a c - 4a b )e f
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 983
+
+--S 984 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (6a b c - b )
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                                  2 2                  2
+--R                      3       2c e x  + 4c d e x + 2c d  + b
+--R       (- 12a b c + 2b )atanh(------------------------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R  /
+--R                        +-----------+
+--R         3      2 2     |          2
+--R     (16a c - 4a b )e f\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 984
+
+--S 985 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 985
+
+--S 986 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+          2 2                  2
+--R                    3  |        2       2c e x  + 4c d e x + 2c d  + b
+--R       (- 6a b c + b )\|4a c - b  atanh(------------------------------)
+--R                                                 +-----------+
+--R                                                 |          2
+--R                                                \|- 4a c + b
+--R     + 
+--R                         +-----------+
+--R                      3  |          2
+--R         (- 6a b c + b )\|- 4a c + b
+--R      *
+--R                                               +---------+
+--R                   2 2                  2      |        2
+--R              (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R  /
+--R                       +-----------+ +---------+
+--R        3      2 2     |          2  |        2
+--R     (8a c - 2a b )e f\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 986
+
+--S 987 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 987
+
+)clear all
+
+--S 988 of 1057
+t0:=1/((d*f+e*f*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 10 2 10      2   9 2 9       2 2         8 2 8
+--R       c e  f x   + 10c d e f x  + (45c d  + 2b c)e f x
+--R     + 
+--R            2 3            7 2 7        2 4          2           2  6 2 6
+--R       (120c d  + 16b c d)e f x  + (210c d  + 56b c d  + 2a c + b )e f x
+--R     + 
+--R            2 5           3              2    5 2 5
+--R       (252c d  + 112b c d  + (12a c + 6b )d)e f x
+--R     + 
+--R            2 6           4               2  2         4 2 4
+--R       (210c d  + 140b c d  + (30a c + 15b )d  + 2a b)e f x
+--R     + 
+--R            2 7           5               2  3           3 2 3
+--R       (120c d  + 112b c d  + (40a c + 20b )d  + 8a b d)e f x
+--R     + 
+--R           2 8          6               2  4          2    2  2 2 2
+--R       (45c d  + 56b c d  + (30a c + 15b )d  + 12a b d  + a )e f x
+--R     + 
+--R           2 9          7              2  5         3     2     2
+--R       (10c d  + 16b c d  + (12a c + 6b )d  + 8a b d  + 2a d)e f x
+--R     + 
+--R         2 10         8            2  6         4    2 2  2
+--R       (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 988
+
+--S 989 of 1057
+r0:=1/2*(-3*b^2+10*a*c)/(a^2*(b^2-4*a*c)*e*f^2*(d+e*x))+1/2*(b^2-_
+   2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f^2*(d+e*x)*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))-1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(3*b^2-10*a*c+b*(3*b^2-16*a*c)/sqrt(b^2-4*a*c))/_
+   (a^2*(b^2-4*a*c)*e*f^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (3*b^2-10*a*c+(-3*b^3+16*a*b*c)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*_
+   e*f^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       2     2   5 5           2      2     4 4
+--R               (- 10a c  + 3b c)e x  + (- 50a c  + 15b c)d e x
+--R             + 
+--R                         2      2   2               3  3 3
+--R               ((- 100a c  + 30b c)d  - 10a b c + 3b )e x
+--R             + 
+--R                         2      2   3                  3    2 2
+--R               ((- 100a c  + 30b c)d  + (- 30a b c + 9b )d)e x
+--R             + 
+--R                        2      2   4                  3  2      2        2
+--R               ((- 50a c  + 15b c)d  + (- 30a b c + 9b )d  - 10a c + 3a b )e x
+--R             + 
+--R                       2     2   5                  3  3         2        2
+--R               (- 10a c  + 3b c)d  + (- 10a b c + 3b )d  + (- 10a c + 3a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   5 5             2      3     4 4
+--R           (- 16a b c  + 3b c)e x  + (- 80a b c  + 15b c)d e x
+--R         + 
+--R                       2      3   2        2      4  3 3
+--R           ((- 160a b c  + 30b c)d  - 16a b c + 3b )e x
+--R         + 
+--R                       2      3   3           2      4    2 2
+--R           ((- 160a b c  + 30b c)d  + (- 48a b c + 9b )d)e x
+--R         + 
+--R                      2      3   4           2      4  2      2          3
+--R           ((- 80a b c  + 15b c)d  + (- 48a b c + 9b )d  - 16a b c + 3a b )e x
+--R         + 
+--R                     2     3   5           2      4  3         2          3
+--R           (- 16a b c  + 3b c)d  + (- 16a b c + 3b )d  + (- 16a b c + 3a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                       2     2   5 5           2      2     4 4
+--R               (- 10a c  + 3b c)e x  + (- 50a c  + 15b c)d e x
+--R             + 
+--R                         2      2   2               3  3 3
+--R               ((- 100a c  + 30b c)d  - 10a b c + 3b )e x
+--R             + 
+--R                         2      2   3                  3    2 2
+--R               ((- 100a c  + 30b c)d  + (- 30a b c + 9b )d)e x
+--R             + 
+--R                        2      2   4                  3  2      2        2
+--R               ((- 50a c  + 15b c)d  + (- 30a b c + 9b )d  - 10a c + 3a b )e x
+--R             + 
+--R                       2     2   5                  3  3         2        2
+--R               (- 10a c  + 3b c)d  + (- 10a b c + 3b )d  + (- 10a c + 3a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   5 5           2      3     4 4
+--R           (16a b c  - 3b c)e x  + (80a b c  - 15b c)d e x
+--R         + 
+--R                     2      3   2        2      4  3 3
+--R           ((160a b c  - 30b c)d  + 16a b c - 3b )e x
+--R         + 
+--R                     2      3   3         2      4    2 2
+--R           ((160a b c  - 30b c)d  + (48a b c - 9b )d)e x
+--R         + 
+--R                    2      3   4         2      4  2      2          3
+--R           ((80a b c  - 15b c)d  + (48a b c - 9b )d  + 16a b c - 3a b )e x
+--R         + 
+--R                   2     3   5         2      4  3       2          3
+--R           (16a b c  - 3b c)d  + (16a b c - 3b )d  + (16a b c - 3a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2     2   4 4           2      2     3 3
+--R           (- 10a c  + 3b c)e x  + (- 40a c  + 12b c)d e x
+--R         + 
+--R                    2      2   2               3  2 2
+--R           ((- 60a c  + 18b c)d  - 11a b c + 3b )e x
+--R         + 
+--R                    2      2   3                  3                 2     2   4
+--R           ((- 40a c  + 12b c)d  + (- 22a b c + 6b )d)e x + (- 10a c  + 3b c)d
+--R         + 
+--R                          3  2     2        2
+--R           (- 11a b c + 3b )d  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            3 2     2 2   6 2 5       3 2      2 2     5 2 4
+--R         (8a c  - 2a b c)e f x  + (40a c  - 10a b c)d e f x
+--R       + 
+--R              3 2      2 2   2     3        2 3  4 2 3
+--R         ((80a c  - 20a b c)d  + 8a b c - 2a b )e f x
+--R       + 
+--R              3 2      2 2   3       3        2 3    3 2 2
+--R         ((80a c  - 20a b c)d  + (24a b c - 6a b )d)e f x
+--R       + 
+--R              3 2      2 2   4       3        2 3  2     4      3 2  2 2
+--R         ((40a c  - 10a b c)d  + (24a b c - 6a b )d  + 8a c - 2a b )e f x
+--R       + 
+--R             3 2     2 2   5      3        2 3  3      4      3 2      2
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d)e f
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 989
+
+--S 990 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 2    2 2   6 2 5         3 2     2 2     5 2 4
+--R           (- 4a c  + a b c)e f x  + (- 20a c  + 5a b c)d e f x
+--R         + 
+--R                  3 2      2 2   2     3       2 3  4 2 3
+--R           ((- 40a c  + 10a b c)d  - 4a b c + a b )e f x
+--R         + 
+--R                  3 2      2 2   3         3        2 3    3 2 2
+--R           ((- 40a c  + 10a b c)d  + (- 12a b c + 3a b )d)e f x
+--R         + 
+--R                  3 2     2 2   4         3        2 3  2     4     3 2  2 2
+--R           ((- 20a c  + 5a b c)d  + (- 12a b c + 3a b )d  - 4a c + a b )e f x
+--R         + 
+--R                 3 2    2 2   5        3       2 3  3        4     3 2      2
+--R           ((- 4a c  + a b c)d  + (- 4a b c + a b )d  + (- 4a c + a b )d)e f
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6  2 4
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e f
+--R               *
+--R                   +-------------------------------------------------------+
+--R                   |       4 4        3 2 3        2 4 2         6       8
+--R                   | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-------------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4 8
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2 4
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                       +-------------------------------------------------------+
+--R                       |       4 4        3 2 3        2 4 2         6       8
+--R                   3 6 | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                  e f  |-------------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4 8
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                      5200a b c  - 14408a b c  + 10549a b c  - 3330a b c
+--R                    + 
+--R                            9       11
+--R                      486a b c - 27b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6  2 4
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                      4 4        3 2 3        2 4 2         6
+--R                                - 625a c  + 2550a b c  - 3051a b c  + 918a b c
+--R                              + 
+--R                                     8
+--R                                - 81b
+--R                           /
+--R                                        13 3         12 2 2        11 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2 4
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R              3 2    2 2   6 2 5       3 2     2 2     5 2 4
+--R           (4a c  - a b c)e f x  + (20a c  - 5a b c)d e f x
+--R         + 
+--R                3 2      2 2   2     3       2 3  4 2 3
+--R           ((40a c  - 10a b c)d  + 4a b c - a b )e f x
+--R         + 
+--R                3 2      2 2   3       3        2 3    3 2 2
+--R           ((40a c  - 10a b c)d  + (12a b c - 3a b )d)e f x
+--R         + 
+--R                3 2     2 2   4       3        2 3  2     4     3 2  2 2
+--R           ((20a c  - 5a b c)d  + (12a b c - 3a b )d  + 4a c - a b )e f x
+--R         + 
+--R               3 2    2 2   5      3       2 3  3      4     3 2      2
+--R           ((4a c  - a b c)d  + (4a b c - a b )d  + (4a c - a b )d)e f
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6  2 4
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e f
+--R               *
+--R                   +-------------------------------------------------------+
+--R                   |       4 4        3 2 3        2 4 2         6       8
+--R                   | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-------------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4 8
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2 4
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                       +-------------------------------------------------------+
+--R                       |       4 4        3 2 3        2 4 2         6       8
+--R                   3 6 | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                  e f  |-------------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4 8
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                    + 
+--R                              9       11
+--R                      - 486a b c + 27b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6  2 4
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                      4 4        3 2 3        2 4 2         6
+--R                                - 625a c  + 2550a b c  - 3051a b c  + 918a b c
+--R                              + 
+--R                                     8
+--R                                - 81b
+--R                           /
+--R                                        13 3         12 2 2        11 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2 4
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R                3 2    2 2   6 2 5         3 2     2 2     5 2 4
+--R           (- 4a c  + a b c)e f x  + (- 20a c  + 5a b c)d e f x
+--R         + 
+--R                  3 2      2 2   2     3       2 3  4 2 3
+--R           ((- 40a c  + 10a b c)d  - 4a b c + a b )e f x
+--R         + 
+--R                  3 2      2 2   3         3        2 3    3 2 2
+--R           ((- 40a c  + 10a b c)d  + (- 12a b c + 3a b )d)e f x
+--R         + 
+--R                  3 2     2 2   4         3        2 3  2     4     3 2  2 2
+--R           ((- 20a c  + 5a b c)d  + (- 12a b c + 3a b )d  - 4a c + a b )e f x
+--R         + 
+--R                 3 2    2 2   5        3       2 3  3        4     3 2      2
+--R           ((- 4a c  + a b c)d  + (- 4a b c + a b )d  + (- 4a c + a b )d)e f
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6  2 4
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e f
+--R               *
+--R                   +-------------------------------------------------------+
+--R                   |       4 4        3 2 3        2 4 2         6       8
+--R                   | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-------------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4 8
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2 4
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                       +-------------------------------------------------------+
+--R                       |       4 4        3 2 3        2 4 2         6       8
+--R                   3 6 | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                  e f  |-------------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4 8
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                      5200a b c  - 14408a b c  + 10549a b c  - 3330a b c
+--R                    + 
+--R                            9       11
+--R                      486a b c - 27b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6  2 4
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                      4 4        3 2 3        2 4 2         6
+--R                                - 625a c  + 2550a b c  - 3051a b c  + 918a b c
+--R                              + 
+--R                                     8
+--R                                - 81b
+--R                           /
+--R                                        13 3         12 2 2        11 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2 4
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R              3 2    2 2   6 2 5       3 2     2 2     5 2 4
+--R           (4a c  - a b c)e f x  + (20a c  - 5a b c)d e f x
+--R         + 
+--R                3 2      2 2   2     3       2 3  4 2 3
+--R           ((40a c  - 10a b c)d  + 4a b c - a b )e f x
+--R         + 
+--R                3 2      2 2   3       3        2 3    3 2 2
+--R           ((40a c  - 10a b c)d  + (12a b c - 3a b )d)e f x
+--R         + 
+--R                3 2     2 2   4       3        2 3  2     4     3 2  2 2
+--R           ((20a c  - 5a b c)d  + (12a b c - 3a b )d  + 4a c - a b )e f x
+--R         + 
+--R               3 2    2 2   5      3       2 3  3      4     3 2      2
+--R           ((4a c  - a b c)d  + (4a b c - a b )d  + (4a c - a b )d)e f
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6  2 4
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e f
+--R               *
+--R                   +-------------------------------------------------------+
+--R                   |       4 4        3 2 3        2 4 2         6       8
+--R                   | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-------------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4 8
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2 4
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                       +-------------------------------------------------------+
+--R                       |       4 4        3 2 3        2 4 2         6       8
+--R                   3 6 | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                  e f  |-------------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4 8
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                    + 
+--R                              9       11
+--R                      - 486a b c + 27b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6  2 4
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                      4 4        3 2 3        2 4 2         6
+--R                                - 625a c  + 2550a b c  - 3051a b c  + 918a b c
+--R                              + 
+--R                                     8
+--R                                - 81b
+--R                           /
+--R                                        13 3         12 2 2        11 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2 4
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R               2     2   4 4           2      2     3 3
+--R       (- 10a c  + 3b c)e x  + (- 40a c  + 12b c)d e x
+--R     + 
+--R                2      2   2               3  2 2
+--R       ((- 60a c  + 18b c)d  - 11a b c + 3b )e x
+--R     + 
+--R                2      2   3                  3                 2     2   4
+--R       ((- 40a c  + 12b c)d  + (- 22a b c + 6b )d)e x + (- 10a c  + 3b c)d
+--R     + 
+--R                      3  2     2        2
+--R       (- 11a b c + 3b )d  - 8a c + 2a b
+--R  /
+--R          3 2     2 2   6 2 5       3 2      2 2     5 2 4
+--R       (8a c  - 2a b c)e f x  + (40a c  - 10a b c)d e f x
+--R     + 
+--R            3 2      2 2   2     3        2 3  4 2 3
+--R       ((80a c  - 20a b c)d  + 8a b c - 2a b )e f x
+--R     + 
+--R            3 2      2 2   3       3        2 3    3 2 2
+--R       ((80a c  - 20a b c)d  + (24a b c - 6a b )d)e f x
+--R     + 
+--R            3 2      2 2   4       3        2 3  2     4      3 2  2 2
+--R       ((40a c  - 10a b c)d  + (24a b c - 6a b )d  + 8a c - 2a b )e f x
+--R     + 
+--R           3 2     2 2   5      3        2 3  3      4      3 2      2
+--R       ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d)e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 990
+
+--S 991 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +--------------------+
+--R                                 +-----------+ |   +-----------+
+--R              3     2 2    2 +-+ |          2  |   |          2
+--R         (- 4a c + a b )e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6  2 4
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e f
+--R               *
+--R                   +-------------------------------------------------------+
+--R                   |       4 4        3 2 3        2 4 2         6       8
+--R                   | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-------------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4 8
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2 4
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                       +-------------------------------------------------------+
+--R                       |       4 4        3 2 3        2 4 2         6       8
+--R                   3 6 | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                  e f  |-------------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4 8
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                      5200a b c  - 14408a b c  + 10549a b c  - 3330a b c
+--R                    + 
+--R                            9       11
+--R                      486a b c - 27b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6  2 4
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                      4 4        3 2 3        2 4 2         6
+--R                                - 625a c  + 2550a b c  - 3051a b c  + 918a b c
+--R                              + 
+--R                                     8
+--R                                - 81b
+--R                           /
+--R                                        13 3         12 2 2        11 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2 4
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R                               +-----------+
+--R            3     2 2    2 +-+ |          2
+--R         (4a c - a b )e f \|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6  2 4
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e f
+--R               *
+--R                   +-------------------------------------------------------+
+--R                   |       4 4        3 2 3        2 4 2         6       8
+--R                   | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-------------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4 8
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2 4
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                       +-------------------------------------------------------+
+--R                       |       4 4        3 2 3        2 4 2         6       8
+--R                   3 6 | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                  e f  |-------------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4 8
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                    + 
+--R                              9       11
+--R                      - 486a b c + 27b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6  2 4
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                      4 4        3 2 3        2 4 2         6
+--R                                - 625a c  + 2550a b c  - 3051a b c  + 918a b c
+--R                              + 
+--R                                     8
+--R                                - 81b
+--R                           /
+--R                                        13 3         12 2 2        11 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2 4
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R                                 +-----------+
+--R              3     2 2    2 +-+ |          2
+--R         (- 4a c + a b )e f \|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6  2 4
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )e f
+--R               *
+--R                   +-------------------------------------------------------+
+--R                   |       4 4        3 2 3        2 4 2         6       8
+--R                   | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-------------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4 8
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2 4
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                       +-------------------------------------------------------+
+--R                       |       4 4        3 2 3        2 4 2         6       8
+--R                   3 6 | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                  e f  |-------------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4 8
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R                + 
+--R                           5   5         4 3 4         3 5 3        2 7 2
+--R                      5200a b c  - 14408a b c  + 10549a b c  - 3330a b c
+--R                    + 
+--R                            9       11
+--R                      486a b c - 27b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6  2 4
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                      4 4        3 2 3        2 4 2         6
+--R                                - 625a c  + 2550a b c  - 3051a b c  + 918a b c
+--R                              + 
+--R                                     8
+--R                                - 81b
+--R                           /
+--R                                        13 3         12 2 2        11 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2 4
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R                                             +--------------------+
+--R                               +-----------+ |   +-----------+
+--R            3     2 2    2 +-+ |          2  |   |          2
+--R         (4a c - a b )e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6  2 4
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )e f
+--R               *
+--R                   +-------------------------------------------------------+
+--R                   |       4 4        3 2 3        2 4 2         6       8
+--R                   | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-------------------------------------------------------
+--R                   |       13 3         12 2 2        11 4        10 6  4 8
+--R                  \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                   8 3       7 2 2      6 4      5 6  2 4
+--R              (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                       +-------------------------------------------------------+
+--R                       |       4 4        3 2 3        2 4 2         6       8
+--R                   3 6 | - 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                  e f  |-------------------------------------------------------
+--R                       |       13 3         12 2 2        11 4        10 6  4 8
+--R                      \|(16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                    + 
+--R                              9       11
+--R                      - 486a b c + 27b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6  2 4
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                      4 4        3 2 3        2 4 2         6
+--R                                - 625a c  + 2550a b c  - 3051a b c  + 918a b c
+--R                              + 
+--R                                     8
+--R                                - 81b
+--R                           /
+--R                                        13 3         12 2 2        11 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                          8 3       7 2 2      6 4      5 6  2 4
+--R                     (512a c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )e x
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )d
+--R     + 
+--R                                                           +------------------+
+--R                        +-----------+                      | +-----------+
+--R                     2  |          2                3  +-+ | |          2
+--R         ((10a c - 3b )\|- 4a c + b   + 16a b c - 3b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                        +-----------+
+--R                     2  |          2                3  +-+
+--R         ((10a c - 3b )\|- 4a c + b   - 16a b c + 3b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                            +--------------------+
+--R                              +-----------+ |   +-----------+
+--R          3      2 2    2 +-+ |          2  |   |          2
+--R       (8a c - 2a b )e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 991
+
+--S 992 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 992
+
+)clear all
+
+--S 993 of 1057
+t0:=1/((d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 11 3 11      2   10 3 10       2 2         9 3 9
+--R       c e  f x   + 11c d e  f x   + (55c d  + 2b c)e f x
+--R     + 
+--R            2 3            8 3 8        2 4          2           2  7 3 7
+--R       (165c d  + 18b c d)e f x  + (330c d  + 72b c d  + 2a c + b )e f x
+--R     + 
+--R            2 5           3              2    6 3 6
+--R       (462c d  + 168b c d  + (14a c + 7b )d)e f x
+--R     + 
+--R            2 6           4               2  2         5 3 5
+--R       (462c d  + 252b c d  + (42a c + 21b )d  + 2a b)e f x
+--R     + 
+--R            2 7           5               2  3            4 3 4
+--R       (330c d  + 252b c d  + (70a c + 35b )d  + 10a b d)e f x
+--R     + 
+--R            2 8           6               2  4          2    2  3 3 3
+--R       (165c d  + 168b c d  + (70a c + 35b )d  + 20a b d  + a )e f x
+--R     + 
+--R           2 9          7               2  5          3     2   2 3 2
+--R       (55c d  + 72b c d  + (42a c + 21b )d  + 20a b d  + 3a d)e f x
+--R     + 
+--R           2 10          8              2  6          4     2 2    3
+--R       (11c d   + 18b c d  + (14a c + 7b )d  + 10a b d  + 3a d )e f x
+--R     + 
+--R         2 11         9            2  7         5    2 3  3
+--R       (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 993
+
+--S 994 of 1057
+r0:=(-b^2+3*a*c)/(a^2*(b^2-4*a*c)*e*f^3*(d+e*x)^2)+1/2*(b^2-2*a*c+_
+   b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f^3*(d+e*x)^2*(a+b*(d+e*x)^2+c*(d+_
+   e*x)^4))-(b^4-6*a*b^2*c+6*a^2*c^2)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-_
+   4*a*c))/(a^3*(b^2-4*a*c)^(3/2)*e*f^3)-2*b*log(d+e*x)/(a^3*e*f^3)+_
+   1/2*b*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a^3*e*f^3)
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   6 6       2 3        2 2      4     5 5
+--R           (12a c  - 12a b c  + 2b c)e x  + (72a c  - 72a b c  + 12b c)d e x
+--R         + 
+--R                 2 3         2 2      4   2      2   2        3      5  4 4
+--R           ((180a c  - 180a b c  + 30b c)d  + 12a b c  - 12a b c + 2b )e x
+--R         + 
+--R                 2 3         2 2      4   3       2   2        3      5    3 3
+--R           ((240a c  - 240a b c  + 40b c)d  + (48a b c  - 48a b c + 8b )d)e x
+--R         + 
+--R                    2 3         2 2      4   4       2   2        3       5  2
+--R               (180a c  - 180a b c  + 30b c)d  + (72a b c  - 72a b c + 12b )d
+--R             + 
+--R                  3 2      2 2        4
+--R               12a c  - 12a b c + 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                   2 3        2 2      4   5       2   2        3      5  3
+--R               (72a c  - 72a b c  + 12b c)d  + (48a b c  - 48a b c + 8b )d
+--R             + 
+--R                   3 2      2 2        4
+--R               (24a c  - 24a b c + 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2 3        2 2     4   6       2   2        3      5  4
+--R           (12a c  - 12a b c  + 2b c)d  + (12a b c  - 12a b c + 2b )d
+--R         + 
+--R               3 2      2 2        4  2
+--R           (12a c  - 12a b c + 2a b )d
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                      2    3   6 6           2     3     5 5
+--R               (4a b c  - b c)e x  + (24a b c  - 6b c)d e x
+--R             + 
+--R                        2      3   2       2     4  4 4
+--R               ((60a b c  - 15b c)d  + 4a b c - b )e x
+--R             + 
+--R                        2      3   3         2      4    3 3
+--R               ((80a b c  - 20b c)d  + (16a b c - 4b )d)e x
+--R             + 
+--R                        2      3   4         2      4  2     2         3  2 2
+--R               ((60a b c  - 15b c)d  + (24a b c - 6b )d  + 4a b c - a b )e x
+--R             + 
+--R                        2     3   5         2      4  3      2          3
+--R               ((24a b c  - 6b c)d  + (16a b c - 4b )d  + (8a b c - 2a b )d)e x
+--R             + 
+--R                      2    3   6        2     4  4      2         3  2
+--R               (4a b c  - b c)d  + (4a b c - b )d  + (4a b c - a b )d
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                         2     3   6 6             2      3     5 5
+--R               (- 16a b c  + 4b c)e x  + (- 96a b c  + 24b c)d e x
+--R             + 
+--R                           2      3   2        2      4  4 4
+--R               ((- 240a b c  + 60b c)d  - 16a b c + 4b )e x
+--R             + 
+--R                           2      3   3           2       4    3 3
+--R               ((- 320a b c  + 80b c)d  + (- 64a b c + 16b )d)e x
+--R             + 
+--R                              2      3   4           2       4  2      2
+--R                   (- 240a b c  + 60b c)d  + (- 96a b c + 24b )d  - 16a b c
+--R                 + 
+--R                       3
+--R                   4a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                             2      3   5           2       4  3
+--R                   (- 96a b c  + 24b c)d  + (- 64a b c + 16b )d
+--R                 + 
+--R                         2          3
+--R                   (- 32a b c + 8a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2     3   6           2      4  4         2          3  2
+--R             (- 16a b c  + 4b c)d  + (- 16a b c + 4b )d  + (- 16a b c + 4a b )d
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                2 2       2   4 4         2 2       2     3 3
+--R           (- 6a c  + 2a b c)e x  + (- 24a c  + 8a b c)d e x
+--R         + 
+--R                  2 2        2   2     2          3  2 2
+--R           ((- 36a c  + 12a b c)d  - 7a b c + 2a b )e x
+--R         + 
+--R                  2 2       2   3         2          3
+--R           ((- 24a c  + 8a b c)d  + (- 14a b c + 4a b )d)e x
+--R         + 
+--R                2 2       2   4        2          3  2     3     2 2
+--R           (- 6a c  + 2a b c)d  + (- 7a b c + 2a b )d  - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            4 2     3 2   7 3 6       4 2      3 2     6 3 5
+--R         (8a c  - 2a b c)e f x  + (48a c  - 12a b c)d e f x
+--R       + 
+--R               4 2      3 2   2     4        3 3  5 3 4
+--R         ((120a c  - 30a b c)d  + 8a b c - 2a b )e f x
+--R       + 
+--R               4 2      3 2   3       4        3 3    4 3 3
+--R         ((160a c  - 40a b c)d  + (32a b c - 8a b )d)e f x
+--R       + 
+--R               4 2      3 2   4       4         3 3  2     5      4 2  3 3 2
+--R         ((120a c  - 30a b c)d  + (48a b c - 12a b )d  + 8a c - 2a b )e f x
+--R       + 
+--R              4 2      3 2   5       4        3 3  3       5      4 2    2 3
+--R         ((48a c  - 12a b c)d  + (32a b c - 8a b )d  + (16a c - 4a b )d)e f x
+--R       + 
+--R             4 2     3 2   6      4        3 3  4      5      4 2  2    3
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d )e f
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 994
+
+--S 995 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3       2 2    4   6 6       2 3        2 2     4     5 5
+--R             (6a c  - 6a b c  + b c)e x  + (36a c  - 36a b c  + 6b c)d e x
+--R           + 
+--R                  2 3        2 2      4   2     2   2       3     5  4 4
+--R             ((90a c  - 90a b c  + 15b c)d  + 6a b c  - 6a b c + b )e x
+--R           + 
+--R                   2 3         2 2      4   3       2   2        3      5    3 3
+--R             ((120a c  - 120a b c  + 20b c)d  + (24a b c  - 24a b c + 4b )d)e x
+--R           + 
+--R                     2 3        2 2      4   4       2   2        3      5  2
+--R                 (90a c  - 90a b c  + 15b c)d  + (36a b c  - 36a b c + 6b )d
+--R               + 
+--R                   3 2     2 2       4
+--R                 6a c  - 6a b c + a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                     2 3        2 2     4   5       2   2        3      5  3
+--R                 (36a c  - 36a b c  + 6b c)d  + (24a b c  - 24a b c + 4b )d
+--R               + 
+--R                     3 2      2 2        4
+--R                 (12a c  - 12a b c + 2a b )d
+--R            *
+--R               e x
+--R           + 
+--R                2 3       2 2    4   6      2   2       3     5  4
+--R             (6a c  - 6a b c  + b c)d  + (6a b c  - 6a b c + b )d
+--R           + 
+--R                3 2     2 2       4  2
+--R             (6a c  - 6a b c + a b )d
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                        2    3   6 6           2     3     5 5
+--R                 (4a b c  - b c)e x  + (24a b c  - 6b c)d e x
+--R               + 
+--R                          2      3   2       2     4  4 4
+--R                 ((60a b c  - 15b c)d  + 4a b c - b )e x
+--R               + 
+--R                          2      3   3         2      4    3 3
+--R                 ((80a b c  - 20b c)d  + (16a b c - 4b )d)e x
+--R               + 
+--R                          2      3   4         2      4  2     2         3  2 2
+--R                 ((60a b c  - 15b c)d  + (24a b c - 6b )d  + 4a b c - a b )e x
+--R               + 
+--R                            2     3   5         2      4  3      2          3
+--R                   ((24a b c  - 6b c)d  + (16a b c - 4b )d  + (8a b c - 2a b )d)
+--R                *
+--R                   e x
+--R               + 
+--R                        2    3   6        2     4  4      2         3  2
+--R                 (4a b c  - b c)d  + (4a b c - b )d  + (4a b c - a b )d
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                           2     3   6 6             2      3     5 5
+--R                 (- 16a b c  + 4b c)e x  + (- 96a b c  + 24b c)d e x
+--R               + 
+--R                             2      3   2        2      4  4 4
+--R                 ((- 240a b c  + 60b c)d  - 16a b c + 4b )e x
+--R               + 
+--R                             2      3   3           2       4    3 3
+--R                 ((- 320a b c  + 80b c)d  + (- 64a b c + 16b )d)e x
+--R               + 
+--R                                2      3   4           2       4  2      2
+--R                     (- 240a b c  + 60b c)d  + (- 96a b c + 24b )d  - 16a b c
+--R                   + 
+--R                         3
+--R                     4a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                               2      3   5           2       4  3
+--R                     (- 96a b c  + 24b c)d  + (- 64a b c + 16b )d
+--R                   + 
+--R                           2          3
+--R                     (- 32a b c + 8a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)d  + (- 16a b c + 4b )d
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )d
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                  2 2       2   4 4         2 2       2     3 3
+--R             (- 6a c  + 2a b c)e x  + (- 24a c  + 8a b c)d e x
+--R           + 
+--R                    2 2        2   2     2          3  2 2
+--R             ((- 36a c  + 12a b c)d  - 7a b c + 2a b )e x
+--R           + 
+--R                    2 2       2   3         2          3
+--R             ((- 24a c  + 8a b c)d  + (- 14a b c + 4a b )d)e x
+--R           + 
+--R                  2 2       2   4        2          3  2     3     2 2
+--R             (- 6a c  + 2a b c)d  + (- 7a b c + 2a b )d  - 4a c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R              4 2     3 2   7 3 6       4 2      3 2     6 3 5
+--R           (8a c  - 2a b c)e f x  + (48a c  - 12a b c)d e f x
+--R         + 
+--R                 4 2      3 2   2     4        3 3  5 3 4
+--R           ((120a c  - 30a b c)d  + 8a b c - 2a b )e f x
+--R         + 
+--R                 4 2      3 2   3       4        3 3    4 3 3
+--R           ((160a c  - 40a b c)d  + (32a b c - 8a b )d)e f x
+--R         + 
+--R                 4 2      3 2   4       4         3 3  2     5      4 2  3 3 2
+--R           ((120a c  - 30a b c)d  + (48a b c - 12a b )d  + 8a c - 2a b )e f x
+--R         + 
+--R                4 2      3 2   5       4        3 3  3       5      4 2    2 3
+--R           ((48a c  - 12a b c)d  + (32a b c - 8a b )d  + (16a c - 4a b )d)e f x
+--R         + 
+--R               4 2     3 2   6      4        3 3  4      5      4 2  2    3
+--R           ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d )e f
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2 3        2 2     4   6 6
+--R             (- 12a c  + 12a b c  - 2b c)e x
+--R           + 
+--R                   2 3        2 2      4     5 5
+--R             (- 72a c  + 72a b c  - 12b c)d e x
+--R           + 
+--R                     2 3         2 2      4   2      2   2        3      5  4 4
+--R             ((- 180a c  + 180a b c  - 30b c)d  - 12a b c  + 12a b c - 2b )e x
+--R           + 
+--R                          2 3         2 2      4   3
+--R                   (- 240a c  + 240a b c  - 40b c)d
+--R                 + 
+--R                         2   2        3      5
+--R                   (- 48a b c  + 48a b c - 8b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                        2 3         2 2      4   4
+--R                 (- 180a c  + 180a b c  - 30b c)d
+--R               + 
+--R                       2   2        3       5  2      3 2      2 2        4
+--R                 (- 72a b c  + 72a b c - 12b )d  - 12a c  + 12a b c - 2a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                       2 3        2 2      4   5
+--R                 (- 72a c  + 72a b c  - 12b c)d
+--R               + 
+--R                       2   2        3      5  3         3 2      2 2        4
+--R                 (- 48a b c  + 48a b c - 8b )d  + (- 24a c  + 24a b c - 4a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   2 3        2 2     4   6         2   2        3      5  4
+--R             (- 12a c  + 12a b c  - 2b c)d  + (- 12a b c  + 12a b c - 2b )d
+--R           + 
+--R                   3 2      2 2        4  2
+--R             (- 12a c  + 12a b c - 2a b )d
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                        2    3   6 6           2     3     5 5
+--R                 (4a b c  - b c)e x  + (24a b c  - 6b c)d e x
+--R               + 
+--R                          2      3   2       2     4  4 4
+--R                 ((60a b c  - 15b c)d  + 4a b c - b )e x
+--R               + 
+--R                          2      3   3         2      4    3 3
+--R                 ((80a b c  - 20b c)d  + (16a b c - 4b )d)e x
+--R               + 
+--R                          2      3   4         2      4  2     2         3  2 2
+--R                 ((60a b c  - 15b c)d  + (24a b c - 6b )d  + 4a b c - a b )e x
+--R               + 
+--R                            2     3   5         2      4  3      2          3
+--R                   ((24a b c  - 6b c)d  + (16a b c - 4b )d  + (8a b c - 2a b )d)
+--R                *
+--R                   e x
+--R               + 
+--R                        2    3   6        2     4  4      2         3  2
+--R                 (4a b c  - b c)d  + (4a b c - b )d  + (4a b c - a b )d
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                           2     3   6 6             2      3     5 5
+--R                 (- 16a b c  + 4b c)e x  + (- 96a b c  + 24b c)d e x
+--R               + 
+--R                             2      3   2        2      4  4 4
+--R                 ((- 240a b c  + 60b c)d  - 16a b c + 4b )e x
+--R               + 
+--R                             2      3   3           2       4    3 3
+--R                 ((- 320a b c  + 80b c)d  + (- 64a b c + 16b )d)e x
+--R               + 
+--R                                2      3   4           2       4  2      2
+--R                     (- 240a b c  + 60b c)d  + (- 96a b c + 24b )d  - 16a b c
+--R                   + 
+--R                         3
+--R                     4a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                               2      3   5           2       4  3
+--R                     (- 96a b c  + 24b c)d  + (- 64a b c + 16b )d
+--R                   + 
+--R                           2          3
+--R                     (- 32a b c + 8a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)d  + (- 16a b c + 4b )d
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )d
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                  2 2       2   4 4         2 2       2     3 3
+--R             (- 6a c  + 2a b c)e x  + (- 24a c  + 8a b c)d e x
+--R           + 
+--R                    2 2        2   2     2          3  2 2
+--R             ((- 36a c  + 12a b c)d  - 7a b c + 2a b )e x
+--R           + 
+--R                    2 2       2   3         2          3
+--R             ((- 24a c  + 8a b c)d  + (- 14a b c + 4a b )d)e x
+--R           + 
+--R                  2 2       2   4        2          3  2     3     2 2
+--R             (- 6a c  + 2a b c)d  + (- 7a b c + 2a b )d  - 4a c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R              4 2     3 2   7 3 6       4 2      3 2     6 3 5
+--R           (8a c  - 2a b c)e f x  + (48a c  - 12a b c)d e f x
+--R         + 
+--R                 4 2      3 2   2     4        3 3  5 3 4
+--R           ((120a c  - 30a b c)d  + 8a b c - 2a b )e f x
+--R         + 
+--R                 4 2      3 2   3       4        3 3    4 3 3
+--R           ((160a c  - 40a b c)d  + (32a b c - 8a b )d)e f x
+--R         + 
+--R                 4 2      3 2   4       4         3 3  2     5      4 2  3 3 2
+--R           ((120a c  - 30a b c)d  + (48a b c - 12a b )d  + 8a c - 2a b )e f x
+--R         + 
+--R                4 2      3 2   5       4        3 3  3       5      4 2    2 3
+--R           ((48a c  - 12a b c)d  + (32a b c - 8a b )d  + (16a c - 4a b )d)e f x
+--R         + 
+--R               4 2     3 2   6      4        3 3  4      5      4 2  2    3
+--R           ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d )e f
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 995
+
+--S 996 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (6a c  - 6a b c + b )
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                                           2 2                  2
+--R             2 2        2      4       2c e x  + 4c d e x + 2c d  + b
+--R       (- 12a c  + 12a b c - 2b )atanh(------------------------------)
+--R                                                +-----------+
+--R                                                |          2
+--R                                               \|- 4a c + b
+--R  /
+--R                        +-----------+
+--R        4      3 2    3 |          2
+--R     (8a c - 2a b )e f \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 996
+
+--S 997 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                               +---------+          2 2                  2
+--R            2 2       2     4  |        2       2c e x  + 4c d e x + 2c d  + b
+--R       (- 6a c  + 6a b c - b )\|4a c - b  atanh(------------------------------)
+--R                                                         +-----------+
+--R                                                         |          2
+--R                                                        \|- 4a c + b
+--R     + 
+--R                                 +-----------+
+--R              2 2       2     4  |          2
+--R         (- 6a c  + 6a b c - b )\|- 4a c + b
+--R      *
+--R                                               +---------+
+--R                   2 2                  2      |        2
+--R              (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R  /
+--R                       +-----------+ +---------+
+--R        4     3 2    3 |          2  |        2
+--R     (4a c - a b )e f \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 998
+
+--S 999 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 999
+
+)clear all
+
+--S 1000 of 1057
+t0:=1/((d*f+e*f*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 12 4 12      2   11 4 11       2 2         10 4 10
+--R       c e  f x   + 12c d e  f x   + (66c d  + 2b c)e  f x
+--R     + 
+--R            2 3            9 4 9        2 4          2           2  8 4 8
+--R       (220c d  + 20b c d)e f x  + (495c d  + 90b c d  + 2a c + b )e f x
+--R     + 
+--R            2 5           3              2    7 4 7
+--R       (792c d  + 240b c d  + (16a c + 8b )d)e f x
+--R     + 
+--R            2 6           4               2  2         6 4 6
+--R       (924c d  + 420b c d  + (56a c + 28b )d  + 2a b)e f x
+--R     + 
+--R            2 7           5                2  3            5 4 5
+--R       (792c d  + 504b c d  + (112a c + 56b )d  + 12a b d)e f x
+--R     + 
+--R            2 8           6                2  4          2    2  4 4 4
+--R       (495c d  + 420b c d  + (140a c + 70b )d  + 30a b d  + a )e f x
+--R     + 
+--R            2 9           7                2  5          3     2   3 4 3
+--R       (220c d  + 240b c d  + (112a c + 56b )d  + 40a b d  + 4a d)e f x
+--R     + 
+--R           2 10          8               2  6          4     2 2  2 4 2
+--R       (66c d   + 90b c d  + (56a c + 28b )d  + 30a b d  + 6a d )e f x
+--R     + 
+--R           2 11          9              2  7          5     2 3    4
+--R       (12c d   + 20b c d  + (16a c + 8b )d  + 12a b d  + 4a d )e f x
+--R     + 
+--R         2 12         10            2  8         6    2 4  4
+--R       (c d   + 2b c d   + (2a c + b )d  + 2a b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1000
+
+--S 1001 of 1057
+r0:=1/6*(-5*b^2+14*a*c)/(a^2*(b^2-4*a*c)*e*f^4*(d+e*x)^3)+1/2*b*(5*b^2-_
+   19*a*c)/(a^3*(b^2-4*a*c)*e*f^4*(d+e*x))+1/2*(b^2-2*a*c+b*c*(d+e*x)^2)/_
+   (a*(b^2-4*a*c)*e*f^4*(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (5*b^3-19*a*b*c+(5*b^4-29*a*b^2*c+28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*_
+   (b^2-4*a*c)*e*f^4*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan((d+e*x)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(5*b^3-19*a*b*c+_
+   (-5*b^4+29*a*b^2*c-28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*_
+   e*f^4*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       2      3   7 7            2       3     6 6
+--R               (57a b c  - 15b c)e x  + (399a b c  - 105b c)d e x
+--R             + 
+--R                          2       3   2        2       4  5 5
+--R               ((1197a b c  - 315b c)d  + 57a b c - 15b )e x
+--R             + 
+--R                          2       3   3          2       4    4 4
+--R               ((1995a b c  - 525b c)d  + (285a b c - 75b )d)e x
+--R             + 
+--R                             2       3   4          2        4  2      2
+--R                   (1995a b c  - 525b c)d  + (570a b c - 150b )d  + 57a b c
+--R                 + 
+--R                          3
+--R                   - 15a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                             2       3   5          2        4  3
+--R                   (1197a b c  - 315b c)d  + (570a b c - 150b )d
+--R                 + 
+--R                        2           3
+--R                   (171a b c - 45a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                            2       3   6          2       4  4
+--R                   (399a b c  - 105b c)d  + (285a b c - 75b )d
+--R                 + 
+--R                        2           3  2
+--R                   (171a b c - 45a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2      3   7         2       4  5       2           3  3
+--R               (57a b c  - 15b c)d  + (57a b c - 15b )d  + (57a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 3        2 2      4   7 7
+--R           (- 84a c  + 87a b c  - 15b c)e x
+--R         + 
+--R                  2 3         2 2       4     6 6
+--R           (- 588a c  + 609a b c  - 105b c)d e x
+--R         + 
+--R                      2 3          2 2       4   2      2   2        3       5
+--R             ((- 1764a c  + 1827a b c  - 315b c)d  - 84a b c  + 87a b c - 15b )
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   3
+--R               (- 2940a c  + 3045a b c  - 525b c)d
+--R             + 
+--R                      2   2         3       5
+--R               (- 420a b c  + 435a b c - 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   4
+--R               (- 2940a c  + 3045a b c  - 525b c)d
+--R             + 
+--R                      2   2         3        5  2      3 2      2 2         4
+--R               (- 840a b c  + 870a b c - 150b )d  - 84a c  + 87a b c - 15a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   5
+--R               (- 1764a c  + 1827a b c  - 315b c)d
+--R             + 
+--R                      2   2         3        5  3
+--R               (- 840a b c  + 870a b c - 150b )d
+--R             + 
+--R                      3 2       2 2         4
+--R               (- 252a c  + 261a b c - 45a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      2 3         2 2       4   6
+--R               (- 588a c  + 609a b c  - 105b c)d
+--R             + 
+--R                      2   2         3       5  4
+--R               (- 420a b c  + 435a b c - 75b )d
+--R             + 
+--R                      3 2       2 2         4  2
+--R               (- 252a c  + 261a b c - 45a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2 3        2 2      4   7         2   2        3       5  5
+--R           (- 84a c  + 87a b c  - 15b c)d  + (- 84a b c  + 87a b c - 15b )d
+--R         + 
+--R                 3 2      2 2         4  3
+--R           (- 84a c  + 87a b c - 15a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                       2      3   7 7            2       3     6 6
+--R               (57a b c  - 15b c)e x  + (399a b c  - 105b c)d e x
+--R             + 
+--R                          2       3   2        2       4  5 5
+--R               ((1197a b c  - 315b c)d  + 57a b c - 15b )e x
+--R             + 
+--R                          2       3   3          2       4    4 4
+--R               ((1995a b c  - 525b c)d  + (285a b c - 75b )d)e x
+--R             + 
+--R                             2       3   4          2        4  2      2
+--R                   (1995a b c  - 525b c)d  + (570a b c - 150b )d  + 57a b c
+--R                 + 
+--R                          3
+--R                   - 15a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                             2       3   5          2        4  3
+--R                   (1197a b c  - 315b c)d  + (570a b c - 150b )d
+--R                 + 
+--R                        2           3
+--R                   (171a b c - 45a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                            2       3   6          2       4  4
+--R                   (399a b c  - 105b c)d  + (285a b c - 75b )d
+--R                 + 
+--R                        2           3  2
+--R                   (171a b c - 45a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2      3   7         2       4  5       2           3  3
+--R               (57a b c  - 15b c)d  + (57a b c - 15b )d  + (57a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 3        2 2      4   7 7
+--R           (84a c  - 87a b c  + 15b c)e x
+--R         + 
+--R                2 3         2 2       4     6 6
+--R           (588a c  - 609a b c  + 105b c)d e x
+--R         + 
+--R                  2 3          2 2       4   2      2   2        3       5  5 5
+--R           ((1764a c  - 1827a b c  + 315b c)d  + 84a b c  - 87a b c + 15b )e x
+--R         + 
+--R                       2 3          2 2       4   3
+--R                 (2940a c  - 3045a b c  + 525b c)d
+--R               + 
+--R                      2   2         3       5
+--R                 (420a b c  - 435a b c + 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2 3          2 2       4   4
+--R               (2940a c  - 3045a b c  + 525b c)d
+--R             + 
+--R                    2   2         3        5  2      3 2      2 2         4
+--R               (840a b c  - 870a b c + 150b )d  + 84a c  - 87a b c + 15a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2 3          2 2       4   5
+--R               (1764a c  - 1827a b c  + 315b c)d
+--R             + 
+--R                  2   2         3        5  3        3 2       2 2         4
+--R             (840a b c  - 870a b c + 150b )d  + (252a c  - 261a b c + 45a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                    2 3         2 2       4   6
+--R               (588a c  - 609a b c  + 105b c)d
+--R             + 
+--R                  2   2         3       5  4        3 2       2 2         4  2
+--R             (420a b c  - 435a b c + 75b )d  + (252a c  - 261a b c + 45a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2 3        2 2      4   7       2   2        3       5  5
+--R           (84a c  - 87a b c  + 15b c)d  + (84a b c  - 87a b c + 15b )d
+--R         + 
+--R               3 2      2 2         4  3
+--R           (84a c  - 87a b c + 15a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2      3   6 6            2      3     5 5
+--R           (57a b c  - 15b c)e x  + (342a b c  - 90b c)d e x
+--R         + 
+--R                     2       3   2      2 2        2       4  4 4
+--R           ((855a b c  - 225b c)d  - 14a c  + 62a b c - 15b )e x
+--R         + 
+--R                      2       3   3         2 2         2       4    3 3
+--R           ((1140a b c  - 300b c)d  + (- 56a c  + 248a b c - 60b )d)e x
+--R         + 
+--R                        2       3   4         2 2         2       4  2      2
+--R               (855a b c  - 225b c)d  + (- 84a c  + 372a b c - 90b )d  + 40a b c
+--R             + 
+--R                      3
+--R               - 10a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        2      3   5         2 2         2       4  3
+--R               (342a b c  - 90b c)d  + (- 56a c  + 248a b c - 60b )d
+--R             + 
+--R                   2           3
+--R               (80a b c - 20a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   2      3   6         2 2        2       4  4
+--R           (57a b c  - 15b c)d  + (- 14a c  + 62a b c - 15b )d
+--R         + 
+--R               2           3  2     3      2 2
+--R           (40a b c - 10a b )d  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R             4 2     3 2   8 4 7        4 2      3 2     7 4 6
+--R         (24a c  - 6a b c)e f x  + (168a c  - 42a b c)d e f x
+--R       + 
+--R               4 2       3 2   2      4        3 3  6 4 5
+--R         ((504a c  - 126a b c)d  + 24a b c - 6a b )e f x
+--R       + 
+--R               4 2       3 2   3        4         3 3    5 4 4
+--R         ((840a c  - 210a b c)d  + (120a b c - 30a b )d)e f x
+--R       + 
+--R               4 2       3 2   4        4         3 3  2      5      4 2  4 4 3
+--R         ((840a c  - 210a b c)d  + (240a b c - 60a b )d  + 24a c - 6a b )e f x
+--R       + 
+--R                 4 2       3 2   5        4         3 3  3       5       4 2
+--R           ((504a c  - 126a b c)d  + (240a b c - 60a b )d  + (72a c - 18a b )d)
+--R        *
+--R            3 4 2
+--R           e f x
+--R       + 
+--R                 4 2      3 2   6        4         3 3  4       5       4 2  2
+--R           ((168a c  - 42a b c)d  + (120a b c - 30a b )d  + (72a c - 18a b )d )
+--R        *
+--R            2 4
+--R           e f x
+--R       + 
+--R              4 2     3 2   7       4        3 3  5       5      4 2  3    4
+--R         ((24a c  - 6a b c)d  + (24a b c - 6a b )d  + (24a c - 6a b )d )e f
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1001
+
+--S 1002 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 4 2     3 2   8 4 7         4 2      3 2     7 4 6
+--R           (- 12a c  + 3a b c)e f x  + (- 84a c  + 21a b c)d e f x
+--R         + 
+--R                   4 2      3 2   2      4        3 3  6 4 5
+--R           ((- 252a c  + 63a b c)d  - 12a b c + 3a b )e f x
+--R         + 
+--R                   4 2       3 2   3         4         3 3    5 4 4
+--R           ((- 420a c  + 105a b c)d  + (- 60a b c + 15a b )d)e f x
+--R         + 
+--R                        4 2       3 2   4          4         3 3  2      5
+--R                 (- 420a c  + 105a b c)d  + (- 120a b c + 30a b )d  - 12a c
+--R               + 
+--R                   4 2
+--R                 3a b
+--R          *
+--R              4 4 3
+--R             e f x
+--R         + 
+--R                      4 2      3 2   5          4         3 3  3
+--R               (- 252a c  + 63a b c)d  + (- 120a b c + 30a b )d
+--R             + 
+--R                     5      4 2
+--R               (- 36a c + 9a b )d
+--R          *
+--R              3 4 2
+--R             e f x
+--R         + 
+--R                     4 2      3 2   6         4         3 3  4
+--R               (- 84a c  + 21a b c)d  + (- 60a b c + 15a b )d
+--R             + 
+--R                     5      4 2  2
+--R               (- 36a c + 9a b )d
+--R          *
+--R              2 4
+--R             e f x
+--R         + 
+--R                       4 2     3 2   7         4        3 3  5
+--R                 (- 12a c  + 3a b c)d  + (- 12a b c + 3a b )d
+--R               + 
+--R                       5      4 2  3
+--R                 (- 12a c + 3a b )d
+--R          *
+--R                4
+--R             e f
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6  2 8
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )e f
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4 16
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2 8
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                  17 3         16 2 2        15 4        14 6  4
+--R                           (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                        *
+--R                            16
+--R                           f
+--R                + 
+--R                            7 7         6 2 6          5 4 5          4 6 4
+--R                      10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                    + 
+--R                            3 8 3         2 10 2          12        14
+--R                      75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6  2 8
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2 8
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R               4 2     3 2   8 4 7       4 2      3 2     7 4 6
+--R           (12a c  - 3a b c)e f x  + (84a c  - 21a b c)d e f x
+--R         + 
+--R                 4 2      3 2   2      4        3 3  6 4 5
+--R           ((252a c  - 63a b c)d  + 12a b c - 3a b )e f x
+--R         + 
+--R                 4 2       3 2   3       4         3 3    5 4 4
+--R           ((420a c  - 105a b c)d  + (60a b c - 15a b )d)e f x
+--R         + 
+--R                   4 2       3 2   4        4         3 3  2      5      4 2  4
+--R             ((420a c  - 105a b c)d  + (120a b c - 30a b )d  + 12a c - 3a b )e
+--R          *
+--R              4 3
+--R             f x
+--R         + 
+--R                   4 2      3 2   5        4         3 3  3       5      4 2
+--R             ((252a c  - 63a b c)d  + (120a b c - 30a b )d  + (36a c - 9a b )d)
+--R          *
+--R              3 4 2
+--R             e f x
+--R         + 
+--R                  4 2      3 2   6       4         3 3  4       5      4 2  2  2
+--R             ((84a c  - 21a b c)d  + (60a b c - 15a b )d  + (36a c - 9a b )d )e
+--R          *
+--R              4
+--R             f x
+--R         + 
+--R                4 2     3 2   7       4        3 3  5       5      4 2  3    4
+--R           ((12a c  - 3a b c)d  + (12a b c - 3a b )d  + (12a c - 3a b )d )e f
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6  2 8
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )e f
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4 16
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2 8
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                  17 3         16 2 2        15 4        14 6  4
+--R                           (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                        *
+--R                            16
+--R                           f
+--R                + 
+--R                              7 7         6 2 6          5 4 5          4 6 4
+--R                      - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                    + 
+--R                              3 8 3         2 10 2          12        14
+--R                      - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6  2 8
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2 8
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R                 4 2     3 2   8 4 7         4 2      3 2     7 4 6
+--R           (- 12a c  + 3a b c)e f x  + (- 84a c  + 21a b c)d e f x
+--R         + 
+--R                   4 2      3 2   2      4        3 3  6 4 5
+--R           ((- 252a c  + 63a b c)d  - 12a b c + 3a b )e f x
+--R         + 
+--R                   4 2       3 2   3         4         3 3    5 4 4
+--R           ((- 420a c  + 105a b c)d  + (- 60a b c + 15a b )d)e f x
+--R         + 
+--R                        4 2       3 2   4          4         3 3  2      5
+--R                 (- 420a c  + 105a b c)d  + (- 120a b c + 30a b )d  - 12a c
+--R               + 
+--R                   4 2
+--R                 3a b
+--R          *
+--R              4 4 3
+--R             e f x
+--R         + 
+--R                      4 2      3 2   5          4         3 3  3
+--R               (- 252a c  + 63a b c)d  + (- 120a b c + 30a b )d
+--R             + 
+--R                     5      4 2
+--R               (- 36a c + 9a b )d
+--R          *
+--R              3 4 2
+--R             e f x
+--R         + 
+--R                     4 2      3 2   6         4         3 3  4
+--R               (- 84a c  + 21a b c)d  + (- 60a b c + 15a b )d
+--R             + 
+--R                     5      4 2  2
+--R               (- 36a c + 9a b )d
+--R          *
+--R              2 4
+--R             e f x
+--R         + 
+--R                       4 2     3 2   7         4        3 3  5
+--R                 (- 12a c  + 3a b c)d  + (- 12a b c + 3a b )d
+--R               + 
+--R                       5      4 2  3
+--R                 (- 12a c + 3a b )d
+--R          *
+--R                4
+--R             e f
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6  2 8
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )e f
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4 16
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2 8
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                  17 3         16 2 2        15 4        14 6  4
+--R                           (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                        *
+--R                            16
+--R                           f
+--R                + 
+--R                            7 7         6 2 6          5 4 5          4 6 4
+--R                      10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                    + 
+--R                            3 8 3         2 10 2          12        14
+--R                      75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6  2 8
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2 8
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R               4 2     3 2   8 4 7       4 2      3 2     7 4 6
+--R           (12a c  - 3a b c)e f x  + (84a c  - 21a b c)d e f x
+--R         + 
+--R                 4 2      3 2   2      4        3 3  6 4 5
+--R           ((252a c  - 63a b c)d  + 12a b c - 3a b )e f x
+--R         + 
+--R                 4 2       3 2   3       4         3 3    5 4 4
+--R           ((420a c  - 105a b c)d  + (60a b c - 15a b )d)e f x
+--R         + 
+--R                   4 2       3 2   4        4         3 3  2      5      4 2  4
+--R             ((420a c  - 105a b c)d  + (120a b c - 30a b )d  + 12a c - 3a b )e
+--R          *
+--R              4 3
+--R             f x
+--R         + 
+--R                   4 2      3 2   5        4         3 3  3       5      4 2
+--R             ((252a c  - 63a b c)d  + (120a b c - 30a b )d  + (36a c - 9a b )d)
+--R          *
+--R              3 4 2
+--R             e f x
+--R         + 
+--R                  4 2      3 2   6       4         3 3  4       5      4 2  2  2
+--R             ((84a c  - 21a b c)d  + (60a b c - 15a b )d  + (36a c - 9a b )d )e
+--R          *
+--R              4
+--R             f x
+--R         + 
+--R                4 2     3 2   7       4        3 3  5       5      4 2  3    4
+--R           ((12a c  - 3a b c)d  + (12a b c - 3a b )d  + (12a c - 3a b )d )e f
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6  2 8
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )e f
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4 16
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2 8
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                  17 3         16 2 2        15 4        14 6  4
+--R                           (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                        *
+--R                            16
+--R                           f
+--R                + 
+--R                              7 7         6 2 6          5 4 5          4 6 4
+--R                      - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                    + 
+--R                              3 8 3         2 10 2          12        14
+--R                      - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6  2 8
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2 8
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R               2      3   6 6            2      3     5 5
+--R       (57a b c  - 15b c)e x  + (342a b c  - 90b c)d e x
+--R     + 
+--R                 2       3   2      2 2        2       4  4 4
+--R       ((855a b c  - 225b c)d  - 14a c  + 62a b c - 15b )e x
+--R     + 
+--R                  2       3   3         2 2         2       4    3 3
+--R       ((1140a b c  - 300b c)d  + (- 56a c  + 248a b c - 60b )d)e x
+--R     + 
+--R                    2       3   4         2 2         2       4  2      2
+--R           (855a b c  - 225b c)d  + (- 84a c  + 372a b c - 90b )d  + 40a b c
+--R         + 
+--R                  3
+--R           - 10a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R                    2      3   5         2 2         2       4  3
+--R           (342a b c  - 90b c)d  + (- 56a c  + 248a b c - 60b )d
+--R         + 
+--R               2           3
+--R           (80a b c - 20a b )d
+--R      *
+--R         e x
+--R     + 
+--R               2      3   6         2 2        2       4  4
+--R       (57a b c  - 15b c)d  + (- 14a c  + 62a b c - 15b )d
+--R     + 
+--R           2           3  2     3      2 2
+--R       (40a b c - 10a b )d  - 8a c + 2a b
+--R  /
+--R           4 2     3 2   8 4 7        4 2      3 2     7 4 6
+--R       (24a c  - 6a b c)e f x  + (168a c  - 42a b c)d e f x
+--R     + 
+--R             4 2       3 2   2      4        3 3  6 4 5
+--R       ((504a c  - 126a b c)d  + 24a b c - 6a b )e f x
+--R     + 
+--R             4 2       3 2   3        4         3 3    5 4 4
+--R       ((840a c  - 210a b c)d  + (120a b c - 30a b )d)e f x
+--R     + 
+--R             4 2       3 2   4        4         3 3  2      5      4 2  4 4 3
+--R       ((840a c  - 210a b c)d  + (240a b c - 60a b )d  + 24a c - 6a b )e f x
+--R     + 
+--R               4 2       3 2   5        4         3 3  3       5       4 2    3
+--R         ((504a c  - 126a b c)d  + (240a b c - 60a b )d  + (72a c - 18a b )d)e
+--R      *
+--R          4 2
+--R         f x
+--R     + 
+--R             4 2      3 2   6        4         3 3  4       5       4 2  2  2 4
+--R       ((168a c  - 42a b c)d  + (120a b c - 30a b )d  + (72a c - 18a b )d )e f x
+--R     + 
+--R            4 2     3 2   7       4        3 3  5       5      4 2  3    4
+--R       ((24a c  - 6a b c)d  + (24a b c - 6a b )d  + (24a c - 6a b )d )e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 1002
+
+--S 1003 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +--------------------+
+--R                                 +-----------+ |   +-----------+
+--R              4     3 2    4 +-+ |          2  |   |          2
+--R         (- 4a c + a b )e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6  2 8
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )e f
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4 16
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2 8
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                  17 3         16 2 2        15 4        14 6  4
+--R                           (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                        *
+--R                            16
+--R                           f
+--R                + 
+--R                            7 7         6 2 6          5 4 5          4 6 4
+--R                      10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                    + 
+--R                            3 8 3         2 10 2          12        14
+--R                      75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6  2 8
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2 8
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R                               +-----------+
+--R            4     3 2    4 +-+ |          2
+--R         (4a c - a b )e f \|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6  2 8
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )e f
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4 16
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2 8
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                  17 3         16 2 2        15 4        14 6  4
+--R                           (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                        *
+--R                            16
+--R                           f
+--R                + 
+--R                              7 7         6 2 6          5 4 5          4 6 4
+--R                      - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                    + 
+--R                              3 8 3         2 10 2          12        14
+--R                      - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6  2 8
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2 8
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R                                 +-----------+
+--R              4     3 2    4 +-+ |          2
+--R         (- 4a c + a b )e f \|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6  2 8
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )e f
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4 16
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2 8
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                  17 3         16 2 2        15 4        14 6  4
+--R                           (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                        *
+--R                            16
+--R                           f
+--R                + 
+--R                            7 7         6 2 6          5 4 5          4 6 4
+--R                      10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                    + 
+--R                            3 8 3         2 10 2          12        14
+--R                      75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6  2 8
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2 8
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R                                             +--------------------+
+--R                               +-----------+ |   +-----------+
+--R            4     3 2    4 +-+ |          2  |   |          2
+--R         (4a c - a b )e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6  2 8
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )e f
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                              17 3         16 2 2        15 4        14 6  4 16
+--R                       (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e f
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                   10 3       9 2 2      8 4      7 6  2 8
+--R              (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                                  17 3         16 2 2        15 4        14 6  4
+--R                           (16384a  c  - 12288a  b c  + 3072a  b c - 256a  b )e
+--R                        *
+--R                            16
+--R                           f
+--R                + 
+--R                              7 7         6 2 6          5 4 5          4 6 4
+--R                      - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                    + 
+--R                              3 8 3         2 10 2          12        14
+--R                      - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6  2 8
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )e f
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                        17 3         16 2 2        15 4
+--R                                  16384a  c  - 12288a  b c  + 3072a  b c
+--R                                + 
+--R                                        14 6
+--R                                  - 256a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                          10 3       9 2 2      8 4      7 6  2 8
+--R                     (512a  c  - 384a b c  + 96a b c - 8a b )e f
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )e x
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )d
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4  +-+
+--R         ((- 19a b c + 5b )\|- 4a c + b   + 28a c  - 29a b c + 5b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                       +-+ +-+
+--R          | |          2              (e x + d)\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4  +-+
+--R         ((- 19a b c + 5b )\|- 4a c + b   - 28a c  + 29a b c - 5b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                            +--------------------+
+--R                              +-----------+ |   +-----------+
+--R          4      3 2    4 +-+ |          2  |   |          2
+--R       (8a c - 2a b )e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1003
+
+--S 1004 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1004
+
+)clear all
+
+--S 1005 of 1057
+t0:=(d*f+e*f*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      4 4 4       3 4 3     2 2 4 2     3   4     4 4
+--R     e f x  + 4d e f x  + 6d e f x  + 4d e f x + d f
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1005
+
+--S 1006 of 1057
+r0:=1/4*f^4*(d+e*x)*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)-1/8*f^4*(d+e*x)*(7*b^2-4*a*c+12*b*c*(d+e*x)^2)/((b^2-_
+   4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+3/4*f^4*atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2+4*a*c-2*b*sqrt(b^2-_
+   4*a*c))/((b^2-4*a*c)^(5/2)*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   3/4*f^4*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (3*b^2+4*a*c+2*b*sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2 8 4 8        2   7 4 7            2 2      2   6 4 6
+--R               - 12b c e f x  - 96b c d e f x  + (- 336b c d  - 24b c)e f x
+--R             + 
+--R                        2 3       2     5 4 5
+--R               (- 672b c d  - 144b c d)e f x
+--R             + 
+--R                        2 4       2   2                3  4 4 4
+--R               (- 840b c d  - 360b c d  - 24a b c - 12b )e f x
+--R             + 
+--R                        2 5       2   3                   3    3 4 3
+--R               (- 672b c d  - 480b c d  + (- 96a b c - 48b )d)e f x
+--R             + 
+--R                        2 6       2   4                    3  2        2  2 4 2
+--R               (- 336b c d  - 360b c d  + (- 144a b c - 72b )d  - 24a b )e f x
+--R             + 
+--R                       2 7       2   5                   3  3        2     4
+--R               (- 96b c d  - 144b c d  + (- 96a b c - 48b )d  - 48a b d)e f x
+--R             + 
+--R                     2 8      2   6                   3  4        2 2      2   4
+--R             (- 12b c d  - 24b c d  + (- 24a b c - 12b )d  - 24a b d  - 12a b)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8 4 8          3       2 2    7 4 7
+--R           (24a c  + 18b c )e f x  + (192a c  + 144b c )d e f x
+--R         + 
+--R                   3       2 2  2          2      3   6 4 6
+--R           ((672a c  + 504b c )d  + 48a b c  + 36b c)e f x
+--R         + 
+--R                    3        2 2  3            2       3     5 4 5
+--R           ((1344a c  + 1008b c )d  + (288a b c  + 216b c)d)e f x
+--R         + 
+--R                       3        2 2  4            2       3   2      2 2
+--R               (1680a c  + 1260b c )d  + (720a b c  + 540b c)d  + 48a c
+--R             + 
+--R                    2       4
+--R               60a b c + 18b
+--R          *
+--R              4 4 4
+--R             e f x
+--R         + 
+--R                       3        2 2  5            2       3   3
+--R               (1344a c  + 1008b c )d  + (960a b c  + 720b c)d
+--R             + 
+--R                    2 2         2       4
+--R               (192a c  + 240a b c + 72b )d
+--R          *
+--R              3 4 3
+--R             e f x
+--R         + 
+--R                      3       2 2  6            2       3   4
+--R               (672a c  + 504b c )d  + (720a b c  + 540b c)d
+--R             + 
+--R                    2 2         2        4  2      2           3
+--R               (288a c  + 360a b c + 108b )d  + 48a b c + 36a b
+--R          *
+--R              2 4 2
+--R             e f x
+--R         + 
+--R                      3       2 2  7            2       3   5
+--R               (192a c  + 144b c )d  + (288a b c  + 216b c)d
+--R             + 
+--R                    2 2         2       4  3       2           3
+--R               (192a c  + 240a b c + 72b )d  + (96a b c + 72a b )d
+--R          *
+--R                4
+--R             e f x
+--R         + 
+--R                     3      2 2  8           2      3   6
+--R               (24a c  + 18b c )d  + (48a b c  + 36b c)d
+--R             + 
+--R                 2 2        2       4  4       2           3  2      3       2 2
+--R             (48a c  + 60a b c + 18b )d  + (48a b c + 36a b )d  + 24a c + 18a b
+--R          *
+--R              4
+--R             f
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2 8 4 8        2   7 4 7            2 2      2   6 4 6
+--R               - 12b c e f x  - 96b c d e f x  + (- 336b c d  - 24b c)e f x
+--R             + 
+--R                        2 3       2     5 4 5
+--R               (- 672b c d  - 144b c d)e f x
+--R             + 
+--R                        2 4       2   2                3  4 4 4
+--R               (- 840b c d  - 360b c d  - 24a b c - 12b )e f x
+--R             + 
+--R                        2 5       2   3                   3    3 4 3
+--R               (- 672b c d  - 480b c d  + (- 96a b c - 48b )d)e f x
+--R             + 
+--R                        2 6       2   4                    3  2        2  2 4 2
+--R               (- 336b c d  - 360b c d  + (- 144a b c - 72b )d  - 24a b )e f x
+--R             + 
+--R                       2 7       2   5                   3  3        2     4
+--R               (- 96b c d  - 144b c d  + (- 96a b c - 48b )d  - 48a b d)e f x
+--R             + 
+--R                     2 8      2   6                   3  4        2 2      2   4
+--R             (- 12b c d  - 24b c d  + (- 24a b c - 12b )d  - 24a b d  - 12a b)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8 4 8            3       2 2    7 4 7
+--R           (- 24a c  - 18b c )e f x  + (- 192a c  - 144b c )d e f x
+--R         + 
+--R                     3       2 2  2          2      3   6 4 6
+--R           ((- 672a c  - 504b c )d  - 48a b c  - 36b c)e f x
+--R         + 
+--R                      3        2 2  3              2       3     5 4 5
+--R           ((- 1344a c  - 1008b c )d  + (- 288a b c  - 216b c)d)e f x
+--R         + 
+--R                         3        2 2  4              2       3   2      2 2
+--R               (- 1680a c  - 1260b c )d  + (- 720a b c  - 540b c)d  - 48a c
+--R             + 
+--R                      2       4
+--R               - 60a b c - 18b
+--R          *
+--R              4 4 4
+--R             e f x
+--R         + 
+--R                         3        2 2  5              2       3   3
+--R               (- 1344a c  - 1008b c )d  + (- 960a b c  - 720b c)d
+--R             + 
+--R                      2 2         2       4
+--R               (- 192a c  - 240a b c - 72b )d
+--R          *
+--R              3 4 3
+--R             e f x
+--R         + 
+--R                        3       2 2  6              2       3   4
+--R               (- 672a c  - 504b c )d  + (- 720a b c  - 540b c)d
+--R             + 
+--R                      2 2         2        4  2      2           3
+--R               (- 288a c  - 360a b c - 108b )d  - 48a b c - 36a b
+--R          *
+--R              2 4 2
+--R             e f x
+--R         + 
+--R                        3       2 2  7              2       3   5
+--R               (- 192a c  - 144b c )d  + (- 288a b c  - 216b c)d
+--R             + 
+--R                      2 2         2       4  3         2           3
+--R               (- 192a c  - 240a b c - 72b )d  + (- 96a b c - 72a b )d
+--R          *
+--R                4
+--R             e f x
+--R         + 
+--R                       3      2 2  8             2      3   6
+--R               (- 24a c  - 18b c )d  + (- 48a b c  - 36b c)d
+--R             + 
+--R                     2 2        2       4  4         2           3  2      3
+--R               (- 48a c  - 60a b c - 18b )d  + (- 48a b c - 36a b )d  - 24a c
+--R             + 
+--R                    2 2
+--R               - 18a b
+--R          *
+--R              4
+--R             f
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 7 4 7        2   6 4 6            2 2       2      2   5 4 5
+--R           - 12b c e f x  - 84b c d e f x  + (- 252b c d  + 4a c  - 19b c)e f x
+--R         + 
+--R                    2 3         2      2     4 4 4
+--R           (- 420b c d  + (20a c  - 95b c)d)e f x
+--R         + 
+--R                    2 4         2       2   2               3  3 4 3
+--R           (- 420b c d  + (40a c  - 190b c)d  - 16a b c - 5b )e f x
+--R         + 
+--R                    2 5         2       2   3                   3    2 4 2
+--R           (- 252b c d  + (40a c  - 190b c)d  + (- 48a b c - 15b )d)e f x
+--R         + 
+--R                      2 6         2      2   4                   3  2      2
+--R               - 84b c d  + (20a c  - 95b c)d  + (- 48a b c - 15b )d  - 12a c
+--R             + 
+--R                     2
+--R               - 3a b
+--R          *
+--R                4
+--R             e f x
+--R         + 
+--R                      2 7        2      2   5                  3  3
+--R               - 12b c d  + (4a c  - 19b c)d  + (- 16a b c - 5b )d
+--R             + 
+--R                     2        2
+--R               (- 12a c - 3a b )d
+--R          *
+--R              4
+--R             f
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 4        2 3     4 2  9 8
+--R         (128a c  - 64a b c  + 8b c )e x
+--R       + 
+--R               2 4         2 3      4 2    8 7
+--R         (1024a c  - 512a b c  + 64b c )d e x
+--R       + 
+--R                  2 4          2 3       4 2  2       2   3         3 2      5
+--R           ((3584a c  - 1792a b c  + 224b c )d  + 256a b c  - 128a b c  + 16b c)
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (7168a c  - 3584a b c  + 448b c )d
+--R           + 
+--R                   2   3         3 2      5
+--R             (1536a b c  - 768a b c  + 96b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (8960a c  - 4480a b c  + 560b c )d
+--R           + 
+--R                   2   3          3 2       5   2       3 3        4      6
+--R             (3840a b c  - 1920a b c  + 240b c)d  + 256a c  - 48a b c + 8b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (7168a c  - 3584a b c  + 448b c )d
+--R           + 
+--R                 2   3          3 2       5   3         3 3         4       6
+--R           (5120a b c  - 2560a b c  + 320b c)d  + (1024a c  - 192a b c + 32b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  6
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   4
+--R             (3840a b c  - 1920a b c  + 240b c)d
+--R           + 
+--R                   3 3         4       6  2       3   2       2 3         5
+--R             (1536a c  - 288a b c + 48b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   2 4         2 3      4 2  7
+--R             (1024a c  - 512a b c  + 64b c )d
+--R           + 
+--R                   2   3         3 2      5   5         3 3         4       6  3
+--R             (1536a b c  - 768a b c  + 96b c)d  + (1024a c  - 192a b c + 32b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  2 4        2 3     4 2  8        2   3         3 2      5   6
+--R             (128a c  - 64a b c  + 8b c )d  + (256a b c  - 128a b c  + 16b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2       2 3         5  2
+--R             (256a c  - 48a b c + 8b )d  + (256a b c  - 128a b c + 16a b )d
+--R           + 
+--R                 4 2      3 2      2 4
+--R             128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1006
+
+--S 1007 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           6 5          5 2 4          4 4 3         3 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         2 8          10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                             16
+--R                          81f
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                     2   2         3      5  8
+--R                (720a b c  + 360a b c + 9b )f
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                               16
+--R                            81f
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                        4 4        3 2 3         6       8    8
+--R                  (9216a c  - 4608a b c  + 288a b c - 36b )e f
+--R             *
+--R                ROOT
+--R                                  6 5          5 2 4          4 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   3 6 2        2 8          10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                    16
+--R                                 81f
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                            2   2         3      5  8
+--R                       (720a b c  + 360a b c + 9b )f
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)e f  x
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)d f
+--R     + 
+--R                 2 4        2 3     4 2  9 8
+--R           (- 64a c  + 32a b c  - 4b c )e x
+--R         + 
+--R                  2 4         2 3      4 2    8 7
+--R           (- 512a c  + 256a b c  - 32b c )d e x
+--R         + 
+--R                         2 4         2 3       4 2  2       2   3        3 2
+--R                 (- 1792a c  + 896a b c  - 112b c )d  - 128a b c  + 64a b c
+--R               + 
+--R                     5
+--R                 - 8b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  3
+--R               (- 3584a c  + 1792a b c  - 224b c )d
+--R             + 
+--R                      2   3         3 2      5
+--R               (- 768a b c  + 384a b c  - 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  4
+--R               (- 4480a c  + 2240a b c  - 280b c )d
+--R             + 
+--R                       2   3         3 2       5   2       3 3        4      6
+--R               (- 1920a b c  + 960a b c  - 120b c)d  - 128a c  + 24a b c - 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  5
+--R               (- 3584a c  + 1792a b c  - 224b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 2560a b c  + 1280a b c  - 160b c)d
+--R             + 
+--R                      3 3        4       6
+--R               (- 512a c  + 96a b c - 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       2 4         2 3       4 2  6
+--R               (- 1792a c  + 896a b c  - 112b c )d
+--R             + 
+--R                       2   3         3 2       5   4
+--R               (- 1920a b c  + 960a b c  - 120b c)d
+--R             + 
+--R                      3 3         4       6  2       3   2      2 3        5
+--R               (- 768a c  + 144a b c - 24b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      2 4         2 3      4 2  7
+--R               (- 512a c  + 256a b c  - 32b c )d
+--R             + 
+--R                      2   3         3 2      5   5
+--R               (- 768a b c  + 384a b c  - 48b c)d
+--R             + 
+--R                    3 3        4       6  3          3   2       2 3         5
+--R             (- 512a c  + 96a b c - 16b )d  + (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     2 4        2 3     4 2  8
+--R               (- 64a c  + 32a b c  - 4b c )d
+--R             + 
+--R                      2   3        3 2     5   6          3 3        4      6  4
+--R               (- 128a b c  + 64a b c  - 8b c)d  + (- 128a c  + 24a b c - 4b )d
+--R             + 
+--R                      3   2      2 3        5  2      4 2      3 2      2 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             6 5          5 2 4          4 4 3         3 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           2 8          10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                             16
+--R                          81f
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                     2   2         3      5  8
+--R                (720a b c  + 360a b c + 9b )f
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                               16
+--R                            81f
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                          4 4        3 2 3         6       8    8
+--R                  (- 9216a c  + 4608a b c  - 288a b c + 36b )e f
+--R             *
+--R                ROOT
+--R                                    6 5          5 2 4          4 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 3 6 2        2 8          10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                    16
+--R                                 81f
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                            2   2         3      5  8
+--R                       (720a b c  + 360a b c + 9b )f
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)e f  x
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)d f
+--R     + 
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             6 5          5 2 4          4 4 3         3 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           2 8          10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                             16
+--R                          81f
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                     2   2         3      5  8
+--R                (720a b c  + 360a b c + 9b )f
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                               16
+--R                            81f
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                        4 4        3 2 3         6       8    8
+--R                  (9216a c  - 4608a b c  + 288a b c - 36b )e f
+--R             *
+--R                ROOT
+--R                                    6 5          5 2 4          4 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 3 6 2        2 8          10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                    16
+--R                                 81f
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                            2   2         3      5  8
+--R                       (720a b c  + 360a b c + 9b )f
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)e f  x
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)d f
+--R     + 
+--R                 2 4        2 3     4 2  9 8
+--R           (- 64a c  + 32a b c  - 4b c )e x
+--R         + 
+--R                  2 4         2 3      4 2    8 7
+--R           (- 512a c  + 256a b c  - 32b c )d e x
+--R         + 
+--R                         2 4         2 3       4 2  2       2   3        3 2
+--R                 (- 1792a c  + 896a b c  - 112b c )d  - 128a b c  + 64a b c
+--R               + 
+--R                     5
+--R                 - 8b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  3
+--R               (- 3584a c  + 1792a b c  - 224b c )d
+--R             + 
+--R                      2   3         3 2      5
+--R               (- 768a b c  + 384a b c  - 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  4
+--R               (- 4480a c  + 2240a b c  - 280b c )d
+--R             + 
+--R                       2   3         3 2       5   2       3 3        4      6
+--R               (- 1920a b c  + 960a b c  - 120b c)d  - 128a c  + 24a b c - 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  5
+--R               (- 3584a c  + 1792a b c  - 224b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 2560a b c  + 1280a b c  - 160b c)d
+--R             + 
+--R                      3 3        4       6
+--R               (- 512a c  + 96a b c - 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       2 4         2 3       4 2  6
+--R               (- 1792a c  + 896a b c  - 112b c )d
+--R             + 
+--R                       2   3         3 2       5   4
+--R               (- 1920a b c  + 960a b c  - 120b c)d
+--R             + 
+--R                      3 3         4       6  2       3   2      2 3        5
+--R               (- 768a c  + 144a b c - 24b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      2 4         2 3      4 2  7
+--R               (- 512a c  + 256a b c  - 32b c )d
+--R             + 
+--R                      2   3         3 2      5   5
+--R               (- 768a b c  + 384a b c  - 48b c)d
+--R             + 
+--R                    3 3        4       6  3          3   2       2 3         5
+--R             (- 512a c  + 96a b c - 16b )d  + (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     2 4        2 3     4 2  8
+--R               (- 64a c  + 32a b c  - 4b c )d
+--R             + 
+--R                      2   3        3 2     5   6          3 3        4      6  4
+--R               (- 128a b c  + 64a b c  - 8b c)d  + (- 128a c  + 24a b c - 4b )d
+--R             + 
+--R                      3   2      2 3        5  2      4 2      3 2      2 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           6 5          5 2 4          4 4 3         3 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         2 8          10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                             16
+--R                          81f
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                     2   2         3      5  8
+--R                (720a b c  + 360a b c + 9b )f
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                               16
+--R                            81f
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                          4 4        3 2 3         6       8    8
+--R                  (- 9216a c  + 4608a b c  - 288a b c + 36b )e f
+--R             *
+--R                ROOT
+--R                                  6 5          5 2 4          4 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   3 6 2        2 8          10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                    16
+--R                                 81f
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                            2   2         3      5  8
+--R                       (720a b c  + 360a b c + 9b )f
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)e f  x
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)d f
+--R     + 
+--R              2 7 4 7        2   6 4 6            2 2       2      2   5 4 5
+--R       - 12b c e f x  - 84b c d e f x  + (- 252b c d  + 4a c  - 19b c)e f x
+--R     + 
+--R                2 3         2      2     4 4 4
+--R       (- 420b c d  + (20a c  - 95b c)d)e f x
+--R     + 
+--R                2 4         2       2   2               3  3 4 3
+--R       (- 420b c d  + (40a c  - 190b c)d  - 16a b c - 5b )e f x
+--R     + 
+--R                2 5         2       2   3                   3    2 4 2
+--R       (- 252b c d  + (40a c  - 190b c)d  + (- 48a b c - 15b )d)e f x
+--R     + 
+--R                    2 6         2      2   4                   3  2      2
+--R             - 84b c d  + (20a c  - 95b c)d  + (- 48a b c - 15b )d  - 12a c
+--R           + 
+--R                   2
+--R             - 3a b
+--R      *
+--R            4
+--R         e f x
+--R     + 
+--R                  2 7        2      2   5                  3  3
+--R           - 12b c d  + (4a c  - 19b c)d  + (- 16a b c - 5b )d
+--R         + 
+--R                 2        2
+--R           (- 12a c - 3a b )d
+--R      *
+--R          4
+--R         f
+--R  /
+--R            2 4        2 3     4 2  9 8         2 4         2 3      4 2    8 7
+--R       (128a c  - 64a b c  + 8b c )e x  + (1024a c  - 512a b c  + 64b c )d e x
+--R     + 
+--R              2 4          2 3       4 2  2       2   3         3 2      5   7 6
+--R       ((3584a c  - 1792a b c  + 224b c )d  + 256a b c  - 128a b c  + 16b c)e x
+--R     + 
+--R                   2 4          2 3       4 2  3
+--R             (7168a c  - 3584a b c  + 448b c )d
+--R           + 
+--R                   2   3         3 2      5
+--R             (1536a b c  - 768a b c  + 96b c)d
+--R      *
+--R          6 5
+--R         e x
+--R     + 
+--R                 2 4          2 3       4 2  4
+--R           (8960a c  - 4480a b c  + 560b c )d
+--R         + 
+--R                 2   3          3 2       5   2       3 3        4      6
+--R           (3840a b c  - 1920a b c  + 240b c)d  + 256a c  - 48a b c + 8b
+--R      *
+--R          5 4
+--R         e x
+--R     + 
+--R                 2 4          2 3       4 2  5
+--R           (7168a c  - 3584a b c  + 448b c )d
+--R         + 
+--R                 2   3          3 2       5   3         3 3         4       6
+--R           (5120a b c  - 2560a b c  + 320b c)d  + (1024a c  - 192a b c + 32b )d
+--R      *
+--R          4 3
+--R         e x
+--R     + 
+--R                 2 4          2 3       4 2  6
+--R           (3584a c  - 1792a b c  + 224b c )d
+--R         + 
+--R                 2   3          3 2       5   4         3 3         4       6  2
+--R           (3840a b c  - 1920a b c  + 240b c)d  + (1536a c  - 288a b c + 48b )d
+--R         + 
+--R               3   2       2 3         5
+--R           256a b c  - 128a b c + 16a b
+--R      *
+--R          3 2
+--R         e x
+--R     + 
+--R                 2 4         2 3      4 2  7
+--R           (1024a c  - 512a b c  + 64b c )d
+--R         + 
+--R                 2   3         3 2      5   5         3 3         4       6  3
+--R           (1536a b c  - 768a b c  + 96b c)d  + (1024a c  - 192a b c + 32b )d
+--R         + 
+--R                3   2       2 3         5
+--R           (512a b c  - 256a b c + 32a b )d
+--R      *
+--R          2
+--R         e x
+--R     + 
+--R                2 4        2 3     4 2  8        2   3         3 2      5   6
+--R           (128a c  - 64a b c  + 8b c )d  + (256a b c  - 128a b c  + 16b c)d
+--R         + 
+--R                3 3        4      6  4        3   2       2 3         5  2
+--R           (256a c  - 48a b c + 8b )d  + (256a b c  - 128a b c + 16a b )d
+--R         + 
+--R               4 2      3 2      2 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R         e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1007
+
+--S 1008 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R             2 2        2      4   +-+ |          2  |   |          2
+--R         (32a c  - 16a b c + 2b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           6 5          5 2 4          4 4 3         3 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         2 8          10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                             16
+--R                          81f
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                     2   2         3      5  8
+--R                (720a b c  + 360a b c + 9b )f
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                               16
+--R                            81f
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                        4 4        3 2 3         6       8    8
+--R                  (9216a c  - 4608a b c  + 288a b c - 36b )e f
+--R             *
+--R                ROOT
+--R                                  6 5          5 2 4          4 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   3 6 2        2 8          10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                    16
+--R                                 81f
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                            2   2         3      5  8
+--R                       (720a b c  + 360a b c + 9b )f
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)e f  x
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)d f
+--R     + 
+--R                                                       +--------------------+
+--R                                         +-----------+ |   +-----------+
+--R               2 2        2      4   +-+ |          2  |   |          2
+--R         (- 32a c  + 16a b c - 2b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                             6 5          5 2 4          4 4 3         3 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           2 8          10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                             16
+--R                          81f
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                     2   2         3      5  8
+--R                (720a b c  + 360a b c + 9b )f
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               7   6            6 3 5           5 5 4
+--R                      12582912a b c  - 14680064a b c  + 6553600a b c
+--R                    + 
+--R                                4 7 3         3 9 2        2 11           13
+--R                      - 1310720a b c  + 81920a b c  + 8192a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                               16
+--R                            81f
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                          4 4        3 2 3         6       8    8
+--R                  (- 9216a c  + 4608a b c  - 288a b c + 36b )e f
+--R             *
+--R                ROOT
+--R                                    6 5          5 2 4          4 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 3 6 2        2 8          10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                    16
+--R                                 81f
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                            2   2         3      5  8
+--R                       (720a b c  + 360a b c + 9b )f
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)e f  x
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)d f
+--R     + 
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R             2 2        2      4   +-+ |          2  |   |          2
+--R         (32a c  - 16a b c + 2b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                             6 5          5 2 4          4 4 3         3 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           2 8          10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                             16
+--R                          81f
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                     2   2         3      5  8
+--R                (720a b c  + 360a b c + 9b )f
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                               16
+--R                            81f
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                        4 4        3 2 3         6       8    8
+--R                  (9216a c  - 4608a b c  + 288a b c - 36b )e f
+--R             *
+--R                ROOT
+--R                                    6 5          5 2 4          4 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 3 6 2        2 8          10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                    16
+--R                                 81f
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                            2   2         3      5  8
+--R                       (720a b c  + 360a b c + 9b )f
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)e f  x
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)d f
+--R     + 
+--R                                                       +--------------------+
+--R                                         +-----------+ |   +-----------+
+--R               2 2        2      4   +-+ |          2  |   |          2
+--R         (- 32a c  + 16a b c - 2b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           6 5          5 2 4          4 4 3         3 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         2 8          10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                     -
+--R                             16
+--R                          81f
+--R                       /
+--R                                       7 5            6 2 4            5 4 3
+--R                              67108864a c  - 83886080a b c  + 41943040a b c
+--R                            + 
+--R                                         4 6 2           3 8          2 10
+--R                              - 10485760a b c  + 1310720a b c - 65536a b
+--R                         *
+--R                             4
+--R                            e
+--R              + 
+--R                     2   2         3      5  8
+--R                (720a b c  + 360a b c + 9b )f
+--R           /
+--R                         6 5          5 2 4         4 4 3         3 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       2 8          10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 7   6            6 3 5           5 5 4
+--R                      - 12582912a b c  + 14680064a b c  - 6553600a b c
+--R                    + 
+--R                              4 7 3         3 9 2        2 11           13
+--R                      1310720a b c  - 81920a b c  - 8192a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                       -
+--R                               16
+--R                            81f
+--R                         /
+--R                                         7 5            6 2 4            5 4 3
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 2           3 8          2 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                           *
+--R                               4
+--R                              e
+--R                + 
+--R                          4 4        3 2 3         6       8    8
+--R                  (- 9216a c  + 4608a b c  - 288a b c + 36b )e f
+--R             *
+--R                ROOT
+--R                                  6 5          5 2 4          4 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   3 6 2        2 8          10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                    16
+--R                                 81f
+--R                              /
+--R                                              7 5            6 2 4
+--R                                     67108864a c  - 83886080a b c
+--R                                   + 
+--R                                              5 4 3            4 6 2
+--R                                     41943040a b c  - 10485760a b c
+--R                                   + 
+--R                                             3 8          2 10
+--R                                     1310720a b c - 65536a b
+--R                                *
+--R                                    4
+--R                                   e
+--R                     + 
+--R                            2   2         3      5  8
+--R                       (720a b c  + 360a b c + 9b )f
+--R                  /
+--R                                6 5          5 2 4         4 4 3         3 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              2 8          10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)e f  x
+--R            + 
+--R                   2 3          2 2       4     12
+--R              (432a c  + 1080a b c  + 135b c)d f
+--R     + 
+--R                                                       +------------------+
+--R                +-----------+                          | +-----------+
+--R              4 |          2                 2  4  +-+ | |          2
+--R         (6b f \|- 4a c + b   + (- 12a c - 9b )f )\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                +-----------+                        |   +-----------+
+--R              4 |          2               2  4  +-+ |   |          2
+--R         (6b f \|- 4a c + b   + (12a c + 9b )f )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                                   +--------------------+
+--R                                     +-----------+ |   +-----------+
+--R           2 2        2      4   +-+ |          2  |   |          2
+--R       (64a c  - 32a b c + 4b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1008
+
+--S 1009 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1009
+
+)clear all
+
+--S 1010 of 1057
+t0:=(d*f+e*f*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      3 3 3       2 3 2     2   3     3 3
+--R     e f x  + 3d e f x  + 3d e f x + d f
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1010
+
+--S 1011 of 1057
+r0:=1/4*f^3*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)-_
+   3/4*b*f^3*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   3*b*c*f^3*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e)
+--R 
+--R
+--R   (2)
+--R                3 8 3 8        3   7 3 7          3 2      2 2  6 3 6
+--R           12b c e f x  + 96b c d e f x  + (336b c d  + 24b c )e f x
+--R         + 
+--R                  3 3       2 2   5 3 5
+--R           (672b c d  + 144b c d)e f x
+--R         + 
+--R                  3 4       2 2 2          2      3   4 3 4
+--R           (840b c d  + 360b c d  + 24a b c  + 12b c)e f x
+--R         + 
+--R                  3 5       2 2 3           2      3     3 3 3
+--R           (672b c d  + 480b c d  + (96a b c  + 48b c)d)e f x
+--R         + 
+--R                  3 6       2 2 4            2      3   2        2   2 3 2
+--R           (336b c d  + 360b c d  + (144a b c  + 72b c)d  + 24a b c)e f x
+--R         + 
+--R                 3 7       2 2 5           2      3   3        2       3
+--R           (96b c d  + 144b c d  + (96a b c  + 48b c)d  + 48a b c d)e f x
+--R         + 
+--R               3 8      2 2 6           2      3   4        2   2      2     3
+--R         (12b c d  + 24b c d  + (24a b c  + 12b c)d  + 24a b c d  + 12a b c)f
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                 2 6 3 6        2   5 3 5           2 2     2   4 3 4
+--R           - 6b c e f x  - 36b c d e f x  + (- 90b c d  - 9b c)e f x
+--R         + 
+--R                    2 3      2     3 3 3
+--R           (- 120b c d  - 36b c d)e f x
+--R         + 
+--R                   2 4      2   2               3  2 3 2
+--R           (- 90b c d  - 54b c d  - 10a b c - 2b )e f x
+--R         + 
+--R                   2 5      2   3                  3      3
+--R           (- 36b c d  - 36b c d  + (- 20a b c - 4b )d)e f x
+--R         + 
+--R                  2 6     2   4                  3  2     2       2  3
+--R           (- 6b c d  - 9b c d  + (- 10a b c - 2b )d  - 8a c - a b )f
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  9 8        2 4         2 3      4 2    8 7
+--R         (64a c  - 32a b c  + 4b c )e x  + (512a c  - 256a b c  + 32b c )d e x
+--R       + 
+--R                2 4         2 3       4 2  2       2   3        3 2     5   7 6
+--R         ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                  2   3         3 2      5
+--R             (768a b c  - 384a b c  + 48b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (4480a c  - 2240a b c  + 280b c )d
+--R           + 
+--R                   2   3         3 2       5   2       3 3        4      6
+--R             (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4         2 3       4 2  6
+--R             (1792a c  - 896a b c  + 112b c )d
+--R           + 
+--R                   2   3         3 2       5   4        3 3         4       6  2
+--R             (1920a b c  - 960a b c  + 120b c)d  + (768a c  - 144a b c + 24b )d
+--R           + 
+--R                 3   2      2 3        5
+--R             128a b c  - 64a b c + 8a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  2 4         2 3      4 2  7
+--R             (512a c  - 256a b c  + 32b c )d
+--R           + 
+--R                  2   3         3 2      5   5        3 3        4       6  3
+--R             (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 2 4        2 3     4 2  8        2   3        3 2     5   6
+--R             (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2      2 3        5  2
+--R             (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                4 2      3 2      2 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1011
+
+--S 1012 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3 8 3 8        3   7 3 7          3 2      2 2  6 3 6
+--R             6b c e f x  + 48b c d e f x  + (168b c d  + 12b c )e f x
+--R           + 
+--R                    3 3      2 2   5 3 5
+--R             (336b c d  + 72b c d)e f x
+--R           + 
+--R                    3 4       2 2 2          2     3   4 3 4
+--R             (420b c d  + 180b c d  + 12a b c  + 6b c)e f x
+--R           + 
+--R                    3 5       2 2 3           2      3     3 3 3
+--R             (336b c d  + 240b c d  + (48a b c  + 24b c)d)e f x
+--R           + 
+--R                    3 6       2 2 4           2      3   2        2   2 3 2
+--R             (168b c d  + 180b c d  + (72a b c  + 36b c)d  + 12a b c)e f x
+--R           + 
+--R                   3 7      2 2 5           2      3   3        2       3
+--R             (48b c d  + 72b c d  + (48a b c  + 24b c)d  + 24a b c d)e f x
+--R           + 
+--R                  3 8      2 2 6           2     3   4        2   2     2     3
+--R             (6b c d  + 12b c d  + (12a b c  + 6b c)d  + 12a b c d  + 6a b c)f
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                   2 6 3 6        2   5 3 5           2 2     2   4 3 4
+--R             - 6b c e f x  - 36b c d e f x  + (- 90b c d  - 9b c)e f x
+--R           + 
+--R                      2 3      2     3 3 3
+--R             (- 120b c d  - 36b c d)e f x
+--R           + 
+--R                     2 4      2   2               3  2 3 2
+--R             (- 90b c d  - 54b c d  - 10a b c - 2b )e f x
+--R           + 
+--R                     2 5      2   3                  3      3
+--R             (- 36b c d  - 36b c d  + (- 20a b c - 4b )d)e f x
+--R           + 
+--R                    2 6     2   4                  3  2     2       2  3
+--R             (- 6b c d  - 9b c d  + (- 10a b c - 2b )d  - 8a c - a b )f
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    3 8 3 8        3   7 3 7            3 2      2 2  6 3 6
+--R             - 12b c e f x  - 96b c d e f x  + (- 336b c d  - 24b c )e f x
+--R           + 
+--R                      3 3       2 2   5 3 5
+--R             (- 672b c d  - 144b c d)e f x
+--R           + 
+--R                      3 4       2 2 2          2      3   4 3 4
+--R             (- 840b c d  - 360b c d  - 24a b c  - 12b c)e f x
+--R           + 
+--R                      3 5       2 2 3             2      3     3 3 3
+--R             (- 672b c d  - 480b c d  + (- 96a b c  - 48b c)d)e f x
+--R           + 
+--R                      3 6       2 2 4              2      3   2        2   2 3 2
+--R             (- 336b c d  - 360b c d  + (- 144a b c  - 72b c)d  - 24a b c)e f x
+--R           + 
+--R                     3 7       2 2 5             2      3   3        2       3
+--R             (- 96b c d  - 144b c d  + (- 96a b c  - 48b c)d  - 48a b c d)e f x
+--R           + 
+--R                        3 8      2 2 6             2      3   4        2   2
+--R                 - 12b c d  - 24b c d  + (- 24a b c  - 12b c)d  - 24a b c d
+--R               + 
+--R                      2
+--R                 - 12a b c
+--R            *
+--R                3
+--R               f
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                   2 6 3 6        2   5 3 5           2 2     2   4 3 4
+--R             - 6b c e f x  - 36b c d e f x  + (- 90b c d  - 9b c)e f x
+--R           + 
+--R                      2 3      2     3 3 3
+--R             (- 120b c d  - 36b c d)e f x
+--R           + 
+--R                     2 4      2   2               3  2 3 2
+--R             (- 90b c d  - 54b c d  - 10a b c - 2b )e f x
+--R           + 
+--R                     2 5      2   3                  3      3
+--R             (- 36b c d  - 36b c d  + (- 20a b c - 4b )d)e f x
+--R           + 
+--R                    2 6     2   4                  3  2     2       2  3
+--R             (- 6b c d  - 9b c d  + (- 10a b c - 2b )d  - 8a c - a b )f
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1012
+
+--S 1013 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               3
+--R         3b c f
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                          2 2                  2
+--R               3      2c e x  + 4c d e x + 2c d  + b
+--R       - 6b c f atanh(------------------------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                               +-----------+
+--R         2 2        2      4   |          2
+--R     (32a c  - 16a b c + 2b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1013
+
+--S 1014 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1014
+
+--S 1015 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 +---------+          2 2                  2
+--R               3 |        2       2c e x  + 4c d e x + 2c d  + b
+--R       - 3b c f \|4a c - b  atanh(------------------------------)
+--R                                           +-----------+
+--R                                           |          2
+--R                                          \|- 4a c + b
+--R     + 
+--R                                                                  +---------+
+--R               +-----------+          2 2                  2      |        2
+--R             3 |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R     - 3b c f \|- 4a c + b  atan(--------------------------------------------)
+--R                                                           2
+--R                                                   4a c - b
+--R  /
+--R                             +-----------+ +---------+
+--R         2 2       2     4   |          2  |        2
+--R     (16a c  - 8a b c + b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1015
+
+--S 1016 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1016
+
+)clear all
+
+--S 1017 of 1057
+t0:=(d*f+e*f*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      2 2 2         2     2 2
+--R     e f x  + 2d e f x + d f
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1017
+
+--S 1018 of 1057
+r0:=-1/4*f^2*(d+e*x)*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/8*f^2*(d+e*x)*(b*(b^2+8*a*c)+c*(b^2+20*a*c)*(d+_
+   e*x)^2)/(a*(b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+1/8*f^2*_
+   atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b^2+_
+   20*a*c+b*(b^2-52*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*e*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/8*f^2*atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b^2+20*a*c-b*(b^2-52*a*c)/_
+   sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     3    2 2  8 2 8          3     2 2    7 2 7
+--R               (20a c  + b c )e f x  + (160a c  + 8b c )d e f x
+--R             + 
+--R                       3      2 2  2          2     3   6 2 6
+--R               ((560a c  + 28b c )d  + 40a b c  + 2b c)e f x
+--R             + 
+--R                        3      2 2  3            2      3     5 2 5
+--R               ((1120a c  + 56b c )d  + (240a b c  + 12b c)d)e f x
+--R             + 
+--R                           3      2 2  4            2      3   2      2 2
+--R                   (1400a c  + 70b c )d  + (600a b c  + 30b c)d  + 40a c
+--R                 + 
+--R                        2     4
+--R                   22a b c + b
+--R              *
+--R                  4 2 4
+--R                 e f x
+--R             + 
+--R                           3      2 2  5            2      3   3
+--R                   (1120a c  + 56b c )d  + (800a b c  + 40b c)d
+--R                 + 
+--R                        2 2        2      4
+--R                   (160a c  + 88a b c + 4b )d
+--R              *
+--R                  3 2 3
+--R                 e f x
+--R             + 
+--R                          3      2 2  6            2      3   4
+--R                   (560a c  + 28b c )d  + (600a b c  + 30b c)d
+--R                 + 
+--R                        2 2         2      4  2      2          3
+--R                   (240a c  + 132a b c + 6b )d  + 40a b c + 2a b
+--R              *
+--R                  2 2 2
+--R                 e f x
+--R             + 
+--R                          3     2 2  7            2      3   5
+--R                   (160a c  + 8b c )d  + (240a b c  + 12b c)d
+--R                 + 
+--R                        2 2        2      4  3       2          3
+--R                   (160a c  + 88a b c + 4b )d  + (80a b c + 4a b )d
+--R              *
+--R                    2
+--R                 e f x
+--R             + 
+--R                         3    2 2  8           2     3   6
+--R                   (20a c  + b c )d  + (40a b c  + 2b c)d
+--R                 + 
+--R                     2 2        2     4  4       2          3  2      3     2 2
+--R                 (40a c  + 22a b c + b )d  + (40a b c + 2a b )d  + 20a c + a b
+--R              *
+--R                  2
+--R                 f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     3    3 2  8 2 8              3     3 2    7 2 7
+--R           (- 52a b c  + b c )e f x  + (- 416a b c  + 8b c )d e f x
+--R         + 
+--R                        3      3 2  2         2 2     4   6 2 6
+--R           ((- 1456a b c  + 28b c )d  - 104a b c  + 2b c)e f x
+--R         + 
+--R                        3      3 2  3            2 2      4     5 2 5
+--R           ((- 2912a b c  + 56b c )d  + (- 624a b c  + 12b c)d)e f x
+--R         + 
+--R                           3      3 2  4             2 2      4   2       2   2
+--R               (- 3640a b c  + 70b c )d  + (- 1560a b c  + 30b c)d  - 104a b c
+--R             + 
+--R                      3     5
+--R               - 50a b c + b
+--R          *
+--R              4 2 4
+--R             e f x
+--R         + 
+--R                           3      3 2  5             2 2      4   3
+--R               (- 2912a b c  + 56b c )d  + (- 2080a b c  + 40b c)d
+--R             + 
+--R                      2   2         3      5
+--R               (- 416a b c  - 200a b c + 4b )d
+--R          *
+--R              3 2 3
+--R             e f x
+--R         + 
+--R                           3      3 2  6             2 2      4   4
+--R               (- 1456a b c  + 28b c )d  + (- 1560a b c  + 30b c)d
+--R             + 
+--R                      2   2         3      5  2       2 2        4
+--R               (- 624a b c  - 300a b c + 6b )d  - 104a b c + 2a b
+--R          *
+--R              2 2 2
+--R             e f x
+--R         + 
+--R                          3     3 2  7            2 2      4   5
+--R               (- 416a b c  + 8b c )d  + (- 624a b c  + 12b c)d
+--R             + 
+--R                      2   2         3      5  3          2 2        4
+--R               (- 416a b c  - 200a b c + 4b )d  + (- 208a b c + 4a b )d
+--R          *
+--R                2
+--R             e f x
+--R         + 
+--R                         3    3 2  8            2 2     4   6
+--R               (- 52a b c  + b c )d  + (- 104a b c  + 2b c)d
+--R             + 
+--R                      2   2        3     5  4          2 2        4  2      3
+--R               (- 104a b c  - 50a b c + b )d  + (- 104a b c + 2a b )d  - 52a b c
+--R             + 
+--R                2 3
+--R               a b
+--R          *
+--R              2
+--R             f
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     3    2 2  8 2 8          3     2 2    7 2 7
+--R               (20a c  + b c )e f x  + (160a c  + 8b c )d e f x
+--R             + 
+--R                       3      2 2  2          2     3   6 2 6
+--R               ((560a c  + 28b c )d  + 40a b c  + 2b c)e f x
+--R             + 
+--R                        3      2 2  3            2      3     5 2 5
+--R               ((1120a c  + 56b c )d  + (240a b c  + 12b c)d)e f x
+--R             + 
+--R                           3      2 2  4            2      3   2      2 2
+--R                   (1400a c  + 70b c )d  + (600a b c  + 30b c)d  + 40a c
+--R                 + 
+--R                        2     4
+--R                   22a b c + b
+--R              *
+--R                  4 2 4
+--R                 e f x
+--R             + 
+--R                           3      2 2  5            2      3   3
+--R                   (1120a c  + 56b c )d  + (800a b c  + 40b c)d
+--R                 + 
+--R                        2 2        2      4
+--R                   (160a c  + 88a b c + 4b )d
+--R              *
+--R                  3 2 3
+--R                 e f x
+--R             + 
+--R                          3      2 2  6            2      3   4
+--R                   (560a c  + 28b c )d  + (600a b c  + 30b c)d
+--R                 + 
+--R                        2 2         2      4  2      2          3
+--R                   (240a c  + 132a b c + 6b )d  + 40a b c + 2a b
+--R              *
+--R                  2 2 2
+--R                 e f x
+--R             + 
+--R                          3     2 2  7            2      3   5
+--R                   (160a c  + 8b c )d  + (240a b c  + 12b c)d
+--R                 + 
+--R                        2 2        2      4  3       2          3
+--R                   (160a c  + 88a b c + 4b )d  + (80a b c + 4a b )d
+--R              *
+--R                    2
+--R                 e f x
+--R             + 
+--R                         3    2 2  8           2     3   6
+--R                   (20a c  + b c )d  + (40a b c  + 2b c)d
+--R                 + 
+--R                     2 2        2     4  4       2          3  2      3     2 2
+--R                 (40a c  + 22a b c + b )d  + (40a b c + 2a b )d  + 20a c + a b
+--R              *
+--R                  2
+--R                 f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3    3 2  8 2 8            3     3 2    7 2 7
+--R           (52a b c  - b c )e f x  + (416a b c  - 8b c )d e f x
+--R         + 
+--R                      3      3 2  2         2 2     4   6 2 6
+--R           ((1456a b c  - 28b c )d  + 104a b c  - 2b c)e f x
+--R         + 
+--R                      3      3 2  3          2 2      4     5 2 5
+--R           ((2912a b c  - 56b c )d  + (624a b c  - 12b c)d)e f x
+--R         + 
+--R                         3      3 2  4           2 2      4   2       2   2
+--R               (3640a b c  - 70b c )d  + (1560a b c  - 30b c)d  + 104a b c
+--R             + 
+--R                    3     5
+--R               50a b c - b
+--R          *
+--R              4 2 4
+--R             e f x
+--R         + 
+--R                         3      3 2  5           2 2      4   3
+--R               (2912a b c  - 56b c )d  + (2080a b c  - 40b c)d
+--R             + 
+--R                    2   2         3      5
+--R               (416a b c  + 200a b c - 4b )d
+--R          *
+--R              3 2 3
+--R             e f x
+--R         + 
+--R                         3      3 2  6           2 2      4   4
+--R               (1456a b c  - 28b c )d  + (1560a b c  - 30b c)d
+--R             + 
+--R                    2   2         3      5  2       2 2        4
+--R               (624a b c  + 300a b c - 6b )d  + 104a b c - 2a b
+--R          *
+--R              2 2 2
+--R             e f x
+--R         + 
+--R                        3     3 2  7          2 2      4   5
+--R               (416a b c  - 8b c )d  + (624a b c  - 12b c)d
+--R             + 
+--R                    2   2         3      5  3        2 2        4
+--R               (416a b c  + 200a b c - 4b )d  + (208a b c - 4a b )d
+--R          *
+--R                2
+--R             e f x
+--R         + 
+--R                       3    3 2  8          2 2     4   6
+--R               (52a b c  - b c )d  + (104a b c  - 2b c)d
+--R             + 
+--R                    2   2        3     5  4        2 2        4  2      3
+--R               (104a b c  + 50a b c - b )d  + (104a b c - 2a b )d  + 52a b c
+--R             + 
+--R                  2 3
+--R               - a b
+--R          *
+--R              2
+--R             f
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 3    2 2  7 2 7          3     2 2    6 2 6
+--R           (20a c  + b c )e f x  + (140a c  + 7b c )d e f x
+--R         + 
+--R                   3      2 2  2          2     3   5 2 5
+--R           ((420a c  + 21b c )d  + 28a b c  + 2b c)e f x
+--R         + 
+--R                   3      2 2  3            2      3     4 2 4
+--R           ((700a c  + 35b c )d  + (140a b c  + 10b c)d)e f x
+--R         + 
+--R                        3      2 2  4            2      3   2      2 2       2
+--R                 (700a c  + 35b c )d  + (280a b c  + 20b c)d  + 36a c  + 5a b c
+--R               + 
+--R                  4
+--R                 b
+--R          *
+--R              3 2 3
+--R             e f x
+--R         + 
+--R                      3      2 2  5            2      3   3
+--R               (420a c  + 21b c )d  + (280a b c  + 20b c)d
+--R             + 
+--R                    2 2        2      4
+--R               (108a c  + 15a b c + 3b )d
+--R          *
+--R              2 2 2
+--R             e f x
+--R         + 
+--R                      3     2 2  6            2      3   4
+--R               (140a c  + 7b c )d  + (140a b c  + 10b c)d
+--R             + 
+--R                    2 2        2      4  2      2         3
+--R               (108a c  + 15a b c + 3b )d  + 16a b c - a b
+--R          *
+--R                2
+--R             e f x
+--R         + 
+--R                     3    2 2  7           2     3   5
+--R               (20a c  + b c )d  + (28a b c  + 2b c)d
+--R             + 
+--R                   2 2       2     4  3       2         3
+--R               (36a c  + 5a b c + b )d  + (16a b c - a b )d
+--R          *
+--R              2
+--R             f
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              3 4      2 2 3       4 2  9 8
+--R         (128a c  - 64a b c  + 8a b c )e x
+--R       + 
+--R               3 4       2 2 3        4 2    8 7
+--R         (1024a c  - 512a b c  + 64a b c )d e x
+--R       + 
+--R                   3 4        2 2 3         4 2  2       3   3       2 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                  5
+--R             16a b c
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  3
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   3   3       2 3 2        5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  4
+--R             (8960a c  - 4480a b c  + 560a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   2       4 3      2 4        6
+--R             (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  5
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   3
+--R             (5120a b c  - 2560a b c  + 320a b c)d
+--R           + 
+--R                   4 3       2 4         6
+--R             (1024a c  - 192a b c + 32a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  6
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   4
+--R             (3840a b c  - 1920a b c  + 240a b c)d
+--R           + 
+--R                   4 3       2 4         6  2       4   2       3 3       2 5
+--R             (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   3 4       2 2 3        4 2  7
+--R             (1024a c  - 512a b c  + 64a b c )d
+--R           + 
+--R                   3   3       2 3 2        5   5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R           + 
+--R                 4 3       2 4         6  3        4   2       3 3       2 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  3 4      2 2 3       4 2  8
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  3   3       2 3 2        5   6        4 3      2 4        6  4
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  4   2       3 3       2 5  2       5 2      4 2      3 4
+--R             (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1018
+
+--S 1019 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 4      2 2 3       4 2  9 8
+--R           (64a c  - 32a b c  + 4a b c )e x
+--R         + 
+--R                3 4       2 2 3        4 2    8 7
+--R           (512a c  - 256a b c  + 32a b c )d e x
+--R         + 
+--R                     3 4       2 2 3         4 2  2       3   3      2 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                   5
+--R               8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    3   3       2 3 2        5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   3   3       2 3 2         5   2       4 3      2 4        6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     3   3        2 3 2         5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    4 3      2 4         6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     3 4       2 2 3         4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     3   3       2 3 2         5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    4 3       2 4         6  2       4   2      3 3      2 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    3 4       2 2 3        4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    3   3       2 3 2        5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  4 3      2 4         6  3        4   2       3 3       2 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   3 4      2 2 3       4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    3   3      2 3 2       5   6        4 3      2 4        6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    4   2      3 3      2 5  2      5 2      4 2      3 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                              2 2        2     4  8
+--R                       (- 625a c  + 50a b c - b )f
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      3   3       2 3 2        5     7  4
+--R                (1680a b c  + 280a b c  - 35a b c + b )f
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                2 2        2     4  8
+--R                         (- 625a c  + 50a b c - b )f
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               5   5         4 3 4         3 5 3        2 7 2
+--R                      - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                    + 
+--R                              9      11
+--R                      - 212a b c + 4b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                     2 2        2     4  8
+--R                              (- 625a c  + 50a b c - b )f
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             3   3       2 3 2        5     7  4
+--R                       (1680a b c  + 280a b c  - 35a b c + b )f
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e f x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d f
+--R     + 
+--R                 3 4      2 2 3       4 2  9 8
+--R           (- 64a c  + 32a b c  - 4a b c )e x
+--R         + 
+--R                  3 4       2 2 3        4 2    8 7
+--R           (- 512a c  + 256a b c  - 32a b c )d e x
+--R         + 
+--R                       3 4       2 2 3         4 2  2       3   3      2 3 2
+--R               (- 1792a c  + 896a b c  - 112a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                     5
+--R               - 8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  3
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                      3   3       2 3 2        5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  4
+--R               (- 4480a c  + 2240a b c  - 280a b c )d
+--R             + 
+--R                     3   3       2 3 2         5   2       4 3      2 4        6
+--R             (- 1920a b c  + 960a b c  - 120a b c)d  - 128a c  + 24a b c - 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  5
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   3
+--R               (- 2560a b c  + 1280a b c  - 160a b c)d
+--R             + 
+--R                      4 3      2 4         6
+--R               (- 512a c  + 96a b c - 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       3 4       2 2 3         4 2  6
+--R               (- 1792a c  + 896a b c  - 112a b c )d
+--R             + 
+--R                       3   3       2 3 2         5   4
+--R               (- 1920a b c  + 960a b c  - 120a b c)d
+--R             + 
+--R                      4 3       2 4         6  2       4   2      3 3      2 5
+--R               (- 768a c  + 144a b c - 24a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      3 4       2 2 3        4 2  7
+--R               (- 512a c  + 256a b c  - 32a b c )d
+--R             + 
+--R                      3   3       2 3 2        5   5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R             + 
+--R                      4 3      2 4         6  3
+--R               (- 512a c  + 96a b c - 16a b )d
+--R             + 
+--R                      4   2       3 3       2 5
+--R               (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     3 4      2 2 3       4 2  8
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      3   3      2 3 2       5   6
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      4 3      2 4        6  4
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                      4   2      3 3      2 5  2      5 2      4 2      3 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                              2 2        2     4  8
+--R                       (- 625a c  + 50a b c - b )f
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      3   3       2 3 2        5     7  4
+--R                (1680a b c  + 280a b c  - 35a b c + b )f
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                2 2        2     4  8
+--R                         (- 625a c  + 50a b c - b )f
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                    + 
+--R                            9      11
+--R                      212a b c - 4b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                     2 2        2     4  8
+--R                              (- 625a c  + 50a b c - b )f
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             3   3       2 3 2        5     7  4
+--R                       (1680a b c  + 280a b c  - 35a b c + b )f
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e f x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d f
+--R     + 
+--R               3 4      2 2 3       4 2  9 8
+--R           (64a c  - 32a b c  + 4a b c )e x
+--R         + 
+--R                3 4       2 2 3        4 2    8 7
+--R           (512a c  - 256a b c  + 32a b c )d e x
+--R         + 
+--R                     3 4       2 2 3         4 2  2       3   3      2 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                   5
+--R               8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    3   3       2 3 2        5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   3   3       2 3 2         5   2       4 3      2 4        6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     3 4        2 2 3         4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     3   3        2 3 2         5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    4 3      2 4         6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     3 4       2 2 3         4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     3   3       2 3 2         5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    4 3       2 4         6  2       4   2      3 3      2 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    3 4       2 2 3        4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    3   3       2 3 2        5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  4 3      2 4         6  3        4   2       3 3       2 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   3 4      2 2 3       4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    3   3      2 3 2       5   6        4 3      2 4        6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    4   2      3 3      2 5  2      5 2      4 2      3 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                              2 2        2     4  8
+--R                       (- 625a c  + 50a b c - b )f
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      3   3       2 3 2        5     7  4
+--R                (1680a b c  + 280a b c  - 35a b c + b )f
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                2 2        2     4  8
+--R                         (- 625a c  + 50a b c - b )f
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               5   5         4 3 4         3 5 3        2 7 2
+--R                      - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                    + 
+--R                              9      11
+--R                      - 212a b c + 4b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                     2 2        2     4  8
+--R                              (- 625a c  + 50a b c - b )f
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             3   3       2 3 2        5     7  4
+--R                       (1680a b c  + 280a b c  - 35a b c + b )f
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e f x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d f
+--R     + 
+--R                 3 4      2 2 3       4 2  9 8
+--R           (- 64a c  + 32a b c  - 4a b c )e x
+--R         + 
+--R                  3 4       2 2 3        4 2    8 7
+--R           (- 512a c  + 256a b c  - 32a b c )d e x
+--R         + 
+--R                       3 4       2 2 3         4 2  2       3   3      2 3 2
+--R               (- 1792a c  + 896a b c  - 112a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                     5
+--R               - 8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  3
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                      3   3       2 3 2        5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  4
+--R               (- 4480a c  + 2240a b c  - 280a b c )d
+--R             + 
+--R                     3   3       2 3 2         5   2       4 3      2 4        6
+--R             (- 1920a b c  + 960a b c  - 120a b c)d  - 128a c  + 24a b c - 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  5
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   3
+--R               (- 2560a b c  + 1280a b c  - 160a b c)d
+--R             + 
+--R                      4 3      2 4         6
+--R               (- 512a c  + 96a b c - 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       3 4       2 2 3         4 2  6
+--R               (- 1792a c  + 896a b c  - 112a b c )d
+--R             + 
+--R                       3   3       2 3 2         5   4
+--R               (- 1920a b c  + 960a b c  - 120a b c)d
+--R             + 
+--R                      4 3       2 4         6  2       4   2      3 3      2 5
+--R               (- 768a c  + 144a b c - 24a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      3 4       2 2 3        4 2  7
+--R               (- 512a c  + 256a b c  - 32a b c )d
+--R             + 
+--R                      3   3       2 3 2        5   5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R             + 
+--R                      4 3      2 4         6  3
+--R               (- 512a c  + 96a b c - 16a b )d
+--R             + 
+--R                      4   2       3 3       2 5
+--R               (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     3 4      2 2 3       4 2  8
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      3   3      2 3 2       5   6
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      4 3      2 4        6  4
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                      4   2      3 3      2 5  2      5 2      4 2      3 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                              2 2        2     4  8
+--R                       (- 625a c  + 50a b c - b )f
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      3   3       2 3 2        5     7  4
+--R                (1680a b c  + 280a b c  - 35a b c + b )f
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                2 2        2     4  8
+--R                         (- 625a c  + 50a b c - b )f
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                    + 
+--R                            9      11
+--R                      212a b c - 4b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                     2 2        2     4  8
+--R                              (- 625a c  + 50a b c - b )f
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             3   3       2 3 2        5     7  4
+--R                       (1680a b c  + 280a b c  - 35a b c + b )f
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e f x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d f
+--R     + 
+--R             3    2 2  7 2 7          3     2 2    6 2 6
+--R       (20a c  + b c )e f x  + (140a c  + 7b c )d e f x
+--R     + 
+--R               3      2 2  2          2     3   5 2 5
+--R       ((420a c  + 21b c )d  + 28a b c  + 2b c)e f x
+--R     + 
+--R               3      2 2  3            2      3     4 2 4
+--R       ((700a c  + 35b c )d  + (140a b c  + 10b c)d)e f x
+--R     + 
+--R                 3      2 2  4            2      3   2      2 2       2     4  3
+--R         ((700a c  + 35b c )d  + (280a b c  + 20b c)d  + 36a c  + 5a b c + b )e
+--R      *
+--R          2 3
+--R         f x
+--R     + 
+--R                  3      2 2  5            2      3   3
+--R           (420a c  + 21b c )d  + (280a b c  + 20b c)d
+--R         + 
+--R                2 2        2      4
+--R           (108a c  + 15a b c + 3b )d
+--R      *
+--R          2 2 2
+--R         e f x
+--R     + 
+--R                  3     2 2  6            2      3   4
+--R           (140a c  + 7b c )d  + (140a b c  + 10b c)d
+--R         + 
+--R                2 2        2      4  2      2         3
+--R           (108a c  + 15a b c + 3b )d  + 16a b c - a b
+--R      *
+--R            2
+--R         e f x
+--R     + 
+--R                 3    2 2  7           2     3   5       2 2       2     4  3
+--R           (20a c  + b c )d  + (28a b c  + 2b c)d  + (36a c  + 5a b c + b )d
+--R         + 
+--R               2         3
+--R           (16a b c - a b )d
+--R      *
+--R          2
+--R         f
+--R  /
+--R            3 4      2 2 3       4 2  9 8
+--R       (128a c  - 64a b c  + 8a b c )e x
+--R     + 
+--R             3 4       2 2 3        4 2    8 7
+--R       (1024a c  - 512a b c  + 64a b c )d e x
+--R     + 
+--R                   3 4        2 2 3         4 2  2       3   3       2 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                  5
+--R             16a b c
+--R      *
+--R          7 6
+--R         e x
+--R     + 
+--R                 3 4        2 2 3         4 2  3
+--R           (7168a c  - 3584a b c  + 448a b c )d
+--R         + 
+--R                 3   3       2 3 2        5
+--R           (1536a b c  - 768a b c  + 96a b c)d
+--R      *
+--R          6 5
+--R         e x
+--R     + 
+--R                 3 4        2 2 3         4 2  4
+--R           (8960a c  - 4480a b c  + 560a b c )d
+--R         + 
+--R                 3   3        2 3 2         5   2       4 3      2 4        6
+--R           (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R      *
+--R          5 4
+--R         e x
+--R     + 
+--R                 3 4        2 2 3         4 2  5
+--R           (7168a c  - 3584a b c  + 448a b c )d
+--R         + 
+--R                 3   3        2 3 2         5   3
+--R           (5120a b c  - 2560a b c  + 320a b c)d
+--R         + 
+--R                 4 3       2 4         6
+--R           (1024a c  - 192a b c + 32a b )d
+--R      *
+--R          4 3
+--R         e x
+--R     + 
+--R                 3 4        2 2 3         4 2  6
+--R           (3584a c  - 1792a b c  + 224a b c )d
+--R         + 
+--R                 3   3        2 3 2         5   4
+--R           (3840a b c  - 1920a b c  + 240a b c)d
+--R         + 
+--R                 4 3       2 4         6  2       4   2       3 3       2 5
+--R           (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R      *
+--R          3 2
+--R         e x
+--R     + 
+--R                 3 4       2 2 3        4 2  7
+--R           (1024a c  - 512a b c  + 64a b c )d
+--R         + 
+--R                 3   3       2 3 2        5   5
+--R           (1536a b c  - 768a b c  + 96a b c)d
+--R         + 
+--R                 4 3       2 4         6  3        4   2       3 3       2 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R      *
+--R          2
+--R         e x
+--R     + 
+--R                3 4      2 2 3       4 2  8
+--R           (128a c  - 64a b c  + 8a b c )d
+--R         + 
+--R                3   3       2 3 2        5   6        4 3      2 4        6  4
+--R           (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R      *
+--R         e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1019
+
+--S 1020 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                       +--------------------+
+--R                                         +-----------+ |   +-----------+
+--R             3 2      2 2        4   +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                              2 2        2     4  8
+--R                       (- 625a c  + 50a b c - b )f
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      3   3       2 3 2        5     7  4
+--R                (1680a b c  + 280a b c  - 35a b c + b )f
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                2 2        2     4  8
+--R                         (- 625a c  + 50a b c - b )f
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               5   5         4 3 4         3 5 3        2 7 2
+--R                      - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                    + 
+--R                              9      11
+--R                      - 212a b c + 4b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                     2 2        2     4  8
+--R                              (- 625a c  + 50a b c - b )f
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             3   3       2 3 2        5     7  4
+--R                       (1680a b c  + 280a b c  - 35a b c + b )f
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e f x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d f
+--R     + 
+--R                                                         +--------------------+
+--R                                           +-----------+ |   +-----------+
+--R               3 2      2 2        4   +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                              2 2        2     4  8
+--R                       (- 625a c  + 50a b c - b )f
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      3   3       2 3 2        5     7  4
+--R                (1680a b c  + 280a b c  - 35a b c + b )f
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               10 7            9 2 6           8 4 5
+--R                      41943040a  c  - 33554432a b c  + 1572864a b c
+--R                    + 
+--R                              7 6 4           6 8 3          5 10 2
+--R                      6553600a b c  - 2785280a b c  + 491520a b  c
+--R                    + 
+--R                              4 12         3 14
+--R                      - 38912a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                2 2        2     4  8
+--R                         (- 625a c  + 50a b c - b )f
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                    + 
+--R                            9      11
+--R                      212a b c - 4b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                     2 2        2     4  8
+--R                              (- 625a c  + 50a b c - b )f
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             3   3       2 3 2        5     7  4
+--R                       (1680a b c  + 280a b c  - 35a b c + b )f
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e f x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d f
+--R     + 
+--R                                                       +--------------------+
+--R                                         +-----------+ |   +-----------+
+--R             3 2      2 2        4   +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                              2 2        2     4  8
+--R                       (- 625a c  + 50a b c - b )f
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      3   3       2 3 2        5     7  4
+--R                (1680a b c  + 280a b c  - 35a b c + b )f
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                2 2        2     4  8
+--R                         (- 625a c  + 50a b c - b )f
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                               5   5         4 3 4         3 5 3        2 7 2
+--R                      - 102400a b c  + 87296a b c  - 27328a b c  + 3760a b c
+--R                    + 
+--R                              9      11
+--R                      - 212a b c + 4b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                     2 2        2     4  8
+--R                              (- 625a c  + 50a b c - b )f
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             3   3       2 3 2        5     7  4
+--R                       (1680a b c  + 280a b c  - 35a b c + b )f
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e f x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d f
+--R     + 
+--R                                                         +--------------------+
+--R                                           +-----------+ |   +-----------+
+--R               3 2      2 2        4   +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                              2 2        2     4  8
+--R                       (- 625a c  + 50a b c - b )f
+--R                    /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      3   3       2 3 2        5     7  4
+--R                (1680a b c  + 280a b c  - 35a b c + b )f
+--R           /
+--R                         8 5          7 2 4         6 4 3         5 6 2
+--R                  131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       4 8        3 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 10 7            9 2 6           8 4 5
+--R                      - 41943040a  c  + 33554432a b c  - 1572864a b c
+--R                    + 
+--R                                7 6 4           6 8 3          5 10 2
+--R                      - 6553600a b c  + 2785280a b c  - 491520a b  c
+--R                    + 
+--R                            4 12         3 14
+--R                      38912a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                2 2        2     4  8
+--R                         (- 625a c  + 50a b c - b )f
+--R                      /
+--R                                      11 5            10 2 4            9 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                           + 
+--R                                        8 6 2           7 8          6 10
+--R                             - 10485760a b c  + 1310720a b c - 65536a b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                             5   5         4 3 4         3 5 3        2 7 2
+--R                      102400a b c  - 87296a b c  + 27328a b c  - 3760a b c
+--R                    + 
+--R                            9      11
+--R                      212a b c - 4b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                     2 2        2     4  8
+--R                              (- 625a c  + 50a b c - b )f
+--R                           /
+--R                                           11 5            10 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           9 4 3            8 6 2           7 8
+--R                                  41943040a b c  - 10485760a b c  + 1310720a b c
+--R                                + 
+--R                                          6 10
+--R                                  - 65536a b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             3   3       2 3 2        5     7  4
+--R                       (1680a b c  + 280a b c  - 35a b c + b )f
+--R                  /
+--R                                8 5          7 2 4         6 4 3         5 6 2
+--R                         131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              4 8        3 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )e f x
+--R            + 
+--R                     3 5         2 2 4          4 3      6 2    6
+--R              (10000a c  + 15000a b c  - 1491a b c  + 35b c )d f
+--R     + 
+--R                           +-----------+
+--R                      2  2 |          2                3  2  +-+
+--R         ((- 20a c - b )f \|- 4a c + b   + (52a b c - b )f )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                       +-+ +-+
+--R          | |          2              (e x + d)\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                           +-----------+
+--R                      2  2 |          2                  3  2  +-+
+--R         ((- 20a c - b )f \|- 4a c + b   + (- 52a b c + b )f )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R            3 2      2 2        4   +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1020
+
+--S 1021 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1021
+
+)clear all
+
+--S 1022 of 1057
+t0:=(d*f+e*f*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R     e f x + d f
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1022
+
+--S 1023 of 1057
+r0:=-1/4*f*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)+_
+   3/2*c*f*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   6*c^2*f*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e)
+--R 
+--R
+--R   (2)
+--R                4 8   8       4   7   7          4 2        3  6   6
+--R           - 24c e f x  - 192c d e f x  + (- 672c d  - 48b c )e f x
+--R         + 
+--R                   4 3         3   5   5
+--R           (- 1344c d  - 288b c d)e f x
+--R         + 
+--R                   4 4         3 2        3      2 2  4   4
+--R           (- 1680c d  - 720b c d  - 48a c  - 24b c )e f x
+--R         + 
+--R                   4 5         3 3            3      2 2    3   3
+--R           (- 1344c d  - 960b c d  + (- 192a c  - 96b c )d)e f x
+--R         + 
+--R                  4 6         3 4            3       2 2  2          2  2   2
+--R           (- 672c d  - 720b c d  + (- 288a c  - 144b c )d  - 48a b c )e f x
+--R         + 
+--R                  4 7         3 5            3      2 2  3          2
+--R           (- 192c d  - 288b c d  + (- 192a c  - 96b c )d  - 96a b c d)e f x
+--R         + 
+--R                 4 8        3 6           3      2 2  4          2 2      2 2
+--R           (- 24c d  - 48b c d  + (- 48a c  - 24b c )d  - 48a b c d  - 24a c )f
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R              3 6   6      3   5   5        3 2        2  4   4
+--R           12c e f x  + 72c d e f x  + (180c d  + 18b c )e f x
+--R         + 
+--R                3 3        2   3   3
+--R           (240c d  + 72b c d)e f x
+--R         + 
+--R                3 4         2 2        2     2   2   2
+--R           (180c d  + 108b c d  + 20a c  + 4b c)e f x
+--R         + 
+--R               3 5        2 3         2     2
+--R           (72c d  + 72b c d  + (40a c  + 8b c)d)e f x
+--R         + 
+--R               3 6        2 4         2     2   2              3
+--R           (12c d  + 18b c d  + (20a c  + 4b c)d  + 10a b c - b )f
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  9 8        2 4         2 3      4 2    8 7
+--R         (64a c  - 32a b c  + 4b c )e x  + (512a c  - 256a b c  + 32b c )d e x
+--R       + 
+--R                2 4         2 3       4 2  2       2   3        3 2     5   7 6
+--R         ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                  2   3         3 2      5
+--R             (768a b c  - 384a b c  + 48b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (4480a c  - 2240a b c  + 280b c )d
+--R           + 
+--R                   2   3         3 2       5   2       3 3        4      6
+--R             (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4         2 3       4 2  6
+--R             (1792a c  - 896a b c  + 112b c )d
+--R           + 
+--R                   2   3         3 2       5   4        3 3         4       6  2
+--R             (1920a b c  - 960a b c  + 120b c)d  + (768a c  - 144a b c + 24b )d
+--R           + 
+--R                 3   2      2 3        5
+--R             128a b c  - 64a b c + 8a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  2 4         2 3      4 2  7
+--R             (512a c  - 256a b c  + 32b c )d
+--R           + 
+--R                  2   3         3 2      5   5        3 3        4       6  3
+--R             (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 2 4        2 3     4 2  8        2   3        3 2     5   6
+--R             (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2      2 3        5  2
+--R             (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                4 2      3 2      2 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1023
+
+--S 1024 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                4 8   8      4   7   7        4 2        3  6   6
+--R             12c e f x  + 96c d e f x  + (336c d  + 24b c )e f x
+--R           + 
+--R                  4 3         3   5   5
+--R             (672c d  + 144b c d)e f x
+--R           + 
+--R                  4 4         3 2        3      2 2  4   4
+--R             (840c d  + 360b c d  + 24a c  + 12b c )e f x
+--R           + 
+--R                  4 5         3 3         3      2 2    3   3
+--R             (672c d  + 480b c d  + (96a c  + 48b c )d)e f x
+--R           + 
+--R                  4 6         3 4          3      2 2  2          2  2   2
+--R             (336c d  + 360b c d  + (144a c  + 72b c )d  + 24a b c )e f x
+--R           + 
+--R                 4 7         3 5         3      2 2  3          2
+--R             (96c d  + 144b c d  + (96a c  + 48b c )d  + 48a b c d)e f x
+--R           + 
+--R                 4 8        3 6         3      2 2  4          2 2      2 2
+--R             (12c d  + 24b c d  + (24a c  + 12b c )d  + 24a b c d  + 12a c )f
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                       2     2   2 2         2     2               2     2   2
+--R                  (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                3 6   6      3   5   5        3 2        2  4   4
+--R             12c e f x  + 72c d e f x  + (180c d  + 18b c )e f x
+--R           + 
+--R                  3 3        2   3   3
+--R             (240c d  + 72b c d)e f x
+--R           + 
+--R                  3 4         2 2        2     2   2   2
+--R             (180c d  + 108b c d  + 20a c  + 4b c)e f x
+--R           + 
+--R                 3 5        2 3         2     2
+--R             (72c d  + 72b c d  + (40a c  + 8b c)d)e f x
+--R           + 
+--R                 3 6        2 4         2     2   2              3
+--R             (12c d  + 18b c d  + (20a c  + 4b c)d  + 10a b c - b )f
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                4 8   8       4   7   7        4 2        3  6   6
+--R             24c e f x  + 192c d e f x  + (672c d  + 48b c )e f x
+--R           + 
+--R                   4 3         3   5   5
+--R             (1344c d  + 288b c d)e f x
+--R           + 
+--R                   4 4         3 2        3      2 2  4   4
+--R             (1680c d  + 720b c d  + 48a c  + 24b c )e f x
+--R           + 
+--R                   4 5         3 3          3      2 2    3   3
+--R             (1344c d  + 960b c d  + (192a c  + 96b c )d)e f x
+--R           + 
+--R                  4 6         3 4          3       2 2  2          2  2   2
+--R             (672c d  + 720b c d  + (288a c  + 144b c )d  + 48a b c )e f x
+--R           + 
+--R                  4 7         3 5          3      2 2  3          2
+--R             (192c d  + 288b c d  + (192a c  + 96b c )d  + 96a b c d)e f x
+--R           + 
+--R                 4 8        3 6         3      2 2  4          2 2      2 2
+--R             (24c d  + 48b c d  + (48a c  + 24b c )d  + 48a b c d  + 24a c )f
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                3 6   6      3   5   5        3 2        2  4   4
+--R             12c e f x  + 72c d e f x  + (180c d  + 18b c )e f x
+--R           + 
+--R                  3 3        2   3   3
+--R             (240c d  + 72b c d)e f x
+--R           + 
+--R                  3 4         2 2        2     2   2   2
+--R             (180c d  + 108b c d  + 20a c  + 4b c)e f x
+--R           + 
+--R                 3 5        2 3         2     2
+--R             (72c d  + 72b c d  + (40a c  + 8b c)d)e f x
+--R           + 
+--R                 3 6        2 4         2     2   2              3
+--R             (12c d  + 18b c d  + (20a c  + 4b c)d  + 10a b c - b )f
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 4        2 3     4 2  9 8
+--R           (64a c  - 32a b c  + 4b c )e x
+--R         + 
+--R                2 4         2 3      4 2    8 7
+--R           (512a c  - 256a b c  + 32b c )d e x
+--R         + 
+--R                    2 4         2 3       4 2  2       2   3        3 2     5
+--R             ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                    2   3         3 2      5
+--R               (768a b c  - 384a b c  + 48b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  4
+--R               (4480a c  - 2240a b c  + 280b c )d
+--R             + 
+--R                     2   3         3 2       5   2       3 3        4      6
+--R               (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (3584a c  - 1792a b c  + 224b c )d
+--R             + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     2 4         2 3       4 2  6
+--R               (1792a c  - 896a b c  + 112b c )d
+--R             + 
+--R                     2   3         3 2       5   4
+--R               (1920a b c  - 960a b c  + 120b c)d
+--R             + 
+--R                    3 3         4       6  2       3   2      2 3        5
+--R               (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    2 4         2 3      4 2  7
+--R               (512a c  - 256a b c  + 32b c )d
+--R             + 
+--R                    2   3         3 2      5   5        3 3        4       6  3
+--R               (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1024
+
+--S 1025 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           2
+--R         3c f
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                     2     2   2 2         2     2               2     2   2
+--R                (8a c  - 2b c)e x  + (16a c  - 4b c)d e x + (8a c  - 2b c)d
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                      2 2                  2
+--R         2        2c e x  + 4c d e x + 2c d  + b
+--R       6c f atanh(------------------------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R                             +-----------+
+--R         2 2       2     4   |          2
+--R     (16a c  - 8a b c + b )e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1025
+
+--S 1026 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1026
+
+--S 1027 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            +---------+          2 2                  2
+--R         2  |        2       2c e x  + 4c d e x + 2c d  + b
+--R       6c f\|4a c - b  atanh(------------------------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R            +-----------+          2 2                  2      |        2
+--R         2  |          2      (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R       6c f\|- 4a c + b  atan(--------------------------------------------)
+--R                                                        2
+--R                                                4a c - b
+--R  /
+--R                             +-----------+ +---------+
+--R         2 2       2     4   |          2  |        2
+--R     (16a c  - 8a b c + b )e\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1027
+
+--S 1028 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1028
+
+)clear all
+
+--S 1029 of 1057
+t0:=1/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1029
+
+--S 1030 of 1057
+r0:=1/4*(d+e*x)*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/8*(d+e*x)*((b^2-7*a*c)*(3*b^2-4*a*c)+3*b*c*(b^2-8*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (b^3-8*a*b*c+(b^4-10*a*b^2*c+56*a^2*c^2)/sqrt(b^2-4*a*c))/(a^2*(b^2-_
+   4*a*c)^2*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+3/8*atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b^3-8*a*b*c+(-b^4+10*a*b^2*c-_
+   56*a^2*c^2)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                         3     3 2  8 8              3      3 2    7 7
+--R               (- 24a b c  + 3b c )e x  + (- 192a b c  + 24b c )d e x
+--R             + 
+--R                           3      3 2  2        2 2     4   6 6
+--R               ((- 672a b c  + 84b c )d  - 48a b c  + 6b c)e x
+--R             + 
+--R                            3       3 2  3            2 2      4     5 5
+--R               ((- 1344a b c  + 168b c )d  + (- 288a b c  + 36b c)d)e x
+--R             + 
+--R                               3       3 2  4            2 2      4   2
+--R                   (- 1680a b c  + 210b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                        2   2        3      5
+--R                   - 48a b c  - 18a b c + 3b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                               3       3 2  5            2 2       4   3
+--R                   (- 1344a b c  + 168b c )d  + (- 960a b c  + 120b c)d
+--R                 + 
+--R                          2   2        3       5
+--R                   (- 192a b c  - 72a b c + 12b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                              3      3 2  6            2 2      4   4
+--R                   (- 672a b c  + 84b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                          2   2         3       5  2      2 2        4
+--R                   (- 288a b c  - 108a b c + 18b )d  - 48a b c + 6a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                              3      3 2  7            2 2      4   5
+--R                   (- 192a b c  + 24b c )d  + (- 288a b c  + 36b c)d
+--R                 + 
+--R                          2   2        3       5  3         2 2         4
+--R                   (- 192a b c  - 72a b c + 12b )d  + (- 96a b c + 12a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )d  + (- 48a b c  + 6b c)d
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )d  + (- 48a b c + 6a b )d  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4        2 3     4 2  8 8
+--R           (168a c  - 30a b c  + 3b c )e x
+--R         + 
+--R                 2 4         2 3      4 2    7 7
+--R           (1344a c  - 240a b c  + 24b c )d e x
+--R         + 
+--R                  2 4         2 3      4 2  2       2   3        3 2     5   6 6
+--R           ((4704a c  - 840a b c  + 84b c )d  + 336a b c  - 60a b c  + 6b c)e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (9408a c  - 1680a b c  + 168b c )d
+--R             + 
+--R                     2   3         3 2      5
+--R               (2016a b c  - 360a b c  + 36b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      2 4          2 3       4 2  4
+--R               (11760a c  - 2100a b c  + 210b c )d
+--R             + 
+--R                     2   3         3 2      5   2       3 3       2 2 2
+--R               (5040a b c  - 900a b c  + 90b c)d  + 336a c  + 108a b c
+--R             + 
+--R                      4      6
+--R               - 24a b c + 3b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (9408a c  - 1680a b c  + 168b c )d
+--R             + 
+--R                     2   3          3 2       5   3
+--R               (6720a b c  - 1200a b c  + 120b c)d
+--R             + 
+--R                     3 3       2 2 2        4       6
+--R               (1344a c  + 432a b c  - 96a b c + 12b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2 4         2 3      4 2  6
+--R               (4704a c  - 840a b c  + 84b c )d
+--R             + 
+--R                     2   3         3 2      5   4
+--R               (5040a b c  - 900a b c  + 90b c)d
+--R             + 
+--R                     3 3       2 2 2         4       6  2       3   2      2 3
+--R               (2016a c  + 648a b c  - 144a b c + 18b )d  + 336a b c  - 60a b c
+--R             + 
+--R                   5
+--R               6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2 4         2 3      4 2  7
+--R               (1344a c  - 240a b c  + 24b c )d
+--R             + 
+--R                     2   3         3 2      5   5
+--R               (2016a b c  - 360a b c  + 36b c)d
+--R             + 
+--R                     3 3       2 2 2        4       6  3
+--R               (1344a c  + 432a b c  - 96a b c + 12b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (672a b c  - 120a b c + 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (168a c  - 30a b c  + 3b c )d  + (336a b c  - 60a b c  + 6b c)d
+--R         + 
+--R                3 3       2 2 2        4      6  4
+--R           (336a c  + 108a b c  - 24a b c + 3b )d
+--R         + 
+--R                3   2      2 3        5  2       4 2      3 2      2 4
+--R           (336a b c  - 60a b c + 6a b )d  + 168a c  - 30a b c + 3a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                         3     3 2  8 8              3      3 2    7 7
+--R               (- 24a b c  + 3b c )e x  + (- 192a b c  + 24b c )d e x
+--R             + 
+--R                           3      3 2  2        2 2     4   6 6
+--R               ((- 672a b c  + 84b c )d  - 48a b c  + 6b c)e x
+--R             + 
+--R                            3       3 2  3            2 2      4     5 5
+--R               ((- 1344a b c  + 168b c )d  + (- 288a b c  + 36b c)d)e x
+--R             + 
+--R                               3       3 2  4            2 2      4   2
+--R                   (- 1680a b c  + 210b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                        2   2        3      5
+--R                   - 48a b c  - 18a b c + 3b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                               3       3 2  5            2 2       4   3
+--R                   (- 1344a b c  + 168b c )d  + (- 960a b c  + 120b c)d
+--R                 + 
+--R                          2   2        3       5
+--R                   (- 192a b c  - 72a b c + 12b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                              3      3 2  6            2 2      4   4
+--R                   (- 672a b c  + 84b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                          2   2         3       5  2      2 2        4
+--R                   (- 288a b c  - 108a b c + 18b )d  - 48a b c + 6a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                              3      3 2  7            2 2      4   5
+--R                   (- 192a b c  + 24b c )d  + (- 288a b c  + 36b c)d
+--R                 + 
+--R                          2   2        3       5  3         2 2         4
+--R                   (- 192a b c  - 72a b c + 12b )d  + (- 96a b c + 12a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )d  + (- 48a b c  + 6b c)d
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )d  + (- 48a b c + 6a b )d  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4        2 3     4 2  8 8
+--R           (- 168a c  + 30a b c  - 3b c )e x
+--R         + 
+--R                   2 4         2 3      4 2    7 7
+--R           (- 1344a c  + 240a b c  - 24b c )d e x
+--R         + 
+--R                      2 4         2 3      4 2  2       2   3        3 2     5
+--R             ((- 4704a c  + 840a b c  - 84b c )d  - 336a b c  + 60a b c  - 6b c)
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  3
+--R               (- 9408a c  + 1680a b c  - 168b c )d
+--R             + 
+--R                       2   3         3 2      5
+--R               (- 2016a b c  + 360a b c  - 36b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  4
+--R               (- 11760a c  + 2100a b c  - 210b c )d
+--R             + 
+--R                       2   3         3 2      5   2       3 3       2 2 2
+--R               (- 5040a b c  + 900a b c  - 90b c)d  - 336a c  - 108a b c
+--R             + 
+--R                    4      6
+--R               24a b c - 3b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  5
+--R               (- 9408a c  + 1680a b c  - 168b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 6720a b c  + 1200a b c  - 120b c)d
+--R             + 
+--R                       3 3       2 2 2        4       6
+--R               (- 1344a c  - 432a b c  + 96a b c - 12b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 4         2 3      4 2  6
+--R               (- 4704a c  + 840a b c  - 84b c )d
+--R             + 
+--R                       2   3         3 2      5   4
+--R               (- 5040a b c  + 900a b c  - 90b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  2       3   2
+--R               (- 2016a c  - 648a b c  + 144a b c - 18b )d  - 336a b c
+--R             + 
+--R                  2 3        5
+--R               60a b c - 6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2 4         2 3      4 2  7
+--R               (- 1344a c  + 240a b c  - 24b c )d
+--R             + 
+--R                       2   3         3 2      5   5
+--R               (- 2016a b c  + 360a b c  - 36b c)d
+--R             + 
+--R                       3 3       2 2 2        4       6  3
+--R               (- 1344a c  - 432a b c  + 96a b c - 12b )d
+--R             + 
+--R                      3   2       2 3         5
+--R               (- 672a b c  + 120a b c - 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                  2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 168a c  + 30a b c  - 3b c )d  + (- 336a b c  + 60a b c  - 6b c)d
+--R         + 
+--R                  3 3       2 2 2        4      6  4
+--R           (- 336a c  - 108a b c  + 24a b c - 3b )d
+--R         + 
+--R                  3   2      2 3        5  2       4 2      3 2      2 4
+--R           (- 336a b c  + 60a b c - 6a b )d  - 168a c  + 30a b c - 3a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                     3     3 2  7 7              3      3 2    6 6
+--R           (- 24a b c  + 3b c )e x  + (- 168a b c  + 21b c )d e x
+--R         + 
+--R                       3      3 2  2      2 3        2 2     4   5 5
+--R           ((- 504a b c  + 63b c )d  + 28a c  - 49a b c  + 6b c)e x
+--R         + 
+--R                       3       3 2  3        2 3         2 2      4     4 4
+--R           ((- 840a b c  + 105b c )d  + (140a c  - 245a b c  + 30b c)d)e x
+--R         + 
+--R                          3       3 2  4        2 3         2 2      4   2
+--R               (- 840a b c  + 105b c )d  + (280a c  - 490a b c  + 60b c)d
+--R             + 
+--R                   2   2        3      5
+--R               - 4a b c  - 20a b c + 3b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                          3      3 2  5        2 3         2 2      4   3
+--R               (- 504a b c  + 63b c )d  + (280a c  - 490a b c  + 60b c)d
+--R             + 
+--R                     2   2        3      5
+--R               (- 12a b c  - 60a b c + 9b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                          3      3 2  6        2 3         2 2      4   4
+--R               (- 168a b c  + 21b c )d  + (140a c  - 245a b c  + 30b c)d
+--R             + 
+--R                     2   2        3      5  2      3 2      2 2        4
+--R               (- 12a b c  - 60a b c + 9b )d  + 44a c  - 37a b c + 5a b
+--R          *
+--R             e x
+--R         + 
+--R                     3     3 2  7       2 3        2 2     4   5
+--R           (- 24a b c  + 3b c )d  + (28a c  - 49a b c  + 6b c)d
+--R         + 
+--R                2   2        3      5  3       3 2      2 2        4
+--R           (- 4a b c  - 20a b c + 3b )d  + (44a c  - 37a b c + 5a b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              4 4      3 2 3     2 4 2  9 8
+--R         (128a c  - 64a b c  + 8a b c )e x
+--R       + 
+--R               4 4       3 2 3      2 4 2    8 7
+--R         (1024a c  - 512a b c  + 64a b c )d e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  2       4   3       3 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                2 5
+--R             16a b c
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  3
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   4   3       3 3 2      2 5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  4
+--R             (8960a c  - 4480a b c  + 560a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   2       5 3      3 4      2 6
+--R             (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  5
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   3
+--R             (5120a b c  - 2560a b c  + 320a b c)d
+--R           + 
+--R                   5 3       3 4       2 6
+--R             (1024a c  - 192a b c + 32a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  6
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   4
+--R             (3840a b c  - 1920a b c  + 240a b c)d
+--R           + 
+--R                   5 3       3 4       2 6  2       5   2       4 3       3 5
+--R             (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   4 4       3 2 3      2 4 2  7
+--R             (1024a c  - 512a b c  + 64a b c )d
+--R           + 
+--R                   4   3       3 3 2      2 5   5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R           + 
+--R                 5 3       3 4       2 6  3        5   2       4 3       3 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  4 4      3 2 3     2 4 2  8
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  4   3       3 3 2      2 5   6        5 3      3 4      2 6  4
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  5   2       4 3       3 5  2       6 2      5 2      4 4
+--R             (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1030
+
+--S 1031 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 4      3 2 3     2 4 2  9 8
+--R           (64a c  - 32a b c  + 4a b c )e x
+--R         + 
+--R                4 4       3 2 3      2 4 2    8 7
+--R           (512a c  - 256a b c  + 32a b c )d e x
+--R         + 
+--R                     4 4       3 2 3       2 4 2  2       4   3      3 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 2 5
+--R               8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    4   3       3 3 2      2 5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   4   3       3 3 2       2 5   2       5 3      3 4      2 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     4   3        3 3 2       2 5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    5 3      3 4       2 6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     4 4       3 2 3       2 4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     4   3       3 3 2       2 5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    5 3       3 4       2 6  2       5   2      4 3      3 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    4 4       3 2 3      2 4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    4   3       3 3 2      2 5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  5 3      3 4       2 6  3        5   2       4 3       3 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   4 4      3 2 3     2 4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    4   3      3 3 2     2 5   6        5 3      3 4      2 6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    5   2      4 3      3 5  2      6 2      5 2      4 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                              7 7           6 2 6           5 4 5          4 6 4
+--R                      3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                    + 
+--R                             3 8 3         2 10 2          12       14
+--R                      139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                 4 4      3 2 3     2 4 2  9 8
+--R           (- 64a c  + 32a b c  - 4a b c )e x
+--R         + 
+--R                  4 4       3 2 3      2 4 2    8 7
+--R           (- 512a c  + 256a b c  - 32a b c )d e x
+--R         + 
+--R                       4 4       3 2 3       2 4 2  2       4   3      3 3 2
+--R               (- 1792a c  + 896a b c  - 112a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                   2 5
+--R               - 8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  3
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                      4   3       3 3 2      2 5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  4
+--R               (- 4480a c  + 2240a b c  - 280a b c )d
+--R             + 
+--R                     4   3       3 3 2       2 5   2       5 3      3 4      2 6
+--R             (- 1920a b c  + 960a b c  - 120a b c)d  - 128a c  + 24a b c - 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  5
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                       4   3        3 3 2       2 5   3
+--R               (- 2560a b c  + 1280a b c  - 160a b c)d
+--R             + 
+--R                      5 3      3 4       2 6
+--R               (- 512a c  + 96a b c - 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       4 4       3 2 3       2 4 2  6
+--R               (- 1792a c  + 896a b c  - 112a b c )d
+--R             + 
+--R                       4   3       3 3 2       2 5   4
+--R               (- 1920a b c  + 960a b c  - 120a b c)d
+--R             + 
+--R                      5 3       3 4       2 6  2       5   2      4 3      3 5
+--R               (- 768a c  + 144a b c - 24a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      4 4       3 2 3      2 4 2  7
+--R               (- 512a c  + 256a b c  - 32a b c )d
+--R             + 
+--R                      4   3       3 3 2      2 5   5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R             + 
+--R                      5 3      3 4       2 6  3
+--R               (- 512a c  + 96a b c - 16a b )d
+--R             + 
+--R                      5   2       4 3       3 5
+--R               (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     4 4      3 2 3     2 4 2  8
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      4   3      3 3 2     2 5   6
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      5 3      3 4      2 6  4
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                      5   2      4 3      3 5  2      6 2      5 2      4 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                7 7           6 2 6           5 4 5
+--R                      - 3161088a c  + 4096512a b c  - 2292480a b c
+--R                    + 
+--R                             4 6 4          3 8 3         2 10 2          12
+--R                      723168a b c  - 139860a b c  + 16704a b  c  - 1152a b  c
+--R                    + 
+--R                         14
+--R                      36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R               4 4      3 2 3     2 4 2  9 8
+--R           (64a c  - 32a b c  + 4a b c )e x
+--R         + 
+--R                4 4       3 2 3      2 4 2    8 7
+--R           (512a c  - 256a b c  + 32a b c )d e x
+--R         + 
+--R                     4 4       3 2 3       2 4 2  2       4   3      3 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 2 5
+--R               8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    4   3       3 3 2      2 5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   4   3       3 3 2       2 5   2       5 3      3 4      2 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                     4 4        3 2 3       2 4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     4   3        3 3 2       2 5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    5 3      3 4       2 6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                     4 4       3 2 3       2 4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     4   3       3 3 2       2 5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    5 3       3 4       2 6  2       5   2      4 3      3 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                    4 4       3 2 3      2 4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    4   3       3 3 2      2 5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  5 3      3 4       2 6  3        5   2       4 3       3 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                   4 4      3 2 3     2 4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    4   3      3 3 2     2 5   6        5 3      3 4      2 6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    5   2      4 3      3 5  2      6 2      5 2      4 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                              7 7           6 2 6           5 4 5          4 6 4
+--R                      3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                    + 
+--R                             3 8 3         2 10 2          12       14
+--R                      139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                 4 4      3 2 3     2 4 2  9 8
+--R           (- 64a c  + 32a b c  - 4a b c )e x
+--R         + 
+--R                  4 4       3 2 3      2 4 2    8 7
+--R           (- 512a c  + 256a b c  - 32a b c )d e x
+--R         + 
+--R                       4 4       3 2 3       2 4 2  2       4   3      3 3 2
+--R               (- 1792a c  + 896a b c  - 112a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                   2 5
+--R               - 8a b c
+--R          *
+--R              7 6
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  3
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                      4   3       3 3 2      2 5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R          *
+--R              6 5
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  4
+--R               (- 4480a c  + 2240a b c  - 280a b c )d
+--R             + 
+--R                     4   3       3 3 2       2 5   2       5 3      3 4      2 6
+--R             (- 1920a b c  + 960a b c  - 120a b c)d  - 128a c  + 24a b c - 4a b
+--R          *
+--R              5 4
+--R             e x
+--R         + 
+--R                       4 4        3 2 3       2 4 2  5
+--R               (- 3584a c  + 1792a b c  - 224a b c )d
+--R             + 
+--R                       4   3        3 3 2       2 5   3
+--R               (- 2560a b c  + 1280a b c  - 160a b c)d
+--R             + 
+--R                      5 3      3 4       2 6
+--R               (- 512a c  + 96a b c - 16a b )d
+--R          *
+--R              4 3
+--R             e x
+--R         + 
+--R                       4 4       3 2 3       2 4 2  6
+--R               (- 1792a c  + 896a b c  - 112a b c )d
+--R             + 
+--R                       4   3       3 3 2       2 5   4
+--R               (- 1920a b c  + 960a b c  - 120a b c)d
+--R             + 
+--R                      5 3       3 4       2 6  2       5   2      4 3      3 5
+--R               (- 768a c  + 144a b c - 24a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              3 2
+--R             e x
+--R         + 
+--R                      4 4       3 2 3      2 4 2  7
+--R               (- 512a c  + 256a b c  - 32a b c )d
+--R             + 
+--R                      4   3       3 3 2      2 5   5
+--R               (- 768a b c  + 384a b c  - 48a b c)d
+--R             + 
+--R                      5 3      3 4       2 6  3
+--R               (- 512a c  + 96a b c - 16a b )d
+--R             + 
+--R                      5   2       4 3       3 5
+--R               (- 256a b c  + 128a b c - 16a b )d
+--R          *
+--R              2
+--R             e x
+--R         + 
+--R                     4 4      3 2 3     2 4 2  8
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      4   3      3 3 2     2 5   6
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      5 3      3 4      2 6  4
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                      5   2      4 3      3 5  2      6 2      5 2      4 4
+--R               (- 128a b c  + 64a b c - 8a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R             e
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                7 7           6 2 6           5 4 5
+--R                      - 3161088a c  + 4096512a b c  - 2292480a b c
+--R                    + 
+--R                             4 6 4          3 8 3         2 10 2          12
+--R                      723168a b c  - 139860a b c  + 16704a b  c  - 1152a b  c
+--R                    + 
+--R                         14
+--R                      36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                 3     3 2  7 7              3      3 2    6 6
+--R       (- 24a b c  + 3b c )e x  + (- 168a b c  + 21b c )d e x
+--R     + 
+--R                   3      3 2  2      2 3        2 2     4   5 5
+--R       ((- 504a b c  + 63b c )d  + 28a c  - 49a b c  + 6b c)e x
+--R     + 
+--R                   3       3 2  3        2 3         2 2      4     4 4
+--R       ((- 840a b c  + 105b c )d  + (140a c  - 245a b c  + 30b c)d)e x
+--R     + 
+--R                      3       3 2  4        2 3         2 2      4   2     2   2
+--R           (- 840a b c  + 105b c )d  + (280a c  - 490a b c  + 60b c)d  - 4a b c
+--R         + 
+--R                  3      5
+--R           - 20a b c + 3b
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R                      3      3 2  5        2 3         2 2      4   3
+--R           (- 504a b c  + 63b c )d  + (280a c  - 490a b c  + 60b c)d
+--R         + 
+--R                 2   2        3      5
+--R           (- 12a b c  - 60a b c + 9b )d
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R                      3      3 2  6        2 3         2 2      4   4
+--R           (- 168a b c  + 21b c )d  + (140a c  - 245a b c  + 30b c)d
+--R         + 
+--R                 2   2        3      5  2      3 2      2 2        4
+--R           (- 12a b c  - 60a b c + 9b )d  + 44a c  - 37a b c + 5a b
+--R      *
+--R         e x
+--R     + 
+--R                 3     3 2  7       2 3        2 2     4   5
+--R       (- 24a b c  + 3b c )d  + (28a c  - 49a b c  + 6b c)d
+--R     + 
+--R            2   2        3      5  3       3 2      2 2        4
+--R       (- 4a b c  - 20a b c + 3b )d  + (44a c  - 37a b c + 5a b )d
+--R  /
+--R            4 4      3 2 3     2 4 2  9 8
+--R       (128a c  - 64a b c  + 8a b c )e x
+--R     + 
+--R             4 4       3 2 3      2 4 2    8 7
+--R       (1024a c  - 512a b c  + 64a b c )d e x
+--R     + 
+--R                   4 4        3 2 3       2 4 2  2       4   3       3 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                2 5
+--R             16a b c
+--R      *
+--R          7 6
+--R         e x
+--R     + 
+--R                 4 4        3 2 3       2 4 2  3
+--R           (7168a c  - 3584a b c  + 448a b c )d
+--R         + 
+--R                 4   3       3 3 2      2 5
+--R           (1536a b c  - 768a b c  + 96a b c)d
+--R      *
+--R          6 5
+--R         e x
+--R     + 
+--R                 4 4        3 2 3       2 4 2  4
+--R           (8960a c  - 4480a b c  + 560a b c )d
+--R         + 
+--R                 4   3        3 3 2       2 5   2       5 3      3 4      2 6
+--R           (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R      *
+--R          5 4
+--R         e x
+--R     + 
+--R                 4 4        3 2 3       2 4 2  5
+--R           (7168a c  - 3584a b c  + 448a b c )d
+--R         + 
+--R                 4   3        3 3 2       2 5   3
+--R           (5120a b c  - 2560a b c  + 320a b c)d
+--R         + 
+--R                 5 3       3 4       2 6
+--R           (1024a c  - 192a b c + 32a b )d
+--R      *
+--R          4 3
+--R         e x
+--R     + 
+--R                 4 4        3 2 3       2 4 2  6
+--R           (3584a c  - 1792a b c  + 224a b c )d
+--R         + 
+--R                 4   3        3 3 2       2 5   4
+--R           (3840a b c  - 1920a b c  + 240a b c)d
+--R         + 
+--R                 5 3       3 4       2 6  2       5   2       4 3       3 5
+--R           (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R      *
+--R          3 2
+--R         e x
+--R     + 
+--R                 4 4       3 2 3      2 4 2  7
+--R           (1024a c  - 512a b c  + 64a b c )d
+--R         + 
+--R                 4   3       3 3 2      2 5   5
+--R           (1536a b c  - 768a b c  + 96a b c)d
+--R         + 
+--R                 5 3       3 4       2 6  3        5   2       4 3       3 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R      *
+--R          2
+--R         e x
+--R     + 
+--R                4 4      3 2 3     2 4 2  8
+--R           (128a c  - 64a b c  + 8a b c )d
+--R         + 
+--R                4   3       3 3 2      2 5   6        5 3      3 4      2 6  4
+--R           (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R         + 
+--R                5   2       4 3       3 5  2       6 2      5 2      4 4
+--R           (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R      *
+--R         e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1031
+
+--S 1032 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                       +--------------------+
+--R                                         +-----------+ |   +-----------+
+--R             4 2      3 2      2 4   +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                              7 7           6 2 6           5 4 5          4 6 4
+--R                      3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                    + 
+--R                             3 8 3         2 10 2          12       14
+--R                      139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                                           +-----------+
+--R               4 2      3 2      2 4   +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               12   7            11 3 6            10 5 5
+--R                      46137344a  b c  - 69206016a  b c  + 44302336a  b c
+--R                    + 
+--R                                 9 7 4           8 9 3          7 11 2
+--R                      - 15728640a b c  + 3358720a b c  - 434176a b  c
+--R                    + 
+--R                            6 13         5 15
+--R                      31744a b  c - 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                7 7           6 2 6           5 4 5
+--R                      - 3161088a c  + 4096512a b c  - 2292480a b c
+--R                    + 
+--R                             4 6 4          3 8 3         2 10 2          12
+--R                      723168a b c  - 139860a b c  + 16704a b  c  - 1152a b  c
+--R                    + 
+--R                         14
+--R                      36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                                         +-----------+
+--R             4 2      3 2      2 4   +-+ |          2
+--R         (64a c  - 32a b c + 4a b )e\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                              7 7           6 2 6           5 4 5          4 6 4
+--R                      3161088a c  - 4096512a b c  + 2292480a b c  - 723168a b c
+--R                    + 
+--R                             3 8 3         2 10 2          12       14
+--R                      139860a b c  - 16704a b  c  + 1152a b  c - 36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                                                         +--------------------+
+--R                                           +-----------+ |   +-----------+
+--R               4 2      3 2      2 4   +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2
+--R                  e
+--R               *
+--R                  ROOT
+--R                                  4 4         3 2 3         2 4 2          6
+--R                         - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                       + 
+--R                              8
+--R                         - 81b
+--R                    /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4
+--R                         e
+--R              + 
+--R                      4   4        3 3 3        2 5 2         7      9
+--R                15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R           /
+--R                         10 5          9 2 4         8 4 3         7 6 2
+--R                  131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                + 
+--R                       6 8        5 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2
+--R                e
+--R      *
+--R         log
+--R                                 12   7            11 3 6            10 5 5
+--R                      - 46137344a  b c  + 69206016a  b c  - 44302336a  b c
+--R                    + 
+--R                               9 7 4           8 9 3          7 11 2
+--R                      15728640a b c  - 3358720a b c  + 434176a b  c
+--R                    + 
+--R                              6 13         5 15
+--R                      - 31744a b  c + 1024a b
+--R                 *
+--R                     3
+--R                    e
+--R                 *
+--R                    ROOT
+--R                                    4 4         3 2 3         2 4 2          6
+--R                           - 194481a c  + 87318a b c  - 17739a b c  + 1782a b c
+--R                         + 
+--R                                8
+--R                           - 81b
+--R                      /
+--R                                      15 5            14 2 4            13 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        12 6 2           11 8          10 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4
+--R                           e
+--R                + 
+--R                                7 7           6 2 6           5 4 5
+--R                      - 3161088a c  + 4096512a b c  - 2292480a b c
+--R                    + 
+--R                             4 6 4          3 8 3         2 10 2          12
+--R                      723168a b c  - 139860a b c  + 16704a b  c  - 1152a b  c
+--R                    + 
+--R                         14
+--R                      36b
+--R                 *
+--R                    e
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2
+--R                         e
+--R                      *
+--R                         ROOT
+--R                                         4 4         3 2 3         2 4 2
+--R                                - 194481a c  + 87318a b c  - 17739a b c
+--R                              + 
+--R                                       6       8
+--R                                1782a b c - 81b
+--R                           /
+--R                                           15 5            14 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           13 4 3            12 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          11 8          10 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4
+--R                                e
+--R                     + 
+--R                             4   4        3 3 3        2 5 2         7      9
+--R                       15120a b c  - 7560a b c  + 1701a b c  - 189a b c + 9b
+--R                  /
+--R                                10 5          9 2 4         8 4 3         7 6 2
+--R                         131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                       + 
+--R                              6 8        5 10
+--R                         2560a b c - 128a b
+--R                    *
+--R                        2
+--R                       e
+--R            + 
+--R                          4 7          3 2 6          2 4 5           6 4
+--R                  1037232a c  - 518616a b c  + 113103a b c  - 12069a b c
+--R                + 
+--R                      8 3
+--R                  567b c
+--R             *
+--R                e x
+--R            + 
+--R                     4 7          3 2 6          2 4 5           6 4       8 3
+--R            (1037232a c  - 518616a b c  + 113103a b c  - 12069a b c  + 567b c )d
+--R     + 
+--R                          +-----------+
+--R                       3  |          2        2 2        2      4  +-+
+--R         ((24a b c - 3b )\|- 4a c + b   - 168a c  + 30a b c - 3b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                       +-+ +-+
+--R          | |          2              (e x + d)\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                       3  |          2        2 2        2      4  +-+
+--R         ((24a b c - 3b )\|- 4a c + b   + 168a c  - 30a b c + 3b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R            4 2      3 2      2 4   +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )e\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1032
+
+--S 1033 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1033
+
+)clear all
+
+--S 1034 of 1057
+t0:=1/((d*f+e*f*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 13   13      3   12   12       3 2       2  11   11
+--R       c e  f x   + 13c d e  f x   + (78c d  + 3b c )e  f x
+--R     + 
+--R            3 3        2   10   10        3 4         2 2       2     2   9   9
+--R       (286c d  + 33b c d)e  f x   + (715c d  + 165b c d  + 3a c  + 3b c)e f x
+--R     + 
+--R             3 5         2 3         2      2     8   8
+--R       (1287c d  + 495b c d  + (27a c  + 27b c)d)e f x
+--R     + 
+--R             3 6         2 4          2       2   2             3  7   7
+--R       (1716c d  + 990b c d  + (108a c  + 108b c)d  + 6a b c + b )e f x
+--R     + 
+--R             3 7          2 5          2       2   3                3    6   6
+--R       (1716c d  + 1386b c d  + (252a c  + 252b c)d  + (42a b c + 7b )d)e f x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           1287c d  + 1386b c d  + (378a c  + 378b c)d  + (126a b c + 21b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          5   5
+--R         e f x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           715c d  + 990b c d  + (378a c  + 378b c)d  + (210a b c + 35b )d
+--R         + 
+--R               2         2
+--R           (15a c + 15a b )d
+--R      *
+--R          4   4
+--R         e f x
+--R     + 
+--R               3 10         2 8          2       2   6                  3  4
+--R           286c d   + 495b c d  + (252a c  + 252b c)d  + (210a b c + 35b )d
+--R         + 
+--R               2         2  2     2
+--R           (30a c + 30a b )d  + 3a b
+--R      *
+--R          3   3
+--R         e f x
+--R     + 
+--R              3 11         2 9          2       2   7                  3  5
+--R           78c d   + 165b c d  + (108a c  + 108b c)d  + (126a b c + 21b )d
+--R         + 
+--R               2         2  3     2
+--R           (30a c + 30a b )d  + 9a b d
+--R      *
+--R          2   2
+--R         e f x
+--R     + 
+--R              3 12        2 10         2      2   8                3  6
+--R           13c d   + 33b c d   + (27a c  + 27b c)d  + (42a b c + 7b )d
+--R         + 
+--R               2         2  4     2   2    3
+--R           (15a c + 15a b )d  + 9a b d  + a
+--R      *
+--R         e f x
+--R     + 
+--R            3 13       2 11        2     2   9              3  7
+--R           c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d
+--R         + 
+--R              2        2  5     2   3    3
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R         f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1034
+
+--S 1035 of 1057
+r0:=1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/4*(2*b^4-15*a*b^2*c+16*a^2*c^2+2*b*c*(b^2-7*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*f*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   1/2*b*(b^4-10*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-_
+   4*a*c))/(a^3*(b^2-4*a*c)^(5/2)*e*f)+log(d+e*x)/(a^3*e*f)-1/4*log(a+_
+   b*(d+e*x)^2+c*(d+e*x)^4)/(a^3*e*f)
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  8 8
+--R           (60a b c  - 20a b c  + 2b c )e x
+--R         + 
+--R                2   4         3 3      5 2    7 7
+--R           (480a b c  - 160a b c  + 16b c )d e x
+--R         + 
+--R                    2   4         3 3      5 2  2       2 2 3        4 2     6
+--R             ((1680a b c  - 560a b c  + 56b c )d  + 120a b c  - 40a b c  + 4b c)
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  3
+--R               (3360a b c  - 1120a b c  + 112b c )d
+--R             + 
+--R                    2 2 3         4 2      6
+--R               (720a b c  - 240a b c  + 24b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  4
+--R               (4200a b c  - 1400a b c  + 140b c )d
+--R             + 
+--R                     2 2 3         4 2      6   2       3   3      2 3 2
+--R               (1800a b c  - 600a b c  + 60b c)d  + 120a b c  + 20a b c
+--R             + 
+--R                      5      7
+--R               - 16a b c + 2b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  5
+--R               (3360a b c  - 1120a b c  + 112b c )d
+--R             + 
+--R                     2 2 3         4 2      6   3
+--R               (2400a b c  - 800a b c  + 80b c)d
+--R             + 
+--R                    3   3      2 3 2        5      7
+--R               (480a b c  + 80a b c  - 64a b c + 8b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2   4         3 3      5 2  6
+--R               (1680a b c  - 560a b c  + 56b c )d
+--R             + 
+--R                     2 2 3         4 2      6   4
+--R               (1800a b c  - 600a b c  + 60b c)d
+--R             + 
+--R                    3   3       2 3 2        5       7  2       3 2 2      2 4
+--R               (720a b c  + 120a b c  - 96a b c + 12b )d  + 120a b c  - 40a b c
+--R             + 
+--R                   6
+--R               4a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                    2   4         3 3      5 2  7
+--R               (480a b c  - 160a b c  + 16b c )d
+--R             + 
+--R                    2 2 3         4 2      6   5
+--R               (720a b c  - 240a b c  + 24b c)d
+--R             + 
+--R                    3   3      2 3 2        5      7  3
+--R               (480a b c  + 80a b c  - 64a b c + 8b )d
+--R             + 
+--R                    3 2 2      2 4        6
+--R               (240a b c  - 80a b c + 8a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2   4        3 3     5 2  8        2 2 3        4 2     6   6
+--R           (60a b c  - 20a b c  + 2b c )d  + (120a b c  - 40a b c  + 4b c)d
+--R         + 
+--R                3   3      2 3 2        5      7  4
+--R           (120a b c  + 20a b c  - 16a b c + 2b )d
+--R         + 
+--R                3 2 2      2 4        6  2      4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )d  + 60a b c  - 20a b c + 2a b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                     2 4       2 3    4 2  8 8
+--R               (- 16a c  + 8a b c  - b c )e x
+--R             + 
+--R                      2 4        2 3     4 2    7 7
+--R               (- 128a c  + 64a b c  - 8b c )d e x
+--R             + 
+--R                            2 4         2 3      4 2  2      2   3        3 2
+--R                     (- 448a c  + 224a b c  - 28b c )d  - 32a b c  + 16a b c
+--R                   + 
+--R                         5
+--R                     - 2b c
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  3
+--R                   (- 896a c  + 448a b c  - 56b c )d
+--R                 + 
+--R                          2   3        3 2      5
+--R                   (- 192a b c  + 96a b c  - 12b c)d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2 4         2 3      4 2  4
+--R                   (- 1120a c  + 560a b c  - 70b c )d
+--R                 + 
+--R                          2   3         3 2      5   2      3 3       4     6
+--R                   (- 480a b c  + 240a b c  - 30b c)d  - 32a c  + 6a b c - b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  5
+--R                   (- 896a c  + 448a b c  - 56b c )d
+--R                 + 
+--R                          2   3         3 2      5   3
+--R                   (- 640a b c  + 320a b c  - 40b c)d
+--R                 + 
+--R                          3 3        4      6
+--R                   (- 128a c  + 24a b c - 4b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  6
+--R                   (- 448a c  + 224a b c  - 28b c )d
+--R                 + 
+--R                          2   3         3 2      5   4
+--R                   (- 480a b c  + 240a b c  - 30b c)d
+--R                 + 
+--R                          3 3        4      6  2      3   2      2 3        5
+--R                   (- 192a c  + 36a b c - 6b )d  - 32a b c  + 16a b c - 2a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2 4        2 3     4 2  7
+--R                   (- 128a c  + 64a b c  - 8b c )d
+--R                 + 
+--R                          2   3        3 2      5   5
+--R                   (- 192a b c  + 96a b c  - 12b c)d
+--R                 + 
+--R                        3 3        4      6  3         3   2      2 3        5
+--R                 (- 128a c  + 24a b c - 4b )d  + (- 64a b c  + 32a b c - 4a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2 4       2 3    4 2  8         2   3        3 2     5   6
+--R               (- 16a c  + 8a b c  - b c )d  + (- 32a b c  + 16a b c  - 2b c)d
+--R             + 
+--R                     3 3       4     6  4         3   2      2 3        5  2
+--R               (- 32a c  + 6a b c - b )d  + (- 32a b c  + 16a b c - 2a b )d
+--R             + 
+--R                    4 2     3 2     2 4
+--R               - 16a c  + 8a b c - a b
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                   2 4        2 3     4 2  8 8
+--R               (64a c  - 32a b c  + 4b c )e x
+--R             + 
+--R                    2 4         2 3      4 2    7 7
+--R               (512a c  - 256a b c  + 32b c )d e x
+--R             + 
+--R                         2 4         2 3       4 2  2       2   3        3 2
+--R                   (1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c
+--R                 + 
+--R                     5
+--R                   8b c
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  3
+--R                   (3584a c  - 1792a b c  + 224b c )d
+--R                 + 
+--R                        2   3         3 2      5
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  4
+--R                   (4480a c  - 2240a b c  + 280b c )d
+--R                 + 
+--R                       2   3         3 2       5   2       3 3        4      6
+--R                 (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  5
+--R                   (3584a c  - 1792a b c  + 224b c )d
+--R                 + 
+--R                         2   3          3 2       5   3
+--R                   (2560a b c  - 1280a b c  + 160b c)d
+--R                 + 
+--R                        3 3        4       6
+--R                   (512a c  - 96a b c + 16b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                         2 4         2 3       4 2  6
+--R                   (1792a c  - 896a b c  + 112b c )d
+--R                 + 
+--R                         2   3         3 2       5   4
+--R                   (1920a b c  - 960a b c  + 120b c)d
+--R                 + 
+--R                        3 3         4       6  2       3   2      2 3        5
+--R                   (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                        2 4         2 3      4 2  7
+--R                   (512a c  - 256a b c  + 32b c )d
+--R                 + 
+--R                        2   3         3 2      5   5
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R                 + 
+--R                      3 3        4       6  3        3   2       2 3         5
+--R                 (512a c  - 96a b c + 16b )d  + (256a b c  - 128a b c + 16a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                 2   3       3 2  6 6         2   3        3 2    5 5
+--R           (- 14a b c  + 2a b c )e x  + (- 84a b c  + 12a b c )d e x
+--R         + 
+--R                   2   3        3 2  2      3 3      2 2 2       4   4 4
+--R           ((- 210a b c  + 30a b c )d  + 16a c  - 29a b c  + 4a b c)e x
+--R         + 
+--R                   2   3        3 2  3       3 3       2 2 2        4     3 3
+--R           ((- 280a b c  + 40a b c )d  + (64a c  - 116a b c  + 16a b c)d)e x
+--R         + 
+--R                      2   3        3 2  4       3 3       2 2 2        4   2
+--R               (- 210a b c  + 30a b c )d  + (96a c  - 174a b c  + 24a b c)d
+--R             + 
+--R                   3   2      2 3        5
+--R               - 2a b c  - 12a b c + 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2   3        3 2  5       3 3       2 2 2        4   3
+--R               (- 84a b c  + 12a b c )d  + (64a c  - 116a b c  + 16a b c)d
+--R             + 
+--R                    3   2      2 3        5
+--R               (- 4a b c  - 24a b c + 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2   3       3 2  6       3 3      2 2 2       4   4
+--R           (- 14a b c  + 2a b c )d  + (16a c  - 29a b c  + 4a b c)d
+--R         + 
+--R                3   2      2 3        5  2      4 2      3 2      2 4
+--R           (- 2a b c  - 12a b c + 2a b )d  + 24a c  - 21a b c + 3a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             5 4      4 2 3     3 4 2  9   8
+--R         (64a c  - 32a b c  + 4a b c )e f x
+--R       + 
+--R              5 4       4 2 3      3 4 2    8   7
+--R         (512a c  - 256a b c  + 32a b c )d e f x
+--R       + 
+--R                     5 4       4 2 3       3 4 2  2       5   3      4 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R        *
+--R            7   6
+--R           e f x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  3
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R        *
+--R            6   5
+--R           e f x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  4
+--R             (4480a c  - 2240a b c  + 280a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   2       6 3      4 4      3 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R        *
+--R            5   4
+--R           e f x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  5
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   3
+--R             (2560a b c  - 1280a b c  + 160a b c)d
+--R           + 
+--R                  6 3      4 4       3 6
+--R             (512a c  - 96a b c + 16a b )d
+--R        *
+--R            4   3
+--R           e f x
+--R       + 
+--R                   5 4       4 2 3       3 4 2  6
+--R             (1792a c  - 896a b c  + 112a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   4
+--R             (1920a b c  - 960a b c  + 120a b c)d
+--R           + 
+--R                  6 3       4 4       3 6  2       6   2      5 3      4 5
+--R             (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R        *
+--R            3   2
+--R           e f x
+--R       + 
+--R                  5 4       4 2 3      3 4 2  7
+--R             (512a c  - 256a b c  + 32a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5   5
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R           + 
+--R                  6 3      4 4       3 6  3        6   2       5 3       4 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e f x
+--R       + 
+--R                 5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R             (64a c  - 32a b c  + 4a b c )d  + (128a b c  - 64a b c  + 8a b c)d
+--R           + 
+--R                  6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R             (128a c  - 24a b c + 4a b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                7 2      6 2      5 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e f
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1035
+
+--S 1036 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   4        3 3    5 2  8 8
+--R             (30a b c  - 10a b c  + b c )e x
+--R           + 
+--R                  2   4        3 3     5 2    7 7
+--R             (240a b c  - 80a b c  + 8b c )d e x
+--R           + 
+--R                     2   4         3 3      5 2  2      2 2 3        4 2     6
+--R               ((840a b c  - 280a b c  + 28b c )d  + 60a b c  - 20a b c  + 2b c)
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                       2   4         3 3      5 2  3
+--R                 (1680a b c  - 560a b c  + 56b c )d
+--R               + 
+--R                      2 2 3         4 2      6
+--R                 (360a b c  - 120a b c  + 12b c)d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                       2   4         3 3      5 2  4
+--R                 (2100a b c  - 700a b c  + 70b c )d
+--R               + 
+--R                      2 2 3         4 2      6   2      3   3      2 3 2
+--R                 (900a b c  - 300a b c  + 30b c)d  + 60a b c  + 10a b c
+--R               + 
+--R                       5     7
+--R                 - 8a b c + b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                       2   4         3 3      5 2  5
+--R                 (1680a b c  - 560a b c  + 56b c )d
+--R               + 
+--R                       2 2 3         4 2      6   3
+--R                 (1200a b c  - 400a b c  + 40b c)d
+--R               + 
+--R                      3   3      2 3 2        5      7
+--R                 (240a b c  + 40a b c  - 32a b c + 4b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                      2   4         3 3      5 2  6
+--R                 (840a b c  - 280a b c  + 28b c )d
+--R               + 
+--R                      2 2 3         4 2      6   4
+--R                 (900a b c  - 300a b c  + 30b c)d
+--R               + 
+--R                      3   3      2 3 2        5      7  2      3 2 2      2 4
+--R                 (360a b c  + 60a b c  - 48a b c + 6b )d  + 60a b c  - 20a b c
+--R               + 
+--R                     6
+--R                 2a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                      2   4        3 3     5 2  7
+--R                 (240a b c  - 80a b c  + 8b c )d
+--R               + 
+--R                      2 2 3         4 2      6   5
+--R                 (360a b c  - 120a b c  + 12b c)d
+--R               + 
+--R                      3   3      2 3 2        5      7  3
+--R                 (240a b c  + 40a b c  - 32a b c + 4b )d
+--R               + 
+--R                      3 2 2      2 4        6
+--R                 (120a b c  - 40a b c + 4a b )d
+--R            *
+--R               e x
+--R           + 
+--R                 2   4        3 3    5 2  8       2 2 3        4 2     6   6
+--R             (30a b c  - 10a b c  + b c )d  + (60a b c  - 20a b c  + 2b c)d
+--R           + 
+--R                 3   3      2 3 2       5     7  4
+--R             (60a b c  + 10a b c  - 8a b c + b )d
+--R           + 
+--R                 3 2 2      2 4        6  2      4   2      3 3     2 5
+--R             (60a b c  - 20a b c + 2a b )d  + 30a b c  - 10a b c + a b
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                       2 4       2 3    4 2  8 8
+--R                 (- 16a c  + 8a b c  - b c )e x
+--R               + 
+--R                        2 4        2 3     4 2    7 7
+--R                 (- 128a c  + 64a b c  - 8b c )d e x
+--R               + 
+--R                            2 4         2 3      4 2  2      2   3        3 2
+--R                     (- 448a c  + 224a b c  - 28b c )d  - 32a b c  + 16a b c
+--R                   + 
+--R                         5
+--R                     - 2b c
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  3
+--R                     (- 896a c  + 448a b c  - 56b c )d
+--R                   + 
+--R                            2   3        3 2      5
+--R                     (- 192a b c  + 96a b c  - 12b c)d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                             2 4         2 3      4 2  4
+--R                     (- 1120a c  + 560a b c  - 70b c )d
+--R                   + 
+--R                            2   3         3 2      5   2      3 3       4     6
+--R                     (- 480a b c  + 240a b c  - 30b c)d  - 32a c  + 6a b c - b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  5
+--R                     (- 896a c  + 448a b c  - 56b c )d
+--R                   + 
+--R                            2   3         3 2      5   3
+--R                     (- 640a b c  + 320a b c  - 40b c)d
+--R                   + 
+--R                            3 3        4      6
+--R                     (- 128a c  + 24a b c - 4b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  6
+--R                     (- 448a c  + 224a b c  - 28b c )d
+--R                   + 
+--R                            2   3         3 2      5   4
+--R                     (- 480a b c  + 240a b c  - 30b c)d
+--R                   + 
+--R                            3 3        4      6  2      3   2      2 3        5
+--R                     (- 192a c  + 36a b c - 6b )d  - 32a b c  + 16a b c - 2a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                            2 4        2 3     4 2  7
+--R                     (- 128a c  + 64a b c  - 8b c )d
+--R                   + 
+--R                            2   3        3 2      5   5
+--R                     (- 192a b c  + 96a b c  - 12b c)d
+--R                   + 
+--R                            3 3        4      6  3
+--R                     (- 128a c  + 24a b c - 4b )d
+--R                   + 
+--R                           3   2      2 3        5
+--R                     (- 64a b c  + 32a b c - 4a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                       2 4       2 3    4 2  8
+--R                 (- 16a c  + 8a b c  - b c )d
+--R               + 
+--R                       2   3        3 2     5   6         3 3       4     6  4
+--R                 (- 32a b c  + 16a b c  - 2b c)d  + (- 32a c  + 6a b c - b )d
+--R               + 
+--R                       3   2      2 3        5  2      4 2     3 2     2 4
+--R                 (- 32a b c  + 16a b c - 2a b )d  - 16a c  + 8a b c - a b
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                     2 4        2 3     4 2  8 8
+--R                 (64a c  - 32a b c  + 4b c )e x
+--R               + 
+--R                      2 4         2 3      4 2    7 7
+--R                 (512a c  - 256a b c  + 32b c )d e x
+--R               + 
+--R                           2 4         2 3       4 2  2       2   3        3 2
+--R                     (1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c
+--R                   + 
+--R                       5
+--R                     8b c
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  3
+--R                     (3584a c  - 1792a b c  + 224b c )d
+--R                   + 
+--R                          2   3         3 2      5
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  4
+--R                     (4480a c  - 2240a b c  + 280b c )d
+--R                   + 
+--R                         2   3         3 2       5   2       3 3        4      6
+--R                   (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  5
+--R                     (3584a c  - 1792a b c  + 224b c )d
+--R                   + 
+--R                           2   3          3 2       5   3
+--R                     (2560a b c  - 1280a b c  + 160b c)d
+--R                   + 
+--R                          3 3        4       6
+--R                     (512a c  - 96a b c + 16b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                           2 4         2 3       4 2  6
+--R                     (1792a c  - 896a b c  + 112b c )d
+--R                   + 
+--R                           2   3         3 2       5   4
+--R                     (1920a b c  - 960a b c  + 120b c)d
+--R                   + 
+--R                        3 3         4       6  2       3   2      2 3        5
+--R                   (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                          2 4         2 3      4 2  7
+--R                     (512a c  - 256a b c  + 32b c )d
+--R                   + 
+--R                          2   3         3 2      5   5
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                   + 
+--R                          3 3        4       6  3
+--R                     (512a c  - 96a b c + 16b )d
+--R                   + 
+--R                          3   2       2 3         5
+--R                     (256a b c  - 128a b c + 16a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                     2 4        2 3     4 2  8        2   3        3 2     5   6
+--R                 (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R               + 
+--R                      3 3        4      6  4        3   2      2 3        5  2
+--R                 (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R               + 
+--R                    4 2      3 2      2 4
+--R                 64a c  - 32a b c + 4a b
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                   2   3       3 2  6 6         2   3        3 2    5 5
+--R             (- 14a b c  + 2a b c )e x  + (- 84a b c  + 12a b c )d e x
+--R           + 
+--R                     2   3        3 2  2      3 3      2 2 2       4   4 4
+--R             ((- 210a b c  + 30a b c )d  + 16a c  - 29a b c  + 4a b c)e x
+--R           + 
+--R                     2   3        3 2  3       3 3       2 2 2        4     3 3
+--R             ((- 280a b c  + 40a b c )d  + (64a c  - 116a b c  + 16a b c)d)e x
+--R           + 
+--R                        2   3        3 2  4       3 3       2 2 2        4   2
+--R                 (- 210a b c  + 30a b c )d  + (96a c  - 174a b c  + 24a b c)d
+--R               + 
+--R                     3   2      2 3        5
+--R                 - 2a b c  - 12a b c + 2a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                       2   3        3 2  5       3 3       2 2 2        4   3
+--R                 (- 84a b c  + 12a b c )d  + (64a c  - 116a b c  + 16a b c)d
+--R               + 
+--R                      3   2      2 3        5
+--R                 (- 4a b c  - 24a b c + 4a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   2   3       3 2  6       3 3      2 2 2       4   4
+--R             (- 14a b c  + 2a b c )d  + (16a c  - 29a b c  + 4a b c)d
+--R           + 
+--R                  3   2      2 3        5  2      4 2      3 2      2 4
+--R             (- 2a b c  - 12a b c + 2a b )d  + 24a c  - 21a b c + 3a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               5 4      4 2 3     3 4 2  9   8
+--R           (64a c  - 32a b c  + 4a b c )e f x
+--R         + 
+--R                5 4       4 2 3      3 4 2    8   7
+--R           (512a c  - 256a b c  + 32a b c )d e f x
+--R         + 
+--R                     5 4       4 2 3       3 4 2  2       5   3      4 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R          *
+--R              7   6
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6   5
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   5   3       4 3 2       3 5   2       6 3      4 4      3 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5   4
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    6 3      4 4       3 6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4   3
+--R             e f x
+--R         + 
+--R                     5 4       4 2 3       3 4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     5   3       4 3 2       3 5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3   2
+--R             e f x
+--R         + 
+--R                    5 4       4 2 3      3 4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  6 3      4 4       3 6  3        6   2       5 3       4 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e f x
+--R         + 
+--R                   5 4      4 2 3     3 4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    5   3      4 3 2     3 5   6        6 3      4 4      3 6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  2      7 2      6 2      5 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e f
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2   4        3 3     5 2  8 8
+--R             (- 60a b c  + 20a b c  - 2b c )e x
+--R           + 
+--R                    2   4         3 3      5 2    7 7
+--R             (- 480a b c  + 160a b c  - 16b c )d e x
+--R           + 
+--R                         2   4         3 3      5 2  2       2 2 3        4 2
+--R                 (- 1680a b c  + 560a b c  - 56b c )d  - 120a b c  + 40a b c
+--R               + 
+--R                     6
+--R                 - 4b c
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                         2   4          3 3       5 2  3
+--R                 (- 3360a b c  + 1120a b c  - 112b c )d
+--R               + 
+--R                        2 2 3         4 2      6
+--R                 (- 720a b c  + 240a b c  - 24b c)d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                         2   4          3 3       5 2  4
+--R                 (- 4200a b c  + 1400a b c  - 140b c )d
+--R               + 
+--R                         2 2 3         4 2      6   2       3   3      2 3 2
+--R                 (- 1800a b c  + 600a b c  - 60b c)d  - 120a b c  - 20a b c
+--R               + 
+--R                      5      7
+--R                 16a b c - 2b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                         2   4          3 3       5 2  5
+--R                 (- 3360a b c  + 1120a b c  - 112b c )d
+--R               + 
+--R                         2 2 3         4 2      6   3
+--R                 (- 2400a b c  + 800a b c  - 80b c)d
+--R               + 
+--R                        3   3      2 3 2        5      7
+--R                 (- 480a b c  - 80a b c  + 64a b c - 8b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                         2   4         3 3      5 2  6
+--R                 (- 1680a b c  + 560a b c  - 56b c )d
+--R               + 
+--R                         2 2 3         4 2      6   4
+--R                 (- 1800a b c  + 600a b c  - 60b c)d
+--R               + 
+--R                        3   3       2 3 2        5       7  2       3 2 2
+--R                 (- 720a b c  - 120a b c  + 96a b c - 12b )d  - 120a b c
+--R               + 
+--R                    2 4        6
+--R                 40a b c - 4a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                        2   4         3 3      5 2  7
+--R                 (- 480a b c  + 160a b c  - 16b c )d
+--R               + 
+--R                        2 2 3         4 2      6   5
+--R                 (- 720a b c  + 240a b c  - 24b c)d
+--R               + 
+--R                        3   3      2 3 2        5      7  3
+--R                 (- 480a b c  - 80a b c  + 64a b c - 8b )d
+--R               + 
+--R                        3 2 2      2 4        6
+--R                 (- 240a b c  + 80a b c - 8a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   2   4        3 3     5 2  8
+--R             (- 60a b c  + 20a b c  - 2b c )d
+--R           + 
+--R                    2 2 3        4 2     6   6
+--R             (- 120a b c  + 40a b c  - 4b c)d
+--R           + 
+--R                    3   3      2 3 2        5      7  4
+--R             (- 120a b c  - 20a b c  + 16a b c - 2b )d
+--R           + 
+--R                    3 2 2      2 4        6  2      4   2      3 3      2 5
+--R             (- 120a b c  + 40a b c - 4a b )d  - 60a b c  + 20a b c - 2a b
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                       2 4       2 3    4 2  8 8
+--R                 (- 16a c  + 8a b c  - b c )e x
+--R               + 
+--R                        2 4        2 3     4 2    7 7
+--R                 (- 128a c  + 64a b c  - 8b c )d e x
+--R               + 
+--R                            2 4         2 3      4 2  2      2   3        3 2
+--R                     (- 448a c  + 224a b c  - 28b c )d  - 32a b c  + 16a b c
+--R                   + 
+--R                         5
+--R                     - 2b c
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  3
+--R                     (- 896a c  + 448a b c  - 56b c )d
+--R                   + 
+--R                            2   3        3 2      5
+--R                     (- 192a b c  + 96a b c  - 12b c)d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                             2 4         2 3      4 2  4
+--R                     (- 1120a c  + 560a b c  - 70b c )d
+--R                   + 
+--R                            2   3         3 2      5   2      3 3       4     6
+--R                     (- 480a b c  + 240a b c  - 30b c)d  - 32a c  + 6a b c - b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  5
+--R                     (- 896a c  + 448a b c  - 56b c )d
+--R                   + 
+--R                            2   3         3 2      5   3
+--R                     (- 640a b c  + 320a b c  - 40b c)d
+--R                   + 
+--R                            3 3        4      6
+--R                     (- 128a c  + 24a b c - 4b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                            2 4         2 3      4 2  6
+--R                     (- 448a c  + 224a b c  - 28b c )d
+--R                   + 
+--R                            2   3         3 2      5   4
+--R                     (- 480a b c  + 240a b c  - 30b c)d
+--R                   + 
+--R                            3 3        4      6  2      3   2      2 3        5
+--R                     (- 192a c  + 36a b c - 6b )d  - 32a b c  + 16a b c - 2a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                            2 4        2 3     4 2  7
+--R                     (- 128a c  + 64a b c  - 8b c )d
+--R                   + 
+--R                            2   3        3 2      5   5
+--R                     (- 192a b c  + 96a b c  - 12b c)d
+--R                   + 
+--R                            3 3        4      6  3
+--R                     (- 128a c  + 24a b c - 4b )d
+--R                   + 
+--R                           3   2      2 3        5
+--R                     (- 64a b c  + 32a b c - 4a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                       2 4       2 3    4 2  8
+--R                 (- 16a c  + 8a b c  - b c )d
+--R               + 
+--R                       2   3        3 2     5   6         3 3       4     6  4
+--R                 (- 32a b c  + 16a b c  - 2b c)d  + (- 32a c  + 6a b c - b )d
+--R               + 
+--R                       3   2      2 3        5  2      4 2     3 2     2 4
+--R                 (- 32a b c  + 16a b c - 2a b )d  - 16a c  + 8a b c - a b
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                     2 4        2 3     4 2  8 8
+--R                 (64a c  - 32a b c  + 4b c )e x
+--R               + 
+--R                      2 4         2 3      4 2    7 7
+--R                 (512a c  - 256a b c  + 32b c )d e x
+--R               + 
+--R                           2 4         2 3       4 2  2       2   3        3 2
+--R                     (1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c
+--R                   + 
+--R                       5
+--R                     8b c
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  3
+--R                     (3584a c  - 1792a b c  + 224b c )d
+--R                   + 
+--R                          2   3         3 2      5
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  4
+--R                     (4480a c  - 2240a b c  + 280b c )d
+--R                   + 
+--R                         2   3         3 2       5   2       3 3        4      6
+--R                   (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                           2 4          2 3       4 2  5
+--R                     (3584a c  - 1792a b c  + 224b c )d
+--R                   + 
+--R                           2   3          3 2       5   3
+--R                     (2560a b c  - 1280a b c  + 160b c)d
+--R                   + 
+--R                          3 3        4       6
+--R                     (512a c  - 96a b c + 16b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                           2 4         2 3       4 2  6
+--R                     (1792a c  - 896a b c  + 112b c )d
+--R                   + 
+--R                           2   3         3 2       5   4
+--R                     (1920a b c  - 960a b c  + 120b c)d
+--R                   + 
+--R                        3 3         4       6  2       3   2      2 3        5
+--R                   (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                          2 4         2 3      4 2  7
+--R                     (512a c  - 256a b c  + 32b c )d
+--R                   + 
+--R                          2   3         3 2      5   5
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                   + 
+--R                          3 3        4       6  3
+--R                     (512a c  - 96a b c + 16b )d
+--R                   + 
+--R                          3   2       2 3         5
+--R                     (256a b c  - 128a b c + 16a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                     2 4        2 3     4 2  8        2   3        3 2     5   6
+--R                 (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R               + 
+--R                      3 3        4      6  4        3   2      2 3        5  2
+--R                 (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R               + 
+--R                    4 2      3 2      2 4
+--R                 64a c  - 32a b c + 4a b
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                   2   3       3 2  6 6         2   3        3 2    5 5
+--R             (- 14a b c  + 2a b c )e x  + (- 84a b c  + 12a b c )d e x
+--R           + 
+--R                     2   3        3 2  2      3 3      2 2 2       4   4 4
+--R             ((- 210a b c  + 30a b c )d  + 16a c  - 29a b c  + 4a b c)e x
+--R           + 
+--R                     2   3        3 2  3       3 3       2 2 2        4     3 3
+--R             ((- 280a b c  + 40a b c )d  + (64a c  - 116a b c  + 16a b c)d)e x
+--R           + 
+--R                        2   3        3 2  4       3 3       2 2 2        4   2
+--R                 (- 210a b c  + 30a b c )d  + (96a c  - 174a b c  + 24a b c)d
+--R               + 
+--R                     3   2      2 3        5
+--R                 - 2a b c  - 12a b c + 2a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                       2   3        3 2  5       3 3       2 2 2        4   3
+--R                 (- 84a b c  + 12a b c )d  + (64a c  - 116a b c  + 16a b c)d
+--R               + 
+--R                      3   2      2 3        5
+--R                 (- 4a b c  - 24a b c + 4a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   2   3       3 2  6       3 3      2 2 2       4   4
+--R             (- 14a b c  + 2a b c )d  + (16a c  - 29a b c  + 4a b c)d
+--R           + 
+--R                  3   2      2 3        5  2      4 2      3 2      2 4
+--R             (- 2a b c  - 12a b c + 2a b )d  + 24a c  - 21a b c + 3a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               5 4      4 2 3     3 4 2  9   8
+--R           (64a c  - 32a b c  + 4a b c )e f x
+--R         + 
+--R                5 4       4 2 3      3 4 2    8   7
+--R           (512a c  - 256a b c  + 32a b c )d e f x
+--R         + 
+--R                     5 4       4 2 3       3 4 2  2       5   3      4 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R          *
+--R              7   6
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  3
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R          *
+--R              6   5
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  4
+--R               (4480a c  - 2240a b c  + 280a b c )d
+--R             + 
+--R                   5   3       4 3 2       3 5   2       6 3      4 4      3 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              5   4
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  5
+--R               (3584a c  - 1792a b c  + 224a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   3
+--R               (2560a b c  - 1280a b c  + 160a b c)d
+--R             + 
+--R                    6 3      4 4       3 6
+--R               (512a c  - 96a b c + 16a b )d
+--R          *
+--R              4   3
+--R             e f x
+--R         + 
+--R                     5 4       4 2 3       3 4 2  6
+--R               (1792a c  - 896a b c  + 112a b c )d
+--R             + 
+--R                     5   3       4 3 2       3 5   4
+--R               (1920a b c  - 960a b c  + 120a b c)d
+--R             + 
+--R                    6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              3   2
+--R             e f x
+--R         + 
+--R                    5 4       4 2 3      3 4 2  7
+--R               (512a c  - 256a b c  + 32a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5   5
+--R               (768a b c  - 384a b c  + 48a b c)d
+--R             + 
+--R                  6 3      4 4       3 6  3        6   2       5 3       4 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R          *
+--R              2
+--R             e f x
+--R         + 
+--R                   5 4      4 2 3     3 4 2  8
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    5   3      4 3 2     3 5   6        6 3      4 4      3 6  4
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  2      7 2      6 2      5 4
+--R               (128a b c  - 64a b c + 8a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R             e f
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1036
+
+--S 1037 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2   2        3     5
+--R         (30a b c  - 10a b c + b )
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                                             2 2                  2
+--R             2   2        3      5       2c e x  + 4c d e x + 2c d  + b
+--R       (- 60a b c  + 20a b c - 2b )atanh(------------------------------)
+--R                                                  +-----------+
+--R                                                  |          2
+--R                                                 \|- 4a c + b
+--R  /
+--R                                   +-----------+
+--R         5 2      4 2      3 4     |          2
+--R     (64a c  - 32a b c + 4a b )e f\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1037
+
+--S 1038 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1038
+
+--S 1039 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                     +---------+
+--R               2   2        3     5  |        2
+--R         (- 30a b c  + 10a b c - b )\|4a c - b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                     +-----------+
+--R               2   2        3     5  |          2
+--R         (- 30a b c  + 10a b c - b )\|- 4a c + b
+--R      *
+--R                                               +---------+
+--R                   2 2                  2      |        2
+--R              (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R  /
+--R                                   +-----------+ +---------+
+--R         5 2      4 2      3 4     |          2  |        2
+--R     (32a c  - 16a b c + 2a b )e f\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1039
+
+--S 1040 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1040
+
+)clear all
+
+--S 1041 of 1057
+t0:=1/((d*f+e*f*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 14 2 14      3   13 2 13       3 2       2  12 2 12
+--R       c e  f x   + 14c d e  f x   + (91c d  + 3b c )e  f x
+--R     + 
+--R            3 3        2   11 2 11
+--R       (364c d  + 36b c d)e  f x
+--R     + 
+--R             3 4         2 2       2     2   10 2 10
+--R       (1001c d  + 198b c d  + 3a c  + 3b c)e  f x
+--R     + 
+--R             3 5         2 3         2      2     9 2 9
+--R       (2002c d  + 660b c d  + (30a c  + 30b c)d)e f x
+--R     + 
+--R             3 6          2 4          2       2   2             3  8 2 8
+--R       (3003c d  + 1485b c d  + (135a c  + 135b c)d  + 6a b c + b )e f x
+--R     + 
+--R             3 7          2 5          2       2   3                3    7 2 7
+--R       (3432c d  + 2376b c d  + (360a c  + 360b c)d  + (48a b c + 8b )d)e f x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           3003c d  + 2772b c d  + (630a c  + 630b c)d  + (168a b c + 28b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          6 2 6
+--R         e f x
+--R     + 
+--R                3 9          2 7          2       2   5                  3  3
+--R           2002c d  + 2376b c d  + (756a c  + 756b c)d  + (336a b c + 56b )d
+--R         + 
+--R               2         2
+--R           (18a c + 18a b )d
+--R      *
+--R          5 2 5
+--R         e f x
+--R     + 
+--R                3 10          2 8          2       2   6                  3  4
+--R           1001c d   + 1485b c d  + (630a c  + 630b c)d  + (420a b c + 70b )d
+--R         + 
+--R               2         2  2     2
+--R           (45a c + 45a b )d  + 3a b
+--R      *
+--R          4 2 4
+--R         e f x
+--R     + 
+--R               3 11         2 9          2       2   7                  3  5
+--R           364c d   + 660b c d  + (360a c  + 360b c)d  + (336a b c + 56b )d
+--R         + 
+--R               2         2  3      2
+--R           (60a c + 60a b )d  + 12a b d
+--R      *
+--R          3 2 3
+--R         e f x
+--R     + 
+--R              3 12         2 10          2       2   8                  3  6
+--R           91c d   + 198b c d   + (135a c  + 135b c)d  + (168a b c + 28b )d
+--R         + 
+--R               2         2  4      2   2    3
+--R           (45a c + 45a b )d  + 18a b d  + a
+--R      *
+--R          2 2 2
+--R         e f x
+--R     + 
+--R              3 13        2 11         2      2   9                3  7
+--R           14c d   + 36b c d   + (30a c  + 30b c)d  + (48a b c + 8b )d
+--R         + 
+--R               2         2  5      2   3     3
+--R           (18a c + 18a b )d  + 12a b d  + 2a d
+--R      *
+--R            2
+--R         e f x
+--R     + 
+--R            3 14       2 12        2     2   10              3  8
+--R           c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R         + 
+--R              2        2  6     2   4    3 2
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R          2
+--R         f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1041
+
+--S 1042 of 1057
+r0:=-3/8*(5*b^2-12*a*c)*(b^2-5*a*c)/(a^3*(b^2-4*a*c)^2*e*f^2*(d+e*x))+_
+   1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f^2*(d+e*x)*(a+b*_
+   (d+e*x)^2+c*(d+e*x)^4)^2)+1/8*(5*b^4-35*a*b^2*c+36*a^2*c^2+b*c*(5*b^2-_
+   32*a*c)*(d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*f^2*(d+e*x)*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))-3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*((5*b^2-12*a*c)*(b^2-5*a*c)+b*(5*b^4-47*a*b^2*c+124*a^2*c^2)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^2*e*f^2*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))-3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   sqrt(c)*((5*b^2-12*a*c)*(b^2-5*a*c)+(-5*b^5+47*a*b^3*c-124*a^2*b*c^2)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^2*e*f^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2 4         2 3      4 2  9 9
+--R               (- 180a c  + 111a b c  - 15b c )e x
+--R             + 
+--R                       2 4         2 3       4 2    8 8
+--R               (- 1620a c  + 999a b c  - 135b c )d e x
+--R             + 
+--R                           2 4          2 3       4 2  2       2   3         3 2
+--R                   (- 6480a c  + 3996a b c  - 540b c )d  - 360a b c  + 222a b c
+--R                 + 
+--R                        5
+--R                   - 30b c
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  3
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                           2   3          3 2       5
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  4
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                           2   3          3 2       5   2       3 3      2 2 2
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d  - 360a c  + 42a b c
+--R                 + 
+--R                        4       6
+--R                   81a b c - 15b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  5
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                            2   3          3 2        5   3
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  6
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                            2   3          3 2        5   4
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  2       3   2
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d  - 360a b c
+--R                 + 
+--R                       2 3         5
+--R                   222a b c - 30a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2 4          2 3       4 2  7
+--R                   (- 6480a c  + 3996a b c  - 540b c )d
+--R                 + 
+--R                           2   3          3 2       5   5
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  3
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d
+--R                 + 
+--R                           3   2       2 3         5
+--R                   (- 1080a b c  + 666a b c - 90a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2 4         2 3       4 2  8
+--R                   (- 1620a c  + 999a b c  - 135b c )d
+--R                 + 
+--R                           2   3          3 2       5   6
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6  4
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R                 + 
+--R                           3   2       2 3         5  2       4 2       3 2
+--R                   (- 1080a b c  + 666a b c - 90a b )d  - 180a c  + 111a b c
+--R                 + 
+--R                        2 4
+--R                   - 15a b
+--R              *
+--R                 e x
+--R             + 
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )d
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)d
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )d
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )d
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2   4         3 3      5 2  9 9
+--R           (- 372a b c  + 141a b c  - 15b c )e x
+--R         + 
+--R                   2   4          3 3       5 2    8 8
+--R           (- 3348a b c  + 1269a b c  - 135b c )d e x
+--R         + 
+--R                        2   4          3 3       5 2  2       2 2 3         4 2
+--R               (- 13392a b c  + 5076a b c  - 540b c )d  - 744a b c  + 282a b c
+--R             + 
+--R                    6
+--R               - 30b c
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  3
+--R               (- 31248a b c  + 11844a b c  - 1260b c )d
+--R             + 
+--R                       2 2 3          4 2       6
+--R               (- 5208a b c  + 1974a b c  - 210b c)d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  4
+--R               (- 46872a b c  + 17766a b c  - 1890b c )d
+--R             + 
+--R                        2 2 3          4 2       6   2       3   3      2 3 2
+--R               (- 15624a b c  + 5922a b c  - 630b c)d  - 744a b c  - 90a b c
+--R             + 
+--R                     5       7
+--R               111a b c - 15b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  5
+--R               (- 46872a b c  + 17766a b c  - 1890b c )d
+--R             + 
+--R                        2 2 3          4 2        6   3
+--R               (- 26040a b c  + 9870a b c  - 1050b c)d
+--R             + 
+--R                       3   3       2 3 2         5       7
+--R               (- 3720a b c  - 450a b c  + 555a b c - 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  6
+--R               (- 31248a b c  + 11844a b c  - 1260b c )d
+--R             + 
+--R                        2 2 3          4 2        6   4
+--R               (- 26040a b c  + 9870a b c  - 1050b c)d
+--R             + 
+--R                       3   3       2 3 2          5        7  2       3 2 2
+--R               (- 7440a b c  - 900a b c  + 1110a b c - 150b )d  - 744a b c
+--R             + 
+--R                   2 4         6
+--R               282a b c - 30a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                        2   4          3 3       5 2  7
+--R               (- 13392a b c  + 5076a b c  - 540b c )d
+--R             + 
+--R                        2 2 3          4 2       6   5
+--R               (- 15624a b c  + 5922a b c  - 630b c)d
+--R             + 
+--R                       3   3       2 3 2          5        7  3
+--R               (- 7440a b c  - 900a b c  + 1110a b c - 150b )d
+--R             + 
+--R                       3 2 2       2 4         6
+--R               (- 2232a b c  + 846a b c - 90a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2   4          3 3       5 2  8
+--R               (- 3348a b c  + 1269a b c  - 135b c )d
+--R             + 
+--R                       2 2 3          4 2       6   6
+--R               (- 5208a b c  + 1974a b c  - 210b c)d
+--R             + 
+--R                       3   3       2 3 2         5       7  4
+--R               (- 3720a b c  - 450a b c  + 555a b c - 75b )d
+--R             + 
+--R                       3 2 2       2 4         6  2       4   2       3 3
+--R               (- 2232a b c  + 846a b c - 90a b )d  - 372a b c  + 141a b c
+--R             + 
+--R                    2 5
+--R               - 15a b
+--R          *
+--R             e x
+--R         + 
+--R                  2   4         3 3      5 2  9
+--R           (- 372a b c  + 141a b c  - 15b c )d
+--R         + 
+--R                  2 2 3         4 2      6   7
+--R           (- 744a b c  + 282a b c  - 30b c)d
+--R         + 
+--R                  3   3      2 3 2         5       7  5
+--R           (- 744a b c  - 90a b c  + 111a b c - 15b )d
+--R         + 
+--R                  3 2 2       2 4         6  3
+--R           (- 744a b c  + 282a b c - 30a b )d
+--R         + 
+--R                  4   2       3 3       2 5
+--R           (- 372a b c  + 141a b c - 15a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2 4         2 3      4 2  9 9
+--R               (- 180a c  + 111a b c  - 15b c )e x
+--R             + 
+--R                       2 4         2 3       4 2    8 8
+--R               (- 1620a c  + 999a b c  - 135b c )d e x
+--R             + 
+--R                           2 4          2 3       4 2  2       2   3         3 2
+--R                   (- 6480a c  + 3996a b c  - 540b c )d  - 360a b c  + 222a b c
+--R                 + 
+--R                        5
+--R                   - 30b c
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  3
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                           2   3          3 2       5
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  4
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                           2   3          3 2       5   2       3 3      2 2 2
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d  - 360a c  + 42a b c
+--R                 + 
+--R                        4       6
+--R                   81a b c - 15b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  5
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                            2   3          3 2        5   3
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  6
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                            2   3          3 2        5   4
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  2       3   2
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d  - 360a b c
+--R                 + 
+--R                       2 3         5
+--R                   222a b c - 30a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2 4          2 3       4 2  7
+--R                   (- 6480a c  + 3996a b c  - 540b c )d
+--R                 + 
+--R                           2   3          3 2       5   5
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  3
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d
+--R                 + 
+--R                           3   2       2 3         5
+--R                   (- 1080a b c  + 666a b c - 90a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2 4         2 3       4 2  8
+--R                   (- 1620a c  + 999a b c  - 135b c )d
+--R                 + 
+--R                           2   3          3 2       5   6
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6  4
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R                 + 
+--R                           3   2       2 3         5  2       4 2       3 2
+--R                   (- 1080a b c  + 666a b c - 90a b )d  - 180a c  + 111a b c
+--R                 + 
+--R                        2 4
+--R                   - 15a b
+--R              *
+--R                 e x
+--R             + 
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )d
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)d
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )d
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )d
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2   4         3 3      5 2  9 9
+--R           (372a b c  - 141a b c  + 15b c )e x
+--R         + 
+--R                 2   4          3 3       5 2    8 8
+--R           (3348a b c  - 1269a b c  + 135b c )d e x
+--R         + 
+--R                      2   4          3 3       5 2  2       2 2 3         4 2
+--R               (13392a b c  - 5076a b c  + 540b c )d  + 744a b c  - 282a b c
+--R             + 
+--R                  6
+--R               30b c
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  3
+--R               (31248a b c  - 11844a b c  + 1260b c )d
+--R             + 
+--R                     2 2 3          4 2       6
+--R               (5208a b c  - 1974a b c  + 210b c)d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  4
+--R               (46872a b c  - 17766a b c  + 1890b c )d
+--R             + 
+--R                      2 2 3          4 2       6   2       3   3      2 3 2
+--R               (15624a b c  - 5922a b c  + 630b c)d  + 744a b c  + 90a b c
+--R             + 
+--R                       5       7
+--R               - 111a b c + 15b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  5
+--R               (46872a b c  - 17766a b c  + 1890b c )d
+--R             + 
+--R                      2 2 3          4 2        6   3
+--R               (26040a b c  - 9870a b c  + 1050b c)d
+--R             + 
+--R                     3   3       2 3 2         5       7
+--R               (3720a b c  + 450a b c  - 555a b c + 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  6
+--R               (31248a b c  - 11844a b c  + 1260b c )d
+--R             + 
+--R                      2 2 3          4 2        6   4
+--R               (26040a b c  - 9870a b c  + 1050b c)d
+--R             + 
+--R                     3   3       2 3 2          5        7  2       3 2 2
+--R               (7440a b c  + 900a b c  - 1110a b c + 150b )d  + 744a b c
+--R             + 
+--R                     2 4         6
+--R               - 282a b c + 30a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      2   4          3 3       5 2  7
+--R               (13392a b c  - 5076a b c  + 540b c )d
+--R             + 
+--R                      2 2 3          4 2       6   5
+--R               (15624a b c  - 5922a b c  + 630b c)d
+--R             + 
+--R                     3   3       2 3 2          5        7  3
+--R               (7440a b c  + 900a b c  - 1110a b c + 150b )d
+--R             + 
+--R                     3 2 2       2 4         6
+--R               (2232a b c  - 846a b c + 90a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  8
+--R               (3348a b c  - 1269a b c  + 135b c )d
+--R             + 
+--R                     2 2 3          4 2       6   6
+--R               (5208a b c  - 1974a b c  + 210b c)d
+--R             + 
+--R                     3   3       2 3 2         5       7  4
+--R               (3720a b c  + 450a b c  - 555a b c + 75b )d
+--R             + 
+--R                   3 2 2       2 4         6  2       4   2       3 3       2 5
+--R             (2232a b c  - 846a b c + 90a b )d  + 372a b c  - 141a b c + 15a b
+--R          *
+--R             e x
+--R         + 
+--R                2   4         3 3      5 2  9
+--R           (372a b c  - 141a b c  + 15b c )d
+--R         + 
+--R                2 2 3         4 2      6   7
+--R           (744a b c  - 282a b c  + 30b c)d
+--R         + 
+--R                3   3      2 3 2         5       7  5
+--R           (744a b c  + 90a b c  - 111a b c + 15b )d
+--R         + 
+--R                3 2 2       2 4         6  3        4   2       3 3       2 5
+--R           (744a b c  - 282a b c + 30a b )d  + (372a b c  - 141a b c + 15a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 4         2 3      4 2  8 8
+--R           (- 180a c  + 111a b c  - 15b c )e x
+--R         + 
+--R                   2 4         2 3       4 2    7 7
+--R           (- 1440a c  + 888a b c  - 120b c )d e x
+--R         + 
+--R                       2 4          2 3       4 2  2       2   3         3 2
+--R               (- 5040a c  + 3108a b c  - 420b c )d  - 392a b c  + 227a b c
+--R             + 
+--R                    5
+--R               - 30b c
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  3
+--R               (- 10080a c  + 6216a b c  - 840b c )d
+--R             + 
+--R                       2   3          3 2       5
+--R               (- 2352a b c  + 1362a b c  - 180b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2 4          2 3        4 2  4
+--R               (- 12600a c  + 7770a b c  - 1050b c )d
+--R             + 
+--R                       2   3          3 2       5   2       3 3      2 2 2
+--R               (- 5880a b c  + 3405a b c  - 450b c)d  - 324a c  - 25a b c
+--R             + 
+--R                    4       6
+--R               91a b c - 15b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  5
+--R               (- 10080a c  + 6216a b c  - 840b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 7840a b c  + 4540a b c  - 600b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6
+--R               (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  6
+--R               (- 5040a c  + 3108a b c  - 420b c )d
+--R             + 
+--R                       2   3          3 2       5   4
+--R               (- 5880a b c  + 3405a b c  - 450b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  2       3   2
+--R               (- 1944a c  - 150a b c  + 546a b c - 90b )d  - 364a b c
+--R             + 
+--R                   2 3         5
+--R               194a b c - 25a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2 4         2 3       4 2  7
+--R               (- 1440a c  + 888a b c  - 120b c )d
+--R             + 
+--R                       2   3          3 2       5   5
+--R               (- 2352a b c  + 1362a b c  - 180b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  3
+--R               (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R             + 
+--R                      3   2       2 3         5
+--R               (- 728a b c  + 388a b c - 50a b )d
+--R          *
+--R             e x
+--R         + 
+--R                  2 4         2 3      4 2  8
+--R           (- 180a c  + 111a b c  - 15b c )d
+--R         + 
+--R                  2   3         3 2      5   6
+--R           (- 392a b c  + 227a b c  - 30b c)d
+--R         + 
+--R                  3 3      2 2 2        4       6  4
+--R           (- 324a c  - 25a b c  + 91a b c - 15b )d
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 364a b c  + 194a b c - 25a b )d  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              5 4      4 2 3     3 4 2  10 2 9
+--R         (128a c  - 64a b c  + 8a b c )e  f x
+--R       + 
+--R               5 4       4 2 3      3 4 2    9 2 8
+--R         (1152a c  - 576a b c  + 72a b c )d e f x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  2       5   3       4 3 2
+--R             (4608a c  - 2304a b c  + 288a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                3 5
+--R             16a b c
+--R        *
+--R            8 2 7
+--R           e f x
+--R       + 
+--R                    5 4        4 2 3       3 4 2  3
+--R             (10752a c  - 5376a b c  + 672a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5
+--R             (1792a b c  - 896a b c  + 112a b c)d
+--R        *
+--R            7 2 6
+--R           e f x
+--R       + 
+--R                    5 4        4 2 3        3 4 2  4
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   2       6 3      4 4      3 6
+--R             (5376a b c  - 2688a b c  + 336a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            6 2 5
+--R           e f x
+--R       + 
+--R                    5 4        4 2 3        3 4 2  5
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   3
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   6 3       4 4       3 6
+--R             (1280a c  - 240a b c + 40a b )d
+--R        *
+--R            5 2 4
+--R           e f x
+--R       + 
+--R                    5 4        4 2 3       3 4 2  6
+--R             (10752a c  - 5376a b c  + 672a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   4
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   6 3       4 4       3 6  2       6   2       5 3       4 5
+--R             (2560a c  - 480a b c + 80a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            4 2 3
+--R           e f x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  7
+--R             (4608a c  - 2304a b c  + 288a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   5
+--R             (5376a b c  - 2688a b c  + 336a b c)d
+--R           + 
+--R                 6 3       4 4       3 6  3        6   2       5 3       4 5
+--R           (2560a c  - 480a b c + 80a b )d  + (768a b c  - 384a b c + 48a b )d
+--R        *
+--R            3 2 2
+--R           e f x
+--R       + 
+--R                   5 4       4 2 3      3 4 2  8
+--R             (1152a c  - 576a b c  + 72a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   6
+--R             (1792a b c  - 896a b c  + 112a b c)d
+--R           + 
+--R                   6 3       4 4       3 6  4
+--R             (1280a c  - 240a b c + 40a b )d
+--R           + 
+--R                  6   2       5 3       4 5  2       7 2      6 2      5 4
+--R             (768a b c  - 384a b c + 48a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R            2 2
+--R           e f x
+--R       + 
+--R                  5 4      4 2 3     3 4 2  9
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5   7        6 3      4 4      3 6  5
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  6   2       5 3       4 5  3        7 2      6 2      5 4
+--R             (256a b c  - 128a b c + 16a b )d  + (128a c  - 64a b c + 8a b )d
+--R        *
+--R              2
+--R           e f
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1042
+
+--S 1043 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 5 4      4 2 3     3 4 2  10 2 9
+--R           (- 64a c  + 32a b c  - 4a b c )e  f x
+--R         + 
+--R                  5 4       4 2 3      3 4 2    9 2 8
+--R           (- 576a c  + 288a b c  - 36a b c )d e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  2       5   3      4 3 2
+--R               (- 2304a c  + 1152a b c  - 144a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                   3 5
+--R               - 8a b c
+--R          *
+--R              8 2 7
+--R             e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  3
+--R               (- 5376a c  + 2688a b c  - 336a b c )d
+--R             + 
+--R                      5   3       4 3 2      3 5
+--R               (- 896a b c  + 448a b c  - 56a b c)d
+--R          *
+--R              7 2 6
+--R             e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  4
+--R               (- 8064a c  + 4032a b c  - 504a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   2       6 3      4 4
+--R               (- 2688a b c  + 1344a b c  - 168a b c)d  - 128a c  + 24a b c
+--R             + 
+--R                   3 6
+--R               - 4a b
+--R          *
+--R              6 2 5
+--R             e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  5
+--R               (- 8064a c  + 4032a b c  - 504a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   3
+--R               (- 4480a b c  + 2240a b c  - 280a b c)d
+--R             + 
+--R                      6 3       4 4       3 6
+--R               (- 640a c  + 120a b c - 20a b )d
+--R          *
+--R              5 2 4
+--R             e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  6
+--R               (- 5376a c  + 2688a b c  - 336a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   4
+--R               (- 4480a b c  + 2240a b c  - 280a b c)d
+--R             + 
+--R                       6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (- 1280a c  + 240a b c - 40a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              4 2 3
+--R             e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  7
+--R               (- 2304a c  + 1152a b c  - 144a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   5
+--R               (- 2688a b c  + 1344a b c  - 168a b c)d
+--R             + 
+--R                       6 3       4 4       3 6  3
+--R               (- 1280a c  + 240a b c - 40a b )d
+--R             + 
+--R                      6   2       5 3       4 5
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R          *
+--R              3 2 2
+--R             e f x
+--R         + 
+--R                      5 4       4 2 3      3 4 2  8
+--R               (- 576a c  + 288a b c  - 36a b c )d
+--R             + 
+--R                      5   3       4 3 2      3 5   6
+--R               (- 896a b c  + 448a b c  - 56a b c)d
+--R             + 
+--R                      6 3       4 4       3 6  4
+--R               (- 640a c  + 120a b c - 20a b )d
+--R             + 
+--R                      6   2       5 3       4 5  2      7 2      6 2      5 4
+--R               (- 384a b c  + 192a b c - 24a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R              2 2
+--R             e f x
+--R         + 
+--R                     5 4      4 2 3     3 4 2  9
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      5   3      4 3 2     3 5   7
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      6 3      4 4      3 6  5
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  3         7 2      6 2      5 4
+--R             (- 128a b c  + 64a b c - 8a b )d  + (- 64a c  + 32a b c - 4a b )d
+--R          *
+--R                2
+--R             e f
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2 4
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 8
+--R                         e f
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2 4
+--R                e f
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                     3 6
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 8
+--R                           e f
+--R                + 
+--R                               8   8             7 3 7             6 5 6
+--R                      47692800a b c  - 204648192a b c  + 257282496a b c
+--R                    + 
+--R                                  5 7 5            4 9 4            3 11 3
+--R                      - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                    + 
+--R                              2 13 2            15         17
+--R                      1776960a b  c  - 135900a b  c + 4500b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2 4
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2 4
+--R                       e f
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R               5 4      4 2 3     3 4 2  10 2 9
+--R           (64a c  - 32a b c  + 4a b c )e  f x
+--R         + 
+--R                5 4       4 2 3      3 4 2    9 2 8
+--R           (576a c  - 288a b c  + 36a b c )d e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  2       5   3      4 3 2
+--R               (2304a c  - 1152a b c  + 144a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R          *
+--R              8 2 7
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  3
+--R               (5376a c  - 2688a b c  + 336a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5
+--R               (896a b c  - 448a b c  + 56a b c)d
+--R          *
+--R              7 2 6
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  4
+--R               (8064a c  - 4032a b c  + 504a b c )d
+--R             + 
+--R                   5   3        4 3 2       3 5   2       6 3      4 4      3 6
+--R             (2688a b c  - 1344a b c  + 168a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              6 2 5
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  5
+--R               (8064a c  - 4032a b c  + 504a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   3
+--R               (4480a b c  - 2240a b c  + 280a b c)d
+--R             + 
+--R                    6 3       4 4       3 6
+--R               (640a c  - 120a b c + 20a b )d
+--R          *
+--R              5 2 4
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  6
+--R               (5376a c  - 2688a b c  + 336a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   4
+--R               (4480a b c  - 2240a b c  + 280a b c)d
+--R             + 
+--R                     6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (1280a c  - 240a b c + 40a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              4 2 3
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  7
+--R               (2304a c  - 1152a b c  + 144a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   5
+--R               (2688a b c  - 1344a b c  + 168a b c)d
+--R             + 
+--R                   6 3       4 4       3 6  3        6   2       5 3       4 5
+--R             (1280a c  - 240a b c + 40a b )d  + (384a b c  - 192a b c + 24a b )d
+--R          *
+--R              3 2 2
+--R             e f x
+--R         + 
+--R                    5 4       4 2 3      3 4 2  8
+--R               (576a c  - 288a b c  + 36a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5   6
+--R               (896a b c  - 448a b c  + 56a b c)d
+--R             + 
+--R                    6 3       4 4       3 6  4
+--R               (640a c  - 120a b c + 20a b )d
+--R             + 
+--R                    6   2       5 3       4 5  2      7 2      6 2      5 4
+--R               (384a b c  - 192a b c + 24a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R              2 2
+--R             e f x
+--R         + 
+--R                   5 4      4 2 3     3 4 2  9
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    5   3      4 3 2     3 5   7        6 3      4 4      3 6  5
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  3       7 2      6 2      5 4
+--R               (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R          *
+--R                2
+--R             e f
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2 4
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 8
+--R                         e f
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2 4
+--R                e f
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                     3 6
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 8
+--R                           e f
+--R                + 
+--R                                 8   8             7 3 7             6 5 6
+--R                      - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                    + 
+--R                                5 7 5            4 9 4            3 11 3
+--R                      160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                    + 
+--R                                2 13 2            15         17
+--R                      - 1776960a b  c  + 135900a b  c - 4500b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2 4
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2 4
+--R                       e f
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R                 5 4      4 2 3     3 4 2  10 2 9
+--R           (- 64a c  + 32a b c  - 4a b c )e  f x
+--R         + 
+--R                  5 4       4 2 3      3 4 2    9 2 8
+--R           (- 576a c  + 288a b c  - 36a b c )d e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  2       5   3      4 3 2
+--R               (- 2304a c  + 1152a b c  - 144a b c )d  - 128a b c  + 64a b c
+--R             + 
+--R                   3 5
+--R               - 8a b c
+--R          *
+--R              8 2 7
+--R             e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  3
+--R               (- 5376a c  + 2688a b c  - 336a b c )d
+--R             + 
+--R                      5   3       4 3 2      3 5
+--R               (- 896a b c  + 448a b c  - 56a b c)d
+--R          *
+--R              7 2 6
+--R             e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  4
+--R               (- 8064a c  + 4032a b c  - 504a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   2       6 3      4 4
+--R               (- 2688a b c  + 1344a b c  - 168a b c)d  - 128a c  + 24a b c
+--R             + 
+--R                   3 6
+--R               - 4a b
+--R          *
+--R              6 2 5
+--R             e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  5
+--R               (- 8064a c  + 4032a b c  - 504a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   3
+--R               (- 4480a b c  + 2240a b c  - 280a b c)d
+--R             + 
+--R                      6 3       4 4       3 6
+--R               (- 640a c  + 120a b c - 20a b )d
+--R          *
+--R              5 2 4
+--R             e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  6
+--R               (- 5376a c  + 2688a b c  - 336a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   4
+--R               (- 4480a b c  + 2240a b c  - 280a b c)d
+--R             + 
+--R                       6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (- 1280a c  + 240a b c - 40a b )d  - 128a b c  + 64a b c - 8a b
+--R          *
+--R              4 2 3
+--R             e f x
+--R         + 
+--R                       5 4        4 2 3       3 4 2  7
+--R               (- 2304a c  + 1152a b c  - 144a b c )d
+--R             + 
+--R                       5   3        4 3 2       3 5   5
+--R               (- 2688a b c  + 1344a b c  - 168a b c)d
+--R             + 
+--R                       6 3       4 4       3 6  3
+--R               (- 1280a c  + 240a b c - 40a b )d
+--R             + 
+--R                      6   2       5 3       4 5
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R          *
+--R              3 2 2
+--R             e f x
+--R         + 
+--R                      5 4       4 2 3      3 4 2  8
+--R               (- 576a c  + 288a b c  - 36a b c )d
+--R             + 
+--R                      5   3       4 3 2      3 5   6
+--R               (- 896a b c  + 448a b c  - 56a b c)d
+--R             + 
+--R                      6 3       4 4       3 6  4
+--R               (- 640a c  + 120a b c - 20a b )d
+--R             + 
+--R                      6   2       5 3       4 5  2      7 2      6 2      5 4
+--R               (- 384a b c  + 192a b c - 24a b )d  - 64a c  + 32a b c - 4a b
+--R          *
+--R              2 2
+--R             e f x
+--R         + 
+--R                     5 4      4 2 3     3 4 2  9
+--R               (- 64a c  + 32a b c  - 4a b c )d
+--R             + 
+--R                      5   3      4 3 2     3 5   7
+--R               (- 128a b c  + 64a b c  - 8a b c)d
+--R             + 
+--R                      6 3      4 4      3 6  5
+--R               (- 128a c  + 24a b c - 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  3         7 2      6 2      5 4
+--R             (- 128a b c  + 64a b c - 8a b )d  + (- 64a c  + 32a b c - 4a b )d
+--R          *
+--R                2
+--R             e f
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2 4
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 8
+--R                         e f
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2 4
+--R                e f
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                     3 6
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 8
+--R                           e f
+--R                + 
+--R                               8   8             7 3 7             6 5 6
+--R                      47692800a b c  - 204648192a b c  + 257282496a b c
+--R                    + 
+--R                                  5 7 5            4 9 4            3 11 3
+--R                      - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                    + 
+--R                              2 13 2            15         17
+--R                      1776960a b  c  - 135900a b  c + 4500b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2 4
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2 4
+--R                       e f
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R               5 4      4 2 3     3 4 2  10 2 9
+--R           (64a c  - 32a b c  + 4a b c )e  f x
+--R         + 
+--R                5 4       4 2 3      3 4 2    9 2 8
+--R           (576a c  - 288a b c  + 36a b c )d e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  2       5   3      4 3 2
+--R               (2304a c  - 1152a b c  + 144a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R          *
+--R              8 2 7
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  3
+--R               (5376a c  - 2688a b c  + 336a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5
+--R               (896a b c  - 448a b c  + 56a b c)d
+--R          *
+--R              7 2 6
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  4
+--R               (8064a c  - 4032a b c  + 504a b c )d
+--R             + 
+--R                   5   3        4 3 2       3 5   2       6 3      4 4      3 6
+--R             (2688a b c  - 1344a b c  + 168a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              6 2 5
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  5
+--R               (8064a c  - 4032a b c  + 504a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   3
+--R               (4480a b c  - 2240a b c  + 280a b c)d
+--R             + 
+--R                    6 3       4 4       3 6
+--R               (640a c  - 120a b c + 20a b )d
+--R          *
+--R              5 2 4
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  6
+--R               (5376a c  - 2688a b c  + 336a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   4
+--R               (4480a b c  - 2240a b c  + 280a b c)d
+--R             + 
+--R                     6 3       4 4       3 6  2       6   2      5 3      4 5
+--R               (1280a c  - 240a b c + 40a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              4 2 3
+--R             e f x
+--R         + 
+--R                     5 4        4 2 3       3 4 2  7
+--R               (2304a c  - 1152a b c  + 144a b c )d
+--R             + 
+--R                     5   3        4 3 2       3 5   5
+--R               (2688a b c  - 1344a b c  + 168a b c)d
+--R             + 
+--R                   6 3       4 4       3 6  3        6   2       5 3       4 5
+--R             (1280a c  - 240a b c + 40a b )d  + (384a b c  - 192a b c + 24a b )d
+--R          *
+--R              3 2 2
+--R             e f x
+--R         + 
+--R                    5 4       4 2 3      3 4 2  8
+--R               (576a c  - 288a b c  + 36a b c )d
+--R             + 
+--R                    5   3       4 3 2      3 5   6
+--R               (896a b c  - 448a b c  + 56a b c)d
+--R             + 
+--R                    6 3       4 4       3 6  4
+--R               (640a c  - 120a b c + 20a b )d
+--R             + 
+--R                    6   2       5 3       4 5  2      7 2      6 2      5 4
+--R               (384a b c  - 192a b c + 24a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R              2 2
+--R             e f x
+--R         + 
+--R                   5 4      4 2 3     3 4 2  9
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    5   3      4 3 2     3 5   7        6 3      4 4      3 6  5
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    6   2      5 3      4 5  3       7 2      6 2      5 4
+--R               (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R          *
+--R                2
+--R             e f
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2 4
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 8
+--R                         e f
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2 4
+--R                e f
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                     3 6
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 8
+--R                           e f
+--R                + 
+--R                                 8   8             7 3 7             6 5 6
+--R                      - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                    + 
+--R                                5 7 5            4 9 4            3 11 3
+--R                      160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                    + 
+--R                                2 13 2            15         17
+--R                      - 1776960a b  c  + 135900a b  c - 4500b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2 4
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2 4
+--R                       e f
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R              2 4         2 3      4 2  8 8
+--R       (- 180a c  + 111a b c  - 15b c )e x
+--R     + 
+--R               2 4         2 3       4 2    7 7
+--R       (- 1440a c  + 888a b c  - 120b c )d e x
+--R     + 
+--R                  2 4          2 3       4 2  2       2   3         3 2      5
+--R         ((- 5040a c  + 3108a b c  - 420b c )d  - 392a b c  + 227a b c  - 30b c)
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R                    2 4          2 3       4 2  3
+--R           (- 10080a c  + 6216a b c  - 840b c )d
+--R         + 
+--R                   2   3          3 2       5
+--R           (- 2352a b c  + 1362a b c  - 180b c)d
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R                    2 4          2 3        4 2  4
+--R           (- 12600a c  + 7770a b c  - 1050b c )d
+--R         + 
+--R                   2   3          3 2       5   2       3 3      2 2 2        4
+--R           (- 5880a b c  + 3405a b c  - 450b c)d  - 324a c  - 25a b c  + 91a b c
+--R         + 
+--R                6
+--R           - 15b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R                    2 4          2 3       4 2  5
+--R           (- 10080a c  + 6216a b c  - 840b c )d
+--R         + 
+--R                   2   3          3 2       5   3
+--R           (- 7840a b c  + 4540a b c  - 600b c)d
+--R         + 
+--R                   3 3       2 2 2         4       6
+--R           (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R                   2 4          2 3       4 2  6
+--R           (- 5040a c  + 3108a b c  - 420b c )d
+--R         + 
+--R                   2   3          3 2       5   4
+--R           (- 5880a b c  + 3405a b c  - 450b c)d
+--R         + 
+--R                   3 3       2 2 2         4       6  2       3   2       2 3
+--R           (- 1944a c  - 150a b c  + 546a b c - 90b )d  - 364a b c  + 194a b c
+--R         + 
+--R                  5
+--R           - 25a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R                   2 4         2 3       4 2  7
+--R           (- 1440a c  + 888a b c  - 120b c )d
+--R         + 
+--R                   2   3          3 2       5   5
+--R           (- 2352a b c  + 1362a b c  - 180b c)d
+--R         + 
+--R                   3 3       2 2 2         4       6  3
+--R           (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R         + 
+--R                  3   2       2 3         5
+--R           (- 728a b c  + 388a b c - 50a b )d
+--R      *
+--R         e x
+--R     + 
+--R              2 4         2 3      4 2  8          2   3         3 2      5   6
+--R       (- 180a c  + 111a b c  - 15b c )d  + (- 392a b c  + 227a b c  - 30b c)d
+--R     + 
+--R              3 3      2 2 2        4       6  4
+--R       (- 324a c  - 25a b c  + 91a b c - 15b )d
+--R     + 
+--R              3   2       2 3         5  2       4 2      3 2      2 4
+--R       (- 364a b c  + 194a b c - 25a b )d  - 128a c  + 64a b c - 8a b
+--R  /
+--R            5 4      4 2 3     3 4 2  10 2 9
+--R       (128a c  - 64a b c  + 8a b c )e  f x
+--R     + 
+--R             5 4       4 2 3      3 4 2    9 2 8
+--R       (1152a c  - 576a b c  + 72a b c )d e f x
+--R     + 
+--R                   5 4        4 2 3       3 4 2  2       5   3       4 3 2
+--R             (4608a c  - 2304a b c  + 288a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                3 5
+--R             16a b c
+--R      *
+--R          8 2 7
+--R         e f x
+--R     + 
+--R                  5 4        4 2 3       3 4 2  3
+--R           (10752a c  - 5376a b c  + 672a b c )d
+--R         + 
+--R                 5   3       4 3 2       3 5
+--R           (1792a b c  - 896a b c  + 112a b c)d
+--R      *
+--R          7 2 6
+--R         e f x
+--R     + 
+--R                  5 4        4 2 3        3 4 2  4
+--R           (16128a c  - 8064a b c  + 1008a b c )d
+--R         + 
+--R                 5   3        4 3 2       3 5   2       6 3      4 4      3 6
+--R           (5376a b c  - 2688a b c  + 336a b c)d  + 256a c  - 48a b c + 8a b
+--R      *
+--R          6 2 5
+--R         e f x
+--R     + 
+--R                  5 4        4 2 3        3 4 2  5
+--R           (16128a c  - 8064a b c  + 1008a b c )d
+--R         + 
+--R                 5   3        4 3 2       3 5   3
+--R           (8960a b c  - 4480a b c  + 560a b c)d
+--R         + 
+--R                 6 3       4 4       3 6
+--R           (1280a c  - 240a b c + 40a b )d
+--R      *
+--R          5 2 4
+--R         e f x
+--R     + 
+--R                  5 4        4 2 3       3 4 2  6
+--R           (10752a c  - 5376a b c  + 672a b c )d
+--R         + 
+--R                 5   3        4 3 2       3 5   4
+--R           (8960a b c  - 4480a b c  + 560a b c)d
+--R         + 
+--R                 6 3       4 4       3 6  2       6   2       5 3       4 5
+--R           (2560a c  - 480a b c + 80a b )d  + 256a b c  - 128a b c + 16a b
+--R      *
+--R          4 2 3
+--R         e f x
+--R     + 
+--R                 5 4        4 2 3       3 4 2  7
+--R           (4608a c  - 2304a b c  + 288a b c )d
+--R         + 
+--R                 5   3        4 3 2       3 5   5
+--R           (5376a b c  - 2688a b c  + 336a b c)d
+--R         + 
+--R                 6 3       4 4       3 6  3        6   2       5 3       4 5
+--R           (2560a c  - 480a b c + 80a b )d  + (768a b c  - 384a b c + 48a b )d
+--R      *
+--R          3 2 2
+--R         e f x
+--R     + 
+--R                 5 4       4 2 3      3 4 2  8
+--R           (1152a c  - 576a b c  + 72a b c )d
+--R         + 
+--R                 5   3       4 3 2       3 5   6
+--R           (1792a b c  - 896a b c  + 112a b c)d
+--R         + 
+--R                 6 3       4 4       3 6  4        6   2       5 3       4 5  2
+--R           (1280a c  - 240a b c + 40a b )d  + (768a b c  - 384a b c + 48a b )d
+--R         + 
+--R               7 2      6 2      5 4
+--R           128a c  - 64a b c + 8a b
+--R      *
+--R          2 2
+--R         e f x
+--R     + 
+--R                5 4      4 2 3     3 4 2  9
+--R           (128a c  - 64a b c  + 8a b c )d
+--R         + 
+--R                5   3       4 3 2      3 5   7        6 3      4 4      3 6  5
+--R           (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R         + 
+--R                6   2       5 3       4 5  3        7 2      6 2      5 4
+--R           (256a b c  - 128a b c + 16a b )d  + (128a c  - 64a b c + 8a b )d
+--R      *
+--R            2
+--R         e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 1043
+
+--S 1044 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +-----------+
+--R               5 2      4 2      3 4    2 +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )e f \|2 \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2 4
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 8
+--R                         e f
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2 4
+--R                e f
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                     3 6
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 8
+--R                           e f
+--R                + 
+--R                               8   8             7 3 7             6 5 6
+--R                      47692800a b c  - 204648192a b c  + 257282496a b c
+--R                    + 
+--R                                  5 7 5            4 9 4            3 11 3
+--R                      - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                    + 
+--R                              2 13 2            15         17
+--R                      1776960a b  c  - 135900a b  c + 4500b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2 4
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2 4
+--R                       e f
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R                                            +-----------+
+--R             5 2      4 2      3 4    2 +-+ |          2
+--R         (64a c  - 32a b c + 4a b )e f \|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2 4
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 8
+--R                         e f
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2 4
+--R                e f
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                15 8             14 2 7             13 4 6
+--R                      125829120a  c  - 331350016a  b c  + 350748672a  b c
+--R                    + 
+--R                                  12 6 5            11 8 4            10 10 3
+--R                      - 201850880a  b c  + 70287360a  b c  - 15319040a  b  c
+--R                    + 
+--R                              9 12 2          8 14         7 16
+--R                      2054144a b  c  - 155648a b  c + 5120a b
+--R                 *
+--R                     3 6
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 8
+--R                           e f
+--R                + 
+--R                                 8   8             7 3 7             6 5 6
+--R                      - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                    + 
+--R                                5 7 5            4 9 4            3 11 3
+--R                      160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                    + 
+--R                                2 13 2            15         17
+--R                      - 1776960a b  c  + 135900a b  c - 4500b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2 4
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2 4
+--R                       e f
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R                                              +-----------+
+--R               5 2      4 2      3 4    2 +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )e f \|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             12 5          11 2 4          10 4 3         9 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a b c
+--R                  + 
+--R                           8 8        7 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                   2 4
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 8
+--R                         e f
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2 4
+--R                e f
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                     3 6
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 8
+--R                           e f
+--R                + 
+--R                               8   8             7 3 7             6 5 6
+--R                      47692800a b c  - 204648192a b c  + 257282496a b c
+--R                    + 
+--R                                  5 7 5            4 9 4            3 11 3
+--R                      - 160673040a b c  + 58447224a b c  - 13058388a b  c
+--R                    + 
+--R                              2 13 2            15         17
+--R                      1776960a b  c  - 135900a b  c + 4500b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    12 5          11 2 4          10 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 9 6 2        8 8        7 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                          2 4
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2 4
+--R                       e f
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R                                                          +--------------------+
+--R                                            +-----------+ |   +-----------+
+--R             5 2      4 2      3 4    2 +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           12 5          11 2 4          10 4 3         9 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a b c
+--R                  + 
+--R                         8 8        7 10
+--R                    5120a b c - 256a b
+--R               *
+--R                   2 4
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                   6 6            5 2 5            4 4 4
+--R                         - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                       + 
+--R                                3 6 3           2 8 2            10          12
+--R                       28456110a b c  - 7672725a b c  + 992250a b  c - 50625b
+--R                    /
+--R                                    19 5            18 2 4            17 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      16 6 2           15 8          14 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 8
+--R                         e f
+--R              + 
+--R                         5   5          4 3 4          3 5 3         2 7 2
+--R                - 166320a b c  + 249480a b c  - 135135a b c  + 35046a b c
+--R              + 
+--R                         9        11
+--R                - 4455a b c + 225b
+--R           /
+--R                         12 5          11 2 4         10 4 3         9 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a b c
+--R                + 
+--R                       8 8        7 10
+--R                  2560a b c - 128a b
+--R             *
+--R                 2 4
+--R                e f
+--R      *
+--R         log
+--R                                  15 8             14 2 7             13 4 6
+--R                      - 125829120a  c  + 331350016a  b c  - 350748672a  b c
+--R                    + 
+--R                                12 6 5            11 8 4            10 10 3
+--R                      201850880a  b c  - 70287360a  b c  + 15319040a  b  c
+--R                    + 
+--R                                9 12 2          8 14         7 16
+--R                      - 2054144a b  c  + 155648a b  c - 5120a b
+--R                 *
+--R                     3 6
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                     6 6            5 2 5            4 4 4
+--R                           - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                         + 
+--R                                    3 6 3           2 8 2            10
+--R                           28456110a b c  - 7672725a b c  + 992250a b  c
+--R                         + 
+--R                                   12
+--R                           - 50625b
+--R                      /
+--R                                      19 5            18 2 4            17 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        16 6 2           15 8          14 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 8
+--R                           e f
+--R                + 
+--R                                 8   8             7 3 7             6 5 6
+--R                      - 47692800a b c  + 204648192a b c  - 257282496a b c
+--R                    + 
+--R                                5 7 5            4 9 4            3 11 3
+--R                      160673040a b c  - 58447224a b c  + 13058388a b  c
+--R                    + 
+--R                                2 13 2            15         17
+--R                      - 1776960a b  c  + 135900a b  c - 4500b
+--R                 *
+--R                       2
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  12 5          11 2 4          10 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   9 6 2        8 8        7 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                          2 4
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                          6 6            5 2 5            4 4 4
+--R                                - 4100625a c  + 25296300a b c  - 47942766a b c
+--R                              + 
+--R                                         3 6 3           2 8 2            10
+--R                                28456110a b c  - 7672725a b c  + 992250a b  c
+--R                              + 
+--R                                        12
+--R                                - 50625b
+--R                           /
+--R                                           19 5            18 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           17 4 3            16 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          15 8          14 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 8
+--R                                e f
+--R                     + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 166320a b c  + 249480a b c  - 135135a b c
+--R                     + 
+--R                             2 7 2          9        11
+--R                       35046a b c  - 4455a b c + 225b
+--R                  /
+--R                                12 5          11 2 4         10 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 9 6 2        8 8        7 10
+--R                         - 20480a b c  + 2560a b c - 128a b
+--R                    *
+--R                        2 4
+--R                       e f
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                e x
+--R            + 
+--R                           5 9            4 2 8            3 4 7
+--R                  21870000a c  - 76545000a b c  + 52848423a b c
+--R                + 
+--R                             2 6 6             8 5          10 4
+--R                  - 15417810a b c  + 2101275a b c  - 111375b  c
+--R             *
+--R                d
+--R     + 
+--R                                         +-----------+
+--R                  2 2         2       4  |          2        2   2         3
+--R             (180a c  - 111a b c + 15b )\|- 4a c + b   + 372a b c  - 141a b c
+--R           + 
+--R                5
+--R             15b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +-----------+
+--R                  2 2         2       4  |          2        2   2         3
+--R             (180a c  - 111a b c + 15b )\|- 4a c + b   - 372a b c  + 141a b c
+--R           + 
+--R                  5
+--R             - 15b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                                                         +--------------------+
+--R                                           +-----------+ |   +-----------+
+--R            5 2      4 2      3 4    2 +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1044
+
+--S 1045 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1045
+
+)clear all
+
+--S 1046 of 1057
+t0:=1/((d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 15 3 15      3   14 3 14        3 2       2  13 3 13
+--R       c e  f x   + 15c d e  f x   + (105c d  + 3b c )e  f x
+--R     + 
+--R            3 3        2   12 3 12
+--R       (455c d  + 39b c d)e  f x
+--R     + 
+--R             3 4         2 2       2     2   11 3 11
+--R       (1365c d  + 234b c d  + 3a c  + 3b c)e  f x
+--R     + 
+--R             3 5         2 3         2      2     10 3 10
+--R       (3003c d  + 858b c d  + (33a c  + 33b c)d)e  f x
+--R     + 
+--R             3 6          2 4          2       2   2             3  9 3 9
+--R       (5005c d  + 2145b c d  + (165a c  + 165b c)d  + 6a b c + b )e f x
+--R     + 
+--R             3 7          2 5          2       2   3                3    8 3 8
+--R       (6435c d  + 3861b c d  + (495a c  + 495b c)d  + (54a b c + 9b )d)e f x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           6435c d  + 5148b c d  + (990a c  + 990b c)d  + (216a b c + 36b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          7 3 7
+--R         e f x
+--R     + 
+--R                3 9          2 7           2        2   5                  3  3
+--R           5005c d  + 5148b c d  + (1386a c  + 1386b c)d  + (504a b c + 84b )d
+--R         + 
+--R               2         2
+--R           (21a c + 21a b )d
+--R      *
+--R          6 3 6
+--R         e f x
+--R     + 
+--R                3 10          2 8           2        2   6
+--R           3003c d   + 3861b c d  + (1386a c  + 1386b c)d
+--R         + 
+--R                           3  4       2         2  2     2
+--R           (756a b c + 126b )d  + (63a c + 63a b )d  + 3a b
+--R      *
+--R          5 3 5
+--R         e f x
+--R     + 
+--R                3 11          2 9          2       2   7                   3  5
+--R           1365c d   + 2145b c d  + (990a c  + 990b c)d  + (756a b c + 126b )d
+--R         + 
+--R                2          2  3      2
+--R           (105a c + 105a b )d  + 15a b d
+--R      *
+--R          4 3 4
+--R         e f x
+--R     + 
+--R               3 12         2 10          2       2   8                  3  6
+--R           455c d   + 858b c d   + (495a c  + 495b c)d  + (504a b c + 84b )d
+--R         + 
+--R                2          2  4      2   2    3
+--R           (105a c + 105a b )d  + 30a b d  + a
+--R      *
+--R          3 3 3
+--R         e f x
+--R     + 
+--R               3 13         2 11          2       2   9                  3  7
+--R           105c d   + 234b c d   + (165a c  + 165b c)d  + (216a b c + 36b )d
+--R         + 
+--R               2         2  5      2   3     3
+--R           (63a c + 63a b )d  + 30a b d  + 3a d
+--R      *
+--R          2 3 2
+--R         e f x
+--R     + 
+--R              3 14        2 12         2      2   10                3  8
+--R           15c d   + 39b c d   + (33a c  + 33b c)d   + (54a b c + 9b )d
+--R         + 
+--R               2         2  6      2   4     3 2
+--R           (21a c + 21a b )d  + 15a b d  + 3a d
+--R      *
+--R            3
+--R         e f x
+--R     + 
+--R            3 15       2 13        2     2   11              3  9
+--R           c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R         + 
+--R              2        2  7     2   5    3 3
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R          3
+--R         f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1046
+
+--S 1047 of 1057
+r0:=-3/2*(b^4-7*a*b^2*c+10*a^2*c^2)/(a^3*(b^2-4*a*c)^2*e*f^3*(d+e*x)^2)+_
+   1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f^3*(d+e*x)^2*(a+b*_
+   (d+e*x)^2+c*(d+e*x)^4)^2)+1/4*(3*b^4-20*a*b^2*c+20*a^2*c^2+3*b*c*_
+   (b^2-6*a*c)*(d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*f^3*(d+e*x)^2*(a+b*_
+   (d+e*x)^2+c*(d+e*x)^4))-3/2*(b^6-10*a*b^4*c+30*a^2*b^2*c^2-20*a^3*c^3)*_
+   atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(5/2)*e*f^3)-_
+   3*b*log(d+e*x)/(a^4*e*f^3)+3/4*b*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a^4*e*f^3)
+--R 
+--R
+--R   (2)
+--R                3 5       2 2 4        4 3     6 2  10 10
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )e  x
+--R         + 
+--R                 3 5        2 2 4         4 3      6 2    9 9
+--R           (1200a c  - 1800a b c  + 600a b c  - 60b c )d e x
+--R         + 
+--R                     3 5        2 2 4          4 3       6 2  2       3   4
+--R               (5400a c  - 8100a b c  + 2700a b c  - 270b c )d  + 240a b c
+--R             + 
+--R                     2 3 3         5 2      7
+--R               - 360a b c  + 120a b c  - 12b c
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                      3 5         2 2 4          4 3       6 2  3
+--R               (14400a c  - 21600a b c  + 7200a b c  - 720b c )d
+--R             + 
+--R                     3   4        2 3 3         5 2      7
+--R               (1920a b c  - 2880a b c  + 960a b c  - 96b c)d
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  4
+--R               (25200a c  - 37800a b c  + 12600a b c  - 1260b c )d
+--R             + 
+--R                     3   4         2 3 3          5 2       7   2       4 4
+--R               (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d  + 240a c
+--R             + 
+--R                     3 2 3      2 4 2        6      8
+--R               - 240a b c  - 60a b c  + 48a b c - 6b
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  5
+--R               (30240a c  - 45360a b c  + 15120a b c  - 1512b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   3
+--R               (13440a b c  - 20160a b c  + 6720a b c  - 672b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8
+--R               (1440a c  - 1440a b c  - 360a b c  + 288a b c - 36b )d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  6
+--R               (25200a c  - 37800a b c  + 12600a b c  - 1260b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   4
+--R               (16800a b c  - 25200a b c  + 8400a b c  - 840b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  2
+--R               (3600a c  - 3600a b c  - 900a b c  + 720a b c - 90b )d
+--R             + 
+--R                   4   3       3 3 2       2 5         7
+--R               240a b c  - 360a b c  + 120a b c - 12a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                      3 5         2 2 4          4 3       6 2  7
+--R               (14400a c  - 21600a b c  + 7200a b c  - 720b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   5
+--R               (13440a b c  - 20160a b c  + 6720a b c  - 672b c)d
+--R             + 
+--R                     4 4        3 2 3        2 4 2         6        8  3
+--R               (4800a c  - 4800a b c  - 1200a b c  + 960a b c - 120b )d
+--R             + 
+--R                    4   3        3 3 2       2 5         7
+--R               (960a b c  - 1440a b c  + 480a b c - 48a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     3 5        2 2 4          4 3       6 2  8
+--R               (5400a c  - 8100a b c  + 2700a b c  - 270b c )d
+--R             + 
+--R                     3   4         2 3 3          5 2       7   6
+--R               (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  4
+--R               (3600a c  - 3600a b c  - 900a b c  + 720a b c - 90b )d
+--R             + 
+--R                     4   3        3 3 2       2 5         7  2       5 3
+--R               (1440a b c  - 2160a b c  + 720a b c - 72a b )d  + 120a c
+--R             + 
+--R                     4 2 2      3 4      2 6
+--R               - 180a b c  + 60a b c - 6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     3 5        2 2 4         4 3      6 2  9
+--R               (1200a c  - 1800a b c  + 600a b c  - 60b c )d
+--R             + 
+--R                     3   4        2 3 3         5 2      7   7
+--R               (1920a b c  - 2880a b c  + 960a b c  - 96b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  5
+--R               (1440a c  - 1440a b c  - 360a b c  + 288a b c - 36b )d
+--R             + 
+--R                    4   3        3 3 2       2 5         7  3
+--R               (960a b c  - 1440a b c  + 480a b c - 48a b )d
+--R             + 
+--R                    5 3       4 2 2       3 4       2 6
+--R               (240a c  - 360a b c  + 120a b c - 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                3 5       2 2 4        4 3     6 2  10
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )d
+--R         + 
+--R                3   4       2 3 3         5 2      7   8
+--R           (240a b c  - 360a b c  + 120a b c  - 12b c)d
+--R         + 
+--R                4 4       3 2 3      2 4 2        6      8  6
+--R           (240a c  - 240a b c  - 60a b c  + 48a b c - 6b )d
+--R         + 
+--R                4   3       3 3 2       2 5         7  4
+--R           (240a b c  - 360a b c  + 120a b c - 12a b )d
+--R         + 
+--R                5 3       4 2 2      3 4      2 6  2
+--R           (120a c  - 180a b c  + 60a b c - 6a b )d
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                   2   4        3 3     5 2  10 10
+--R               (48a b c  - 24a b c  + 3b c )e  x
+--R             + 
+--R                    2   4         3 3      5 2    9 9
+--R               (480a b c  - 240a b c  + 30b c )d e x
+--R             + 
+--R                         2   4          3 3       5 2  2      2 2 3        4 2
+--R                   (2160a b c  - 1080a b c  + 135b c )d  + 96a b c  - 48a b c
+--R                 + 
+--R                     6
+--R                   6b c
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  3
+--R                   (5760a b c  - 2880a b c  + 360b c )d
+--R                 + 
+--R                        2 2 3         4 2      6
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  4
+--R                   (10080a b c  - 5040a b c  + 630b c )d
+--R                 + 
+--R                       2 2 3          4 2       6   2      3   3        5      7
+--R                 (2688a b c  - 1344a b c  + 168b c)d  + 96a b c  - 18a b c + 3b
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  5
+--R                   (12096a b c  - 6048a b c  + 756b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   3
+--R                   (5376a b c  - 2688a b c  + 336b c)d
+--R                 + 
+--R                        3   3         5       7
+--R                   (576a b c  - 108a b c + 18b )d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  6
+--R                   (10080a b c  - 5040a b c  + 630b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   4
+--R                   (6720a b c  - 3360a b c  + 420b c)d
+--R                 + 
+--R                       3   3         5       7  2      3 2 2      2 4        6
+--R                 (1440a b c  - 270a b c + 45b )d  + 96a b c  - 48a b c + 6a b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  7
+--R                   (5760a b c  - 2880a b c  + 360b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   5
+--R                   (5376a b c  - 2688a b c  + 336b c)d
+--R                 + 
+--R                         3   3         5       7  3
+--R                   (1920a b c  - 360a b c + 60b )d
+--R                 + 
+--R                        3 2 2       2 4         6
+--R                   (384a b c  - 192a b c + 24a b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  8
+--R                   (2160a b c  - 1080a b c  + 135b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   6
+--R                   (2688a b c  - 1344a b c  + 168b c)d
+--R                 + 
+--R                         3   3         5       7  4
+--R                   (1440a b c  - 270a b c + 45b )d
+--R                 + 
+--R                      3 2 2       2 4         6  2      4   2      3 3      2 5
+--R                 (576a b c  - 288a b c + 36a b )d  + 48a b c  - 24a b c + 3a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                        2   4         3 3      5 2  9
+--R                   (480a b c  - 240a b c  + 30b c )d
+--R                 + 
+--R                        2 2 3         4 2      6   7
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R                 + 
+--R                        3   3         5       7  5
+--R                   (576a b c  - 108a b c + 18b )d
+--R                 + 
+--R                        3 2 2       2 4         6  3
+--R                   (384a b c  - 192a b c + 24a b )d
+--R                 + 
+--R                       4   2      3 3      2 5
+--R                   (96a b c  - 48a b c + 6a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                   2   4        3 3     5 2  10       2 2 3        4 2     6   8
+--R               (48a b c  - 24a b c  + 3b c )d   + (96a b c  - 48a b c  + 6b c)d
+--R             + 
+--R                   3   3        5      7  6       3 2 2      2 4        6  4
+--R               (96a b c  - 18a b c + 3b )d  + (96a b c  - 48a b c + 6a b )d
+--R             + 
+--R                   4   2      3 3      2 5  2
+--R               (48a b c  - 24a b c + 3a b )d
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                      2   4        3 3      5 2  10 10
+--R               (- 192a b c  + 96a b c  - 12b c )e  x
+--R             + 
+--R                       2   4         3 3       5 2    9 9
+--R               (- 1920a b c  + 960a b c  - 120b c )d e x
+--R             + 
+--R                           2   4          3 3       5 2  2       2 2 3
+--R                   (- 8640a b c  + 4320a b c  - 540b c )d  - 384a b c
+--R                 + 
+--R                         4 2      6
+--R                   192a b c  - 24b c
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  3
+--R                   (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                 + 
+--R                           2 2 3          4 2       6
+--R                   (- 3072a b c  + 1536a b c  - 192b c)d
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  4
+--R                   (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                 + 
+--R                            2 2 3          4 2       6   2       3   3        5
+--R                   (- 10752a b c  + 5376a b c  - 672b c)d  - 384a b c  + 72a b c
+--R                 + 
+--R                        7
+--R                   - 12b
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  5
+--R                   (- 48384a b c  + 24192a b c  - 3024b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   3
+--R                   (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                 + 
+--R                           3   3         5       7
+--R                   (- 2304a b c  + 432a b c - 72b )d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  6
+--R                   (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   4
+--R                   (- 26880a b c  + 13440a b c  - 1680b c)d
+--R                 + 
+--R                           3   3          5        7  2       3 2 2       2 4
+--R                   (- 5760a b c  + 1080a b c - 180b )d  - 384a b c  + 192a b c
+--R                 + 
+--R                          6
+--R                   - 24a b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  7
+--R                   (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   5
+--R                   (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                 + 
+--R                           3   3          5        7  3
+--R                   (- 7680a b c  + 1440a b c - 240b )d
+--R                 + 
+--R                           3 2 2       2 4         6
+--R                   (- 1536a b c  + 768a b c - 96a b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2   4          3 3       5 2  8
+--R                   (- 8640a b c  + 4320a b c  - 540b c )d
+--R                 + 
+--R                            2 2 3          4 2       6   6
+--R                   (- 10752a b c  + 5376a b c  - 672b c)d
+--R                 + 
+--R                           3   3          5        7  4
+--R                   (- 5760a b c  + 1080a b c - 180b )d
+--R                 + 
+--R                           3 2 2        2 4          6  2       4   2      3 3
+--R                   (- 2304a b c  + 1152a b c - 144a b )d  - 192a b c  + 96a b c
+--R                 + 
+--R                        2 5
+--R                   - 12a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2   4         3 3       5 2  9
+--R                   (- 1920a b c  + 960a b c  - 120b c )d
+--R                 + 
+--R                           2 2 3          4 2       6   7
+--R                   (- 3072a b c  + 1536a b c  - 192b c)d
+--R                 + 
+--R                           3   3         5       7  5
+--R                   (- 2304a b c  + 432a b c - 72b )d
+--R                 + 
+--R                           3 2 2       2 4         6  3
+--R                   (- 1536a b c  + 768a b c - 96a b )d
+--R                 + 
+--R                          4   2       3 3       2 5
+--R                   (- 384a b c  + 192a b c - 24a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                      2   4        3 3      5 2  10
+--R               (- 192a b c  + 96a b c  - 12b c )d
+--R             + 
+--R                      2 2 3         4 2      6   8
+--R               (- 384a b c  + 192a b c  - 24b c)d
+--R             + 
+--R                      3   3        5       7  6
+--R               (- 384a b c  + 72a b c - 12b )d
+--R             + 
+--R                      3 2 2       2 4         6  4
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R             + 
+--R                      4   2      3 3       2 5  2
+--R               (- 192a b c  + 96a b c - 12a b )d
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                 3 4      2 2 3       4 2  8 8
+--R           (- 60a c  + 42a b c  - 6a b c )e x
+--R         + 
+--R                  3 4       2 2 3        4 2    7 7
+--R           (- 480a c  + 336a b c  - 48a b c )d e x
+--R         + 
+--R                       3 4        2 2 3         4 2  2       3   3      2 3 2
+--R               (- 1680a c  + 1176a b c  - 168a b c )d  - 138a b c  + 87a b c
+--R             + 
+--R                      5
+--R               - 12a b c
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  3
+--R               (- 3360a c  + 2352a b c  - 336a b c )d
+--R             + 
+--R                      3   3       2 3 2        5
+--R               (- 828a b c  + 522a b c  - 72a b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  4
+--R               (- 4200a c  + 2940a b c  - 420a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   2       4 3      3 2 2
+--R               (- 2070a b c  + 1305a b c  - 180a b c)d  - 100a c  - 14a b c
+--R             + 
+--R                  2 4        6
+--R               36a b c - 6a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  5
+--R               (- 3360a c  + 2352a b c  - 336a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   3
+--R               (- 2760a b c  + 1740a b c  - 240a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6
+--R               (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  6
+--R               (- 1680a c  + 1176a b c  - 168a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   4
+--R               (- 2070a b c  + 1305a b c  - 180a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6  2       4   2
+--R               (- 600a c  - 84a b c  + 216a b c - 36a b )d  - 122a b c
+--R             + 
+--R                  3 3      2 5
+--R               68a b c - 9a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3 4       2 2 3        4 2  7
+--R               (- 480a c  + 336a b c  - 48a b c )d
+--R             + 
+--R                      3   3       2 3 2        5   5
+--R               (- 828a b c  + 522a b c  - 72a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6  3
+--R               (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R             + 
+--R                      4   2       3 3       2 5
+--R               (- 244a b c  + 136a b c - 18a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 3 4      2 2 3       4 2  8
+--R           (- 60a c  + 42a b c  - 6a b c )d
+--R         + 
+--R                  3   3      2 3 2        5   6
+--R           (- 138a b c  + 87a b c  - 12a b c)d
+--R         + 
+--R                  4 3      3 2 2      2 4        6  4
+--R           (- 100a c  - 14a b c  + 36a b c - 6a b )d
+--R         + 
+--R                  4   2      3 3      2 5  2      5 2      4 2      3 4
+--R           (- 122a b c  + 68a b c - 9a b )d  - 32a c  + 16a b c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             6 4      5 2 3     4 4 2  11 3 10
+--R         (64a c  - 32a b c  + 4a b c )e  f x
+--R       + 
+--R              6 4       5 2 3      4 4 2    10 3 9
+--R         (640a c  - 320a b c  + 40a b c )d e  f x
+--R       + 
+--R                     6 4        5 2 3       4 4 2  2       6   3      5 3 2
+--R               (2880a c  - 1440a b c  + 180a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 4 5
+--R               8a b c
+--R        *
+--R            9 3 8
+--R           e f x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  3
+--R             (7680a c  - 3840a b c  + 480a b c )d
+--R           + 
+--R                   6   3       5 3 2      4 5
+--R             (1024a b c  - 512a b c  + 64a b c)d
+--R        *
+--R            8 3 7
+--R           e f x
+--R       + 
+--R                    6 4        5 2 3       4 4 2  4
+--R             (13440a c  - 6720a b c  + 840a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   2       7 3      5 4      4 6
+--R             (3584a b c  - 1792a b c  + 224a b c)d  + 128a c  - 24a b c + 4a b
+--R        *
+--R            7 3 6
+--R           e f x
+--R       + 
+--R                    6 4        5 2 3        4 4 2  5
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   3
+--R             (7168a b c  - 3584a b c  + 448a b c)d
+--R           + 
+--R                  7 3       5 4       4 6
+--R             (768a c  - 144a b c + 24a b )d
+--R        *
+--R            6 3 5
+--R           e f x
+--R       + 
+--R                    6 4        5 2 3       4 4 2  6
+--R             (13440a c  - 6720a b c  + 840a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   4
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   7 3       5 4       4 6  2       7   2      6 3      5 5
+--R             (1920a c  - 360a b c + 60a b )d  + 128a b c  - 64a b c + 8a b
+--R        *
+--R            5 3 4
+--R           e f x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  7
+--R             (7680a c  - 3840a b c  + 480a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   5
+--R             (7168a b c  - 3584a b c  + 448a b c)d
+--R           + 
+--R                 7 3       5 4       4 6  3        7   2       6 3       5 5
+--R           (2560a c  - 480a b c + 80a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            4 3 3
+--R           e f x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  8
+--R             (2880a c  - 1440a b c  + 180a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   6
+--R             (3584a b c  - 1792a b c  + 224a b c)d
+--R           + 
+--R                   7 3       5 4       4 6  4
+--R             (1920a c  - 360a b c + 60a b )d
+--R           + 
+--R                  7   2       6 3       5 5  2      8 2      7 2      6 4
+--R             (768a b c  - 384a b c + 48a b )d  + 64a c  - 32a b c + 4a b
+--R        *
+--R            3 3 2
+--R           e f x
+--R       + 
+--R                  6 4       5 2 3      4 4 2  9
+--R             (640a c  - 320a b c  + 40a b c )d
+--R           + 
+--R                   6   3       5 3 2      4 5   7
+--R             (1024a b c  - 512a b c  + 64a b c)d
+--R           + 
+--R                  7 3       5 4       4 6  5        7   2       6 3       5 5  3
+--R             (768a c  - 144a b c + 24a b )d  + (512a b c  - 256a b c + 32a b )d
+--R           + 
+--R                  8 2      7 2      6 4
+--R             (128a c  - 64a b c + 8a b )d
+--R        *
+--R            2 3
+--R           e f x
+--R       + 
+--R                 6 4      5 2 3     4 4 2  10
+--R             (64a c  - 32a b c  + 4a b c )d
+--R           + 
+--R                  6   3      5 3 2     4 5   8        7 3      5 4      4 6  6
+--R             (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R           + 
+--R                  7   2      6 3      5 5  4       8 2      7 2      6 4  2
+--R             (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R        *
+--R              3
+--R           e f
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1047
+
+--S 1048 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3 5      2 2 4        4 3     6 2  10 10
+--R             (60a c  - 90a b c  + 30a b c  - 3b c )e  x
+--R           + 
+--R                  3 5       2 2 4         4 3      6 2    9 9
+--R             (600a c  - 900a b c  + 300a b c  - 30b c )d e x
+--R           + 
+--R                       3 5        2 2 4          4 3       6 2  2       3   4
+--R                 (2700a c  - 4050a b c  + 1350a b c  - 135b c )d  + 120a b c
+--R               + 
+--R                       2 3 3        5 2     7
+--R                 - 180a b c  + 60a b c  - 6b c
+--R            *
+--R                8 8
+--R               e x
+--R           + 
+--R                       3 5         2 2 4          4 3       6 2  3
+--R                 (7200a c  - 10800a b c  + 3600a b c  - 360b c )d
+--R               + 
+--R                      3   4        2 3 3         5 2      7
+--R                 (960a b c  - 1440a b c  + 480a b c  - 48b c)d
+--R            *
+--R                7 7
+--R               e x
+--R           + 
+--R                        3 5         2 2 4          4 3       6 2  4
+--R                 (12600a c  - 18900a b c  + 6300a b c  - 630b c )d
+--R               + 
+--R                       3   4        2 3 3          5 2       7   2       4 4
+--R                 (3360a b c  - 5040a b c  + 1680a b c  - 168b c)d  + 120a c
+--R               + 
+--R                       3 2 3      2 4 2        6      8
+--R                 - 120a b c  - 30a b c  + 24a b c - 3b
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                        3 5         2 2 4          4 3       6 2  5
+--R                 (15120a c  - 22680a b c  + 7560a b c  - 756b c )d
+--R               + 
+--R                       3   4         2 3 3          5 2       7   3
+--R                 (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d
+--R               + 
+--R                      4 4       3 2 3       2 4 2         6       8
+--R                 (720a c  - 720a b c  - 180a b c  + 144a b c - 18b )d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                        3 5         2 2 4          4 3       6 2  6
+--R                 (12600a c  - 18900a b c  + 6300a b c  - 630b c )d
+--R               + 
+--R                       3   4         2 3 3          5 2       7   4
+--R                 (8400a b c  - 12600a b c  + 4200a b c  - 420b c)d
+--R               + 
+--R                       4 4        3 2 3       2 4 2         6       8  2
+--R                 (1800a c  - 1800a b c  - 450a b c  + 360a b c - 45b )d
+--R               + 
+--R                     4   3       3 3 2      2 5        7
+--R                 120a b c  - 180a b c  + 60a b c - 6a b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                       3 5         2 2 4          4 3       6 2  7
+--R                 (7200a c  - 10800a b c  + 3600a b c  - 360b c )d
+--R               + 
+--R                       3   4         2 3 3          5 2       7   5
+--R                 (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d
+--R               + 
+--R                       4 4        3 2 3       2 4 2         6       8  3
+--R                 (2400a c  - 2400a b c  - 600a b c  + 480a b c - 60b )d
+--R               + 
+--R                      4   3       3 3 2       2 5         7
+--R                 (480a b c  - 720a b c  + 240a b c - 24a b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                       3 5        2 2 4          4 3       6 2  8
+--R                 (2700a c  - 4050a b c  + 1350a b c  - 135b c )d
+--R               + 
+--R                       3   4        2 3 3          5 2       7   6
+--R                 (3360a b c  - 5040a b c  + 1680a b c  - 168b c)d
+--R               + 
+--R                       4 4        3 2 3       2 4 2         6       8  4
+--R                 (1800a c  - 1800a b c  - 450a b c  + 360a b c - 45b )d
+--R               + 
+--R                      4   3        3 3 2       2 5         7  2      5 3
+--R                 (720a b c  - 1080a b c  + 360a b c - 36a b )d  + 60a c
+--R               + 
+--R                      4 2 2      3 4      2 6
+--R                 - 90a b c  + 30a b c - 3a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                      3 5       2 2 4         4 3      6 2  9
+--R                 (600a c  - 900a b c  + 300a b c  - 30b c )d
+--R               + 
+--R                      3   4        2 3 3         5 2      7   7
+--R                 (960a b c  - 1440a b c  + 480a b c  - 48b c)d
+--R               + 
+--R                      4 4       3 2 3       2 4 2         6       8  5
+--R                 (720a c  - 720a b c  - 180a b c  + 144a b c - 18b )d
+--R               + 
+--R                      4   3       3 3 2       2 5         7  3
+--R                 (480a b c  - 720a b c  + 240a b c - 24a b )d
+--R               + 
+--R                      5 3       4 2 2      3 4      2 6
+--R                 (120a c  - 180a b c  + 60a b c - 6a b )d
+--R            *
+--R               e x
+--R           + 
+--R                 3 5      2 2 4        4 3     6 2  10
+--R             (60a c  - 90a b c  + 30a b c  - 3b c )d
+--R           + 
+--R                  3   4       2 3 3        5 2     7   8
+--R             (120a b c  - 180a b c  + 60a b c  - 6b c)d
+--R           + 
+--R                  4 4       3 2 3      2 4 2        6      8  6
+--R             (120a c  - 120a b c  - 30a b c  + 24a b c - 3b )d
+--R           + 
+--R                  4   3       3 3 2      2 5        7  4
+--R             (120a b c  - 180a b c  + 60a b c - 6a b )d
+--R           + 
+--R                 5 3      4 2 2      3 4      2 6  2
+--R             (60a c  - 90a b c  + 30a b c - 3a b )d
+--R        *
+--R           log
+--R                        2 4 4     2   3 3       2 2         2 2
+--R                      2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                    + 
+--R                         2 3                  2 4         2           2
+--R                      (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R                 *
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R                + 
+--R                         2     2   2 2           2     2
+--R                  (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)d  - 4a b c + b
+--R             /
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R       + 
+--R                     2   4        3 3     5 2  10 10
+--R                 (48a b c  - 24a b c  + 3b c )e  x
+--R               + 
+--R                      2   4         3 3      5 2    9 9
+--R                 (480a b c  - 240a b c  + 30b c )d e x
+--R               + 
+--R                           2   4          3 3       5 2  2      2 2 3        4 2
+--R                     (2160a b c  - 1080a b c  + 135b c )d  + 96a b c  - 48a b c
+--R                   + 
+--R                       6
+--R                     6b c
+--R                *
+--R                    8 8
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  3
+--R                     (5760a b c  - 2880a b c  + 360b c )d
+--R                   + 
+--R                          2 2 3         4 2      6
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                *
+--R                    7 7
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  4
+--R                     (10080a b c  - 5040a b c  + 630b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   2      3   3        5
+--R                     (2688a b c  - 1344a b c  + 168b c)d  + 96a b c  - 18a b c
+--R                   + 
+--R                       7
+--R                     3b
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  5
+--R                     (12096a b c  - 6048a b c  + 756b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   3
+--R                     (5376a b c  - 2688a b c  + 336b c)d
+--R                   + 
+--R                          3   3         5       7
+--R                     (576a b c  - 108a b c + 18b )d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  6
+--R                     (10080a b c  - 5040a b c  + 630b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   4
+--R                     (6720a b c  - 3360a b c  + 420b c)d
+--R                   + 
+--R                         3   3         5       7  2      3 2 2      2 4        6
+--R                   (1440a b c  - 270a b c + 45b )d  + 96a b c  - 48a b c + 6a b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  7
+--R                     (5760a b c  - 2880a b c  + 360b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   5
+--R                     (5376a b c  - 2688a b c  + 336b c)d
+--R                   + 
+--R                           3   3         5       7  3
+--R                     (1920a b c  - 360a b c + 60b )d
+--R                   + 
+--R                          3 2 2       2 4         6
+--R                     (384a b c  - 192a b c + 24a b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  8
+--R                     (2160a b c  - 1080a b c  + 135b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   6
+--R                     (2688a b c  - 1344a b c  + 168b c)d
+--R                   + 
+--R                           3   3         5       7  4
+--R                     (1440a b c  - 270a b c + 45b )d
+--R                   + 
+--R                          3 2 2       2 4         6  2      4   2      3 3
+--R                     (576a b c  - 288a b c + 36a b )d  + 48a b c  - 24a b c
+--R                   + 
+--R                       2 5
+--R                     3a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                          2   4         3 3      5 2  9
+--R                     (480a b c  - 240a b c  + 30b c )d
+--R                   + 
+--R                          2 2 3         4 2      6   7
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                   + 
+--R                          3   3         5       7  5
+--R                     (576a b c  - 108a b c + 18b )d
+--R                   + 
+--R                          3 2 2       2 4         6  3
+--R                     (384a b c  - 192a b c + 24a b )d
+--R                   + 
+--R                         4   2      3 3      2 5
+--R                     (96a b c  - 48a b c + 6a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                     2   4        3 3     5 2  10
+--R                 (48a b c  - 24a b c  + 3b c )d
+--R               + 
+--R                     2 2 3        4 2     6   8       3   3        5      7  6
+--R                 (96a b c  - 48a b c  + 6b c)d  + (96a b c  - 18a b c + 3b )d
+--R               + 
+--R                   3 2 2      2 4        6  4       4   2      3 3      2 5  2
+--R               (96a b c  - 48a b c + 6a b )d  + (48a b c  - 24a b c + 3a b )d
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                        2   4        3 3      5 2  10 10
+--R                 (- 192a b c  + 96a b c  - 12b c )e  x
+--R               + 
+--R                         2   4         3 3       5 2    9 9
+--R                 (- 1920a b c  + 960a b c  - 120b c )d e x
+--R               + 
+--R                             2   4          3 3       5 2  2       2 2 3
+--R                     (- 8640a b c  + 4320a b c  - 540b c )d  - 384a b c
+--R                   + 
+--R                           4 2      6
+--R                     192a b c  - 24b c
+--R                *
+--R                    8 8
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  3
+--R                     (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                   + 
+--R                             2 2 3          4 2       6
+--R                     (- 3072a b c  + 1536a b c  - 192b c)d
+--R                *
+--R                    7 7
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  4
+--R                     (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                   + 
+--R                              2 2 3          4 2       6   2       3   3
+--R                     (- 10752a b c  + 5376a b c  - 672b c)d  - 384a b c
+--R                   + 
+--R                          5       7
+--R                     72a b c - 12b
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  5
+--R                     (- 48384a b c  + 24192a b c  - 3024b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   3
+--R                     (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                   + 
+--R                             3   3         5       7
+--R                     (- 2304a b c  + 432a b c - 72b )d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  6
+--R                     (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   4
+--R                     (- 26880a b c  + 13440a b c  - 1680b c)d
+--R                   + 
+--R                             3   3          5        7  2       3 2 2       2 4
+--R                     (- 5760a b c  + 1080a b c - 180b )d  - 384a b c  + 192a b c
+--R                   + 
+--R                            6
+--R                     - 24a b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  7
+--R                     (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   5
+--R                     (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                   + 
+--R                             3   3          5        7  3
+--R                     (- 7680a b c  + 1440a b c - 240b )d
+--R                   + 
+--R                             3 2 2       2 4         6
+--R                     (- 1536a b c  + 768a b c - 96a b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                             2   4          3 3       5 2  8
+--R                     (- 8640a b c  + 4320a b c  - 540b c )d
+--R                   + 
+--R                              2 2 3          4 2       6   6
+--R                     (- 10752a b c  + 5376a b c  - 672b c)d
+--R                   + 
+--R                             3   3          5        7  4
+--R                     (- 5760a b c  + 1080a b c - 180b )d
+--R                   + 
+--R                             3 2 2        2 4          6  2       4   2
+--R                     (- 2304a b c  + 1152a b c - 144a b )d  - 192a b c
+--R                   + 
+--R                        3 3       2 5
+--R                     96a b c - 12a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                             2   4         3 3       5 2  9
+--R                     (- 1920a b c  + 960a b c  - 120b c )d
+--R                   + 
+--R                             2 2 3          4 2       6   7
+--R                     (- 3072a b c  + 1536a b c  - 192b c)d
+--R                   + 
+--R                             3   3         5       7  5
+--R                     (- 2304a b c  + 432a b c - 72b )d
+--R                   + 
+--R                             3 2 2       2 4         6  3
+--R                     (- 1536a b c  + 768a b c - 96a b )d
+--R                   + 
+--R                            4   2       3 3       2 5
+--R                     (- 384a b c  + 192a b c - 24a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                        2   4        3 3      5 2  10
+--R                 (- 192a b c  + 96a b c  - 12b c )d
+--R               + 
+--R                        2 2 3         4 2      6   8
+--R                 (- 384a b c  + 192a b c  - 24b c)d
+--R               + 
+--R                        3   3        5       7  6
+--R                 (- 384a b c  + 72a b c - 12b )d
+--R               + 
+--R                        3 2 2       2 4         6  4
+--R                 (- 384a b c  + 192a b c - 24a b )d
+--R               + 
+--R                        4   2      3 3       2 5  2
+--R                 (- 192a b c  + 96a b c - 12a b )d
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                   3 4      2 2 3       4 2  8 8
+--R             (- 60a c  + 42a b c  - 6a b c )e x
+--R           + 
+--R                    3 4       2 2 3        4 2    7 7
+--R             (- 480a c  + 336a b c  - 48a b c )d e x
+--R           + 
+--R                         3 4        2 2 3         4 2  2       3   3      2 3 2
+--R                 (- 1680a c  + 1176a b c  - 168a b c )d  - 138a b c  + 87a b c
+--R               + 
+--R                        5
+--R                 - 12a b c
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  3
+--R                 (- 3360a c  + 2352a b c  - 336a b c )d
+--R               + 
+--R                        3   3       2 3 2        5
+--R                 (- 828a b c  + 522a b c  - 72a b c)d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  4
+--R                 (- 4200a c  + 2940a b c  - 420a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   2       4 3      3 2 2
+--R                 (- 2070a b c  + 1305a b c  - 180a b c)d  - 100a c  - 14a b c
+--R               + 
+--R                    2 4        6
+--R                 36a b c - 6a b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  5
+--R                 (- 3360a c  + 2352a b c  - 336a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   3
+--R                 (- 2760a b c  + 1740a b c  - 240a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6
+--R                 (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  6
+--R                 (- 1680a c  + 1176a b c  - 168a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   4
+--R                 (- 2070a b c  + 1305a b c  - 180a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6  2       4   2
+--R                 (- 600a c  - 84a b c  + 216a b c - 36a b )d  - 122a b c
+--R               + 
+--R                    3 3      2 5
+--R                 68a b c - 9a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                        3 4       2 2 3        4 2  7
+--R                 (- 480a c  + 336a b c  - 48a b c )d
+--R               + 
+--R                        3   3       2 3 2        5   5
+--R                 (- 828a b c  + 522a b c  - 72a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6  3
+--R                 (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R               + 
+--R                        4   2       3 3       2 5
+--R                 (- 244a b c  + 136a b c - 18a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   3 4      2 2 3       4 2  8
+--R             (- 60a c  + 42a b c  - 6a b c )d
+--R           + 
+--R                    3   3      2 3 2        5   6
+--R             (- 138a b c  + 87a b c  - 12a b c)d
+--R           + 
+--R                    4 3      3 2 2      2 4        6  4
+--R             (- 100a c  - 14a b c  + 36a b c - 6a b )d
+--R           + 
+--R                    4   2      3 3      2 5  2      5 2      4 2      3 4
+--R             (- 122a b c  + 68a b c - 9a b )d  - 32a c  + 16a b c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               6 4      5 2 3     4 4 2  11 3 10
+--R           (64a c  - 32a b c  + 4a b c )e  f x
+--R         + 
+--R                6 4       5 2 3      4 4 2    10 3 9
+--R           (640a c  - 320a b c  + 40a b c )d e  f x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  2       6   3      5 3 2
+--R               (2880a c  - 1440a b c  + 180a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 4 5
+--R               8a b c
+--R          *
+--R              9 3 8
+--R             e f x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  3
+--R               (7680a c  - 3840a b c  + 480a b c )d
+--R             + 
+--R                     6   3       5 3 2      4 5
+--R               (1024a b c  - 512a b c  + 64a b c)d
+--R          *
+--R              8 3 7
+--R             e f x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  4
+--R               (13440a c  - 6720a b c  + 840a b c )d
+--R             + 
+--R                   6   3        5 3 2       4 5   2       7 3      5 4      4 6
+--R             (3584a b c  - 1792a b c  + 224a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              7 3 6
+--R             e f x
+--R         + 
+--R                      6 4        5 2 3        4 4 2  5
+--R               (16128a c  - 8064a b c  + 1008a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   3
+--R               (7168a b c  - 3584a b c  + 448a b c)d
+--R             + 
+--R                    7 3       5 4       4 6
+--R               (768a c  - 144a b c + 24a b )d
+--R          *
+--R              6 3 5
+--R             e f x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  6
+--R               (13440a c  - 6720a b c  + 840a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   4
+--R               (8960a b c  - 4480a b c  + 560a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  2       7   2      6 3      5 5
+--R               (1920a c  - 360a b c + 60a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              5 3 4
+--R             e f x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  7
+--R               (7680a c  - 3840a b c  + 480a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   5
+--R               (7168a b c  - 3584a b c  + 448a b c)d
+--R             + 
+--R                   7 3       5 4       4 6  3        7   2       6 3       5 5
+--R             (2560a c  - 480a b c + 80a b )d  + (512a b c  - 256a b c + 32a b )d
+--R          *
+--R              4 3 3
+--R             e f x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  8
+--R               (2880a c  - 1440a b c  + 180a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   6
+--R               (3584a b c  - 1792a b c  + 224a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  4
+--R               (1920a c  - 360a b c + 60a b )d
+--R             + 
+--R                    7   2       6 3       5 5  2      8 2      7 2      6 4
+--R               (768a b c  - 384a b c + 48a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R              3 3 2
+--R             e f x
+--R         + 
+--R                    6 4       5 2 3      4 4 2  9
+--R               (640a c  - 320a b c  + 40a b c )d
+--R             + 
+--R                     6   3       5 3 2      4 5   7
+--R               (1024a b c  - 512a b c  + 64a b c)d
+--R             + 
+--R                    7 3       5 4       4 6  5
+--R               (768a c  - 144a b c + 24a b )d
+--R             + 
+--R                    7   2       6 3       5 5  3        8 2      7 2      6 4
+--R               (512a b c  - 256a b c + 32a b )d  + (128a c  - 64a b c + 8a b )d
+--R          *
+--R              2 3
+--R             e f x
+--R         + 
+--R                   6 4      5 2 3     4 4 2  10
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    6   3      5 3 2     4 5   8        7 3      5 4      4 6  6
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    7   2      6 3      5 5  4       8 2      7 2      6 4  2
+--R               (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R          *
+--R                3
+--R             e f
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    3 5       2 2 4        4 3     6 2  10 10
+--R             (- 120a c  + 180a b c  - 60a b c  + 6b c )e  x
+--R           + 
+--R                     3 5        2 2 4         4 3      6 2    9 9
+--R             (- 1200a c  + 1800a b c  - 600a b c  + 60b c )d e x
+--R           + 
+--R                         3 5        2 2 4          4 3       6 2  2       3   4
+--R                 (- 5400a c  + 8100a b c  - 2700a b c  + 270b c )d  - 240a b c
+--R               + 
+--R                     2 3 3         5 2      7
+--R                 360a b c  - 120a b c  + 12b c
+--R            *
+--R                8 8
+--R               e x
+--R           + 
+--R                          3 5         2 2 4          4 3       6 2  3
+--R                 (- 14400a c  + 21600a b c  - 7200a b c  + 720b c )d
+--R               + 
+--R                         3   4        2 3 3         5 2      7
+--R                 (- 1920a b c  + 2880a b c  - 960a b c  + 96b c)d
+--R            *
+--R                7 7
+--R               e x
+--R           + 
+--R                          3 5         2 2 4           4 3        6 2  4
+--R                 (- 25200a c  + 37800a b c  - 12600a b c  + 1260b c )d
+--R               + 
+--R                         3   4         2 3 3          5 2       7   2       4 4
+--R                 (- 6720a b c  + 10080a b c  - 3360a b c  + 336b c)d  - 240a c
+--R               + 
+--R                     3 2 3      2 4 2        6      8
+--R                 240a b c  + 60a b c  - 48a b c + 6b
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                          3 5         2 2 4           4 3        6 2  5
+--R                 (- 30240a c  + 45360a b c  - 15120a b c  + 1512b c )d
+--R               + 
+--R                          3   4         2 3 3          5 2       7   3
+--R                 (- 13440a b c  + 20160a b c  - 6720a b c  + 672b c)d
+--R               + 
+--R                         4 4        3 2 3       2 4 2         6       8
+--R                 (- 1440a c  + 1440a b c  + 360a b c  - 288a b c + 36b )d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                          3 5         2 2 4           4 3        6 2  6
+--R                 (- 25200a c  + 37800a b c  - 12600a b c  + 1260b c )d
+--R               + 
+--R                          3   4         2 3 3          5 2       7   4
+--R                 (- 16800a b c  + 25200a b c  - 8400a b c  + 840b c)d
+--R               + 
+--R                         4 4        3 2 3       2 4 2         6       8  2
+--R                 (- 3600a c  + 3600a b c  + 900a b c  - 720a b c + 90b )d
+--R               + 
+--R                       4   3       3 3 2       2 5         7
+--R                 - 240a b c  + 360a b c  - 120a b c + 12a b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                          3 5         2 2 4          4 3       6 2  7
+--R                 (- 14400a c  + 21600a b c  - 7200a b c  + 720b c )d
+--R               + 
+--R                          3   4         2 3 3          5 2       7   5
+--R                 (- 13440a b c  + 20160a b c  - 6720a b c  + 672b c)d
+--R               + 
+--R                         4 4        3 2 3        2 4 2         6        8  3
+--R                 (- 4800a c  + 4800a b c  + 1200a b c  - 960a b c + 120b )d
+--R               + 
+--R                        4   3        3 3 2       2 5         7
+--R                 (- 960a b c  + 1440a b c  - 480a b c + 48a b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                         3 5        2 2 4          4 3       6 2  8
+--R                 (- 5400a c  + 8100a b c  - 2700a b c  + 270b c )d
+--R               + 
+--R                         3   4         2 3 3          5 2       7   6
+--R                 (- 6720a b c  + 10080a b c  - 3360a b c  + 336b c)d
+--R               + 
+--R                         4 4        3 2 3       2 4 2         6       8  4
+--R                 (- 3600a c  + 3600a b c  + 900a b c  - 720a b c + 90b )d
+--R               + 
+--R                         4   3        3 3 2       2 5         7  2       5 3
+--R                 (- 1440a b c  + 2160a b c  - 720a b c + 72a b )d  - 120a c
+--R               + 
+--R                     4 2 2      3 4      2 6
+--R                 180a b c  - 60a b c + 6a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                         3 5        2 2 4         4 3      6 2  9
+--R                 (- 1200a c  + 1800a b c  - 600a b c  + 60b c )d
+--R               + 
+--R                         3   4        2 3 3         5 2      7   7
+--R                 (- 1920a b c  + 2880a b c  - 960a b c  + 96b c)d
+--R               + 
+--R                         4 4        3 2 3       2 4 2         6       8  5
+--R                 (- 1440a c  + 1440a b c  + 360a b c  - 288a b c + 36b )d
+--R               + 
+--R                        4   3        3 3 2       2 5         7  3
+--R                 (- 960a b c  + 1440a b c  - 480a b c + 48a b )d
+--R               + 
+--R                        5 3       4 2 2       3 4       2 6
+--R                 (- 240a c  + 360a b c  - 120a b c + 12a b )d
+--R            *
+--R               e x
+--R           + 
+--R                    3 5       2 2 4        4 3     6 2  10
+--R             (- 120a c  + 180a b c  - 60a b c  + 6b c )d
+--R           + 
+--R                    3   4       2 3 3         5 2      7   8
+--R             (- 240a b c  + 360a b c  - 120a b c  + 12b c)d
+--R           + 
+--R                    4 4       3 2 3      2 4 2        6      8  6
+--R             (- 240a c  + 240a b c  + 60a b c  - 48a b c + 6b )d
+--R           + 
+--R                    4   3       3 3 2       2 5         7  4
+--R             (- 240a b c  + 360a b c  - 120a b c + 12a b )d
+--R           + 
+--R                    5 3       4 2 2      3 4      2 6  2
+--R             (- 120a c  + 180a b c  - 60a b c + 6a b )d
+--R        *
+--R                                                 +---------+
+--R                     2 2                  2      |        2
+--R                (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                     2   4        3 3     5 2  10 10
+--R                 (48a b c  - 24a b c  + 3b c )e  x
+--R               + 
+--R                      2   4         3 3      5 2    9 9
+--R                 (480a b c  - 240a b c  + 30b c )d e x
+--R               + 
+--R                           2   4          3 3       5 2  2      2 2 3        4 2
+--R                     (2160a b c  - 1080a b c  + 135b c )d  + 96a b c  - 48a b c
+--R                   + 
+--R                       6
+--R                     6b c
+--R                *
+--R                    8 8
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  3
+--R                     (5760a b c  - 2880a b c  + 360b c )d
+--R                   + 
+--R                          2 2 3         4 2      6
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                *
+--R                    7 7
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  4
+--R                     (10080a b c  - 5040a b c  + 630b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   2      3   3        5
+--R                     (2688a b c  - 1344a b c  + 168b c)d  + 96a b c  - 18a b c
+--R                   + 
+--R                       7
+--R                     3b
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  5
+--R                     (12096a b c  - 6048a b c  + 756b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   3
+--R                     (5376a b c  - 2688a b c  + 336b c)d
+--R                   + 
+--R                          3   3         5       7
+--R                     (576a b c  - 108a b c + 18b )d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                            2   4          3 3       5 2  6
+--R                     (10080a b c  - 5040a b c  + 630b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   4
+--R                     (6720a b c  - 3360a b c  + 420b c)d
+--R                   + 
+--R                         3   3         5       7  2      3 2 2      2 4        6
+--R                   (1440a b c  - 270a b c + 45b )d  + 96a b c  - 48a b c + 6a b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  7
+--R                     (5760a b c  - 2880a b c  + 360b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   5
+--R                     (5376a b c  - 2688a b c  + 336b c)d
+--R                   + 
+--R                           3   3         5       7  3
+--R                     (1920a b c  - 360a b c + 60b )d
+--R                   + 
+--R                          3 2 2       2 4         6
+--R                     (384a b c  - 192a b c + 24a b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                           2   4          3 3       5 2  8
+--R                     (2160a b c  - 1080a b c  + 135b c )d
+--R                   + 
+--R                           2 2 3          4 2       6   6
+--R                     (2688a b c  - 1344a b c  + 168b c)d
+--R                   + 
+--R                           3   3         5       7  4
+--R                     (1440a b c  - 270a b c + 45b )d
+--R                   + 
+--R                          3 2 2       2 4         6  2      4   2      3 3
+--R                     (576a b c  - 288a b c + 36a b )d  + 48a b c  - 24a b c
+--R                   + 
+--R                       2 5
+--R                     3a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                          2   4         3 3      5 2  9
+--R                     (480a b c  - 240a b c  + 30b c )d
+--R                   + 
+--R                          2 2 3         4 2      6   7
+--R                     (768a b c  - 384a b c  + 48b c)d
+--R                   + 
+--R                          3   3         5       7  5
+--R                     (576a b c  - 108a b c + 18b )d
+--R                   + 
+--R                          3 2 2       2 4         6  3
+--R                     (384a b c  - 192a b c + 24a b )d
+--R                   + 
+--R                         4   2      3 3      2 5
+--R                     (96a b c  - 48a b c + 6a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                     2   4        3 3     5 2  10
+--R                 (48a b c  - 24a b c  + 3b c )d
+--R               + 
+--R                     2 2 3        4 2     6   8       3   3        5      7  6
+--R                 (96a b c  - 48a b c  + 6b c)d  + (96a b c  - 18a b c + 3b )d
+--R               + 
+--R                   3 2 2      2 4        6  4       4   2      3 3      2 5  2
+--R               (96a b c  - 48a b c + 6a b )d  + (48a b c  - 24a b c + 3a b )d
+--R            *
+--R               log
+--R                       4 4         3 3        2      2 2        3
+--R                    c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                  + 
+--R                       4      2
+--R                    c d  + b d  + a
+--R           + 
+--R                        2   4        3 3      5 2  10 10
+--R                 (- 192a b c  + 96a b c  - 12b c )e  x
+--R               + 
+--R                         2   4         3 3       5 2    9 9
+--R                 (- 1920a b c  + 960a b c  - 120b c )d e x
+--R               + 
+--R                             2   4          3 3       5 2  2       2 2 3
+--R                     (- 8640a b c  + 4320a b c  - 540b c )d  - 384a b c
+--R                   + 
+--R                           4 2      6
+--R                     192a b c  - 24b c
+--R                *
+--R                    8 8
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  3
+--R                     (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                   + 
+--R                             2 2 3          4 2       6
+--R                     (- 3072a b c  + 1536a b c  - 192b c)d
+--R                *
+--R                    7 7
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  4
+--R                     (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                   + 
+--R                              2 2 3          4 2       6   2       3   3
+--R                     (- 10752a b c  + 5376a b c  - 672b c)d  - 384a b c
+--R                   + 
+--R                          5       7
+--R                     72a b c - 12b
+--R                *
+--R                    6 6
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  5
+--R                     (- 48384a b c  + 24192a b c  - 3024b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   3
+--R                     (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                   + 
+--R                             3   3         5       7
+--R                     (- 2304a b c  + 432a b c - 72b )d
+--R                *
+--R                    5 5
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  6
+--R                     (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   4
+--R                     (- 26880a b c  + 13440a b c  - 1680b c)d
+--R                   + 
+--R                             3   3          5        7  2       3 2 2       2 4
+--R                     (- 5760a b c  + 1080a b c - 180b )d  - 384a b c  + 192a b c
+--R                   + 
+--R                            6
+--R                     - 24a b
+--R                *
+--R                    4 4
+--R                   e x
+--R               + 
+--R                              2   4           3 3        5 2  7
+--R                     (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                   + 
+--R                              2 2 3           4 2        6   5
+--R                     (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                   + 
+--R                             3   3          5        7  3
+--R                     (- 7680a b c  + 1440a b c - 240b )d
+--R                   + 
+--R                             3 2 2       2 4         6
+--R                     (- 1536a b c  + 768a b c - 96a b )d
+--R                *
+--R                    3 3
+--R                   e x
+--R               + 
+--R                             2   4          3 3       5 2  8
+--R                     (- 8640a b c  + 4320a b c  - 540b c )d
+--R                   + 
+--R                              2 2 3          4 2       6   6
+--R                     (- 10752a b c  + 5376a b c  - 672b c)d
+--R                   + 
+--R                             3   3          5        7  4
+--R                     (- 5760a b c  + 1080a b c - 180b )d
+--R                   + 
+--R                             3 2 2        2 4          6  2       4   2
+--R                     (- 2304a b c  + 1152a b c - 144a b )d  - 192a b c
+--R                   + 
+--R                        3 3       2 5
+--R                     96a b c - 12a b
+--R                *
+--R                    2 2
+--R                   e x
+--R               + 
+--R                             2   4         3 3       5 2  9
+--R                     (- 1920a b c  + 960a b c  - 120b c )d
+--R                   + 
+--R                             2 2 3          4 2       6   7
+--R                     (- 3072a b c  + 1536a b c  - 192b c)d
+--R                   + 
+--R                             3   3         5       7  5
+--R                     (- 2304a b c  + 432a b c - 72b )d
+--R                   + 
+--R                             3 2 2       2 4         6  3
+--R                     (- 1536a b c  + 768a b c - 96a b )d
+--R                   + 
+--R                            4   2       3 3       2 5
+--R                     (- 384a b c  + 192a b c - 24a b )d
+--R                *
+--R                   e x
+--R               + 
+--R                        2   4        3 3      5 2  10
+--R                 (- 192a b c  + 96a b c  - 12b c )d
+--R               + 
+--R                        2 2 3         4 2      6   8
+--R                 (- 384a b c  + 192a b c  - 24b c)d
+--R               + 
+--R                        3   3        5       7  6
+--R                 (- 384a b c  + 72a b c - 12b )d
+--R               + 
+--R                        3 2 2       2 4         6  4
+--R                 (- 384a b c  + 192a b c - 24a b )d
+--R               + 
+--R                        4   2      3 3       2 5  2
+--R                 (- 192a b c  + 96a b c - 12a b )d
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                   3 4      2 2 3       4 2  8 8
+--R             (- 60a c  + 42a b c  - 6a b c )e x
+--R           + 
+--R                    3 4       2 2 3        4 2    7 7
+--R             (- 480a c  + 336a b c  - 48a b c )d e x
+--R           + 
+--R                         3 4        2 2 3         4 2  2       3   3      2 3 2
+--R                 (- 1680a c  + 1176a b c  - 168a b c )d  - 138a b c  + 87a b c
+--R               + 
+--R                        5
+--R                 - 12a b c
+--R            *
+--R                6 6
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  3
+--R                 (- 3360a c  + 2352a b c  - 336a b c )d
+--R               + 
+--R                        3   3       2 3 2        5
+--R                 (- 828a b c  + 522a b c  - 72a b c)d
+--R            *
+--R                5 5
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  4
+--R                 (- 4200a c  + 2940a b c  - 420a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   2       4 3      3 2 2
+--R                 (- 2070a b c  + 1305a b c  - 180a b c)d  - 100a c  - 14a b c
+--R               + 
+--R                    2 4        6
+--R                 36a b c - 6a b
+--R            *
+--R                4 4
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  5
+--R                 (- 3360a c  + 2352a b c  - 336a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   3
+--R                 (- 2760a b c  + 1740a b c  - 240a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6
+--R                 (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R            *
+--R                3 3
+--R               e x
+--R           + 
+--R                         3 4        2 2 3         4 2  6
+--R                 (- 1680a c  + 1176a b c  - 168a b c )d
+--R               + 
+--R                         3   3        2 3 2         5   4
+--R                 (- 2070a b c  + 1305a b c  - 180a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6  2       4   2
+--R                 (- 600a c  - 84a b c  + 216a b c - 36a b )d  - 122a b c
+--R               + 
+--R                    3 3      2 5
+--R                 68a b c - 9a b
+--R            *
+--R                2 2
+--R               e x
+--R           + 
+--R                        3 4       2 2 3        4 2  7
+--R                 (- 480a c  + 336a b c  - 48a b c )d
+--R               + 
+--R                        3   3       2 3 2        5   5
+--R                 (- 828a b c  + 522a b c  - 72a b c)d
+--R               + 
+--R                        4 3      3 2 2       2 4         6  3
+--R                 (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R               + 
+--R                        4   2       3 3       2 5
+--R                 (- 244a b c  + 136a b c - 18a b )d
+--R            *
+--R               e x
+--R           + 
+--R                   3 4      2 2 3       4 2  8
+--R             (- 60a c  + 42a b c  - 6a b c )d
+--R           + 
+--R                    3   3      2 3 2        5   6
+--R             (- 138a b c  + 87a b c  - 12a b c)d
+--R           + 
+--R                    4 3      3 2 2      2 4        6  4
+--R             (- 100a c  - 14a b c  + 36a b c - 6a b )d
+--R           + 
+--R                    4   2      3 3      2 5  2      5 2      4 2      3 4
+--R             (- 122a b c  + 68a b c - 9a b )d  - 32a c  + 16a b c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               6 4      5 2 3     4 4 2  11 3 10
+--R           (64a c  - 32a b c  + 4a b c )e  f x
+--R         + 
+--R                6 4       5 2 3      4 4 2    10 3 9
+--R           (640a c  - 320a b c  + 40a b c )d e  f x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  2       6   3      5 3 2
+--R               (2880a c  - 1440a b c  + 180a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 4 5
+--R               8a b c
+--R          *
+--R              9 3 8
+--R             e f x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  3
+--R               (7680a c  - 3840a b c  + 480a b c )d
+--R             + 
+--R                     6   3       5 3 2      4 5
+--R               (1024a b c  - 512a b c  + 64a b c)d
+--R          *
+--R              8 3 7
+--R             e f x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  4
+--R               (13440a c  - 6720a b c  + 840a b c )d
+--R             + 
+--R                   6   3        5 3 2       4 5   2       7 3      5 4      4 6
+--R             (3584a b c  - 1792a b c  + 224a b c)d  + 128a c  - 24a b c + 4a b
+--R          *
+--R              7 3 6
+--R             e f x
+--R         + 
+--R                      6 4        5 2 3        4 4 2  5
+--R               (16128a c  - 8064a b c  + 1008a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   3
+--R               (7168a b c  - 3584a b c  + 448a b c)d
+--R             + 
+--R                    7 3       5 4       4 6
+--R               (768a c  - 144a b c + 24a b )d
+--R          *
+--R              6 3 5
+--R             e f x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  6
+--R               (13440a c  - 6720a b c  + 840a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   4
+--R               (8960a b c  - 4480a b c  + 560a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  2       7   2      6 3      5 5
+--R               (1920a c  - 360a b c + 60a b )d  + 128a b c  - 64a b c + 8a b
+--R          *
+--R              5 3 4
+--R             e f x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  7
+--R               (7680a c  - 3840a b c  + 480a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   5
+--R               (7168a b c  - 3584a b c  + 448a b c)d
+--R             + 
+--R                   7 3       5 4       4 6  3        7   2       6 3       5 5
+--R             (2560a c  - 480a b c + 80a b )d  + (512a b c  - 256a b c + 32a b )d
+--R          *
+--R              4 3 3
+--R             e f x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  8
+--R               (2880a c  - 1440a b c  + 180a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   6
+--R               (3584a b c  - 1792a b c  + 224a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  4
+--R               (1920a c  - 360a b c + 60a b )d
+--R             + 
+--R                    7   2       6 3       5 5  2      8 2      7 2      6 4
+--R               (768a b c  - 384a b c + 48a b )d  + 64a c  - 32a b c + 4a b
+--R          *
+--R              3 3 2
+--R             e f x
+--R         + 
+--R                    6 4       5 2 3      4 4 2  9
+--R               (640a c  - 320a b c  + 40a b c )d
+--R             + 
+--R                     6   3       5 3 2      4 5   7
+--R               (1024a b c  - 512a b c  + 64a b c)d
+--R             + 
+--R                    7 3       5 4       4 6  5
+--R               (768a c  - 144a b c + 24a b )d
+--R             + 
+--R                    7   2       6 3       5 5  3        8 2      7 2      6 4
+--R               (512a b c  - 256a b c + 32a b )d  + (128a c  - 64a b c + 8a b )d
+--R          *
+--R              2 3
+--R             e f x
+--R         + 
+--R                   6 4      5 2 3     4 4 2  10
+--R               (64a c  - 32a b c  + 4a b c )d
+--R             + 
+--R                    6   3      5 3 2     4 5   8        7 3      5 4      4 6  6
+--R               (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R             + 
+--R                    7   2      6 3      5 5  4       8 2      7 2      6 4  2
+--R               (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R          *
+--R                3
+--R             e f
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1048
+
+--S 1049 of 1057
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             3 3      2 2 2        4      6
+--R         (60a c  - 90a b c  + 30a b c - 3b )
+--R      *
+--R         log
+--R                      2 4 4     2   3 3       2 2         2 2
+--R                    2c e x  + 8c d e x  + (12c d  + 2b c)e x
+--R                  + 
+--R                       2 3                  2 4         2           2
+--R                    (8c d  + 4b c d)e x + 2c d  + 2b c d  - 2a c + b
+--R               *
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R              + 
+--R                       2     2   2 2           2     2
+--R                (- 8a c  + 2b c)e x  + (- 16a c  + 4b c)d e x
+--R              + 
+--R                       2     2   2             3
+--R                (- 8a c  + 2b c)d  - 4a b c + b
+--R           /
+--R                   4 4         3 3        2      2 2        3                 4
+--R                c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R              + 
+--R                   2
+--R                b d  + a
+--R     + 
+--R                3 3       2 2 2        4      6
+--R         (- 120a c  + 180a b c  - 60a b c + 6b )
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R  /
+--R                                    +-----------+
+--R         6 2      5 2      4 4    3 |          2
+--R     (64a c  - 32a b c + 4a b )e f \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1049
+
+--S 1050 of 1057
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1050
+
+--S 1051 of 1057
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                               +---------+
+--R               3 3      2 2 2        4      6  |        2
+--R         (- 60a c  + 90a b c  - 30a b c + 3b )\|4a c - b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                               +-----------+
+--R               3 3      2 2 2        4      6  |          2
+--R         (- 60a c  + 90a b c  - 30a b c + 3b )\|- 4a c + b
+--R      *
+--R                                               +---------+
+--R                   2 2                  2      |        2
+--R              (2c e x  + 4c d e x + 2c d  + b)\|4a c - b
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R  /
+--R                                    +-----------+ +---------+
+--R         6 2      5 2      4 4    3 |          2  |        2
+--R     (32a c  - 16a b c + 2a b )e f \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1051
+
+--S 1052 of 1057
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1052
+
+)clear all
+
+--S 1053 of 1057
+t0:=1/((d*f+e*f*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 16 4 16      3   15 4 15        3 2       2  14 4 14
+--R       c e  f x   + 16c d e  f x   + (120c d  + 3b c )e  f x
+--R     + 
+--R            3 3        2   13 4 13
+--R       (560c d  + 42b c d)e  f x
+--R     + 
+--R             3 4         2 2       2     2   12 4 12
+--R       (1820c d  + 273b c d  + 3a c  + 3b c)e  f x
+--R     + 
+--R             3 5          2 3         2      2     11 4 11
+--R       (4368c d  + 1092b c d  + (36a c  + 36b c)d)e  f x
+--R     + 
+--R             3 6          2 4          2       2   2             3  10 4 10
+--R       (8008c d  + 3003b c d  + (198a c  + 198b c)d  + 6a b c + b )e  f x
+--R     + 
+--R              3 7          2 5          2       2   3                 3    9 4 9
+--R       (11440c d  + 6006b c d  + (660a c  + 660b c)d  + (60a b c + 10b )d)e f x
+--R     + 
+--R                 3 8          2 6           2        2   4                  3  2
+--R           12870c d  + 9009b c d  + (1485a c  + 1485b c)d  + (270a b c + 45b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          8 4 8
+--R         e f x
+--R     + 
+--R                 3 9           2 7           2        2   5
+--R           11440c d  + 10296b c d  + (2376a c  + 2376b c)d
+--R         + 
+--R                           3  3       2         2
+--R           (720a b c + 120b )d  + (24a c + 24a b )d
+--R      *
+--R          7 4 7
+--R         e f x
+--R     + 
+--R                3 10          2 8           2        2   6
+--R           8008c d   + 9009b c d  + (2772a c  + 2772b c)d
+--R         + 
+--R                            3  4       2         2  2     2
+--R           (1260a b c + 210b )d  + (84a c + 84a b )d  + 3a b
+--R      *
+--R          6 4 6
+--R         e f x
+--R     + 
+--R                3 11          2 9           2        2   7
+--R           4368c d   + 6006b c d  + (2376a c  + 2376b c)d
+--R         + 
+--R                            3  5        2          2  3      2
+--R           (1512a b c + 252b )d  + (168a c + 168a b )d  + 18a b d
+--R      *
+--R          5 4 5
+--R         e f x
+--R     + 
+--R                3 12          2 10           2        2   8
+--R           1820c d   + 3003b c d   + (1485a c  + 1485b c)d
+--R         + 
+--R                            3  6        2          2  4      2   2    3
+--R           (1260a b c + 210b )d  + (210a c + 210a b )d  + 45a b d  + a
+--R      *
+--R          4 4 4
+--R         e f x
+--R     + 
+--R               3 13          2 11          2       2   9                   3  7
+--R           560c d   + 1092b c d   + (660a c  + 660b c)d  + (720a b c + 120b )d
+--R         + 
+--R                2          2  5      2   3     3
+--R           (168a c + 168a b )d  + 60a b d  + 4a d
+--R      *
+--R          3 4 3
+--R         e f x
+--R     + 
+--R               3 14         2 12          2       2   10                  3  8
+--R           120c d   + 273b c d   + (198a c  + 198b c)d   + (270a b c + 45b )d
+--R         + 
+--R               2         2  6      2   4     3 2
+--R           (84a c + 84a b )d  + 45a b d  + 6a d
+--R      *
+--R          2 4 2
+--R         e f x
+--R     + 
+--R              3 15        2 13         2      2   11                 3  9
+--R           16c d   + 42b c d   + (36a c  + 36b c)d   + (60a b c + 10b )d
+--R         + 
+--R               2         2  7      2   5     3 3
+--R           (24a c + 24a b )d  + 18a b d  + 4a d
+--R      *
+--R            4
+--R         e f x
+--R     + 
+--R            3 16       2 14        2     2   12              3  10
+--R           c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R         + 
+--R              2        2  8     2   6    3 4
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R          4
+--R         f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1053
+
+--S 1054 of 1057
+r0:=1/24*(-35*b^4+235*a*b^2*c-308*a^2*c^2)/(a^3*(b^2-4*a*c)^2*e*f^4*_
+   (d+e*x)^3)+1/8*b*(35*b^4-270*a*b^2*c+508*a^2*c^2)/(a^4*(b^2-4*a*c)^2*_
+   e*f^4*(d+e*x))+1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f^4*(d+_
+   e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)+1/8*(7*b^4-45*a*b^2*c+44*a^2*c^2+_
+   b*c*(7*b^2-40*a*c)*(d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*f^4*(d+e*x)^3*(a+_
+   b*(d+e*x)^2+c*(d+e*x)^4))+1/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(35*b^5-270*a*b^3*c+508*a^2*b*c^2+(35*b^6-_
+   340*a*b^4*c+978*a^2*b^2*c^2-616*a^3*c^3)/sqrt(b^2-4*a*c))/(a^4*(b^2-_
+   4*a*c)^2*e*f^4*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/8*atan((d+e*x)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(35*b^5-270*a*b^3*c+_
+   508*a^2*b*c^2+(-35*b^6+340*a*b^4*c-978*a^2*b^2*c^2+616*a^3*c^3)/_
+   sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^2*e*f^4*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     2   4         3 3       5 2  11 11
+--R               (1524a b c  - 810a b c  + 105b c )e  x
+--R             + 
+--R                      2   4          3 3        5 2    10 10
+--R               (16764a b c  - 8910a b c  + 1155b c )d e  x
+--R             + 
+--R                          2   4           3 3        5 2  2        2 2 3
+--R                   (83820a b c  - 44550a b c  + 5775b c )d  + 3048a b c
+--R                 + 
+--R                            4 2       6
+--R                   - 1620a b c  + 210b c
+--R              *
+--R                  9 9
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  3
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                          2 2 3           4 2        6
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  4
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   2        3   3
+--R                   (109728a b c  - 58320a b c  + 7560b c)d  + 3048a b c
+--R                 + 
+--R                        2 3 2         5        7
+--R                   - 96a b c  - 600a b c + 105b
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  5
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   3
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  6
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   4
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  2
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                        3 2 2        2 4          6
+--R                   3048a b c  - 1620a b c + 210a b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  7
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   5
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  3
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2        2 4           6
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  8
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   6
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  4
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2         2 4           6  2        4   2
+--R                   (30480a b c  - 16200a b c + 2100a b )d  + 1524a b c
+--R                 + 
+--R                         3 3        2 5
+--R                   - 810a b c + 105a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2   4           3 3        5 2  9
+--R                   (83820a b c  - 44550a b c  + 5775b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   7
+--R                   (109728a b c  - 58320a b c  + 7560b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  5
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                          3 2 2         2 4           6  3
+--R                   (30480a b c  - 16200a b c + 2100a b )d
+--R                 + 
+--R                         4   2        3 3        2 5
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2   4          3 3        5 2  10
+--R                   (16764a b c  - 8910a b c  + 1155b c )d
+--R                 + 
+--R                          2 2 3           4 2        6   8
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7  6
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R                 + 
+--R                          3 2 2        2 4           6  4
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R                 + 
+--R                         4   2        3 3        2 5  2
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )d
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)d
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )d
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )d
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3 5        2 2 4          4 3       6 2  11 11
+--R           (- 1848a c  + 2934a b c  - 1020a b c  + 105b c )e  x
+--R         + 
+--R                    3 5         2 2 4           4 3        6 2    10 10
+--R           (- 20328a c  + 32274a b c  - 11220a b c  + 1155b c )d e  x
+--R         + 
+--R                         3 5          2 2 4           4 3        6 2  2
+--R               (- 101640a c  + 161370a b c  - 56100a b c  + 5775b c )d
+--R             + 
+--R                      3   4        2 3 3          5 2       7
+--R               - 3696a b c  + 5868a b c  - 2040a b c  + 210b c
+--R          *
+--R              9 9
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  3
+--R               (- 304920a c  + 484110a b c  - 168300a b c  + 17325b c )d
+--R             + 
+--R                        3   4         2 3 3           5 2        7
+--R               (- 33264a b c  + 52812a b c  - 18360a b c  + 1890b c)d
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  4
+--R               (- 609840a c  + 968220a b c  - 336600a b c  + 34650b c )d
+--R             + 
+--R                         3   4          2 3 3           5 2        7   2
+--R               (- 133056a b c  + 211248a b c  - 73440a b c  + 7560b c)d
+--R             + 
+--R                      4 4        3 2 3       2 4 2         6        8
+--R               - 3696a c  + 4020a b c  + 894a b c  - 810a b c + 105b
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                         3 5           2 2 4            4 3         6 2  5
+--R               (- 853776a c  + 1355508a b c  - 471240a b c  + 48510b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   3
+--R               (- 310464a b c  + 492912a b c  - 171360a b c  + 17640b c)d
+--R             + 
+--R                        4 4         3 2 3        2 4 2          6        8
+--R               (- 25872a c  + 28140a b c  + 6258a b c  - 5670a b c + 735b )d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                         3 5           2 2 4            4 3         6 2  6
+--R               (- 853776a c  + 1355508a b c  - 471240a b c  + 48510b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   4
+--R               (- 465696a b c  + 739368a b c  - 257040a b c  + 26460b c)d
+--R             + 
+--R                        4 4         3 2 3         2 4 2           6         8  2
+--R               (- 77616a c  + 84420a b c  + 18774a b c  - 17010a b c + 2205b )d
+--R             + 
+--R                      4   3        3 3 2        2 5          7
+--R               - 3696a b c  + 5868a b c  - 2040a b c + 210a b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  7
+--R               (- 609840a c  + 968220a b c  - 336600a b c  + 34650b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   5
+--R               (- 465696a b c  + 739368a b c  - 257040a b c  + 26460b c)d
+--R             + 
+--R                              4 4          3 2 3         2 4 2           6
+--R                     - 129360a c  + 140700a b c  + 31290a b c  - 28350a b c
+--R                   + 
+--R                          8
+--R                     3675b
+--R              *
+--R                  3
+--R                 d
+--R             + 
+--R                        4   3         3 3 2         2 5           7
+--R               (- 18480a b c  + 29340a b c  - 10200a b c + 1050a b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  8
+--R               (- 304920a c  + 484110a b c  - 168300a b c  + 17325b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   6
+--R               (- 310464a b c  + 492912a b c  - 171360a b c  + 17640b c)d
+--R             + 
+--R                              4 4          3 2 3         2 4 2           6
+--R                     - 129360a c  + 140700a b c  + 31290a b c  - 28350a b c
+--R                   + 
+--R                          8
+--R                     3675b
+--R              *
+--R                  4
+--R                 d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  2
+--R               (- 36960a b c  + 58680a b c  - 20400a b c + 2100a b )d
+--R             + 
+--R                      5 3        4 2 2        3 4        2 6
+--R               - 1848a c  + 2934a b c  - 1020a b c + 105a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                         3 5          2 2 4           4 3        6 2  9
+--R               (- 101640a c  + 161370a b c  - 56100a b c  + 5775b c )d
+--R             + 
+--R                         3   4          2 3 3           5 2        7   7
+--R               (- 133056a b c  + 211248a b c  - 73440a b c  + 7560b c)d
+--R             + 
+--R                        4 4         3 2 3         2 4 2           6         8  5
+--R               (- 77616a c  + 84420a b c  + 18774a b c  - 17010a b c + 2205b )d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  3
+--R               (- 36960a b c  + 58680a b c  - 20400a b c + 2100a b )d
+--R             + 
+--R                       5 3        4 2 2        3 4        2 6
+--R               (- 5544a c  + 8802a b c  - 3060a b c + 315a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        3 5         2 2 4           4 3        6 2  10
+--R               (- 20328a c  + 32274a b c  - 11220a b c  + 1155b c )d
+--R             + 
+--R                        3   4         2 3 3           5 2        7   8
+--R               (- 33264a b c  + 52812a b c  - 18360a b c  + 1890b c)d
+--R             + 
+--R                        4 4         3 2 3        2 4 2          6        8  6
+--R               (- 25872a c  + 28140a b c  + 6258a b c  - 5670a b c + 735b )d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  4
+--R               (- 18480a b c  + 29340a b c  - 10200a b c + 1050a b )d
+--R             + 
+--R                       5 3        4 2 2        3 4        2 6  2
+--R               (- 5544a c  + 8802a b c  - 3060a b c + 315a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   3 5        2 2 4          4 3       6 2  11
+--R           (- 1848a c  + 2934a b c  - 1020a b c  + 105b c )d
+--R         + 
+--R                   3   4        2 3 3          5 2       7   9
+--R           (- 3696a b c  + 5868a b c  - 2040a b c  + 210b c)d
+--R         + 
+--R                   4 4        3 2 3       2 4 2         6        8  7
+--R           (- 3696a c  + 4020a b c  + 894a b c  - 810a b c + 105b )d
+--R         + 
+--R                   4   3        3 3 2        2 5          7  5
+--R           (- 3696a b c  + 5868a b c  - 2040a b c + 210a b )d
+--R         + 
+--R                   5 3        4 2 2        3 4        2 6  3
+--R           (- 1848a c  + 2934a b c  - 1020a b c + 105a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     2   4         3 3       5 2  11 11
+--R               (1524a b c  - 810a b c  + 105b c )e  x
+--R             + 
+--R                      2   4          3 3        5 2    10 10
+--R               (16764a b c  - 8910a b c  + 1155b c )d e  x
+--R             + 
+--R                          2   4           3 3        5 2  2        2 2 3
+--R                   (83820a b c  - 44550a b c  + 5775b c )d  + 3048a b c
+--R                 + 
+--R                            4 2       6
+--R                   - 1620a b c  + 210b c
+--R              *
+--R                  9 9
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  3
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                          2 2 3           4 2        6
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  4
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   2        3   3
+--R                   (109728a b c  - 58320a b c  + 7560b c)d  + 3048a b c
+--R                 + 
+--R                        2 3 2         5        7
+--R                   - 96a b c  - 600a b c + 105b
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  5
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   3
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  6
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   4
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  2
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                        3 2 2        2 4          6
+--R                   3048a b c  - 1620a b c + 210a b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  7
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   5
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  3
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2        2 4           6
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  8
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   6
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  4
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2         2 4           6  2        4   2
+--R                   (30480a b c  - 16200a b c + 2100a b )d  + 1524a b c
+--R                 + 
+--R                         3 3        2 5
+--R                   - 810a b c + 105a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2   4           3 3        5 2  9
+--R                   (83820a b c  - 44550a b c  + 5775b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   7
+--R                   (109728a b c  - 58320a b c  + 7560b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  5
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                          3 2 2         2 4           6  3
+--R                   (30480a b c  - 16200a b c + 2100a b )d
+--R                 + 
+--R                         4   2        3 3        2 5
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2   4          3 3        5 2  10
+--R                   (16764a b c  - 8910a b c  + 1155b c )d
+--R                 + 
+--R                          2 2 3           4 2        6   8
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7  6
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R                 + 
+--R                          3 2 2        2 4           6  4
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R                 + 
+--R                         4   2        3 3        2 5  2
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )d
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)d
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )d
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )d
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3 5        2 2 4          4 3       6 2  11 11
+--R           (1848a c  - 2934a b c  + 1020a b c  - 105b c )e  x
+--R         + 
+--R                  3 5         2 2 4           4 3        6 2    10 10
+--R           (20328a c  - 32274a b c  + 11220a b c  - 1155b c )d e  x
+--R         + 
+--R                       3 5          2 2 4           4 3        6 2  2
+--R               (101640a c  - 161370a b c  + 56100a b c  - 5775b c )d
+--R             + 
+--R                    3   4        2 3 3          5 2       7
+--R               3696a b c  - 5868a b c  + 2040a b c  - 210b c
+--R          *
+--R              9 9
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  3
+--R               (304920a c  - 484110a b c  + 168300a b c  - 17325b c )d
+--R             + 
+--R                      3   4         2 3 3           5 2        7
+--R               (33264a b c  - 52812a b c  + 18360a b c  - 1890b c)d
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  4
+--R               (609840a c  - 968220a b c  + 336600a b c  - 34650b c )d
+--R             + 
+--R                       3   4          2 3 3           5 2        7   2
+--R               (133056a b c  - 211248a b c  + 73440a b c  - 7560b c)d
+--R             + 
+--R                    4 4        3 2 3       2 4 2         6        8
+--R               3696a c  - 4020a b c  - 894a b c  + 810a b c - 105b
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                       3 5           2 2 4            4 3         6 2  5
+--R               (853776a c  - 1355508a b c  + 471240a b c  - 48510b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   3
+--R               (310464a b c  - 492912a b c  + 171360a b c  - 17640b c)d
+--R             + 
+--R                      4 4         3 2 3        2 4 2          6        8
+--R               (25872a c  - 28140a b c  - 6258a b c  + 5670a b c - 735b )d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       3 5           2 2 4            4 3         6 2  6
+--R               (853776a c  - 1355508a b c  + 471240a b c  - 48510b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   4
+--R               (465696a b c  - 739368a b c  + 257040a b c  - 26460b c)d
+--R             + 
+--R                      4 4         3 2 3         2 4 2           6         8  2
+--R               (77616a c  - 84420a b c  - 18774a b c  + 17010a b c - 2205b )d
+--R             + 
+--R                    4   3        3 3 2        2 5          7
+--R               3696a b c  - 5868a b c  + 2040a b c - 210a b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  7
+--R               (609840a c  - 968220a b c  + 336600a b c  - 34650b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   5
+--R               (465696a b c  - 739368a b c  + 257040a b c  - 26460b c)d
+--R             + 
+--R                       4 4          3 2 3         2 4 2           6         8  3
+--R               (129360a c  - 140700a b c  - 31290a b c  + 28350a b c - 3675b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7
+--R               (18480a b c  - 29340a b c  + 10200a b c - 1050a b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  8
+--R               (304920a c  - 484110a b c  + 168300a b c  - 17325b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   6
+--R               (310464a b c  - 492912a b c  + 171360a b c  - 17640b c)d
+--R             + 
+--R                       4 4          3 2 3         2 4 2           6         8  4
+--R               (129360a c  - 140700a b c  - 31290a b c  + 28350a b c - 3675b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  2        5 3
+--R               (36960a b c  - 58680a b c  + 20400a b c - 2100a b )d  + 1848a c
+--R             + 
+--R                      4 2 2        3 4        2 6
+--R               - 2934a b c  + 1020a b c - 105a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       3 5          2 2 4           4 3        6 2  9
+--R               (101640a c  - 161370a b c  + 56100a b c  - 5775b c )d
+--R             + 
+--R                       3   4          2 3 3           5 2        7   7
+--R               (133056a b c  - 211248a b c  + 73440a b c  - 7560b c)d
+--R             + 
+--R                      4 4         3 2 3         2 4 2           6         8  5
+--R               (77616a c  - 84420a b c  - 18774a b c  + 17010a b c - 2205b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  3
+--R               (36960a b c  - 58680a b c  + 20400a b c - 2100a b )d
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6
+--R               (5544a c  - 8802a b c  + 3060a b c - 315a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  10
+--R               (20328a c  - 32274a b c  + 11220a b c  - 1155b c )d
+--R             + 
+--R                      3   4         2 3 3           5 2        7   8
+--R               (33264a b c  - 52812a b c  + 18360a b c  - 1890b c)d
+--R             + 
+--R                      4 4         3 2 3        2 4 2          6        8  6
+--R               (25872a c  - 28140a b c  - 6258a b c  + 5670a b c - 735b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  4
+--R               (18480a b c  - 29340a b c  + 10200a b c - 1050a b )d
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6  2
+--R               (5544a c  - 8802a b c  + 3060a b c - 315a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 3 5        2 2 4          4 3       6 2  11
+--R           (1848a c  - 2934a b c  + 1020a b c  - 105b c )d
+--R         + 
+--R                 3   4        2 3 3          5 2       7   9
+--R           (3696a b c  - 5868a b c  + 2040a b c  - 210b c)d
+--R         + 
+--R                 4 4        3 2 3       2 4 2         6        8  7
+--R           (3696a c  - 4020a b c  - 894a b c  + 810a b c - 105b )d
+--R         + 
+--R                 4   3        3 3 2        2 5          7  5
+--R           (3696a b c  - 5868a b c  + 2040a b c - 210a b )d
+--R         + 
+--R                 5 3        4 2 2        3 4        2 6  3
+--R           (1848a c  - 2934a b c  + 1020a b c - 105a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 2   4         3 3       5 2  10 10
+--R           (1524a b c  - 810a b c  + 105b c )e  x
+--R         + 
+--R                  2   4          3 3        5 2    9 9
+--R           (15240a b c  - 8100a b c  + 1050b c )d e x
+--R         + 
+--R                      2   4           3 3        5 2  2       3 4        2 2 3
+--R               (68580a b c  - 36450a b c  + 4725b c )d  - 308a c  + 3283a b c
+--R             + 
+--R                        4 2       6
+--R               - 1655a b c  + 210b c
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                       2   4           3 3         5 2  3
+--R               (182880a b c  - 97200a b c  + 12600b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6
+--R               (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  4
+--R               (320040a b c  - 170100a b c  + 22050b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   2        3   3
+--R               (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d  + 2312a b c
+--R             + 
+--R                   2 3 2         5        7
+--R               395a b c  - 670a b c + 105b
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  5
+--R               (384048a b c  - 204120a b c  + 26460b c )d
+--R             + 
+--R                        3 4          2 2 3           4 2         6   3
+--R               (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R             + 
+--R                      3   3        2 3 2          5        7
+--R               (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  6
+--R               (320040a b c  - 170100a b c  + 22050b c )d
+--R             + 
+--R                        3 4          2 2 3            4 2         6   4
+--R               (- 21560a c  + 229810a b c  - 115850a b c  + 14700b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  2       4 3
+--R               (34680a b c  + 5925a b c  - 10050a b c + 1575b )d  - 484a c
+--R             + 
+--R                    3 2 2        2 4          6
+--R               2955a b c  - 1413a b c + 175a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2   4           3 3         5 2  7
+--R               (182880a b c  - 97200a b c  + 12600b c )d
+--R             + 
+--R                        3 4          2 2 3           4 2         6   5
+--R               (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  3
+--R               (46240a b c  + 7900a b c  - 13400a b c + 2100b )d
+--R             + 
+--R                       4 3         3 2 2        2 4          6
+--R               (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  8
+--R               (68580a b c  - 36450a b c  + 4725b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   6
+--R               (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  4
+--R               (34680a b c  + 5925a b c  - 10050a b c + 1575b )d
+--R             + 
+--R                       4 3         3 2 2        2 4           6  2       4   2
+--R               (- 2904a c  + 17730a b c  - 8478a b c + 1050a b )d  + 896a b c
+--R             + 
+--R                     3 3       2 5
+--R               - 448a b c + 56a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      2   4          3 3        5 2  9
+--R               (15240a b c  - 8100a b c  + 1050b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   7
+--R               (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R             + 
+--R                      3   3        2 3 2          5        7  5
+--R               (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R             + 
+--R                       4 3         3 2 2        2 4          6  3
+--R               (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R             + 
+--R                     4   2       3 3        2 5
+--R               (1792a b c  - 896a b c + 112a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2   4         3 3       5 2  10
+--R           (1524a b c  - 810a b c  + 105b c )d
+--R         + 
+--R                  3 4        2 2 3          4 2       6   8
+--R           (- 308a c  + 3283a b c  - 1655a b c  + 210b c)d
+--R         + 
+--R                 3   3       2 3 2         5        7  6
+--R           (2312a b c  + 395a b c  - 670a b c + 105b )d
+--R         + 
+--R                  4 3        3 2 2        2 4          6  4
+--R           (- 484a c  + 2955a b c  - 1413a b c + 175a b )d
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (896a b c  - 448a b c + 56a b )d  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              6 4       5 2 3      4 4 2  12 4 11
+--R         (384a c  - 192a b c  + 24a b c )e  f x
+--R       + 
+--R               6 4        5 2 3       4 4 2    11 4 10
+--R         (4224a c  - 2112a b c  + 264a b c )d e  f x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  2       6   3       5 3 2
+--R             (21120a c  - 10560a b c  + 1320a b c )d  + 768a b c  - 384a b c
+--R           + 
+--R                4 5
+--R             48a b c
+--R        *
+--R            10 4 9
+--R           e  f x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  3
+--R             (63360a c  - 31680a b c  + 3960a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5
+--R             (6912a b c  - 3456a b c  + 432a b c)d
+--R        *
+--R            9 4 8
+--R           e f x
+--R       + 
+--R                     6 4         5 2 3        4 4 2  4
+--R             (126720a c  - 63360a b c  + 7920a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   2       7 3       5 4
+--R             (27648a b c  - 13824a b c  + 1728a b c)d  + 768a c  - 144a b c
+--R           + 
+--R                4 6
+--R             24a b
+--R        *
+--R            8 4 7
+--R           e f x
+--R       + 
+--R                     6 4         5 2 3         4 4 2  5
+--R             (177408a c  - 88704a b c  + 11088a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   3
+--R             (64512a b c  - 32256a b c  + 4032a b c)d
+--R           + 
+--R                   7 3        5 4        4 6
+--R             (5376a c  - 1008a b c + 168a b )d
+--R        *
+--R            7 4 6
+--R           e f x
+--R       + 
+--R                     6 4         5 2 3         4 4 2  6
+--R             (177408a c  - 88704a b c  + 11088a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   4
+--R             (96768a b c  - 48384a b c  + 6048a b c)d
+--R           + 
+--R                  7 3        5 4        4 6  2       7   2       6 3       5 5
+--R           (16128a c  - 3024a b c + 504a b )d  + 768a b c  - 384a b c + 48a b
+--R        *
+--R            6 4 5
+--R           e f x
+--R       + 
+--R                     6 4         5 2 3        4 4 2  7
+--R             (126720a c  - 63360a b c  + 7920a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   5
+--R             (96768a b c  - 48384a b c  + 6048a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  3
+--R             (26880a c  - 5040a b c + 840a b )d
+--R           + 
+--R                   7   2        6 3        5 5
+--R             (3840a b c  - 1920a b c + 240a b )d
+--R        *
+--R            5 4 4
+--R           e f x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  8
+--R             (63360a c  - 31680a b c  + 3960a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   6
+--R             (64512a b c  - 32256a b c  + 4032a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  4
+--R             (26880a c  - 5040a b c + 840a b )d
+--R           + 
+--R                   7   2        6 3        5 5  2       8 2       7 2       6 4
+--R             (7680a b c  - 3840a b c + 480a b )d  + 384a c  - 192a b c + 24a b
+--R        *
+--R            4 4 3
+--R           e f x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  9
+--R             (21120a c  - 10560a b c  + 1320a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   7
+--R             (27648a b c  - 13824a b c  + 1728a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  5
+--R             (16128a c  - 3024a b c + 504a b )d
+--R           + 
+--R                   7   2        6 3        5 5  3
+--R             (7680a b c  - 3840a b c + 480a b )d
+--R           + 
+--R                   8 2       7 2       6 4
+--R             (1152a c  - 576a b c + 72a b )d
+--R        *
+--R            3 4 2
+--R           e f x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  10
+--R             (4224a c  - 2112a b c  + 264a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   8
+--R             (6912a b c  - 3456a b c  + 432a b c)d
+--R           + 
+--R                   7 3        5 4        4 6  6
+--R             (5376a c  - 1008a b c + 168a b )d
+--R           + 
+--R                   7   2        6 3        5 5  4
+--R             (3840a b c  - 1920a b c + 240a b )d
+--R           + 
+--R                   8 2       7 2       6 4  2
+--R             (1152a c  - 576a b c + 72a b )d
+--R        *
+--R            2 4
+--R           e f x
+--R       + 
+--R                  6 4       5 2 3      4 4 2  11
+--R             (384a c  - 192a b c  + 24a b c )d
+--R           + 
+--R                  6   3       5 3 2      4 5   9
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R           + 
+--R                  7 3       5 4       4 6  7        7   2       6 3       5 5  5
+--R             (768a c  - 144a b c + 24a b )d  + (768a b c  - 384a b c + 48a b )d
+--R           + 
+--R                  8 2       7 2       6 4  3
+--R             (384a c  - 192a b c + 24a b )d
+--R        *
+--R              4
+--R           e f
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1054
+
+--S 1055 of 1057
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  6 4      5 2 3      4 4 2  12 4 11
+--R           (- 192a c  + 96a b c  - 12a b c )e  f x
+--R         + 
+--R                   6 4        5 2 3       4 4 2    11 4 10
+--R           (- 2112a c  + 1056a b c  - 132a b c )d e  f x
+--R         + 
+--R                        6 4        5 2 3       4 4 2  2       6   3       5 3 2
+--R               (- 10560a c  + 5280a b c  - 660a b c )d  - 384a b c  + 192a b c
+--R             + 
+--R                    4 5
+--R               - 24a b c
+--R          *
+--R              10 4 9
+--R             e  f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  3
+--R               (- 31680a c  + 15840a b c  - 1980a b c )d
+--R             + 
+--R                       6   3        5 3 2       4 5
+--R               (- 3456a b c  + 1728a b c  - 216a b c)d
+--R          *
+--R              9 4 8
+--R             e f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  4
+--R               (- 63360a c  + 31680a b c  - 3960a b c )d
+--R             + 
+--R                        6   3        5 3 2       4 5   2       7 3      5 4
+--R               (- 13824a b c  + 6912a b c  - 864a b c)d  - 384a c  + 72a b c
+--R             + 
+--R                    4 6
+--R               - 12a b
+--R          *
+--R              8 4 7
+--R             e f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  5
+--R               (- 88704a c  + 44352a b c  - 5544a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   3
+--R               (- 32256a b c  + 16128a b c  - 2016a b c)d
+--R             + 
+--R                       7 3       5 4       4 6
+--R               (- 2688a c  + 504a b c - 84a b )d
+--R          *
+--R              7 4 6
+--R             e f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  6
+--R               (- 88704a c  + 44352a b c  - 5544a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   4
+--R               (- 48384a b c  + 24192a b c  - 3024a b c)d
+--R             + 
+--R                       7 3        5 4        4 6  2       7   2       6 3
+--R               (- 8064a c  + 1512a b c - 252a b )d  - 384a b c  + 192a b c
+--R             + 
+--R                    5 5
+--R               - 24a b
+--R          *
+--R              6 4 5
+--R             e f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  7
+--R               (- 63360a c  + 31680a b c  - 3960a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   5
+--R               (- 48384a b c  + 24192a b c  - 3024a b c)d
+--R             + 
+--R                        7 3        5 4        4 6  3
+--R               (- 13440a c  + 2520a b c - 420a b )d
+--R             + 
+--R                       7   2       6 3        5 5
+--R               (- 1920a b c  + 960a b c - 120a b )d
+--R          *
+--R              5 4 4
+--R             e f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  8
+--R               (- 31680a c  + 15840a b c  - 1980a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   6
+--R               (- 32256a b c  + 16128a b c  - 2016a b c)d
+--R             + 
+--R                        7 3        5 4        4 6  4
+--R               (- 13440a c  + 2520a b c - 420a b )d
+--R             + 
+--R                     7   2        6 3        5 5  2       8 2      7 2       6 4
+--R             (- 3840a b c  + 1920a b c - 240a b )d  - 192a c  + 96a b c - 12a b
+--R          *
+--R              4 4 3
+--R             e f x
+--R         + 
+--R                        6 4        5 2 3       4 4 2  9
+--R               (- 10560a c  + 5280a b c  - 660a b c )d
+--R             + 
+--R                        6   3        5 3 2       4 5   7
+--R               (- 13824a b c  + 6912a b c  - 864a b c)d
+--R             + 
+--R                       7 3        5 4        4 6  5
+--R               (- 8064a c  + 1512a b c - 252a b )d
+--R             + 
+--R                       7   2        6 3        5 5  3
+--R               (- 3840a b c  + 1920a b c - 240a b )d
+--R             + 
+--R                      8 2       7 2       6 4
+--R               (- 576a c  + 288a b c - 36a b )d
+--R          *
+--R              3 4 2
+--R             e f x
+--R         + 
+--R                       6 4        5 2 3       4 4 2  10
+--R               (- 2112a c  + 1056a b c  - 132a b c )d
+--R             + 
+--R                       6   3        5 3 2       4 5   8
+--R               (- 3456a b c  + 1728a b c  - 216a b c)d
+--R             + 
+--R                       7 3       5 4       4 6  6
+--R               (- 2688a c  + 504a b c - 84a b )d
+--R             + 
+--R                       7   2       6 3        5 5  4
+--R               (- 1920a b c  + 960a b c - 120a b )d
+--R             + 
+--R                      8 2       7 2       6 4  2
+--R               (- 576a c  + 288a b c - 36a b )d
+--R          *
+--R              2 4
+--R             e f x
+--R         + 
+--R                      6 4      5 2 3      4 4 2  11
+--R               (- 192a c  + 96a b c  - 12a b c )d
+--R             + 
+--R                      6   3       5 3 2      4 5   9
+--R               (- 384a b c  + 192a b c  - 24a b c)d
+--R             + 
+--R                      7 3      5 4       4 6  7
+--R               (- 384a c  + 72a b c - 12a b )d
+--R             + 
+--R                      7   2       6 3       5 5  5
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R             + 
+--R                      8 2      7 2       6 4  3
+--R               (- 192a c  + 96a b c - 12a b )d
+--R          *
+--R                4
+--R             e f
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                   2 8
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 16
+--R                         e f
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2 8
+--R                e f
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 16
+--R                           e f
+--R                + 
+--R                                10 10              9 2 9               8 4 8
+--R                      467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                    + 
+--R                                    7 6 7               6 8 6
+--R                      - 21970145504a b c  + 17711314348a b c
+--R                    + 
+--R                                   5 10 5              4 12 4             3 14 3
+--R                      - 8747324300a b  c  + 2769618280a b  c  - 566790200a b  c
+--R                    + 
+--R                               2 16 2             18           20
+--R                      72753100a b  c  - 5341000a b  c + 171500b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                          2 8
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2 8
+--R                       e f
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                6 4      5 2 3      4 4 2  12 4 11
+--R           (192a c  - 96a b c  + 12a b c )e  f x
+--R         + 
+--R                 6 4        5 2 3       4 4 2    11 4 10
+--R           (2112a c  - 1056a b c  + 132a b c )d e  f x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  2       6   3       5 3 2
+--R               (10560a c  - 5280a b c  + 660a b c )d  + 384a b c  - 192a b c
+--R             + 
+--R                  4 5
+--R               24a b c
+--R          *
+--R              10 4 9
+--R             e  f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  3
+--R               (31680a c  - 15840a b c  + 1980a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5
+--R               (3456a b c  - 1728a b c  + 216a b c)d
+--R          *
+--R              9 4 8
+--R             e f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  4
+--R               (63360a c  - 31680a b c  + 3960a b c )d
+--R             + 
+--R                      6   3        5 3 2       4 5   2       7 3      5 4
+--R               (13824a b c  - 6912a b c  + 864a b c)d  + 384a c  - 72a b c
+--R             + 
+--R                  4 6
+--R               12a b
+--R          *
+--R              8 4 7
+--R             e f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  5
+--R               (88704a c  - 44352a b c  + 5544a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   3
+--R               (32256a b c  - 16128a b c  + 2016a b c)d
+--R             + 
+--R                     7 3       5 4       4 6
+--R               (2688a c  - 504a b c + 84a b )d
+--R          *
+--R              7 4 6
+--R             e f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  6
+--R               (88704a c  - 44352a b c  + 5544a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   4
+--R               (48384a b c  - 24192a b c  + 3024a b c)d
+--R             + 
+--R                   7 3        5 4        4 6  2       7   2       6 3       5 5
+--R             (8064a c  - 1512a b c + 252a b )d  + 384a b c  - 192a b c + 24a b
+--R          *
+--R              6 4 5
+--R             e f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  7
+--R               (63360a c  - 31680a b c  + 3960a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   5
+--R               (48384a b c  - 24192a b c  + 3024a b c)d
+--R             + 
+--R                      7 3        5 4        4 6  3
+--R               (13440a c  - 2520a b c + 420a b )d
+--R             + 
+--R                     7   2       6 3        5 5
+--R               (1920a b c  - 960a b c + 120a b )d
+--R          *
+--R              5 4 4
+--R             e f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  8
+--R               (31680a c  - 15840a b c  + 1980a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   6
+--R               (32256a b c  - 16128a b c  + 2016a b c)d
+--R             + 
+--R                      7 3        5 4        4 6  4
+--R               (13440a c  - 2520a b c + 420a b )d
+--R             + 
+--R                   7   2        6 3        5 5  2       8 2      7 2       6 4
+--R             (3840a b c  - 1920a b c + 240a b )d  + 192a c  - 96a b c + 12a b
+--R          *
+--R              4 4 3
+--R             e f x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  9
+--R               (10560a c  - 5280a b c  + 660a b c )d
+--R             + 
+--R                      6   3        5 3 2       4 5   7
+--R               (13824a b c  - 6912a b c  + 864a b c)d
+--R             + 
+--R                     7 3        5 4        4 6  5
+--R               (8064a c  - 1512a b c + 252a b )d
+--R             + 
+--R                     7   2        6 3        5 5  3
+--R               (3840a b c  - 1920a b c + 240a b )d
+--R             + 
+--R                    8 2       7 2       6 4
+--R               (576a c  - 288a b c + 36a b )d
+--R          *
+--R              3 4 2
+--R             e f x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  10
+--R               (2112a c  - 1056a b c  + 132a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   8
+--R               (3456a b c  - 1728a b c  + 216a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  6
+--R               (2688a c  - 504a b c + 84a b )d
+--R             + 
+--R                     7   2       6 3        5 5  4
+--R               (1920a b c  - 960a b c + 120a b )d
+--R             + 
+--R                    8 2       7 2       6 4  2
+--R               (576a c  - 288a b c + 36a b )d
+--R          *
+--R              2 4
+--R             e f x
+--R         + 
+--R                    6 4      5 2 3      4 4 2  11
+--R               (192a c  - 96a b c  + 12a b c )d
+--R             + 
+--R                    6   3       5 3 2      4 5   9
+--R               (384a b c  - 192a b c  + 24a b c)d
+--R             + 
+--R                    7 3      5 4       4 6  7
+--R               (384a c  - 72a b c + 12a b )d
+--R             + 
+--R                  7   2       6 3       5 5  5        8 2      7 2       6 4  3
+--R             (384a b c  - 192a b c + 24a b )d  + (192a c  - 96a b c + 12a b )d
+--R          *
+--R                4
+--R             e f
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                   2 8
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 16
+--R                         e f
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2 8
+--R                e f
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 16
+--R                           e f
+--R                + 
+--R                                  10 10              9 2 9               8 4 8
+--R                      - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                    + 
+--R                                  7 6 7               6 8 6              5 10 5
+--R                      21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                    + 
+--R                                   4 12 4             3 14 3            2 16 2
+--R                      - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                    + 
+--R                                18           20
+--R                      5341000a b  c - 171500b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                          2 8
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2 8
+--R                       e f
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                  6 4      5 2 3      4 4 2  12 4 11
+--R           (- 192a c  + 96a b c  - 12a b c )e  f x
+--R         + 
+--R                   6 4        5 2 3       4 4 2    11 4 10
+--R           (- 2112a c  + 1056a b c  - 132a b c )d e  f x
+--R         + 
+--R                        6 4        5 2 3       4 4 2  2       6   3       5 3 2
+--R               (- 10560a c  + 5280a b c  - 660a b c )d  - 384a b c  + 192a b c
+--R             + 
+--R                    4 5
+--R               - 24a b c
+--R          *
+--R              10 4 9
+--R             e  f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  3
+--R               (- 31680a c  + 15840a b c  - 1980a b c )d
+--R             + 
+--R                       6   3        5 3 2       4 5
+--R               (- 3456a b c  + 1728a b c  - 216a b c)d
+--R          *
+--R              9 4 8
+--R             e f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  4
+--R               (- 63360a c  + 31680a b c  - 3960a b c )d
+--R             + 
+--R                        6   3        5 3 2       4 5   2       7 3      5 4
+--R               (- 13824a b c  + 6912a b c  - 864a b c)d  - 384a c  + 72a b c
+--R             + 
+--R                    4 6
+--R               - 12a b
+--R          *
+--R              8 4 7
+--R             e f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  5
+--R               (- 88704a c  + 44352a b c  - 5544a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   3
+--R               (- 32256a b c  + 16128a b c  - 2016a b c)d
+--R             + 
+--R                       7 3       5 4       4 6
+--R               (- 2688a c  + 504a b c - 84a b )d
+--R          *
+--R              7 4 6
+--R             e f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  6
+--R               (- 88704a c  + 44352a b c  - 5544a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   4
+--R               (- 48384a b c  + 24192a b c  - 3024a b c)d
+--R             + 
+--R                       7 3        5 4        4 6  2       7   2       6 3
+--R               (- 8064a c  + 1512a b c - 252a b )d  - 384a b c  + 192a b c
+--R             + 
+--R                    5 5
+--R               - 24a b
+--R          *
+--R              6 4 5
+--R             e f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  7
+--R               (- 63360a c  + 31680a b c  - 3960a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   5
+--R               (- 48384a b c  + 24192a b c  - 3024a b c)d
+--R             + 
+--R                        7 3        5 4        4 6  3
+--R               (- 13440a c  + 2520a b c - 420a b )d
+--R             + 
+--R                       7   2       6 3        5 5
+--R               (- 1920a b c  + 960a b c - 120a b )d
+--R          *
+--R              5 4 4
+--R             e f x
+--R         + 
+--R                        6 4         5 2 3        4 4 2  8
+--R               (- 31680a c  + 15840a b c  - 1980a b c )d
+--R             + 
+--R                        6   3         5 3 2        4 5   6
+--R               (- 32256a b c  + 16128a b c  - 2016a b c)d
+--R             + 
+--R                        7 3        5 4        4 6  4
+--R               (- 13440a c  + 2520a b c - 420a b )d
+--R             + 
+--R                     7   2        6 3        5 5  2       8 2      7 2       6 4
+--R             (- 3840a b c  + 1920a b c - 240a b )d  - 192a c  + 96a b c - 12a b
+--R          *
+--R              4 4 3
+--R             e f x
+--R         + 
+--R                        6 4        5 2 3       4 4 2  9
+--R               (- 10560a c  + 5280a b c  - 660a b c )d
+--R             + 
+--R                        6   3        5 3 2       4 5   7
+--R               (- 13824a b c  + 6912a b c  - 864a b c)d
+--R             + 
+--R                       7 3        5 4        4 6  5
+--R               (- 8064a c  + 1512a b c - 252a b )d
+--R             + 
+--R                       7   2        6 3        5 5  3
+--R               (- 3840a b c  + 1920a b c - 240a b )d
+--R             + 
+--R                      8 2       7 2       6 4
+--R               (- 576a c  + 288a b c - 36a b )d
+--R          *
+--R              3 4 2
+--R             e f x
+--R         + 
+--R                       6 4        5 2 3       4 4 2  10
+--R               (- 2112a c  + 1056a b c  - 132a b c )d
+--R             + 
+--R                       6   3        5 3 2       4 5   8
+--R               (- 3456a b c  + 1728a b c  - 216a b c)d
+--R             + 
+--R                       7 3       5 4       4 6  6
+--R               (- 2688a c  + 504a b c - 84a b )d
+--R             + 
+--R                       7   2       6 3        5 5  4
+--R               (- 1920a b c  + 960a b c - 120a b )d
+--R             + 
+--R                      8 2       7 2       6 4  2
+--R               (- 576a c  + 288a b c - 36a b )d
+--R          *
+--R              2 4
+--R             e f x
+--R         + 
+--R                      6 4      5 2 3      4 4 2  11
+--R               (- 192a c  + 96a b c  - 12a b c )d
+--R             + 
+--R                      6   3       5 3 2      4 5   9
+--R               (- 384a b c  + 192a b c  - 24a b c)d
+--R             + 
+--R                      7 3      5 4       4 6  7
+--R               (- 384a c  + 72a b c - 12a b )d
+--R             + 
+--R                      7   2       6 3       5 5  5
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R             + 
+--R                      8 2      7 2       6 4  3
+--R               (- 192a c  + 96a b c - 12a b )d
+--R          *
+--R                4
+--R             e f
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                   2 8
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 16
+--R                         e f
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2 8
+--R                e f
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 16
+--R                           e f
+--R                + 
+--R                                10 10              9 2 9               8 4 8
+--R                      467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                    + 
+--R                                    7 6 7               6 8 6
+--R                      - 21970145504a b c  + 17711314348a b c
+--R                    + 
+--R                                   5 10 5              4 12 4             3 14 3
+--R                      - 8747324300a b  c  + 2769618280a b  c  - 566790200a b  c
+--R                    + 
+--R                               2 16 2             18           20
+--R                      72753100a b  c  - 5341000a b  c + 171500b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                          2 8
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2 8
+--R                       e f
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                6 4      5 2 3      4 4 2  12 4 11
+--R           (192a c  - 96a b c  + 12a b c )e  f x
+--R         + 
+--R                 6 4        5 2 3       4 4 2    11 4 10
+--R           (2112a c  - 1056a b c  + 132a b c )d e  f x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  2       6   3       5 3 2
+--R               (10560a c  - 5280a b c  + 660a b c )d  + 384a b c  - 192a b c
+--R             + 
+--R                  4 5
+--R               24a b c
+--R          *
+--R              10 4 9
+--R             e  f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  3
+--R               (31680a c  - 15840a b c  + 1980a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5
+--R               (3456a b c  - 1728a b c  + 216a b c)d
+--R          *
+--R              9 4 8
+--R             e f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  4
+--R               (63360a c  - 31680a b c  + 3960a b c )d
+--R             + 
+--R                      6   3        5 3 2       4 5   2       7 3      5 4
+--R               (13824a b c  - 6912a b c  + 864a b c)d  + 384a c  - 72a b c
+--R             + 
+--R                  4 6
+--R               12a b
+--R          *
+--R              8 4 7
+--R             e f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  5
+--R               (88704a c  - 44352a b c  + 5544a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   3
+--R               (32256a b c  - 16128a b c  + 2016a b c)d
+--R             + 
+--R                     7 3       5 4       4 6
+--R               (2688a c  - 504a b c + 84a b )d
+--R          *
+--R              7 4 6
+--R             e f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  6
+--R               (88704a c  - 44352a b c  + 5544a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   4
+--R               (48384a b c  - 24192a b c  + 3024a b c)d
+--R             + 
+--R                   7 3        5 4        4 6  2       7   2       6 3       5 5
+--R             (8064a c  - 1512a b c + 252a b )d  + 384a b c  - 192a b c + 24a b
+--R          *
+--R              6 4 5
+--R             e f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  7
+--R               (63360a c  - 31680a b c  + 3960a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   5
+--R               (48384a b c  - 24192a b c  + 3024a b c)d
+--R             + 
+--R                      7 3        5 4        4 6  3
+--R               (13440a c  - 2520a b c + 420a b )d
+--R             + 
+--R                     7   2       6 3        5 5
+--R               (1920a b c  - 960a b c + 120a b )d
+--R          *
+--R              5 4 4
+--R             e f x
+--R         + 
+--R                      6 4         5 2 3        4 4 2  8
+--R               (31680a c  - 15840a b c  + 1980a b c )d
+--R             + 
+--R                      6   3         5 3 2        4 5   6
+--R               (32256a b c  - 16128a b c  + 2016a b c)d
+--R             + 
+--R                      7 3        5 4        4 6  4
+--R               (13440a c  - 2520a b c + 420a b )d
+--R             + 
+--R                   7   2        6 3        5 5  2       8 2      7 2       6 4
+--R             (3840a b c  - 1920a b c + 240a b )d  + 192a c  - 96a b c + 12a b
+--R          *
+--R              4 4 3
+--R             e f x
+--R         + 
+--R                      6 4        5 2 3       4 4 2  9
+--R               (10560a c  - 5280a b c  + 660a b c )d
+--R             + 
+--R                      6   3        5 3 2       4 5   7
+--R               (13824a b c  - 6912a b c  + 864a b c)d
+--R             + 
+--R                     7 3        5 4        4 6  5
+--R               (8064a c  - 1512a b c + 252a b )d
+--R             + 
+--R                     7   2        6 3        5 5  3
+--R               (3840a b c  - 1920a b c + 240a b )d
+--R             + 
+--R                    8 2       7 2       6 4
+--R               (576a c  - 288a b c + 36a b )d
+--R          *
+--R              3 4 2
+--R             e f x
+--R         + 
+--R                     6 4        5 2 3       4 4 2  10
+--R               (2112a c  - 1056a b c  + 132a b c )d
+--R             + 
+--R                     6   3        5 3 2       4 5   8
+--R               (3456a b c  - 1728a b c  + 216a b c)d
+--R             + 
+--R                     7 3       5 4       4 6  6
+--R               (2688a c  - 504a b c + 84a b )d
+--R             + 
+--R                     7   2       6 3        5 5  4
+--R               (1920a b c  - 960a b c + 120a b )d
+--R             + 
+--R                    8 2       7 2       6 4  2
+--R               (576a c  - 288a b c + 36a b )d
+--R          *
+--R              2 4
+--R             e f x
+--R         + 
+--R                    6 4      5 2 3      4 4 2  11
+--R               (192a c  - 96a b c  + 12a b c )d
+--R             + 
+--R                    6   3       5 3 2      4 5   9
+--R               (384a b c  - 192a b c  + 24a b c)d
+--R             + 
+--R                    7 3      5 4       4 6  7
+--R               (384a c  - 72a b c + 12a b )d
+--R             + 
+--R                  7   2       6 3       5 5  5        8 2      7 2       6 4  3
+--R             (384a b c  - 192a b c + 24a b )d  + (192a c  - 96a b c + 12a b )d
+--R          *
+--R                4
+--R             e f
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                   2 8
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 16
+--R                         e f
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2 8
+--R                e f
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 16
+--R                           e f
+--R                + 
+--R                                  10 10              9 2 9               8 4 8
+--R                      - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                    + 
+--R                                  7 6 7               6 8 6              5 10 5
+--R                      21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                    + 
+--R                                   4 12 4             3 14 3            2 16 2
+--R                      - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                    + 
+--R                                18           20
+--R                      5341000a b  c - 171500b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                          2 8
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2 8
+--R                       e f
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R             2   4         3 3       5 2  10 10
+--R       (1524a b c  - 810a b c  + 105b c )e  x
+--R     + 
+--R              2   4          3 3        5 2    9 9
+--R       (15240a b c  - 8100a b c  + 1050b c )d e x
+--R     + 
+--R                  2   4           3 3        5 2  2       3 4        2 2 3
+--R           (68580a b c  - 36450a b c  + 4725b c )d  - 308a c  + 3283a b c
+--R         + 
+--R                    4 2       6
+--R           - 1655a b c  + 210b c
+--R      *
+--R          8 8
+--R         e x
+--R     + 
+--R                   2   4           3 3         5 2  3
+--R           (182880a b c  - 97200a b c  + 12600b c )d
+--R         + 
+--R                   3 4         2 2 3           4 2        6
+--R           (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R      *
+--R          7 7
+--R         e x
+--R     + 
+--R                   2   4            3 3         5 2  4
+--R           (320040a b c  - 170100a b c  + 22050b c )d
+--R         + 
+--R                   3 4         2 2 3           4 2        6   2        3   3
+--R           (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d  + 2312a b c
+--R         + 
+--R               2 3 2         5        7
+--R           395a b c  - 670a b c + 105b
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R                   2   4            3 3         5 2  5
+--R           (384048a b c  - 204120a b c  + 26460b c )d
+--R         + 
+--R                    3 4          2 2 3           4 2         6   3
+--R           (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R         + 
+--R                  3   3        2 3 2          5        7
+--R           (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R                   2   4            3 3         5 2  6
+--R           (320040a b c  - 170100a b c  + 22050b c )d
+--R         + 
+--R                    3 4          2 2 3            4 2         6   4
+--R           (- 21560a c  + 229810a b c  - 115850a b c  + 14700b c)d
+--R         + 
+--R                  3   3        2 3 2           5         7  2       4 3
+--R           (34680a b c  + 5925a b c  - 10050a b c + 1575b )d  - 484a c
+--R         + 
+--R                3 2 2        2 4          6
+--R           2955a b c  - 1413a b c + 175a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R                   2   4           3 3         5 2  7
+--R           (182880a b c  - 97200a b c  + 12600b c )d
+--R         + 
+--R                    3 4          2 2 3           4 2         6   5
+--R           (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R         + 
+--R                  3   3        2 3 2           5         7  3
+--R           (46240a b c  + 7900a b c  - 13400a b c + 2100b )d
+--R         + 
+--R                   4 3         3 2 2        2 4          6
+--R           (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R                  2   4           3 3        5 2  8
+--R           (68580a b c  - 36450a b c  + 4725b c )d
+--R         + 
+--R                   3 4         2 2 3           4 2        6   6
+--R           (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d
+--R         + 
+--R                  3   3        2 3 2           5         7  4
+--R           (34680a b c  + 5925a b c  - 10050a b c + 1575b )d
+--R         + 
+--R                   4 3         3 2 2        2 4           6  2       4   2
+--R           (- 2904a c  + 17730a b c  - 8478a b c + 1050a b )d  + 896a b c
+--R         + 
+--R                 3 3       2 5
+--R           - 448a b c + 56a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R                  2   4          3 3        5 2  9
+--R           (15240a b c  - 8100a b c  + 1050b c )d
+--R         + 
+--R                   3 4         2 2 3           4 2        6   7
+--R           (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R         + 
+--R                  3   3        2 3 2          5        7  5
+--R           (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R         + 
+--R                   4 3         3 2 2        2 4          6  3
+--R           (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R         + 
+--R                 4   2       3 3        2 5
+--R           (1792a b c  - 896a b c + 112a b )d
+--R      *
+--R         e x
+--R     + 
+--R             2   4         3 3       5 2  10
+--R       (1524a b c  - 810a b c  + 105b c )d
+--R     + 
+--R              3 4        2 2 3          4 2       6   8
+--R       (- 308a c  + 3283a b c  - 1655a b c  + 210b c)d
+--R     + 
+--R             3   3       2 3 2         5        7  6
+--R       (2312a b c  + 395a b c  - 670a b c + 105b )d
+--R     + 
+--R              4 3        3 2 2        2 4          6  4
+--R       (- 484a c  + 2955a b c  - 1413a b c + 175a b )d
+--R     + 
+--R            4   2       3 3       2 5  2       5 2      4 2      3 4
+--R       (896a b c  - 448a b c + 56a b )d  - 128a c  + 64a b c - 8a b
+--R  /
+--R            6 4       5 2 3      4 4 2  12 4 11
+--R       (384a c  - 192a b c  + 24a b c )e  f x
+--R     + 
+--R             6 4        5 2 3       4 4 2    11 4 10
+--R       (4224a c  - 2112a b c  + 264a b c )d e  f x
+--R     + 
+--R                  6 4         5 2 3        4 4 2  2       6   3       5 3 2
+--R           (21120a c  - 10560a b c  + 1320a b c )d  + 768a b c  - 384a b c
+--R         + 
+--R              4 5
+--R           48a b c
+--R      *
+--R          10 4 9
+--R         e  f x
+--R     + 
+--R                  6 4         5 2 3        4 4 2  3
+--R           (63360a c  - 31680a b c  + 3960a b c )d
+--R         + 
+--R                 6   3        5 3 2       4 5
+--R           (6912a b c  - 3456a b c  + 432a b c)d
+--R      *
+--R          9 4 8
+--R         e f x
+--R     + 
+--R                   6 4         5 2 3        4 4 2  4
+--R           (126720a c  - 63360a b c  + 7920a b c )d
+--R         + 
+--R                6   3         5 3 2        4 5   2       7 3       5 4       4 6
+--R         (27648a b c  - 13824a b c  + 1728a b c)d  + 768a c  - 144a b c + 24a b
+--R      *
+--R          8 4 7
+--R         e f x
+--R     + 
+--R                   6 4         5 2 3         4 4 2  5
+--R           (177408a c  - 88704a b c  + 11088a b c )d
+--R         + 
+--R                  6   3         5 3 2        4 5   3
+--R           (64512a b c  - 32256a b c  + 4032a b c)d
+--R         + 
+--R                 7 3        5 4        4 6
+--R           (5376a c  - 1008a b c + 168a b )d
+--R      *
+--R          7 4 6
+--R         e f x
+--R     + 
+--R                   6 4         5 2 3         4 4 2  6
+--R           (177408a c  - 88704a b c  + 11088a b c )d
+--R         + 
+--R                  6   3         5 3 2        4 5   4
+--R           (96768a b c  - 48384a b c  + 6048a b c)d
+--R         + 
+--R                  7 3        5 4        4 6  2       7   2       6 3       5 5
+--R           (16128a c  - 3024a b c + 504a b )d  + 768a b c  - 384a b c + 48a b
+--R      *
+--R          6 4 5
+--R         e f x
+--R     + 
+--R                   6 4         5 2 3        4 4 2  7
+--R           (126720a c  - 63360a b c  + 7920a b c )d
+--R         + 
+--R                  6   3         5 3 2        4 5   5
+--R           (96768a b c  - 48384a b c  + 6048a b c)d
+--R         + 
+--R                  7 3        5 4        4 6  3
+--R           (26880a c  - 5040a b c + 840a b )d
+--R         + 
+--R                 7   2        6 3        5 5
+--R           (3840a b c  - 1920a b c + 240a b )d
+--R      *
+--R          5 4 4
+--R         e f x
+--R     + 
+--R                  6 4         5 2 3        4 4 2  8
+--R           (63360a c  - 31680a b c  + 3960a b c )d
+--R         + 
+--R                  6   3         5 3 2        4 5   6
+--R           (64512a b c  - 32256a b c  + 4032a b c)d
+--R         + 
+--R                  7 3        5 4        4 6  4
+--R           (26880a c  - 5040a b c + 840a b )d
+--R         + 
+--R                 7   2        6 3        5 5  2       8 2       7 2       6 4
+--R           (7680a b c  - 3840a b c + 480a b )d  + 384a c  - 192a b c + 24a b
+--R      *
+--R          4 4 3
+--R         e f x
+--R     + 
+--R                  6 4         5 2 3        4 4 2  9
+--R           (21120a c  - 10560a b c  + 1320a b c )d
+--R         + 
+--R                  6   3         5 3 2        4 5   7
+--R           (27648a b c  - 13824a b c  + 1728a b c)d
+--R         + 
+--R                  7 3        5 4        4 6  5
+--R           (16128a c  - 3024a b c + 504a b )d
+--R         + 
+--R               7   2        6 3        5 5  3         8 2       7 2       6 4
+--R         (7680a b c  - 3840a b c + 480a b )d  + (1152a c  - 576a b c + 72a b )d
+--R      *
+--R          3 4 2
+--R         e f x
+--R     + 
+--R                 6 4        5 2 3       4 4 2  10
+--R           (4224a c  - 2112a b c  + 264a b c )d
+--R         + 
+--R                 6   3        5 3 2       4 5   8
+--R           (6912a b c  - 3456a b c  + 432a b c)d
+--R         + 
+--R                 7 3        5 4        4 6  6
+--R           (5376a c  - 1008a b c + 168a b )d
+--R         + 
+--R               7   2        6 3        5 5  4         8 2       7 2       6 4  2
+--R         (3840a b c  - 1920a b c + 240a b )d  + (1152a c  - 576a b c + 72a b )d
+--R      *
+--R          2 4
+--R         e f x
+--R     + 
+--R                6 4       5 2 3      4 4 2  11
+--R           (384a c  - 192a b c  + 24a b c )d
+--R         + 
+--R                6   3       5 3 2      4 5   9        7 3       5 4       4 6  7
+--R           (768a b c  - 384a b c  + 48a b c)d  + (768a c  - 144a b c + 24a b )d
+--R         + 
+--R                7   2       6 3       5 5  5        8 2       7 2       6 4  3
+--R           (768a b c  - 384a b c + 48a b )d  + (384a c  - 192a b c + 24a b )d
+--R      *
+--R            4
+--R         e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 1055
+
+--S 1056 of 1057
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +-----------+
+--R               6 2      5 2      4 4    4 +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )e f \|2 \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                   2 8
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 16
+--R                         e f
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2 8
+--R                e f
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 16
+--R                           e f
+--R                + 
+--R                                10 10              9 2 9               8 4 8
+--R                      467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                    + 
+--R                                    7 6 7               6 8 6
+--R                      - 21970145504a b c  + 17711314348a b c
+--R                    + 
+--R                                   5 10 5              4 12 4             3 14 3
+--R                      - 8747324300a b  c  + 2769618280a b  c  - 566790200a b  c
+--R                    + 
+--R                               2 16 2             18           20
+--R                      72753100a b  c  - 5341000a b  c + 171500b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                          2 8
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2 8
+--R                       e f
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                                            +-----------+
+--R             6 2      5 2      4 4    4 +-+ |          2
+--R         (64a c  - 32a b c + 4a b )e f \|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                   2 8
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 16
+--R                         e f
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2 8
+--R                e f
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 17   8              16 3 7              15 5 6
+--R                      1388314624a  b c  - 3080716288a  b c  + 2942566400a  b c
+--R                    + 
+--R                                   14 7 5             13 9 4             12 11 3
+--R                      - 1585971200a  b c  + 528957440a  b c  - 112009216a  b  c
+--R                    + 
+--R                               11 13 2           10 15          9 17
+--R                      14728192a  b  c  - 1100800a  b  c + 35840a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 16
+--R                           e f
+--R                + 
+--R                                  10 10              9 2 9               8 4 8
+--R                      - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                    + 
+--R                                  7 6 7               6 8 6              5 10 5
+--R                      21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                    + 
+--R                                   4 12 4             3 14 3            2 16 2
+--R                      - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                    + 
+--R                                18           20
+--R                      5341000a b  c - 171500b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                          2 8
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2 8
+--R                       e f
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                                              +-----------+
+--R               6 2      5 2      4 4    4 +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )e f \|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             14 5          13 2 4          12 4 3         11 6 2
+--R                    - 262144a  c  + 327680a  b c  - 163840a  b c  + 40960a  b c
+--R                  + 
+--R                           10 8        9 10
+--R                    - 5120a  b c + 256a b
+--R               *
+--R                   2 8
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 16
+--R                         e f
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2 8
+--R                e f
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 16
+--R                           e f
+--R                + 
+--R                                10 10              9 2 9               8 4 8
+--R                      467489792a  c   - 4771841536a b c  + 15133757440a b c
+--R                    + 
+--R                                    7 6 7               6 8 6
+--R                      - 21970145504a b c  + 17711314348a b c
+--R                    + 
+--R                                   5 10 5              4 12 4             3 14 3
+--R                      - 8747324300a b  c  + 2769618280a b  c  - 566790200a b  c
+--R                    + 
+--R                               2 16 2             18           20
+--R                      72753100a b  c  - 5341000a b  c + 171500b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                    14 5          13 2 4          12 4 3
+--R                           - 262144a  c  + 327680a  b c  - 163840a  b c
+--R                         + 
+--R                                 11 6 2        10 8        9 10
+--R                           40960a  b c  - 5120a  b c + 256a b
+--R                      *
+--R                          2 8
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2 8
+--R                       e f
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                                                          +--------------------+
+--R                                            +-----------+ |   +-----------+
+--R             6 2      5 2      4 4    4 +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           14 5          13 2 4          12 4 3         11 6 2
+--R                    262144a  c  - 327680a  b c  + 163840a  b c  - 40960a  b c
+--R                  + 
+--R                         10 8        9 10
+--R                    5120a  b c - 256a b
+--R               *
+--R                   2 8
+--R                  e f
+--R               *
+--R                  ROOT
+--R                                    8 8             7 2 7              6 4 6
+--R                         - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                       + 
+--R                                    5 6 5              4 8 4              3 10 3
+--R                         3671443850a b c  - 2857107775a b c  + 1178885750a b  c
+--R                       + 
+--R                                     2 12 2              14            16
+--R                         - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                    /
+--R                                    23 5            22 2 4            21 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      20 6 2           19 8          18 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                      *
+--R                          4 16
+--R                         e f
+--R              + 
+--R                       6   6           5 3 5           4 5 4          3 7 3
+--R                720720a b c  - 2042040a b c  + 1930929a b c  - 870870a b c
+--R              + 
+--R                       2 9 2           11         13
+--R                206635a b c  - 25025a b  c + 1225b
+--R           /
+--R                         14 5          13 2 4         12 4 3         11 6 2
+--R                  131072a  c  - 163840a  b c  + 81920a  b c  - 20480a  b c
+--R                + 
+--R                       10 8        9 10
+--R                  2560a  b c - 128a b
+--R             *
+--R                 2 8
+--R                e f
+--R      *
+--R         log
+--R                                   17   8              16 3 7
+--R                      - 1388314624a  b c  + 3080716288a  b c
+--R                    + 
+--R                                   15 5 6              14 7 5             13 9 4
+--R                      - 2942566400a  b c  + 1585971200a  b c  - 528957440a  b c
+--R                    + 
+--R                                12 11 3            11 13 2           10 15
+--R                      112009216a  b  c  - 14728192a  b  c  + 1100800a  b  c
+--R                    + 
+--R                              9 17
+--R                      - 35840a b
+--R                 *
+--R                     3 12
+--R                    e f
+--R                 *
+--R                    ROOT
+--R                                      8 8             7 2 7              6 4 6
+--R                           - 35153041a c  + 495308660a b c  - 2244369730a b c
+--R                         + 
+--R                                      5 6 5              4 8 4
+--R                           3671443850a b c  - 2857107775a b c
+--R                         + 
+--R                                      3 10 3             2 12 2              14
+--R                           1178885750a b  c  - 266431375a b  c  + 31298750a b  c
+--R                         + 
+--R                                     16
+--R                           - 1500625b
+--R                      /
+--R                                      23 5            22 2 4            21 4 3
+--R                             67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                           + 
+--R                                        20 6 2           19 8          18 10
+--R                             - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                        *
+--R                            4 16
+--R                           e f
+--R                + 
+--R                                  10 10              9 2 9               8 4 8
+--R                      - 467489792a  c   + 4771841536a b c  - 15133757440a b c
+--R                    + 
+--R                                  7 6 7               6 8 6              5 10 5
+--R                      21970145504a b c  - 17711314348a b c  + 8747324300a b  c
+--R                    + 
+--R                                   4 12 4             3 14 3            2 16 2
+--R                      - 2769618280a b  c  + 566790200a b  c  - 72753100a b  c
+--R                    + 
+--R                                18           20
+--R                      5341000a b  c - 171500b
+--R                 *
+--R                       4
+--R                    e f
+--R             *
+--R                ROOT
+--R                                  14 5          13 2 4          12 4 3
+--R                           262144a  c  - 327680a  b c  + 163840a  b c
+--R                         + 
+--R                                   11 6 2        10 8        9 10
+--R                           - 40960a  b c  + 5120a  b c - 256a b
+--R                      *
+--R                          2 8
+--R                         e f
+--R                      *
+--R                         ROOT
+--R                                           8 8             7 2 7
+--R                                - 35153041a c  + 495308660a b c
+--R                              + 
+--R                                             6 4 6              5 6 5
+--R                                - 2244369730a b c  + 3671443850a b c
+--R                              + 
+--R                                             4 8 4              3 10 3
+--R                                - 2857107775a b c  + 1178885750a b  c
+--R                              + 
+--R                                          2 12 2              14            16
+--R                              - 266431375a b  c  + 31298750a b  c - 1500625b
+--R                           /
+--R                                           23 5            22 2 4
+--R                                  67108864a  c  - 83886080a  b c
+--R                                + 
+--R                                           21 4 3            20 6 2
+--R                                  41943040a  b c  - 10485760a  b c
+--R                                + 
+--R                                          19 8          18 10
+--R                                  1310720a  b c - 65536a  b
+--R                             *
+--R                                 4 16
+--R                                e f
+--R                     + 
+--R                              6   6           5 3 5           4 5 4
+--R                       720720a b c  - 2042040a b c  + 1930929a b c
+--R                     + 
+--R                                3 7 3          2 9 2           11         13
+--R                       - 870870a b c  + 206635a b c  - 25025a b  c + 1225b
+--R                  /
+--R                                14 5          13 2 4         12 4 3
+--R                         131072a  c  - 163840a  b c  + 81920a  b c
+--R                       + 
+--R                                 11 6 2        10 8        9 10
+--R                         - 20480a  b c  + 2560a  b c - 128a b
+--R                    *
+--R                        2 8
+--R                       e f
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                e x
+--R            + 
+--R                            6 11              5 2 10              4 4 9
+--R                  562448656a c   - 4218364920a b c   + 5829562485a b c
+--R                + 
+--R                               3 6 8             2 8 7               10 6
+--R                  - 3239493050a b c  + 878463075a b c  - 116809875a b  c
+--R                + 
+--R                          12 5
+--R                  6131125b  c
+--R             *
+--R                d
+--R     + 
+--R                                           +-----------+
+--R                  2   2         3       5  |          2        3 3       2 2 2
+--R           (- 508a b c  + 270a b c - 35b )\|- 4a c + b   + 616a c  - 978a b c
+--R         + 
+--R                 4       6
+--R           340a b c - 35b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                           +-----------+
+--R                  2   2         3       5  |          2        3 3       2 2 2
+--R           (- 508a b c  + 270a b c - 35b )\|- 4a c + b   - 616a c  + 978a b c
+--R         + 
+--R                   4       6
+--R           - 340a b c + 35b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                                                         +--------------------+
+--R                                           +-----------+ |   +-----------+
+--R            6 2      5 2      4 4    4 +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )e f \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1056
+
+--S 1057 of 1057
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1057
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich15.input.pamphlet b/src/input/rich15.input.pamphlet
new file mode 100644
index 0000000..139ca16
--- /dev/null
+++ b/src/input/rich15.input.pamphlet
@@ -0,0 +1,167587 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich15.input}
+\author{Timothy Daly}
+\maketitle
+\begin{abstract}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich15.output
+)spool rich15.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 3139
+t0:=(d+e*x^2)/(d^2+e^2*x^4)
+--R 
+--R
+--R            2
+--R         e x  + d
+--R   (1)  ---------
+--R         2 4    2
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1
+
+--S 2 of 3139
+r0:=-atan(1-x*sqrt(2)*sqrt(e)/sqrt(d))/(sqrt(2)*sqrt(d)*sqrt(e))+_
+   atan(1+x*sqrt(2)*sqrt(e)/sqrt(d))/(sqrt(2)*sqrt(d)*sqrt(e))
+--R 
+--R
+--R               +-+ +-+    +-+           +-+ +-+    +-+
+--R             x\|2 \|e  + \|d          x\|2 \|e  - \|d
+--R        atan(----------------) + atan(----------------)
+--R                    +-+                      +-+
+--R                   \|d                      \|d
+--R   (2)  -----------------------------------------------
+--R                           +-+ +-+ +-+
+--R                          \|2 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 4         2    2  +------+       2 3     2
+--R        (e x  - 4d e x  + d )\|- 2d e  + 4d e x  - 4d e x
+--R    log(-------------------------------------------------)
+--R                             2 4    2
+--R                            e x  + d
+--R   [------------------------------------------------------,
+--R                            +------+
+--R                          2\|- 2d e
+--R           +----+          2 3
+--R         x\|2d e          e x  + d e x
+--R    atan(--------) + atan(------------)
+--R            2d                +----+
+--R                            d\|2d e
+--R    -----------------------------------]
+--R                   +----+
+--R                  \|2d e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 3
+
+--S 4 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         2 4         2    2  +------+       2 3     2
+--R        +-+ +-+ +-+    (e x  - 4d e x  + d )\|- 2d e  + 4d e x  - 4d e x
+--R       \|2 \|d \|e log(-------------------------------------------------)
+--R                                            2 4    2
+--R                                           e x  + d
+--R     + 
+--R                          +-+ +-+    +-+                     +-+ +-+    +-+
+--R           +------+     x\|2 \|e  + \|d       +------+     x\|2 \|e  - \|d
+--R       - 2\|- 2d e atan(----------------) - 2\|- 2d e atan(----------------)
+--R                               +-+                                +-+
+--R                              \|d                                \|d
+--R  /
+--R       +-+ +------+ +-+ +-+
+--R     2\|2 \|- 2d e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          +----+                  +-+ +-+    +-+
+--R        +-+ +-+ +-+     x\|2d e      +----+     x\|2 \|e  + \|d
+--R       \|2 \|d \|e atan(--------) - \|2d e atan(----------------)
+--R                           2d                          +-+
+--R                                                      \|d
+--R     + 
+--R                       +-+ +-+    +-+                      2 3
+--R          +----+     x\|2 \|e  - \|d      +-+ +-+ +-+     e x  + d e x
+--R       - \|2d e atan(----------------) + \|2 \|d \|e atan(------------)
+--R                            +-+                               +----+
+--R                           \|d                              d\|2d e
+--R  /
+--R      +-+ +-+ +-+ +----+
+--R     \|2 \|d \|e \|2d e
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 7
+
+)clear all
+
+--S 8 of 3139
+t0:=(d-e*x^2)/(d^2+e^2*x^4)
+--R 
+--R
+--R             2
+--R        - e x  + d
+--R   (1)  ----------
+--R          2 4    2
+--R         e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 8
+
+--S 9 of 3139
+r0:=-1/2*log(d+e*x^2-x*sqrt(2)*sqrt(d)*sqrt(e))/(sqrt(2)*sqrt(d)*sqrt(e))+_
+   1/2*log(d+e*x^2+x*sqrt(2)*sqrt(d)*sqrt(e))/(sqrt(2)*sqrt(d)*sqrt(e))
+--R 
+--R
+--R              +-+ +-+ +-+      2                +-+ +-+ +-+      2
+--R        log(x\|2 \|d \|e  + e x  + d) - log(- x\|2 \|d \|e  + e x  + d)
+--R   (2)  ---------------------------------------------------------------
+--R                                   +-+ +-+ +-+
+--R                                 2\|2 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 4         2    2  +----+       2 3     2
+--R        (e x  + 4d e x  + d )\|2d e  + 4d e x  + 4d e x
+--R    log(-----------------------------------------------)
+--R                            2 4    2
+--R                           e x  + d
+--R   [----------------------------------------------------,
+--R                            +----+
+--R                          2\|2d e
+--R           +------+          2 3
+--R         x\|- 2d e          e x  - d e x
+--R    atan(----------) + atan(------------)
+--R             2d                +------+
+--R                             d\|- 2d e
+--R    -------------------------------------]
+--R                   +------+
+--R                  \|- 2d e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 10
+
+--S 11 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         2 4         2    2  +----+       2 3     2
+--R        +-+ +-+ +-+    (e x  + 4d e x  + d )\|2d e  + 4d e x  + 4d e x
+--R       \|2 \|d \|e log(-----------------------------------------------)
+--R                                           2 4    2
+--R                                          e x  + d
+--R     + 
+--R          +----+      +-+ +-+ +-+      2
+--R       - \|2d e log(x\|2 \|d \|e  + e x  + d)
+--R     + 
+--R        +----+        +-+ +-+ +-+      2
+--R       \|2d e log(- x\|2 \|d \|e  + e x  + d)
+--R  /
+--R       +-+ +-+ +-+ +----+
+--R     2\|2 \|d \|e \|2d e
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +------+      +-+ +-+ +-+      2
+--R       - \|- 2d e log(x\|2 \|d \|e  + e x  + d)
+--R     + 
+--R                                                                      +------+
+--R        +------+        +-+ +-+ +-+      2          +-+ +-+ +-+     x\|- 2d e
+--R       \|- 2d e log(- x\|2 \|d \|e  + e x  + d) + 2\|2 \|d \|e atan(----------)
+--R                                                                        2d
+--R     + 
+--R                          2 3
+--R         +-+ +-+ +-+     e x  - d e x
+--R       2\|2 \|d \|e atan(------------)
+--R                            +------+
+--R                          d\|- 2d e
+--R  /
+--R       +-+ +------+ +-+ +-+
+--R     2\|2 \|- 2d e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 14
+
+)clear all
+
+--S 15 of 3139
+t0:=(d+e*x^2)/(d^2+b*x^2+e^2*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  + b x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 15
+
+--S 16 of 3139
+r0:=-atan((-2*e*x+sqrt(-b+2*d*e))/sqrt(b+2*d*e))/sqrt(b+2*d*e)+_
+   atan((2*e*x+sqrt(-b+2*d*e))/sqrt(b+2*d*e))/sqrt(b+2*d*e)
+--R 
+--R
+--R              +--------+                 +--------+
+--R             \|2d e - b  + 2e x         \|2d e - b  - 2e x
+--R        atan(------------------) - atan(------------------)
+--R                  +--------+                 +--------+
+--R                 \|2d e + b                 \|2d e + b
+--R   (2)  ---------------------------------------------------
+--R                             +--------+
+--R                            \|2d e + b
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 4                2    2  +----------+        2         3
+--R              (e x  + (- 4d e - b)x  + d )\|- 2d e - b  + (4d e  + 2b e)x
+--R            + 
+--R                   2
+--R              (- 4d e - 2b d)x
+--R         /
+--R             2 4      2    2
+--R            e x  + b x  + d
+--R    /
+--R         +----------+
+--R       2\|- 2d e - b
+--R     ,
+--R             +--------+          2 3
+--R         e x\|2d e + b          e x  + (d e + b)x
+--R    atan(--------------) + atan(-----------------)
+--R            2d e + b                 +--------+
+--R                                   d\|2d e + b
+--R    ----------------------------------------------]
+--R                       +--------+
+--R                      \|2d e + b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 17
+
+--S 18 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +--------+
+--R         \|2d e + b
+--R      *
+--R         log
+--R                  2 4                2    2  +----------+        2         3
+--R                (e x  + (- 4d e - b)x  + d )\|- 2d e - b  + (4d e  + 2b e)x
+--R              + 
+--R                     2
+--R                (- 4d e - 2b d)x
+--R           /
+--R               2 4      2    2
+--R              e x  + b x  + d
+--R     + 
+--R                             +--------+
+--R           +----------+     \|2d e - b  + 2e x
+--R       - 2\|- 2d e - b atan(------------------)
+--R                                 +--------+
+--R                                \|2d e + b
+--R     + 
+--R                           +--------+
+--R         +----------+     \|2d e - b  - 2e x
+--R       2\|- 2d e - b atan(------------------)
+--R                               +--------+
+--R                              \|2d e + b
+--R  /
+--R       +----------+ +--------+
+--R     2\|- 2d e - b \|2d e + b
+--R                                                    Type: Expression(Integer)
+--E 18
+
+--S 19 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                +--------+          +--------+
+--R            e x\|2d e + b          \|2d e - b  + 2e x
+--R       atan(--------------) - atan(------------------)
+--R               2d e + b                 +--------+
+--R                                       \|2d e + b
+--R     + 
+--R             +--------+                 2 3
+--R            \|2d e - b  - 2e x         e x  + (d e + b)x
+--R       atan(------------------) + atan(-----------------)
+--R                 +--------+                 +--------+
+--R                \|2d e + b                d\|2d e + b
+--R  /
+--R      +--------+
+--R     \|2d e + b
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 3139
+t0:=(d+e*x^2)/(d^2-b*x^2+e^2*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  - b x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 22
+
+--S 23 of 3139
+r0:=atanh((-2*e*x+sqrt(b+2*d*e))/sqrt(b-2*d*e))/sqrt(b-2*d*e)-_
+   atanh((2*e*x+sqrt(b+2*d*e))/sqrt(b-2*d*e))/sqrt(b-2*d*e)
+--R 
+--R
+--R                 +--------+                  +--------+
+--R                \|2d e + b  + 2e x          \|2d e + b  - 2e x
+--R        - atanh(------------------) + atanh(------------------)
+--R                    +----------+                +----------+
+--R                   \|- 2d e + b                \|- 2d e + b
+--R   (2)  -------------------------------------------------------
+--R                              +----------+
+--R                             \|- 2d e + b
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 4                2    2  +----------+        2         3
+--R              (e x  + (- 4d e + b)x  + d )\|- 2d e + b  + (4d e  - 2b e)x
+--R            + 
+--R                   2
+--R              (- 4d e + 2b d)x
+--R         /
+--R             2 4      2    2
+--R            e x  - b x  + d
+--R    /
+--R         +----------+
+--R       2\|- 2d e + b
+--R     ,
+--R             +--------+          2 3
+--R         e x\|2d e - b          e x  + (d e - b)x
+--R    atan(--------------) + atan(-----------------)
+--R            2d e - b                 +--------+
+--R                                   d\|2d e - b
+--R    ----------------------------------------------]
+--R                       +--------+
+--R                      \|2d e - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 24
+
+--S 25 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                2 4                2    2  +----------+        2         3
+--R              (e x  + (- 4d e + b)x  + d )\|- 2d e + b  + (4d e  - 2b e)x
+--R            + 
+--R                   2
+--R              (- 4d e + 2b d)x
+--R         /
+--R             2 4      2    2
+--R            e x  - b x  + d
+--R     + 
+--R               +--------+                   +--------+
+--R              \|2d e + b  + 2e x           \|2d e + b  - 2e x
+--R       2atanh(------------------) - 2atanh(------------------)
+--R                  +----------+                 +----------+
+--R                 \|- 2d e + b                 \|- 2d e + b
+--R  /
+--R       +----------+
+--R     2\|- 2d e + b
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         +--------+
+--R        +--------+      \|2d e + b  + 2e x
+--R       \|2d e - b atanh(------------------)
+--R                            +----------+
+--R                           \|- 2d e + b
+--R     + 
+--R                           +--------+
+--R          +--------+      \|2d e + b  - 2e x
+--R       - \|2d e - b atanh(------------------)
+--R                              +----------+
+--R                             \|- 2d e + b
+--R     + 
+--R                             +--------+                       2 3
+--R        +----------+     e x\|2d e - b      +----------+     e x  + (d e - b)x
+--R       \|- 2d e + b atan(--------------) + \|- 2d e + b atan(-----------------)
+--R                            2d e - b                              +--------+
+--R                                                                d\|2d e - b
+--R  /
+--R      +----------+ +--------+
+--R     \|- 2d e + b \|2d e - b
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 28
+
+)clear all
+
+--S 29 of 3139
+t0:=(d+e*x^2)/(d^2+f*x^2+e^2*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  + f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 29
+
+--S 30 of 3139
+r0:=-atan((-2*e*x+sqrt(2*d*e-f))/sqrt(2*d*e+f))/sqrt(2*d*e+f)+_
+   atan((2*e*x+sqrt(2*d*e-f))/sqrt(2*d*e+f))/sqrt(2*d*e+f)
+--R 
+--R
+--R              +----------+                 +----------+
+--R             \|- f + 2d e  + 2e x         \|- f + 2d e  - 2e x
+--R        atan(--------------------) - atan(--------------------)
+--R                   +--------+                   +--------+
+--R                  \|f + 2d e                   \|f + 2d e
+--R   (2)  -------------------------------------------------------
+--R                               +--------+
+--R                              \|f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 30
+
+--S 31 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 4                2    2  +----------+               2  3
+--R              (e x  + (- f - 4d e)x  + d )\|- f - 2d e  + (2e f + 4d e )x
+--R            + 
+--R                          2
+--R              (- 2d f - 4d e)x
+--R         /
+--R             2 4      2    2
+--R            e x  + f x  + d
+--R    /
+--R         +----------+
+--R       2\|- f - 2d e
+--R     ,
+--R             +--------+          2 3
+--R         e x\|f + 2d e          e x  + (f + d e)x
+--R    atan(--------------) + atan(-----------------)
+--R            f + 2d e                 +--------+
+--R                                   d\|f + 2d e
+--R    ----------------------------------------------]
+--R                       +--------+
+--R                      \|f + 2d e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 31
+
+--S 32 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +--------+
+--R         \|f + 2d e
+--R      *
+--R         log
+--R                  2 4                2    2  +----------+               2  3
+--R                (e x  + (- f - 4d e)x  + d )\|- f - 2d e  + (2e f + 4d e )x
+--R              + 
+--R                            2
+--R                (- 2d f - 4d e)x
+--R           /
+--R               2 4      2    2
+--R              e x  + f x  + d
+--R     + 
+--R                             +----------+
+--R           +----------+     \|- f + 2d e  + 2e x
+--R       - 2\|- f - 2d e atan(--------------------)
+--R                                  +--------+
+--R                                 \|f + 2d e
+--R     + 
+--R                           +----------+
+--R         +----------+     \|- f + 2d e  - 2e x
+--R       2\|- f - 2d e atan(--------------------)
+--R                                +--------+
+--R                               \|f + 2d e
+--R  /
+--R       +----------+ +--------+
+--R     2\|- f - 2d e \|f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+--S 34 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                +--------+          +----------+
+--R            e x\|f + 2d e          \|- f + 2d e  + 2e x
+--R       atan(--------------) - atan(--------------------)
+--R               f + 2d e                  +--------+
+--R                                        \|f + 2d e
+--R     + 
+--R             +----------+                 2 3
+--R            \|- f + 2d e  - 2e x         e x  + (f + d e)x
+--R       atan(--------------------) + atan(-----------------)
+--R                  +--------+                  +--------+
+--R                 \|f + 2d e                 d\|f + 2d e
+--R  /
+--R      +--------+
+--R     \|f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 35
+
+)clear all
+
+--S 36 of 3139
+t0:=(d+e*x^2)/(d^2-f*x^2+e^2*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  - f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 36
+
+--S 37 of 3139
+r0:=-atan((-2*e*x+sqrt(2*d*e+f))/sqrt(2*d*e-f))/sqrt(2*d*e-f)+_
+   atan((2*e*x+sqrt(2*d*e+f))/sqrt(2*d*e-f))/sqrt(2*d*e-f)
+--R 
+--R
+--R              +--------+                 +--------+
+--R             \|f + 2d e  + 2e x         \|f + 2d e  - 2e x
+--R        atan(------------------) - atan(------------------)
+--R                 +----------+               +----------+
+--R                \|- f + 2d e               \|- f + 2d e
+--R   (2)  ---------------------------------------------------
+--R                            +----------+
+--R                           \|- f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 4              2    2  +--------+                 2  3
+--R              (e x  + (f - 4d e)x  + d )\|f - 2d e  + (- 2e f + 4d e )x
+--R            + 
+--R                        2
+--R              (2d f - 4d e)x
+--R         /
+--R             2 4      2    2
+--R            e x  - f x  + d
+--R    /
+--R         +--------+
+--R       2\|f - 2d e
+--R     ,
+--R               +----------+          2 3
+--R           e x\|- f + 2d e          e x  + (- f + d e)x
+--R    - atan(----------------) + atan(-------------------)
+--R               f - 2d e                  +----------+
+--R                                       d\|- f + 2d e
+--R    ----------------------------------------------------]
+--R                         +----------+
+--R                        \|- f + 2d e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 38
+
+--S 39 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +----------+
+--R         \|- f + 2d e
+--R      *
+--R         log
+--R                  2 4              2    2  +--------+                 2  3
+--R                (e x  + (f - 4d e)x  + d )\|f - 2d e  + (- 2e f + 4d e )x
+--R              + 
+--R                          2
+--R                (2d f - 4d e)x
+--R           /
+--R               2 4      2    2
+--R              e x  - f x  + d
+--R     + 
+--R                           +--------+
+--R           +--------+     \|f + 2d e  + 2e x
+--R       - 2\|f - 2d e atan(------------------)
+--R                              +----------+
+--R                             \|- f + 2d e
+--R     + 
+--R                         +--------+
+--R         +--------+     \|f + 2d e  - 2e x
+--R       2\|f - 2d e atan(------------------)
+--R                            +----------+
+--R                           \|- f + 2d e
+--R  /
+--R       +----------+ +--------+
+--R     2\|- f + 2d e \|f - 2d e
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               +--------+                 +--------+
+--R              \|f + 2d e  + 2e x         \|f + 2d e  - 2e x
+--R       - atan(------------------) + atan(------------------)
+--R                  +----------+               +----------+
+--R                 \|- f + 2d e               \|- f + 2d e
+--R     + 
+--R                  +----------+          2 3
+--R              e x\|- f + 2d e          e x  + (- f + d e)x
+--R       - atan(----------------) + atan(-------------------)
+--R                  f - 2d e                  +----------+
+--R                                          d\|- f + 2d e
+--R  /
+--R      +----------+
+--R     \|- f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 3139
+t0:=(d-e*x^2)/(d^2+b*x^2+e^2*x^4)
+--R 
+--R
+--R                2
+--R           - e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  + b x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 43
+
+--S 44 of 3139
+r0:=atan((-2*e*x+sqrt(-b-2*d*e))/sqrt(b-2*d*e))/sqrt(b-2*d*e)-_
+   atan((2*e*x+sqrt(-b-2*d*e))/sqrt(b-2*d*e))/sqrt(b-2*d*e)
+--R 
+--R
+--R                +----------+                 +----------+
+--R               \|- 2d e - b  + 2e x         \|- 2d e - b  - 2e x
+--R        - atan(--------------------) + atan(--------------------)
+--R                    +----------+                 +----------+
+--R                   \|- 2d e + b                 \|- 2d e + b
+--R   (2)  ---------------------------------------------------------
+--R                               +----------+
+--R                              \|- 2d e + b
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 4              2    2  +--------+        2         3
+--R              (e x  + (4d e - b)x  + d )\|2d e - b  + (4d e  - 2b e)x
+--R            + 
+--R                 2
+--R              (4d e - 2b d)x
+--R         /
+--R             2 4      2    2
+--R            e x  + b x  + d
+--R    /
+--R         +--------+
+--R       2\|2d e - b
+--R     ,
+--R             +----------+          2 3
+--R         e x\|- 2d e + b          e x  + (- d e + b)x
+--R    atan(----------------) + atan(-------------------)
+--R             2d e - b                  +----------+
+--R                                     d\|- 2d e + b
+--R    --------------------------------------------------]
+--R                        +----------+
+--R                       \|- 2d e + b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 45
+
+--S 46 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +----------+
+--R         \|- 2d e + b
+--R      *
+--R         log
+--R                  2 4              2    2  +--------+        2         3
+--R                (e x  + (4d e - b)x  + d )\|2d e - b  + (4d e  - 2b e)x
+--R              + 
+--R                   2
+--R                (4d e - 2b d)x
+--R           /
+--R               2 4      2    2
+--R              e x  + b x  + d
+--R     + 
+--R                         +----------+
+--R         +--------+     \|- 2d e - b  + 2e x
+--R       2\|2d e - b atan(--------------------)
+--R                             +----------+
+--R                            \|- 2d e + b
+--R     + 
+--R                           +----------+
+--R           +--------+     \|- 2d e - b  - 2e x
+--R       - 2\|2d e - b atan(--------------------)
+--R                               +----------+
+--R                              \|- 2d e + b
+--R  /
+--R       +----------+ +--------+
+--R     2\|- 2d e + b \|2d e - b
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                +----------+          +----------+
+--R            e x\|- 2d e + b          \|- 2d e - b  + 2e x
+--R       atan(----------------) + atan(--------------------)
+--R                2d e - b                  +----------+
+--R                                         \|- 2d e + b
+--R     + 
+--R               +----------+                 2 3
+--R              \|- 2d e - b  - 2e x         e x  + (- d e + b)x
+--R       - atan(--------------------) + atan(-------------------)
+--R                   +----------+                 +----------+
+--R                  \|- 2d e + b                d\|- 2d e + b
+--R  /
+--R      +----------+
+--R     \|- 2d e + b
+--R                                                    Type: Expression(Integer)
+--E 48
+
+--S 49 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 49
+
+)clear all
+
+--S 50 of 3139
+t0:=(d-e*x^2)/(d^2-b*x^2+e^2*x^4)
+--R 
+--R
+--R                2
+--R           - e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  - b x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 50
+
+--S 51 of 3139
+r0:=-atanh((-2*e*x+sqrt(b-2*d*e))/sqrt(b+2*d*e))/sqrt(b+2*d*e)+_
+   atanh((2*e*x+sqrt(b-2*d*e))/sqrt(b+2*d*e))/sqrt(b+2*d*e)
+--R 
+--R
+--R               +----------+                  +----------+
+--R              \|- 2d e + b  + 2e x          \|- 2d e + b  - 2e x
+--R        atanh(--------------------) - atanh(--------------------)
+--R                    +--------+                    +--------+
+--R                   \|2d e + b                    \|2d e + b
+--R   (2)  ---------------------------------------------------------
+--R                                +--------+
+--R                               \|2d e + b
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 4              2    2  +--------+        2         3
+--R              (e x  + (4d e + b)x  + d )\|2d e + b  + (4d e  + 2b e)x
+--R            + 
+--R                 2
+--R              (4d e + 2b d)x
+--R         /
+--R             2 4      2    2
+--R            e x  - b x  + d
+--R    /
+--R         +--------+
+--R       2\|2d e + b
+--R     ,
+--R             +----------+          2 3
+--R         e x\|- 2d e - b          e x  + (- d e - b)x
+--R    atan(----------------) + atan(-------------------)
+--R             2d e + b                  +----------+
+--R                                     d\|- 2d e - b
+--R    --------------------------------------------------]
+--R                        +----------+
+--R                       \|- 2d e - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 52
+
+--S 53 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                2 4              2    2  +--------+        2         3
+--R              (e x  + (4d e + b)x  + d )\|2d e + b  + (4d e  + 2b e)x
+--R            + 
+--R                 2
+--R              (4d e + 2b d)x
+--R         /
+--R             2 4      2    2
+--R            e x  - b x  + d
+--R     + 
+--R                 +----------+                   +----------+
+--R                \|- 2d e + b  + 2e x           \|- 2d e + b  - 2e x
+--R       - 2atanh(--------------------) + 2atanh(--------------------)
+--R                      +--------+                     +--------+
+--R                     \|2d e + b                     \|2d e + b
+--R  /
+--R       +--------+
+--R     2\|2d e + b
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             +----------+
+--R          +----------+      \|- 2d e + b  + 2e x
+--R       - \|- 2d e - b atanh(--------------------)
+--R                                  +--------+
+--R                                 \|2d e + b
+--R     + 
+--R                           +----------+
+--R        +----------+      \|- 2d e + b  - 2e x
+--R       \|- 2d e - b atanh(--------------------)
+--R                                +--------+
+--R                               \|2d e + b
+--R     + 
+--R                           +----------+                     2 3
+--R        +--------+     e x\|- 2d e - b      +--------+     e x  + (- d e - b)x
+--R       \|2d e + b atan(----------------) + \|2d e + b atan(-------------------)
+--R                           2d e + b                             +----------+
+--R                                                              d\|- 2d e - b
+--R  /
+--R      +----------+ +--------+
+--R     \|- 2d e - b \|2d e + b
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 56
+
+)clear all
+
+--S 57 of 3139
+t0:=(d-e*x^2)/(d^2+f*x^2+e^2*x^4)
+--R 
+--R
+--R                2
+--R           - e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  + f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 57
+
+--S 58 of 3139
+r0:=-1/2*log(d+e*x^2-x*sqrt(2*d*e-f))/sqrt(2*d*e-f)+_
+   1/2*log(d+e*x^2+x*sqrt(2*d*e-f))/sqrt(2*d*e-f)
+--R 
+--R
+--R              +----------+      2                +----------+      2
+--R        log(x\|- f + 2d e  + e x  + d) - log(- x\|- f + 2d e  + e x  + d)
+--R   (2)  -----------------------------------------------------------------
+--R                                    +----------+
+--R                                  2\|- f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 4                2    2  +----------+                 2  3
+--R              (e x  + (- f + 4d e)x  + d )\|- f + 2d e  + (- 2e f + 4d e )x
+--R            + 
+--R                          2
+--R              (- 2d f + 4d e)x
+--R         /
+--R             2 4      2    2
+--R            e x  + f x  + d
+--R    /
+--R         +----------+
+--R       2\|- f + 2d e
+--R     ,
+--R               +--------+          2 3
+--R           e x\|f - 2d e          e x  + (f - d e)x
+--R    - atan(--------------) + atan(-----------------)
+--R              f - 2d e                 +--------+
+--R                                     d\|f - 2d e
+--R    ------------------------------------------------]
+--R                        +--------+
+--R                       \|f - 2d e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 59
+
+--S 60 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               +----------+      2
+--R       - log(x\|- f + 2d e  + e x  + d)
+--R     + 
+--R       log
+--R                2 4                2    2  +----------+                 2  3
+--R              (e x  + (- f + 4d e)x  + d )\|- f + 2d e  + (- 2e f + 4d e )x
+--R            + 
+--R                          2
+--R              (- 2d f + 4d e)x
+--R         /
+--R             2 4      2    2
+--R            e x  + f x  + d
+--R     + 
+--R               +----------+      2
+--R       log(- x\|- f + 2d e  + e x  + d)
+--R  /
+--R       +----------+
+--R     2\|- f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 60
+
+--S 61 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +--------+      +----------+      2
+--R       - \|f - 2d e log(x\|- f + 2d e  + e x  + d)
+--R     + 
+--R        +--------+        +----------+      2
+--R       \|f - 2d e log(- x\|- f + 2d e  + e x  + d)
+--R     + 
+--R                                +--------+
+--R           +----------+     e x\|f - 2d e
+--R       - 2\|- f + 2d e atan(--------------)
+--R                               f - 2d e
+--R     + 
+--R                           2 3
+--R         +----------+     e x  + (f - d e)x
+--R       2\|- f + 2d e atan(-----------------)
+--R                               +--------+
+--R                             d\|f - 2d e
+--R  /
+--R       +----------+ +--------+
+--R     2\|- f + 2d e \|f - 2d e
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 3139
+t0:=(d-e*x^2)/(d^2-f*x^2+e^2*x^4)
+--R 
+--R
+--R                2
+--R           - e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  - f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 64
+
+--S 65 of 3139
+r0:=-1/2*log(d+e*x^2-x*sqrt(2*d*e+f))/sqrt(2*d*e+f)+_
+   1/2*log(d+e*x^2+x*sqrt(2*d*e+f))/sqrt(2*d*e+f)
+--R 
+--R
+--R              +--------+      2                +--------+      2
+--R        log(x\|f + 2d e  + e x  + d) - log(- x\|f + 2d e  + e x  + d)
+--R   (2)  -------------------------------------------------------------
+--R                                   +--------+
+--R                                 2\|f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 4              2    2  +--------+               2  3
+--R              (e x  + (f + 4d e)x  + d )\|f + 2d e  + (2e f + 4d e )x
+--R            + 
+--R                        2
+--R              (2d f + 4d e)x
+--R         /
+--R             2 4      2    2
+--R            e x  - f x  + d
+--R    /
+--R         +--------+
+--R       2\|f + 2d e
+--R     ,
+--R             +----------+          2 3
+--R         e x\|- f - 2d e          e x  + (- f - d e)x
+--R    atan(----------------) + atan(-------------------)
+--R             f + 2d e                  +----------+
+--R                                     d\|- f - 2d e
+--R    --------------------------------------------------]
+--R                        +----------+
+--R                       \|- f - 2d e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 66
+
+--S 67 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               +--------+      2
+--R       - log(x\|f + 2d e  + e x  + d)
+--R     + 
+--R       log
+--R                2 4              2    2  +--------+               2  3
+--R              (e x  + (f + 4d e)x  + d )\|f + 2d e  + (2e f + 4d e )x
+--R            + 
+--R                        2
+--R              (2d f + 4d e)x
+--R         /
+--R             2 4      2    2
+--R            e x  - f x  + d
+--R     + 
+--R               +--------+      2
+--R       log(- x\|f + 2d e  + e x  + d)
+--R  /
+--R       +--------+
+--R     2\|f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +----------+      +--------+      2
+--R       - \|- f - 2d e log(x\|f + 2d e  + e x  + d)
+--R     + 
+--R        +----------+        +--------+      2
+--R       \|- f - 2d e log(- x\|f + 2d e  + e x  + d)
+--R     + 
+--R                          +----------+                      2 3
+--R       +--------+     e x\|- f - 2d e       +--------+     e x  + (- f - d e)x
+--R     2\|f + 2d e atan(----------------) + 2\|f + 2d e atan(-------------------)
+--R                          f + 2d e                              +----------+
+--R                                                              d\|- f - 2d e
+--R  /
+--R       +----------+ +--------+
+--R     2\|- f - 2d e \|f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 70
+
+)clear all
+
+--S 71 of 3139
+t0:=(1+2*x^2)/(1+b*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R            2x  + 1
+--R   (1)  --------------
+--R          4      2
+--R        4x  + b x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 71
+
+--S 72 of 3139
+r0:=-atan((-4*x+sqrt(4-b))/sqrt(4+b))/sqrt(4+b)+_
+   atan((4*x+sqrt(4-b))/sqrt(4+b))/sqrt(4+b)
+--R 
+--R
+--R              +-------+               +-------+
+--R             \|- b + 4  + 4x         \|- b + 4  - 4x
+--R        atan(---------------) - atan(---------------)
+--R                  +-----+                 +-----+
+--R                 \|b + 4                 \|b + 4
+--R   (2)  ---------------------------------------------
+--R                            +-----+
+--R                           \|b + 4
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4             2      +-------+             3
+--R        (4x  + (- b - 8)x  + 1)\|- b - 4  + (4b + 16)x  + (- 2b - 8)x
+--R    log(-------------------------------------------------------------)
+--R                                  4      2
+--R                                4x  + b x  + 1
+--R   [------------------------------------------------------------------,
+--R                                  +-------+
+--R                                2\|- b - 4
+--R            +-----+           3
+--R         2x\|b + 4          4x  + (b + 2)x
+--R    atan(----------) + atan(--------------)
+--R            b + 4               +-----+
+--R                               \|b + 4
+--R    ---------------------------------------]
+--R                     +-----+
+--R                    \|b + 4
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 73
+
+--S 74 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-----+
+--R         \|b + 4
+--R      *
+--R                4             2      +-------+             3
+--R             (4x  + (- b - 8)x  + 1)\|- b - 4  + (4b + 16)x  + (- 2b - 8)x
+--R         log(-------------------------------------------------------------)
+--R                                       4      2
+--R                                     4x  + b x  + 1
+--R     + 
+--R                          +-------+                          +-------+
+--R           +-------+     \|- b + 4  + 4x      +-------+     \|- b + 4  - 4x
+--R       - 2\|- b - 4 atan(---------------) + 2\|- b - 4 atan(---------------)
+--R                              +-----+                            +-----+
+--R                             \|b + 4                            \|b + 4
+--R  /
+--R       +-------+ +-----+
+--R     2\|- b - 4 \|b + 4
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+--S 76 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               +-----+          +-------+               +-------+
+--R            2x\|b + 4          \|- b + 4  + 4x         \|- b + 4  - 4x
+--R       atan(----------) - atan(---------------) + atan(---------------)
+--R               b + 4                +-----+                 +-----+
+--R                                   \|b + 4                 \|b + 4
+--R     + 
+--R              3
+--R            4x  + (b + 2)x
+--R       atan(--------------)
+--R                +-----+
+--R               \|b + 4
+--R  /
+--R      +-----+
+--R     \|b + 4
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 77
+
+)clear all
+
+--S 78 of 3139
+t0:=(1+2*x^2)/(1-b*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R            2x  + 1
+--R   (1)  --------------
+--R          4      2
+--R        4x  - b x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 78
+
+--S 79 of 3139
+r0:=-atan((-4*x+sqrt(4+b))/sqrt(4-b))/sqrt(4-b)+_
+   atan((4*x+sqrt(4+b))/sqrt(4-b))/sqrt(4-b)
+--R 
+--R
+--R              +-----+               +-----+
+--R             \|b + 4  + 4x         \|b + 4  - 4x
+--R        atan(-------------) - atan(-------------)
+--R                +-------+             +-------+
+--R               \|- b + 4             \|- b + 4
+--R   (2)  -----------------------------------------
+--R                         +-------+
+--R                        \|- b + 4
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4           2      +-----+               3
+--R        (4x  + (b - 8)x  + 1)\|b - 4  + (- 4b + 16)x  + (2b - 8)x
+--R    log(---------------------------------------------------------)
+--R                                4      2
+--R                              4x  - b x  + 1
+--R   [--------------------------------------------------------------,
+--R                                 +-----+
+--R                               2\|b - 4
+--R              +-------+           3
+--R           2x\|- b + 4          4x  + (- b + 2)x
+--R    - atan(------------) + atan(----------------)
+--R               b - 4                +-------+
+--R                                   \|- b + 4
+--R    ---------------------------------------------]
+--R                       +-------+
+--R                      \|- b + 4
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 80
+
+--S 81 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        4           2      +-----+               3
+--R        +-------+    (4x  + (b - 8)x  + 1)\|b - 4  + (- 4b + 16)x  + (2b - 8)x
+--R       \|- b + 4 log(---------------------------------------------------------)
+--R                                             4      2
+--R                                           4x  - b x  + 1
+--R     + 
+--R                        +-----+                        +-----+
+--R           +-----+     \|b + 4  + 4x      +-----+     \|b + 4  - 4x
+--R       - 2\|b - 4 atan(-------------) + 2\|b - 4 atan(-------------)
+--R                          +-------+                      +-------+
+--R                         \|- b + 4                      \|- b + 4
+--R  /
+--R       +-------+ +-----+
+--R     2\|- b + 4 \|b - 4
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               +-----+               +-----+                 +-------+
+--R              \|b + 4  + 4x         \|b + 4  - 4x         2x\|- b + 4
+--R       - atan(-------------) + atan(-------------) - atan(------------)
+--R                 +-------+             +-------+              b - 4
+--R                \|- b + 4             \|- b + 4
+--R     + 
+--R              3
+--R            4x  + (- b + 2)x
+--R       atan(----------------)
+--R                +-------+
+--R               \|- b + 4
+--R  /
+--R      +-------+
+--R     \|- b + 4
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 3139
+t0:=(1+2*x^2)/(1+6*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 6x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 85
+
+--S 86 of 3139
+r0:=atan(2*x/sqrt(3-sqrt(5)))/sqrt(10)+atan(2*x/sqrt(3+sqrt(5)))/sqrt(10)
+--R 
+--R
+--R                            +--------+                      +----------+
+--R                  +-+       | +-+                 +-+       |   +-+
+--R               (x\|5  - 3x)\|\|5  + 3          (x\|5  + 3x)\|- \|5  + 3
+--R        - atan(-----------------------) + atan(-------------------------)
+--R                          2                                2
+--R   (2)  -----------------------------------------------------------------
+--R                                       +--+
+--R                                      \|10
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +--+           3
+--R             x\|10          4x  + 8x
+--R        atan(------) + atan(--------)
+--R                5              +--+
+--R                              \|10
+--R   (3)  -----------------------------
+--R                     +--+
+--R                    \|10
+--R                                         Type: Union(Expression(Integer),...)
+--E 87
+
+--S 88 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +--------+                      +----------+
+--R               +-+       | +-+                 +-+       |   +-+
+--R            (x\|5  - 3x)\|\|5  + 3          (x\|5  + 3x)\|- \|5  + 3
+--R       atan(-----------------------) - atan(-------------------------)
+--R                       2                                2
+--R     + 
+--R              +--+           3
+--R            x\|10          4x  + 8x
+--R       atan(------) + atan(--------)
+--R               5              +--+
+--R                             \|10
+--R  /
+--R      +--+
+--R     \|10
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                             +--------+                           +----------+
+--R         +-+     2      +--+ | +-+            +-+     2      +--+ |   +-+
+--R       (\|5  - 4x  - 3)\|10 \|\|5  + 3  + (- \|5  - 4x  - 3)\|10 \|- \|5  + 3
+--R     + 
+--R          2
+--R       40x  + 20
+--R  /
+--R        4       2
+--R     80x  + 120x  + 20
+--R                                                    Type: Expression(Integer)
+--E 89
+
+)clear all
+
+--S 90 of 3139
+t0:=(1+2*x^2)/(1+5*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 90
+
+--S 91 of 3139
+r0:=1/3*atan(x)+1/3*atan(2*x)
+--R 
+--R
+--R        atan(2x) + atan(x)
+--R   (2)  ------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3
+--R             4x  + 7x         2x
+--R        atan(--------) + atan(--)
+--R                 3             3
+--R   (3)  -------------------------
+--R                    3
+--R                                         Type: Union(Expression(Integer),...)
+--E 92
+
+--S 93 of 3139
+m0:=a0-r0
+--R 
+--R
+--R               3
+--R             4x  + 7x                              2x
+--R        atan(--------) - atan(2x) - atan(x) + atan(--)
+--R                 3                                  3
+--R   (4)  ----------------------------------------------
+--R                               3
+--R                                                    Type: Expression(Integer)
+--E 93
+
+--S 94 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 94
+
+)clear all
+
+--S 95 of 3139
+t0:=(1+2*x^2)/(1+4*x^2+4*x^4)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R          2
+--R        2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 95
+
+--S 96 of 3139
+r0:=atan(x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R               +-+
+--R        atan(x\|2 )
+--R   (2)  -----------
+--R             +-+
+--R            \|2
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+
+--R        atan(x\|2 )
+--R   (3)  -----------
+--R             +-+
+--R            \|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 97
+
+--S 98 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 3139
+t0:=(1+2*x^2)/(1+3*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 100
+
+--S 101 of 3139
+r0:=-atan((1-4*x)/sqrt(7))/sqrt(7)+atan((1+4*x)/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                      +-+                  +-+
+--R             (4x + 1)\|7          (4x - 1)\|7
+--R        atan(------------) + atan(------------)
+--R                   7                    7
+--R   (2)  ---------------------------------------
+--R                           +-+
+--R                          \|7
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +-+           3
+--R             2x\|7          4x  + 5x
+--R        atan(------) + atan(--------)
+--R                7              +-+
+--R                              \|7
+--R   (3)  -----------------------------
+--R                      +-+
+--R                     \|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 102
+
+--S 103 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +-+                  +-+            +-+           3
+--R          (4x + 1)\|7          (4x - 1)\|7          2x\|7          4x  + 5x
+--R   - atan(------------) - atan(------------) + atan(------) + atan(--------)
+--R                7                    7                 7              +-+
+--R                                                                     \|7
+--R   -------------------------------------------------------------------------
+--R                                       +-+
+--R                                      \|7
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 104
+
+)clear all
+
+--S 105 of 3139
+t0:=(1+2*x^2)/(1+2*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 105
+
+--S 106 of 3139
+r0:=-atan((-4*x+sqrt(2))/sqrt(6))/sqrt(6)+atan((4*x+sqrt(2))/sqrt(6))/sqrt(6)
+--R 
+--R
+--R               +-+       +-+           +-+       +-+
+--R             (\|2  + 4x)\|6          (\|2  - 4x)\|6
+--R        atan(---------------) - atan(---------------)
+--R                    6                       6
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                             \|6
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+           3
+--R             x\|6          4x  + 4x
+--R        atan(-----) + atan(--------)
+--R               3              +-+
+--R                             \|6
+--R   (3)  ----------------------------
+--R                     +-+
+--R                    \|6
+--R                                         Type: Union(Expression(Integer),...)
+--E 107
+
+--S 108 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+       +-+           +-+       +-+           +-+
+--R              (\|2  + 4x)\|6          (\|2  - 4x)\|6          x\|6
+--R       - atan(---------------) + atan(---------------) + atan(-----)
+--R                     6                       6                  3
+--R     + 
+--R              3
+--R            4x  + 4x
+--R       atan(--------)
+--R               +-+
+--R              \|6
+--R  /
+--R      +-+
+--R     \|6
+--R                                                    Type: Expression(Integer)
+--E 108
+
+--S 109 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 109
+
+)clear all
+
+--S 110 of 3139
+t0:=(1+2*x^2)/(1+x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  ------------
+--R          4    2
+--R        4x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 110
+
+--S 111 of 3139
+r0:=-atan((-4*x+sqrt(3))/sqrt(5))/sqrt(5)+atan((4*x+sqrt(3))/sqrt(5))/sqrt(5)
+--R 
+--R
+--R               +-+       +-+           +-+       +-+
+--R             (\|3  + 4x)\|5          (\|3  - 4x)\|5
+--R        atan(---------------) - atan(---------------)
+--R                    5                       5
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                             \|5
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +-+           3
+--R             2x\|5          4x  + 3x
+--R        atan(------) + atan(--------)
+--R                5              +-+
+--R                              \|5
+--R   (3)  -----------------------------
+--R                      +-+
+--R                     \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 112
+
+--S 113 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+       +-+           +-+       +-+            +-+
+--R              (\|3  + 4x)\|5          (\|3  - 4x)\|5          2x\|5
+--R       - atan(---------------) + atan(---------------) + atan(------)
+--R                     5                       5                   5
+--R     + 
+--R              3
+--R            4x  + 3x
+--R       atan(--------)
+--R               +-+
+--R              \|5
+--R  /
+--R      +-+
+--R     \|5
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 3139
+t0:=(1+2*x^2)/(1+4*x^4)
+--R 
+--R
+--R          2
+--R        2x  + 1
+--R   (1)  -------
+--R          4
+--R        4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 115
+
+--S 116 of 3139
+r0:=-1/2*atan(1-2*x)+1/2*atan(1+2*x)
+--R 
+--R
+--R        atan(2x + 1) + atan(2x - 1)
+--R   (2)  ---------------------------
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3
+--R        3atan(2x  + x) + %pi
+--R   (3)  --------------------
+--R                  6
+--R                                         Type: Union(Expression(Integer),...)
+--E 117
+
+--S 118 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                3
+--R        3atan(2x  + x) - 3atan(2x + 1) - 3atan(2x - 1) + %pi
+--R   (4)  ----------------------------------------------------
+--R                                  6
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R             1
+--R   (5)  - -------
+--R            2
+--R          2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 119
+
+)clear all
+
+--S 120 of 3139
+t0:=(1+2*x^2)/(1-x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  ------------
+--R          4    2
+--R        4x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 120
+
+--S 121 of 3139
+r0:=-atan((-4*x+sqrt(5))/sqrt(3))/sqrt(3)+atan((4*x+sqrt(5))/sqrt(3))/sqrt(3)
+--R 
+--R
+--R              +-+ +-+      +-+          +-+ +-+      +-+
+--R             \|3 \|5  + 4x\|3          \|3 \|5  - 4x\|3
+--R        atan(-----------------) - atan(-----------------)
+--R                     3                         3
+--R   (2)  -------------------------------------------------
+--R                                +-+
+--R                               \|3
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +-+           3
+--R             2x\|3          4x  + x
+--R        atan(------) + atan(-------)
+--R                3              +-+
+--R                              \|3
+--R   (3)  ----------------------------
+--R                     +-+
+--R                    \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 122
+
+--S 123 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+ +-+      +-+          +-+ +-+      +-+            +-+
+--R              \|3 \|5  + 4x\|3          \|3 \|5  - 4x\|3          2x\|3
+--R       - atan(-----------------) + atan(-----------------) + atan(------)
+--R                      3                         3                    3
+--R     + 
+--R              3
+--R            4x  + x
+--R       atan(-------)
+--R               +-+
+--R              \|3
+--R  /
+--R      +-+
+--R     \|3
+--R                                                    Type: Expression(Integer)
+--E 123
+
+--S 124 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 124
+
+)clear all
+
+--S 125 of 3139
+t0:=(1+2*x^2)/(1-2*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 125
+
+--S 126 of 3139
+r0:=-atan((-4*x+sqrt(6))/sqrt(2))/sqrt(2)+atan((4*x+sqrt(6))/sqrt(2))/sqrt(2)
+--R 
+--R
+--R              +-+ +-+      +-+          +-+ +-+      +-+
+--R             \|2 \|6  + 4x\|2          \|2 \|6  - 4x\|2
+--R        atan(-----------------) - atan(-----------------)
+--R                     2                         2
+--R   (2)  -------------------------------------------------
+--R                                +-+
+--R                               \|2
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                              3
+--R               +-+          4x
+--R        atan(x\|2 ) + atan(----)
+--R                            +-+
+--R                           \|2
+--R   (3)  ------------------------
+--R                   +-+
+--R                  \|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 127
+
+--S 128 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+ +-+      +-+          +-+ +-+      +-+
+--R              \|2 \|6  + 4x\|2          \|2 \|6  - 4x\|2            +-+
+--R       - atan(-----------------) + atan(-----------------) + atan(x\|2 )
+--R                      2                         2
+--R     + 
+--R               3
+--R             4x
+--R       atan(----)
+--R             +-+
+--R            \|2
+--R  /
+--R      +-+
+--R     \|2
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 3139
+t0:=(1+2*x^2)/(1-3*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 130
+
+--S 131 of 3139
+r0:=-atan(-4*x+sqrt(7))+atan(4*x+sqrt(7))
+--R 
+--R
+--R              +-+               +-+
+--R   (2)  atan(\|7  + 4x) - atan(\|7  - 4x)
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3
+--R   (3)  atan(4x  - x) + atan(2x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 132
+
+--S 133 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                +-+               +-+                3
+--R   (4)  - atan(\|7  + 4x) + atan(\|7  - 4x) + atan(4x  - x) + atan(2x)
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 134
+
+)clear all
+
+--S 135 of 3139
+t0:=(1+2*x^2)/(1-4*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 135
+
+--S 136 of 3139
+r0:=x/(1-2*x^2)
+--R 
+--R
+--R             x
+--R   (2)  - -------
+--R            2
+--R          2x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 136
+
+--S 137 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             x
+--R   (3)  - -------
+--R            2
+--R          2x  - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 137
+
+--S 138 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+--S 139 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 139
+
+)clear all
+
+--S 140 of 3139
+t0:=(1+2*x^2)/(1-5*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 140
+
+--S 141 of 3139
+r0:=atanh(3-4*x)-atanh(3+4*x)
+--R 
+--R
+--R   (2)  - atanh(4x + 3) - atanh(4x - 3)
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2                  2
+--R        - log(2x  + x - 1) + log(2x  - x - 1)
+--R   (3)  -------------------------------------
+--R                          2
+--R                                         Type: Union(Expression(Integer),...)
+--E 142
+
+--S 143 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2                  2
+--R   - log(2x  + x - 1) + log(2x  - x - 1) + 2atanh(4x + 3) + 2atanh(4x - 3)
+--R   -----------------------------------------------------------------------
+--R                                      2
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 3139
+t0:=(1+2*x^2)/(1-6*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 6x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 145
+
+--S 146 of 3139
+r0:=atanh((-4*x+sqrt(10))/sqrt(2))/sqrt(2)-_
+   atanh((4*x+sqrt(10))/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                 +-+ +--+      +-+           +-+ +--+      +-+
+--R                \|2 \|10  + 4x\|2           \|2 \|10  - 4x\|2
+--R        - atanh(------------------) + atanh(------------------)
+--R                         2                           2
+--R   (2)  -------------------------------------------------------
+--R                                   +-+
+--R                                  \|2
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4     2      +-+     3
+--R            (4x  - 2x  + 1)\|2  - 8x  + 4x
+--R        log(------------------------------)
+--R                       4     2
+--R                     4x  - 6x  + 1
+--R   (3)  -----------------------------------
+--R                         +-+
+--R                       2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 147
+
+--S 148 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              4     2      +-+     3                 +-+ +--+      +-+
+--R           (4x  - 2x  + 1)\|2  - 8x  + 4x           \|2 \|10  + 4x\|2
+--R       log(------------------------------) + 2atanh(------------------)
+--R                      4     2                                2
+--R                    4x  - 6x  + 1
+--R     + 
+--R                 +-+ +--+      +-+
+--R                \|2 \|10  - 4x\|2
+--R       - 2atanh(------------------)
+--R                         2
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 149
+
+)clear all
+
+--S 150 of 3139
+t0:=(1-2*x^2)/(1+b*x^2+4*x^4)
+--R 
+--R
+--R               2
+--R           - 2x  + 1
+--R   (1)  --------------
+--R          4      2
+--R        4x  + b x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 150
+
+--S 151 of 3139
+r0:=-1/2*log(1+2*x^2-x*sqrt(4-b))/sqrt(4-b)+_
+   1/2*log(1+2*x^2+x*sqrt(4-b))/sqrt(4-b)
+--R 
+--R
+--R              +-------+     2                +-------+     2
+--R        log(x\|- b + 4  + 2x  + 1) - log(- x\|- b + 4  + 2x  + 1)
+--R   (2)  ---------------------------------------------------------
+--R                                 +-------+
+--R                               2\|- b + 4
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4             2      +-------+               3
+--R        (4x  + (- b + 8)x  + 1)\|- b + 4  + (- 4b + 16)x  + (- 2b + 8)x
+--R    log(---------------------------------------------------------------)
+--R                                   4      2
+--R                                 4x  + b x  + 1
+--R   [--------------------------------------------------------------------,
+--R                                   +-------+
+--R                                 2\|- b + 4
+--R              +-----+           3
+--R           2x\|b - 4          4x  + (b - 2)x
+--R    - atan(----------) + atan(--------------)
+--R              b - 4               +-----+
+--R                                 \|b - 4
+--R    -----------------------------------------]
+--R                      +-----+
+--R                     \|b - 4
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 152
+
+--S 153 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               +-------+     2
+--R       - log(x\|- b + 4  + 2x  + 1)
+--R     + 
+--R              4             2      +-------+               3
+--R           (4x  + (- b + 8)x  + 1)\|- b + 4  + (- 4b + 16)x  + (- 2b + 8)x
+--R       log(---------------------------------------------------------------)
+--R                                      4      2
+--R                                    4x  + b x  + 1
+--R     + 
+--R               +-------+     2
+--R       log(- x\|- b + 4  + 2x  + 1)
+--R  /
+--R       +-------+
+--R     2\|- b + 4
+--R                                                    Type: Expression(Integer)
+--E 153
+
+--S 154 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +-----+      +-------+     2
+--R       - \|b - 4 log(x\|- b + 4  + 2x  + 1)
+--R     + 
+--R                                                                 +-----+
+--R        +-----+        +-------+     2          +-------+     2x\|b - 4
+--R       \|b - 4 log(- x\|- b + 4  + 2x  + 1) - 2\|- b + 4 atan(----------)
+--R                                                                 b - 4
+--R     + 
+--R                         3
+--R         +-------+     4x  + (b - 2)x
+--R       2\|- b + 4 atan(--------------)
+--R                           +-----+
+--R                          \|b - 4
+--R  /
+--R       +-------+ +-----+
+--R     2\|- b + 4 \|b - 4
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 3139
+t0:=(1-2*x^2)/(1+6*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 6x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 157
+
+--S 158 of 3139
+r0:=atan(2*x/sqrt(3-sqrt(5)))/sqrt(2)-atan(2*x/sqrt(3+sqrt(5)))/sqrt(2)
+--R 
+--R
+--R                          +--------+                      +----------+
+--R                +-+       | +-+                 +-+       |   +-+
+--R             (x\|5  - 3x)\|\|5  + 3          (x\|5  + 3x)\|- \|5  + 3
+--R        atan(-----------------------) + atan(-------------------------)
+--R                        2                                2
+--R   (2)  ---------------------------------------------------------------
+--R                                       +-+
+--R                                      \|2
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               3
+--R                 +-+         4x  + 4x
+--R        - atan(x\|2 ) + atan(--------)
+--R                                +-+
+--R                               \|2
+--R   (3)  ------------------------------
+--R                      +-+
+--R                     \|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 159
+
+--S 160 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           +--------+                      +----------+
+--R                 +-+       | +-+                 +-+       |   +-+
+--R              (x\|5  - 3x)\|\|5  + 3          (x\|5  + 3x)\|- \|5  + 3
+--R       - atan(-----------------------) - atan(-------------------------)
+--R                         2                                2
+--R     + 
+--R                              3
+--R                +-+         4x  + 4x
+--R       - atan(x\|2 ) + atan(--------)
+--R                               +-+
+--R                              \|2
+--R  /
+--R      +-+
+--R     \|2
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                    +--------+
+--R           +-+ +-+      2      +-+  | +-+
+--R       (- \|2 \|5  + (4x  + 3)\|2 )\|\|5  + 3
+--R     + 
+--R                                      +----------+
+--R           +-+ +-+        2      +-+  |   +-+          2
+--R       (- \|2 \|5  + (- 4x  - 3)\|2 )\|- \|5  + 3  - 8x  + 4
+--R  /
+--R        4      2
+--R     16x  + 24x  + 4
+--R                                                    Type: Expression(Integer)
+--E 161
+
+)clear all
+
+--S 162 of 3139
+t0:=(1-2*x^2)/(1+5*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 162
+
+--S 163 of 3139
+r0:=-atan(x)+atan(2*x)
+--R 
+--R
+--R        3atan(2x) - %pi
+--R   (2)  ---------------
+--R               3
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3
+--R   (3)  atan(4x  + 3x) - atan(2x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 164
+
+--S 165 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                3
+--R        3atan(4x  + 3x) - 6atan(2x) + %pi
+--R   (4)  ---------------------------------
+--R                        3
+--R                                                    Type: Expression(Integer)
+--E 165
+
+--S 166 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R             1
+--R   (5)  - ------
+--R           2
+--R          x  + 1
+--R                                                    Type: Expression(Integer)
+--E 166
+
+)clear all
+
+--S 167 of 3139
+t0:=(1-2*x^2)/(1+4*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 167
+
+--S 168 of 3139
+r0:=x/(1+2*x^2)
+--R 
+--R
+--R           x
+--R   (2)  -------
+--R          2
+--R        2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 168
+
+--S 169 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x
+--R   (3)  -------
+--R          2
+--R        2x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 169
+
+--S 170 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 3139
+t0:=(1-2*x^2)/(1+3*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 172
+
+--S 173 of 3139
+r0:=-1/2*log(1-x+2*x^2)+1/2*log(1+x+2*x^2)
+--R 
+--R
+--R              2                  2
+--R        log(2x  + x + 1) - log(2x  - x + 1)
+--R   (2)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                  2
+--R        log(2x  + x + 1) - log(2x  - x + 1)
+--R   (3)  -----------------------------------
+--R                         2
+--R                                         Type: Union(Expression(Integer),...)
+--E 174
+
+--S 175 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 176
+
+)clear all
+
+--S 177 of 3139
+t0:=(1-2*x^2)/(1+2*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 177
+
+--S 178 of 3139
+r0:=-1/2*log(1+2*x^2-x*sqrt(2))/sqrt(2)+1/2*log(1+2*x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R              +-+     2                +-+     2
+--R        log(x\|2  + 2x  + 1) - log(- x\|2  + 2x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            2\|2
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4     2      +-+     3
+--R            (4x  + 6x  + 1)\|2  + 8x  + 4x
+--R        log(------------------------------)
+--R                       4     2
+--R                     4x  + 2x  + 1
+--R   (3)  -----------------------------------
+--R                         +-+
+--R                       2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 179
+
+--S 180 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       4     2      +-+     3
+--R               +-+     2            (4x  + 6x  + 1)\|2  + 8x  + 4x
+--R       - log(x\|2  + 2x  + 1) + log(------------------------------)
+--R                                               4     2
+--R                                             4x  + 2x  + 1
+--R     + 
+--R               +-+     2
+--R       log(- x\|2  + 2x  + 1)
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 180
+
+--S 181 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 181
+
+)clear all
+
+--S 182 of 3139
+t0:=(1-2*x^2)/(1+x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  ------------
+--R          4    2
+--R        4x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 182
+
+--S 183 of 3139
+r0:=-1/2*log(1+2*x^2-x*sqrt(3))/sqrt(3)+1/2*log(1+2*x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R              +-+     2                +-+     2
+--R        log(x\|3  + 2x  + 1) - log(- x\|3  + 2x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            2\|3
+--R                                                    Type: Expression(Integer)
+--E 183
+
+--S 184 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4     2      +-+      3
+--R            (4x  + 7x  + 1)\|3  + 12x  + 6x
+--R        log(-------------------------------)
+--R                        4    2
+--R                      4x  + x  + 1
+--R   (3)  ------------------------------------
+--R                          +-+
+--R                        2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 184
+
+--S 185 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       4     2      +-+      3
+--R               +-+     2            (4x  + 7x  + 1)\|3  + 12x  + 6x
+--R       - log(x\|3  + 2x  + 1) + log(-------------------------------)
+--R                                                4    2
+--R                                              4x  + x  + 1
+--R     + 
+--R               +-+     2
+--R       log(- x\|3  + 2x  + 1)
+--R  /
+--R       +-+
+--R     2\|3
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 3139
+t0:=(1-2*x^2)/(1+4*x^4)
+--R 
+--R
+--R            2
+--R        - 2x  + 1
+--R   (1)  ---------
+--R           4
+--R         4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 187
+
+--S 188 of 3139
+r0:=-1/4*log(1-2*x+2*x^2)+1/4*log(1+2*x+2*x^2)
+--R 
+--R
+--R              2                   2
+--R        log(2x  + 2x + 1) - log(2x  - 2x + 1)
+--R   (2)  -------------------------------------
+--R                          4
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                   2
+--R        log(2x  + 2x + 1) - log(2x  - 2x + 1)
+--R   (3)  -------------------------------------
+--R                          4
+--R                                         Type: Union(Expression(Integer),...)
+--E 189
+
+--S 190 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 191
+
+)clear all
+
+--S 192 of 3139
+t0:=(1-2*x^2)/(1-x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  ------------
+--R          4    2
+--R        4x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 192
+
+--S 193 of 3139
+r0:=-1/2*log(1+2*x^2-x*sqrt(5))/sqrt(5)+1/2*log(1+2*x^2+x*sqrt(5))/sqrt(5)
+--R 
+--R
+--R              +-+     2                +-+     2
+--R        log(x\|5  + 2x  + 1) - log(- x\|5  + 2x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            2\|5
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4     2      +-+      3
+--R            (4x  + 9x  + 1)\|5  + 20x  + 10x
+--R        log(--------------------------------)
+--R                        4    2
+--R                      4x  - x  + 1
+--R   (3)  -------------------------------------
+--R                          +-+
+--R                        2\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 194
+
+--S 195 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       4     2      +-+      3
+--R               +-+     2            (4x  + 9x  + 1)\|5  + 20x  + 10x
+--R       - log(x\|5  + 2x  + 1) + log(--------------------------------)
+--R                                                4    2
+--R                                              4x  - x  + 1
+--R     + 
+--R               +-+     2
+--R       log(- x\|5  + 2x  + 1)
+--R  /
+--R       +-+
+--R     2\|5
+--R                                                    Type: Expression(Integer)
+--E 195
+
+--S 196 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 196
+
+)clear all
+
+--S 197 of 3139
+t0:=(1-2*x^2)/(1-2*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 197
+
+--S 198 of 3139
+r0:=-1/2*log(1+2*x^2-x*sqrt(6))/sqrt(6)+1/2*log(1+2*x^2+x*sqrt(6))/sqrt(6)
+--R 
+--R
+--R              +-+     2                +-+     2
+--R        log(x\|6  + 2x  + 1) - log(- x\|6  + 2x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            2\|6
+--R                                                    Type: Expression(Integer)
+--E 198
+
+--S 199 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4      2      +-+      3
+--R            (4x  + 10x  + 1)\|6  + 24x  + 12x
+--R        log(---------------------------------)
+--R                        4     2
+--R                      4x  - 2x  + 1
+--R   (3)  --------------------------------------
+--R                           +-+
+--R                         2\|6
+--R                                         Type: Union(Expression(Integer),...)
+--E 199
+
+--S 200 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       4      2      +-+      3
+--R               +-+     2            (4x  + 10x  + 1)\|6  + 24x  + 12x
+--R       - log(x\|6  + 2x  + 1) + log(---------------------------------)
+--R                                                4     2
+--R                                              4x  - 2x  + 1
+--R     + 
+--R               +-+     2
+--R       log(- x\|6  + 2x  + 1)
+--R  /
+--R       +-+
+--R     2\|6
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 3139
+t0:=(1-2*x^2)/(1-3*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 202
+
+--S 203 of 3139
+r0:=-1/2*log(1+2*x^2-x*sqrt(7))/sqrt(7)+1/2*log(1+2*x^2+x*sqrt(7))/sqrt(7)
+--R 
+--R
+--R              +-+     2                +-+     2
+--R        log(x\|7  + 2x  + 1) - log(- x\|7  + 2x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            2\|7
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4      2      +-+      3
+--R            (4x  + 11x  + 1)\|7  + 28x  + 14x
+--R        log(---------------------------------)
+--R                        4     2
+--R                      4x  - 3x  + 1
+--R   (3)  --------------------------------------
+--R                           +-+
+--R                         2\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 204
+
+--S 205 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       4      2      +-+      3
+--R               +-+     2            (4x  + 11x  + 1)\|7  + 28x  + 14x
+--R       - log(x\|7  + 2x  + 1) + log(---------------------------------)
+--R                                                4     2
+--R                                              4x  - 3x  + 1
+--R     + 
+--R               +-+     2
+--R       log(- x\|7  + 2x  + 1)
+--R  /
+--R       +-+
+--R     2\|7
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 206
+
+)clear all
+
+--S 207 of 3139
+t0:=(1-2*x^2)/(1-4*x^2+4*x^4)
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R            2
+--R          2x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 207
+
+--S 208 of 3139
+r0:=atanh(x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R                +-+
+--R        atanh(x\|2 )
+--R   (2)  ------------
+--R             +-+
+--R            \|2
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2      +-+
+--R            (2x  + 1)\|2  + 4x
+--R        log(------------------)
+--R                    2
+--R                  2x  - 1
+--R   (3)  -----------------------
+--R                   +-+
+--R                 2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 209
+
+--S 210 of 3139
+m0:=a0-r0
+--R 
+--R
+--R               2      +-+
+--R            (2x  + 1)\|2  + 4x             +-+
+--R        log(------------------) - 2atanh(x\|2 )
+--R                    2
+--R                  2x  - 1
+--R   (4)  ---------------------------------------
+--R                           +-+
+--R                         2\|2
+--R                                                    Type: Expression(Integer)
+--E 210
+
+--S 211 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 211
+
+)clear all
+
+--S 212 of 3139
+t0:=(1-2*x^2)/(1-5*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 212
+
+--S 213 of 3139
+r0:=-1/6*log(1-2*x)-1/6*log(1-x)+1/6*log(1+x)+1/6*log(1+2*x)
+--R 
+--R
+--R        log(2x + 1) + log(x + 1) - log(- x + 1) - log(- 2x + 1)
+--R   (2)  -------------------------------------------------------
+--R                                   6
+--R                                                    Type: Expression(Integer)
+--E 213
+
+--S 214 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                   2
+--R        log(2x  + 3x + 1) - log(2x  - 3x + 1)
+--R   (3)  -------------------------------------
+--R                          6
+--R                                         Type: Union(Expression(Integer),...)
+--E 214
+
+--S 215 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2                   2
+--R       log(2x  + 3x + 1) - log(2x  - 3x + 1) - log(2x + 1) - log(x + 1)
+--R     + 
+--R       log(- x + 1) + log(- 2x + 1)
+--R  /
+--R     6
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 3139
+t0:=(1-2*x^2)/(1-6*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 6x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 217
+
+--S 218 of 3139
+r0:=-atanh((-4*x+sqrt(2))/sqrt(10))/sqrt(10)+_
+   atanh((4*x+sqrt(2))/sqrt(10))/sqrt(10)
+--R 
+--R
+--R                +-+       +--+            +-+       +--+
+--R              (\|2  + 4x)\|10           (\|2  - 4x)\|10
+--R        atanh(----------------) - atanh(----------------)
+--R                     10                        10
+--R   (2)  -------------------------------------------------
+--R                               +--+
+--R                              \|10
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4      2      +--+      3
+--R            (4x  + 14x  + 1)\|10  + 40x  + 20x
+--R        log(----------------------------------)
+--R                         4     2
+--R                       4x  - 6x  + 1
+--R   (3)  ---------------------------------------
+--R                           +--+
+--R                         2\|10
+--R                                         Type: Union(Expression(Integer),...)
+--E 219
+
+--S 220 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              4      2      +--+      3                   +-+       +--+
+--R           (4x  + 14x  + 1)\|10  + 40x  + 20x           (\|2  + 4x)\|10
+--R       log(----------------------------------) - 2atanh(----------------)
+--R                        4     2                                10
+--R                      4x  - 6x  + 1
+--R     + 
+--R                +-+       +--+
+--R              (\|2  - 4x)\|10
+--R       2atanh(----------------)
+--R                     10
+--R  /
+--R       +--+
+--R     2\|10
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 221
+
+)clear all
+
+--S 222 of 3139
+t0:=x^m*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R              6               4        2  m
+--R   (1)  (B c x  + (A c + B b)x  + A b x )x
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 3139
+r0:=A*b*x^(3+m)/(3+m)+(b*B+A*c)*x^(5+m)/(5+m)+B*c*x^(7+m)/(7+m)
+--R 
+--R
+--R   (2)
+--R             2                   m + 7
+--R       (B c m  + 8B c m + 15B c)x
+--R     + 
+--R                    2                                     m + 5
+--R       ((A c + B b)m  + (10A c + 10B b)m + 21A c + 21B b)x
+--R     + 
+--R             2                    m + 3
+--R       (A b m  + 12A b m + 35A b)x
+--R  /
+--R      3      2
+--R     m  + 15m  + 71m + 105
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2                   7
+--R         (B c m  + 8B c m + 15B c)x
+--R       + 
+--R                      2                                     5
+--R         ((A c + B b)m  + (10A c + 10B b)m + 21A c + 21B b)x
+--R       + 
+--R               2                    3
+--R         (A b m  + 12A b m + 35A b)x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      3      2
+--R     m  + 15m  + 71m + 105
+--R                                         Type: Union(Expression(Integer),...)
+--E 224
+
+--S 225 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 2                   7
+--R           (B c m  + 8B c m + 15B c)x
+--R         + 
+--R                        2                                     5
+--R           ((A c + B b)m  + (10A c + 10B b)m + 21A c + 21B b)x
+--R         + 
+--R                 2                    3
+--R           (A b m  + 12A b m + 35A b)x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R               2                   m + 7
+--R       (- B c m  - 8B c m - 15B c)x
+--R     + 
+--R                      2                                       m + 5
+--R       ((- A c - B b)m  + (- 10A c - 10B b)m - 21A c - 21B b)x
+--R     + 
+--R               2                    m + 3
+--R       (- A b m  - 12A b m - 35A b)x
+--R  /
+--R      3      2
+--R     m  + 15m  + 71m + 105
+--R                                                    Type: Expression(Integer)
+--E 225
+
+--S 226 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           6               4        2   m log(x)        m + 6
+--R     (B c x  + (A c + B b)x  + A b x )%e         - B c x
+--R   + 
+--R                   m + 4        m + 2
+--R     (- A c - B b)x      - A b x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+)clear all
+
+--S 227 of 3139
+t0:=x^2*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R             8               6        4
+--R   (1)  B c x  + (A c + B b)x  + A b x
+--R                                                    Type: Polynomial(Integer)
+--E 227
+
+--S 228 of 3139
+r0:=1/5*A*b*x^5+1/7*(b*B+A*c)*x^7+1/9*B*c*x^9
+--R 
+--R
+--R        1      9    1       1      7   1      5
+--R   (2)  - B c x  + (- A c + - B b)x  + - A b x
+--R        9           7       7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 228
+
+--S 229 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1      9    1       1      7   1      5
+--R   (3)  - B c x  + (- A c + - B b)x  + - A b x
+--R        9           7       7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 229
+
+--S 230 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 230
+
+--S 231 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 231
+
+)clear all
+
+--S 232 of 3139
+t0:=x*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R             7               5        3
+--R   (1)  B c x  + (A c + B b)x  + A b x
+--R                                                    Type: Polynomial(Integer)
+--E 232
+
+--S 233 of 3139
+r0:=1/4*A*b*x^4+1/6*(b*B+A*c)*x^6+1/8*B*c*x^8
+--R 
+--R
+--R        1      8    1       1      6   1      4
+--R   (2)  - B c x  + (- A c + - B b)x  + - A b x
+--R        8           6       6          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 233
+
+--S 234 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1      8    1       1      6   1      4
+--R   (3)  - B c x  + (- A c + - B b)x  + - A b x
+--R        8           6       6          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 234
+
+--S 235 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 235
+
+--S 236 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 236
+
+)clear all
+
+--S 237 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R             6               4        2
+--R   (1)  B c x  + (A c + B b)x  + A b x
+--R                                                    Type: Polynomial(Integer)
+--E 237
+
+--S 238 of 3139
+r0:=1/3*A*b*x^3+1/5*(b*B+A*c)*x^5+1/7*B*c*x^7
+--R 
+--R
+--R        1      7    1       1      5   1      3
+--R   (2)  - B c x  + (- A c + - B b)x  + - A b x
+--R        7           5       5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 238
+
+--S 239 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1      7    1       1      5   1      3
+--R   (3)  - B c x  + (- A c + - B b)x  + - A b x
+--R        7           5       5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 239
+
+--S 240 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 240
+
+--S 241 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 241
+
+)clear all
+
+--S 242 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x
+--R 
+--R
+--R             5               3
+--R   (1)  B c x  + (A c + B b)x  + A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 242
+
+--S 243 of 3139
+r0:=1/2*A*b*x^2+1/4*(b*B+A*c)*x^4+1/6*B*c*x^6
+--R 
+--R
+--R        1      6    1       1      4   1      2
+--R   (2)  - B c x  + (- A c + - B b)x  + - A b x
+--R        6           4       4          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 243
+
+--S 244 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              6                 4         2
+--R        2B c x  + (3A c + 3B b)x  + 6A b x
+--R   (3)  -----------------------------------
+--R                         12
+--R                                         Type: Union(Expression(Integer),...)
+--E 244
+
+--S 245 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R             4               2
+--R   (1)  B c x  + (A c + B b)x  + A b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 247
+
+--S 248 of 3139
+r0:=A*b*x+1/3*(b*B+A*c)*x^3+1/5*B*c*x^5
+--R 
+--R
+--R        1      5    1       1      3
+--R   (2)  - B c x  + (- A c + - B b)x  + A b x
+--R        5           3       3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 248
+
+--S 249 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              5                 3
+--R        3B c x  + (5A c + 5B b)x  + 15A b x
+--R   (3)  -----------------------------------
+--R                         15
+--R                                         Type: Union(Expression(Integer),...)
+--E 249
+
+--S 250 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 251
+
+)clear all
+
+--S 252 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^3
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 252
+
+--S 253 of 3139
+r0:=1/2*(b*B+A*c)*x^2+1/4*B*c*x^4+A*b*log(x)
+--R 
+--R
+--R                           4                 2
+--R        4A b log(x) + B c x  + (2A c + 2B b)x
+--R   (2)  --------------------------------------
+--R                           4
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           4                 2
+--R        4A b log(x) + B c x  + (2A c + 2B b)x
+--R   (3)  --------------------------------------
+--R                           4
+--R                                         Type: Union(Expression(Integer),...)
+--E 254
+
+--S 255 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+--S 256 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 256
+
+)clear all
+
+--S 257 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^4
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      2
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 257
+
+--S 258 of 3139
+r0:=-A*b/x+(b*B+A*c)*x+1/3*B*c*x^3
+--R 
+--R
+--R             4                 2
+--R        B c x  + (3A c + 3B b)x  - 3A b
+--R   (2)  -------------------------------
+--R                       3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 258
+
+--S 259 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4                 2
+--R        B c x  + (3A c + 3B b)x  - 3A b
+--R   (3)  -------------------------------
+--R                       3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 259
+
+--S 260 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^5
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      3
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 262
+
+--S 263 of 3139
+r0:=-1/2*A*b/x^2+1/2*B*c*x^2+(b*B+A*c)*log(x)
+--R 
+--R
+--R                      2              4
+--R        (2A c + 2B b)x log(x) + B c x  - A b
+--R   (2)  ------------------------------------
+--R                           2
+--R                         2x
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      2              4
+--R        (2A c + 2B b)x log(x) + B c x  - A b
+--R   (3)  ------------------------------------
+--R                           2
+--R                         2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 264
+
+--S 265 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 266
+
+)clear all
+
+--S 267 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^6
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      4
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 267
+
+--S 268 of 3139
+r0:=-1/3*A*b/x^3+(-b*B-A*c)/x+B*c*x
+--R 
+--R
+--R             4                 2   1
+--R        B c x  + (- A c - B b)x  - - A b
+--R                                   3
+--R   (2)  --------------------------------
+--R                        3
+--R                       x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 268
+
+--S 269 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4                   2
+--R        3B c x  + (- 3A c - 3B b)x  - A b
+--R   (3)  ---------------------------------
+--R                         3
+--R                       3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 269
+
+--S 270 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+--S 271 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 271
+
+)clear all
+
+--S 272 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^7
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      5
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 272
+
+--S 273 of 3139
+r0:=-1/4*A*b/x^4+1/2*(-b*B-A*c)/x^2+B*c*log(x)
+--R 
+--R
+--R              4                         2
+--R        4B c x log(x) + (- 2A c - 2B b)x  - A b
+--R   (2)  ---------------------------------------
+--R                            4
+--R                          4x
+--R                                                    Type: Expression(Integer)
+--E 273
+
+--S 274 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4                         2
+--R        4B c x log(x) + (- 2A c - 2B b)x  - A b
+--R   (3)  ---------------------------------------
+--R                            4
+--R                          4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 274
+
+--S 275 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^8
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      6
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 277
+
+--S 278 of 3139
+r0:=-1/5*A*b/x^5+1/3*(-b*B-A*c)/x^3-B*c/x
+--R 
+--R
+--R               4      1       1      2   1
+--R        - B c x  + (- - A c - - B b)x  - - A b
+--R                      3       3          5
+--R   (2)  --------------------------------------
+--R                           5
+--R                          x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 278
+
+--S 279 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 4                   2
+--R        - 15B c x  + (- 5A c - 5B b)x  - 3A b
+--R   (3)  -------------------------------------
+--R                            5
+--R                         15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 279
+
+--S 280 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 281
+
+)clear all
+
+--S 282 of 3139
+t0:=x^m*(A+B*x^2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R            2 10       2           8                2  6      2 4  m
+--R   (1)  (B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )x
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 3139
+r0:=A*b^2*x^(5+m)/(5+m)+b*(b*B+2*A*c)*x^(7+m)/(7+m)+_
+   c*(2*b*B+A*c)*x^(9+m)/(9+m)+B*c^2*x^(11+m)/(11+m)
+--R 
+--R
+--R   (2)
+--R           2 3        2 2         2          2  m + 11
+--R       (B c m  + 21B c m  + 143B c m + 315B c )x
+--R     + 
+--R               2           3         2            2          2
+--R           (A c  + 2B b c)m  + (23A c  + 46B b c)m  + (167A c  + 334B b c)m
+--R         + 
+--R                 2
+--R           385A c  + 770B b c
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                        2  3                   2  2                     2
+--R           (2A b c + B b )m  + (50A b c + 25B b )m  + (398A b c + 199B b )m
+--R         + 
+--R                            2
+--R           990A b c + 495B b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R           2 3        2 2         2          2  m + 5
+--R       (A b m  + 27A b m  + 239A b m + 693A b )x
+--R  /
+--R      4      3       2
+--R     m  + 32m  + 374m  + 1888m + 3465
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 3        2 2         2          2  11
+--R         (B c m  + 21B c m  + 143B c m + 315B c )x
+--R       + 
+--R                 2           3         2            2          2
+--R             (A c  + 2B b c)m  + (23A c  + 46B b c)m  + (167A c  + 334B b c)m
+--R           + 
+--R                   2
+--R             385A c  + 770B b c
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                          2  3                   2  2                     2
+--R             (2A b c + B b )m  + (50A b c + 25B b )m  + (398A b c + 199B b )m
+--R           + 
+--R                              2
+--R             990A b c + 495B b
+--R        *
+--R            7
+--R           x
+--R       + 
+--R             2 3        2 2         2          2  5
+--R         (A b m  + 27A b m  + 239A b m + 693A b )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      4      3       2
+--R     m  + 32m  + 374m  + 1888m + 3465
+--R                                         Type: Union(Expression(Integer),...)
+--E 284
+
+--S 285 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               2 3        2 2         2          2  11
+--R           (B c m  + 21B c m  + 143B c m + 315B c )x
+--R         + 
+--R                   2           3         2            2          2
+--R               (A c  + 2B b c)m  + (23A c  + 46B b c)m  + (167A c  + 334B b c)m
+--R             + 
+--R                     2
+--R               385A c  + 770B b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                            2  3                   2  2                     2
+--R               (2A b c + B b )m  + (50A b c + 25B b )m  + (398A b c + 199B b )m
+--R             + 
+--R                                2
+--R               990A b c + 495B b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R               2 3        2 2         2          2  5
+--R           (A b m  + 27A b m  + 239A b m + 693A b )x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R             2 3        2 2         2          2  m + 11
+--R       (- B c m  - 21B c m  - 143B c m - 315B c )x
+--R     + 
+--R                 2           3           2            2
+--R           (- A c  - 2B b c)m  + (- 23A c  - 46B b c)m
+--R         + 
+--R                    2                      2
+--R           (- 167A c  - 334B b c)m - 385A c  - 770B b c
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                          2  3                     2  2
+--R           (- 2A b c - B b )m  + (- 50A b c - 25B b )m
+--R         + 
+--R                               2                      2
+--R           (- 398A b c - 199B b )m - 990A b c - 495B b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R             2 3        2 2         2          2  m + 5
+--R       (- A b m  - 27A b m  - 239A b m - 693A b )x
+--R  /
+--R      4      3       2
+--R     m  + 32m  + 374m  + 1888m + 3465
+--R                                                    Type: Expression(Integer)
+--E 285
+
+--S 286 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         2 10       2           8                2  6      2 4   m log(x)
+--R     (B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )%e
+--R   + 
+--R          2 m + 10         2           m + 8                  2  m + 6
+--R     - B c x       + (- A c  - 2B b c)x      + (- 2A b c - B b )x
+--R   + 
+--R          2 m + 4
+--R     - A b x
+--R                                                    Type: Expression(Integer)
+--E 286
+
+)clear all
+
+--S 287 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R           2 10       2           8                2  6      2 4
+--R   (1)  B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R                                                    Type: Polynomial(Integer)
+--E 287
+
+--S 288 of 3139
+r0:=1/5*A*b^2*x^5+1/7*b*(b*B+2*A*c)*x^7+1/9*c*(2*b*B+A*c)*x^9+1/11*B*c^2*x^11
+--R 
+--R
+--R         1    2 11    1    2   2        9    2         1    2  7   1    2 5
+--R   (2)  -- B c x   + (- A c  + - B b c)x  + (- A b c + - B b )x  + - A b x
+--R        11            9        9             7         7           5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 288
+
+--S 289 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1    2 11    1    2   2        9    2         1    2  7   1    2 5
+--R   (3)  -- B c x   + (- A c  + - B b c)x  + (- A b c + - B b )x  + - A b x
+--R        11            9        9             7         7           5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 289
+
+--S 290 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 290
+
+--S 291 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 291
+
+)clear all
+
+--S 292 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x
+--R 
+--R
+--R           2 9       2           7                2  5      2 3
+--R   (1)  B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 292
+
+--S 293 of 3139
+r0:=1/4*A*b^2*x^4+1/6*b*(b*B+2*A*c)*x^6+1/8*c*(2*b*B+A*c)*x^8+1/10*B*c^2*x^10
+--R 
+--R
+--R         1    2 10    1    2   1        8    1         1    2  6   1    2 4
+--R   (2)  -- B c x   + (- A c  + - B b c)x  + (- A b c + - B b )x  + - A b x
+--R        10            8        4             3         6           4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 293
+
+--S 294 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 10         2            8                   2  6        2 4
+--R        12B c x   + (15A c  + 30B b c)x  + (40A b c + 20B b )x  + 30A b x
+--R   (3)  ------------------------------------------------------------------
+--R                                        120
+--R                                         Type: Union(Expression(Integer),...)
+--E 294
+
+--S 295 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 296
+
+)clear all
+
+--S 297 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^2
+--R 
+--R
+--R           2 8       2           6                2  4      2 2
+--R   (1)  B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 297
+
+--S 298 of 3139
+r0:=1/3*A*b^2*x^3+1/5*b*(b*B+2*A*c)*x^5+1/7*c*(2*b*B+A*c)*x^7+1/9*B*c^2*x^9
+--R 
+--R
+--R        1    2 9    1    2   2        7    2         1    2  5   1    2 3
+--R   (2)  - B c x  + (- A c  + - B b c)x  + (- A b c + - B b )x  + - A b x
+--R        9           7        7             5         5           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 298
+
+--S 299 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 9         2            7                    2  5         2 3
+--R        35B c x  + (45A c  + 90B b c)x  + (126A b c + 63B b )x  + 105A b x
+--R   (3)  -------------------------------------------------------------------
+--R                                        315
+--R                                         Type: Union(Expression(Integer),...)
+--E 299
+
+--S 300 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+--S 301 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 301
+
+)clear all
+
+--S 302 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^3
+--R 
+--R
+--R           2 7       2           5                2  3      2
+--R   (1)  B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 302
+
+--S 303 of 3139
+r0:=-1/6*(b*B-A*c)*(b+c*x^2)^3/c^2+1/8*B*(b+c*x^2)^4/c^2
+--R 
+--R
+--R   (2)
+--R       1    4 8    1    4   1      3  6    1      3   1    2 2  4   1    2 2 2
+--R       - B c x  + (- A c  + - B b c )x  + (- A b c  + - B b c )x  + - A b c x
+--R       8           6        3              2          4             2
+--R     + 
+--R       1    3     1    4
+--R       - A b c - -- B b
+--R       6         24
+--R  /
+--R      2
+--R     c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 303
+
+--S 304 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 8        2           6                  2  4        2 2
+--R        3B c x  + (4A c  + 8B b c)x  + (12A b c + 6B b )x  + 12A b x
+--R   (3)  -------------------------------------------------------------
+--R                                      24
+--R                                         Type: Union(Expression(Integer),...)
+--E 304
+
+--S 305 of 3139
+m0:=a0-r0
+--R 
+--R
+--R              3       4
+--R        - 4A b c + B b
+--R   (4)  ---------------
+--R                 2
+--R              24c
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^4
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R   (1)  B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 307
+
+--S 308 of 3139
+r0:=A*b^2*x+1/3*b*(b*B+2*A*c)*x^3+1/5*c*(2*b*B+A*c)*x^5+1/7*B*c^2*x^7
+--R 
+--R
+--R        1    2 7    1    2   2        5    2         1    2  3      2
+--R   (2)  - B c x  + (- A c  + - B b c)x  + (- A b c + - B b )x  + A b x
+--R        7           5        5             3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 308
+
+--S 309 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 7         2            5                   2  3         2
+--R        15B c x  + (21A c  + 42B b c)x  + (70A b c + 35B b )x  + 105A b x
+--R   (3)  -----------------------------------------------------------------
+--R                                       105
+--R                                         Type: Union(Expression(Integer),...)
+--E 309
+
+--S 310 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 311
+
+)clear all
+
+--S 312 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^5
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 312
+
+--S 313 of 3139
+r0:=A*b*c*x^2+1/4*A*c^2*x^4+1/6*B*(b+c*x^2)^3/c+A*b^2*log(x)
+--R 
+--R
+--R   (2)
+--R            2               3 6        3         2  4           2       2   2
+--R       12A b c log(x) + 2B c x  + (3A c  + 6B b c )x  + (12A b c  + 6B b c)x
+--R     + 
+--R           3
+--R       2B b
+--R  /
+--R     12c
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2             2 6        2           4                  2  2
+--R        12A b log(x) + 2B c x  + (3A c  + 6B b c)x  + (12A b c + 6B b )x
+--R   (3)  -----------------------------------------------------------------
+--R                                        12
+--R                                         Type: Union(Expression(Integer),...)
+--E 314
+
+--S 315 of 3139
+m0:=a0-r0
+--R 
+--R
+--R             3
+--R          B b
+--R   (4)  - ----
+--R           6c
+--R                                                    Type: Expression(Integer)
+--E 315
+
+--S 316 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 316
+
+)clear all
+
+--S 317 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^6
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   2
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 317
+
+--S 318 of 3139
+r0:=-A*b^2/x+b*(b*B+2*A*c)*x+1/3*c*(2*b*B+A*c)*x^3+1/5*B*c^2*x^5
+--R 
+--R
+--R            2 6        2            4                   2  2        2
+--R        3B c x  + (5A c  + 10B b c)x  + (30A b c + 15B b )x  - 15A b
+--R   (2)  -------------------------------------------------------------
+--R                                     15x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 318
+
+--S 319 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 6        2            4                   2  2        2
+--R        3B c x  + (5A c  + 10B b c)x  + (30A b c + 15B b )x  - 15A b
+--R   (3)  -------------------------------------------------------------
+--R                                     15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 319
+
+--S 320 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^7
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   3
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 322
+
+--S 323 of 3139
+r0:=-1/2*A*b^2/x^2+1/2*c*(2*b*B+A*c)*x^2+1/4*B*c^2*x^4+b*(b*B+2*A*c)*log(x)
+--R 
+--R
+--R                      2  2            2 6        2           4       2
+--R        (8A b c + 4B b )x log(x) + B c x  + (2A c  + 4B b c)x  - 2A b
+--R   (2)  --------------------------------------------------------------
+--R                                        2
+--R                                      4x
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      2  2            2 6        2           4       2
+--R        (8A b c + 4B b )x log(x) + B c x  + (2A c  + 4B b c)x  - 2A b
+--R   (3)  --------------------------------------------------------------
+--R                                        2
+--R                                      4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 324
+
+--S 325 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 326
+
+)clear all
+
+--S 327 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^8
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   4
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 327
+
+--S 328 of 3139
+r0:=-1/3*A*b^2/x^3-b*(b*B+2*A*c)/x+c*(2*b*B+A*c)*x+1/3*B*c^2*x^3
+--R 
+--R
+--R        1    2 6       2           4                  2  2   1    2
+--R        - B c x  + (A c  + 2B b c)x  + (- 2A b c - B b )x  - - A b
+--R        3                                                    3
+--R   (2)  -----------------------------------------------------------
+--R                                      3
+--R                                     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 328
+
+--S 329 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 6        2           4                   2  2      2
+--R        B c x  + (3A c  + 6B b c)x  + (- 6A b c - 3B b )x  - A b
+--R   (3)  ---------------------------------------------------------
+--R                                     3
+--R                                   3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 329
+
+--S 330 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+--S 331 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 331
+
+)clear all
+
+--S 332 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^9
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   5
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 332
+
+--S 333 of 3139
+r0:=-1/4*A*b^2/x^4-1/2*b*(b*B+2*A*c)/x^2+1/2*B*c^2*x^2+c*(2*b*B+A*c)*log(x)
+--R 
+--R
+--R             2           4             2 6                   2  2      2
+--R        (4A c  + 8B b c)x log(x) + 2B c x  + (- 4A b c - 2B b )x  - A b
+--R   (2)  ----------------------------------------------------------------
+--R                                         4
+--R                                       4x
+--R                                                    Type: Expression(Integer)
+--E 333
+
+--S 334 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2           4             2 6                   2  2      2
+--R        (4A c  + 8B b c)x log(x) + 2B c x  + (- 4A b c - 2B b )x  - A b
+--R   (3)  ----------------------------------------------------------------
+--R                                         4
+--R                                       4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 334
+
+--S 335 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^10
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   6
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 337
+
+--S 338 of 3139
+r0:=-1/5*A*b^2/x^5-1/3*b*(b*B+2*A*c)/x^3-c*(2*b*B+A*c)/x+B*c^2*x
+--R 
+--R
+--R           2 6         2           4      2         1    2  2   1    2
+--R        B c x  + (- A c  - 2B b c)x  + (- - A b c - - B b )x  - - A b
+--R                                          3         3           5
+--R   (2)  --------------------------------------------------------------
+--R                                       5
+--R                                      x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 338
+
+--S 339 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 6           2            4                    2  2       2
+--R        15B c x  + (- 15A c  - 30B b c)x  + (- 10A b c - 5B b )x  - 3A b
+--R   (3)  -----------------------------------------------------------------
+--R                                          5
+--R                                       15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 339
+
+--S 340 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 341
+
+)clear all
+
+--S 342 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^11
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   7
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 342
+
+--S 343 of 3139
+r0:=-1/4*b^2*B/x^4-b*B*c/x^2-1/6*A*(b+c*x^2)^3/(b*x^6)+B*c^2*log(x)
+--R 
+--R
+--R   (2)
+--R              2 6             3 6            2        2   4
+--R       12B b c x log(x) - 2A c x  + (- 6A b c  - 12B b c)x
+--R     + 
+--R              2        3  2       3
+--R       (- 6A b c - 3B b )x  - 2A b
+--R  /
+--R          6
+--R     12b x
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 6                2            4                   2  2       2
+--R        12B c x log(x) + (- 6A c  - 12B b c)x  + (- 6A b c - 3B b )x  - 2A b
+--R   (3)  ---------------------------------------------------------------------
+--R                                            6
+--R                                         12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 344
+
+--S 345 of 3139
+m0:=a0-r0
+--R 
+--R
+--R           3
+--R        A c
+--R   (4)  ----
+--R         6b
+--R                                                    Type: Expression(Integer)
+--E 345
+
+--S 346 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 346
+
+)clear all
+
+--S 347 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^12
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   8
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 347
+
+--S 348 of 3139
+r0:=-1/7*A*b^2/x^7-1/5*b*(b*B+2*A*c)/x^5-1/3*c*(2*b*B+A*c)/x^3-B*c^2/x
+--R 
+--R
+--R             2 6      1    2   2        4      2         1    2  2   1    2
+--R        - B c x  + (- - A c  - - B b c)x  + (- - A b c - - B b )x  - - A b
+--R                      3        3               5         5           7
+--R   (2)  -------------------------------------------------------------------
+--R                                          7
+--R                                         x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 348
+
+--S 349 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2 6           2            4                     2  2        2
+--R        - 105B c x  + (- 35A c  - 70B b c)x  + (- 42A b c - 21B b )x  - 15A b
+--R   (3)  ----------------------------------------------------------------------
+--R                                             7
+--R                                         105x
+--R                                         Type: Union(Expression(Integer),...)
+--E 349
+
+--S 350 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 3139
+t0:=x^m*(A+B*x^2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R          3 14       3         2  12          2       2   10        2       3  8
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x   + (3A b c + B b )x
+--R     + 
+--R          3 6
+--R       A b x
+--R  *
+--R      m
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 3139
+r0:=A*b^3*x^(7+m)/(7+m)+b^2*(b*B+3*A*c)*x^(9+m)/(9+m)+3*b*c*(b*B+A*c)*_
+   x^(11+m)/(11+m)+c^2*(3*b*B+A*c)*x^(13+m)/(13+m)+B*c^3*x^(15+m)/(15+m)
+--R 
+--R
+--R   (2)
+--R           3 4        3 3         3 2          3           3  m + 15
+--R       (B c m  + 40B c m  + 590B c m  + 3800B c m + 9009B c )x
+--R     + 
+--R               3         2  4         3           2  3
+--R           (A c  + 3B b c )m  + (42A c  + 126B b c )m
+--R         + 
+--R                  3            2  2           3             2             3
+--R           (644A c  + 1932B b c )m  + (4278A c  + 12834B b c )m + 10395A c
+--R         + 
+--R                     2
+--R           31185B b c
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                  2       2   4            2         2   3
+--R           (3A b c  + 3B b c)m  + (132A b c  + 132B b c)m
+--R         + 
+--R                     2          2   2              2           2
+--R           (2118A b c  + 2118B b c)m  + (14652A b c  + 14652B b c)m
+--R         + 
+--R                     2           2
+--R           36855A b c  + 36855B b c
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                2       3  4          2         3  3           2          3  2
+--R           (3A b c + B b )m  + (138A b c + 46B b )m  + (2328A b c + 776B b )m
+--R         + 
+--R                    2           3             2            3
+--R           (16998A b c + 5666B b )m + 45045A b c + 15015B b
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R           3 4        3 3         3 2          3            3  m + 7
+--R       (A b m  + 48A b m  + 854A b m  + 6672A b m + 19305A b )x
+--R  /
+--R      5      4        3         2
+--R     m  + 55m  + 1190m  + 12650m  + 66009m + 135135
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3 4        3 3         3 2          3           3  15
+--R         (B c m  + 40B c m  + 590B c m  + 3800B c m + 9009B c )x
+--R       + 
+--R                 3         2  4         3           2  3
+--R             (A c  + 3B b c )m  + (42A c  + 126B b c )m
+--R           + 
+--R                    3            2  2           3             2             3
+--R             (644A c  + 1932B b c )m  + (4278A c  + 12834B b c )m + 10395A c
+--R           + 
+--R                       2
+--R             31185B b c
+--R        *
+--R            13
+--R           x
+--R       + 
+--R                    2       2   4            2         2   3
+--R             (3A b c  + 3B b c)m  + (132A b c  + 132B b c)m
+--R           + 
+--R                       2          2   2              2           2
+--R             (2118A b c  + 2118B b c)m  + (14652A b c  + 14652B b c)m
+--R           + 
+--R                       2           2
+--R             36855A b c  + 36855B b c
+--R        *
+--R            11
+--R           x
+--R       + 
+--R                  2       3  4          2         3  3           2          3  2
+--R             (3A b c + B b )m  + (138A b c + 46B b )m  + (2328A b c + 776B b )m
+--R           + 
+--R                      2           3             2            3
+--R             (16998A b c + 5666B b )m + 45045A b c + 15015B b
+--R        *
+--R            9
+--R           x
+--R       + 
+--R             3 4        3 3         3 2          3            3  7
+--R         (A b m  + 48A b m  + 854A b m  + 6672A b m + 19305A b )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      5      4        3         2
+--R     m  + 55m  + 1190m  + 12650m  + 66009m + 135135
+--R                                         Type: Union(Expression(Integer),...)
+--E 354
+
+--S 355 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               3 4        3 3         3 2          3           3  15
+--R           (B c m  + 40B c m  + 590B c m  + 3800B c m + 9009B c )x
+--R         + 
+--R                   3         2  4         3           2  3
+--R               (A c  + 3B b c )m  + (42A c  + 126B b c )m
+--R             + 
+--R                      3            2  2           3             2             3
+--R               (644A c  + 1932B b c )m  + (4278A c  + 12834B b c )m + 10395A c
+--R             + 
+--R                         2
+--R               31185B b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                      2       2   4            2         2   3
+--R               (3A b c  + 3B b c)m  + (132A b c  + 132B b c)m
+--R             + 
+--R                         2          2   2              2           2
+--R               (2118A b c  + 2118B b c)m  + (14652A b c  + 14652B b c)m
+--R             + 
+--R                         2           2
+--R               36855A b c  + 36855B b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                    2       3  4          2         3  3
+--R               (3A b c + B b )m  + (138A b c + 46B b )m
+--R             + 
+--R                       2          3  2            2           3             2
+--R               (2328A b c + 776B b )m  + (16998A b c + 5666B b )m + 45045A b c
+--R             + 
+--R                       3
+--R               15015B b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R               3 4        3 3         3 2          3            3  7
+--R           (A b m  + 48A b m  + 854A b m  + 6672A b m + 19305A b )x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R             3 4        3 3         3 2          3           3  m + 15
+--R       (- B c m  - 40B c m  - 590B c m  - 3800B c m - 9009B c )x
+--R     + 
+--R                 3         2  4           3           2  3
+--R           (- A c  - 3B b c )m  + (- 42A c  - 126B b c )m
+--R         + 
+--R                    3            2  2             3             2             3
+--R           (- 644A c  - 1932B b c )m  + (- 4278A c  - 12834B b c )m - 10395A c
+--R         + 
+--R                       2
+--R           - 31185B b c
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                    2       2   4              2         2   3
+--R           (- 3A b c  - 3B b c)m  + (- 132A b c  - 132B b c)m
+--R         + 
+--R                       2          2   2                2           2
+--R           (- 2118A b c  - 2118B b c)m  + (- 14652A b c  - 14652B b c)m
+--R         + 
+--R                       2           2
+--R           - 36855A b c  - 36855B b c
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                  2       3  4            2         3  3
+--R           (- 3A b c - B b )m  + (- 138A b c - 46B b )m
+--R         + 
+--R                     2          3  2              2           3             2
+--R           (- 2328A b c - 776B b )m  + (- 16998A b c - 5666B b )m - 45045A b c
+--R         + 
+--R                     3
+--R           - 15015B b
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R             3 4        3 3         3 2          3            3  m + 7
+--R       (- A b m  - 48A b m  - 854A b m  - 6672A b m - 19305A b )x
+--R  /
+--R      5      4        3         2
+--R     m  + 55m  + 1190m  + 12650m  + 66009m + 135135
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            3 14       3         2  12          2       2   10
+--R         B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x
+--R       + 
+--R              2       3  8      3 6
+--R         (3A b c + B b )x  + A b x
+--R    *
+--R         m log(x)
+--R       %e
+--R   + 
+--R          3 m + 14         3         2  m + 12            2       2   m + 10
+--R     - B c x       + (- A c  - 3B b c )x       + (- 3A b c  - 3B b c)x
+--R   + 
+--R            2       3  m + 8      3 m + 6
+--R     (- 3A b c - B b )x      - A b x
+--R                                                    Type: Expression(Integer)
+--E 356
+
+)clear all
+
+--S 357 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^2
+--R 
+--R
+--R   (1)
+--R        3 12       3         2  10          2       2   8        2       3  6
+--R     B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R   + 
+--R        3 4
+--R     A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 357
+
+--S 358 of 3139
+r0:=1/5*A*b^3*x^5+1/7*b^2*(b*B+3*A*c)*x^7+1/3*b*c*(b*B+A*c)*x^9+_
+   1/11*c^2*(3*b*B+A*c)*x^11+1/13*B*c^3*x^13
+--R 
+--R
+--R   (2)
+--R      1    3 13     1    3    3      2  11    1      2   1    2   9
+--R     -- B c x   + (-- A c  + -- B b c )x   + (- A b c  + - B b c)x
+--R     13            11        11               3          3
+--R   + 
+--R      3    2    1    3  7   1    3 5
+--R     (- A b c + - B b )x  + - A b x
+--R      7         7           5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 358
+
+--S 359 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 13           3            2  11             2          2   9
+--R       1155B c x   + (1365A c  + 4095B b c )x   + (5005A b c  + 5005B b c)x
+--R     + 
+--R               2           3  7          3 5
+--R       (6435A b c + 2145B b )x  + 3003A b x
+--R  /
+--R     15015
+--R                                         Type: Union(Expression(Integer),...)
+--E 359
+
+--S 360 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+--S 361 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 361
+
+)clear all
+
+--S 362 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^3
+--R 
+--R
+--R   (1)
+--R        3 11       3         2  9          2       2   7        2       3  5
+--R     B c x   + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R   + 
+--R        3 3
+--R     A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 362
+
+--S 363 of 3139
+r0:=1/8*b*(b*B-A*c)*(b+c*x^2)^4/c^3-1/10*(2*b*B-A*c)*(b+c*x^2)^5/c^3+_
+   1/12*B*(b+c*x^2)^6/c^3
+--R 
+--R
+--R   (2)
+--R        1    6 12     1    6    3      5  10    3      5   3    2 4  8
+--R       -- B c x   + (-- A c  + -- B b c )x   + (- A b c  + - B b c )x
+--R       12            10        10               8          8
+--R     + 
+--R        1    2 4   1    3 3  6   1    3 3 4    1    5     1     6
+--R       (- A b c  + - B b c )x  + - A b c x  - -- A b c + --- B b
+--R        2          6             4            40         120
+--R  /
+--R      3
+--R     c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 363
+
+--S 364 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 12         3          2  10           2        2   8
+--R       10B c x   + (12A c  + 36B b c )x   + (45A b c  + 45B b c)x
+--R     + 
+--R             2         3  6        3 4
+--R       (60A b c + 20B b )x  + 30A b x
+--R  /
+--R     120
+--R                                         Type: Union(Expression(Integer),...)
+--E 364
+
+--S 365 of 3139
+m0:=a0-r0
+--R 
+--R
+--R            5       6
+--R        3A b c - B b
+--R   (4)  -------------
+--R                3
+--R            120c
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^4
+--R 
+--R
+--R   (1)
+--R        3 10       3         2  8          2       2   6        2       3  4
+--R     B c x   + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R   + 
+--R        3 2
+--R     A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 367
+
+--S 368 of 3139
+r0:=1/3*A*b^3*x^3+1/5*b^2*(b*B+3*A*c)*x^5+3/7*b*c*(b*B+A*c)*x^7+_
+   1/9*c^2*(3*b*B+A*c)*x^9+1/11*B*c^3*x^11
+--R 
+--R
+--R   (2)
+--R      1    3 11    1    3   1      2  9    3      2   3    2   7
+--R     -- B c x   + (- A c  + - B b c )x  + (- A b c  + - B b c)x
+--R     11            9        3              7          7
+--R   + 
+--R      3    2    1    3  5   1    3 3
+--R     (- A b c + - B b )x  + - A b x
+--R      5         5           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 368
+
+--S 369 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3 11          3            2  9             2          2   7
+--R       315B c x   + (385A c  + 1155B b c )x  + (1485A b c  + 1485B b c)x
+--R     + 
+--R               2          3  5          3 3
+--R       (2079A b c + 693B b )x  + 1155A b x
+--R  /
+--R     3465
+--R                                         Type: Union(Expression(Integer),...)
+--E 369
+
+--S 370 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 371
+
+)clear all
+
+--S 372 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^5
+--R 
+--R
+--R   (1)
+--R        3 9       3         2  7          2       2   5        2       3  3
+--R     B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R   + 
+--R        3
+--R     A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 372
+
+--S 373 of 3139
+r0:=-1/8*(b*B-A*c)*(b+c*x^2)^4/c^2+1/10*B*(b+c*x^2)^5/c^2
+--R 
+--R
+--R   (2)
+--R        1    5 10    1    5   3      4  8    1      4   1    2 3  6
+--R       -- B c x   + (- A c  + - B b c )x  + (- A b c  + - B b c )x
+--R       10            8        8              2          2
+--R     + 
+--R        3    2 3   1    3 2  4   1    3 2 2   1    4     1    5
+--R       (- A b c  + - B b c )x  + - A b c x  + - A b c - -- B b
+--R        4          4             2            8         40
+--R  /
+--R      2
+--R     c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 373
+
+--S 374 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 10        3          2  8           2        2   6
+--R       4B c x   + (5A c  + 15B b c )x  + (20A b c  + 20B b c)x
+--R     + 
+--R             2         3  4        3 2
+--R       (30A b c + 10B b )x  + 20A b x
+--R  /
+--R     40
+--R                                         Type: Union(Expression(Integer),...)
+--E 374
+
+--S 375 of 3139
+m0:=a0-r0
+--R 
+--R
+--R              4       5
+--R        - 5A b c + B b
+--R   (4)  ---------------
+--R                 2
+--R              40c
+--R                                                    Type: Expression(Integer)
+--E 375
+
+--S 376 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 376
+
+)clear all
+
+--S 377 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^6
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 377
+
+--S 378 of 3139
+r0:=A*b^3*x+1/3*b^2*(b*B+3*A*c)*x^3+3/5*b*c*(b*B+A*c)*x^5+_
+   1/7*c^2*(3*b*B+A*c)*x^7+1/9*B*c^3*x^9
+--R 
+--R
+--R   (2)
+--R     1    3 9    1    3   3      2  7    3      2   3    2   5
+--R     - B c x  + (- A c  + - B b c )x  + (- A b c  + - B b c)x
+--R     9           7        7              5          5
+--R   + 
+--R         2    1    3  3      3
+--R     (A b c + - B b )x  + A b x
+--R              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 378
+
+--S 379 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 9         3           2  7            2         2   5
+--R       35B c x  + (45A c  + 135B b c )x  + (189A b c  + 189B b c)x
+--R     + 
+--R              2          3  3         3
+--R       (315A b c + 105B b )x  + 315A b x
+--R  /
+--R     315
+--R                                         Type: Union(Expression(Integer),...)
+--E 379
+
+--S 380 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^7
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 382
+
+--S 383 of 3139
+r0:=3/2*A*b^2*c*x^2+3/4*A*b*c^2*x^4+1/6*A*c^3*x^6+1/8*B*(b+c*x^2)^4/c+_
+   A*b^3*log(x)
+--R 
+--R
+--R   (2)
+--R            3               4 8        4          3  6           3        2 2  4
+--R       24A b c log(x) + 3B c x  + (4A c  + 12B b c )x  + (18A b c  + 18B b c )x
+--R     + 
+--R             2 2        3   2       4
+--R       (36A b c  + 12B b c)x  + 3B b
+--R  /
+--R     24c
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3             3 8        3          2  6           2        2   4
+--R       24A b log(x) + 3B c x  + (4A c  + 12B b c )x  + (18A b c  + 18B b c)x
+--R     + 
+--R             2         3  2
+--R       (36A b c + 12B b )x
+--R  /
+--R     24
+--R                                         Type: Union(Expression(Integer),...)
+--E 384
+
+--S 385 of 3139
+m0:=a0-r0
+--R 
+--R
+--R             4
+--R          B b
+--R   (4)  - ----
+--R           8c
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 386
+
+)clear all
+
+--S 387 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^8
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          2
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 387
+
+--S 388 of 3139
+r0:=-A*b^3/x+b^2*(b*B+3*A*c)*x+b*c*(b*B+A*c)*x^3+1/5*c^2*(3*b*B+A*c)*x^5+_
+   1/7*B*c^3*x^7
+--R 
+--R
+--R   (2)
+--R           3 8        3          2  6           2        2   4
+--R       5B c x  + (7A c  + 21B b c )x  + (35A b c  + 35B b c)x
+--R     + 
+--R              2         3  2        3
+--R       (105A b c + 35B b )x  - 35A b
+--R  /
+--R     35x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 388
+
+--S 389 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 8        3          2  6           2        2   4
+--R       5B c x  + (7A c  + 21B b c )x  + (35A b c  + 35B b c)x
+--R     + 
+--R              2         3  2        3
+--R       (105A b c + 35B b )x  - 35A b
+--R  /
+--R     35x
+--R                                         Type: Union(Expression(Integer),...)
+--E 389
+
+--S 390 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 390
+
+--S 391 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 391
+
+)clear all
+
+--S 392 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^9
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          3
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 392
+
+--S 393 of 3139
+r0:=-1/2*A*b^3/x^2+3/2*b*c*(b*B+A*c)*x^2+1/4*c^2*(3*b*B+A*c)*x^4+_
+   1/6*B*c^3*x^6+b^2*(b*B+3*A*c)*log(x)
+--R 
+--R
+--R   (2)
+--R             2         3  2             3 8        3         2  6
+--R       (36A b c + 12B b )x log(x) + 2B c x  + (3A c  + 9B b c )x
+--R     + 
+--R               2        2   4       3
+--R       (18A b c  + 18B b c)x  - 6A b
+--R  /
+--R        2
+--R     12x
+--R                                                    Type: Expression(Integer)
+--E 393
+
+--S 394 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2         3  2             3 8        3         2  6
+--R       (36A b c + 12B b )x log(x) + 2B c x  + (3A c  + 9B b c )x
+--R     + 
+--R               2        2   4       3
+--R       (18A b c  + 18B b c)x  - 6A b
+--R  /
+--R        2
+--R     12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 394
+
+--S 395 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^10
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          4
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 397
+
+--S 398 of 3139
+r0:=-1/3*A*b^3/x^3-b^2*(b*B+3*A*c)/x+3*b*c*(b*B+A*c)*x+_
+   1/3*c^2*(3*b*B+A*c)*x^3+1/5*B*c^3*x^5
+--R 
+--R
+--R   (2)
+--R       1    3 8    1    3        2  6          2       2   4
+--R       - B c x  + (- A c  + B b c )x  + (3A b c  + 3B b c)x
+--R       5           3
+--R     + 
+--R              2       3  2   1    3
+--R       (- 3A b c - B b )x  - - A b
+--R                             3
+--R  /
+--R      3
+--R     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 398
+
+--S 399 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 8        3          2  6           2        2   4
+--R       3B c x  + (5A c  + 15B b c )x  + (45A b c  + 45B b c)x
+--R     + 
+--R               2         3  2       3
+--R       (- 45A b c - 15B b )x  - 5A b
+--R  /
+--R        3
+--R     15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 399
+
+--S 400 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 401
+
+)clear all
+
+--S 402 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^11
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          5
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 402
+
+--S 403 of 3139
+r0:=-1/4*A*b^3/x^4-1/2*b^2*(b*B+3*A*c)/x^2+1/2*c^2*(3*b*B+A*c)*x^2+_
+   1/4*B*c^3*x^4+3*b*c*(b*B+A*c)*log(x)
+--R 
+--R
+--R   (2)
+--R               2        2   4            3 8        3         2  6
+--R       (12A b c  + 12B b c)x log(x) + B c x  + (2A c  + 6B b c )x
+--R     + 
+--R              2        3  2      3
+--R       (- 6A b c - 2B b )x  - A b
+--R  /
+--R       4
+--R     4x
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2        2   4            3 8        3         2  6
+--R       (12A b c  + 12B b c)x log(x) + B c x  + (2A c  + 6B b c )x
+--R     + 
+--R              2        3  2      3
+--R       (- 6A b c - 2B b )x  - A b
+--R  /
+--R       4
+--R     4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 404
+
+--S 405 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+--S 406 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 406
+
+)clear all
+
+--S 407 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^12
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          6
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 407
+
+--S 408 of 3139
+r0:=-1/5*A*b^3/x^5-1/3*b^2*(b*B+3*A*c)/x^3-3*b*c*(b*B+A*c)/x+_
+   c^2*(3*b*B+A*c)*x+1/3*B*c^3*x^3
+--R 
+--R
+--R   (2)
+--R       1    3 8       3         2  6            2       2   4
+--R       - B c x  + (A c  + 3B b c )x  + (- 3A b c  - 3B b c)x
+--R       3
+--R     + 
+--R             2    1    3  2   1    3
+--R       (- A b c - - B b )x  - - A b
+--R                  3           5
+--R  /
+--R      5
+--R     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 408
+
+--S 409 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 8         3          2  6             2        2   4
+--R       5B c x  + (15A c  + 45B b c )x  + (- 45A b c  - 45B b c)x
+--R     + 
+--R               2        3  2       3
+--R       (- 15A b c - 5B b )x  - 3A b
+--R  /
+--R        5
+--R     15x
+--R                                         Type: Union(Expression(Integer),...)
+--E 409
+
+--S 410 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^13
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          7
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 412
+
+--S 413 of 3139
+r0:=-1/6*A*b^3/x^6-1/4*b^2*(b*B+3*A*c)/x^4-3/2*b*c*(b*B+A*c)/x^2+_
+   1/2*B*c^3*x^2+c^2*(3*b*B+A*c)*log(x)
+--R 
+--R
+--R   (2)
+--R             3          2  6             3 8             2        2   4
+--R       (12A c  + 36B b c )x log(x) + 6B c x  + (- 18A b c  - 18B b c)x
+--R     + 
+--R              2        3  2       3
+--R       (- 9A b c - 3B b )x  - 2A b
+--R  /
+--R        6
+--R     12x
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3          2  6             3 8             2        2   4
+--R       (12A c  + 36B b c )x log(x) + 6B c x  + (- 18A b c  - 18B b c)x
+--R     + 
+--R              2        3  2       3
+--R       (- 9A b c - 3B b )x  - 2A b
+--R  /
+--R        6
+--R     12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 414
+
+--S 415 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 416
+
+)clear all
+
+--S 417 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^14
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          8
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 417
+
+--S 418 of 3139
+r0:=-1/7*A*b^3/x^7-1/5*b^2*(b*B+3*A*c)/x^5-b*c*(b*B+A*c)/x^3-_
+   c^2*(3*b*B+A*c)/x+B*c^3*x
+--R 
+--R
+--R   (2)
+--R          3 8         3         2  6           2      2   4
+--R       B c x  + (- A c  - 3B b c )x  + (- A b c  - B b c)x
+--R     + 
+--R          3    2    1    3  2   1    3
+--R       (- - A b c - - B b )x  - - A b
+--R          5         5           7
+--R  /
+--R      7
+--R     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 418
+
+--S 419 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 8           3           2  6             2        2   4
+--R       35B c x  + (- 35A c  - 105B b c )x  + (- 35A b c  - 35B b c)x
+--R     + 
+--R               2        3  2       3
+--R       (- 21A b c - 7B b )x  - 5A b
+--R  /
+--R        7
+--R     35x
+--R                                         Type: Union(Expression(Integer),...)
+--E 419
+
+--S 420 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+--S 421 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 421
+
+)clear all
+
+--S 422 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^15
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          9
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 422
+
+--S 423 of 3139
+r0:=-1/6*b^3*B/x^6-3/4*b^2*B*c/x^4-3/2*b*B*c^2/x^2-_
+   1/8*A*(b+c*x^2)^4/(b*x^8)+B*c^3*log(x)
+--R 
+--R
+--R   (2)
+--R              3 8             4 8             3        2 2  6
+--R       24B b c x log(x) - 3A c x  + (- 12A b c  - 36B b c )x
+--R     + 
+--R               2 2        3   4           3        4  2       4
+--R       (- 18A b c  - 18B b c)x  + (- 12A b c - 4B b )x  - 3A b
+--R  /
+--R          8
+--R     24b x
+--R                                                    Type: Expression(Integer)
+--E 423
+
+--S 424 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 8                 3          2  6             2        2   4
+--R       24B c x log(x) + (- 12A c  - 36B b c )x  + (- 18A b c  - 18B b c)x
+--R     + 
+--R               2        3  2       3
+--R       (- 12A b c - 4B b )x  - 3A b
+--R  /
+--R        8
+--R     24x
+--R                                         Type: Union(Expression(Integer),...)
+--E 424
+
+--S 425 of 3139
+m0:=a0-r0
+--R 
+--R
+--R           4
+--R        A c
+--R   (4)  ----
+--R         8b
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^16
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                         10
+--R                                        x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 427
+
+--S 428 of 3139
+r0:=-1/9*A*b^3/x^9-1/7*b^2*(b*B+3*A*c)/x^7-3/5*b*c*(b*B+A*c)/x^5-_
+   1/3*c^2*(3*b*B+A*c)/x^3-B*c^3/x
+--R 
+--R
+--R   (2)
+--R            3 8      1    3        2  6      3      2   3    2   4
+--R       - B c x  + (- - A c  - B b c )x  + (- - A b c  - - B b c)x
+--R                     3                       5          5
+--R     + 
+--R          3    2    1    3  2   1    3
+--R       (- - A b c - - B b )x  - - A b
+--R          7         7           9
+--R  /
+--R      9
+--R     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 428
+
+--S 429 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 8            3           2  6              2         2   4
+--R       - 315B c x  + (- 105A c  - 315B b c )x  + (- 189A b c  - 189B b c)x
+--R     + 
+--R                2         3  2        3
+--R       (- 135A b c - 45B b )x  - 35A b
+--R  /
+--R         9
+--R     315x
+--R                                         Type: Union(Expression(Integer),...)
+--E 429
+
+--S 430 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 431
+
+)clear all
+
+--S 432 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^17
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                         11
+--R                                        x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 432
+
+--S 433 of 3139
+r0:=-1/10*A*(b+c*x^2)^4/(b*x^10)-1/40*(5*b*B-A*c)*(b+c*x^2)^4/(b^2*x^8)
+--R 
+--R
+--R   (2)
+--R         1    5   1      4  10   1    2 3 8      1    2 3   3    3 2  6
+--R       (-- A c  - - B b c )x   - - B b c x  + (- - A b c  - - B b c )x
+--R        40        8              2               4          4
+--R     + 
+--R          1    3 2   1    4   4      3    4    1    5  2    1    5
+--R       (- - A b c  - - B b c)x  + (- - A b c - - B b )x  - -- A b
+--R          2          2               8         8           10
+--R  /
+--R      2 10
+--R     b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 433
+
+--S 434 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 8           3          2  6             2        2   4
+--R       - 20B c x  + (- 10A c  - 30B b c )x  + (- 20A b c  - 20B b c)x
+--R     + 
+--R               2        3  2       3
+--R       (- 15A b c - 5B b )x  - 4A b
+--R  /
+--R        10
+--R     40x
+--R                                         Type: Union(Expression(Integer),...)
+--E 434
+
+--S 435 of 3139
+m0:=a0-r0
+--R 
+--R
+--R             5         4
+--R        - A c  + 5B b c
+--R   (4)  ----------------
+--R                 2
+--R              40b
+--R                                                    Type: Expression(Integer)
+--E 435
+
+--S 436 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 436
+
+)clear all
+
+--S 437 of 3139
+t0:=x^10*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           10      8
+--R        B x   + A x
+--R   (1)  ------------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 437
+
+--S 438 of 3139
+r0:=b^3*(b*B-A*c)*x/c^5-1/3*b^2*(b*B-A*c)*x^3/c^4+1/5*b*(b*B-A*c)*x^5/c^3-_
+   1/7*(b*B-A*c)*x^7/c^2+1/9*B*x^9/c-b^(7/2)*(b*B-A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/c^(11/2)
+--R 
+--R
+--R   (2)
+--R                                      +-+
+--R              3          4  +-+     x\|c
+--R       (315A b c - 315B b )\|b atan(-----)
+--R                                      +-+
+--R                                     \|b
+--R     + 
+--R                4 9         4          3  7             3        2 2  5
+--R           35B c x  + (45A c  - 45B b c )x  + (- 63A b c  + 63B b c )x
+--R         + 
+--R                  2 2         3   3            3          4
+--R           (105A b c  - 105B b c)x  + (- 315A b c + 315B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R         5 +-+
+--R     315c \|c
+--R                                                    Type: Expression(Integer)
+--E 438
+
+--S 439 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                            +---+
+--R                                            |  b       2
+--R                              +---+    2c x |- -  + c x  - b
+--R                3          4  |  b         \|  c                     4 9
+--R         (315A b c - 315B b ) |- - log(---------------------) + 70B c x
+--R                             \|  c               2
+--R                                              c x  + b
+--R       + 
+--R               4          3  7              3         2 2  5
+--R         (90A c  - 90B b c )x  + (- 126A b c  + 126B b c )x
+--R       + 
+--R                2 2         3   3            3          4
+--R         (210A b c  - 210B b c)x  + (- 630A b c + 630B b )x
+--R    /
+--R           5
+--R       630c
+--R     ,
+--R
+--R                                         +-+
+--R                                         |b
+--R                                +-+      |-
+--R                  3          4  |b      \|c          4 9         4          3  7
+--R         (- 315A b c + 315B b ) |- atan(----) + 35B c x  + (45A c  - 45B b c )x
+--R                               \|c        x
+--R       + 
+--R                   3        2 2  5          2 2         3   3
+--R         (- 63A b c  + 63B b c )x  + (105A b c  - 105B b c)x
+--R       + 
+--R                  3          4
+--R         (- 315A b c + 315B b )x
+--R    /
+--R           5
+--R       315c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 439
+
+--S 440 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                        +---+
+--R                                        |  b       2
+--R                      +---+        2c x |- -  + c x  - b
+--R           3       4  |  b  +-+        \|  c
+--R       (A b c - B b ) |- - \|c log(---------------------)
+--R                     \|  c                   2
+--R                                          c x  + b
+--R     + 
+--R                                    +-+
+--R              3        4  +-+     x\|c
+--R       (- 2A b c + 2B b )\|b atan(-----)
+--R                                    +-+
+--R                                   \|b
+--R  /
+--R       5 +-+
+--R     2c \|c
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                        +-+
+--R                                                                        |b
+--R                                   +-+                     +-+          |-
+--R              3       4  +-+     x\|c           3       4  |b  +-+     \|c
+--R        (- A b c + B b )\|b atan(-----) + (- A b c + B b ) |- \|c atan(----)
+--R                                   +-+                    \|c            x
+--R                                  \|b
+--R   (6)  --------------------------------------------------------------------
+--R                                        5 +-+
+--R                                       c \|c
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 443
+
+)clear all
+
+--S 444 of 3139
+t0:=x^9*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           9      7
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 444
+
+--S 445 of 3139
+r0:=-1/2*b^2*(b*B-A*c)*x^2/c^4+1/4*b*(b*B-A*c)*x^4/c^3-_
+   1/6*(b*B-A*c)*x^6/c^2+1/8*B*x^8/c+1/2*b^3*(b*B-A*c)*log(b+c*x^2)/c^5
+--R 
+--R
+--R   (2)
+--R               3         4        2            4 8        4         3  6
+--R       (- 12A b c + 12B b )log(c x  + b) + 3B c x  + (4A c  - 4B b c )x
+--R     + 
+--R                3       2 2  4         2 2        3   2
+--R       (- 6A b c  + 6B b c )x  + (12A b c  - 12B b c)x
+--R  /
+--R        5
+--R     24c
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3         4        2            4 8        4         3  6
+--R       (- 12A b c + 12B b )log(c x  + b) + 3B c x  + (4A c  - 4B b c )x
+--R     + 
+--R                3       2 2  4         2 2        3   2
+--R       (- 6A b c  + 6B b c )x  + (12A b c  - 12B b c)x
+--R  /
+--R        5
+--R     24c
+--R                                         Type: Union(Expression(Integer),...)
+--E 446
+
+--S 447 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 448
+
+)clear all
+
+--S 449 of 3139
+t0:=x^8*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           8      6
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 449
+
+--S 450 of 3139
+r0:=-b^2*(b*B-A*c)*x/c^4+1/3*b*(b*B-A*c)*x^3/c^3-1/5*(b*B-A*c)*x^5/c^2+_
+   1/7*B*x^7/c+b^(5/2)*(b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/c^(9/2)
+--R 
+--R
+--R   (2)
+--R                                        +-+
+--R                2          3  +-+     x\|c
+--R       (- 105A b c + 105B b )\|b atan(-----)
+--R                                        +-+
+--R                                       \|b
+--R     + 
+--R                3 7         3          2  5             2        2   3
+--R           15B c x  + (21A c  - 21B b c )x  + (- 35A b c  + 35B b c)x
+--R         + 
+--R                  2          3
+--R           (105A b c - 105B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R         4 +-+
+--R     105c \|c
+--R                                                    Type: Expression(Integer)
+--E 450
+
+--S 451 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                              +---+
+--R                                              |  b       2
+--R                              +---+    - 2c x |- -  + c x  - b
+--R                2          3  |  b           \|  c                     3 7
+--R         (105A b c - 105B b ) |- - log(-----------------------) + 30B c x
+--R                             \|  c                2
+--R                                               c x  + b
+--R       + 
+--R             3          2  5             2        2   3          2          3
+--R       (42A c  - 42B b c )x  + (- 70A b c  + 70B b c)x  + (210A b c - 210B b )x
+--R    /
+--R           4
+--R       210c
+--R     ,
+--R
+--R                                       +-+
+--R                                       |b
+--R                              +-+      |-
+--R                2          3  |b      \|c          3 7         3          2  5
+--R         (105A b c - 105B b ) |- atan(----) + 15B c x  + (21A c  - 21B b c )x
+--R                             \|c        x
+--R       + 
+--R                   2        2   3          2          3
+--R         (- 35A b c  + 35B b c)x  + (105A b c - 105B b )x
+--R    /
+--R           4
+--R       105c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 451
+
+--S 452 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                          +---+
+--R                                          |  b       2
+--R                      +---+        - 2c x |- -  + c x  - b
+--R           2       3  |  b  +-+          \|  c
+--R       (A b c - B b ) |- - \|c log(-----------------------)
+--R                     \|  c                    2
+--R                                           c x  + b
+--R     + 
+--R                                  +-+
+--R            2        3  +-+     x\|c
+--R       (2A b c - 2B b )\|b atan(-----)
+--R                                  +-+
+--R                                 \|b
+--R  /
+--R       4 +-+
+--R     2c \|c
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+--S 454 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                    +-+
+--R                                                                    |b
+--R                                 +-+                   +-+          |-
+--R            2       3  +-+     x\|c         2       3  |b  +-+     \|c
+--R        (A b c - B b )\|b atan(-----) + (A b c - B b ) |- \|c atan(----)
+--R                                 +-+                  \|c            x
+--R                                \|b
+--R   (6)  ----------------------------------------------------------------
+--R                                      4 +-+
+--R                                     c \|c
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 455
+
+)clear all
+
+--S 456 of 3139
+t0:=x^7*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           7      5
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 456
+
+--S 457 of 3139
+r0:=1/2*b*(b*B-A*c)*x^2/c^3-1/4*(b*B-A*c)*x^4/c^2+1/6*B*x^6/c-_
+   1/2*b^2*(b*B-A*c)*log(b+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R            2        3        2            3 6        3         2  4
+--R       (6A b c - 6B b )log(c x  + b) + 2B c x  + (3A c  - 3B b c )x
+--R     + 
+--R                2       2   2
+--R       (- 6A b c  + 6B b c)x
+--R  /
+--R        4
+--R     12c
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2        3        2            3 6        3         2  4
+--R       (6A b c - 6B b )log(c x  + b) + 2B c x  + (3A c  - 3B b c )x
+--R     + 
+--R                2       2   2
+--R       (- 6A b c  + 6B b c)x
+--R  /
+--R        4
+--R     12c
+--R                                         Type: Union(Expression(Integer),...)
+--E 458
+
+--S 459 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 460
+
+)clear all
+
+--S 461 of 3139
+t0:=x^6*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           6      4
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 461
+
+--S 462 of 3139
+r0:=b*(b*B-A*c)*x/c^3-1/3*(b*B-A*c)*x^3/c^2+1/5*B*x^5/c-_
+   b^(3/2)*(b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/c^(7/2)
+--R 
+--R
+--R   (2)
+--R                                    +-+
+--R                       2  +-+     x\|c
+--R       (15A b c - 15B b )\|b atan(-----)
+--R                                    +-+
+--R                                   \|b
+--R     + 
+--R            2 5        2           3                     2    +-+
+--R       (3B c x  + (5A c  - 5B b c)x  + (- 15A b c + 15B b )x)\|c
+--R  /
+--R        3 +-+
+--R     15c \|c
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                          +---+
+--R                                          |  b       2
+--R                            +---+    2c x |- -  + c x  - b
+--R                         2  |  b         \|  c                    2 5
+--R         (15A b c - 15B b ) |- - log(---------------------) + 6B c x
+--R                           \|  c               2
+--R                                            c x  + b
+--R       + 
+--R               2            3                     2
+--R         (10A c  - 10B b c)x  + (- 30A b c + 30B b )x
+--R    /
+--R          3
+--R       30c
+--R     ,
+--R
+--R                                       +-+
+--R                                       |b
+--R                              +-+      |-
+--R                           2  |b      \|c         2 5        2           3
+--R         (- 15A b c + 15B b ) |- atan(----) + 3B c x  + (5A c  - 5B b c)x
+--R                             \|c        x
+--R       + 
+--R                           2
+--R         (- 15A b c + 15B b )x
+--R    /
+--R          3
+--R       15c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 463
+
+--S 464 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                        +---+
+--R                                        |  b       2
+--R                      +---+        2c x |- -  + c x  - b
+--R                   2  |  b  +-+        \|  c
+--R       (A b c - B b ) |- - \|c log(---------------------)
+--R                     \|  c                   2
+--R                                          c x  + b
+--R     + 
+--R                                    +-+
+--R                       2  +-+     x\|c
+--R       (- 2A b c + 2B b )\|b atan(-----)
+--R                                    +-+
+--R                                   \|b
+--R  /
+--R       3 +-+
+--R     2c \|c
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                        +-+
+--R                                                                        |b
+--R                                   +-+                     +-+          |-
+--R                      2  +-+     x\|c                   2  |b  +-+     \|c
+--R        (- A b c + B b )\|b atan(-----) + (- A b c + B b ) |- \|c atan(----)
+--R                                   +-+                    \|c            x
+--R                                  \|b
+--R   (6)  --------------------------------------------------------------------
+--R                                        3 +-+
+--R                                       c \|c
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 467
+
+)clear all
+
+--S 468 of 3139
+t0:=x^5*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           5      3
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 468
+
+--S 469 of 3139
+r0:=-1/2*(b*B-A*c)*x^2/c^2+1/4*B*x^4/c+1/2*b*(b*B-A*c)*log(b+c*x^2)/c^3
+--R 
+--R
+--R                        2        2           2 4        2           2
+--R        (- 2A b c + 2B b )log(c x  + b) + B c x  + (2A c  - 2B b c)x
+--R   (2)  -------------------------------------------------------------
+--R                                       3
+--R                                     4c
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        2        2           2 4        2           2
+--R        (- 2A b c + 2B b )log(c x  + b) + B c x  + (2A c  - 2B b c)x
+--R   (3)  -------------------------------------------------------------
+--R                                       3
+--R                                     4c
+--R                                         Type: Union(Expression(Integer),...)
+--E 470
+
+--S 471 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 472
+
+)clear all
+
+--S 473 of 3139
+t0:=x^4*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           4      2
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 473
+
+--S 474 of 3139
+r0:=-(b*B-A*c)*x/c^2+1/3*B*x^3/c+(b*B-A*c)*atan(x*sqrt(c)/sqrt(b))*_
+   sqrt(b)/c^(5/2)
+--R 
+--R
+--R                                  +-+
+--R                        +-+     x\|c           3                   +-+
+--R        (- 3A c + 3B b)\|b atan(-----) + (B c x  + (3A c - 3B b)x)\|c
+--R                                  +-+
+--R                                 \|b
+--R   (2)  --------------------------------------------------------------
+--R                                      2 +-+
+--R                                    3c \|c
+--R                                                    Type: Expression(Integer)
+--E 474
+
+--S 475 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                  +---+
+--R                                  |  b       2
+--R                  +---+    - 2c x |- -  + c x  - b
+--R                  |  b           \|  c                      3
+--R    (3A c - 3B b) |- - log(-----------------------) + 2B c x  + (6A c - 6B b)x
+--R                 \|  c                2
+--R                                   c x  + b
+--R   [--------------------------------------------------------------------------,
+--R                                          2
+--R                                        6c
+--R                           +-+
+--R                           |b
+--R                  +-+      |-
+--R                  |b      \|c          3
+--R    (3A c - 3B b) |- atan(----) + B c x  + (3A c - 3B b)x
+--R                 \|c        x
+--R    -----------------------------------------------------]
+--R                               2
+--R                             3c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 475
+
+--S 476 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                       +---+
+--R                                       |  b       2
+--R                   +---+        - 2c x |- -  + c x  - b
+--R                   |  b  +-+          \|  c
+--R       (A c - B b) |- - \|c log(-----------------------)
+--R                  \|  c                    2
+--R                                        c x  + b
+--R     + 
+--R                               +-+
+--R                     +-+     x\|c
+--R       (2A c - 2B b)\|b atan(-----)
+--R                               +-+
+--R                              \|b
+--R  /
+--R       2 +-+
+--R     2c \|c
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                              +-+
+--R                                                              |b
+--R                              +-+                +-+          |-
+--R                    +-+     x\|c                 |b  +-+     \|c
+--R        (A c - B b)\|b atan(-----) + (A c - B b) |- \|c atan(----)
+--R                              +-+               \|c            x
+--R                             \|b
+--R   (6)  ----------------------------------------------------------
+--R                                   2 +-+
+--R                                  c \|c
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 479
+
+)clear all
+
+--S 480 of 3139
+t0:=x^3*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           3
+--R        B x  + A x
+--R   (1)  ----------
+--R            2
+--R         c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 480
+
+--S 481 of 3139
+r0:=1/2*B*x^2/c-1/2*(b*B-A*c)*log(b+c*x^2)/c^2
+--R 
+--R
+--R                          2             2
+--R        (A c - B b)log(c x  + b) + B c x
+--R   (2)  ---------------------------------
+--R                         2
+--R                       2c
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          2             2
+--R        (A c - B b)log(c x  + b) + B c x
+--R   (3)  ---------------------------------
+--R                         2
+--R                       2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 482
+
+--S 483 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 484
+
+)clear all
+
+--S 485 of 3139
+t0:=x^2*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           2
+--R        B x  + A
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 485
+
+--S 486 of 3139
+r0:=B*x/c-(b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/(c^(3/2)*sqrt(b))
+--R 
+--R
+--R                          +-+
+--R                        x\|c         +-+ +-+
+--R        (A c - B b)atan(-----) + B x\|b \|c
+--R                          +-+
+--R                         \|b
+--R   (2)  ------------------------------------
+--R                        +-+ +-+
+--R                      c\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       2      +-----+
+--R                   (c x  - b)\|- b c  + 2b c x         +-----+
+--R    (A c - B b)log(---------------------------) + 2B x\|- b c
+--R                                2
+--R                             c x  + b
+--R   [----------------------------------------------------------,
+--R                               +-----+
+--R                            2c\|- b c
+--R                      +---+
+--R                    x\|b c         +---+
+--R    (A c - B b)atan(-------) + B x\|b c
+--R                       b
+--R    ------------------------------------]
+--R                     +---+
+--R                   c\|b c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 487
+
+--S 488 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                  2      +-----+
+--R                   +-+ +-+    (c x  - b)\|- b c  + 2b c x
+--R       (A c - B b)\|b \|c log(---------------------------)
+--R                                           2
+--R                                        c x  + b
+--R     + 
+--R                                     +-+
+--R                       +-----+     x\|c
+--R       (- 2A c + 2B b)\|- b c atan(-----)
+--R                                     +-+
+--R                                    \|b
+--R  /
+--R        +-----+ +-+ +-+
+--R     2c\|- b c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                  +---+                              +-+
+--R                    +-+ +-+     x\|b c                   +---+     x\|c
+--R        (A c - B b)\|b \|c atan(-------) + (- A c + B b)\|b c atan(-----)
+--R                                   b                                 +-+
+--R                                                                    \|b
+--R   (6)  -----------------------------------------------------------------
+--R                                   +-+ +-+ +---+
+--R                                 c\|b \|c \|b c
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 491
+
+)clear all
+
+--S 492 of 3139
+t0:=x*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            2
+--R         B x  + A
+--R   (1)  ----------
+--R           3
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 492
+
+--S 493 of 3139
+r0:=A*log(x)/b+1/2*(b*B-A*c)*log(b+c*x^2)/(b*c)
+--R 
+--R
+--R                            2
+--R        (- A c + B b)log(c x  + b) + 2A c log(x)
+--R   (2)  ----------------------------------------
+--R                          2b c
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            2
+--R        (- A c + B b)log(c x  + b) + 2A c log(x)
+--R   (3)  ----------------------------------------
+--R                          2b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 494
+
+--S 495 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+--S 496 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 496
+
+)clear all
+
+--S 497 of 3139
+t0:=(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           4      2
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 497
+
+--S 498 of 3139
+r0:=-A/(b*x)+(b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/(b^(3/2)*sqrt(c))
+--R 
+--R
+--R                              +-+
+--R                            x\|c       +-+ +-+
+--R        (- A c + B b)x atan(-----) - A\|b \|c
+--R                              +-+
+--R                             \|b
+--R   (2)  --------------------------------------
+--R                          +-+ +-+
+--R                      b x\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         2      +-----+
+--R                     (c x  - b)\|- b c  - 2b c x       +-----+
+--R    (A c - B b)x log(---------------------------) - 2A\|- b c
+--R                                  2
+--R                               c x  + b
+--R   [----------------------------------------------------------,
+--R                                +-----+
+--R                           2b x\|- b c
+--R                          +---+
+--R                        x\|b c       +---+
+--R    (- A c + B b)x atan(-------) - A\|b c
+--R                           b
+--R    --------------------------------------]
+--R                       +---+
+--R                   b x\|b c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 499
+
+--S 500 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                  2      +-----+
+--R                   +-+ +-+    (c x  - b)\|- b c  - 2b c x
+--R       (A c - B b)\|b \|c log(---------------------------)
+--R                                           2
+--R                                        c x  + b
+--R     + 
+--R                                   +-+
+--R                     +-----+     x\|c
+--R       (2A c - 2B b)\|- b c atan(-----)
+--R                                   +-+
+--R                                  \|b
+--R  /
+--R        +-----+ +-+ +-+
+--R     2b\|- b c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                    +---+                            +-+
+--R                      +-+ +-+     x\|b c                 +---+     x\|c
+--R        (- A c + B b)\|b \|c atan(-------) + (A c - B b)\|b c atan(-----)
+--R                                     b                               +-+
+--R                                                                    \|b
+--R   (6)  -----------------------------------------------------------------
+--R                                   +-+ +-+ +---+
+--R                                 b\|b \|c \|b c
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 503
+
+)clear all
+
+--S 504 of 3139
+t0:=(A+B*x^2)/(b*x^2-c*x^4)
+--R 
+--R
+--R              2
+--R         - B x  - A
+--R   (1)  -----------
+--R           4      2
+--R        c x  - b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 504
+
+--S 505 of 3139
+r0:=-A/(b*x)+(b*B+A*c)*atanh(x*sqrt(c)/sqrt(b))/(b^(3/2)*sqrt(c))
+--R 
+--R
+--R                             +-+
+--R                           x\|c       +-+ +-+
+--R        (A c + B b)x atanh(-----) - A\|b \|c
+--R                             +-+
+--R                            \|b
+--R   (2)  -------------------------------------
+--R                         +-+ +-+
+--R                     b x\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         2      +---+
+--R                     (c x  + b)\|b c  + 2b c x       +---+
+--R    (A c + B b)x log(-------------------------) - 2A\|b c
+--R                                 2
+--R                              c x  - b
+--R   [------------------------------------------------------,
+--R                               +---+
+--R                          2b x\|b c
+--R                        +-----+
+--R                      x\|- b c       +-----+
+--R    (A c + B b)x atan(---------) - A\|- b c
+--R                          b
+--R    ----------------------------------------]
+--R                       +-----+
+--R                   b x\|- b c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 506
+
+--S 507 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                  2      +---+
+--R                   +-+ +-+    (c x  + b)\|b c  + 2b c x
+--R       (A c + B b)\|b \|c log(-------------------------)
+--R                                          2
+--R                                       c x  - b
+--R     + 
+--R                                    +-+
+--R                       +---+      x\|c
+--R       (- 2A c - 2B b)\|b c atanh(-----)
+--R                                    +-+
+--R                                   \|b
+--R  /
+--R        +-+ +-+ +---+
+--R     2b\|b \|c \|b c
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                     +-+                              +-----+
+--R                      +-----+      x\|c                 +-+ +-+     x\|- b c
+--R        (- A c - B b)\|- b c atanh(-----) + (A c + B b)\|b \|c atan(---------)
+--R                                     +-+                                b
+--R                                    \|b
+--R   (6)  ----------------------------------------------------------------------
+--R                                     +-----+ +-+ +-+
+--R                                   b\|- b c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 3139
+t0:=(A+B*x^2)/(x*(b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           5      3
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 511
+
+--S 512 of 3139
+r0:=-1/2*A/(b*x^2)+(b*B-A*c)*log(x)/b^2-1/2*(b*B-A*c)*log(b+c*x^2)/b^2
+--R 
+--R
+--R                    2       2                        2
+--R        (A c - B b)x log(c x  + b) + (- 2A c + 2B b)x log(x) - A b
+--R   (2)  ----------------------------------------------------------
+--R                                     2 2
+--R                                   2b x
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    2       2                        2
+--R        (A c - B b)x log(c x  + b) + (- 2A c + 2B b)x log(x) - A b
+--R   (3)  ----------------------------------------------------------
+--R                                     2 2
+--R                                   2b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 513
+
+--S 514 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 515
+
+)clear all
+
+--S 516 of 3139
+t0:=(A+B*x^2)/(x^2*(b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           6      4
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 516
+
+--S 517 of 3139
+r0:=-1/3*A/(b*x^3)+(-b*B+A*c)/(b^2*x)-(b*B-A*c)*_
+   atan(x*sqrt(c)/sqrt(b))*sqrt(c)/b^(5/2)
+--R 
+--R
+--R                                  +-+
+--R                      3 +-+     x\|c                    2        +-+
+--R        (3A c - 3B b)x \|c atan(-----) + ((3A c - 3B b)x  - A b)\|b
+--R                                  +-+
+--R                                 \|b
+--R   (2)  ------------------------------------------------------------
+--R                                    2 3 +-+
+--R                                  3b x \|b
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                  +---+
+--R                                  |  c       2
+--R                    +---+    2b x |- -  + c x  - b
+--R                  3 |  c         \|  b                              2
+--R    (3A c - 3B b)x  |- - log(---------------------) + (6A c - 6B b)x  - 2A b
+--R                   \|  b               2
+--R                                    c x  + b
+--R   [------------------------------------------------------------------------,
+--R                                        2 3
+--R                                      6b x
+--R                                +-+
+--R                                |c
+--R                      +-+     b |-
+--R                    3 |c       \|b                   2
+--R    (- 3A c + 3B b)x  |- atan(-----) + (3A c - 3B b)x  - A b
+--R                     \|b       c x
+--R    --------------------------------------------------------]
+--R                                2 3
+--R                              3b x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 518
+
+--S 519 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                     +---+
+--R                                     |  c       2
+--R                   +---+        2b x |- -  + c x  - b
+--R                   |  c  +-+        \|  b
+--R       (A c - B b) |- - \|b log(---------------------)
+--R                  \|  b                   2
+--R                                       c x  + b
+--R     + 
+--R                                 +-+
+--R                       +-+     x\|c
+--R       (- 2A c + 2B b)\|c atan(-----)
+--R                                 +-+
+--R                                \|b
+--R  /
+--R       2 +-+
+--R     2b \|b
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                   +-+
+--R                                                                   |c
+--R                                +-+                      +-+     b |-
+--R                      +-+     x\|c                   +-+ |c       \|b
+--R        (- A c + B b)\|c atan(-----) + (- A c + B b)\|b  |- atan(-----)
+--R                                +-+                     \|b       c x
+--R                               \|b
+--R   (6)  ---------------------------------------------------------------
+--R                                      2 +-+
+--R                                     b \|b
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 3139
+t0:=(A+B*x^2)/(x^3*(b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           7      5
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 523
+
+--S 524 of 3139
+r0:=-1/4*A/(b*x^4)+1/2*(-b*B+A*c)/(b^2*x^2)-c*(b*B-A*c)*log(x)/b^3+_
+   1/2*c*(b*B-A*c)*log(b+c*x^2)/b^3
+--R 
+--R
+--R   (2)
+--R              2           4       2             2           4
+--R       (- 2A c  + 2B b c)x log(c x  + b) + (4A c  - 4B b c)x log(x)
+--R     + 
+--R                     2  2      2
+--R       (2A b c - 2B b )x  - A b
+--R  /
+--R       3 4
+--R     4b x
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2           4       2             2           4
+--R       (- 2A c  + 2B b c)x log(c x  + b) + (4A c  - 4B b c)x log(x)
+--R     + 
+--R                     2  2      2
+--R       (2A b c - 2B b )x  - A b
+--R  /
+--R       3 4
+--R     4b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 525
+
+--S 526 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 527
+
+)clear all
+
+--S 528 of 3139
+t0:=(A+B*x^2)/(x^4*(b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           8      6
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 528
+
+--S 529 of 3139
+r0:=-1/5*A/(b*x^5)+1/3*(-b*B+A*c)/(b^2*x^3)+c*(b*B-A*c)/(b^3*x)+c^(3/2)*_
+   (b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/b^(7/2)
+--R 
+--R
+--R   (2)
+--R                                        +-+
+--R               2            5 +-+     x\|c
+--R       (- 15A c  + 15B b c)x \|c atan(-----)
+--R                                        +-+
+--R                                       \|b
+--R     + 
+--R                2            4                 2  2       2  +-+
+--R       ((- 15A c  + 15B b c)x  + (5A b c - 5B b )x  - 3A b )\|b
+--R  /
+--R        3 5 +-+
+--R     15b x \|b
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                              +---+
+--R                                              |  c       2
+--R                              +---+    - 2b x |- -  + c x  - b
+--R               2            5 |  c           \|  b
+--R         (15A c  - 15B b c)x  |- - log(-----------------------)
+--R                             \|  b                2
+--R                                               c x  + b
+--R       + 
+--R                 2            4                   2  2       2
+--R         (- 30A c  + 30B b c)x  + (10A b c - 10B b )x  - 6A b
+--R    /
+--R          3 5
+--R       30b x
+--R     ,
+--R
+--R                                        +-+
+--R                                        |c
+--R                              +-+     b |-
+--R               2            5 |c       \|b             2            4
+--R         (15A c  - 15B b c)x  |- atan(-----) + (- 15A c  + 15B b c)x
+--R                             \|b       c x
+--R       + 
+--R                       2  2       2
+--R         (5A b c - 5B b )x  - 3A b
+--R    /
+--R          3 5
+--R       15b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 530
+
+--S 531 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                          +---+
+--R                                          |  c       2
+--R                      +---+        - 2b x |- -  + c x  - b
+--R           2          |  c  +-+          \|  b
+--R       (A c  - B b c) |- - \|b log(-----------------------)
+--R                     \|  b                    2
+--R                                           c x  + b
+--R     + 
+--R                                  +-+
+--R            2           +-+     x\|c
+--R       (2A c  - 2B b c)\|c atan(-----)
+--R                                  +-+
+--R                                 \|b
+--R  /
+--R       3 +-+
+--R     2b \|b
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                     +-+
+--R                                                                     |c
+--R                                 +-+                       +-+     b |-
+--R            2          +-+     x\|c         2          +-+ |c       \|b
+--R        (A c  - B b c)\|c atan(-----) + (A c  - B b c)\|b  |- atan(-----)
+--R                                 +-+                      \|b       c x
+--R                                \|b
+--R   (6)  -----------------------------------------------------------------
+--R                                       3 +-+
+--R                                      b \|b
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 534
+
+)clear all
+
+--S 535 of 3139
+t0:=(A+B*x^2)/(x^5*(b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           9      7
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 535
+
+--S 536 of 3139
+r0:=-1/6*A/(b*x^6)+1/4*(-b*B+A*c)/(b^2*x^4)+1/2*c*(b*B-A*c)/(b^3*x^2)+_
+   c^2*(b*B-A*c)*log(x)/b^4-1/2*c^2*(b*B-A*c)*log(b+c*x^2)/b^4
+--R 
+--R
+--R   (2)
+--R            3         2  6       2                3          2  6
+--R       (6A c  - 6B b c )x log(c x  + b) + (- 12A c  + 12B b c )x log(x)
+--R     + 
+--R                2       2   4        2        3  2       3
+--R       (- 6A b c  + 6B b c)x  + (3A b c - 3B b )x  - 2A b
+--R  /
+--R        4 6
+--R     12b x
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3         2  6       2                3          2  6
+--R       (6A c  - 6B b c )x log(c x  + b) + (- 12A c  + 12B b c )x log(x)
+--R     + 
+--R                2       2   4        2        3  2       3
+--R       (- 6A b c  + 6B b c)x  + (3A b c - 3B b )x  - 2A b
+--R  /
+--R        4 6
+--R     12b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 537
+
+--S 538 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 539
+
+)clear all
+
+--S 540 of 3139
+t0:=x^12*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               10      8
+--R            B x   + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 540
+
+--S 541 of 3139
+r0:=-1/2*b^2*(9*b*B-7*A*c)*x/c^5+1/6*b*(9*b*B-7*A*c)*x^3/c^4-_
+   1/10*(9*b*B-7*A*c)*x^5/c^3+1/14*(9*b*B-7*A*c)*x^7/(b*c^2)-_
+   1/2*(b*B-A*c)*x^9/(b*c*(b+c*x^2))+1/2*b^(5/2)*(9*b*B-7*A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/c^(11/2)
+--R 
+--R
+--R   (2)
+--R                                                                   +-+
+--R                 2 2         3   2         3          4  +-+     x\|c
+--R       ((- 735A b c  + 945B b c)x  - 735A b c + 945B b )\|b atan(-----)
+--R                                                                   +-+
+--R                                                                  \|b
+--R     + 
+--R                4 9         4          3  7             3         2 2  5
+--R           30B c x  + (42A c  - 54B b c )x  + (- 98A b c  + 126B b c )x
+--R         + 
+--R                  2 2         3   3          3          4
+--R           (490A b c  - 630B b c)x  + (735A b c - 945B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R          6 2         5  +-+
+--R     (210c x  + 210b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                           +---+
+--R                   2 2         3   2         3          4  |  b
+--R           ((735A b c  - 945B b c)x  + 735A b c - 945B b ) |- -
+--R                                                          \|  c
+--R        *
+--R                      +---+
+--R                      |  b       2
+--R               - 2c x |- -  + c x  - b
+--R                     \|  c
+--R           log(-----------------------)
+--R                          2
+--R                       c x  + b
+--R       + 
+--R              4 9         4           3  7              3         2 2  5
+--R         60B c x  + (84A c  - 108B b c )x  + (- 196A b c  + 252B b c )x
+--R       + 
+--R                2 2          3   3           3           4
+--R         (980A b c  - 1260B b c)x  + (1470A b c - 1890B b )x
+--R    /
+--R           6 2         5
+--R       420c x  + 420b c
+--R     ,
+--R
+--R                                                                  +-+
+--R                                                                  |b
+--R                                                         +-+      |-
+--R                 2 2         3   2         3          4  |b      \|c
+--R         ((735A b c  - 945B b c)x  + 735A b c - 945B b ) |- atan(----)
+--R                                                        \|c        x
+--R       + 
+--R              4 9         4          3  7             3         2 2  5
+--R         30B c x  + (42A c  - 54B b c )x  + (- 98A b c  + 126B b c )x
+--R       + 
+--R                2 2         3   3          3          4
+--R         (490A b c  - 630B b c)x  + (735A b c - 945B b )x
+--R    /
+--R           6 2         5
+--R       210c x  + 210b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 542
+
+--S 543 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                            +---+
+--R                                            |  b       2
+--R                        +---+        - 2c x |- -  + c x  - b
+--R            2        3  |  b  +-+          \|  c
+--R       (7A b c - 9B b ) |- - \|c log(-----------------------)
+--R                       \|  c                    2
+--R                                             c x  + b
+--R     + 
+--R                                    +-+
+--R             2         3  +-+     x\|c
+--R       (14A b c - 18B b )\|b atan(-----)
+--R                                    +-+
+--R                                   \|b
+--R  /
+--R       5 +-+
+--R     4c \|c
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                        +-+
+--R                                                                        |b
+--R                                   +-+                     +-+          |-
+--R             2        3  +-+     x\|c          2        3  |b  +-+     \|c
+--R        (7A b c - 9B b )\|b atan(-----) + (7A b c - 9B b ) |- \|c atan(----)
+--R                                   +-+                    \|c            x
+--R                                  \|b
+--R   (6)  --------------------------------------------------------------------
+--R                                         5 +-+
+--R                                       2c \|c
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 546
+
+)clear all
+
+--S 547 of 3139
+t0:=x^11*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               9      7
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 547
+
+--S 548 of 3139
+r0:=1/2*b*(3*b*B-2*A*c)*x^2/c^4-1/4*(2*b*B-A*c)*x^4/c^3+1/6*B*x^6/c^2-_
+   1/2*b^3*(b*B-A*c)/(c^5*(b+c*x^2))-1/2*b^2*(4*b*B-3*A*c)*log(b+c*x^2)/c^5
+--R 
+--R
+--R   (2)
+--R              2 2        3   2        3         4        2            4 8
+--R       ((18A b c  - 24B b c)x  + 18A b c - 24B b )log(c x  + b) + 2B c x
+--R     + 
+--R            4         3  6            3        2 2  4           2 2        3   2
+--R       (3A c  - 4B b c )x  + (- 9A b c  + 12B b c )x  + (- 12A b c  + 18B b c)x
+--R     + 
+--R           3        4
+--R       6A b c - 6B b
+--R  /
+--R        6 2        5
+--R     12c x  + 12b c
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 2        3   2        3         4        2            4 8
+--R       ((18A b c  - 24B b c)x  + 18A b c - 24B b )log(c x  + b) + 2B c x
+--R     + 
+--R            4         3  6            3        2 2  4           2 2        3   2
+--R       (3A c  - 4B b c )x  + (- 9A b c  + 12B b c )x  + (- 12A b c  + 18B b c)x
+--R     + 
+--R           3        4
+--R       6A b c - 6B b
+--R  /
+--R        6 2        5
+--R     12c x  + 12b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 549
+
+--S 550 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 551
+
+)clear all
+
+--S 552 of 3139
+t0:=x^10*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               8      6
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 552
+
+--S 553 of 3139
+r0:=1/2*b*(7*b*B-5*A*c)*x/c^4-1/6*(7*b*B-5*A*c)*x^3/c^3+1/10*(7*b*B-5*A*c)*_
+   x^5/(b*c^2)-1/2*(b*B-A*c)*x^7/(b*c*(b+c*x^2))-1/2*b^(3/2)*(7*b*B-5*A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/c^(9/2)
+--R 
+--R
+--R   (2)
+--R                                                               +-+
+--R                2         2   2        2          3  +-+     x\|c
+--R       ((75A b c  - 105B b c)x  + 75A b c - 105B b )\|b atan(-----)
+--R                                                               +-+
+--R                                                              \|b
+--R     + 
+--R               3 7         3          2  5             2        2   3
+--R           6B c x  + (10A c  - 14B b c )x  + (- 50A b c  + 70B b c)x
+--R         + 
+--R                   2          3
+--R           (- 75A b c + 105B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R         5 2        4  +-+
+--R     (30c x  + 30b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                         +---+
+--R                    2         2   2        2          3  |  b
+--R           ((75A b c  - 105B b c)x  + 75A b c - 105B b ) |- -
+--R                                                        \|  c
+--R        *
+--R                    +---+
+--R                    |  b       2
+--R               2c x |- -  + c x  - b
+--R                   \|  c
+--R           log(---------------------)
+--R                         2
+--R                      c x  + b
+--R       + 
+--R              3 7         3          2  5              2         2   3
+--R         12B c x  + (20A c  - 28B b c )x  + (- 100A b c  + 140B b c)x
+--R       + 
+--R                  2          3
+--R         (- 150A b c + 210B b )x
+--R    /
+--R          5 2        4
+--R       60c x  + 60b c
+--R     ,
+--R
+--R                                                                  +-+
+--R                                                                  |b
+--R                                                         +-+      |-
+--R                    2         2   2        2          3  |b      \|c         3 7
+--R         ((- 75A b c  + 105B b c)x  - 75A b c + 105B b ) |- atan(----) + 6B c x
+--R                                                        \|c        x
+--R       + 
+--R             3          2  5             2        2   3           2          3
+--R       (10A c  - 14B b c )x  + (- 50A b c  + 70B b c)x  + (- 75A b c + 105B b )x
+--R    /
+--R          5 2        4
+--R       30c x  + 30b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 554
+
+--S 555 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                          +---+
+--R                                          |  b       2
+--R                        +---+        2c x |- -  + c x  - b
+--R                     2  |  b  +-+        \|  c
+--R       (5A b c - 7B b ) |- - \|c log(---------------------)
+--R                       \|  c                   2
+--R                                            c x  + b
+--R     + 
+--R                                      +-+
+--R                         2  +-+     x\|c
+--R       (- 10A b c + 14B b )\|b atan(-----)
+--R                                      +-+
+--R                                     \|b
+--R  /
+--R       4 +-+
+--R     4c \|c
+--R                                                    Type: Expression(Integer)
+--E 555
+
+--S 556 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                       +-+
+--R                                                                       |b
+--R                                +-+                       +-+          |-
+--R                   2  +-+     x\|c                     2  |b  +-+     \|c
+--R   (- 5A b c + 7B b )\|b atan(-----) + (- 5A b c + 7B b ) |- \|c atan(----)
+--R                                +-+                      \|c            x
+--R                               \|b
+--R   ------------------------------------------------------------------------
+--R                                      4 +-+
+--R                                    2c \|c
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 558
+
+)clear all
+
+--S 559 of 3139
+t0:=x^9*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               7      5
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 559
+
+--S 560 of 3139
+r0:=-1/2*(2*b*B-A*c)*x^2/c^3+1/4*B*x^4/c^2+1/2*b^2*(b*B-A*c)/_
+   (c^4*(b+c*x^2))+1/2*b*(3*b*B-2*A*c)*log(b+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R                 2       2   2       2        3        2           3 6
+--R       ((- 4A b c  + 6B b c)x  - 4A b c + 6B b )log(c x  + b) + B c x
+--R     + 
+--R            3         2  4          2       2   2       2        3
+--R       (2A c  - 3B b c )x  + (2A b c  - 4B b c)x  - 2A b c + 2B b
+--R  /
+--R       5 2       4
+--R     4c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2       2   2       2        3        2           3 6
+--R       ((- 4A b c  + 6B b c)x  - 4A b c + 6B b )log(c x  + b) + B c x
+--R     + 
+--R            3         2  4          2       2   2       2        3
+--R       (2A c  - 3B b c )x  + (2A b c  - 4B b c)x  - 2A b c + 2B b
+--R  /
+--R       5 2       4
+--R     4c x  + 4b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 561
+
+--S 562 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 563
+
+)clear all
+
+--S 564 of 3139
+t0:=x^8*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               6      4
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 564
+
+--S 565 of 3139
+r0:=-1/2*(5*b*B-3*A*c)*x/c^3+1/6*(5*b*B-3*A*c)*x^3/(b*c^2)-_
+   1/2*(b*B-A*c)*x^5/(b*c*(b+c*x^2))+1/2*(5*b*B-3*A*c)*_
+   atan(x*sqrt(c)/sqrt(b))*sqrt(b)/c^(7/2)
+--R 
+--R
+--R   (2)
+--R                                                           +-+
+--R               2            2                 2  +-+     x\|c
+--R       ((- 9A c  + 15B b c)x  - 9A b c + 15B b )\|b atan(-----)
+--R                                                           +-+
+--R                                                          \|b
+--R     + 
+--R            2 5        2            3                  2    +-+
+--R       (2B c x  + (6A c  - 10B b c)x  + (9A b c - 15B b )x)\|c
+--R  /
+--R        4 2       3  +-+
+--R     (6c x  + 6b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                   +---+
+--R                 2            2                 2  |  b
+--R           ((9A c  - 15B b c)x  + 9A b c - 15B b ) |- -
+--R                                                  \|  c
+--R        *
+--R                      +---+
+--R                      |  b       2
+--R               - 2c x |- -  + c x  - b
+--R                     \|  c
+--R           log(-----------------------)
+--R                          2
+--R                       c x  + b
+--R       + 
+--R             2 5         2            3                   2
+--R         4B c x  + (12A c  - 20B b c)x  + (18A b c - 30B b )x
+--R    /
+--R          4 2        3
+--R       12c x  + 12b c
+--R     ,
+--R
+--R                                                          +-+
+--R                                                          |b
+--R                                                 +-+      |-
+--R               2            2                 2  |b      \|c         2 5
+--R         ((9A c  - 15B b c)x  + 9A b c - 15B b ) |- atan(----) + 2B c x
+--R                                                \|c        x
+--R       + 
+--R              2            3                  2
+--R         (6A c  - 10B b c)x  + (9A b c - 15B b )x
+--R    /
+--R         4 2       3
+--R       6c x  + 6b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 566
+
+--S 567 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                         +---+
+--R                                         |  b       2
+--R                     +---+        - 2c x |- -  + c x  - b
+--R                     |  b  +-+          \|  c
+--R       (3A c - 5B b) |- - \|c log(-----------------------)
+--R                    \|  c                    2
+--R                                          c x  + b
+--R     + 
+--R                                +-+
+--R                      +-+     x\|c
+--R       (6A c - 10B b)\|b atan(-----)
+--R                                +-+
+--R                               \|b
+--R  /
+--R       3 +-+
+--R     4c \|c
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                  +-+
+--R                                                                  |b
+--R                                +-+                  +-+          |-
+--R                      +-+     x\|c                   |b  +-+     \|c
+--R        (3A c - 5B b)\|b atan(-----) + (3A c - 5B b) |- \|c atan(----)
+--R                                +-+                 \|c            x
+--R                               \|b
+--R   (6)  --------------------------------------------------------------
+--R                                      3 +-+
+--R                                    2c \|c
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 3139
+t0:=x^7*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               5      3
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 571
+
+--S 572 of 3139
+r0:=1/2*B*x^2/c^2-1/2*b*(b*B-A*c)/(c^3*(b+c*x^2))-_
+   1/2*(2*b*B-A*c)*log(b+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R            2           2               2        2           2 4          2
+--R       ((A c  - 2B b c)x  + A b c - 2B b )log(c x  + b) + B c x  + B b c x
+--R     + 
+--R                  2
+--R       A b c - B b
+--R  /
+--R       4 2       3
+--R     2c x  + 2b c
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2           2               2        2           2 4          2
+--R       ((A c  - 2B b c)x  + A b c - 2B b )log(c x  + b) + B c x  + B b c x
+--R     + 
+--R                  2
+--R       A b c - B b
+--R  /
+--R       4 2       3
+--R     2c x  + 2b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 573
+
+--S 574 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 575
+
+)clear all
+
+--S 576 of 3139
+t0:=x^6*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               4      2
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 576
+
+--S 577 of 3139
+r0:=1/2*(3*b*B-A*c)*x/(b*c^2)-1/2*(b*B-A*c)*x^3/(b*c*(b+c*x^2))-_
+   1/2*(3*b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/(c^(5/2)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                                                 +-+
+--R            2           2               2      x\|c
+--R       ((A c  - 3B b c)x  + A b c - 3B b )atan(-----)
+--R                                                 +-+
+--R                                                \|b
+--R     + 
+--R              3                    +-+ +-+
+--R       (2B c x  + (- A c + 3B b)x)\|b \|c
+--R  /
+--R        3 2       2  +-+ +-+
+--R     (2c x  + 2b c )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                    2      +-----+
+--R              2           2               2     (c x  - b)\|- b c  + 2b c x
+--R         ((A c  - 3B b c)x  + A b c - 3B b )log(---------------------------)
+--R                                                             2
+--R                                                          c x  + b
+--R       + 
+--R                3                     +-----+
+--R         (4B c x  + (- 2A c + 6B b)x)\|- b c
+--R    /
+--R          3 2       2  +-----+
+--R       (4c x  + 4b c )\|- b c
+--R     ,
+--R
+--R                                                   +---+
+--R              2           2               2      x\|b c
+--R         ((A c  - 3B b c)x  + A b c - 3B b )atan(-------)
+--R                                                    b
+--R       + 
+--R                3                    +---+
+--R         (2B c x  + (- A c + 3B b)x)\|b c
+--R    /
+--R          3 2       2  +---+
+--R       (2c x  + 2b c )\|b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 578
+
+--S 579 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                   2      +-----+
+--R                    +-+ +-+    (c x  - b)\|- b c  + 2b c x
+--R       (A c - 3B b)\|b \|c log(---------------------------)
+--R                                            2
+--R                                         c x  + b
+--R     + 
+--R                                     +-+
+--R                       +-----+     x\|c
+--R       (- 2A c + 6B b)\|- b c atan(-----)
+--R                                     +-+
+--R                                    \|b
+--R  /
+--R       2 +-----+ +-+ +-+
+--R     4c \|- b c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                   +---+                               +-+
+--R                     +-+ +-+     x\|b c                    +---+     x\|c
+--R        (A c - 3B b)\|b \|c atan(-------) + (- A c + 3B b)\|b c atan(-----)
+--R                                    b                                  +-+
+--R                                                                      \|b
+--R   (6)  -------------------------------------------------------------------
+--R                                   2 +-+ +-+ +---+
+--R                                 2c \|b \|c \|b c
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 3139
+t0:=x^5*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                3
+--R             B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 583
+
+--S 584 of 3139
+r0:=1/2*(b*B-A*c)/(c^2*(b+c*x^2))+1/2*B*log(b+c*x^2)/c^2
+--R 
+--R
+--R              2              2
+--R        (B c x  + B b)log(c x  + b) - A c + B b
+--R   (2)  ---------------------------------------
+--R                       3 2       2
+--R                     2c x  + 2b c
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2              2
+--R        (B c x  + B b)log(c x  + b) - A c + B b
+--R   (3)  ---------------------------------------
+--R                       3 2       2
+--R                     2c x  + 2b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 585
+
+--S 586 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 587
+
+)clear all
+
+--S 588 of 3139
+t0:=x^4*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 588
+
+--S 589 of 3139
+r0:=-1/2*(b*B-A*c)*x/(b*c*(b+c*x^2))+1/2*(b*B+A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/(b^(3/2)*c^(3/2))
+--R 
+--R
+--R                                                +-+
+--R             2          2              2      x\|c                  +-+ +-+
+--R        ((A c  + B b c)x  + A b c + B b )atan(-----) + (A c - B b)x\|b \|c
+--R                                                +-+
+--R                                               \|b
+--R   (2)  -------------------------------------------------------------------
+--R                                   2 2     2   +-+ +-+
+--R                              (2b c x  + 2b c)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                  2      +-----+
+--R              2          2              2     (c x  - b)\|- b c  + 2b c x
+--R         ((A c  + B b c)x  + A b c + B b )log(---------------------------)
+--R                                                           2
+--R                                                        c x  + b
+--R       + 
+--R                        +-----+
+--R         (2A c - 2B b)x\|- b c
+--R    /
+--R            2 2     2   +-----+
+--R       (4b c x  + 4b c)\|- b c
+--R     ,
+--R                                            +---+
+--R         2          2              2      x\|b c                  +---+
+--R    ((A c  + B b c)x  + A b c + B b )atan(-------) + (A c - B b)x\|b c
+--R                                             b
+--R    -------------------------------------------------------------------]
+--R                                2 2     2   +---+
+--R                           (2b c x  + 2b c)\|b c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 590
+
+--S 591 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                  2      +-----+
+--R                   +-+ +-+    (c x  - b)\|- b c  + 2b c x
+--R       (A c + B b)\|b \|c log(---------------------------)
+--R                                           2
+--R                                        c x  + b
+--R     + 
+--R                                     +-+
+--R                       +-----+     x\|c
+--R       (- 2A c - 2B b)\|- b c atan(-----)
+--R                                     +-+
+--R                                    \|b
+--R  /
+--R          +-----+ +-+ +-+
+--R     4b c\|- b c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                  +---+                              +-+
+--R                    +-+ +-+     x\|b c                   +---+     x\|c
+--R        (A c + B b)\|b \|c atan(-------) + (- A c - B b)\|b c atan(-----)
+--R                                   b                                 +-+
+--R                                                                    \|b
+--R   (6)  -----------------------------------------------------------------
+--R                                     +-+ +-+ +---+
+--R                                2b c\|b \|c \|b c
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 594
+
+)clear all
+
+--S 595 of 3139
+t0:=x^3*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  --------------------
+--R         2 5         3    2
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 595
+
+--S 596 of 3139
+r0:=1/2*(-b*B+A*c)/(b*c*(b+c*x^2))+A*log(x)/b^2-1/2*A*log(b+c*x^2)/b^2
+--R 
+--R
+--R   (2)
+--R         2 2                2             2 2                              2
+--R   (- A c x  - A b c)log(c x  + b) + (2A c x  + 2A b c)log(x) + A b c - B b
+--R   -------------------------------------------------------------------------
+--R                                   2 2 2     3
+--R                                 2b c x  + 2b c
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2 2                2             2 2                              2
+--R   (- A c x  - A b c)log(c x  + b) + (2A c x  + 2A b c)log(x) + A b c - B b
+--R   -------------------------------------------------------------------------
+--R                                   2 2 2     3
+--R                                 2b c x  + 2b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 597
+
+--S 598 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 599
+
+)clear all
+
+--S 600 of 3139
+t0:=x^2*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  2
+--R               B x  + A
+--R   (1)  ---------------------
+--R         2 6         4    2 2
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 600
+
+--S 601 of 3139
+r0:=1/2*(b*B-3*A*c)/(b^2*c*x)+1/2*(-b*B+A*c)/(b*c*x*(b+c*x^2))+_
+   1/2*(b*B-3*A*c)*atan(x*sqrt(c)/sqrt(b))/(b^(5/2)*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                                                        +-+
+--R               2          3                  2        x\|c
+--R       ((- 3A c  + B b c)x  + (- 3A b c + B b )x)atan(-----)
+--R                                                        +-+
+--R                                                       \|b
+--R     + 
+--R                       2         +-+ +-+
+--R       ((- 3A c + B b)x  - 2A b)\|b \|c
+--R  /
+--R        2   3     3   +-+ +-+
+--R     (2b c x  + 2b x)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                       2      +-----+
+--R               2          3                2       (c x  - b)\|- b c  - 2b c x
+--R         ((3A c  - B b c)x  + (3A b c - B b )x)log(---------------------------)
+--R                                                                2
+--R                                                             c x  + b
+--R       + 
+--R                          2         +-----+
+--R         ((- 6A c + 2B b)x  - 4A b)\|- b c
+--R    /
+--R          2   3     3   +-----+
+--R       (4b c x  + 4b x)\|- b c
+--R     ,
+--R
+--R                                                          +---+
+--R                 2          3                  2        x\|b c
+--R         ((- 3A c  + B b c)x  + (- 3A b c + B b )x)atan(-------)
+--R                                                           b
+--R       + 
+--R                         2         +---+
+--R         ((- 3A c + B b)x  - 2A b)\|b c
+--R    /
+--R          2   3     3   +---+
+--R       (2b c x  + 2b x)\|b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 602
+
+--S 603 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                   2      +-----+
+--R                    +-+ +-+    (c x  - b)\|- b c  - 2b c x
+--R       (3A c - B b)\|b \|c log(---------------------------)
+--R                                            2
+--R                                         c x  + b
+--R     + 
+--R                                   +-+
+--R                     +-----+     x\|c
+--R       (6A c - 2B b)\|- b c atan(-----)
+--R                                   +-+
+--R                                  \|b
+--R  /
+--R       2 +-----+ +-+ +-+
+--R     4b \|- b c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                     +---+                             +-+
+--R                       +-+ +-+     x\|b c                  +---+     x\|c
+--R        (- 3A c + B b)\|b \|c atan(-------) + (3A c - B b)\|b c atan(-----)
+--R                                      b                                +-+
+--R                                                                      \|b
+--R   (6)  -------------------------------------------------------------------
+--R                                   2 +-+ +-+ +---+
+--R                                 2b \|b \|c \|b c
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 606
+
+)clear all
+
+--S 607 of 3139
+t0:=x*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  2
+--R               B x  + A
+--R   (1)  ---------------------
+--R         2 7         5    2 3
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 607
+
+--S 608 of 3139
+r0:=1/2*(b*B-2*A*c)/(b^2*c*x^2)+1/2*(-b*B+A*c)/(b*c*x^2*(b+c*x^2))+_
+   (b*B-2*A*c)*log(x)/b^3-1/2*(b*B-2*A*c)*log(b+c*x^2)/b^3
+--R 
+--R
+--R   (2)
+--R             2          4                2  2        2
+--R       ((2A c  - B b c)x  + (2A b c - B b )x )log(c x  + b)
+--R     + 
+--R               2           4                   2  2                         2  2
+--R       ((- 4A c  + 2B b c)x  + (- 4A b c + 2B b )x )log(x) + (- 2A b c + B b )x
+--R     + 
+--R            2
+--R       - A b
+--R  /
+--R       3   4     4 2
+--R     2b c x  + 2b x
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2          4                2  2        2
+--R       ((2A c  - B b c)x  + (2A b c - B b )x )log(c x  + b)
+--R     + 
+--R               2           4                   2  2                         2  2
+--R       ((- 4A c  + 2B b c)x  + (- 4A b c + 2B b )x )log(x) + (- 2A b c + B b )x
+--R     + 
+--R            2
+--R       - A b
+--R  /
+--R       3   4     4 2
+--R     2b c x  + 2b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 609
+
+--S 610 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 611
+
+)clear all
+
+--S 612 of 3139
+t0:=(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  2
+--R               B x  + A
+--R   (1)  ---------------------
+--R         2 8         6    2 4
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 612
+
+--S 613 of 3139
+r0:=1/6*(3*b*B-5*A*c)/(b^2*c*x^3)+1/2*(-3*b*B+5*A*c)/(b^3*x)+_
+   1/2*(-b*B+A*c)/(b*c*x^3*(b+c*x^2))-_
+   1/2*(3*b*B-5*A*c)*atan(x*sqrt(c)/sqrt(b))*sqrt(c)/b^(7/2)
+--R 
+--R
+--R   (2)
+--R                                                             +-+
+--R              2           5                  2  3  +-+     x\|c
+--R       ((15A c  - 9B b c)x  + (15A b c - 9B b )x )\|c atan(-----)
+--R                                                             +-+
+--R                                                            \|b
+--R     + 
+--R              2           4                  2  2       2  +-+
+--R       ((15A c  - 9B b c)x  + (10A b c - 6B b )x  - 2A b )\|b
+--R  /
+--R        3   5     4 3  +-+
+--R     (6b c x  + 6b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                       +---+
+--R                  2           5                  2  3  |  c
+--R           ((15A c  - 9B b c)x  + (15A b c - 9B b )x ) |- -
+--R                                                      \|  b
+--R        *
+--R                    +---+
+--R                    |  c       2
+--R               2b x |- -  + c x  - b
+--R                   \|  b
+--R           log(---------------------)
+--R                         2
+--R                      c x  + b
+--R       + 
+--R               2            4                   2  2       2
+--R         (30A c  - 18B b c)x  + (20A b c - 12B b )x  - 4A b
+--R    /
+--R          3   5      4 3
+--R       12b c x  + 12b x
+--R     ,
+--R
+--R                                                                   +-+
+--R                                                                   |c
+--R                                                         +-+     b |-
+--R                  2           5                    2  3  |c       \|b
+--R         ((- 15A c  + 9B b c)x  + (- 15A b c + 9B b )x ) |- atan(-----)
+--R                                                        \|b       c x
+--R       + 
+--R               2           4                  2  2       2
+--R         (15A c  - 9B b c)x  + (10A b c - 6B b )x  - 2A b
+--R    /
+--R         3   5     4 3
+--R       6b c x  + 6b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 614
+
+--S 615 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                       +---+
+--R                                       |  c       2
+--R                     +---+        2b x |- -  + c x  - b
+--R                     |  c  +-+        \|  b
+--R       (5A c - 3B b) |- - \|b log(---------------------)
+--R                    \|  b                   2
+--R                                         c x  + b
+--R     + 
+--R                                  +-+
+--R                        +-+     x\|c
+--R       (- 10A c + 6B b)\|c atan(-----)
+--R                                  +-+
+--R                                 \|b
+--R  /
+--R       3 +-+
+--R     4b \|b
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                       +-+
+--R                                                                       |c
+--R                                  +-+                        +-+     b |-
+--R                        +-+     x\|c                     +-+ |c       \|b
+--R        (- 5A c + 3B b)\|c atan(-----) + (- 5A c + 3B b)\|b  |- atan(-----)
+--R                                  +-+                       \|b       c x
+--R                                 \|b
+--R   (6)  -------------------------------------------------------------------
+--R                                        3 +-+
+--R                                      2b \|b
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 618
+
+)clear all
+
+--S 619 of 3139
+t0:=(A+B*x^2)/(x*(b*x^2+c*x^4)^2)
+--R 
+--R
+--R                  2
+--R               B x  + A
+--R   (1)  ---------------------
+--R         2 9         7    2 5
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 619
+
+--S 620 of 3139
+r0:=1/4*(2*b*B-3*A*c)/(b^2*c*x^4)+1/2*(-2*b*B+3*A*c)/(b^3*x^2)+_
+   1/2*(-b*B+A*c)/(b*c*x^4*(b+c*x^2))-c*(2*b*B-3*A*c)*log(x)/b^4+_
+   1/2*c*(2*b*B-3*A*c)*log(b+c*x^2)/b^4
+--R 
+--R
+--R   (2)
+--R               3         2  6            2       2   4        2
+--R       ((- 6A c  + 4B b c )x  + (- 6A b c  + 4B b c)x )log(c x  + b)
+--R     + 
+--R              3         2  6           2       2   4
+--R       ((12A c  - 8B b c )x  + (12A b c  - 8B b c)x )log(x)
+--R     + 
+--R              2       2   4        2        3  2      3
+--R       (6A b c  - 4B b c)x  + (3A b c - 2B b )x  - A b
+--R  /
+--R       4   6     5 4
+--R     4b c x  + 4b x
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3         2  6            2       2   4        2
+--R       ((- 6A c  + 4B b c )x  + (- 6A b c  + 4B b c)x )log(c x  + b)
+--R     + 
+--R              3         2  6           2       2   4
+--R       ((12A c  - 8B b c )x  + (12A b c  - 8B b c)x )log(x)
+--R     + 
+--R              2       2   4        2        3  2      3
+--R       (6A b c  - 4B b c)x  + (3A b c - 2B b )x  - A b
+--R  /
+--R       4   6     5 4
+--R     4b c x  + 4b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 621
+
+--S 622 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 623
+
+)clear all
+
+--S 624 of 3139
+t0:=(A+B*x^2)/(x^2*(b*x^2+c*x^4)^2)
+--R 
+--R
+--R                  2
+--R               B x  + A
+--R   (1)  ----------------------
+--R         2 10         8    2 6
+--R        c x   + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 624
+
+--S 625 of 3139
+r0:=1/10*(5*b*B-7*A*c)/(b^2*c*x^5)+1/6*(-5*b*B+7*A*c)/(b^3*x^3)+_
+   1/2*c*(5*b*B-7*A*c)/(b^4*x)+1/2*(-b*B+A*c)/(b*c*x^5*(b+c*x^2))+_
+   1/2*c^(3/2)*(5*b*B-7*A*c)*atan(x*sqrt(c)/sqrt(b))/b^(9/2)
+--R 
+--R
+--R   (2)
+--R                                                                        +-+
+--R                 3          2  7              2        2   5  +-+     x\|c
+--R       ((- 105A c  + 75B b c )x  + (- 105A b c  + 75B b c)x )\|c atan(-----)
+--R                                                                        +-+
+--R                                                                       \|b
+--R     + 
+--R                    3          2  6             2        2   4
+--R           (- 105A c  + 75B b c )x  + (- 70A b c  + 50B b c)x
+--R         + 
+--R                 2         3  2       3
+--R           (14A b c - 10B b )x  - 6A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R         4   7      5 5  +-+
+--R     (30b c x  + 30b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                              +---+
+--R                   3          2  7            2        2   5  |  c
+--R           ((105A c  - 75B b c )x  + (105A b c  - 75B b c)x ) |- -
+--R                                                             \|  b
+--R        *
+--R                      +---+
+--R                      |  c       2
+--R               - 2b x |- -  + c x  - b
+--R                     \|  b
+--R           log(-----------------------)
+--R                          2
+--R                       c x  + b
+--R       + 
+--R                  3           2  6              2         2   4
+--R         (- 210A c  + 150B b c )x  + (- 140A b c  + 100B b c)x
+--R       + 
+--R               2         3  2        3
+--R         (28A b c - 20B b )x  - 12A b
+--R    /
+--R          4   7      5 5
+--R       60b c x  + 60b x
+--R     ,
+--R
+--R                                                                      +-+
+--R                                                                      |c
+--R                                                            +-+     b |-
+--R                 3          2  7            2        2   5  |c       \|b
+--R         ((105A c  - 75B b c )x  + (105A b c  - 75B b c)x ) |- atan(-----)
+--R                                                           \|b       c x
+--R       + 
+--R                  3          2  6             2        2   4
+--R         (- 105A c  + 75B b c )x  + (- 70A b c  + 50B b c)x
+--R       + 
+--R               2         3  2       3
+--R         (14A b c - 10B b )x  - 6A b
+--R    /
+--R          4   7      5 5
+--R       30b c x  + 30b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 626
+
+--S 627 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                            +---+
+--R                                            |  c       2
+--R                        +---+        - 2b x |- -  + c x  - b
+--R            2           |  c  +-+          \|  b
+--R       (7A c  - 5B b c) |- - \|b log(-----------------------)
+--R                       \|  b                    2
+--R                                             c x  + b
+--R     + 
+--R                                    +-+
+--R             2            +-+     x\|c
+--R       (14A c  - 10B b c)\|c atan(-----)
+--R                                    +-+
+--R                                   \|b
+--R  /
+--R       4 +-+
+--R     4b \|b
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 628
+
+--S 629 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                         +-+
+--R                                                                         |c
+--R                                   +-+                         +-+     b |-
+--R             2           +-+     x\|c          2           +-+ |c       \|b
+--R        (7A c  - 5B b c)\|c atan(-----) + (7A c  - 5B b c)\|b  |- atan(-----)
+--R                                   +-+                        \|b       c x
+--R                                  \|b
+--R   (6)  ---------------------------------------------------------------------
+--R                                         4 +-+
+--R                                       2b \|b
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 630
+
+)clear all
+
+--S 631 of 3139
+t0:=x^14*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    10      8
+--R                 B x   + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 631
+
+--S 632 of 3139
+r0:=7/8*b*(9*b*B-5*A*c)*x/c^5-7/24*(9*b*B-5*A*c)*x^3/c^4+7/40*(9*b*B-5*A*c)*_
+   x^5/(b*c^3)-1/4*(b*B-A*c)*x^9/(b*c*(b+c*x^2)^2)-1/8*(9*b*B-5*A*c)*x^7/_
+   (b*c^2*(b+c*x^2))-7/8*b^(3/2)*(9*b*B-5*A*c)*atan(x*sqrt(c)/sqrt(b))/c^(11/2)
+--R 
+--R
+--R   (2)
+--R                    3         2 2  4           2 2          3   2         3
+--R           (525A b c  - 945B b c )x  + (1050A b c  - 1890B b c)x  + 525A b c
+--R         + 
+--R                   4
+--R           - 945B b
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|b
+--R     + 
+--R                4 9         4          3  7              3         2 2  5
+--R           24B c x  + (40A c  - 72B b c )x  + (- 280A b c  + 504B b c )x
+--R         + 
+--R                    2 2          3   3            3          4
+--R           (- 875A b c  + 1575B b c)x  + (- 525A b c + 945B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R          7 4         6 2       2 5  +-+
+--R     (120c x  + 240b c x  + 120b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3         2 2  4           2 2          3   2         3
+--R             (525A b c  - 945B b c )x  + (1050A b c  - 1890B b c)x  + 525A b c
+--R           + 
+--R                     4
+--R             - 945B b
+--R        *
+--R                          +---+
+--R                          |  b       2
+--R            +---+    2c x |- -  + c x  - b
+--R            |  b         \|  c
+--R            |- - log(---------------------)
+--R           \|  c               2
+--R                            c x  + b
+--R       + 
+--R              4 9         4           3  7              3          2 2  5
+--R         48B c x  + (80A c  - 144B b c )x  + (- 560A b c  + 1008B b c )x
+--R       + 
+--R                   2 2          3   3             3           4
+--R         (- 1750A b c  + 3150B b c)x  + (- 1050A b c + 1890B b )x
+--R    /
+--R           7 4         6 2       2 5
+--R       240c x  + 480b c x  + 240b c
+--R     ,
+--R
+--R                        3         2 2  4             2 2          3   2
+--R             (- 525A b c  + 945B b c )x  + (- 1050A b c  + 1890B b c)x
+--R           + 
+--R                     3          4
+--R             - 525A b c + 945B b
+--R        *
+--R                     +-+
+--R                     |b
+--R            +-+      |-
+--R            |b      \|c
+--R            |- atan(----)
+--R           \|c        x
+--R       + 
+--R              4 9         4          3  7              3         2 2  5
+--R         24B c x  + (40A c  - 72B b c )x  + (- 280A b c  + 504B b c )x
+--R       + 
+--R                  2 2          3   3            3          4
+--R         (- 875A b c  + 1575B b c)x  + (- 525A b c + 945B b )x
+--R    /
+--R           7 4         6 2       2 5
+--R       120c x  + 240b c x  + 120b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 633
+
+--S 634 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                            +---+
+--R                                            |  b       2
+--R                          +---+        2c x |- -  + c x  - b
+--R                       2  |  b  +-+        \|  c
+--R       (35A b c - 63B b ) |- - \|c log(---------------------)
+--R                         \|  c                   2
+--R                                              c x  + b
+--R     + 
+--R                                       +-+
+--R                          2  +-+     x\|c
+--R       (- 70A b c + 126B b )\|b atan(-----)
+--R                                       +-+
+--R                                      \|b
+--R  /
+--R        5 +-+
+--R     16c \|c
+--R                                                    Type: Expression(Integer)
+--E 634
+
+--S 635 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                           +-+
+--R                                                                           |b
+--R                                  +-+                         +-+          |-
+--R                     2  +-+     x\|c                       2  |b  +-+     \|c
+--R   (- 35A b c + 63B b )\|b atan(-----) + (- 35A b c + 63B b ) |- \|c atan(----)
+--R                                  +-+                        \|c            x
+--R                                 \|b
+--R   ----------------------------------------------------------------------------
+--R                                        5 +-+
+--R                                      8c \|c
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 637
+
+)clear all
+
+--S 638 of 3139
+t0:=x^13*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    9      7
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 638
+
+--S 639 of 3139
+r0:=-1/2*(3*b*B-A*c)*x^2/c^4+1/4*B*x^4/c^3-1/4*b^3*(b*B-A*c)/(c^5*_
+   (b+c*x^2)^2)+1/2*b^2*(4*b*B-3*A*c)/(c^5*(b+c*x^2))+3/2*b*(2*b*B-A*c)*_
+   log(b+c*x^2)/c^5
+--R 
+--R
+--R   (2)
+--R                   3        2 2  4           2 2        3   2       3         4
+--R         ((- 6A b c  + 12B b c )x  + (- 12A b c  + 24B b c)x  - 6A b c + 12B b )
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R          4 8        4         3  6          3        2 2  4
+--R       B c x  + (2A c  - 4B b c )x  + (4A b c  - 11B b c )x
+--R     + 
+--R              2 2       3   2       3        4
+--R       (- 4A b c  + 2B b c)x  - 5A b c + 7B b
+--R  /
+--R       7 4       6 2     2 5
+--R     4c x  + 8b c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 639
+
+--S 640 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   3        2 2  4           2 2        3   2       3         4
+--R         ((- 6A b c  + 12B b c )x  + (- 12A b c  + 24B b c)x  - 6A b c + 12B b )
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R          4 8        4         3  6          3        2 2  4
+--R       B c x  + (2A c  - 4B b c )x  + (4A b c  - 11B b c )x
+--R     + 
+--R              2 2       3   2       3        4
+--R       (- 4A b c  + 2B b c)x  - 5A b c + 7B b
+--R  /
+--R       7 4       6 2     2 5
+--R     4c x  + 8b c x  + 4b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 640
+
+--S 641 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 642
+
+)clear all
+
+--S 643 of 3139
+t0:=x^12*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    8      6
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 643
+
+--S 644 of 3139
+r0:=-5/8*(7*b*B-3*A*c)*x/c^4+5/24*(7*b*B-3*A*c)*x^3/(b*c^3)-_
+   1/4*(b*B-A*c)*x^7/(b*c*(b+c*x^2)^2)-1/8*(7*b*B-3*A*c)*x^5/(b*c^2*_
+   (b+c*x^2))+5/8*(7*b*B-3*A*c)*atan(x*sqrt(c)/sqrt(b))*sqrt(b)/c^(9/2)
+--R 
+--R
+--R   (2)
+--R                   3           2  4             2         2   2        2
+--R           (- 45A c  + 105B b c )x  + (- 90A b c  + 210B b c)x  - 45A b c
+--R         + 
+--R                 3
+--R           105B b
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|b
+--R     + 
+--R               3 7         3          2  5           2         2   3
+--R           8B c x  + (24A c  - 56B b c )x  + (75A b c  - 175B b c)x
+--R         + 
+--R                 2          3
+--R           (45A b c - 105B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R         6 4        5 2      2 4  +-+
+--R     (24c x  + 48b c x  + 24b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 644
+
+--S 645 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     3           2  4           2         2   2        2
+--R               (45A c  - 105B b c )x  + (90A b c  - 210B b c)x  + 45A b c
+--R             + 
+--R                       3
+--R               - 105B b
+--R        *
+--R                            +---+
+--R                            |  b       2
+--R            +---+    - 2c x |- -  + c x  - b
+--R            |  b           \|  c
+--R            |- - log(-----------------------)
+--R           \|  c                2
+--R                             c x  + b
+--R       + 
+--R              3 7         3           2  5            2         2   3
+--R         16B c x  + (48A c  - 112B b c )x  + (150A b c  - 350B b c)x
+--R       + 
+--R               2          3
+--R         (90A b c - 210B b )x
+--R    /
+--R          6 4        5 2      2 4
+--R       48c x  + 96b c x  + 48b c
+--R     ,
+--R
+--R                     3           2  4           2         2   2        2
+--R               (45A c  - 105B b c )x  + (90A b c  - 210B b c)x  + 45A b c
+--R             + 
+--R                       3
+--R               - 105B b
+--R        *
+--R                     +-+
+--R                     |b
+--R            +-+      |-
+--R            |b      \|c
+--R            |- atan(----)
+--R           \|c        x
+--R       + 
+--R             3 7         3          2  5           2         2   3
+--R         8B c x  + (24A c  - 56B b c )x  + (75A b c  - 175B b c)x
+--R       + 
+--R               2          3
+--R         (45A b c - 105B b )x
+--R    /
+--R          6 4        5 2      2 4
+--R       24c x  + 48b c x  + 24b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 645
+
+--S 646 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                           +---+
+--R                                           |  b       2
+--R                       +---+        - 2c x |- -  + c x  - b
+--R                       |  b  +-+          \|  c
+--R       (15A c - 35B b) |- - \|c log(-----------------------)
+--R                      \|  c                    2
+--R                                            c x  + b
+--R     + 
+--R                                 +-+
+--R                       +-+     x\|c
+--R       (30A c - 70B b)\|b atan(-----)
+--R                                 +-+
+--R                                \|b
+--R  /
+--R        4 +-+
+--R     16c \|c
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                      +-+
+--R                                                                      |b
+--R                                  +-+                    +-+          |-
+--R                        +-+     x\|c                     |b  +-+     \|c
+--R        (15A c - 35B b)\|b atan(-----) + (15A c - 35B b) |- \|c atan(----)
+--R                                  +-+                   \|c            x
+--R                                 \|b
+--R   (6)  ------------------------------------------------------------------
+--R                                        4 +-+
+--R                                      8c \|c
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 649
+
+)clear all
+
+--S 650 of 3139
+t0:=x^11*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    7      5
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 650
+
+--S 651 of 3139
+r0:=1/2*B*x^2/c^3+1/4*b^2*(b*B-A*c)/(c^4*(b+c*x^2)^2)-_
+   1/2*b*(3*b*B-2*A*c)/(c^4*(b+c*x^2))-1/2*(3*b*B-A*c)*log(b+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R               3         2  4          2        2   2       2        3
+--R         ((2A c  - 6B b c )x  + (4A b c  - 12B b c)x  + 2A b c - 6B b )
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R           3 6         2 4          2       2   2       2        3
+--R       2B c x  + 4B b c x  + (4A b c  - 4B b c)x  + 3A b c - 5B b
+--R  /
+--R       6 4       5 2     2 4
+--R     4c x  + 8b c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3         2  4          2        2   2       2        3
+--R         ((2A c  - 6B b c )x  + (4A b c  - 12B b c)x  + 2A b c - 6B b )
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R           3 6         2 4          2       2   2       2        3
+--R       2B c x  + 4B b c x  + (4A b c  - 4B b c)x  + 3A b c - 5B b
+--R  /
+--R       6 4       5 2     2 4
+--R     4c x  + 8b c x  + 4b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 652
+
+--S 653 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 653
+
+--S 654 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 654
+
+)clear all
+
+--S 655 of 3139
+t0:=x^10*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    6      4
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 655
+
+--S 656 of 3139
+r0:=3/8*(5*b*B-A*c)*x/(b*c^3)-1/4*(b*B-A*c)*x^5/(b*c*(b+c*x^2)^2)-_
+   1/8*(5*b*B-A*c)*x^3/(b*c^2*(b+c*x^2))-3/8*(5*b*B-A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/(c^(7/2)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R               3          2  4          2        2   2       2         3
+--R         ((3A c  - 15B b c )x  + (6A b c  - 30B b c)x  + 3A b c - 15B b )
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|b
+--R     + 
+--R            2 5          2            3                    2    +-+ +-+
+--R       (8B c x  + (- 5A c  + 25B b c)x  + (- 3A b c + 15B b )x)\|b \|c
+--R  /
+--R        5 4        4 2     2 3  +-+ +-+
+--R     (8c x  + 16b c x  + 8b c )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3          2  4          2        2   2       2         3
+--R           ((3A c  - 15B b c )x  + (6A b c  - 30B b c)x  + 3A b c - 15B b )
+--R        *
+--R                   2      +-----+
+--R               (c x  - b)\|- b c  + 2b c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + b
+--R       + 
+--R               2 5           2            3                    2    +-----+
+--R         (16B c x  + (- 10A c  + 50B b c)x  + (- 6A b c + 30B b )x)\|- b c
+--R    /
+--R           5 4        4 2      2 3  +-----+
+--R       (16c x  + 32b c x  + 16b c )\|- b c
+--R     ,
+--R
+--R                 3          2  4          2        2   2       2         3
+--R           ((3A c  - 15B b c )x  + (6A b c  - 30B b c)x  + 3A b c - 15B b )
+--R        *
+--R                  +---+
+--R                x\|b c
+--R           atan(-------)
+--R                   b
+--R       + 
+--R              2 5          2            3                    2    +---+
+--R         (8B c x  + (- 5A c  + 25B b c)x  + (- 3A b c + 15B b )x)\|b c
+--R    /
+--R          5 4        4 2     2 3  +---+
+--R       (8c x  + 16b c x  + 8b c )\|b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 657
+
+--S 658 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                     2      +-----+
+--R                      +-+ +-+    (c x  - b)\|- b c  + 2b c x
+--R       (3A c - 15B b)\|b \|c log(---------------------------)
+--R                                              2
+--R                                           c x  + b
+--R     + 
+--R                                      +-+
+--R                        +-----+     x\|c
+--R       (- 6A c + 30B b)\|- b c atan(-----)
+--R                                      +-+
+--R                                     \|b
+--R  /
+--R        3 +-----+ +-+ +-+
+--R     16c \|- b c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 658
+
+--S 659 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 659
+
+--S 660 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                +---+                                 +-+
+--R                  +-+ +-+     x\|b c                      +---+     x\|c
+--R   (3A c - 15B b)\|b \|c atan(-------) + (- 3A c + 15B b)\|b c atan(-----)
+--R                                 b                                    +-+
+--R                                                                     \|b
+--R   -----------------------------------------------------------------------
+--R                                3 +-+ +-+ +---+
+--R                              8c \|b \|c \|b c
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 661
+
+)clear all
+
+--S 662 of 3139
+t0:=x^9*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    5      3
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 662
+
+--S 663 of 3139
+r0:=-1/4*b*(b*B-A*c)/(c^3*(b+c*x^2)^2)+1/2*(2*b*B-A*c)/(c^3*(b+c*x^2))+_
+   1/2*B*log(b+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R            2 4           2       2        2               2           2
+--R       (2B c x  + 4B b c x  + 2B b )log(c x  + b) + (- 2A c  + 4B b c)x  - A b c
+--R     + 
+--R           2
+--R       3B b
+--R  /
+--R       5 4       4 2     2 3
+--R     4c x  + 8b c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 663
+
+--S 664 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2 4           2       2        2               2           2
+--R       (2B c x  + 4B b c x  + 2B b )log(c x  + b) + (- 2A c  + 4B b c)x  - A b c
+--R     + 
+--R           2
+--R       3B b
+--R  /
+--R       5 4       4 2     2 3
+--R     4c x  + 8b c x  + 4b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 664
+
+--S 665 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 666
+
+)clear all
+
+--S 667 of 3139
+t0:=x^8*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    4      2
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 667
+
+--S 668 of 3139
+r0:=-1/4*(b*B-A*c)*x^3/(b*c*(b+c*x^2)^2)-1/8*(3*b*B+A*c)*_
+   x/(b*c^2*(b+c*x^2))+1/8*(3*b*B+A*c)*atan(x*sqrt(c)/sqrt(b))/_
+   (b^(3/2)*c^(5/2))
+--R 
+--R
+--R   (2)
+--R                                                                         +-+
+--R            3         2  4          2       2   2      2        3      x\|c
+--R       ((A c  + 3B b c )x  + (2A b c  + 6B b c)x  + A b c + 3B b )atan(-----)
+--R                                                                         +-+
+--R                                                                        \|b
+--R     + 
+--R            2           3                  2    +-+ +-+
+--R       ((A c  - 5B b c)x  + (- A b c - 3B b )x)\|b \|c
+--R  /
+--R          4 4      2 3 2     3 2  +-+ +-+
+--R     (8b c x  + 16b c x  + 8b c )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 668
+
+--S 669 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                3         2  4          2       2   2      2        3
+--R           ((A c  + 3B b c )x  + (2A b c  + 6B b c)x  + A b c + 3B b )
+--R        *
+--R                   2      +-----+
+--R               (c x  - b)\|- b c  + 2b c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + b
+--R       + 
+--R               2            3                   2    +-----+
+--R         ((2A c  - 10B b c)x  + (- 2A b c - 6B b )x)\|- b c
+--R    /
+--R             4 4      2 3 2      3 2  +-----+
+--R       (16b c x  + 32b c x  + 16b c )\|- b c
+--R     ,
+--R
+--R                3         2  4          2       2   2      2        3
+--R           ((A c  + 3B b c )x  + (2A b c  + 6B b c)x  + A b c + 3B b )
+--R        *
+--R                  +---+
+--R                x\|b c
+--R           atan(-------)
+--R                   b
+--R       + 
+--R              2           3                  2    +---+
+--R         ((A c  - 5B b c)x  + (- A b c - 3B b )x)\|b c
+--R    /
+--R            4 4      2 3 2     3 2  +---+
+--R       (8b c x  + 16b c x  + 8b c )\|b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 669
+
+--S 670 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                   2      +-----+
+--R                    +-+ +-+    (c x  - b)\|- b c  + 2b c x
+--R       (A c + 3B b)\|b \|c log(---------------------------)
+--R                                            2
+--R                                         c x  + b
+--R     + 
+--R                                     +-+
+--R                       +-----+     x\|c
+--R       (- 2A c - 6B b)\|- b c atan(-----)
+--R                                     +-+
+--R                                    \|b
+--R  /
+--R          2 +-----+ +-+ +-+
+--R     16b c \|- b c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                   +---+                               +-+
+--R                     +-+ +-+     x\|b c                    +---+     x\|c
+--R        (A c + 3B b)\|b \|c atan(-------) + (- A c - 3B b)\|b c atan(-----)
+--R                                    b                                  +-+
+--R                                                                      \|b
+--R   (6)  -------------------------------------------------------------------
+--R                                    2 +-+ +-+ +---+
+--R                                8b c \|b \|c \|b c
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 673
+
+)clear all
+
+--S 674 of 3139
+t0:=x^7*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     3
+--R                  B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 674
+
+--S 675 of 3139
+r0:=1/4*(A+B*x^2)^2/((b*B-A*c)*(b+c*x^2)^2)
+--R 
+--R
+--R                         1  2 4   1      2   1  2
+--R                       - - B x  - - A B x  - - A
+--R                         4        2          4
+--R   (2)  -------------------------------------------------------
+--R            3        2  4          2       2   2      2       3
+--R        (A c  - B b c )x  + (2A b c  - 2B b c)x  + A b c - B b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 675
+
+--S 676 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 2
+--R         - 2B c x  - A c - B b
+--R   (3)  -----------------------
+--R          4 4       3 2     2 2
+--R        4c x  + 8b c x  + 4b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 676
+
+--S 677 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                2
+--R               B
+--R   (4)  ---------------
+--R            3         2
+--R        4A c  - 4B b c
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 678
+
+)clear all
+
+--S 679 of 3139
+t0:=x^6*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      2
+--R                   B x  + A
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 679
+
+--S 680 of 3139
+r0:=-1/4*(b*B-A*c)*x/(b*c*(b+c*x^2)^2)+1/8*(b*B+3*A*c)*x/(b^2*c*(b+c*x^2))+_
+   1/8*(b*B+3*A*c)*atan(x*sqrt(c)/sqrt(b))/(b^(5/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                                                                         +-+
+--R             3        2  4          2       2   2       2       3      x\|c
+--R       ((3A c  + B b c )x  + (6A b c  + 2B b c)x  + 3A b c + B b )atan(-----)
+--R                                                                         +-+
+--R                                                                        \|b
+--R     + 
+--R             2          3                2    +-+ +-+
+--R       ((3A c  + B b c)x  + (5A b c - B b )x)\|b \|c
+--R  /
+--R        2 3 4      3 2 2     4   +-+ +-+
+--R     (8b c x  + 16b c x  + 8b c)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3        2  4          2       2   2       2       3
+--R           ((3A c  + B b c )x  + (6A b c  + 2B b c)x  + 3A b c + B b )
+--R        *
+--R                   2      +-----+
+--R               (c x  - b)\|- b c  + 2b c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + b
+--R       + 
+--R               2           3                  2    +-----+
+--R         ((6A c  + 2B b c)x  + (10A b c - 2B b )x)\|- b c
+--R    /
+--R           2 3 4      3 2 2      4   +-----+
+--R       (16b c x  + 32b c x  + 16b c)\|- b c
+--R     ,
+--R
+--R                 3        2  4          2       2   2       2       3
+--R           ((3A c  + B b c )x  + (6A b c  + 2B b c)x  + 3A b c + B b )
+--R        *
+--R                  +---+
+--R                x\|b c
+--R           atan(-------)
+--R                   b
+--R       + 
+--R               2          3                2    +---+
+--R         ((3A c  + B b c)x  + (5A b c - B b )x)\|b c
+--R    /
+--R          2 3 4      3 2 2     4   +---+
+--R       (8b c x  + 16b c x  + 8b c)\|b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 681
+
+--S 682 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                   2      +-----+
+--R                    +-+ +-+    (c x  - b)\|- b c  + 2b c x
+--R       (3A c + B b)\|b \|c log(---------------------------)
+--R                                            2
+--R                                         c x  + b
+--R     + 
+--R                                     +-+
+--R                       +-----+     x\|c
+--R       (- 6A c - 2B b)\|- b c atan(-----)
+--R                                     +-+
+--R                                    \|b
+--R  /
+--R        2  +-----+ +-+ +-+
+--R     16b c\|- b c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 683
+
+--S 684 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                   +---+                               +-+
+--R                     +-+ +-+     x\|b c                    +---+     x\|c
+--R        (3A c + B b)\|b \|c atan(-------) + (- 3A c - B b)\|b c atan(-----)
+--R                                    b                                  +-+
+--R                                                                      \|b
+--R   (6)  -------------------------------------------------------------------
+--R                                   2  +-+ +-+ +---+
+--R                                 8b c\|b \|c \|b c
+--R                                                    Type: Expression(Integer)
+--E 684
+
+--S 685 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 685
+
+)clear all
+
+--S 686 of 3139
+t0:=x^5*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      2
+--R                   B x  + A
+--R   (1)  ------------------------------
+--R         3 7       2 5     2   3    3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 686
+
+--S 687 of 3139
+r0:=1/4*(-b*B+A*c)/(b*c*(b+c*x^2)^2)+1/2*A/(b^2*(b+c*x^2))+A*log(x)/b^3-_
+   1/2*A*log(b+c*x^2)/b^3
+--R 
+--R
+--R   (2)
+--R              3 4         2 2       2         2
+--R       (- 2A c x  - 4A b c x  - 2A b c)log(c x  + b)
+--R     + 
+--R            3 4         2 2       2                 2 2       2       3
+--R       (4A c x  + 8A b c x  + 4A b c)log(x) + 2A b c x  + 3A b c - B b
+--R  /
+--R       3 3 4     4 2 2     5
+--R     4b c x  + 8b c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 4         2 2       2         2
+--R       (- 2A c x  - 4A b c x  - 2A b c)log(c x  + b)
+--R     + 
+--R            3 4         2 2       2                 2 2       2       3
+--R       (4A c x  + 8A b c x  + 4A b c)log(x) + 2A b c x  + 3A b c - B b
+--R  /
+--R       3 3 4     4 2 2     5
+--R     4b c x  + 8b c x  + 4b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 688
+
+--S 689 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 690
+
+)clear all
+
+--S 691 of 3139
+t0:=x^4*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R         3 8       2 6     2   4    3 2
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 691
+
+--S 692 of 3139
+r0:=3/8*(b*B-5*A*c)/(b^3*c*x)+1/4*(-b*B+A*c)/(b*c*x*(b+c*x^2)^2)+_
+   1/8*(-b*B+5*A*c)/(b^2*c*x*(b+c*x^2))+3/8*(b*B-5*A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/(b^(7/2)*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                     3         2  5             2       2   3
+--R             (- 15A c  + 3B b c )x  + (- 30A b c  + 6B b c)x
+--R           + 
+--R                     2        3
+--R             (- 15A b c + 3B b )x
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|b
+--R     + 
+--R                2           4                    2  2       2  +-+ +-+
+--R       ((- 15A c  + 3B b c)x  + (- 25A b c + 5B b )x  - 8A b )\|b \|c
+--R  /
+--R        3 2 5      4   3     5   +-+ +-+
+--R     (8b c x  + 16b c x  + 8b x)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3         2  5           2       2   3         2        3
+--R           ((15A c  - 3B b c )x  + (30A b c  - 6B b c)x  + (15A b c - 3B b )x)
+--R        *
+--R                   2      +-----+
+--R               (c x  - b)\|- b c  - 2b c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + b
+--R       + 
+--R                  2           4                     2  2        2  +-----+
+--R         ((- 30A c  + 6B b c)x  + (- 50A b c + 10B b )x  - 16A b )\|- b c
+--R    /
+--R           3 2 5      4   3      5   +-----+
+--R       (16b c x  + 32b c x  + 16b x)\|- b c
+--R     ,
+--R
+--R                     3         2  5             2       2   3
+--R             (- 15A c  + 3B b c )x  + (- 30A b c  + 6B b c)x
+--R           + 
+--R                     2        3
+--R             (- 15A b c + 3B b )x
+--R        *
+--R                  +---+
+--R                x\|b c
+--R           atan(-------)
+--R                   b
+--R       + 
+--R                  2           4                    2  2       2  +---+
+--R         ((- 15A c  + 3B b c)x  + (- 25A b c + 5B b )x  - 8A b )\|b c
+--R    /
+--R          3 2 5      4   3     5   +---+
+--R       (8b c x  + 16b c x  + 8b x)\|b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 693
+
+--S 694 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                     2      +-----+
+--R                      +-+ +-+    (c x  - b)\|- b c  - 2b c x
+--R       (15A c - 3B b)\|b \|c log(---------------------------)
+--R                                              2
+--R                                           c x  + b
+--R     + 
+--R                                    +-+
+--R                      +-----+     x\|c
+--R       (30A c - 6B b)\|- b c atan(-----)
+--R                                    +-+
+--R                                   \|b
+--R  /
+--R        3 +-----+ +-+ +-+
+--R     16b \|- b c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 694
+
+--S 695 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---+                               +-+
+--R                    +-+ +-+     x\|b c                    +---+     x\|c
+--R   (- 15A c + 3B b)\|b \|c atan(-------) + (15A c - 3B b)\|b c atan(-----)
+--R                                   b                                  +-+
+--R                                                                     \|b
+--R   -----------------------------------------------------------------------
+--R                                3 +-+ +-+ +---+
+--R                              8b \|b \|c \|b c
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 697
+
+)clear all
+
+--S 698 of 3139
+t0:=x^3*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R         3 9       2 7     2   5    3 3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 698
+
+--S 699 of 3139
+r0:=1/2*(b*B-3*A*c)/(b^3*c*x^2)+1/4*(-b*B+A*c)/(b*c*x^2*(b+c*x^2)^2)+_
+   1/4*(-b*B+3*A*c)/(b^2*c*x^2*(b+c*x^2))+(b*B-3*A*c)*log(x)/b^4-_
+   1/2*(b*B-3*A*c)*log(b+c*x^2)/b^4
+--R 
+--R
+--R   (2)
+--R               3         2  6           2       2   4        2        3  2
+--R         ((6A c  - 2B b c )x  + (12A b c  - 4B b c)x  + (6A b c - 2B b )x )
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R                   3         2  6             2       2   4
+--R           (- 12A c  + 4B b c )x  + (- 24A b c  + 8B b c)x
+--R         + 
+--R                   2        3  2
+--R           (- 12A b c + 4B b )x
+--R      *
+--R         log(x)
+--R     + 
+--R                2       2   4          2        3  2       3
+--R       (- 6A b c  + 2B b c)x  + (- 9A b c + 3B b )x  - 2A b
+--R  /
+--R       4 2 6     5   4     6 2
+--R     4b c x  + 8b c x  + 4b x
+--R                                                    Type: Expression(Integer)
+--E 699
+
+--S 700 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3         2  6           2       2   4        2        3  2
+--R         ((6A c  - 2B b c )x  + (12A b c  - 4B b c)x  + (6A b c - 2B b )x )
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R                   3         2  6             2       2   4
+--R           (- 12A c  + 4B b c )x  + (- 24A b c  + 8B b c)x
+--R         + 
+--R                   2        3  2
+--R           (- 12A b c + 4B b )x
+--R      *
+--R         log(x)
+--R     + 
+--R                2       2   4          2        3  2       3
+--R       (- 6A b c  + 2B b c)x  + (- 9A b c + 3B b )x  - 2A b
+--R  /
+--R       4 2 6     5   4     6 2
+--R     4b c x  + 8b c x  + 4b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 700
+
+--S 701 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 702
+
+)clear all
+
+--S 703 of 3139
+t0:=x^2*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  --------------------------------
+--R         3 10       2 8     2   6    3 4
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 703
+
+--S 704 of 3139
+r0:=5/24*(3*b*B-7*A*c)/(b^3*c*x^3)-5/8*(3*b*B-7*A*c)/(b^4*x)+_
+   1/4*(-b*B+A*c)/(b*c*x^3*(b+c*x^2)^2)+1/8*(-3*b*B+7*A*c)/_
+   (b^2*c*x^3*(b+c*x^2))-5/8*(3*b*B-7*A*c)*atan(x*sqrt(c)/sqrt(b))*_
+   sqrt(c)/b^(9/2)
+--R 
+--R
+--R   (2)
+--R                  3          2  7            2        2   5
+--R           (105A c  - 45B b c )x  + (210A b c  - 90B b c)x
+--R         + 
+--R                  2         3  3
+--R           (105A b c - 45B b )x
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|c atan(-----)
+--R                    +-+
+--R                   \|b
+--R     + 
+--R                  3          2  6            2        2   4
+--R           (105A c  - 45B b c )x  + (175A b c  - 75B b c)x
+--R         + 
+--R                 2         3  2       3
+--R           (56A b c - 24B b )x  - 8A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R         4 2 7      5   5      6 3  +-+
+--R     (24b c x  + 48b c x  + 24b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    3          2  7            2        2   5
+--R             (105A c  - 45B b c )x  + (210A b c  - 90B b c)x
+--R           + 
+--R                    2         3  3
+--R             (105A b c - 45B b )x
+--R        *
+--R                          +---+
+--R                          |  c       2
+--R            +---+    2b x |- -  + c x  - b
+--R            |  c         \|  b
+--R            |- - log(---------------------)
+--R           \|  b               2
+--R                            c x  + b
+--R       + 
+--R                3          2  6            2         2   4
+--R         (210A c  - 90B b c )x  + (350A b c  - 150B b c)x
+--R       + 
+--R                2         3  2        3
+--R         (112A b c - 48B b )x  - 16A b
+--R    /
+--R          4 2 7      5   5      6 3
+--R       48b c x  + 96b c x  + 48b x
+--R     ,
+--R
+--R                      3          2  7              2        2   5
+--R             (- 105A c  + 45B b c )x  + (- 210A b c  + 90B b c)x
+--R           + 
+--R                      2         3  3
+--R             (- 105A b c + 45B b )x
+--R        *
+--R                      +-+
+--R                      |c
+--R            +-+     b |-
+--R            |c       \|b
+--R            |- atan(-----)
+--R           \|b       c x
+--R       + 
+--R                3          2  6            2        2   4         2         3  2
+--R         (105A c  - 45B b c )x  + (175A b c  - 75B b c)x  + (56A b c - 24B b )x
+--R       + 
+--R               3
+--R         - 8A b
+--R    /
+--R          4 2 7      5   5      6 3
+--R       24b c x  + 48b c x  + 24b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 705
+
+--S 706 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                         +---+
+--R                                         |  c       2
+--R                       +---+        2b x |- -  + c x  - b
+--R                       |  c  +-+        \|  b
+--R       (35A c - 15B b) |- - \|b log(---------------------)
+--R                      \|  b                   2
+--R                                           c x  + b
+--R     + 
+--R                                   +-+
+--R                         +-+     x\|c
+--R       (- 70A c + 30B b)\|c atan(-----)
+--R                                   +-+
+--R                                  \|b
+--R  /
+--R        4 +-+
+--R     16b \|b
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                      +-+
+--R                                                                      |c
+--R                               +-+                          +-+     b |-
+--R                     +-+     x\|c                       +-+ |c       \|b
+--R   (- 35A c + 15B b)\|c atan(-----) + (- 35A c + 15B b)\|b  |- atan(-----)
+--R                               +-+                         \|b       c x
+--R                              \|b
+--R   -----------------------------------------------------------------------
+--R                                     4 +-+
+--R                                   8b \|b
+--R                                                    Type: Expression(Integer)
+--E 708
+
+--S 709 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 709
+
+)clear all
+
+--S 710 of 3139
+t0:=x*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  --------------------------------
+--R         3 11       2 9     2   7    3 5
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 710
+
+--S 711 of 3139
+r0:=3/4*(b*B-2*A*c)/(b^3*c*x^4)-3/2*(b*B-2*A*c)/(b^4*x^2)+1/4*(-b*B+A*c)/_
+   (b*c*x^4*(b+c*x^2)^2)+1/2*(-b*B+2*A*c)/(b^2*c*x^4*(b+c*x^2))-_
+   3*c*(b*B-2*A*c)*log(x)/b^5+3/2*c*(b*B-2*A*c)*log(b+c*x^2)/b^5
+--R 
+--R
+--R   (2)
+--R                   4         3  8             3        2 2  6
+--R           (- 12A c  + 6B b c )x  + (- 24A b c  + 12B b c )x
+--R         + 
+--R                   2 2       3   4
+--R           (- 12A b c  + 6B b c)x
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R                 4          3  8           3        2 2  6
+--R           (24A c  - 12B b c )x  + (48A b c  - 24B b c )x
+--R         + 
+--R                 2 2        3   4
+--R           (24A b c  - 12B b c)x
+--R      *
+--R         log(x)
+--R     + 
+--R             3       2 2  6         2 2       3   4        3        4  2      4
+--R     (12A b c  - 6B b c )x  + (18A b c  - 9B b c)x  + (4A b c - 2B b )x  - A b
+--R  /
+--R       5 2 8     6   6     7 4
+--R     4b c x  + 8b c x  + 4b x
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   4         3  8             3        2 2  6
+--R           (- 12A c  + 6B b c )x  + (- 24A b c  + 12B b c )x
+--R         + 
+--R                   2 2       3   4
+--R           (- 12A b c  + 6B b c)x
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R                 4          3  8           3        2 2  6
+--R           (24A c  - 12B b c )x  + (48A b c  - 24B b c )x
+--R         + 
+--R                 2 2        3   4
+--R           (24A b c  - 12B b c)x
+--R      *
+--R         log(x)
+--R     + 
+--R             3       2 2  6         2 2       3   4        3        4  2      4
+--R     (12A b c  - 6B b c )x  + (18A b c  - 9B b c)x  + (4A b c - 2B b )x  - A b
+--R  /
+--R       5 2 8     6   6     7 4
+--R     4b c x  + 8b c x  + 4b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 712
+
+--S 713 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 714
+
+)clear all
+
+--S 715 of 3139
+t0:=(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                        2
+--R                     B x  + A
+--R   (1)  ---------------------------------
+--R         3 12       2 10     2   8    3 6
+--R        c x   + 3b c x   + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 715
+
+--S 716 of 3139
+r0:=7/40*(5*b*B-9*A*c)/(b^3*c*x^5)-7/24*(5*b*B-9*A*c)/(b^4*x^3)+_
+   7/8*c*(5*b*B-9*A*c)/(b^5*x)+1/4*(-b*B+A*c)/(b*c*x^5*(b+c*x^2)^2)+_
+   1/8*(-5*b*B+9*A*c)/(b^2*c*x^5*(b+c*x^2))+7/8*c^(3/2)*(5*b*B-9*A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/b^(11/2)
+--R 
+--R
+--R   (2)
+--R                    4           3  9               3          2 2  7
+--R           (- 945A c  + 525B b c )x  + (- 1890A b c  + 1050B b c )x
+--R         + 
+--R                    2 2         3   5
+--R           (- 945A b c  + 525B b c)x
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|c atan(-----)
+--R                    +-+
+--R                   \|b
+--R     + 
+--R                    4           3  8               3         2 2  6
+--R           (- 945A c  + 525B b c )x  + (- 1575A b c  + 875B b c )x
+--R         + 
+--R                    2 2         3   4         3         4  2        4
+--R           (- 504A b c  + 280B b c)x  + (72A b c - 40B b )x  - 24A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R          5 2 9       6   7       7 5  +-+
+--R     (120b c x  + 240b c x  + 120b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    4           3  9             3          2 2  7
+--R             (945A c  - 525B b c )x  + (1890A b c  - 1050B b c )x
+--R           + 
+--R                    2 2         3   5
+--R             (945A b c  - 525B b c)x
+--R        *
+--R                            +---+
+--R                            |  c       2
+--R            +---+    - 2b x |- -  + c x  - b
+--R            |  c           \|  b
+--R            |- - log(-----------------------)
+--R           \|  b                2
+--R                             c x  + b
+--R       + 
+--R                   4            3  8               3          2 2  6
+--R         (- 1890A c  + 1050B b c )x  + (- 3150A b c  + 1750B b c )x
+--R       + 
+--R                   2 2         3   4          3         4  2        4
+--R         (- 1008A b c  + 560B b c)x  + (144A b c - 80B b )x  - 48A b
+--R    /
+--R           5 2 9       6   7       7 5
+--R       240b c x  + 480b c x  + 240b x
+--R     ,
+--R
+--R                    4           3  9             3          2 2  7
+--R             (945A c  - 525B b c )x  + (1890A b c  - 1050B b c )x
+--R           + 
+--R                    2 2         3   5
+--R             (945A b c  - 525B b c)x
+--R        *
+--R                      +-+
+--R                      |c
+--R            +-+     b |-
+--R            |c       \|b
+--R            |- atan(-----)
+--R           \|b       c x
+--R       + 
+--R                  4           3  8               3         2 2  6
+--R         (- 945A c  + 525B b c )x  + (- 1575A b c  + 875B b c )x
+--R       + 
+--R                  2 2         3   4         3         4  2        4
+--R         (- 504A b c  + 280B b c)x  + (72A b c - 40B b )x  - 24A b
+--R    /
+--R           5 2 9       6   7       7 5
+--R       120b c x  + 240b c x  + 120b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 717
+
+--S 718 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                              +---+
+--R                                              |  c       2
+--R                          +---+        - 2b x |- -  + c x  - b
+--R             2            |  c  +-+          \|  b
+--R       (63A c  - 35B b c) |- - \|b log(-----------------------)
+--R                         \|  b                    2
+--R                                               c x  + b
+--R     + 
+--R                                     +-+
+--R              2            +-+     x\|c
+--R       (126A c  - 70B b c)\|c atan(-----)
+--R                                     +-+
+--R                                    \|b
+--R  /
+--R        5 +-+
+--R     16b \|b
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                        +-+
+--R                                                                        |c
+--R                                +-+                           +-+     b |-
+--R         2            +-+     x\|c           2            +-+ |c       \|b
+--R   (63A c  - 35B b c)\|c atan(-----) + (63A c  - 35B b c)\|b  |- atan(-----)
+--R                                +-+                          \|b       c x
+--R                               \|b
+--R   -------------------------------------------------------------------------
+--R                                      5 +-+
+--R                                    8b \|b
+--R                                                    Type: Expression(Integer)
+--E 720
+
+--S 721 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 721
+
+)clear all
+
+--S 722 of 3139
+t0:=(A+B*x^2)/(x*(b*x^2+c*x^4)^3)
+--R 
+--R
+--R                        2
+--R                     B x  + A
+--R   (1)  ---------------------------------
+--R         3 13       2 11     2   9    3 7
+--R        c x   + 3b c x   + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 722
+
+--S 723 of 3139
+r0:=1/3*(3*b*B-5*A*c)/(b^3*c*x^6)+1/2*(-3*b*B+5*A*c)/(b^4*x^4)+_
+   c*(3*b*B-5*A*c)/(b^5*x^2)+1/4*(-b*B+A*c)/(b*c*x^6*(b+c*x^2)^2)+_
+   1/4*(-3*b*B+5*A*c)/(b^2*c*x^6*(b+c*x^2))+2*c^2*(3*b*B-5*A*c)*log(x)/b^6-_
+   c^2*(3*b*B-5*A*c)*log(b+c*x^2)/b^6
+--R 
+--R
+--R   (2)
+--R                 5          4  10            4        2 3  8
+--R           (60A c  - 36B b c )x   + (120A b c  - 72B b c )x
+--R         + 
+--R                 2 3        3 2  6
+--R           (60A b c  - 36B b c )x
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R                    5          4  10              4         2 3  8
+--R           (- 120A c  + 72B b c )x   + (- 240A b c  + 144B b c )x
+--R         + 
+--R                    2 3        3 2  6
+--R           (- 120A b c  + 72B b c )x
+--R      *
+--R         log(x)
+--R     + 
+--R                 4        2 3  8           2 3        3 2  6
+--R       (- 60A b c  + 36B b c )x  + (- 90A b c  + 54B b c )x
+--R     + 
+--R               3 2        4   4        4        5  2       5
+--R       (- 20A b c  + 12B b c)x  + (5A b c - 3B b )x  - 2A b
+--R  /
+--R        6 2 10      7   8      8 6
+--R     12b c x   + 24b c x  + 12b x
+--R                                                    Type: Expression(Integer)
+--E 723
+
+--S 724 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 5          4  10            4        2 3  8
+--R           (60A c  - 36B b c )x   + (120A b c  - 72B b c )x
+--R         + 
+--R                 2 3        3 2  6
+--R           (60A b c  - 36B b c )x
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R                    5          4  10              4         2 3  8
+--R           (- 120A c  + 72B b c )x   + (- 240A b c  + 144B b c )x
+--R         + 
+--R                    2 3        3 2  6
+--R           (- 120A b c  + 72B b c )x
+--R      *
+--R         log(x)
+--R     + 
+--R                 4        2 3  8           2 3        3 2  6
+--R       (- 60A b c  + 36B b c )x  + (- 90A b c  + 54B b c )x
+--R     + 
+--R               3 2        4   4        4        5  2       5
+--R       (- 20A b c  + 12B b c)x  + (5A b c - 3B b )x  - 2A b
+--R  /
+--R        6 2 10      7   8      8 6
+--R     12b c x   + 24b c x  + 12b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 724
+
+--S 725 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 726
+
+)clear all
+
+--S 727 of 3139
+t0:=x^7*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      +-----------+
+--R            9      7  |   4      2
+--R   (1)  (B x  + A x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 727
+
+--S 728 of 3139
+r0:=1/12*B*x^6*(b*x^2+c*x^4)^(3/2)/c-7/1024*b^5*(3*b*B-4*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(11/2)+7/1024*b^4*(3*b*B-4*A*c)*_
+   sqrt(b*x^2+c*x^4)/c^5-7/1536*b^3*(3*b*B-4*A*c)*x^2*sqrt(b*x^2+c*x^4)/_
+   c^4+7/1920*b^2*(3*b*B-4*A*c)*x^4*sqrt(b*x^2+c*x^4)/c^3-_
+   1/320*b*(3*b*B-4*A*c)*x^6*sqrt(b*x^2+c*x^4)/c^2-1/40*(3*b*B-4*A*c)*_
+   x^8*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                      2 +-+
+--R              5          6           x \|c
+--R       (420A b c - 315B b )atanh(--------------)
+--R                                  +-----------+
+--R                                  |   4      2
+--R                                 \|c x  + b x
+--R     + 
+--R                  5 10           5           4  8            4         2 3  6
+--R           1280B c x   + (1536A c  + 128B b c )x  + (192A b c  - 144B b c )x
+--R         + 
+--R                    2 3         3 2  4          3 2         4   2         4
+--R           (- 224A b c  + 168B b c )x  + (280A b c  - 210B b c)x  - 420A b c
+--R         + 
+--R                 5
+--R           315B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R           5 +-+
+--R     15360c \|c
+--R                                                    Type: Expression(Integer)
+--E 728
+
+--S 729 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         5 6          6 5  10             6 5           7 4  8
+--R                 (5040A b c  - 3780B b c )x   + (117600A b c  - 88200B b c )x
+--R               + 
+--R                           7 4            8 3  6
+--R                 (752640A b c  - 564480B b c )x
+--R               + 
+--R                            8 3             9 2  4
+--R                 (1935360A b c  - 1451520B b c )x
+--R               + 
+--R                            9 2             10   2            10             11
+--R                 (2150400A b c  - 1612800B b  c)x  + 860160A b  c - 645120B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                      5 7         6 6  12              6 6           7 5  10
+--R             (- 420A b c  + 315B b c )x   + (- 30240A b c  + 22680B b c )x
+--R           + 
+--R                         7 5            8 4  8
+--R             (- 352800A b c  + 264600B b c )x
+--R           + 
+--R                          8 4             9 3  6
+--R             (- 1505280A b c  + 1128960B b c )x
+--R           + 
+--R                          9 3             10 2  4
+--R             (- 2903040A b c  + 2177280B b  c )x
+--R           + 
+--R                          10 2             11   2            11             12
+--R             (- 2580480A b  c  + 1935360B b  c)x  - 860160A b  c + 645120B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                      11 23             11             10  21
+--R             - 1280B c  x   + (- 1536A c   - 92288B b c  )x
+--R           + 
+--R                           10             2 9  19
+--R             (- 110784A b c   - 1084272B b c )x
+--R           + 
+--R                          2 9             3 8  17
+--R             (- 1303840A b c  - 4684840B b c )x
+--R           + 
+--R                          3 8             4 7  15
+--R             (- 5650456A b c  - 9197038B b c )x
+--R           + 
+--R                           4 7             5 6  13
+--R             (- 11136540A b c  - 8359275B b c )x
+--R           + 
+--R                           5 6             6 5  11
+--R             (- 10166432A b c  - 2860936B b c )x
+--R           + 
+--R                          6 5           7 4  9             7 4            8 3  7
+--R             (- 3427808A b c  - 50584B b c )x  + (552960A b c  - 414720B b c )x
+--R           + 
+--R                        8 3             9 2  5
+--R             (1641472A b c  - 1231104B b c )x
+--R           + 
+--R                        9 2             10   3             10             11
+--R             (2007040A b c  - 1505280B b  c)x  + (860160A b  c - 645120B b  )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                     11 23            11              10  21
+--R             15360B c  x   + (18432A c   + 375296B b c  )x
+--R           + 
+--R                         10             2 9  19
+--R             (450816A b c   + 2687808B b c )x
+--R           + 
+--R                        2 9             3 8  17
+--R             (3235968A b c  + 8417184B b c )x
+--R           + 
+--R                         3 8              4 7  15
+--R             (10166176A b c  + 13019208B b c )x
+--R           + 
+--R                         4 7             5 6  13
+--R             (15783600A b c  + 9789180B b c )x
+--R           + 
+--R                         5 6             6 5  11
+--R             (11901744A b c  + 2870172B b c )x
+--R           + 
+--R                        6 5            7 4  9
+--R             (3264672A b c  + 172936B b c )x
+--R           + 
+--R                          7 4            8 3  7
+--R             (- 1176576A b c  + 882432B b c )x
+--R           + 
+--R                          8 3             9 2  5
+--R             (- 2537472A b c  + 1903104B b c )x
+--R           + 
+--R                        9 2             10   3               10             11
+--R           (- 2437120A b c  + 1827840B b  c)x  + (- 860160A b  c + 645120B b  )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                    10 10             9 8            2 8 6            3 7 4
+--R             184320c  x   + 4300800b c x  + 27525120b c x  + 70778880b c x
+--R           + 
+--R                      4 6 2            5 5
+--R             78643200b c x  + 31457280b c
+--R        *
+--R                    +--------+
+--R            +-+ +-+ |   2
+--R           \|b \|c \|c x  + b
+--R       + 
+--R                     11 12             10 10            2 9 8            3 8 6
+--R             - 15360c  x   - 1105920b c  x   - 12902400b c x  - 55050240b c x
+--R           + 
+--R                         4 7 4            5 6 2            6 5
+--R             - 106168320b c x  - 94371840b c x  - 31457280b c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                          5 6          6 5  10             6 5            7 4  8
+--R                 (10080A b c  - 7560B b c )x   + (235200A b c  - 176400B b c )x
+--R               + 
+--R                            7 4             8 3  6
+--R                 (1505280A b c  - 1128960B b c )x
+--R               + 
+--R                            8 3             9 2  4
+--R                 (3870720A b c  - 2903040B b c )x
+--R               + 
+--R                          9 2             10   2             10              11
+--R               (4300800A b c  - 3225600B b  c)x  + 1720320A b  c - 1290240B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                      5 7         6 6  12              6 6           7 5  10
+--R             (- 840A b c  + 630B b c )x   + (- 60480A b c  + 45360B b c )x
+--R           + 
+--R                         7 5            8 4  8
+--R             (- 705600A b c  + 529200B b c )x
+--R           + 
+--R                          8 4             9 3  6
+--R             (- 3010560A b c  + 2257920B b c )x
+--R           + 
+--R                          9 3             10 2  4
+--R             (- 5806080A b c  + 4354560B b  c )x
+--R           + 
+--R                        10 2             11   2             11              12
+--R           (- 5160960A b  c  + 3870720B b  c)x  - 1720320A b  c + 1290240B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                      11 23             11             10  21
+--R             - 1280B c  x   + (- 1536A c   - 92288B b c  )x
+--R           + 
+--R                           10             2 9  19
+--R             (- 110784A b c   - 1084272B b c )x
+--R           + 
+--R                          2 9             3 8  17
+--R             (- 1303840A b c  - 4684840B b c )x
+--R           + 
+--R                          3 8             4 7  15
+--R             (- 5650456A b c  - 9197038B b c )x
+--R           + 
+--R                           4 7             5 6  13
+--R             (- 11136540A b c  - 8359275B b c )x
+--R           + 
+--R                           5 6             6 5  11
+--R             (- 10166432A b c  - 2860936B b c )x
+--R           + 
+--R                          6 5           7 4  9             7 4            8 3  7
+--R             (- 3427808A b c  - 50584B b c )x  + (552960A b c  - 414720B b c )x
+--R           + 
+--R                        8 3             9 2  5
+--R             (1641472A b c  - 1231104B b c )x
+--R           + 
+--R                        9 2             10   3             10             11
+--R             (2007040A b c  - 1505280B b  c)x  + (860160A b  c - 645120B b  )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                     11 23            11              10  21
+--R             15360B c  x   + (18432A c   + 375296B b c  )x
+--R           + 
+--R                         10             2 9  19
+--R             (450816A b c   + 2687808B b c )x
+--R           + 
+--R                        2 9             3 8  17
+--R             (3235968A b c  + 8417184B b c )x
+--R           + 
+--R                         3 8              4 7  15
+--R             (10166176A b c  + 13019208B b c )x
+--R           + 
+--R                         4 7             5 6  13
+--R             (15783600A b c  + 9789180B b c )x
+--R           + 
+--R                         5 6             6 5  11
+--R             (11901744A b c  + 2870172B b c )x
+--R           + 
+--R                        6 5            7 4  9
+--R             (3264672A b c  + 172936B b c )x
+--R           + 
+--R                          7 4            8 3  7
+--R             (- 1176576A b c  + 882432B b c )x
+--R           + 
+--R                          8 3             9 2  5
+--R             (- 2537472A b c  + 1903104B b c )x
+--R           + 
+--R                        9 2             10   3               10             11
+--R           (- 2437120A b c  + 1827840B b  c)x  + (- 860160A b  c + 645120B b  )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                    10 10             9 8            2 8 6            3 7 4
+--R             184320c  x   + 4300800b c x  + 27525120b c x  + 70778880b c x
+--R           + 
+--R                      4 6 2            5 5
+--R             78643200b c x  + 31457280b c
+--R        *
+--R                      +--------+
+--R            +---+ +-+ |   2
+--R           \|- c \|b \|c x  + b
+--R       + 
+--R                     11 12             10 10            2 9 8            3 8 6
+--R             - 15360c  x   - 1105920b c  x   - 12902400b c x  - 55050240b c x
+--R           + 
+--R                         4 7 4            5 6 2            6 5
+--R             - 106168320b c x  - 94371840b c x  - 31457280b c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 729
+
+--S 730 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       5 6          6 5  10             6 5           7 4  8
+--R               (5040A b c  - 3780B b c )x   + (117600A b c  - 88200B b c )x
+--R             + 
+--R                         7 4            8 3  6
+--R               (752640A b c  - 564480B b c )x
+--R             + 
+--R                          8 3             9 2  4
+--R               (1935360A b c  - 1451520B b c )x
+--R             + 
+--R                          9 2             10   2            10             11
+--R               (2150400A b c  - 1612800B b  c)x  + 860160A b  c - 645120B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                    5 7         6 6  12              6 6           7 5  10
+--R           (- 420A b c  + 315B b c )x   + (- 30240A b c  + 22680B b c )x
+--R         + 
+--R                       7 5            8 4  8
+--R           (- 352800A b c  + 264600B b c )x
+--R         + 
+--R                        8 4             9 3  6
+--R           (- 1505280A b c  + 1128960B b c )x
+--R         + 
+--R                        9 3             10 2  4
+--R           (- 2903040A b c  + 2177280B b  c )x
+--R         + 
+--R                        10 2             11   2            11             12
+--R           (- 2580480A b  c  + 1935360B b  c)x  - 860160A b  c + 645120B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                         5 6          6 5  10               6 5           7 4  8
+--R               (- 5040A b c  + 3780B b c )x   + (- 117600A b c  + 88200B b c )x
+--R             + 
+--R                           7 4            8 3  6
+--R               (- 752640A b c  + 564480B b c )x
+--R             + 
+--R                            8 3             9 2  4
+--R               (- 1935360A b c  + 1451520B b c )x
+--R             + 
+--R                            9 2             10   2            10             11
+--R               (- 2150400A b c  + 1612800B b  c)x  - 860160A b  c + 645120B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  5 7         6 6  12            6 6           7 5  10
+--R           (420A b c  - 315B b c )x   + (30240A b c  - 22680B b c )x
+--R         + 
+--R                     7 5            8 4  8              8 4             9 3  6
+--R           (352800A b c  - 264600B b c )x  + (1505280A b c  - 1128960B b c )x
+--R         + 
+--R                      9 3             10 2  4
+--R           (2903040A b c  - 2177280B b  c )x
+--R         + 
+--R                      10 2             11   2            11             12
+--R           (2580480A b  c  - 1935360B b  c)x  + 860160A b  c - 645120B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                         10 20              10              9  18
+--R               - 15360B c  x   + (- 18432A c   - 359936B b c )x
+--R             + 
+--R                             9             2 8  16
+--R               (- 432384A b c  - 2327872B b c )x
+--R             + 
+--R                            2 8             3 7  14
+--R               (- 2803584A b c  - 6089312B b c )x
+--R             + 
+--R                            3 7             4 6  12
+--R               (- 7362592A b c  - 6929896B b c )x
+--R             + 
+--R                            4 6             5 5  10
+--R               (- 8421008A b c  - 2859284B b c )x
+--R             + 
+--R                            5 5           6 4  8
+--R               (- 3480736A b c  - 10888B b c )x
+--R             + 
+--R                         6 4            7 3  6             7 3            8 2  4
+--R               (216064A b c  - 162048B b c )x  + (960512A b c  - 720384B b c )x
+--R             + 
+--R                          8 2             9   2            9             10
+--R               (1576960A b c  - 1182720B b c)x  + 860160A b c - 645120B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                      11 22           11             10  20
+--R               1280B c  x   + (1536A c   + 92288B b c  )x
+--R             + 
+--R                           10             2 9  18
+--R               (110784A b c   + 1084272B b c )x
+--R             + 
+--R                          2 9             3 8  16
+--R               (1303840A b c  + 4684840B b c )x
+--R             + 
+--R                          3 8             4 7  14
+--R               (5650456A b c  + 9197038B b c )x
+--R             + 
+--R                           4 7             5 6  12
+--R               (11136540A b c  + 8359275B b c )x
+--R             + 
+--R                           5 6             6 5  10
+--R               (10166432A b c  + 2860936B b c )x
+--R             + 
+--R                          6 5           7 4  8
+--R               (3427808A b c  + 50584B b c )x
+--R             + 
+--R                           7 4            8 3  6
+--R               (- 552960A b c  + 414720B b c )x
+--R             + 
+--R                            8 3             9 2  4
+--R               (- 1641472A b c  + 1231104B b c )x
+--R             + 
+--R                            9 2             10   2            10             11
+--R               (- 2007040A b c  + 1505280B b  c)x  - 860160A b  c + 645120B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    11 23             11             10  21
+--R           - 1280B c  x   + (- 1536A c   - 92288B b c  )x
+--R         + 
+--R                         10             2 9  19
+--R           (- 110784A b c   - 1084272B b c )x
+--R         + 
+--R                        2 9             3 8  17
+--R           (- 1303840A b c  - 4684840B b c )x
+--R         + 
+--R                        3 8             4 7  15
+--R           (- 5650456A b c  - 9197038B b c )x
+--R         + 
+--R                         4 7             5 6  13
+--R           (- 11136540A b c  - 8359275B b c )x
+--R         + 
+--R                         5 6             6 5  11
+--R           (- 10166432A b c  - 2860936B b c )x
+--R         + 
+--R                        6 5           7 4  9             7 4            8 3  7
+--R           (- 3427808A b c  - 50584B b c )x  + (552960A b c  - 414720B b c )x
+--R         + 
+--R                      8 3             9 2  5              9 2             10   3
+--R           (1641472A b c  - 1231104B b c )x  + (2007040A b c  - 1505280B b  c)x
+--R         + 
+--R                     10             11
+--R           (860160A b  c - 645120B b  )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                   11 23            11              10  21
+--R           15360B c  x   + (18432A c   + 375296B b c  )x
+--R         + 
+--R                       10             2 9  19
+--R           (450816A b c   + 2687808B b c )x
+--R         + 
+--R                      2 9             3 8  17
+--R           (3235968A b c  + 8417184B b c )x
+--R         + 
+--R                       3 8              4 7  15
+--R           (10166176A b c  + 13019208B b c )x
+--R         + 
+--R                       4 7             5 6  13
+--R           (15783600A b c  + 9789180B b c )x
+--R         + 
+--R                       5 6             6 5  11
+--R           (11901744A b c  + 2870172B b c )x
+--R         + 
+--R                      6 5            7 4  9                7 4            8 3  7
+--R           (3264672A b c  + 172936B b c )x  + (- 1176576A b c  + 882432B b c )x
+--R         + 
+--R                        8 3             9 2  5
+--R           (- 2537472A b c  + 1903104B b c )x
+--R         + 
+--R                      9 2             10   3               10             11
+--R         (- 2437120A b c  + 1827840B b  c)x  + (- 860160A b  c + 645120B b  )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                  10 10             9 8            2 8 6            3 7 4
+--R           184320c  x   + 4300800b c x  + 27525120b c x  + 70778880b c x
+--R         + 
+--R                    4 6 2            5 5
+--R           78643200b c x  + 31457280b c
+--R      *
+--R                  +--------+
+--R          +-+ +-+ |   2
+--R         \|b \|c \|c x  + b
+--R     + 
+--R                   11 12             10 10            2 9 8            3 8 6
+--R           - 15360c  x   - 1105920b c  x   - 12902400b c x  - 55050240b c x
+--R         + 
+--R                       4 7 4            5 6 2            6 5
+--R           - 106168320b c x  - 94371840b c x  - 31457280b c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 730
+
+--S 731 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          14 38           14            13  36
+--R                   - 27B c  x   + (- 27A c   - 3303B b c  )x
+--R                 + 
+--R                               13            2 12  34
+--R                   (- 3303A b c   - 121212B b c  )x
+--R                 + 
+--R                               2 12             3 11  32
+--R                   (- 121212A b c   - 2094768B b c  )x
+--R                 + 
+--R                                3 11              4 10  30
+--R                   (- 2094768A b c   - 20646912B b c  )x
+--R                 + 
+--R                                 4 10               5 9  28
+--R                   (- 20646912A b c   - 128653824B b c )x
+--R                 + 
+--R                                  5 9               6 8  26
+--R                   (- 128653824A b c  - 538638336B b c )x
+--R                 + 
+--R                                  6 8                7 7  24
+--R                   (- 538638336A b c  - 1571733504B b c )x
+--R                 + 
+--R                                   7 7                8 6  22
+--R                   (- 1571733504A b c  - 3261136896B b c )x
+--R                 + 
+--R                                   8 6                9 5  20
+--R                   (- 3261136896A b c  - 4843044864B b c )x
+--R                 + 
+--R                                   9 5                10 4  18
+--R                   (- 4843044864A b c  - 5112594432B b  c )x
+--R                 + 
+--R                                   10 4                11 3  16
+--R                   (- 5112594432A b  c  - 3746562048B b  c )x
+--R                 + 
+--R                                   11 3                12 2  14
+--R                   (- 3746562048A b  c  - 1811939328B b  c )x
+--R                 + 
+--R                                   12 2               13   12
+--R                   (- 1811939328A b  c  - 520093696B b  c)x
+--R                 + 
+--R                                  13               14  10              14 8
+--R                   (- 520093696A b  c - 67108864B b  )x   - 67108864A b  x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  15 39       15           14  37
+--R               B c  x   + (A c   + 365B b c  )x
+--R             + 
+--R                        14           2 13  35
+--R               (365A b c   + 22204B b c  )x
+--R             + 
+--R                        2 13            3 12  33
+--R               (22204A b c   + 534352B b c  )x
+--R             + 
+--R                         3 12             4 11  31
+--R               (534352A b c   + 6735872B b c  )x
+--R             + 
+--R                          4 11              5 10  29
+--R               (6735872A b c   + 51031552B b c  )x
+--R             + 
+--R                           5 10               6 9  27
+--R               (51031552A b c   + 251197440B b c )x
+--R             + 
+--R                            6 9               7 8  25
+--R               (251197440A b c  + 841433088B b c )x
+--R             + 
+--R                            7 8                8 7  23
+--R               (841433088A b c  + 1968635904B b c )x
+--R             + 
+--R                             8 7                9 6  21
+--R               (1968635904A b c  + 3251175424B b c )x
+--R             + 
+--R                             9 6                10 5  19
+--R               (3251175424A b c  + 3774611456B b  c )x
+--R             + 
+--R                             10 5                11 4  17
+--R               (3774611456A b  c  + 3014656000B b  c )x
+--R             + 
+--R                             11 4                12 3  15
+--R               (3014656000A b  c  + 1577058304B b  c )x
+--R             + 
+--R                             12 3               13 2  13
+--R               (1577058304A b  c  + 486539264B b  c )x
+--R             + 
+--R                            13 2              14   11              14   9
+--R               (486539264A b  c  + 67108864B b  c)x   + 67108864A b  c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  15 40       15           14  38
+--R               B c  x   + (A c   + 366B b c  )x
+--R             + 
+--R                        14           2 13  36
+--R               (366A b c   + 22569B b c  )x
+--R             + 
+--R                        2 13            3 12  34
+--R               (22569A b c   + 556556B b c  )x
+--R             + 
+--R                         3 12             4 11  32
+--R               (556556A b c   + 7270224B b c  )x
+--R             + 
+--R                          4 11              5 10  30
+--R               (7270224A b c   + 57767424B b c  )x
+--R             + 
+--R                           5 10               6 9  28
+--R               (57767424A b c   + 302228992B b c )x
+--R             + 
+--R                            6 9                7 8  26
+--R               (302228992A b c  + 1092630528B b c )x
+--R             + 
+--R                             7 8                8 7  24
+--R               (1092630528A b c  + 2810068992B b c )x
+--R             + 
+--R                             8 7                9 6  22
+--R               (2810068992A b c  + 5219811328B b c )x
+--R             + 
+--R                             9 6                10 5  20
+--R               (5219811328A b c  + 7025786880B b  c )x
+--R             + 
+--R                             10 5                11 4  18
+--R               (7025786880A b  c  + 6789267456B b  c )x
+--R             + 
+--R                             11 4                12 3  16
+--R               (6789267456A b  c  + 4591714304B b  c )x
+--R             + 
+--R                             12 3                13 2  14
+--R               (4591714304A b  c  + 2063597568B b  c )x
+--R             + 
+--R                             13 2               14   12
+--R               (2063597568A b  c  + 553648128B b  c)x
+--R             + 
+--R                            14               15  10              15 8
+--R               (553648128A b  c + 67108864B b  )x   + 67108864A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      15 39           15            14  37
+--R               - 27B c  x   + (- 27A c   - 3303B b c  )x
+--R             + 
+--R                           14            2 13  35
+--R               (- 3303A b c   - 121212B b c  )x
+--R             + 
+--R                           2 13             3 12  33
+--R               (- 121212A b c   - 2094768B b c  )x
+--R             + 
+--R                            3 12              4 11  31
+--R               (- 2094768A b c   - 20646912B b c  )x
+--R             + 
+--R                             4 11               5 10  29
+--R               (- 20646912A b c   - 128653824B b c  )x
+--R             + 
+--R                              5 10               6 9  27
+--R               (- 128653824A b c   - 538638336B b c )x
+--R             + 
+--R                              6 9                7 8  25
+--R               (- 538638336A b c  - 1571733504B b c )x
+--R             + 
+--R                               7 8                8 7  23
+--R               (- 1571733504A b c  - 3261136896B b c )x
+--R             + 
+--R                               8 7                9 6  21
+--R               (- 3261136896A b c  - 4843044864B b c )x
+--R             + 
+--R                               9 6                10 5  19
+--R               (- 4843044864A b c  - 5112594432B b  c )x
+--R             + 
+--R                               10 5                11 4  17
+--R               (- 5112594432A b  c  - 3746562048B b  c )x
+--R             + 
+--R                               11 4                12 3  15
+--R               (- 3746562048A b  c  - 1811939328B b  c )x
+--R             + 
+--R                               12 3               13 2  13
+--R               (- 1811939328A b  c  - 520093696B b  c )x
+--R             + 
+--R                              13 2              14   11              14   9
+--R               (- 520093696A b  c  - 67108864B b  c)x   - 67108864A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    15 41         15           14  39
+--R               - B c  x   + (- A c   - 366B b c  )x
+--R             + 
+--R                          14           2 13  37
+--R               (- 366A b c   - 22569B b c  )x
+--R             + 
+--R                          2 13            3 12  35
+--R               (- 22569A b c   - 556556B b c  )x
+--R             + 
+--R                           3 12             4 11  33
+--R               (- 556556A b c   - 7270224B b c  )x
+--R             + 
+--R                            4 11              5 10  31
+--R               (- 7270224A b c   - 57767424B b c  )x
+--R             + 
+--R                             5 10               6 9  29
+--R               (- 57767424A b c   - 302228992B b c )x
+--R             + 
+--R                              6 9                7 8  27
+--R               (- 302228992A b c  - 1092630528B b c )x
+--R             + 
+--R                               7 8                8 7  25
+--R               (- 1092630528A b c  - 2810068992B b c )x
+--R             + 
+--R                               8 7                9 6  23
+--R               (- 2810068992A b c  - 5219811328B b c )x
+--R             + 
+--R                               9 6                10 5  21
+--R               (- 5219811328A b c  - 7025786880B b  c )x
+--R             + 
+--R                               10 5                11 4  19
+--R               (- 7025786880A b  c  - 6789267456B b  c )x
+--R             + 
+--R                               11 4                12 3  17
+--R               (- 6789267456A b  c  - 4591714304B b  c )x
+--R             + 
+--R                               12 3                13 2  15
+--R               (- 4591714304A b  c  - 2063597568B b  c )x
+--R             + 
+--R                               13 2               14   13
+--R               (- 2063597568A b  c  - 553648128B b  c)x
+--R             + 
+--R                              14               15  11              15 9
+--R               (- 553648128A b  c - 67108864B b  )x   - 67108864A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    15 40         15            14  38
+--R               27B c  x   + (27A c   + 3303B b c  )x
+--R             + 
+--R                         14            2 13  36
+--R               (3303A b c   + 121212B b c  )x
+--R             + 
+--R                         2 13             3 12  34
+--R               (121212A b c   + 2094768B b c  )x
+--R             + 
+--R                          3 12              4 11  32
+--R               (2094768A b c   + 20646912B b c  )x
+--R             + 
+--R                           4 11               5 10  30
+--R               (20646912A b c   + 128653824B b c  )x
+--R             + 
+--R                            5 10               6 9  28
+--R               (128653824A b c   + 538638336B b c )x
+--R             + 
+--R                            6 9                7 8  26
+--R               (538638336A b c  + 1571733504B b c )x
+--R             + 
+--R                             7 8                8 7  24
+--R               (1571733504A b c  + 3261136896B b c )x
+--R             + 
+--R                             8 7                9 6  22
+--R               (3261136896A b c  + 4843044864B b c )x
+--R             + 
+--R                             9 6                10 5  20
+--R               (4843044864A b c  + 5112594432B b  c )x
+--R             + 
+--R                             10 5                11 4  18
+--R               (5112594432A b  c  + 3746562048B b  c )x
+--R             + 
+--R                             11 4                12 3  16
+--R               (3746562048A b  c  + 1811939328B b  c )x
+--R             + 
+--R                             12 3               13 2  14
+--R               (1811939328A b  c  + 520093696B b  c )x
+--R             + 
+--R                            13 2              14   12              14   10
+--R               (520093696A b  c  + 67108864B b  c)x   + 67108864A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                15 41         15            14  39
+--R           27B c  x   + (27A c   + 3330B b c  )x
+--R         + 
+--R                     14            2 13  37
+--R           (3330A b c   + 124515B b c  )x
+--R         + 
+--R                     2 13             3 12  35
+--R           (124515A b c   + 2215980B b c  )x
+--R         + 
+--R                      3 12              4 11  33
+--R           (2215980A b c   + 22741680B b c  )x
+--R         + 
+--R                       4 11               5 10  31
+--R           (22741680A b c   + 149300736B b c  )x
+--R         + 
+--R                        5 10               6 9  29
+--R           (149300736A b c   + 667292160B b c )x
+--R         + 
+--R                        6 9                7 8  27
+--R           (667292160A b c  + 2110371840B b c )x
+--R         + 
+--R                         7 8                8 7  25
+--R           (2110371840A b c  + 4832870400B b c )x
+--R         + 
+--R                         8 7                9 6  23
+--R           (4832870400A b c  + 8104181760B b c )x
+--R         + 
+--R                         9 6                10 5  21
+--R           (8104181760A b c  + 9955639296B b  c )x
+--R         + 
+--R                         10 5                11 4  19
+--R           (9955639296A b  c  + 8859156480B b  c )x
+--R         + 
+--R                         11 4                12 3  17
+--R           (8859156480A b  c  + 5558501376B b  c )x
+--R         + 
+--R                         12 3                13 2  15
+--R           (5558501376A b  c  + 2332033024B b  c )x
+--R         + 
+--R                         13 2               14   13
+--R           (2332033024A b  c  + 587202560B b  c)x
+--R         + 
+--R                        14               15  11              15 9
+--R           (587202560A b  c + 67108864B b  )x   + 67108864A b  x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            16 42         16           15  40              15           2 14  38
+--R       - B c  x   + (- A c   - 366B b c  )x   + (- 366A b c   - 22569B b c  )x
+--R     + 
+--R                  2 14            3 13  36
+--R       (- 22569A b c   - 556556B b c  )x
+--R     + 
+--R                   3 13             4 12  34
+--R       (- 556556A b c   - 7270224B b c  )x
+--R     + 
+--R                    4 12              5 11  32
+--R       (- 7270224A b c   - 57767424B b c  )x
+--R     + 
+--R                     5 11               6 10  30
+--R       (- 57767424A b c   - 302228992B b c  )x
+--R     + 
+--R                      6 10                7 9  28
+--R       (- 302228992A b c   - 1092630528B b c )x
+--R     + 
+--R                       7 9                8 8  26
+--R       (- 1092630528A b c  - 2810068992B b c )x
+--R     + 
+--R                       8 8                9 7  24
+--R       (- 2810068992A b c  - 5219811328B b c )x
+--R     + 
+--R                       9 7                10 6  22
+--R       (- 5219811328A b c  - 7025786880B b  c )x
+--R     + 
+--R                       10 6                11 5  20
+--R       (- 7025786880A b  c  - 6789267456B b  c )x
+--R     + 
+--R                       11 5                12 4  18
+--R       (- 6789267456A b  c  - 4591714304B b  c )x
+--R     + 
+--R                       12 4                13 3  16
+--R       (- 4591714304A b  c  - 2063597568B b  c )x
+--R     + 
+--R                       13 3               14 2  14
+--R       (- 2063597568A b  c  - 553648128B b  c )x
+--R     + 
+--R                      14 2              15   12              15   10
+--R       (- 553648128A b  c  - 67108864B b  c)x   - 67108864A b  c x
+--R  /
+--R                  14 28         13 26         2 12 24          3 11 22
+--R                 c  x   + 365b c  x   + 22204b c  x   + 534352b c  x
+--R               + 
+--R                         4 10 20            5 9 18             6 8 16
+--R                 6735872b c  x   + 51031552b c x   + 251197440b c x
+--R               + 
+--R                           7 7 14              8 6 12              9 5 10
+--R                 841433088b c x   + 1968635904b c x   + 3251175424b c x
+--R               + 
+--R                            10 4 8              11 3 6              12 2 4
+--R                 3774611456b  c x  + 3014656000b  c x  + 1577058304b  c x
+--R               + 
+--R                           13   2            14
+--R                 486539264b  c x  + 67108864b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                      14 27          13 25          2 12 23           3 11 21
+--R                 - 27c  x   - 3276b c  x   - 117936b c  x   - 1976832b c  x
+--R               + 
+--R                            4 10 19             5 9 17             6 8 15
+--R                 - 18670080b c  x   - 109983744b c x   - 428654592b c x
+--R               + 
+--R                              7 7 13              8 6 11              9 5 9
+--R                 - 1143078912b c x   - 2118057984b c x   - 2724986880b c x
+--R               + 
+--R                              10 4 7              11 3 5             12 2 3
+--R                 - 2387607552b  c x  - 1358954496b  c x  - 452984832b  c x
+--R               + 
+--R                            13
+--R                 - 67108864b  c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  14 28          13 26          2 12 24           3 11 22
+--R             - 27c  x   - 3303b c  x   - 121212b c  x   - 2094768b c  x
+--R           + 
+--R                        4 10 20             5 9 18             6 8 16
+--R             - 20646912b c  x   - 128653824b c x   - 538638336b c x
+--R           + 
+--R                          7 7 14              8 6 12              9 5 10
+--R             - 1571733504b c x   - 3261136896b c x   - 4843044864b c x
+--R           + 
+--R                          10 4 8              11 3 6              12 2 4
+--R             - 5112594432b  c x  - 3746562048b  c x  - 1811939328b  c x
+--R           + 
+--R                         13   2            14
+--R             - 520093696b  c x  - 67108864b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          15 29         14 27         2 13 25          3 12 23           4 11 21
+--R         c  x   + 365b c  x   + 22204b c  x   + 534352b c  x   + 6735872b c  x
+--R       + 
+--R                  5 10 19             6 9 17             7 8 15
+--R         51031552b c  x   + 251197440b c x   + 841433088b c x
+--R       + 
+--R                    8 7 13              9 6 11              10 5 9
+--R         1968635904b c x   + 3251175424b c x   + 3774611456b  c x
+--R       + 
+--R                  11 4 7              12 3 5             13 2 3            14
+--R       3014656000b  c x  + 1577058304b  c x  + 486539264b  c x  + 67108864b  c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         5 6          6 5  10               6 5           7 4  8
+--R               (- 5040A b c  + 3780B b c )x   + (- 117600A b c  + 88200B b c )x
+--R             + 
+--R                           7 4            8 3  6
+--R               (- 752640A b c  + 564480B b c )x
+--R             + 
+--R                            8 3             9 2  4
+--R               (- 1935360A b c  + 1451520B b c )x
+--R             + 
+--R                            9 2             10   2            10             11
+--R               (- 2150400A b c  + 1612800B b  c)x  - 860160A b  c + 645120B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                      5 7         6 6  12            6 6           7 5  10
+--R               (420A b c  - 315B b c )x   + (30240A b c  - 22680B b c )x
+--R             + 
+--R                         7 5            8 4  8
+--R               (352800A b c  - 264600B b c )x
+--R             + 
+--R                          8 4             9 3  6
+--R               (1505280A b c  - 1128960B b c )x
+--R             + 
+--R                          9 3             10 2  4
+--R               (2903040A b c  - 2177280B b  c )x
+--R             + 
+--R                          10 2             11   2            11             12
+--R               (2580480A b  c  - 1935360B b  c)x  + 860160A b  c - 645120B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                        5 6          6 5  10             6 5            7 4  8
+--R               (10080A b c  - 7560B b c )x   + (235200A b c  - 176400B b c )x
+--R             + 
+--R                          7 4             8 3  6
+--R               (1505280A b c  - 1128960B b c )x
+--R             + 
+--R                          8 3             9 2  4
+--R               (3870720A b c  - 2903040B b c )x
+--R             + 
+--R                          9 2             10   2             10              11
+--R               (4300800A b c  - 3225600B b  c)x  + 1720320A b  c - 1290240B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                        5 7         6 6  12              6 6           7 5  10
+--R               (- 840A b c  + 630B b c )x   + (- 60480A b c  + 45360B b c )x
+--R             + 
+--R                           7 5            8 4  8
+--R               (- 705600A b c  + 529200B b c )x
+--R             + 
+--R                            8 4             9 3  6
+--R               (- 3010560A b c  + 2257920B b c )x
+--R             + 
+--R                            9 3             10 2  4
+--R               (- 5806080A b c  + 4354560B b  c )x
+--R             + 
+--R                          10 2             11   2             11              12
+--R             (- 5160960A b  c  + 3870720B b  c)x  - 1720320A b  c + 1290240B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                         10 20              10              9  18
+--R               - 15360B c  x   + (- 18432A c   - 359936B b c )x
+--R             + 
+--R                             9             2 8  16
+--R               (- 432384A b c  - 2327872B b c )x
+--R             + 
+--R                            2 8             3 7  14
+--R               (- 2803584A b c  - 6089312B b c )x
+--R             + 
+--R                            3 7             4 6  12
+--R               (- 7362592A b c  - 6929896B b c )x
+--R             + 
+--R                            4 6             5 5  10
+--R               (- 8421008A b c  - 2859284B b c )x
+--R             + 
+--R                            5 5           6 4  8
+--R               (- 3480736A b c  - 10888B b c )x
+--R             + 
+--R                         6 4            7 3  6             7 3            8 2  4
+--R               (216064A b c  - 162048B b c )x  + (960512A b c  - 720384B b c )x
+--R             + 
+--R                          8 2             9   2            9             10
+--R               (1576960A b c  - 1182720B b c)x  + 860160A b c - 645120B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                      11 22           11             10  20
+--R               1280B c  x   + (1536A c   + 92288B b c  )x
+--R             + 
+--R                           10             2 9  18
+--R               (110784A b c   + 1084272B b c )x
+--R             + 
+--R                          2 9             3 8  16
+--R               (1303840A b c  + 4684840B b c )x
+--R             + 
+--R                          3 8             4 7  14
+--R               (5650456A b c  + 9197038B b c )x
+--R             + 
+--R                           4 7             5 6  12
+--R               (11136540A b c  + 8359275B b c )x
+--R             + 
+--R                           5 6             6 5  10
+--R               (10166432A b c  + 2860936B b c )x
+--R             + 
+--R                          6 5           7 4  8
+--R               (3427808A b c  + 50584B b c )x
+--R             + 
+--R                           7 4            8 3  6
+--R               (- 552960A b c  + 414720B b c )x
+--R             + 
+--R                            8 3             9 2  4
+--R               (- 1641472A b c  + 1231104B b c )x
+--R             + 
+--R                            9 2             10   2            10             11
+--R               (- 2007040A b c  + 1505280B b  c)x  - 860160A b  c + 645120B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    11 23             11             10  21
+--R           - 1280B c  x   + (- 1536A c   - 92288B b c  )x
+--R         + 
+--R                         10             2 9  19
+--R           (- 110784A b c   - 1084272B b c )x
+--R         + 
+--R                        2 9             3 8  17
+--R           (- 1303840A b c  - 4684840B b c )x
+--R         + 
+--R                        3 8             4 7  15
+--R           (- 5650456A b c  - 9197038B b c )x
+--R         + 
+--R                         4 7             5 6  13
+--R           (- 11136540A b c  - 8359275B b c )x
+--R         + 
+--R                         5 6             6 5  11
+--R           (- 10166432A b c  - 2860936B b c )x
+--R         + 
+--R                        6 5           7 4  9             7 4            8 3  7
+--R           (- 3427808A b c  - 50584B b c )x  + (552960A b c  - 414720B b c )x
+--R         + 
+--R                      8 3             9 2  5              9 2             10   3
+--R           (1641472A b c  - 1231104B b c )x  + (2007040A b c  - 1505280B b  c)x
+--R         + 
+--R                     10             11
+--R           (860160A b  c - 645120B b  )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                   11 23            11              10  21
+--R           15360B c  x   + (18432A c   + 375296B b c  )x
+--R         + 
+--R                       10             2 9  19
+--R           (450816A b c   + 2687808B b c )x
+--R         + 
+--R                      2 9             3 8  17
+--R           (3235968A b c  + 8417184B b c )x
+--R         + 
+--R                       3 8              4 7  15
+--R           (10166176A b c  + 13019208B b c )x
+--R         + 
+--R                       4 7             5 6  13
+--R           (15783600A b c  + 9789180B b c )x
+--R         + 
+--R                       5 6             6 5  11
+--R           (11901744A b c  + 2870172B b c )x
+--R         + 
+--R                      6 5            7 4  9                7 4            8 3  7
+--R           (3264672A b c  + 172936B b c )x  + (- 1176576A b c  + 882432B b c )x
+--R         + 
+--R                        8 3             9 2  5
+--R           (- 2537472A b c  + 1903104B b c )x
+--R         + 
+--R                      9 2             10   3               10             11
+--R         (- 2437120A b c  + 1827840B b  c)x  + (- 860160A b  c + 645120B b  )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R                  10 10             9 8            2 8 6            3 7 4
+--R           184320c  x   + 4300800b c x  + 27525120b c x  + 70778880b c x
+--R         + 
+--R                    4 6 2            5 5
+--R           78643200b c x  + 31457280b c
+--R      *
+--R                        +--------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|b \|c \|c x  + b
+--R     + 
+--R                   11 12             10 10            2 9 8            3 8 6
+--R           - 15360c  x   - 1105920b c  x   - 12902400b c x  - 55050240b c x
+--R         + 
+--R                       4 7 4            5 6 2            6 5
+--R           - 106168320b c x  - 94371840b c x  - 31457280b c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      12 34           12            11  32
+--R               - 24B c  x   + (- 24A c   - 2312B b c  )x
+--R             + 
+--R                           11           2 10  30
+--R               (- 2312A b c   - 66352B b c  )x
+--R             + 
+--R                          2 10            3 9  28
+--R               (- 66352A b c   - 887744B b c )x
+--R             + 
+--R                           3 9             4 8  26
+--R               (- 887744A b c  - 6680960B b c )x
+--R             + 
+--R                            4 8              5 7  24
+--R               (- 6680960A b c  - 31203328B b c )x
+--R             + 
+--R                             5 7              6 6  22
+--R               (- 31203328A b c  - 95535104B b c )x
+--R             + 
+--R                             6 6               7 5  20
+--R               (- 95535104A b c  - 197197824B b c )x
+--R             + 
+--R                              7 5               8 4  18
+--R               (- 197197824A b c  - 276430848B b c )x
+--R             + 
+--R                              8 4               9 3  16
+--R               (- 276430848A b c  - 259522560B b c )x
+--R             + 
+--R                              9 3               10 2  14
+--R               (- 259522560A b c  - 156237824B b  c )x
+--R             + 
+--R                              10 2              11   12
+--R               (- 156237824A b  c  - 54525952B b  c)x
+--R             + 
+--R                             11              12  10             12 8
+--R               (- 54525952A b  c - 8388608B b  )x   - 8388608A b  x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              13 36       13           12  34            12           2 11  32
+--R           B c  x   + (A c   + 289B b c  )x   + (289A b c   + 14016B b c  )x
+--R         + 
+--R                    2 11            3 10  30
+--R           (14016A b c   + 269984B b c  )x
+--R         + 
+--R                     3 10             4 9  28
+--R           (269984A b c   + 2727296B b c )x
+--R         + 
+--R                      4 9              5 8  26
+--R           (2727296A b c  + 16528512B b c )x
+--R         + 
+--R                       5 8              6 7  24
+--R           (16528512A b c  + 64749568B b c )x
+--R         + 
+--R                       6 7               7 6  22
+--R           (64749568A b c  + 171016192B b c )x
+--R         + 
+--R                        7 6               8 5  20
+--R           (171016192A b c  + 310837248B b c )x
+--R         + 
+--R                        8 5               9 4  18
+--R           (310837248A b c  + 389742592B b c )x
+--R         + 
+--R                        9 4               10 3  16
+--R           (389742592A b c  + 331350016B b  c )x
+--R         + 
+--R                        10 3               11 2  14
+--R           (331350016A b  c  + 182452224B b  c )x
+--R         + 
+--R                        11 2              12   12
+--R           (182452224A b  c  + 58720256B b  c)x
+--R         + 
+--R                       12              13  10             13 8
+--R           (58720256A b  c + 8388608B b  )x   + 8388608A b  x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                13 37         13           12  35
+--R           - B c  x   + (- A c   - 289B b c  )x
+--R         + 
+--R                      12           2 11  33
+--R           (- 289A b c   - 14016B b c  )x
+--R         + 
+--R                      2 11            3 10  31
+--R           (- 14016A b c   - 269984B b c  )x
+--R         + 
+--R                       3 10             4 9  29
+--R           (- 269984A b c   - 2727296B b c )x
+--R         + 
+--R                        4 9              5 8  27
+--R           (- 2727296A b c  - 16528512B b c )x
+--R         + 
+--R                         5 8              6 7  25
+--R           (- 16528512A b c  - 64749568B b c )x
+--R         + 
+--R                         6 7               7 6  23
+--R           (- 64749568A b c  - 171016192B b c )x
+--R         + 
+--R                          7 6               8 5  21
+--R           (- 171016192A b c  - 310837248B b c )x
+--R         + 
+--R                          8 5               9 4  19
+--R           (- 310837248A b c  - 389742592B b c )x
+--R         + 
+--R                          9 4               10 3  17
+--R           (- 389742592A b c  - 331350016B b  c )x
+--R         + 
+--R                          10 3               11 2  15
+--R           (- 331350016A b  c  - 182452224B b  c )x
+--R         + 
+--R                          11 2              12   13
+--R           (- 182452224A b  c  - 58720256B b  c)x
+--R         + 
+--R                         12              13  11             13 9
+--R           (- 58720256A b  c - 8388608B b  )x   - 8388608A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                13 37         13            12  35
+--R           24B c  x   + (24A c   + 2336B b c  )x
+--R         + 
+--R                     12           2 11  33            2 11            3 10  31
+--R           (2336A b c   + 68664B b c  )x   + (68664A b c   + 954096B b c  )x
+--R         + 
+--R                     3 10             4 9  29
+--R           (954096A b c   + 7568704B b c )x
+--R         + 
+--R                      4 9              5 8  27
+--R           (7568704A b c  + 37884288B b c )x
+--R         + 
+--R                       5 8               6 7  25
+--R           (37884288A b c  + 126738432B b c )x
+--R         + 
+--R                        6 7               7 6  23
+--R           (126738432A b c  + 292732928B b c )x
+--R         + 
+--R                        7 6               8 5  21
+--R           (292732928A b c  + 473628672B b c )x
+--R         + 
+--R                        8 5               9 4  19
+--R           (473628672A b c  + 535953408B b c )x
+--R         + 
+--R                        9 4               10 3  17
+--R           (535953408A b c  + 415760384B b  c )x
+--R         + 
+--R                        10 3               11 2  15
+--R           (415760384A b  c  + 210763776B b  c )x
+--R         + 
+--R                        11 2              12   13
+--R           (210763776A b  c  + 62914560B b  c)x
+--R         + 
+--R                       12              13  11             13 9
+--R           (62914560A b  c + 8388608B b  )x   + 8388608A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              12 24         11 22         2 10 20          3 9 18
+--R             c  x   + 288b c  x   + 13728b c  x   + 256256b c x
+--R           + 
+--R                     4 8 16            5 7 14            6 6 12
+--R             2471040b c x   + 14057472b c x   + 50692096b c x
+--R           + 
+--R                       7 5 10             8 4 8             9 3 6
+--R             120324096b c x   + 190513152b c x  + 199229440b c x
+--R           + 
+--R                       10 2 4            11   2           12
+--R             132120576b  c x  + 50331648b  c x  + 8388608b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  12 24          11 22         2 10 20          3 9 18
+--R             - 24c  x   - 2312b c  x   - 66352b c  x   - 887744b c x
+--R           + 
+--R                       4 8 16            5 7 14            6 6 12
+--R             - 6680960b c x   - 31203328b c x   - 95535104b c x
+--R           + 
+--R                         7 5 10             8 4 8             9 3 6
+--R             - 197197824b c x   - 276430848b c x  - 259522560b c x
+--R           + 
+--R                         10 2 4            11   2           12
+--R             - 156237824b  c x  - 54525952b  c x  - 8388608b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 733
+
+)clear all
+
+--S 734 of 3139
+t0:=x^5*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      +-----------+
+--R            7      5  |   4      2
+--R   (1)  (B x  + A x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 734
+
+--S 735 of 3139
+r0:=1/10*B*x^4*(b*x^2+c*x^4)^(3/2)/c+1/256*b^4*(7*b*B-10*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(9/2)-1/256*b^3*(7*b*B-10*A*c)*_
+   sqrt(b*x^2+c*x^4)/c^4+1/384*b^2*(7*b*B-10*A*c)*x^2*_
+   sqrt(b*x^2+c*x^4)/c^3-1/480*b*(7*b*B-10*A*c)*x^4*sqrt(b*x^2+c*x^4)/c^2-_
+   1/80*(7*b*B-10*A*c)*x^6*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                        2 +-+
+--R                4          5           x \|c
+--R       (- 150A b c + 105B b )atanh(--------------)
+--R                                    +-----------+
+--R                                    |   4      2
+--R                                   \|c x  + b x
+--R     + 
+--R                 4 8          4          3  6           3        2 2  4
+--R           384B c x  + (480A c  + 48B b c )x  + (80A b c  - 56B b c )x
+--R         + 
+--R                    2 2        3   2         3          4
+--R           (- 100A b c  + 70B b c)x  + 150A b c - 105B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R          4 +-+
+--R     3840c \|c
+--R                                                    Type: Expression(Integer)
+--E 735
+
+--S 736 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         4 5          5 4  8            5 4           6 3  6
+--R                 (1500A b c  - 1050B b c )x  + (24000A b c  - 16800B b c )x
+--R               + 
+--R                           6 3           7 2  4             7 2            8   2
+--R                 (100800A b c  - 70560B b c )x  + (153600A b c  - 107520B b c)x
+--R               + 
+--R                         8            9
+--R                 76800A b c - 53760B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                      4 6         5 5  10             5 5          6 4  8
+--R             (- 150A b c  + 105B b c )x   + (- 7500A b c  + 5250B b c )x
+--R           + 
+--R                        6 4           7 3  6               7 3            8 2  4
+--R             (- 60000A b c  + 42000B b c )x  + (- 168000A b c  + 117600B b c )x
+--R           + 
+--R                         8 2            9   2           9            10
+--R             (- 192000A b c  + 134400B b c)x  - 76800A b c + 53760B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                     9 19            9             8  17
+--R             - 384B c x   + (- 480A c  - 19248B b c )x
+--R           + 
+--R                          8            2 7  15
+--R             (- 24080A b c  - 155944B b c )x
+--R           + 
+--R                         2 7            3 6  13
+--R             (- 195900A b c  - 446550B b c )x
+--R           + 
+--R                         3 6            4 5  11
+--R             (- 564750A b c  - 526275B b c )x
+--R           + 
+--R                         4 5            5 4  9
+--R             (- 671500A b c  - 218078B b c )x
+--R           + 
+--R                         5 4           6 3  7              6 3           7 2  5
+--R             (- 296160A b c  + 10704B b c )x  + (- 80960A b c  + 56672B b c )x
+--R           + 
+--R                         7 2           8   3              8            9
+--R             (- 140800A b c  + 98560B b c)x  + (- 76800A b c + 53760B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                    9 19           9             8  17
+--R             3840B c x   + (4800A c  + 65760B b c )x
+--R           + 
+--R                        8            2 7  15             2 7            3 6  13
+--R             (82400A b c  + 327088B b c )x   + (411960A b c  + 682380B b c )x
+--R           + 
+--R                       3 6            4 5  11             4 5            5 4  9
+--R             (865140A b c  + 635490B b c )x   + (815260A b c  + 215750B b c )x
+--R           + 
+--R                       5 4           6 3  7             6 3           7 2  5
+--R             (323840A b c  - 30080B b c )x  + (141760A b c  - 99232B b c )x
+--R           + 
+--R                       7 2            8   3            8            9
+--R             (179200A b c  - 125440B b c)x  + (76800A b c - 53760B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                   8 8            7 6           2 6 4           3 5 2
+--R             38400c x  + 614400b c x  + 2580480b c x  + 3932160b c x
+--R           + 
+--R                     4 4
+--R             1966080b c
+--R        *
+--R                    +--------+
+--R            +-+ +-+ |   2
+--R           \|b \|c \|c x  + b
+--R       + 
+--R                    9 10            8 8           2 7 6           3 6 4
+--R             - 3840c x   - 192000b c x  - 1536000b c x  - 4300800b c x
+--R           + 
+--R                       4 5 2           5 4
+--R             - 4915200b c x  - 1966080b c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                           4 5          5 4  8              5 4           6 3  6
+--R                 (- 3000A b c  + 2100B b c )x  + (- 48000A b c  + 33600B b c )x
+--R               + 
+--R                             6 3            7 2  4
+--R                 (- 201600A b c  + 141120B b c )x
+--R               + 
+--R                             7 2            8   2            8             9
+--R                 (- 307200A b c  + 215040B b c)x  - 153600A b c + 107520B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                    4 6         5 5  10            5 5           6 4  8
+--R             (300A b c  - 210B b c )x   + (15000A b c  - 10500B b c )x
+--R           + 
+--R                       6 4           7 3  6             7 3            8 2  4
+--R             (120000A b c  - 84000B b c )x  + (336000A b c  - 235200B b c )x
+--R           + 
+--R                       8 2            9   2            9             10
+--R             (384000A b c  - 268800B b c)x  + 153600A b c - 107520B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                     9 19            9             8  17
+--R             - 384B c x   + (- 480A c  - 19248B b c )x
+--R           + 
+--R                          8            2 7  15
+--R             (- 24080A b c  - 155944B b c )x
+--R           + 
+--R                         2 7            3 6  13
+--R             (- 195900A b c  - 446550B b c )x
+--R           + 
+--R                         3 6            4 5  11
+--R             (- 564750A b c  - 526275B b c )x
+--R           + 
+--R                         4 5            5 4  9
+--R             (- 671500A b c  - 218078B b c )x
+--R           + 
+--R                         5 4           6 3  7              6 3           7 2  5
+--R             (- 296160A b c  + 10704B b c )x  + (- 80960A b c  + 56672B b c )x
+--R           + 
+--R                         7 2           8   3              8            9
+--R             (- 140800A b c  + 98560B b c)x  + (- 76800A b c + 53760B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                    9 19           9             8  17
+--R             3840B c x   + (4800A c  + 65760B b c )x
+--R           + 
+--R                        8            2 7  15             2 7            3 6  13
+--R             (82400A b c  + 327088B b c )x   + (411960A b c  + 682380B b c )x
+--R           + 
+--R                       3 6            4 5  11             4 5            5 4  9
+--R             (865140A b c  + 635490B b c )x   + (815260A b c  + 215750B b c )x
+--R           + 
+--R                       5 4           6 3  7             6 3           7 2  5
+--R             (323840A b c  - 30080B b c )x  + (141760A b c  - 99232B b c )x
+--R           + 
+--R                       7 2            8   3            8            9
+--R             (179200A b c  - 125440B b c)x  + (76800A b c - 53760B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                   8 8            7 6           2 6 4           3 5 2
+--R             38400c x  + 614400b c x  + 2580480b c x  + 3932160b c x
+--R           + 
+--R                     4 4
+--R             1966080b c
+--R        *
+--R                      +--------+
+--R            +---+ +-+ |   2
+--R           \|- c \|b \|c x  + b
+--R       + 
+--R                    9 10            8 8           2 7 6           3 6 4
+--R             - 3840c x   - 192000b c x  - 1536000b c x  - 4300800b c x
+--R           + 
+--R                       4 5 2           5 4
+--R             - 4915200b c x  - 1966080b c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 736
+
+--S 737 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       4 5          5 4  8            5 4           6 3  6
+--R               (1500A b c  - 1050B b c )x  + (24000A b c  - 16800B b c )x
+--R             + 
+--R                         6 3           7 2  4             7 2            8   2
+--R               (100800A b c  - 70560B b c )x  + (153600A b c  - 107520B b c)x
+--R             + 
+--R                       8            9
+--R               76800A b c - 53760B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                    4 6         5 5  10             5 5          6 4  8
+--R           (- 150A b c  + 105B b c )x   + (- 7500A b c  + 5250B b c )x
+--R         + 
+--R                      6 4           7 3  6               7 3            8 2  4
+--R           (- 60000A b c  + 42000B b c )x  + (- 168000A b c  + 117600B b c )x
+--R         + 
+--R                       8 2            9   2           9            10
+--R           (- 192000A b c  + 134400B b c)x  - 76800A b c + 53760B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                       4 5          5 4  8            5 4           6 3  6
+--R               (1500A b c  - 1050B b c )x  + (24000A b c  - 16800B b c )x
+--R             + 
+--R                         6 3           7 2  4             7 2            8   2
+--R               (100800A b c  - 70560B b c )x  + (153600A b c  - 107520B b c)x
+--R             + 
+--R                       8            9
+--R               76800A b c - 53760B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                    4 6         5 5  10             5 5          6 4  8
+--R           (- 150A b c  + 105B b c )x   + (- 7500A b c  + 5250B b c )x
+--R         + 
+--R                      6 4           7 3  6               7 3            8 2  4
+--R           (- 60000A b c  + 42000B b c )x  + (- 168000A b c  + 117600B b c )x
+--R         + 
+--R                       8 2            9   2           9            10
+--R           (- 192000A b c  + 134400B b c)x  - 76800A b c + 53760B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                        8 16             8             7  14
+--R               - 3840B c x   + (- 4800A c  - 61920B b c )x
+--R             + 
+--R                            7            2 6  12
+--R               (- 77600A b c  - 265168B b c )x
+--R             + 
+--R                           2 6            3 5  10
+--R               (- 334360A b c  - 417212B b c )x
+--R             + 
+--R                           3 5            4 4  8
+--R               (- 530780A b c  - 218278B b c )x
+--R             + 
+--R                           4 4          5 3  6              5 3           6 2  4
+--R               (- 284480A b c  + 2528B b c )x  + (- 39360A b c  + 27552B b c )x
+--R             + 
+--R                           6 2           7   2           7            8
+--R               (- 102400A b c  + 71680B b c)x  - 76800A b c + 53760B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                     9 18          9             8  16
+--R               384B c x   + (480A c  + 19248B b c )x
+--R             + 
+--R                          8            2 7  14
+--R               (24080A b c  + 155944B b c )x
+--R             + 
+--R                         2 7            3 6  12
+--R               (195900A b c  + 446550B b c )x
+--R             + 
+--R                         3 6            4 5  10
+--R               (564750A b c  + 526275B b c )x
+--R             + 
+--R                         4 5            5 4  8             5 4           6 3  6
+--R               (671500A b c  + 218078B b c )x  + (296160A b c  - 10704B b c )x
+--R             + 
+--R                        6 3           7 2  4             7 2           8   2
+--R               (80960A b c  - 56672B b c )x  + (140800A b c  - 98560B b c)x
+--R             + 
+--R                       8            9
+--R               76800A b c - 53760B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                   9 19            9             8  17
+--R           - 384B c x   + (- 480A c  - 19248B b c )x
+--R         + 
+--R                        8            2 7  15
+--R           (- 24080A b c  - 155944B b c )x
+--R         + 
+--R                       2 7            3 6  13
+--R           (- 195900A b c  - 446550B b c )x
+--R         + 
+--R                       3 6            4 5  11
+--R           (- 564750A b c  - 526275B b c )x
+--R         + 
+--R                       4 5            5 4  9               5 4           6 3  7
+--R           (- 671500A b c  - 218078B b c )x  + (- 296160A b c  + 10704B b c )x
+--R         + 
+--R                      6 3           7 2  5               7 2           8   3
+--R           (- 80960A b c  + 56672B b c )x  + (- 140800A b c  + 98560B b c)x
+--R         + 
+--R                      8            9
+--R           (- 76800A b c + 53760B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                  9 19           9             8  17
+--R           3840B c x   + (4800A c  + 65760B b c )x
+--R         + 
+--R                      8            2 7  15             2 7            3 6  13
+--R           (82400A b c  + 327088B b c )x   + (411960A b c  + 682380B b c )x
+--R         + 
+--R                     3 6            4 5  11             4 5            5 4  9
+--R           (865140A b c  + 635490B b c )x   + (815260A b c  + 215750B b c )x
+--R         + 
+--R                     5 4           6 3  7             6 3           7 2  5
+--R           (323840A b c  - 30080B b c )x  + (141760A b c  - 99232B b c )x
+--R         + 
+--R                     7 2            8   3            8            9
+--R           (179200A b c  - 125440B b c)x  + (76800A b c - 53760B b )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                   8 8            7 6           2 6 4           3 5 2
+--R             38400c x  + 614400b c x  + 2580480b c x  + 3932160b c x
+--R           + 
+--R                     4 4
+--R             1966080b c
+--R      *
+--R                  +--------+
+--R          +-+ +-+ |   2
+--R         \|b \|c \|c x  + b
+--R     + 
+--R                  9 10            8 8           2 7 6           3 6 4
+--R           - 3840c x   - 192000b c x  - 1536000b c x  - 4300800b c x
+--R         + 
+--R                     4 5 2           5 4
+--R           - 4915200b c x  - 1966080b c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          12 32           12            11  30
+--R                   - 23B c  x   + (- 23A c   - 2047B b c  )x
+--R                 + 
+--R                               11           2 10  28
+--R                   (- 2047A b c   - 54648B b c  )x
+--R                 + 
+--R                              2 10            3 9  26
+--R                   (- 54648A b c   - 684112B b c )x
+--R                 + 
+--R                               3 9             4 8  24
+--R                   (- 684112A b c  - 4841408B b c )x
+--R                 + 
+--R                                4 8              5 7  22
+--R                   (- 4841408A b c  - 21355776B b c )x
+--R                 + 
+--R                                 5 7              6 6  20
+--R                   (- 21355776A b c  - 61988864B b c )x
+--R                 + 
+--R                                 6 6               7 5  18
+--R                   (- 61988864A b c  - 121716736B b c )x
+--R                 + 
+--R                                  7 5               8 4  16
+--R                   (- 121716736A b c  - 162791424B b c )x
+--R                 + 
+--R                                  8 4               9 3  14
+--R                   (- 162791424A b c  - 146210816B b c )x
+--R                 + 
+--R                                  9 3              10 2  12
+--R                   (- 146210816A b c  - 84410368B b  c )x
+--R                 + 
+--R                                 10 2              11   10
+--R                   (- 84410368A b  c  - 28311552B b  c)x
+--R                 + 
+--R                                 11              12  8             12 6
+--R                   (- 28311552A b  c - 4194304B b  )x  - 4194304A b  x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                    13 33         13           12  31
+--R               - B c  x   + (- A c   - 265B b c  )x
+--R             + 
+--R                          12           2 11  29
+--R               (- 265A b c   - 11704B b c  )x
+--R             + 
+--R                          2 11            3 10  27
+--R               (- 11704A b c   - 203632B b c  )x
+--R             + 
+--R                           3 10             4 9  25
+--R               (- 203632A b c   - 1839552B b c )x
+--R             + 
+--R                            4 9             5 8  23
+--R               (- 1839552A b c  - 9847552B b c )x
+--R             + 
+--R                            5 8              6 7  21
+--R               (- 9847552A b c  - 33546240B b c )x
+--R             + 
+--R                             6 7              7 6  19
+--R               (- 33546240A b c  - 75481088B b c )x
+--R             + 
+--R                             7 6               8 5  17
+--R               (- 75481088A b c  - 113639424B b c )x
+--R             + 
+--R                              8 5               9 4  15
+--R               (- 113639424A b c  - 113311744B b c )x
+--R             + 
+--R                              9 4              10 3  13
+--R               (- 113311744A b c  - 71827456B b  c )x
+--R             + 
+--R                             10 3              11 2  11
+--R               (- 71827456A b  c  - 26214400B b  c )x
+--R             + 
+--R                             11 2             12   9             12   7
+--R               (- 26214400A b  c  - 4194304B b  c)x  - 4194304A b  c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  13 34       13           12  32
+--R               B c  x   + (A c   + 266B b c  )x
+--R             + 
+--R                        12           2 11  30
+--R               (266A b c   + 11969B b c  )x
+--R             + 
+--R                        2 11            3 10  28
+--R               (11969A b c   + 215336B b c  )x
+--R             + 
+--R                         3 10             4 9  26
+--R               (215336A b c   + 2043184B b c )x
+--R             + 
+--R                          4 9              5 8  24
+--R               (2043184A b c  + 11687104B b c )x
+--R             + 
+--R                           5 8              6 7  22
+--R               (11687104A b c  + 43393792B b c )x
+--R             + 
+--R                           6 7               7 6  20
+--R               (43393792A b c  + 109027328B b c )x
+--R             + 
+--R                            7 6               8 5  18
+--R               (109027328A b c  + 189120512B b c )x
+--R             + 
+--R                            8 5               9 4  16
+--R               (189120512A b c  + 226951168B b c )x
+--R             + 
+--R                            9 4               10 3  14
+--R               (226951168A b c  + 185139200B b  c )x
+--R             + 
+--R                            10 3              11 2  12
+--R               (185139200A b  c  + 98041856B b  c )x
+--R             + 
+--R                           11 2              12   10
+--R               (98041856A b  c  + 30408704B b  c)x
+--R             + 
+--R                           12              13  8             13 6
+--R               (30408704A b  c + 4194304B b  )x  + 4194304A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    13 33         13            12  31
+--R               23B c  x   + (23A c   + 2047B b c  )x
+--R             + 
+--R                         12           2 11  29
+--R               (2047A b c   + 54648B b c  )x
+--R             + 
+--R                        2 11            3 10  27
+--R               (54648A b c   + 684112B b c  )x
+--R             + 
+--R                         3 10             4 9  25
+--R               (684112A b c   + 4841408B b c )x
+--R             + 
+--R                          4 9              5 8  23
+--R               (4841408A b c  + 21355776B b c )x
+--R             + 
+--R                           5 8              6 7  21
+--R               (21355776A b c  + 61988864B b c )x
+--R             + 
+--R                           6 7               7 6  19
+--R               (61988864A b c  + 121716736B b c )x
+--R             + 
+--R                            7 6               8 5  17
+--R               (121716736A b c  + 162791424B b c )x
+--R             + 
+--R                            8 5               9 4  15
+--R               (162791424A b c  + 146210816B b c )x
+--R             + 
+--R                            9 4              10 3  13
+--R               (146210816A b c  + 84410368B b  c )x
+--R             + 
+--R                           10 3              11 2  11
+--R               (84410368A b  c  + 28311552B b  c )x
+--R             + 
+--R                           11 2             12   9             12   7
+--R               (28311552A b  c  + 4194304B b  c)x  + 4194304A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    13 35         13           12  33
+--R               - B c  x   + (- A c   - 266B b c  )x
+--R             + 
+--R                          12           2 11  31
+--R               (- 266A b c   - 11969B b c  )x
+--R             + 
+--R                          2 11            3 10  29
+--R               (- 11969A b c   - 215336B b c  )x
+--R             + 
+--R                           3 10             4 9  27
+--R               (- 215336A b c   - 2043184B b c )x
+--R             + 
+--R                            4 9              5 8  25
+--R               (- 2043184A b c  - 11687104B b c )x
+--R             + 
+--R                             5 8              6 7  23
+--R               (- 11687104A b c  - 43393792B b c )x
+--R             + 
+--R                             6 7               7 6  21
+--R               (- 43393792A b c  - 109027328B b c )x
+--R             + 
+--R                              7 6               8 5  19
+--R               (- 109027328A b c  - 189120512B b c )x
+--R             + 
+--R                              8 5               9 4  17
+--R               (- 189120512A b c  - 226951168B b c )x
+--R             + 
+--R                              9 4               10 3  15
+--R               (- 226951168A b c  - 185139200B b  c )x
+--R             + 
+--R                              10 3              11 2  13
+--R               (- 185139200A b  c  - 98041856B b  c )x
+--R             + 
+--R                             11 2              12   11
+--R               (- 98041856A b  c  - 30408704B b  c)x
+--R             + 
+--R                             12              13  9             13 7
+--R               (- 30408704A b  c - 4194304B b  )x  - 4194304A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      13 34           13            12  32
+--R               - 23B c  x   + (- 23A c   - 2047B b c  )x
+--R             + 
+--R                           12           2 11  30
+--R               (- 2047A b c   - 54648B b c  )x
+--R             + 
+--R                          2 11            3 10  28
+--R               (- 54648A b c   - 684112B b c  )x
+--R             + 
+--R                           3 10             4 9  26
+--R               (- 684112A b c   - 4841408B b c )x
+--R             + 
+--R                            4 9              5 8  24
+--R               (- 4841408A b c  - 21355776B b c )x
+--R             + 
+--R                             5 8              6 7  22
+--R               (- 21355776A b c  - 61988864B b c )x
+--R             + 
+--R                             6 7               7 6  20
+--R               (- 61988864A b c  - 121716736B b c )x
+--R             + 
+--R                              7 6               8 5  18
+--R               (- 121716736A b c  - 162791424B b c )x
+--R             + 
+--R                              8 5               9 4  16
+--R               (- 162791424A b c  - 146210816B b c )x
+--R             + 
+--R                              9 4              10 3  14
+--R               (- 146210816A b c  - 84410368B b  c )x
+--R             + 
+--R                             10 3              11 2  12
+--R               (- 84410368A b  c  - 28311552B b  c )x
+--R             + 
+--R                             11 2             12   10             12   8
+--R               (- 28311552A b  c  - 4194304B b  c)x   - 4194304A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                13 35         13            12  33
+--R           23B c  x   + (23A c   + 2070B b c  )x
+--R         + 
+--R                     12           2 11  31            2 11            3 10  29
+--R           (2070A b c   + 56695B b c  )x   + (56695A b c   + 738760B b c  )x
+--R         + 
+--R                     3 10             4 9  27
+--R           (738760A b c   + 5525520B b c )x
+--R         + 
+--R                      4 9              5 8  25
+--R           (5525520A b c  + 26197184B b c )x
+--R         + 
+--R                       5 8              6 7  23
+--R           (26197184A b c  + 83344640B b c )x
+--R         + 
+--R                       6 7               7 6  21
+--R           (83344640A b c  + 183705600B b c )x
+--R         + 
+--R                        7 6               8 5  19
+--R           (183705600A b c  + 284508160B b c )x
+--R         + 
+--R                        8 5               9 4  17
+--R           (284508160A b c  + 309002240B b c )x
+--R         + 
+--R                        9 4               10 3  15
+--R           (309002240A b c  + 230621184B b  c )x
+--R         + 
+--R                        10 3               11 2  13
+--R           (230621184A b  c  + 112721920B b  c )x
+--R         + 
+--R                        11 2              12   11
+--R           (112721920A b  c  + 32505856B b  c)x
+--R         + 
+--R                       12              13  9             13 7
+--R           (32505856A b  c + 4194304B b  )x  + 4194304A b  x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R          14 36       14           13  34            13           2 12  32
+--R       B c  x   + (A c   + 266B b c  )x   + (266A b c   + 11969B b c  )x
+--R     + 
+--R                2 12            3 11  30             3 11             4 10  28
+--R       (11969A b c   + 215336B b c  )x   + (215336A b c   + 2043184B b c  )x
+--R     + 
+--R                  4 10              5 9  26
+--R       (2043184A b c   + 11687104B b c )x
+--R     + 
+--R                   5 9              6 8  24
+--R       (11687104A b c  + 43393792B b c )x
+--R     + 
+--R                   6 8               7 7  22
+--R       (43393792A b c  + 109027328B b c )x
+--R     + 
+--R                    7 7               8 6  20
+--R       (109027328A b c  + 189120512B b c )x
+--R     + 
+--R                    8 6               9 5  18
+--R       (189120512A b c  + 226951168B b c )x
+--R     + 
+--R                    9 5               10 4  16
+--R       (226951168A b c  + 185139200B b  c )x
+--R     + 
+--R                    10 4              11 3  14
+--R       (185139200A b  c  + 98041856B b  c )x
+--R     + 
+--R                   11 3              12 2  12
+--R       (98041856A b  c  + 30408704B b  c )x
+--R     + 
+--R                   12 2             13   10             13   8
+--R       (30408704A b  c  + 4194304B b  c)x   + 4194304A b  c x
+--R  /
+--R                  12 24         11 22         2 10 20          3 9 18
+--R                 c  x   + 265b c  x   + 11704b c  x   + 203632b c x
+--R               + 
+--R                         4 8 16           5 7 14            6 6 12
+--R                 1839552b c x   + 9847552b c x   + 33546240b c x
+--R               + 
+--R                          7 5 10             8 4 8             9 3 6
+--R                 75481088b c x   + 113639424b c x  + 113311744b c x
+--R               + 
+--R                          10 2 4            11   2           12
+--R                 71827456b  c x  + 26214400b  c x  + 4194304b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                    12 23          11 21         2 10 19          3 9 17
+--R                 23c  x   + 2024b c  x   + 52624b c  x   + 631488b c x
+--R               + 
+--R                         4 8 15            5 7 13            6 6 11
+--R                 4209920b c x   + 17145856b c x   + 44843008b c x
+--R               + 
+--R                          7 5 9            8 4 7            9 3 5
+--R                 76873728b c x  + 85917696b c x  + 60293120b c x
+--R               + 
+--R                          10 2 3           11
+--R                 24117248b  c x  + 4194304b  c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  12 24          11 22         2 10 20          3 9 18
+--R             - 23c  x   - 2047b c  x   - 54648b c  x   - 684112b c x
+--R           + 
+--R                       4 8 16            5 7 14            6 6 12
+--R             - 4841408b c x   - 21355776b c x   - 61988864b c x
+--R           + 
+--R                         7 5 10             8 4 8             9 3 6
+--R             - 121716736b c x   - 162791424b c x  - 146210816b c x
+--R           + 
+--R                        10 2 4            11   2           12
+--R             - 84410368b  c x  - 28311552b  c x  - 4194304b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R            13 25         12 23         2 11 21          3 10 19
+--R         - c  x   - 265b c  x   - 11704b c  x   - 203632b c  x
+--R       + 
+--R                   4 9 17           5 8 15            6 7 13            7 6 11
+--R         - 1839552b c x   - 9847552b c x   - 33546240b c x   - 75481088b c x
+--R       + 
+--R                     8 5 9             9 4 7            10 3 5            11 2 3
+--R         - 113639424b c x  - 113311744b c x  - 71827456b  c x  - 26214400b  c x
+--R       + 
+--R                   12
+--R         - 4194304b  c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 738
+
+--S 739 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       4 5          5 4  8            5 4           6 3  6
+--R               (1500A b c  - 1050B b c )x  + (24000A b c  - 16800B b c )x
+--R             + 
+--R                         6 3           7 2  4             7 2            8   2
+--R               (100800A b c  - 70560B b c )x  + (153600A b c  - 107520B b c)x
+--R             + 
+--R                       8            9
+--R               76800A b c - 53760B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                        4 6         5 5  10             5 5          6 4  8
+--R               (- 150A b c  + 105B b c )x   + (- 7500A b c  + 5250B b c )x
+--R             + 
+--R                          6 4           7 3  6
+--R               (- 60000A b c  + 42000B b c )x
+--R             + 
+--R                           7 3            8 2  4
+--R               (- 168000A b c  + 117600B b c )x
+--R             + 
+--R                           8 2            9   2           9            10
+--R               (- 192000A b c  + 134400B b c)x  - 76800A b c + 53760B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                         4 5          5 4  8              5 4           6 3  6
+--R               (- 3000A b c  + 2100B b c )x  + (- 48000A b c  + 33600B b c )x
+--R             + 
+--R                           6 3            7 2  4
+--R               (- 201600A b c  + 141120B b c )x
+--R             + 
+--R                           7 2            8   2            8             9
+--R               (- 307200A b c  + 215040B b c)x  - 153600A b c + 107520B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                      4 6         5 5  10            5 5           6 4  8
+--R               (300A b c  - 210B b c )x   + (15000A b c  - 10500B b c )x
+--R             + 
+--R                         6 4           7 3  6             7 3            8 2  4
+--R               (120000A b c  - 84000B b c )x  + (336000A b c  - 235200B b c )x
+--R             + 
+--R                         8 2            9   2            9             10
+--R               (384000A b c  - 268800B b c)x  + 153600A b c - 107520B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                        8 16             8             7  14
+--R               - 3840B c x   + (- 4800A c  - 61920B b c )x
+--R             + 
+--R                            7            2 6  12
+--R               (- 77600A b c  - 265168B b c )x
+--R             + 
+--R                           2 6            3 5  10
+--R               (- 334360A b c  - 417212B b c )x
+--R             + 
+--R                           3 5            4 4  8
+--R               (- 530780A b c  - 218278B b c )x
+--R             + 
+--R                           4 4          5 3  6              5 3           6 2  4
+--R               (- 284480A b c  + 2528B b c )x  + (- 39360A b c  + 27552B b c )x
+--R             + 
+--R                           6 2           7   2           7            8
+--R               (- 102400A b c  + 71680B b c)x  - 76800A b c + 53760B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                     9 18          9             8  16
+--R               384B c x   + (480A c  + 19248B b c )x
+--R             + 
+--R                          8            2 7  14
+--R               (24080A b c  + 155944B b c )x
+--R             + 
+--R                         2 7            3 6  12
+--R               (195900A b c  + 446550B b c )x
+--R             + 
+--R                         3 6            4 5  10
+--R               (564750A b c  + 526275B b c )x
+--R             + 
+--R                         4 5            5 4  8             5 4           6 3  6
+--R               (671500A b c  + 218078B b c )x  + (296160A b c  - 10704B b c )x
+--R             + 
+--R                        6 3           7 2  4             7 2           8   2
+--R               (80960A b c  - 56672B b c )x  + (140800A b c  - 98560B b c)x
+--R             + 
+--R                       8            9
+--R               76800A b c - 53760B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                   9 19            9             8  17
+--R           - 384B c x   + (- 480A c  - 19248B b c )x
+--R         + 
+--R                        8            2 7  15
+--R           (- 24080A b c  - 155944B b c )x
+--R         + 
+--R                       2 7            3 6  13
+--R           (- 195900A b c  - 446550B b c )x
+--R         + 
+--R                       3 6            4 5  11
+--R           (- 564750A b c  - 526275B b c )x
+--R         + 
+--R                       4 5            5 4  9               5 4           6 3  7
+--R           (- 671500A b c  - 218078B b c )x  + (- 296160A b c  + 10704B b c )x
+--R         + 
+--R                      6 3           7 2  5               7 2           8   3
+--R           (- 80960A b c  + 56672B b c )x  + (- 140800A b c  + 98560B b c)x
+--R         + 
+--R                      8            9
+--R           (- 76800A b c + 53760B b )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                  9 19           9             8  17
+--R           3840B c x   + (4800A c  + 65760B b c )x
+--R         + 
+--R                      8            2 7  15             2 7            3 6  13
+--R           (82400A b c  + 327088B b c )x   + (411960A b c  + 682380B b c )x
+--R         + 
+--R                     3 6            4 5  11             4 5            5 4  9
+--R           (865140A b c  + 635490B b c )x   + (815260A b c  + 215750B b c )x
+--R         + 
+--R                     5 4           6 3  7             6 3           7 2  5
+--R           (323840A b c  - 30080B b c )x  + (141760A b c  - 99232B b c )x
+--R         + 
+--R                     7 2            8   3            8            9
+--R           (179200A b c  - 125440B b c)x  + (76800A b c - 53760B b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R                   8 8            7 6           2 6 4           3 5 2
+--R             38400c x  + 614400b c x  + 2580480b c x  + 3932160b c x
+--R           + 
+--R                     4 4
+--R             1966080b c
+--R      *
+--R                        +--------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|b \|c \|c x  + b
+--R     + 
+--R                  9 10            8 8           2 7 6           3 6 4
+--R           - 3840c x   - 192000b c x  - 1536000b c x  - 4300800b c x
+--R         + 
+--R                     4 5 2           5 4
+--R           - 4915200b c x  - 1966080b c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      10 28           10            9  26
+--R               - 20B c  x   + (- 20A c   - 1340B b c )x
+--R             + 
+--R                           9           2 8  24
+--R               (- 1340A b c  - 26664B b c )x
+--R             + 
+--R                          2 8            3 7  22
+--R               (- 26664A b c  - 244992B b c )x
+--R             + 
+--R                           3 7             4 6  20
+--R               (- 244992A b c  - 1244672B b c )x
+--R             + 
+--R                            4 6             5 5  18
+--R               (- 1244672A b c  - 3820544B b c )x
+--R             + 
+--R                            5 5             6 4  16
+--R               (- 3820544A b c  - 7383040B b c )x
+--R             + 
+--R                            6 4             7 3  14
+--R               (- 7383040A b c  - 9043968B b c )x
+--R             + 
+--R                            7 3             8 2  12
+--R               (- 9043968A b c  - 6815744B b c )x
+--R             + 
+--R                            8 2             9   10
+--R               (- 6815744A b c  - 2883584B b c)x
+--R             + 
+--R                            9             10  8            10 6
+--R               (- 2883584A b c - 524288B b  )x  - 524288A b  x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              11 30       11           10  28            10          2 9  26
+--R           B c  x   + (A c   + 201B b c  )x   + (201A b c   + 6800B b c )x
+--R         + 
+--R                   2 9           3 8  24            3 8            4 7  22
+--R           (6800A b c  + 91080B b c )x   + (91080A b c  + 633600B b c )x
+--R         + 
+--R                     4 7             5 6  20
+--R           (633600A b c  + 2599168B b c )x
+--R         + 
+--R                      5 6             6 5  18
+--R           (2599168A b c  + 6709248B b c )x
+--R         + 
+--R                      6 5              7 4  16
+--R           (6709248A b c  + 11212800B b c )x
+--R         + 
+--R                       7 4              8 3  14
+--R           (11212800A b c  + 12124160B b c )x
+--R         + 
+--R                       8 3             9 2  12
+--R           (12124160A b c  + 8192000B b c )x
+--R         + 
+--R                      9 2             10   10              10             11  8
+--R           (8192000A b c  + 3145728B b  c)x   + (3145728A b  c + 524288B b  )x
+--R         + 
+--R                    11 6
+--R           524288A b  x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                11 31         11           10  29
+--R           - B c  x   + (- A c   - 201B b c  )x
+--R         + 
+--R                      10          2 9  27             2 9           3 8  25
+--R           (- 201A b c   - 6800B b c )x   + (- 6800A b c  - 91080B b c )x
+--R         + 
+--R                      3 8            4 7  23
+--R           (- 91080A b c  - 633600B b c )x
+--R         + 
+--R                       4 7             5 6  21
+--R           (- 633600A b c  - 2599168B b c )x
+--R         + 
+--R                        5 6             6 5  19
+--R           (- 2599168A b c  - 6709248B b c )x
+--R         + 
+--R                        6 5              7 4  17
+--R           (- 6709248A b c  - 11212800B b c )x
+--R         + 
+--R                         7 4              8 3  15
+--R           (- 11212800A b c  - 12124160B b c )x
+--R         + 
+--R                         8 3             9 2  13
+--R           (- 12124160A b c  - 8192000B b c )x
+--R         + 
+--R                        9 2             10   11
+--R           (- 8192000A b c  - 3145728B b  c)x
+--R         + 
+--R                        10             11  9            11 7
+--R           (- 3145728A b  c - 524288B b  )x  - 524288A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                11 31         11            10  29
+--R           20B c  x   + (20A c   + 1360B b c  )x
+--R         + 
+--R                     10           2 9  27            2 9            3 8  25
+--R           (1360A b c   + 28004B b c )x   + (28004A b c  + 271656B b c )x
+--R         + 
+--R                     3 8             4 7  23
+--R           (271656A b c  + 1489664B b c )x
+--R         + 
+--R                      4 7             5 6  21
+--R           (1489664A b c  + 5065216B b c )x
+--R         + 
+--R                      5 6              6 5  19
+--R           (5065216A b c  + 11203584B b c )x
+--R         + 
+--R                       6 5              7 4  17
+--R           (11203584A b c  + 16427008B b c )x
+--R         + 
+--R                       7 4              8 3  15
+--R           (16427008A b c  + 15859712B b c )x
+--R         + 
+--R                       8 3             9 2  13
+--R           (15859712A b c  + 9699328B b c )x
+--R         + 
+--R                      9 2             10   11              10             11  9
+--R           (9699328A b c  + 3407872B b  c)x   + (3407872A b  c + 524288B b  )x
+--R         + 
+--R                    11 7
+--R           524288A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              10 20         9 18        2 8 16         3 7 14          4 6 12
+--R             c  x   + 200b c x   + 6600b c x   + 84480b c x   + 549120b c x
+--R           + 
+--R                     5 5 10           6 4 8           7 3 6           8 2 4
+--R             2050048b c x   + 4659200b c x  + 6553600b c x  + 5570560b c x
+--R           + 
+--R                     9   2          10
+--R             2621440b c x  + 524288b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  10 20          9 18         2 8 16          3 7 14
+--R             - 20c  x   - 1340b c x   - 26664b c x   - 244992b c x
+--R           + 
+--R                       4 6 12           5 5 10           6 4 8           7 3 6
+--R             - 1244672b c x   - 3820544b c x   - 7383040b c x  - 9043968b c x
+--R           + 
+--R                       8 2 4           9   2          10
+--R             - 6815744b c x  - 2883584b c x  - 524288b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 740
+
+)clear all
+
+--S 741 of 3139
+t0:=x^3*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      +-----------+
+--R            5      3  |   4      2
+--R   (1)  (B x  + A x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 741
+
+--S 742 of 3139
+r0:=1/8*B*x^2*(b*x^2+c*x^4)^(3/2)/c-1/128*b^3*(5*b*B-8*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(7/2)+1/128*b^2*(5*b*B-8*A*c)*_
+   sqrt(b*x^2+c*x^4)/c^3-1/192*b*(5*b*B-8*A*c)*x^2*sqrt(b*x^2+c*x^4)/c^2-_
+   1/48*(5*b*B-8*A*c)*x^4*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                    2 +-+
+--R             3         4           x \|c
+--R       (24A b c - 15B b )atanh(--------------)
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R     + 
+--R                3 6         3         2  4           2        2   2        2
+--R           48B c x  + (64A c  + 8B b c )x  + (16A b c  - 10B b c)x  - 24A b c
+--R         + 
+--R                3
+--R           15B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R         3 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        3 4         4 3  6           4 3          5 2  4
+--R                 (192A b c  - 120B b c )x  + (1920A b c  - 1200B b c )x
+--R               + 
+--R                         5 2          6   2          6           7
+--R                 (4608A b c  - 2880B b c)x  + 3072A b c - 1920B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     3 5        4 4  8            4 4         5 3  6
+--R             (- 24A b c  + 15B b c )x  + (- 768A b c  + 480B b c )x
+--R           + 
+--R                       5 3          6 2  4             6 2          7   2
+--R             (- 3840A b c  + 2400B b c )x  + (- 6144A b c  + 3840B b c)x
+--R           + 
+--R                      7           8
+--R             - 3072A b c + 1920B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                    7 15           7            6  13
+--R             - 48B c x   + (- 64A c  - 1544B b c )x
+--R           + 
+--R                         6          2 5  11              2 5           3 4  9
+--R             (- 2064A b c  - 7926B b c )x   + (- 10728A b c  - 13263B b c )x
+--R           + 
+--R                        3 4          4 3  7             4 3         5 2  5
+--R             (- 18176A b c  - 7072B b c )x  + (- 8448A b c  - 864B b c )x
+--R           + 
+--R                     5 2          6   3           6           7
+--R             (4096A b c  - 2560B b c)x  + (3072A b c - 1920B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                   7 15          7            6  13
+--R             384B c x   + (512A c  + 4288B b c )x
+--R           + 
+--R                       6           2 5  11            2 5           3 4  9
+--R             (5760A b c  + 13680B b c )x   + (18624A b c  + 16776B b c )x
+--R           + 
+--R                      3 4          4 3  7           4 3          5 2  5
+--R             (22720A b c  + 7304B b c )x  + (6784A b c  + 1904B b c )x
+--R           + 
+--R                       5 2          6   3             6           7
+--R             (- 5632A b c  + 3520B b c)x  + (- 3072A b c + 1920B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                                                                    +--------+
+--R               6 6           5 4         2 4 2         3 3  +-+ +-+ |   2
+--R         (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|b \|c \|c x  + b
+--R       + 
+--R                7 8           6 6         2 5 4         3 4 2         4 3  +-+
+--R         (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|c
+--R     ,
+--R
+--R                        3 4         4 3  6           4 3          5 2  4
+--R                 (384A b c  - 240B b c )x  + (3840A b c  - 2400B b c )x
+--R               + 
+--R                         5 2          6   2          6           7
+--R                 (9216A b c  - 5760B b c)x  + 6144A b c - 3840B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     3 5        4 4  8             4 4         5 3  6
+--R             (- 48A b c  + 30B b c )x  + (- 1536A b c  + 960B b c )x
+--R           + 
+--R                       5 3          6 2  4              6 2          7   2
+--R             (- 7680A b c  + 4800B b c )x  + (- 12288A b c  + 7680B b c)x
+--R           + 
+--R                      7           8
+--R             - 6144A b c + 3840B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                    7 15           7            6  13
+--R             - 48B c x   + (- 64A c  - 1544B b c )x
+--R           + 
+--R                         6          2 5  11              2 5           3 4  9
+--R             (- 2064A b c  - 7926B b c )x   + (- 10728A b c  - 13263B b c )x
+--R           + 
+--R                        3 4          4 3  7             4 3         5 2  5
+--R             (- 18176A b c  - 7072B b c )x  + (- 8448A b c  - 864B b c )x
+--R           + 
+--R                     5 2          6   3           6           7
+--R             (4096A b c  - 2560B b c)x  + (3072A b c - 1920B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                   7 15          7            6  13
+--R             384B c x   + (512A c  + 4288B b c )x
+--R           + 
+--R                       6           2 5  11            2 5           3 4  9
+--R             (5760A b c  + 13680B b c )x   + (18624A b c  + 16776B b c )x
+--R           + 
+--R                      3 4          4 3  7           4 3          5 2  5
+--R             (22720A b c  + 7304B b c )x  + (6784A b c  + 1904B b c )x
+--R           + 
+--R                       5 2          6   3             6           7
+--R             (- 5632A b c  + 3520B b c)x  + (- 3072A b c + 1920B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                                                                      +--------+
+--R               6 6           5 4         2 4 2         3 3  +---+ +-+ |   2
+--R         (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|- c \|b \|c x  + b
+--R       + 
+--R              7 8           6 6         2 5 4         3 4 2         4 3  +---+
+--R       (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 743
+
+--S 744 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      3 4         4 3  6           4 3          5 2  4
+--R               (192A b c  - 120B b c )x  + (1920A b c  - 1200B b c )x
+--R             + 
+--R                       5 2          6   2          6           7
+--R               (4608A b c  - 2880B b c)x  + 3072A b c - 1920B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   3 5        4 4  8            4 4         5 3  6
+--R           (- 24A b c  + 15B b c )x  + (- 768A b c  + 480B b c )x
+--R         + 
+--R                     5 3          6 2  4             6 2          7   2
+--R           (- 3840A b c  + 2400B b c )x  + (- 6144A b c  + 3840B b c)x
+--R         + 
+--R                    7           8
+--R           - 3072A b c + 1920B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                        3 4         4 3  6             4 3          5 2  4
+--R               (- 192A b c  + 120B b c )x  + (- 1920A b c  + 1200B b c )x
+--R             + 
+--R                         5 2          6   2          6           7
+--R               (- 4608A b c  + 2880B b c)x  - 3072A b c + 1920B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                 3 5        4 4  8          4 4         5 3  6
+--R           (24A b c  - 15B b c )x  + (768A b c  - 480B b c )x
+--R         + 
+--R                   5 3          6 2  4           6 2          7   2          7
+--R           (3840A b c  - 2400B b c )x  + (6144A b c  - 3840B b c)x  + 3072A b c
+--R         + 
+--R                    8
+--R           - 1920B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                       6 12            6            5  10
+--R               - 384B c x   + (- 512A c  - 3904B b c )x
+--R             + 
+--R                           5          2 4  8              2 4          3 3  6
+--R               (- 5248A b c  - 9776B b c )x  + (- 13376A b c  - 7000B b c )x
+--R             + 
+--R                         3 3         4 2  4           4 2          5   2
+--R               (- 9344A b c  - 304B b c )x  + (2560A b c  - 1600B b c)x
+--R             + 
+--R                      5           6
+--R               3072A b c - 1920B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                    7 14         7            6  12
+--R               48B c x   + (64A c  + 1544B b c )x
+--R             + 
+--R                         6          2 5  10            2 5           3 4  8
+--R               (2064A b c  + 7926B b c )x   + (10728A b c  + 13263B b c )x
+--R             + 
+--R                        3 4          4 3  6           4 3         5 2  4
+--R               (18176A b c  + 7072B b c )x  + (8448A b c  + 864B b c )x
+--R             + 
+--R                         5 2          6   2          6           7
+--R               (- 4096A b c  + 2560B b c)x  - 3072A b c + 1920B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  7 15           7            6  13
+--R           - 48B c x   + (- 64A c  - 1544B b c )x
+--R         + 
+--R                       6          2 5  11              2 5           3 4  9
+--R           (- 2064A b c  - 7926B b c )x   + (- 10728A b c  - 13263B b c )x
+--R         + 
+--R                      3 4          4 3  7             4 3         5 2  5
+--R           (- 18176A b c  - 7072B b c )x  + (- 8448A b c  - 864B b c )x
+--R         + 
+--R                   5 2          6   3           6           7
+--R           (4096A b c  - 2560B b c)x  + (3072A b c - 1920B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                 7 15          7            6  13
+--R           384B c x   + (512A c  + 4288B b c )x
+--R         + 
+--R                     6           2 5  11            2 5           3 4  9
+--R           (5760A b c  + 13680B b c )x   + (18624A b c  + 16776B b c )x
+--R         + 
+--R                    3 4          4 3  7           4 3          5 2  5
+--R           (22720A b c  + 7304B b c )x  + (6784A b c  + 1904B b c )x
+--R         + 
+--R                     5 2          6   3             6           7
+--R           (- 5632A b c  + 3520B b c)x  + (- 3072A b c + 1920B b )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                                                                  +--------+
+--R             6 6           5 4         2 4 2         3 3  +-+ +-+ |   2
+--R       (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|b \|c \|c x  + b
+--R     + 
+--R              7 8           6 6         2 5 4         3 4 2         4 3  +-+
+--R       (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          10 26           10            9  24
+--R                   - 19B c  x   + (- 19A c   - 1159B b c )x
+--R                 + 
+--R                               9           2 8  22
+--R                   (- 1159A b c  - 21204B b c )x
+--R                 + 
+--R                              2 8            3 7  20
+--R                   (- 21204A b c  - 180576B b c )x
+--R                 + 
+--R                               3 7            4 6  18
+--R                   (- 180576A b c  - 856064B b c )x
+--R                 + 
+--R                               4 6             5 5  16
+--R                   (- 856064A b c  - 2466048B b c )x
+--R                 + 
+--R                                5 5             6 4  14
+--R                   (- 2466048A b c  - 4494336B b c )x
+--R                 + 
+--R                                6 4             7 3  12
+--R                   (- 4494336A b c  - 5214208B b c )x
+--R                 + 
+--R                                7 3             8 2  10
+--R                   (- 5214208A b c  - 3735552B b c )x
+--R                 + 
+--R                                8 2             9   8
+--R                   (- 3735552A b c  - 1507328B b c)x
+--R                 + 
+--R                                9             10  6            10 4
+--R                   (- 1507328A b c - 262144B b  )x  - 262144A b  x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  11 27       11           10  25            10          2 9  23
+--R               B c  x   + (A c   + 181B b c  )x   + (181A b c   + 5460B b c )x
+--R             + 
+--R                       2 9           3 8  21            3 8            4 7  19
+--R               (5460A b c  + 64416B b c )x   + (64416A b c  + 388608B b c )x
+--R             + 
+--R                         4 7             5 6  17
+--R               (388608A b c  + 1354496B b c )x
+--R             + 
+--R                          5 6             6 5  15
+--R               (1354496A b c  + 2888704B b c )x
+--R             + 
+--R                          6 5             7 4  13
+--R               (2888704A b c  + 3829760B b c )x
+--R             + 
+--R                          7 4             8 3  11
+--R               (3829760A b c  + 3080192B b c )x
+--R             + 
+--R                          8 3             9 2  9
+--R               (3080192A b c  + 1376256B b c )x
+--R             + 
+--R                          9 2            10   7            10   5
+--R               (1376256A b c  + 262144B b  c)x  + 262144A b  c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  11 28       11           10  26            10          2 9  24
+--R               B c  x   + (A c   + 182B b c  )x   + (182A b c   + 5641B b c )x
+--R             + 
+--R                       2 9           3 8  22            3 8            4 7  20
+--R               (5641A b c  + 69876B b c )x   + (69876A b c  + 453024B b c )x
+--R             + 
+--R                         4 7             5 6  18
+--R               (453024A b c  + 1743104B b c )x
+--R             + 
+--R                          5 6             6 5  16
+--R               (1743104A b c  + 4243200B b c )x
+--R             + 
+--R                          6 5             7 4  14
+--R               (4243200A b c  + 6718464B b c )x
+--R             + 
+--R                          7 4             8 3  12
+--R               (6718464A b c  + 6909952B b c )x
+--R             + 
+--R                          8 3             9 2  10
+--R               (6909952A b c  + 4456448B b c )x
+--R             + 
+--R                          9 2             10   8
+--R               (4456448A b c  + 1638400B b  c)x
+--R             + 
+--R                          10             11  6            11 4
+--R               (1638400A b  c + 262144B b  )x  + 262144A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      11 27           11            10  25
+--R               - 19B c  x   + (- 19A c   - 1159B b c  )x
+--R             + 
+--R                           10           2 9  23
+--R               (- 1159A b c   - 21204B b c )x
+--R             + 
+--R                          2 9            3 8  21
+--R               (- 21204A b c  - 180576B b c )x
+--R             + 
+--R                           3 8            4 7  19
+--R               (- 180576A b c  - 856064B b c )x
+--R             + 
+--R                           4 7             5 6  17
+--R               (- 856064A b c  - 2466048B b c )x
+--R             + 
+--R                            5 6             6 5  15
+--R               (- 2466048A b c  - 4494336B b c )x
+--R             + 
+--R                            6 5             7 4  13
+--R               (- 4494336A b c  - 5214208B b c )x
+--R             + 
+--R                            7 4             8 3  11
+--R               (- 5214208A b c  - 3735552B b c )x
+--R             + 
+--R                            8 3             9 2  9
+--R               (- 3735552A b c  - 1507328B b c )x
+--R             + 
+--R                            9 2            10   7            10   5
+--R               (- 1507328A b c  - 262144B b  c)x  - 262144A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    11 29         11           10  27
+--R               - B c  x   + (- A c   - 182B b c  )x
+--R             + 
+--R                          10          2 9  25             2 9           3 8  23
+--R               (- 182A b c   - 5641B b c )x   + (- 5641A b c  - 69876B b c )x
+--R             + 
+--R                          3 8            4 7  21
+--R               (- 69876A b c  - 453024B b c )x
+--R             + 
+--R                           4 7             5 6  19
+--R               (- 453024A b c  - 1743104B b c )x
+--R             + 
+--R                            5 6             6 5  17
+--R               (- 1743104A b c  - 4243200B b c )x
+--R             + 
+--R                            6 5             7 4  15
+--R               (- 4243200A b c  - 6718464B b c )x
+--R             + 
+--R                            7 4             8 3  13
+--R               (- 6718464A b c  - 6909952B b c )x
+--R             + 
+--R                            8 3             9 2  11
+--R               (- 6909952A b c  - 4456448B b c )x
+--R             + 
+--R                            9 2             10   9
+--R               (- 4456448A b c  - 1638400B b  c)x
+--R             + 
+--R                            10             11  7            11 5
+--R               (- 1638400A b  c - 262144B b  )x  - 262144A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    11 28         11            10  26
+--R               19B c  x   + (19A c   + 1159B b c  )x
+--R             + 
+--R                         10           2 9  24            2 9            3 8  22
+--R               (1159A b c   + 21204B b c )x   + (21204A b c  + 180576B b c )x
+--R             + 
+--R                         3 8            4 7  20
+--R               (180576A b c  + 856064B b c )x
+--R             + 
+--R                         4 7             5 6  18
+--R               (856064A b c  + 2466048B b c )x
+--R             + 
+--R                          5 6             6 5  16
+--R               (2466048A b c  + 4494336B b c )x
+--R             + 
+--R                          6 5             7 4  14
+--R               (4494336A b c  + 5214208B b c )x
+--R             + 
+--R                          7 4             8 3  12
+--R               (5214208A b c  + 3735552B b c )x
+--R             + 
+--R                          8 3             9 2  10
+--R               (3735552A b c  + 1507328B b c )x
+--R             + 
+--R                          9 2            10   8            10   6
+--R               (1507328A b c  + 262144B b  c)x  + 262144A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                11 29         11            10  27
+--R           19B c  x   + (19A c   + 1178B b c  )x
+--R         + 
+--R                     10           2 9  25            2 9            3 8  23
+--R           (1178A b c   + 22363B b c )x   + (22363A b c  + 201780B b c )x
+--R         + 
+--R                     3 8             4 7  21
+--R           (201780A b c  + 1036640B b c )x
+--R         + 
+--R                      4 7             5 6  19
+--R           (1036640A b c  + 3322112B b c )x
+--R         + 
+--R                      5 6             6 5  17
+--R           (3322112A b c  + 6960384B b c )x
+--R         + 
+--R                      6 5             7 4  15
+--R           (6960384A b c  + 9708544B b c )x
+--R         + 
+--R                      7 4             8 3  13
+--R           (9708544A b c  + 8949760B b c )x
+--R         + 
+--R                      8 3             9 2  11
+--R           (8949760A b c  + 5242880B b c )x
+--R         + 
+--R                      9 2             10   9              10             11  7
+--R           (5242880A b c  + 1769472B b  c)x  + (1769472A b  c + 262144B b  )x
+--R         + 
+--R                    11 5
+--R           262144A b  x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            12 30         12           11  28              11          2 10  26
+--R       - B c  x   + (- A c   - 182B b c  )x   + (- 182A b c   - 5641B b c  )x
+--R     + 
+--R                 2 10           3 9  24              3 9            4 8  22
+--R       (- 5641A b c   - 69876B b c )x   + (- 69876A b c  - 453024B b c )x
+--R     + 
+--R                   4 8             5 7  20
+--R       (- 453024A b c  - 1743104B b c )x
+--R     + 
+--R                    5 7             6 6  18
+--R       (- 1743104A b c  - 4243200B b c )x
+--R     + 
+--R                    6 6             7 5  16
+--R       (- 4243200A b c  - 6718464B b c )x
+--R     + 
+--R                    7 5             8 4  14
+--R       (- 6718464A b c  - 6909952B b c )x
+--R     + 
+--R                    8 4             9 3  12
+--R       (- 6909952A b c  - 4456448B b c )x
+--R     + 
+--R                    9 3             10 2  10
+--R       (- 4456448A b c  - 1638400B b  c )x
+--R     + 
+--R                    10 2            11   8            11   6
+--R       (- 1638400A b  c  - 262144B b  c)x  - 262144A b  c x
+--R  /
+--R                  10 20         9 18        2 8 16         3 7 14
+--R                 c  x   + 181b c x   + 5460b c x   + 64416b c x
+--R               + 
+--R                        4 6 12           5 5 10           6 4 8           7 3 6
+--R                 388608b c x   + 1354496b c x   + 2888704b c x  + 3829760b c x
+--R               + 
+--R                         8 2 4           9   2          10
+--R                 3080192b c x  + 1376256b c x  + 262144b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                      10 19          9 17         2 8 15          3 7 13
+--R                 - 19c  x   - 1140b c x   - 20064b c x   - 160512b c x
+--R               + 
+--R                          4 6 11           5 5 9           6 4 7           7 3 5
+--R                 - 695552b c x   - 1770496b c x  - 2723840b c x  - 2490368b c x
+--R               + 
+--R                           8 2 3          9
+--R                 - 1245184b c x  - 262144b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  10 20          9 18         2 8 16          3 7 14
+--R             - 19c  x   - 1159b c x   - 21204b c x   - 180576b c x
+--R           + 
+--R                      4 6 12           5 5 10           6 4 8           7 3 6
+--R             - 856064b c x   - 2466048b c x   - 4494336b c x  - 5214208b c x
+--R           + 
+--R                       8 2 4           9   2          10
+--R             - 3735552b c x  - 1507328b c x  - 262144b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          11 21         10 19        2 9 17         3 8 15          4 7 13
+--R         c  x   + 181b c  x   + 5460b c x   + 64416b c x   + 388608b c x
+--R       + 
+--R                 5 6 11           6 5 9           7 4 7           8 3 5
+--R         1354496b c x   + 2888704b c x  + 3829760b c x  + 3080192b c x
+--R       + 
+--R                 9 2 3          10
+--R         1376256b c x  + 262144b  c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 745
+
+--S 746 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        3 4         4 3  6             4 3          5 2  4
+--R               (- 192A b c  + 120B b c )x  + (- 1920A b c  + 1200B b c )x
+--R             + 
+--R                         5 2          6   2          6           7
+--R               (- 4608A b c  + 2880B b c)x  - 3072A b c + 1920B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                     3 5        4 4  8          4 4         5 3  6
+--R               (24A b c  - 15B b c )x  + (768A b c  - 480B b c )x
+--R             + 
+--R                       5 3          6 2  4           6 2          7   2
+--R               (3840A b c  - 2400B b c )x  + (6144A b c  - 3840B b c)x
+--R             + 
+--R                      7           8
+--R               3072A b c - 1920B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                      3 4         4 3  6           4 3          5 2  4
+--R               (384A b c  - 240B b c )x  + (3840A b c  - 2400B b c )x
+--R             + 
+--R                       5 2          6   2          6           7
+--R               (9216A b c  - 5760B b c)x  + 6144A b c - 3840B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                       3 5        4 4  8             4 4         5 3  6
+--R               (- 48A b c  + 30B b c )x  + (- 1536A b c  + 960B b c )x
+--R             + 
+--R                         5 3          6 2  4              6 2          7   2
+--R               (- 7680A b c  + 4800B b c )x  + (- 12288A b c  + 7680B b c)x
+--R             + 
+--R                        7           8
+--R               - 6144A b c + 3840B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                       6 12            6            5  10
+--R               - 384B c x   + (- 512A c  - 3904B b c )x
+--R             + 
+--R                           5          2 4  8              2 4          3 3  6
+--R               (- 5248A b c  - 9776B b c )x  + (- 13376A b c  - 7000B b c )x
+--R             + 
+--R                         3 3         4 2  4           4 2          5   2
+--R               (- 9344A b c  - 304B b c )x  + (2560A b c  - 1600B b c)x
+--R             + 
+--R                      5           6
+--R               3072A b c - 1920B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                    7 14         7            6  12
+--R               48B c x   + (64A c  + 1544B b c )x
+--R             + 
+--R                         6          2 5  10            2 5           3 4  8
+--R               (2064A b c  + 7926B b c )x   + (10728A b c  + 13263B b c )x
+--R             + 
+--R                        3 4          4 3  6           4 3         5 2  4
+--R               (18176A b c  + 7072B b c )x  + (8448A b c  + 864B b c )x
+--R             + 
+--R                         5 2          6   2          6           7
+--R               (- 4096A b c  + 2560B b c)x  - 3072A b c + 1920B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  7 15           7            6  13
+--R           - 48B c x   + (- 64A c  - 1544B b c )x
+--R         + 
+--R                       6          2 5  11              2 5           3 4  9
+--R           (- 2064A b c  - 7926B b c )x   + (- 10728A b c  - 13263B b c )x
+--R         + 
+--R                      3 4          4 3  7             4 3         5 2  5
+--R           (- 18176A b c  - 7072B b c )x  + (- 8448A b c  - 864B b c )x
+--R         + 
+--R                   5 2          6   3           6           7
+--R           (4096A b c  - 2560B b c)x  + (3072A b c - 1920B b )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                 7 15          7            6  13
+--R           384B c x   + (512A c  + 4288B b c )x
+--R         + 
+--R                     6           2 5  11            2 5           3 4  9
+--R           (5760A b c  + 13680B b c )x   + (18624A b c  + 16776B b c )x
+--R         + 
+--R                    3 4          4 3  7           4 3          5 2  5
+--R           (22720A b c  + 7304B b c )x  + (6784A b c  + 1904B b c )x
+--R         + 
+--R                     5 2          6   3             6           7
+--R           (- 5632A b c  + 3520B b c)x  + (- 3072A b c + 1920B b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R               6 6           5 4         2 4 2         3 3  +---+ +-+ +-+
+--R         (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|- c \|b \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R            7 8           6 6         2 5 4         3 4 2         4 3  +---+ +-+
+--R     (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      8 22           8           7  20
+--R               - 16B c x   + (- 16A c  - 688B b c )x
+--R             + 
+--R                          7          2 6  18             2 6           3 5  16
+--R               (- 688A b c  - 8736B b c )x   + (- 8736A b c  - 50304B b c )x
+--R             + 
+--R                          3 5            4 4  14
+--R               (- 50304A b c  - 154880B b c )x
+--R             + 
+--R                           4 4            5 3  12
+--R               (- 154880A b c  - 272384B b c )x
+--R             + 
+--R                           5 3            6 2  10
+--R               (- 272384A b c  - 274432B b c )x
+--R             + 
+--R                           6 2            7   8               7            8  6
+--R               (- 274432A b c  - 147456B b c)x  + (- 147456A b c - 32768B b )x
+--R             + 
+--R                         8 4
+--R               - 32768A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              9 24       9           8  22            8          2 7  20
+--R           B c x   + (A c  + 129B b c )x   + (129A b c  + 2816B b c )x
+--R         + 
+--R                   2 7           3 6  18            3 6            4 5  16
+--R           (2816A b c  + 24192B b c )x   + (24192A b c  + 105984B b c )x
+--R         + 
+--R                     4 5            5 4  14             5 4            6 3  12
+--R           (105984A b c  + 264704B b c )x   + (264704A b c  + 393216B b c )x
+--R         + 
+--R                     6 3            7 2  10             7 2            8   8
+--R           (393216A b c  + 344064B b c )x   + (344064A b c  + 163840B b c)x
+--R         + 
+--R                     8            9  6           9 4
+--R           (163840A b c + 32768B b )x  + 32768A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                9 25         9           8  23              8          2 7  21
+--R           - B c x   + (- A c  - 129B b c )x   + (- 129A b c  - 2816B b c )x
+--R         + 
+--R                     2 7           3 6  19              3 6            4 5  17
+--R           (- 2816A b c  - 24192B b c )x   + (- 24192A b c  - 105984B b c )x
+--R         + 
+--R                       4 5            5 4  15
+--R           (- 105984A b c  - 264704B b c )x
+--R         + 
+--R                       5 4            6 3  13
+--R           (- 264704A b c  - 393216B b c )x
+--R         + 
+--R                       6 3            7 2  11               7 2            8   9
+--R           (- 393216A b c  - 344064B b c )x   + (- 344064A b c  - 163840B b c)x
+--R         + 
+--R                       8            9  7           9 5
+--R           (- 163840A b c - 32768B b )x  - 32768A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                9 25         9           8  23            8          2 7  21
+--R           16B c x   + (16A c  + 704B b c )x   + (704A b c  + 9424B b c )x
+--R         + 
+--R                   2 7           3 6  19            3 6            4 5  17
+--R           (9424A b c  + 59040B b c )x   + (59040A b c  + 205184B b c )x
+--R         + 
+--R                     4 5            5 4  15             5 4            6 3  13
+--R           (205184A b c  + 427264B b c )x   + (427264A b c  + 546816B b c )x
+--R         + 
+--R                     6 3            7 2  11             7 2            8   9
+--R           (546816A b c  + 421888B b c )x   + (421888A b c  + 180224B b c)x
+--R         + 
+--R                     8            9  7           9 5
+--R           (180224A b c + 32768B b )x  + 32768A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              8 16         7 14        2 6 12         3 5 10         4 4 8
+--R             c x   + 128b c x   + 2688b c x   + 21504b c x   + 84480b c x
+--R           + 
+--R                    5 3 6          6 2 4          7   2         8
+--R             180224b c x  + 212992b c x  + 131072b c x  + 32768b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  8 16         7 14        2 6 12         3 5 10          4 4 8
+--R             - 16c x   - 688b c x   - 8736b c x   - 50304b c x   - 154880b c x
+--R           + 
+--R                      5 3 6          6 2 4          7   2         8
+--R             - 272384b c x  - 274432b c x  - 147456b c x  - 32768b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 747
+
+)clear all
+
+--S 748 of 3139
+t0:=x*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                     +-----------+
+--R            3        |   4      2
+--R   (1)  (B x  + A x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 748
+
+--S 749 of 3139
+r0:=1/6*B*(b*x^2+c*x^4)^(3/2)/c+1/16*b^2*(b*B-2*A*c)*atanh(x^2*sqrt(c)/_
+   sqrt(b*x^2+c*x^4))/c^(5/2)-1/16*b*(b*B-2*A*c)*sqrt(b*x^2+c*x^4)/c^2-_
+   1/8*(b*B-2*A*c)*x^2*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                    2 +-+
+--R              2        3           x \|c
+--R       (- 6A b c + 3B b )atanh(--------------)
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R     + 
+--R                                                            +-----------+
+--R            2 4         2           2                2  +-+ |   4      2
+--R       (8B c x  + (12A c  + 2B b c)x  + 6A b c - 3B b )\|c \|c x  + b x
+--R  /
+--R        2 +-+
+--R     48c \|c
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       2 3        3 2  4          3 2        4   2         4
+--R                 (36A b c  - 18B b c )x  + (192A b c  - 96B b c)x  + 192A b c
+--R               + 
+--R                        5
+--R                 - 96B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                    2 4       3 3  6            3 3        4 2  4
+--R             (- 6A b c  + 3B b c )x  + (- 108A b c  + 54B b c )x
+--R           + 
+--R                      4 2         5   2         5         6
+--R             (- 288A b c  + 144B b c)x  - 192A b c + 96B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                   5 11           5           4  9              4         2 3  7
+--R             - 8B c x   + (- 12A c  - 146B b c )x  + (- 222A b c  - 417B b c )x
+--R           + 
+--R                      2 3         3 2  5            3 2        4   3
+--R             (- 684A b c  - 298B b c )x  + (- 672A b c  + 80B b c)x
+--R           + 
+--R                      4         5
+--R             (- 192A b c + 96B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                  5 11         5           4  9            4         2 3  7
+--R             48B c x   + (72A c  + 316B b c )x  + (492A b c  + 570B b c )x
+--R           + 
+--R                    2 3         3 2  5          3 2         4   3
+--R             (996A b c  + 270B b c )x  + (768A b c  - 128B b c)x
+--R           + 
+--R                    4         5
+--R             (192A b c - 96B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                                                   +--------+
+--R              4 4          3 2        2 2  +-+ +-+ |   2
+--R         (288c x  + 1536b c x  + 1536b c )\|b \|c \|c x  + b
+--R       + 
+--R               5 6         4 4        2 3 2        3 2  +-+
+--R         (- 48c x  - 864b c x  - 2304b c x  - 1536b c )\|c
+--R     ,
+--R
+--R                         2 3        3 2  4            3 2         4   2
+--R                 (- 72A b c  + 36B b c )x  + (- 384A b c  + 192B b c)x
+--R               + 
+--R                         4          5
+--R                 - 384A b c + 192B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                   2 4       3 3  6          3 3         4 2  4
+--R             (12A b c  - 6B b c )x  + (216A b c  - 108B b c )x
+--R           + 
+--R                    4 2         5   2         5          6
+--R             (576A b c  - 288B b c)x  + 384A b c - 192B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                   5 11           5           4  9              4         2 3  7
+--R             - 8B c x   + (- 12A c  - 146B b c )x  + (- 222A b c  - 417B b c )x
+--R           + 
+--R                      2 3         3 2  5            3 2        4   3
+--R             (- 684A b c  - 298B b c )x  + (- 672A b c  + 80B b c)x
+--R           + 
+--R                      4         5
+--R             (- 192A b c + 96B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                  5 11         5           4  9            4         2 3  7
+--R             48B c x   + (72A c  + 316B b c )x  + (492A b c  + 570B b c )x
+--R           + 
+--R                    2 3         3 2  5          3 2         4   3
+--R             (996A b c  + 270B b c )x  + (768A b c  - 128B b c)x
+--R           + 
+--R                    4         5
+--R             (192A b c - 96B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                                                     +--------+
+--R              4 4          3 2        2 2  +---+ +-+ |   2
+--R         (288c x  + 1536b c x  + 1536b c )\|- c \|b \|c x  + b
+--R       + 
+--R               5 6         4 4        2 3 2        3 2  +---+
+--R         (- 48c x  - 864b c x  - 2304b c x  - 1536b c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 750
+
+--S 751 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     2 3        3 2  4          3 2        4   2         4
+--R               (36A b c  - 18B b c )x  + (192A b c  - 96B b c)x  + 192A b c
+--R             + 
+--R                      5
+--R               - 96B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  2 4       3 3  6            3 3        4 2  4
+--R           (- 6A b c  + 3B b c )x  + (- 108A b c  + 54B b c )x
+--R         + 
+--R                    4 2         5   2         5         6
+--R           (- 288A b c  + 144B b c)x  - 192A b c + 96B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                     2 3        3 2  4          3 2        4   2         4
+--R               (36A b c  - 18B b c )x  + (192A b c  - 96B b c)x  + 192A b c
+--R             + 
+--R                      5
+--R               - 96B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  2 4       3 3  6            3 3        4 2  4
+--R           (- 6A b c  + 3B b c )x  + (- 108A b c  + 54B b c )x
+--R         + 
+--R                    4 2         5   2         5         6
+--R           (- 288A b c  + 144B b c)x  - 192A b c + 96B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                      4 8           4           3  6
+--R               - 48B c x  + (- 72A c  - 268B b c )x
+--R             + 
+--R                          3         2 2  4            2 2        3   2
+--R               (- 420A b c  - 302B b c )x  + (- 576A b c  + 32B b c)x
+--R             + 
+--R                       3         4
+--R               - 192A b c + 96B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                   5 10         5           4  8            4         2 3  6
+--R               8B c x   + (12A c  + 146B b c )x  + (222A b c  + 417B b c )x
+--R             + 
+--R                      2 3         3 2  4          3 2        4   2         4
+--R               (684A b c  + 298B b c )x  + (672A b c  - 80B b c)x  + 192A b c
+--R             + 
+--R                      5
+--R               - 96B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 5 11           5           4  9              4         2 3  7
+--R           - 8B c x   + (- 12A c  - 146B b c )x  + (- 222A b c  - 417B b c )x
+--R         + 
+--R                    2 3         3 2  5            3 2        4   3
+--R           (- 684A b c  - 298B b c )x  + (- 672A b c  + 80B b c)x
+--R         + 
+--R                    4         5
+--R           (- 192A b c + 96B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                5 11         5           4  9            4         2 3  7
+--R           48B c x   + (72A c  + 316B b c )x  + (492A b c  + 570B b c )x
+--R         + 
+--R                  2 3         3 2  5          3 2         4   3
+--R           (996A b c  + 270B b c )x  + (768A b c  - 128B b c)x
+--R         + 
+--R                  4         5
+--R           (192A b c - 96B b )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                                                 +--------+
+--R            4 4          3 2        2 2  +-+ +-+ |   2
+--R       (288c x  + 1536b c x  + 1536b c )\|b \|c \|c x  + b
+--R     + 
+--R             5 6         4 4        2 3 2        3 2  +-+
+--R       (- 48c x  - 864b c x  - 2304b c x  - 1536b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          8 20           8           7  18
+--R                   - 15B c x   + (- 15A c  - 575B b c )x
+--R                 + 
+--R                              7          2 6  16
+--R                   (- 575A b c  - 6608B b c )x
+--R                 + 
+--R                             2 6           3 5  14
+--R                   (- 6608A b c  - 34848B b c )x
+--R                 + 
+--R                              3 5           4 4  12
+--R                   (- 34848A b c  - 99200B b c )x
+--R                 + 
+--R                              4 4            5 3  10
+--R                   (- 99200A b c  - 162560B b c )x
+--R                 + 
+--R                               5 3            6 2  8
+--R                   (- 162560A b c  - 153600B b c )x
+--R                 + 
+--R                               6 2           7   6
+--R                   (- 153600A b c  - 77824B b c)x
+--R                 + 
+--R                              7            8  4           8 2
+--R                   (- 77824A b c - 16384B b )x  - 16384A b x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                    9 21         9           8  19
+--R               - B c x   + (- A c  - 113B b c )x
+--R             + 
+--R                          8          2 7  17             2 7           3 6  15
+--R               (- 113A b c  - 2128B b c )x   + (- 2128A b c  - 15456B b c )x
+--R             + 
+--R                          3 6           4 5  13
+--R               (- 15456A b c  - 55680B b c )x
+--R             + 
+--R                          4 5            5 4  11
+--R               (- 55680A b c  - 109824B b c )x
+--R             + 
+--R                           5 4            6 3  9
+--R               (- 109824A b c  - 120832B b c )x
+--R             + 
+--R                           6 3           7 2  7              7 2           8   5
+--R               (- 120832A b c  - 69632B b c )x  + (- 69632A b c  - 16384B b c)x
+--R             + 
+--R                         8   3
+--R               - 16384A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  9 22       9           8  20            8          2 7  18
+--R               B c x   + (A c  + 114B b c )x   + (114A b c  + 2241B b c )x
+--R             + 
+--R                       2 7           3 6  16            3 6           4 5  14
+--R               (2241A b c  + 17584B b c )x   + (17584A b c  + 71136B b c )x
+--R             + 
+--R                        4 5            5 4  12
+--R               (71136A b c  + 165504B b c )x
+--R             + 
+--R                         5 4            6 3  10
+--R               (165504A b c  + 230656B b c )x
+--R             + 
+--R                         6 3            7 2  8             7 2           8   6
+--R               (230656A b c  + 190464B b c )x  + (190464A b c  + 86016B b c)x
+--R             + 
+--R                        8            9  4           9 2
+--R               (86016A b c + 16384B b )x  + 16384A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    9 21         9           8  19            8          2 7  17
+--R               15B c x   + (15A c  + 575B b c )x   + (575A b c  + 6608B b c )x
+--R             + 
+--R                       2 7           3 6  15            3 6           4 5  13
+--R               (6608A b c  + 34848B b c )x   + (34848A b c  + 99200B b c )x
+--R             + 
+--R                        4 5            5 4  11             5 4            6 3  9
+--R               (99200A b c  + 162560B b c )x   + (162560A b c  + 153600B b c )x
+--R             + 
+--R                         6 3           7 2  7            7 2           8   5
+--R               (153600A b c  + 77824B b c )x  + (77824A b c  + 16384B b c)x
+--R             + 
+--R                       8   3
+--R               16384A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    9 23         9           8  21
+--R               - B c x   + (- A c  - 114B b c )x
+--R             + 
+--R                          8          2 7  19             2 7           3 6  17
+--R               (- 114A b c  - 2241B b c )x   + (- 2241A b c  - 17584B b c )x
+--R             + 
+--R                          3 6           4 5  15
+--R               (- 17584A b c  - 71136B b c )x
+--R             + 
+--R                          4 5            5 4  13
+--R               (- 71136A b c  - 165504B b c )x
+--R             + 
+--R                           5 4            6 3  11
+--R               (- 165504A b c  - 230656B b c )x
+--R             + 
+--R                           6 3            7 2  9
+--R               (- 230656A b c  - 190464B b c )x
+--R             + 
+--R                           7 2           8   7              8            9  5
+--R               (- 190464A b c  - 86016B b c)x  + (- 86016A b c - 16384B b )x
+--R             + 
+--R                         9 3
+--R               - 16384A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      9 22           9           8  20
+--R               - 15B c x   + (- 15A c  - 575B b c )x
+--R             + 
+--R                          8          2 7  18             2 7           3 6  16
+--R               (- 575A b c  - 6608B b c )x   + (- 6608A b c  - 34848B b c )x
+--R             + 
+--R                          3 6           4 5  14
+--R               (- 34848A b c  - 99200B b c )x
+--R             + 
+--R                          4 5            5 4  12
+--R               (- 99200A b c  - 162560B b c )x
+--R             + 
+--R                           5 4            6 3  10
+--R               (- 162560A b c  - 153600B b c )x
+--R             + 
+--R                           6 3           7 2  8              7 2           8   6
+--R               (- 153600A b c  - 77824B b c )x  + (- 77824A b c  - 16384B b c)x
+--R             + 
+--R                         8   4
+--R               - 16384A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                9 23         9           8  21            8          2 7  19
+--R           15B c x   + (15A c  + 590B b c )x   + (590A b c  + 7183B b c )x
+--R         + 
+--R                   2 7           3 6  17            3 6            4 5  15
+--R           (7183A b c  + 41456B b c )x   + (41456A b c  + 134048B b c )x
+--R         + 
+--R                     4 5            5 4  13             5 4            6 3  11
+--R           (134048A b c  + 261760B b c )x   + (261760A b c  + 316160B b c )x
+--R         + 
+--R                     6 3            7 2  9             7 2           8   7
+--R           (316160A b c  + 231424B b c )x  + (231424A b c  + 94208B b c)x
+--R         + 
+--R                    8            9  5           9 3
+--R           (94208A b c + 16384B b )x  + 16384A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R          10 24       10           9  22            9          2 8  20
+--R       B c  x   + (A c   + 114B b c )x   + (114A b c  + 2241B b c )x
+--R     + 
+--R               2 8           3 7  18            3 7           4 6  16
+--R       (2241A b c  + 17584B b c )x   + (17584A b c  + 71136B b c )x
+--R     + 
+--R                4 6            5 5  14             5 5            6 4  12
+--R       (71136A b c  + 165504B b c )x   + (165504A b c  + 230656B b c )x
+--R     + 
+--R                 6 4            7 3  10             7 3           8 2  8
+--R       (230656A b c  + 190464B b c )x   + (190464A b c  + 86016B b c )x
+--R     + 
+--R                8 2           9   6           9   4
+--R       (86016A b c  + 16384B b c)x  + 16384A b c x
+--R  /
+--R                  8 16         7 14        2 6 12         3 5 10         4 4 8
+--R                 c x   + 113b c x   + 2128b c x   + 15456b c x   + 55680b c x
+--R               + 
+--R                        5 3 6          6 2 4         7   2         8
+--R                 109824b c x  + 120832b c x  + 69632b c x  + 16384b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                    8 15         7 13        2 6 11         3 5 9         4 4 7
+--R                 15c x   + 560b c x   + 6048b c x   + 28800b c x  + 70400b c x
+--R               + 
+--R                       5 3 5         6 2 3         7
+--R                 92160b c x  + 61440b c x  + 16384b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  8 16         7 14        2 6 12         3 5 10         4 4 8
+--R             - 15c x   - 575b c x   - 6608b c x   - 34848b c x   - 99200b c x
+--R           + 
+--R                      5 3 6          6 2 4         7   2         8
+--R             - 162560b c x  - 153600b c x  - 77824b c x  - 16384b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R            9 17         8 15        2 7 13         3 6 11         4 5 9
+--R         - c x   - 113b c x   - 2128b c x   - 15456b c x   - 55680b c x
+--R       + 
+--R                  5 4 7          6 3 5         7 2 3         8
+--R         - 109824b c x  - 120832b c x  - 69632b c x  - 16384b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     2 3        3 2  4          3 2        4   2         4
+--R               (36A b c  - 18B b c )x  + (192A b c  - 96B b c)x  + 192A b c
+--R             + 
+--R                      5
+--R               - 96B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                      2 4       3 3  6            3 3        4 2  4
+--R               (- 6A b c  + 3B b c )x  + (- 108A b c  + 54B b c )x
+--R             + 
+--R                        4 2         5   2         5         6
+--R               (- 288A b c  + 144B b c)x  - 192A b c + 96B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                       2 3        3 2  4            3 2         4   2         4
+--R               (- 72A b c  + 36B b c )x  + (- 384A b c  + 192B b c)x  - 384A b c
+--R             + 
+--R                     5
+--R               192B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                     2 4       3 3  6          3 3         4 2  4
+--R               (12A b c  - 6B b c )x  + (216A b c  - 108B b c )x
+--R             + 
+--R                      4 2         5   2         5          6
+--R               (576A b c  - 288B b c)x  + 384A b c - 192B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                      4 8           4           3  6
+--R               - 48B c x  + (- 72A c  - 268B b c )x
+--R             + 
+--R                          3         2 2  4            2 2        3   2
+--R               (- 420A b c  - 302B b c )x  + (- 576A b c  + 32B b c)x
+--R             + 
+--R                       3         4
+--R               - 192A b c + 96B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                   5 10         5           4  8            4         2 3  6
+--R               8B c x   + (12A c  + 146B b c )x  + (222A b c  + 417B b c )x
+--R             + 
+--R                      2 3         3 2  4          3 2        4   2         4
+--R               (684A b c  + 298B b c )x  + (672A b c  - 80B b c)x  + 192A b c
+--R             + 
+--R                      5
+--R               - 96B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 5 11           5           4  9              4         2 3  7
+--R           - 8B c x   + (- 12A c  - 146B b c )x  + (- 222A b c  - 417B b c )x
+--R         + 
+--R                    2 3         3 2  5            3 2        4   3
+--R           (- 684A b c  - 298B b c )x  + (- 672A b c  + 80B b c)x
+--R         + 
+--R                    4         5
+--R           (- 192A b c + 96B b )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                5 11         5           4  9            4         2 3  7
+--R           48B c x   + (72A c  + 316B b c )x  + (492A b c  + 570B b c )x
+--R         + 
+--R                  2 3         3 2  5          3 2         4   3
+--R           (996A b c  + 270B b c )x  + (768A b c  - 128B b c)x
+--R         + 
+--R                  4         5
+--R           (192A b c - 96B b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R                                                       +--------+
+--R            4 4          3 2        2 2  +---+ +-+ +-+ |   2
+--R       (288c x  + 1536b c x  + 1536b c )\|- c \|b \|c \|c x  + b
+--R     + 
+--R             5 6         4 4        2 3 2        3 2  +---+ +-+
+--R       (- 48c x  - 864b c x  - 2304b c x  - 1536b c )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 753
+
+--S 754 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      6 16           6           5  14
+--R               - 12B c x   + (- 12A c  - 292B b c )x
+--R             + 
+--R                          5          2 4  12             2 4          3 3  10
+--R               (- 292A b c  - 2072B b c )x   + (- 2072A b c  - 6400B b c )x
+--R             + 
+--R                         3 3          4 2  8             4 2          5   6
+--R               (- 6400A b c  - 9728B b c )x  + (- 9728A b c  - 7168B b c)x
+--R             + 
+--R                         5           6  4          6 2
+--R               (- 7168A b c - 2048B b )x  - 2048A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              7 18       7          6  16           6         2 5  14
+--R           B c x   + (A c  + 73B b c )x   + (73A b c  + 912B b c )x
+--R         + 
+--R                  2 5          3 4  12           3 4           4 3  10
+--R           (912A b c  + 4424B b c )x   + (4424A b c  + 10496B b c )x
+--R         + 
+--R                    4 3           5 2  8            5 2          6   6
+--R           (10496A b c  + 13056B b c )x  + (13056A b c  + 8192B b c)x
+--R         + 
+--R                   6           7  4          7 2
+--R           (8192A b c + 2048B b )x  + 2048A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                7 19         7          6  17             6         2 5  15
+--R           - B c x   + (- A c  - 73B b c )x   + (- 73A b c  - 912B b c )x
+--R         + 
+--R                    2 5          3 4  13             3 4           4 3  11
+--R           (- 912A b c  - 4424B b c )x   + (- 4424A b c  - 10496B b c )x
+--R         + 
+--R                      4 3           5 2  9              5 2          6   7
+--R           (- 10496A b c  - 13056B b c )x  + (- 13056A b c  - 8192B b c)x
+--R         + 
+--R                     6           7  5          7 3
+--R           (- 8192A b c - 2048B b )x  - 2048A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 19         7           6  17            6          2 5  15
+--R           12B c x   + (12A c  + 304B b c )x   + (304A b c  + 2364B b c )x
+--R         + 
+--R                   2 5          3 4  13           3 4           4 3  11
+--R           (2364A b c  + 8472B b c )x   + (8472A b c  + 16128B b c )x
+--R         + 
+--R                    4 3           5 2  9            5 2          6   7
+--R           (16128A b c  + 16896B b c )x  + (16896A b c  + 9216B b c)x
+--R         + 
+--R                   6           7  5          7 3
+--R           (9216A b c + 2048B b )x  + 2048A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              6 12        5 10       2 4 8        3 3 6        4 2 4
+--R             c x   + 72b c x   + 840b c x  + 3584b c x  + 6912b c x
+--R           + 
+--R                  5   2        6
+--R             6144b c x  + 2048b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  6 12         5 10        2 4 8        3 3 6        4 2 4
+--R             - 12c x   - 292b c x   - 2072b c x  - 6400b c x  - 9728b c x
+--R           + 
+--R                    5   2        6
+--R             - 7168b c x  - 2048b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 754
+
+)clear all
+
+--S 755 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 755
+
+--S 756 of 3139
+r0:=1/4*B*(b*x^2+c*x^4)^(3/2)/(c*x^2)-1/8*b*(b*B-4*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)-1/8*(b*B-4*A*c)*_
+   sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                 2 +-+
+--R                    2           x \|c
+--R       (4A b c - B b )atanh(--------------)
+--R                             +-----------+
+--R                             |   4      2
+--R                            \|c x  + b x
+--R     + 
+--R                                  +-----------+
+--R              2               +-+ |   4      2
+--R       (2B c x  + 4A c + B b)\|c \|c x  + b x
+--R  /
+--R        +-+
+--R     8c\|c
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                           +--------+
+--R                      2       2   2        2        3  +-+ |   2
+--R             ((16A b c  - 4B b c)x  + 32A b c - 8B b )\|b \|c x  + b
+--R           + 
+--R                      3      2 2  4           2 2       3   2        3        4
+--R             (- 4A b c  + B b c )x  + (- 32A b c  + 8B b c)x  - 32A b c + 8B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                   3 7          3          2  5             2        2   3
+--R             - 2B c x  + (- 4A c  - 17B b c )x  + (- 32A b c  - 24B b c)x
+--R           + 
+--R                     2        3
+--R             (- 32A b c - 8B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                 3 7         3          2  5           2        2   3
+--R             8B c x  + (16A c  + 28B b c )x  + (48A b c  + 28B b c)x
+--R           + 
+--R                   2        3
+--R             (32A b c + 8B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                                +--------+
+--R           2 2          +-+ +-+ |   2             3 4        2 2      2   +-+
+--R       (32c x  + 64b c)\|b \|c \|c x  + b  + (- 8c x  - 64b c x  - 64b c)\|c
+--R     ,
+--R
+--R                                                            +--------+
+--R                      2       2   2        2         3  +-+ |   2
+--R             ((32A b c  - 8B b c)x  + 64A b c - 16B b )\|b \|c x  + b
+--R           + 
+--R                    3       2 2  4           2 2        3   2        3         4
+--R           (- 8A b c  + 2B b c )x  + (- 64A b c  + 16B b c)x  - 64A b c + 16B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                   3 7          3          2  5             2        2   3
+--R             - 2B c x  + (- 4A c  - 17B b c )x  + (- 32A b c  - 24B b c)x
+--R           + 
+--R                     2        3
+--R             (- 32A b c - 8B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                 3 7         3          2  5           2        2   3
+--R             8B c x  + (16A c  + 28B b c )x  + (48A b c  + 28B b c)x
+--R           + 
+--R                   2        3
+--R             (32A b c + 8B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                                    +--------+
+--R             2 2          +---+ +-+ |   2
+--R         (32c x  + 64b c)\|- c \|b \|c x  + b
+--R       + 
+--R              3 4        2 2      2   +---+
+--R         (- 8c x  - 64b c x  - 64b c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 757
+
+--S 758 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                         +--------+
+--R                    2       2   2        2        3  +-+ |   2
+--R           ((16A b c  - 4B b c)x  + 32A b c - 8B b )\|b \|c x  + b
+--R         + 
+--R                    3      2 2  4           2 2       3   2        3        4
+--R           (- 4A b c  + B b c )x  + (- 32A b c  + 8B b c)x  - 32A b c + 8B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                                                           +--------+
+--R                      2       2   2        2        3  +-+ |   2
+--R           ((- 16A b c  + 4B b c)x  - 32A b c + 8B b )\|b \|c x  + b
+--R         + 
+--R                  3      2 2  4         2 2       3   2        3        4
+--R           (4A b c  - B b c )x  + (32A b c  - 8B b c)x  + 32A b c - 8B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                    2 4           2            2                 2  +-+ +-+
+--R             (- 8B c x  + (- 16A c  - 20B b c)x  - 32A b c - 8B b )\|b \|c
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                   3 6        3          2  4           2        2   2        2
+--R               2B c x  + (4A c  + 17B b c )x  + (32A b c  + 24B b c)x  + 32A b c
+--R             + 
+--R                   3
+--R               8B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 3 7          3          2  5             2        2   3
+--R           - 2B c x  + (- 4A c  - 17B b c )x  + (- 32A b c  - 24B b c)x
+--R         + 
+--R                   2        3
+--R           (- 32A b c - 8B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R               3 7         3          2  5           2        2   3
+--R           8B c x  + (16A c  + 28B b c )x  + (48A b c  + 28B b c)x
+--R         + 
+--R                 2        3
+--R           (32A b c + 8B b )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                              +--------+
+--R         2 2          +-+ +-+ |   2             3 4        2 2      2   +-+
+--R     (32c x  + 64b c)\|b \|c \|c x  + b  + (- 8c x  - 64b c x  - 64b c)\|c
+--R                                                    Type: Expression(Integer)
+--E 758
+
+--S 759 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          6 14           6           5  12
+--R                   - 11B c x   + (- 11A c  - 231B b c )x
+--R                 + 
+--R                              5          2 4  10             2 4          3 3  8
+--R                   (- 231A b c  - 1452B b c )x   + (- 1452A b c  - 4048B b c )x
+--R                 + 
+--R                             3 3          4 2  6             4 2          5   4
+--R                   (- 4048A b c  - 5632B b c )x  + (- 5632A b c  - 3840B b c)x
+--R                 + 
+--R                             5           6  2          6
+--R                   (- 3840A b c - 1024B b )x  - 1024A b
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  7 15       7          6  13           6         2 5  11
+--R               B c x   + (A c  + 61B b c )x   + (61A b c  + 620B b c )x
+--R             + 
+--R                      2 5          3 4  9           3 4          4 3  7
+--R               (620A b c  + 2352B b c )x  + (2352A b c  + 4096B b c )x
+--R             + 
+--R                       4 3          5 2  5           5 2          6   3
+--R               (4096A b c  + 3328B b c )x  + (3328A b c  + 1024B b c)x
+--R             + 
+--R                      6
+--R               1024A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  7 16       7          6  14           6         2 5  12
+--R               B c x   + (A c  + 62B b c )x   + (62A b c  + 681B b c )x
+--R             + 
+--R                      2 5          3 4  10           3 4          4 3  8
+--R               (681A b c  + 2972B b c )x   + (2972A b c  + 6448B b c )x
+--R             + 
+--R                       4 3          5 2  6           5 2          6   4
+--R               (6448A b c  + 7424B b c )x  + (7424A b c  + 4352B b c)x
+--R             + 
+--R                       6           7  2          7
+--R               (4352A b c + 1024B b )x  + 1024A b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      7 15           7           6  13
+--R               - 11B c x   + (- 11A c  - 231B b c )x
+--R             + 
+--R                          6          2 5  11             2 5          3 4  9
+--R               (- 231A b c  - 1452B b c )x   + (- 1452A b c  - 4048B b c )x
+--R             + 
+--R                         3 4          4 3  7             4 3          5 2  5
+--R               (- 4048A b c  - 5632B b c )x  + (- 5632A b c  - 3840B b c )x
+--R             + 
+--R                         5 2          6   3          6
+--R               (- 3840A b c  - 1024B b c)x  - 1024A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    7 17         7          6  15             6         2 5  13
+--R               - B c x   + (- A c  - 62B b c )x   + (- 62A b c  - 681B b c )x
+--R             + 
+--R                        2 5          3 4  11             3 4          4 3  9
+--R               (- 681A b c  - 2972B b c )x   + (- 2972A b c  - 6448B b c )x
+--R             + 
+--R                         4 3          5 2  7             5 2          6   5
+--R               (- 6448A b c  - 7424B b c )x  + (- 7424A b c  - 4352B b c)x
+--R             + 
+--R                         6           7  3          7
+--R               (- 4352A b c - 1024B b )x  - 1024A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    7 16         7           6  14            6          2 5  12
+--R               11B c x   + (11A c  + 231B b c )x   + (231A b c  + 1452B b c )x
+--R             + 
+--R                       2 5          3 4  10           3 4          4 3  8
+--R               (1452A b c  + 4048B b c )x   + (4048A b c  + 5632B b c )x
+--R             + 
+--R                       4 3          5 2  6           5 2          6   4
+--R               (5632A b c  + 3840B b c )x  + (3840A b c  + 1024B b c)x
+--R             + 
+--R                      6   2
+--R               1024A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 17         7           6  15            6          2 5  13
+--R           11B c x   + (11A c  + 242B b c )x   + (242A b c  + 1683B b c )x
+--R         + 
+--R                   2 5          3 4  11           3 4          4 3  9
+--R           (1683A b c  + 5500B b c )x   + (5500A b c  + 9680B b c )x
+--R         + 
+--R                   4 3          5 2  7           5 2          6   5
+--R           (9680A b c  + 9472B b c )x  + (9472A b c  + 4864B b c)x
+--R         + 
+--R                   6           7  3          7
+--R           (4864A b c + 1024B b )x  + 1024A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            8 18         8          7  16             7         2 6  14
+--R       - B c x   + (- A c  - 62B b c )x   + (- 62A b c  - 681B b c )x
+--R     + 
+--R                2 6          3 5  12             3 5          4 4  10
+--R       (- 681A b c  - 2972B b c )x   + (- 2972A b c  - 6448B b c )x
+--R     + 
+--R                 4 4          5 3  8             5 3          6 2  6
+--R       (- 6448A b c  - 7424B b c )x  + (- 7424A b c  - 4352B b c )x
+--R     + 
+--R                 6 2          7   4          7   2
+--R       (- 4352A b c  - 1024B b c)x  - 1024A b c x
+--R  /
+--R                  6 12        5 10       2 4 8        3 3 6        4 2 4
+--R                 c x   + 61b c x   + 620b c x  + 2352b c x  + 4096b c x
+--R               + 
+--R                      5   2        6
+--R                 3328b c x  + 1024b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                      6 11         5 9        2 4 7        3 3 5        4 2 3
+--R                 - 11c x   - 220b c x  - 1232b c x  - 2816b c x  - 2816b c x
+--R               + 
+--R                        5
+--R                 - 1024b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  6 12         5 10        2 4 8        3 3 6        4 2 4
+--R             - 11c x   - 231b c x   - 1452b c x  - 4048b c x  - 5632b c x
+--R           + 
+--R                    5   2        6
+--R             - 3840b c x  - 1024b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          7 13        6 11       2 5 9        3 4 7        4 3 5        5 2 3
+--R         c x   + 61b c x   + 620b c x  + 2352b c x  + 4096b c x  + 3328b c x
+--R       + 
+--R              6
+--R         1024b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                 +--------+
+--R                      2       2   2        2        3  +---+ +-+ |   2
+--R           ((- 16A b c  + 4B b c)x  - 32A b c + 8B b )\|- c \|b \|c x  + b
+--R         + 
+--R                 3      2 2  4         2 2       3   2        3        4  +---+
+--R         ((4A b c  - B b c )x  + (32A b c  - 8B b c)x  + 32A b c - 8B b )\|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                                              +--------+
+--R                    2       2   2        2         3  +-+ +-+ |   2
+--R           ((32A b c  - 8B b c)x  + 64A b c - 16B b )\|b \|c \|c x  + b
+--R         + 
+--R                        3       2 2  4           2 2        3   2        3
+--R               (- 8A b c  + 2B b c )x  + (- 64A b c  + 16B b c)x  - 64A b c
+--R             + 
+--R                    4
+--R               16B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                    2 4           2            2                 2  +---+ +-+
+--R             (- 8B c x  + (- 16A c  - 20B b c)x  - 32A b c - 8B b )\|- c \|b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|c x  + b
+--R         + 
+--R                   3 6        3          2  4           2        2   2        2
+--R               2B c x  + (4A c  + 17B b c )x  + (32A b c  + 24B b c)x  + 32A b c
+--R             + 
+--R                   3
+--R               8B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 3 7          3          2  5             2        2   3
+--R           - 2B c x  + (- 4A c  - 17B b c )x  + (- 32A b c  - 24B b c)x
+--R         + 
+--R                   2        3
+--R           (- 32A b c - 8B b )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R               3 7         3          2  5           2        2   3
+--R           8B c x  + (16A c  + 28B b c )x  + (48A b c  + 28B b c)x
+--R         + 
+--R                 2        3
+--R           (32A b c + 8B b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R                                      +--------+
+--R           2 2          +---+ +-+ +-+ |   2
+--R       (32c x  + 64b c)\|- c \|b \|c \|c x  + b
+--R     + 
+--R            3 4        2 2      2   +---+ +-+
+--R       (- 8c x  - 64b c x  - 64b c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 760
+
+--S 761 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                     4 10          4          3  8             3         2 2  6
+--R               - 8B c x   + (- 8A c  - 88B b c )x  + (- 88A b c  - 272B b c )x
+--R             + 
+--R                        2 2         3   4            3          4  2         4
+--R               (- 272A b c  - 320B b c)x  + (- 320A b c - 128B b )x  - 128A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              5 12       5          4  10           4         2 3  8
+--R           B c x   + (A c  + 33B b c )x   + (33A b c  + 192B b c )x
+--R         + 
+--R                  2 3         3 2  6          3 2         4   4
+--R           (192A b c  + 416B b c )x  + (416A b c  + 384B b c)x
+--R         + 
+--R                  4          5  2         5
+--R           (384A b c + 128B b )x  + 128A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                5 13         5          4  11             4         2 3  9
+--R           - B c x   + (- A c  - 33B b c )x   + (- 33A b c  - 192B b c )x
+--R         + 
+--R                    2 3         3 2  7            3 2         4   5
+--R           (- 192A b c  - 416B b c )x  + (- 416A b c  - 384B b c)x
+--R         + 
+--R                    4          5  3         5
+--R           (- 384A b c - 128B b )x  - 128A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               5 13        5          4  11           4         2 3  9
+--R           8B c x   + (8A c  + 96B b c )x   + (96A b c  + 360B b c )x
+--R         + 
+--R                  2 3         3 2  7          3 2         4   5
+--R           (360A b c  + 592B b c )x  + (592A b c  + 448B b c)x
+--R         + 
+--R                  4          5  3         5
+--R           (448A b c + 128B b )x  + 128A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                           +--------+
+--R           4 8        3 6       2 2 4       3   2       4  |   2
+--R         (c x  + 32b c x  + 160b c x  + 256b c x  + 128b )\|c x  + b
+--R       + 
+--R              4 8        3 6       2 2 4       3   2       4  +-+
+--R         (- 8c x  - 88b c x  - 272b c x  - 320b c x  - 128b )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 761
+
+)clear all
+
+--S 762 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^3
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    3
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 3139
+r0:=-A*(b*x^2+c*x^4)^(3/2)/(b*x^4)+1/2*(b*B+2*A*c)*atanh(x^2*sqrt(c)/_
+   sqrt(b*x^2+c*x^4))/sqrt(c)+1/2*(b*B+2*A*c)*sqrt(b*x^2+c*x^4)/b
+--R 
+--R
+--R                                 2 +-+                        +-----------+
+--R                     2          x \|c             2       +-+ |   4      2
+--R        (2A c + B b)x atanh(--------------) + (B x  - 2A)\|c \|c x  + b x
+--R                             +-----------+
+--R                             |   4      2
+--R                            \|c x  + b x
+--R   (2)  -------------------------------------------------------------------
+--R                                        2 +-+
+--R                                      2x \|c
+--R                                                    Type: Expression(Integer)
+--E 763
+
+--S 764 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                     +--------+
+--R                   2          3                 2    |   2
+--R             ((2A c  + B b c)x  + (8A b c + 4B b )x)\|c x  + b
+--R           + 
+--R                     2           3                   2    +-+
+--R             ((- 6A c  - 3B b c)x  + (- 8A b c - 4B b )x)\|b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                                                      +--------+
+--R                  4                 2         +-+ +-+ |   2
+--R         (- 3B c x  + (6A c - 4B b)x  + 8A b)\|b \|c \|c x  + b
+--R       + 
+--R             2 6          2           4                    2  2       2  +-+
+--R         (B c x  + (- 2A c  + 5B b c)x  + (- 10A b c + 4B b )x  - 8A b )\|c
+--R    /
+--R                          +--------+
+--R            3         +-+ |   2               3         +-+ +-+
+--R       (2c x  + 8b x)\|c \|c x  + b  + (- 6c x  - 8b x)\|b \|c
+--R     ,
+--R
+--R                                                       +--------+
+--R                   2           3                  2    |   2
+--R             ((4A c  + 2B b c)x  + (16A b c + 8B b )x)\|c x  + b
+--R           + 
+--R                      2           3                    2    +-+
+--R             ((- 12A c  - 6B b c)x  + (- 16A b c - 8B b )x)\|b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                                                        +--------+
+--R                  4                 2         +---+ +-+ |   2
+--R         (- 3B c x  + (6A c - 4B b)x  + 8A b)\|- c \|b \|c x  + b
+--R       + 
+--R             2 6          2           4                    2  2       2  +---+
+--R         (B c x  + (- 2A c  + 5B b c)x  + (- 10A b c + 4B b )x  - 8A b )\|- c
+--R    /
+--R                            +--------+
+--R            3         +---+ |   2               3         +---+ +-+
+--R       (2c x  + 8b x)\|- c \|c x  + b  + (- 6c x  - 8b x)\|- c \|b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 764
+
+--S 765 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                    +--------+
+--R                 2          4                 2  2  |   2
+--R           ((2A c  + B b c)x  + (8A b c + 4B b )x )\|c x  + b
+--R         + 
+--R                   2           4                   2  2  +-+
+--R           ((- 6A c  - 3B b c)x  + (- 8A b c - 4B b )x )\|b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                                                        +--------+
+--R                   2          4                   2  2  |   2
+--R           ((- 2A c  - B b c)x  + (- 8A b c - 4B b )x )\|c x  + b
+--R         + 
+--R                 2           4                 2  2  +-+
+--R           ((6A c  + 3B b c)x  + (8A b c + 4B b )x )\|b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                                   +--------+
+--R                   4                 2         +-+ |   2
+--R           (- B c x  + (2A c - 4B b)x  + 8A b)\|c \|c x  + b
+--R         + 
+--R                  4                   2         +-+ +-+
+--R           (3B c x  + (- 6A c + 4B b)x  - 8A b)\|b \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                      +--------+
+--R                5                 3           +-+ +-+ |   2
+--R       (- 3B c x  + (6A c - 4B b)x  + 8A b x)\|b \|c \|c x  + b
+--R     + 
+--R           2 7          2           5                    2  3       2   +-+
+--R       (B c x  + (- 2A c  + 5B b c)x  + (- 10A b c + 4B b )x  - 8A b x)\|c
+--R  /
+--R                         +--------+
+--R          4       2  +-+ |   2               4       2  +-+ +-+
+--R     (2c x  + 8b x )\|c \|c x  + b  + (- 6c x  - 8b x )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 765
+
+--S 766 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         5 12          5           4  10
+--R                   - 9B c x   + (- 9A c  - 129B b c )x
+--R                 + 
+--R                              4         2 3  8            2 3          3 2  6
+--R                   (- 129A b c  - 552B b c )x  + (- 552A b c  - 1008B b c )x
+--R                 + 
+--R                             3 2         4   4            4          5  2
+--R                   (- 1008A b c  - 832B b c)x  + (- 832A b c - 256B b )x
+--R                 + 
+--R                           5
+--R                   - 256A b
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  6 13       6          5  11           5         2 4  9
+--R               B c x   + (A c  + 41B b c )x   + (41A b c  + 280B b c )x
+--R             + 
+--R                      2 4         3 3  7          3 3         4 2  5
+--R               (280A b c  + 688B b c )x  + (688A b c  + 704B b c )x
+--R             + 
+--R                      4 2         5   3         5
+--R               (704A b c  + 256B b c)x  + 256A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  6 14       6          5  12           5         2 4  10
+--R               B c x   + (A c  + 42B b c )x   + (42A b c  + 321B b c )x
+--R             + 
+--R                      2 4         3 3  8          3 3          4 2  6
+--R               (321A b c  + 968B b c )x  + (968A b c  + 1392B b c )x
+--R             + 
+--R                       4 2         5   4          5          6  2         6
+--R               (1392A b c  + 960B b c)x  + (960A b c + 256B b )x  + 256A b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                     6 13          6           5  11
+--R               - 9B c x   + (- 9A c  - 129B b c )x
+--R             + 
+--R                          5         2 4  9            2 4          3 3  7
+--R               (- 129A b c  - 552B b c )x  + (- 552A b c  - 1008B b c )x
+--R             + 
+--R                         3 3         4 2  5            4 2         5   3
+--R               (- 1008A b c  - 832B b c )x  + (- 832A b c  - 256B b c)x
+--R             + 
+--R                       5
+--R               - 256A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    6 15         6          5  13             5         2 4  11
+--R               - B c x   + (- A c  - 42B b c )x   + (- 42A b c  - 321B b c )x
+--R             + 
+--R                        2 4         3 3  9            3 3          4 2  7
+--R               (- 321A b c  - 968B b c )x  + (- 968A b c  - 1392B b c )x
+--R             + 
+--R                       4 2         5   5            5          6  3         6
+--R             (- 1392A b c  - 960B b c)x  + (- 960A b c - 256B b )x  - 256A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                   6 14        6           5  12            5         2 4  10
+--R               9B c x   + (9A c  + 129B b c )x   + (129A b c  + 552B b c )x
+--R             + 
+--R                      2 4          3 3  8           3 3         4 2  6
+--R               (552A b c  + 1008B b c )x  + (1008A b c  + 832B b c )x
+--R             + 
+--R                      4 2         5   4         5   2
+--R               (832A b c  + 256B b c)x  + 256A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               6 15        6           5  13            5         2 4  11
+--R           9B c x   + (9A c  + 138B b c )x   + (138A b c  + 681B b c )x
+--R         + 
+--R                  2 4          3 3  9           3 3          4 2  7
+--R           (681A b c  + 1560B b c )x  + (1560A b c  + 1840B b c )x
+--R         + 
+--R                   4 2          5   5           5          6  3         6
+--R           (1840A b c  + 1088B b c)x  + (1088A b c + 256B b )x  + 256A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            7 16         7          6  14             6         2 5  12
+--R       - B c x   + (- A c  - 42B b c )x   + (- 42A b c  - 321B b c )x
+--R     + 
+--R                2 5         3 4  10            3 4          4 3  8
+--R       (- 321A b c  - 968B b c )x   + (- 968A b c  - 1392B b c )x
+--R     + 
+--R                 4 3         5 2  6            5 2         6   4         6   2
+--R       (- 1392A b c  - 960B b c )x  + (- 960A b c  - 256B b c)x  - 256A b c x
+--R  /
+--R                 5 12        4 10       2 3 8       3 2 6       4   4       5 2
+--R               (c x   + 41b c x   + 280b c x  + 688b c x  + 704b c x  + 256b x )
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                  5 11         4 9       2 3 7       3 2 5       4   3  +-+
+--R             (- 9c x   - 120b c x  - 432b c x  - 576b c x  - 256b c x )\|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                   5 12         4 10       2 3 8        3 2 6       4   4
+--R               - 9c x   - 129b c x   - 552b c x  - 1008b c x  - 832b c x
+--R             + 
+--R                     5 2
+--R               - 256b x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          6 13        5 11       2 4 9       3 3 7       4 2 5       5   3
+--R         c x   + 41b c x   + 280b c x  + 688b c x  + 704b c x  + 256b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                              +--------+
+--R                   2          4                   2  2  +---+ |   2
+--R           ((- 2A c  - B b c)x  + (- 8A b c - 4B b )x )\|- c \|c x  + b
+--R         + 
+--R                 2           4                 2  2  +---+ +-+
+--R           ((6A c  + 3B b c)x  + (8A b c + 4B b )x )\|- c \|b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                                          +--------+
+--R                 2           4                  2  2  +-+ |   2
+--R           ((4A c  + 2B b c)x  + (16A b c + 8B b )x )\|c \|c x  + b
+--R         + 
+--R                    2           4                    2  2  +-+ +-+
+--R           ((- 12A c  - 6B b c)x  + (- 16A b c - 8B b )x )\|b \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                                                         +--------+
+--R                   4                 2         +---+ +-+ |   2
+--R           (- B c x  + (2A c - 4B b)x  + 8A b)\|- c \|c \|c x  + b
+--R         + 
+--R                  4                   2         +---+ +-+ +-+
+--R           (3B c x  + (- 6A c + 4B b)x  - 8A b)\|- c \|b \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                            +--------+
+--R                5                 3           +---+ +-+ +-+ |   2
+--R       (- 3B c x  + (6A c - 4B b)x  + 8A b x)\|- c \|b \|c \|c x  + b
+--R     + 
+--R         2 7          2           5                    2  3       2   +---+ +-+
+--R     (B c x  + (- 2A c  + 5B b c)x  + (- 10A b c + 4B b )x  - 8A b x)\|- c \|c
+--R  /
+--R                               +--------+
+--R          4       2  +---+ +-+ |   2               4       2  +---+ +-+ +-+
+--R     (2c x  + 8b x )\|- c \|c \|c x  + b  + (- 6c x  - 8b x )\|- c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                     3 8          3          2  6             2        2   4
+--R               - 6B c x  + (- 6A c  - 38B b c )x  + (- 38A b c  - 64B b c)x
+--R             + 
+--R                       2         3  2        3
+--R               (- 64A b c - 32B b )x  - 32A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              4 10       4          3  8           3        2 2  6
+--R           B c x   + (A c  + 19B b c )x  + (19A b c  + 66B b c )x
+--R         + 
+--R                 2 2        3   4         3         4  2        4
+--R           (66A b c  + 80B b c)x  + (80A b c + 32B b )x  + 32A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                4 11         4          3  9             3        2 2  7
+--R           - B c x   + (- A c  - 19B b c )x  + (- 19A b c  - 66B b c )x
+--R         + 
+--R                   2 2        3   5           3         4  3        4
+--R           (- 66A b c  - 80B b c)x  + (- 80A b c - 32B b )x  - 32A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               4 11        4          3  9           3         2 2  7
+--R           6B c x   + (6A c  + 44B b c )x  + (44A b c  + 102B b c )x
+--R         + 
+--R                  2 2        3   5         3         4  3        4
+--R           (102A b c  + 96B b c)x  + (96A b c + 32B b )x  + 32A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                               +--------+
+--R           3 8        2 6      2   4      3 2  |   2
+--R         (c x  + 18b c x  + 48b c x  + 32b x )\|c x  + b
+--R       + 
+--R              3 8        2 6      2   4      3 2  +-+
+--R         (- 6c x  - 38b c x  - 64b c x  - 32b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 768
+
+)clear all
+
+--S 769 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^5
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    5
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 3139
+r0:=-1/3*A*(b*x^2+c*x^4)^(3/2)/(b*x^6)+B*atanh(x^2*sqrt(c)/_
+   sqrt(b*x^2+c*x^4))*sqrt(c)-B*sqrt(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                         2 +-+                                 +-----------+
+--R         4 +-+          x \|c                         2        |   4      2
+--R   3B b x \|c atanh(--------------) + ((- A c - 3B b)x  - A b)\|c x  + b x
+--R                     +-----------+
+--R                     |   4      2
+--R                    \|c x  + b x
+--R   -------------------------------------------------------------------------
+--R                                         4
+--R                                     3b x
+--R                                                    Type: Expression(Integer)
+--E 770
+
+--S 771 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                        +--------+
+--R                      5        2 3  +-+ |   2
+--R             (3B b c x  + 12B b x )\|c \|c x  + b
+--R           + 
+--R                        5        2 3  +-+ +-+
+--R             (- 9B b c x  - 12B b x )\|b \|c
+--R        *
+--R                                +--------+
+--R                    +-+    +-+  |   2          +-+ +-+      2
+--R               (- x\|c  + \|b )\|c x  + b  + x\|b \|c  - c x  - b
+--R           log(--------------------------------------------------)
+--R                                    +--------+
+--R                                +-+ |   2
+--R                               \|b \|c x  + b  - b
+--R       + 
+--R                                                                +--------+
+--R               2           4                  2  2       2  +-+ |   2
+--R         ((3A c  + 9B b c)x  + (7A b c + 12B b )x  + 4A b )\|b \|c x  + b
+--R       + 
+--R               3         2  6            2        2   4          2         3  2
+--R         (- A c  - 3B b c )x  + (- 6A b c  - 15B b c)x  + (- 9A b c - 12B b )x
+--R       + 
+--R               3
+--R         - 4A b
+--R    /
+--R                          +--------+
+--R              5      2 3  |   2                 5      2 3  +-+
+--R       (3b c x  + 12b x )\|c x  + b  + (- 9b c x  - 12b x )\|b
+--R     ,
+--R
+--R                                          +--------+
+--R                      5        2 3  +---+ |   2
+--R             (6B b c x  + 24B b x )\|- c \|c x  + b
+--R           + 
+--R                         5        2 3  +---+ +-+
+--R             (- 18B b c x  - 24B b x )\|- c \|b
+--R        *
+--R                 +--------+
+--R                 |   2         +-+
+--R                \|c x  + b  - \|b
+--R           atan(------------------)
+--R                        +---+
+--R                      x\|- c
+--R       + 
+--R                                                                +--------+
+--R               2           4                  2  2       2  +-+ |   2
+--R         ((3A c  + 9B b c)x  + (7A b c + 12B b )x  + 4A b )\|b \|c x  + b
+--R       + 
+--R               3         2  6            2        2   4          2         3  2
+--R         (- A c  - 3B b c )x  + (- 6A b c  - 15B b c)x  + (- 9A b c - 12B b )x
+--R       + 
+--R               3
+--R         - 4A b
+--R    /
+--R                          +--------+
+--R              5      2 3  |   2                 5      2 3  +-+
+--R       (3b c x  + 12b x )\|c x  + b  + (- 9b c x  - 12b x )\|b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 771
+
+--S 772 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                      +--------+
+--R                    6        2 4  +-+ |   2
+--R           (3B b c x  + 12B b x )\|c \|c x  + b
+--R         + 
+--R                      6        2 4  +-+ +-+
+--R           (- 9B b c x  - 12B b x )\|b \|c
+--R      *
+--R                              +--------+
+--R                  +-+    +-+  |   2          +-+ +-+      2
+--R             (- x\|c  + \|b )\|c x  + b  + x\|b \|c  - c x  - b
+--R         log(--------------------------------------------------)
+--R                                  +--------+
+--R                              +-+ |   2
+--R                             \|b \|c x  + b  - b
+--R     + 
+--R                                        +--------+
+--R                      6        2 4  +-+ |   2
+--R           (- 3B b c x  - 12B b x )\|c \|c x  + b
+--R         + 
+--R                    6        2 4  +-+ +-+
+--R           (9B b c x  + 12B b x )\|b \|c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                                             +--------+
+--R                2           4                  2  2       2  |   2
+--R           ((A c  + 3B b c)x  + (5A b c + 12B b )x  + 4A b )\|c x  + b
+--R         + 
+--R                   2           4                    2  2       2  +-+
+--R           ((- 3A c  - 9B b c)x  + (- 7A b c - 12B b )x  - 4A b )\|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                               +--------+
+--R             2           5                  2  3       2   +-+ |   2
+--R       ((3A c  + 9B b c)x  + (7A b c + 12B b )x  + 4A b x)\|b \|c x  + b
+--R     + 
+--R             3         2  7            2        2   5          2         3  3
+--R       (- A c  - 3B b c )x  + (- 6A b c  - 15B b c)x  + (- 9A b c - 12B b )x
+--R     + 
+--R             3
+--R       - 4A b x
+--R  /
+--R                        +--------+
+--R            6      2 4  |   2                 6      2 4  +-+
+--R     (3b c x  + 12b x )\|c x  + b  + (- 9b c x  - 12b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        5 13         5          4  11
+--R                   - B c x   + (- A c  - 41B b c )x
+--R                 + 
+--R                             4         2 3  9            2 3         3 2  7
+--R                   (- 41A b c  - 280B b c )x  + (- 280A b c  - 688B b c )x
+--R                 + 
+--R                            3 2         4   5            4          5  3
+--R                   (- 688A b c  - 704B b c)x  + (- 704A b c - 256B b )x
+--R                 + 
+--R                           5
+--R                   - 256A b x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                       5 12        5           4  10            4         2 3  8
+--R                   9B c x   + (9A c  + 129B b c )x   + (129A b c  + 552B b c )x
+--R                 + 
+--R                          2 3          3 2  6           3 2         4   4
+--R                   (552A b c  + 1008B b c )x  + (1008A b c  + 832B b c)x
+--R                 + 
+--R                          4          5  2         5
+--R                   (832A b c + 256B b )x  + 256A b
+--R              *
+--R                  +-+
+--R                 \|b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                   5 13        5           4  11            4         2 3  9
+--R               9B c x   + (9A c  + 129B b c )x   + (129A b c  + 552B b c )x
+--R             + 
+--R                      2 3          3 2  7           3 2         4   5
+--R               (552A b c  + 1008B b c )x  + (1008A b c  + 832B b c)x
+--R             + 
+--R                      4          5  3         5
+--R               (832A b c + 256B b )x  + 256A b x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R         + 
+--R                6 14         6          5  12             5         2 4  10
+--R           - B c x   + (- A c  - 42B b c )x   + (- 42A b c  - 321B b c )x
+--R         + 
+--R                    2 4         3 3  8            3 3          4 2  6
+--R           (- 321A b c  - 968B b c )x  + (- 968A b c  - 1392B b c )x
+--R         + 
+--R                     4 2         5   4            5          6  2         6
+--R           (- 1392A b c  - 960B b c)x  + (- 960A b c - 256B b )x  - 256A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                     5 14          5           4  12
+--R               - 9B c x   + (- 9A c  - 129B b c )x
+--R             + 
+--R                          4         2 3  10            2 3          3 2  8
+--R               (- 129A b c  - 552B b c )x   + (- 552A b c  - 1008B b c )x
+--R             + 
+--R                       3 2         4   6            4          5  4         5 2
+--R             (- 1008A b c  - 832B b c)x  + (- 832A b c - 256B b )x  - 256A b x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R         + 
+--R              6 15       6          5  13           5         2 4  11
+--R           B c x   + (A c  + 42B b c )x   + (42A b c  + 321B b c )x
+--R         + 
+--R                  2 4         3 3  9          3 3          4 2  7
+--R           (321A b c  + 968B b c )x  + (968A b c  + 1392B b c )x
+--R         + 
+--R                   4 2         5   5          5          6  3         6
+--R           (1392A b c  + 960B b c)x  + (960A b c + 256B b )x  + 256A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R              6 16       6          5  14           5         2 4  12
+--R           B c x   + (A c  + 42B b c )x   + (42A b c  + 321B b c )x
+--R         + 
+--R                  2 4         3 3  10          3 3          4 2  8
+--R           (321A b c  + 968B b c )x   + (968A b c  + 1392B b c )x
+--R         + 
+--R                   4 2         5   6          5          6  4         6 2
+--R           (1392A b c  + 960B b c)x  + (960A b c + 256B b )x  + 256A b x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                 6 15          6           5  13              5         2 4  11
+--R           - 9B c x   + (- 9A c  - 138B b c )x   + (- 138A b c  - 681B b c )x
+--R         + 
+--R                    2 4          3 3  9             3 3          4 2  7
+--R           (- 681A b c  - 1560B b c )x  + (- 1560A b c  - 1840B b c )x
+--R         + 
+--R                     4 2          5   5             5          6  3         6
+--R           (- 1840A b c  - 1088B b c)x  + (- 1088A b c - 256B b )x  - 256A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                4 13         3 11       2 2 9       3   7       4 5  +-+ +-+
+--R             (9c x   + 120b c x   + 432b c x  + 576b c x  + 256b x )\|b \|c
+--R           + 
+--R                5 14        4 12       2 3 10       3 2 8       4   6       5 4
+--R             - c x   - 41b c x   - 280b c x   - 688b c x  - 704b c x  - 256b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R               5 15        4 13       2 3 11       3 2 9       4   7       5 5
+--R           (- c x   - 41b c x   - 280b c x   - 688b c x  - 704b c x  - 256b x )
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R          5 14         4 12       2 3 10        3 2 8       4   6       5 4  +-+
+--R       (9c x   + 129b c x   + 552b c x   + 1008b c x  + 832b c x  + 256b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 773
+
+--S 774 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                        +--------+
+--R                      6        2 4  +-+ |   2
+--R           (- 3B b c x  - 12B b x )\|c \|c x  + b
+--R         + 
+--R                    6        2 4  +-+ +-+
+--R           (9B b c x  + 12B b x )\|b \|c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                        +--------+
+--R                    6        2 4  +---+ |   2
+--R           (6B b c x  + 24B b x )\|- c \|c x  + b
+--R         + 
+--R                       6        2 4  +---+ +-+
+--R           (- 18B b c x  - 24B b x )\|- c \|b
+--R      *
+--R               +--------+
+--R               |   2         +-+
+--R              \|c x  + b  - \|b
+--R         atan(------------------)
+--R                      +---+
+--R                    x\|- c
+--R     + 
+--R                                                             +--------+
+--R                2           4                  2  2       2  |   2
+--R           ((A c  + 3B b c)x  + (5A b c + 12B b )x  + 4A b )\|c x  + b
+--R         + 
+--R                   2           4                    2  2       2  +-+
+--R           ((- 3A c  - 9B b c)x  + (- 7A b c - 12B b )x  - 4A b )\|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                               +--------+
+--R             2           5                  2  3       2   +-+ |   2
+--R       ((3A c  + 9B b c)x  + (7A b c + 12B b )x  + 4A b x)\|b \|c x  + b
+--R     + 
+--R             3         2  7            2        2   5          2         3  3
+--R       (- A c  - 3B b c )x  + (- 6A b c  - 15B b c)x  + (- 9A b c - 12B b )x
+--R     + 
+--R             3
+--R       - 4A b x
+--R  /
+--R                        +--------+
+--R            6      2 4  |   2                 6      2 4  +-+
+--R     (3b c x  + 12b x )\|c x  + b  + (- 9b c x  - 12b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                     3 8          3          2  6             2        2   4
+--R               - 6B c x  + (- 6A c  - 38B b c )x  + (- 38A b c  - 64B b c)x
+--R             + 
+--R                       2         3  2        3
+--R               (- 64A b c - 32B b )x  - 32A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              4 10       4          3  8           3        2 2  6
+--R           B c x   + (A c  + 19B b c )x  + (19A b c  + 66B b c )x
+--R         + 
+--R                 2 2        3   4         3         4  2        4
+--R           (66A b c  + 80B b c)x  + (80A b c + 32B b )x  + 32A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                4 11         4          3  9             3        2 2  7
+--R           - B c x   + (- A c  - 19B b c )x  + (- 19A b c  - 66B b c )x
+--R         + 
+--R                   2 2        3   5           3         4  3        4
+--R           (- 66A b c  - 80B b c)x  + (- 80A b c - 32B b )x  - 32A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               4 11        4          3  9           3         2 2  7
+--R           6B c x   + (6A c  + 44B b c )x  + (44A b c  + 102B b c )x
+--R         + 
+--R                  2 2        3   5         3         4  3        4
+--R           (102A b c  + 96B b c)x  + (96A b c + 32B b )x  + 32A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                +--------+
+--R           3 10        2 8      2   6      3 4  |   2
+--R         (c x   + 18b c x  + 48b c x  + 32b x )\|c x  + b
+--R       + 
+--R              3 10        2 8      2   6      3 4  +-+
+--R         (- 6c x   - 38b c x  - 64b c x  - 32b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 775
+
+)clear all
+
+--S 776 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^7
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    7
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 3139
+r0:=-1/5*A*(b*x^2+c*x^4)^(3/2)/(b*x^8)-1/15*(5*b*B-2*A*c)*_
+   (b*x^2+c*x^4)^(3/2)/(b^2*x^6)
+--R 
+--R
+--R                                                           +-----------+
+--R              2           4                  2  2       2  |   4      2
+--R        ((2A c  - 5B b c)x  + (- A b c - 5B b )x  - 3A b )\|c x  + b x
+--R   (2)  ----------------------------------------------------------------
+--R                                        2 6
+--R                                     15b x
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   4          3  8             3         2 2  6
+--R           (- 10A c  + 25B b c )x  + (- 35A b c  + 125B b c )x
+--R         + 
+--R                2 2         3   4         3         4  2        4
+--R           (3A b c  + 180B b c)x  + (76A b c + 80B b )x  + 48A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R            5         4  10           4        2 3  8         2 3         3 2  6
+--R       (2A c  - 5B b c )x   + (25A b c  - 70B b c )x  + (40A b c  - 205B b c )x
+--R     + 
+--R               3 2         4   4            4         5  2        5
+--R       (- 35A b c  - 220B b c)x  + (- 100A b c - 80B b )x  - 48A b
+--R  /
+--R                                        +--------+
+--R           2 2 9       3   7       4 5  |   2
+--R       (15b c x  + 180b c x  + 240b x )\|c x  + b
+--R     + 
+--R             2 2 9       3   7       4 5  +-+
+--R       (- 75b c x  - 300b c x  - 240b x )\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 778
+
+--S 779 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      4         3  8             3        2 2  6
+--R               (- 2A c  + 5B b c )x  + (- 23A b c  + 65B b c )x
+--R             + 
+--R                       2 2         3   4         3         4  2        4
+--R               (- 17A b c  + 140B b c)x  + (52A b c + 80B b )x  + 48A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                     4          3  8           3         2 2  6
+--R               (10A c  - 25B b c )x  + (35A b c  - 125B b c )x
+--R             + 
+--R                      2 2         3   4           3         4  2        4
+--R               (- 3A b c  - 180B b c)x  + (- 76A b c - 80B b )x  - 48A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                   4          3  9             3         2 2  7
+--R           (- 10A c  + 25B b c )x  + (- 35A b c  + 125B b c )x
+--R         + 
+--R                2 2         3   5         3         4  3        4
+--R           (3A b c  + 180B b c)x  + (76A b c + 80B b )x  + 48A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R            5         4  11           4        2 3  9         2 3         3 2  7
+--R       (2A c  - 5B b c )x   + (25A b c  - 70B b c )x  + (40A b c  - 205B b c )x
+--R     + 
+--R               3 2         4   5            4         5  3        5
+--R       (- 35A b c  - 220B b c)x  + (- 100A b c - 80B b )x  - 48A b x
+--R  /
+--R                                         +--------+
+--R           2 2 10       3   8       4 6  |   2
+--R       (15b c x   + 180b c x  + 240b x )\|c x  + b
+--R     + 
+--R             2 2 10       3   8       4 6  +-+
+--R       (- 75b c x   - 300b c x  - 240b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      5 12           5           4  10
+--R               - 10B c x   + (- 10A c  - 170B b c )x
+--R             + 
+--R                          4         2 3  8            2 3          3 2  6
+--R               (- 170A b c  - 832B b c )x  + (- 832A b c  - 1696B b c )x
+--R             + 
+--R                       3 2          4   4             4          5  2         5
+--R             (- 1696A b c  - 1536B b c)x  + (- 1536A b c - 512B b )x  - 512A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              6 14       6          5  12           5         2 4  10
+--R           B c x   + (A c  + 51B b c )x   + (51A b c  + 450B b c )x
+--R         + 
+--R                  2 4          3 3  8           3 3          4 2  6
+--R           (450A b c  + 1520B b c )x  + (1520A b c  + 2400B b c )x
+--R         + 
+--R                   4 2          5   4           5          6  2         6
+--R           (2400A b c  + 1792B b c)x  + (1792A b c + 512B b )x  + 512A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                6 15         6          5  13             5         2 4  11
+--R           - B c x   + (- A c  - 51B b c )x   + (- 51A b c  - 450B b c )x
+--R         + 
+--R                    2 4          3 3  9             3 3          4 2  7
+--R           (- 450A b c  - 1520B b c )x  + (- 1520A b c  - 2400B b c )x
+--R         + 
+--R                     4 2          5   5             5          6  3         6
+--R           (- 2400A b c  - 1792B b c)x  + (- 1792A b c - 512B b )x  - 512A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                6 15         6           5  13            5          2 4  11
+--R           10B c x   + (10A c  + 180B b c )x   + (180A b c  + 1002B b c )x
+--R         + 
+--R                   2 4          3 3  9           3 3          4 2  7
+--R           (1002A b c  + 2528B b c )x  + (2528A b c  + 3232B b c )x
+--R         + 
+--R                   4 2          5   5           5          6  3         6
+--R           (3232A b c  + 2048B b c)x  + (2048A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R             5 16        4 14       2 3 12        3 2 10        4   8       5 6
+--R           (c x   + 50b c x   + 400b c x   + 1120b c x   + 1280b c x  + 512b x )
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  5 16         4 14       2 3 12        3 2 10        4   8
+--R             - 10c x   - 170b c x   - 832b c x   - 1696b c x   - 1536b c x
+--R           + 
+--R                   5 6
+--R             - 512b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 780
+
+)clear all
+
+--S 781 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^9
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    9
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 781
+
+--S 782 of 3139
+r0:=-1/7*A*(b*x^2+c*x^4)^(3/2)/(b*x^10)-1/35*(7*b*B-4*A*c)*_
+   (b*x^2+c*x^4)^(3/2)/(b^2*x^8)+2/105*c*(7*b*B-4*A*c)*(b*x^2+_
+   c*x^4)^(3/2)/(b^3*x^6)
+--R 
+--R
+--R   (2)
+--R                3          2  6          2       2   4          2         3  2
+--R         (- 8A c  + 14B b c )x  + (4A b c  - 7B b c)x  + (- 3A b c - 21B b )x
+--R       + 
+--R                3
+--R         - 15A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         3 8
+--R     105b x
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 6          5  12            5         2 4  10
+--R           (56A c  - 98B b c )x   + (420A b c  - 735B b c )x
+--R         + 
+--R                  2 4          3 3  8          3 3          4 2  6
+--R           (693A b c  - 1029B b c )x  + (337A b c  + 1064B b c )x
+--R         + 
+--R                  4 2          5   4           5           6  2         6
+--R           (920A b c  + 2800B b c)x  + (1872A b c + 1344B b )x  + 960A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              7          6  14              6         2 5  12
+--R       (- 8A c  + 14B b c )x   + (- 196A b c  + 343B b c )x
+--R     + 
+--R                2 5          3 4  10            3 4         4 3  8
+--R       (- 735A b c  + 1260B b c )x   + (- 826A b c  + 763B b c )x
+--R     + 
+--R                4 3          5 2  6             5 2          6   4
+--R       (- 623A b c  - 2296B b c )x  + (- 1736A b c  - 3472B b c)x
+--R     + 
+--R                 6           7  2         7
+--R       (- 2352A b c - 1344B b )x  - 960A b
+--R  /
+--R                                                          +--------+
+--R            3 3 13        4 2 11        5   9        6 7  |   2
+--R       (105b c x   + 2520b c x   + 8400b c x  + 6720b x )\|c x  + b
+--R     + 
+--R              3 3 13        4 2 11         5   9        6 7  +-+
+--R       (- 735b c x   - 5880b c x   - 11760b c x  - 6720b x )\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 783
+
+--S 784 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    6          5  12            5         2 4  10
+--R               (8A c  - 14B b c )x   + (188A b c  - 329B b c )x
+--R             + 
+--R                      2 4         3 3  8          3 3         4 2  6
+--R               (547A b c  - 931B b c )x  + (279A b c  + 168B b c )x
+--R             + 
+--R                      4 2          5   4           5           6  2         6
+--R               (344A b c  + 2128B b c)x  + (1392A b c + 1344B b )x  + 960A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                       6          5  12              5         2 4  10
+--R               (- 56A c  + 98B b c )x   + (- 420A b c  + 735B b c )x
+--R             + 
+--R                        2 4          3 3  8            3 3          4 2  6
+--R               (- 693A b c  + 1029B b c )x  + (- 337A b c  - 1064B b c )x
+--R             + 
+--R                      4 2          5   4             5           6  2         6
+--R             (- 920A b c  - 2800B b c)x  + (- 1872A b c - 1344B b )x  - 960A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 6          5  13            5         2 4  11
+--R           (56A c  - 98B b c )x   + (420A b c  - 735B b c )x
+--R         + 
+--R                  2 4          3 3  9          3 3          4 2  7
+--R           (693A b c  - 1029B b c )x  + (337A b c  + 1064B b c )x
+--R         + 
+--R                  4 2          5   5           5           6  3         6
+--R           (920A b c  + 2800B b c)x  + (1872A b c + 1344B b )x  + 960A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              7          6  15              6         2 5  13
+--R       (- 8A c  + 14B b c )x   + (- 196A b c  + 343B b c )x
+--R     + 
+--R                2 5          3 4  11            3 4         4 3  9
+--R       (- 735A b c  + 1260B b c )x   + (- 826A b c  + 763B b c )x
+--R     + 
+--R                4 3          5 2  7             5 2          6   5
+--R       (- 623A b c  - 2296B b c )x  + (- 1736A b c  - 3472B b c)x
+--R     + 
+--R                 6           7  3         7
+--R       (- 2352A b c - 1344B b )x  - 960A b x
+--R  /
+--R                                                           +--------+
+--R            3 3 14        4 2 12        5   10        6 8  |   2
+--R       (105b c x   + 2520b c x   + 8400b c x   + 6720b x )\|c x  + b
+--R     + 
+--R              3 3 14        4 2 12         5   10        6 8  +-+
+--R       (- 735b c x   - 5880b c x   - 11760b c x   - 6720b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      7 16           7           6  14
+--R               - 14B c x   + (- 14A c  - 462B b c )x
+--R             + 
+--R                          6          2 5  12             2 5           3 4  10
+--R               (- 462A b c  - 4480B b c )x   + (- 4480A b c  - 19392B b c )x
+--R             + 
+--R                          3 4           4 3  8              4 3           5 2  6
+--R               (- 19392A b c  - 43520B b c )x  + (- 43520A b c  - 52736B b c )x
+--R             + 
+--R                          5 2           6   4              6           7  2
+--R               (- 52736A b c  - 32768B b c)x  + (- 32768A b c - 8192B b )x
+--R             + 
+--R                        7
+--R               - 8192A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              8 18       8          7  16           7          2 6  14
+--R           B c x   + (A c  + 99B b c )x   + (99A b c  + 1666B b c )x
+--R         + 
+--R                   2 6           3 5  12            3 5           4 4  10
+--R           (1666A b c  + 10976B b c )x   + (10976A b c  + 36288B b c )x
+--R         + 
+--R                    4 4           5 3  8            5 3           6 2  6
+--R           (36288A b c  + 66304B b c )x  + (66304A b c  + 68096B b c )x
+--R         + 
+--R                    6 2           7   4            7           8  2          8
+--R           (68096A b c  + 36864B b c)x  + (36864A b c + 8192B b )x  + 8192A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                8 19         8          7  17             7          2 6  15
+--R           - B c x   + (- A c  - 99B b c )x   + (- 99A b c  - 1666B b c )x
+--R         + 
+--R                     2 6           3 5  13              3 5           4 4  11
+--R           (- 1666A b c  - 10976B b c )x   + (- 10976A b c  - 36288B b c )x
+--R         + 
+--R                      4 4           5 3  9              5 3           6 2  7
+--R           (- 36288A b c  - 66304B b c )x  + (- 66304A b c  - 68096B b c )x
+--R         + 
+--R                      6 2           7   5              7           8  3
+--R           (- 68096A b c  - 36864B b c)x  + (- 36864A b c - 8192B b )x
+--R         + 
+--R                    8
+--R           - 8192A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                8 19         8           7  17            7          2 6  15
+--R           14B c x   + (14A c  + 476B b c )x   + (476A b c  + 4942B b c )x
+--R         + 
+--R                   2 6           3 5  13            3 5           4 4  11
+--R           (4942A b c  + 23872B b c )x   + (23872A b c  + 62912B b c )x
+--R         + 
+--R                    4 4           5 3  9            5 3           6 2  7
+--R           (62912A b c  + 96256B b c )x  + (96256A b c  + 85504B b c )x
+--R         + 
+--R                    6 2           7   5            7           8  3          8
+--R           (85504A b c  + 40960B b c)x  + (40960A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              7 22        6 20        2 5 18        3 4 16         4 3 14
+--R             c x   + 98b c x   + 1568b c x   + 9408b c x   + 26880b c x
+--R           + 
+--R                   5 2 12         6   10        7 8
+--R             39424b c x   + 28672b c x   + 8192b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  7 22         6 20        2 5 18         3 4 16         4 3 14
+--R             - 14c x   - 462b c x   - 4480b c x   - 19392b c x   - 43520b c x
+--R           + 
+--R                     5 2 12         6   10        7 8
+--R             - 52736b c x   - 32768b c x   - 8192b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 785
+
+)clear all
+
+--S 786 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^11
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    11
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 3139
+r0:=-1/9*A*(b*x^2+c*x^4)^(3/2)/(b*x^12)-1/21*(3*b*B-2*A*c)*_
+   (b*x^2+c*x^4)^(3/2)/(b^2*x^10)+4/105*c*(3*b*B-2*A*c)*(b*x^2+_
+   c*x^4)^(3/2)/(b^3*x^8)-8/315*c^2*(3*b*B-2*A*c)*(b*x^2+c*x^4)^(3/2)/(b^4*x^6)
+--R 
+--R
+--R   (2)
+--R               4          3  8            3        2 2  6        2 2       3   4
+--R         (16A c  - 24B b c )x  + (- 8A b c  + 12B b c )x  + (6A b c  - 9B b c)x
+--R       + 
+--R                3         4  2        4
+--R         (- 5A b c - 45B b )x  - 35A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         4 10
+--R     315b x
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    8           7  16               7          2 6  14
+--R           (- 144A c  + 216B b c )x   + (- 1848A b c  + 2772B b c )x
+--R         + 
+--R                     2 6          3 5  12             3 5           4 4  10
+--R           (- 6006A b c  + 9009B b c )x   + (- 6435A b c  + 10125B b c )x
+--R         + 
+--R                     4 4          5 3  8           5 3           6 2  6
+--R           (- 1165A b c  + 8520B b c )x  + (4952A b c  + 21552B b c )x
+--R         + 
+--R                    6 2           7   4            7            8  2          8
+--R           (16464A b c  + 28224B b c)x  + (21440A b c + 11520B b )x  + 8960A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R             9          8  18            8         2 7  16
+--R       (16A c  - 24B b c )x   + (648A b c  - 972B b c )x
+--R     + 
+--R               2 7          3 6  14           3 6           4 5  12
+--R       (4158A b c  - 6237B b c )x   + (9009A b c  - 13566B b c )x
+--R     + 
+--R               4 5           5 4  10            5 4           6 3  8
+--R       (7200A b c  - 13005B b c )x   + (- 243A b c  - 16488B b c )x
+--R     + 
+--R                  6 3           7 2  6              7 2           8   4
+--R       (- 11064A b c  - 34224B b c )x  + (- 26064A b c  - 33984B b c)x
+--R     + 
+--R                  8            9  2          9
+--R       (- 25920A b c - 11520B b )x  - 8960A b
+--R  /
+--R              4 4 17         5 3 15         6 2 13          7   11         8 9
+--R         (315b c x   + 12600b c x   + 75600b c x   + 141120b c x   + 80640b x )
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                  4 4 17         5 3 15          6 2 13          7   11
+--R           - 2835b c x   - 37800b c x   - 136080b c x   - 181440b c x
+--R         + 
+--R                   8 9
+--R           - 80640b x
+--R      *
+--R          +-+
+--R         \|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 788
+
+--S 789 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       8          7  16              7         2 6  14
+--R               (- 16A c  + 24B b c )x   + (- 632A b c  + 948B b c )x
+--R             + 
+--R                         2 6          3 5  12             3 5          4 4  10
+--R               (- 3526A b c  + 5289B b c )x   + (- 5483A b c  + 8277B b c )x
+--R             + 
+--R                         4 4          5 3  8           5 3           6 2  6
+--R               (- 1717A b c  + 4728B b c )x  + (1960A b c  + 11760B b c )x
+--R             + 
+--R                     6 2           7   4            7            8  2          8
+--R             (9104A b c  + 22464B b c)x  + (16960A b c + 11520B b )x  + 8960A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                      8           7  16             7          2 6  14
+--R               (144A c  - 216B b c )x   + (1848A b c  - 2772B b c )x
+--R             + 
+--R                       2 6          3 5  12           3 5           4 4  10
+--R               (6006A b c  - 9009B b c )x   + (6435A b c  - 10125B b c )x
+--R             + 
+--R                       4 4          5 3  8             5 3           6 2  6
+--R               (1165A b c  - 8520B b c )x  + (- 4952A b c  - 21552B b c )x
+--R             + 
+--R                          6 2           7   4              7            8  2
+--R               (- 16464A b c  - 28224B b c)x  + (- 21440A b c - 11520B b )x
+--R             + 
+--R                        8
+--R               - 8960A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    8           7  17               7          2 6  15
+--R           (- 144A c  + 216B b c )x   + (- 1848A b c  + 2772B b c )x
+--R         + 
+--R                     2 6          3 5  13             3 5           4 4  11
+--R           (- 6006A b c  + 9009B b c )x   + (- 6435A b c  + 10125B b c )x
+--R         + 
+--R                     4 4          5 3  9           5 3           6 2  7
+--R           (- 1165A b c  + 8520B b c )x  + (4952A b c  + 21552B b c )x
+--R         + 
+--R                  6 2           7   5            7            8  3          8
+--R         (16464A b c  + 28224B b c)x  + (21440A b c + 11520B b )x  + 8960A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R             9          8  19            8         2 7  17
+--R       (16A c  - 24B b c )x   + (648A b c  - 972B b c )x
+--R     + 
+--R               2 7          3 6  15           3 6           4 5  13
+--R       (4158A b c  - 6237B b c )x   + (9009A b c  - 13566B b c )x
+--R     + 
+--R               4 5           5 4  11            5 4           6 3  9
+--R       (7200A b c  - 13005B b c )x   + (- 243A b c  - 16488B b c )x
+--R     + 
+--R                  6 3           7 2  7              7 2           8   5
+--R       (- 11064A b c  - 34224B b c )x  + (- 26064A b c  - 33984B b c)x
+--R     + 
+--R                  8            9  3          9
+--R       (- 25920A b c - 11520B b )x  - 8960A b x
+--R  /
+--R              4 4 18         5 3 16         6 2 14          7   12         8 10
+--R         (315b c x   + 12600b c x   + 75600b c x   + 141120b c x   + 80640b x  )
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                  4 4 18         5 3 16          6 2 14          7   12
+--R           - 2835b c x   - 37800b c x   - 136080b c x   - 181440b c x
+--R         + 
+--R                   8 10
+--R           - 80640b x
+--R      *
+--R          +-+
+--R         \|b
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      9 20           9           8  18
+--R               - 18B c x   + (- 18A c  - 978B b c )x
+--R             + 
+--R                          8           2 7  16
+--R               (- 978A b c  - 15744B b c )x
+--R             + 
+--R                          2 7            3 6  14
+--R               (- 15744A b c  - 116160B b c )x
+--R             + 
+--R                           3 6            4 5  12
+--R               (- 116160A b c  - 467456B b c )x
+--R             + 
+--R                           4 5             5 4  10
+--R               (- 467456A b c  - 1111552B b c )x
+--R             + 
+--R                            5 4             6 3  8
+--R               (- 1111552A b c  - 1605632B b c )x
+--R             + 
+--R                            6 3             7 2  6
+--R               (- 1605632A b c  - 1384448B b c )x
+--R             + 
+--R                            7 2            8   4
+--R               (- 1384448A b c  - 655360B b c)x
+--R             + 
+--R                           8             9  2            9
+--R               (- 655360A b c - 131072B b )x  - 131072A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              10 22       10           9  20            9          2 8  18
+--R           B c  x   + (A c   + 163B b c )x   + (163A b c  + 4482B b c )x
+--R         + 
+--R                   2 8           3 7  16            3 7            4 6  14
+--R           (4482A b c  + 48672B b c )x   + (48672A b c  + 272448B b c )x
+--R         + 
+--R                     4 6            5 5  12             5 5             6 4  10
+--R           (272448A b c  + 887040B b c )x   + (887040A b c  + 1777152B b c )x
+--R         + 
+--R                      6 4             7 3  8              7 3             8 2  6
+--R           (1777152A b c  + 2224128B b c )x  + (2224128A b c  + 1695744B b c )x
+--R         + 
+--R                      8 2            9   4             9             10  2
+--R           (1695744A b c  + 720896B b c)x  + (720896A b c + 131072B b  )x
+--R         + 
+--R                    10
+--R           131072A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                10 23         10           9  21              9          2 8  19
+--R           - B c  x   + (- A c   - 163B b c )x   + (- 163A b c  - 4482B b c )x
+--R         + 
+--R                     2 8           3 7  17              3 7            4 6  15
+--R           (- 4482A b c  - 48672B b c )x   + (- 48672A b c  - 272448B b c )x
+--R         + 
+--R                       4 6            5 5  13
+--R           (- 272448A b c  - 887040B b c )x
+--R         + 
+--R                       5 5             6 4  11
+--R           (- 887040A b c  - 1777152B b c )x
+--R         + 
+--R                        6 4             7 3  9
+--R           (- 1777152A b c  - 2224128B b c )x
+--R         + 
+--R                        7 3             8 2  7
+--R           (- 2224128A b c  - 1695744B b c )x
+--R         + 
+--R                        8 2            9   5               9             10  3
+--R           (- 1695744A b c  - 720896B b c)x  + (- 720896A b c - 131072B b  )x
+--R         + 
+--R                      10
+--R           - 131072A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                10 23         10           9  21            9           2 8  19
+--R           18B c  x   + (18A c   + 996B b c )x   + (996A b c  + 16722B b c )x
+--R         + 
+--R                    2 8            3 7  17             3 7            4 6  15
+--R           (16722A b c  + 131904B b c )x   + (131904A b c  + 583616B b c )x
+--R         + 
+--R                     4 6             5 5  13
+--R           (583616A b c  + 1579008B b c )x
+--R         + 
+--R                      5 5             6 4  11
+--R           (1579008A b c  + 2717184B b c )x
+--R         + 
+--R                      6 4             7 3  9              7 3             8 2  7
+--R           (2717184A b c  + 2990080B b c )x  + (2990080A b c  + 2039808B b c )x
+--R         + 
+--R                      8 2            9   5             9             10  3
+--R           (2039808A b c  + 786432B b c)x  + (786432A b c + 131072B b  )x
+--R         + 
+--R                    10
+--R           131072A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              9 28         8 26        2 7 24         3 6 22          4 5 20
+--R             c x   + 162b c x   + 4320b c x   + 44352b c x   + 228096b c x
+--R           + 
+--R                    5 4 18           6 3 16           7 2 14          8   12
+--R             658944b c x   + 1118208b c x   + 1105920b c x   + 589824b c x
+--R           + 
+--R                    9 10
+--R             131072b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  9 28         8 26         2 7 24          3 6 22
+--R             - 18c x   - 978b c x   - 15744b c x   - 116160b c x
+--R           + 
+--R                      4 5 20           5 4 18           6 3 16           7 2 14
+--R             - 467456b c x   - 1111552b c x   - 1605632b c x   - 1384448b c x
+--R           + 
+--R                      8   12          9 10
+--R             - 655360b c x   - 131072b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 790
+
+)clear all
+
+--S 791 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^13
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    13
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 3139
+r0:=-1/11*A*(b*x^2+c*x^4)^(3/2)/(b*x^14)-1/99*(11*b*B-8*A*c)*_
+   (b*x^2+c*x^4)^(3/2)/(b^2*x^12)+2/231*c*(11*b*B-8*A*c)*(b*x^2+_
+   c*x^4)^(3/2)/(b^3*x^10)-8/1155*c^2*(11*b*B-8*A*c)*(b*x^2+_
+   c*x^4)^(3/2)/(b^4*x^8)+16/3465*c^3*(11*b*B-8*A*c)*(b*x^2+_
+   c*x^4)^(3/2)/(b^5*x^6)
+--R 
+--R
+--R   (2)
+--R                  5           4  10           4        2 3  8
+--R         (- 128A c  + 176B b c )x   + (64A b c  - 88B b c )x
+--R       + 
+--R                 2 3        3 2  6         3 2        4   4
+--R         (- 48A b c  + 66B b c )x  + (40A b c  - 55B b c)x
+--R       + 
+--R                 4          5  2         5
+--R         (- 35A b c - 385B b )x  - 315A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R          5 12
+--R     3465b x
+--R                                                    Type: Expression(Integer)
+--E 792
+
+--S 793 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   10            9  20              9           2 8  18
+--R           (1408A c   - 1936B b c )x   + (27456A b c  - 37752B b c )x
+--R         + 
+--R                     2 8            3 7  16             3 7            4 6  14
+--R           (144144A b c  - 198198B b c )x   + (291720A b c  - 401115B b c )x
+--R         + 
+--R                     4 6            5 5  12            5 5           6 4  10
+--R           (230945A b c  - 312785B b c )x   + (47901A b c  + 34188B b c )x
+--R         + 
+--R                    6 4            7 3  8             7 3             8 2  6
+--R           (69412A b c  + 533456B b c )x  + (423152A b c  + 1171456B b c )x
+--R         + 
+--R                     8 2             9   4             9             10  2
+--R           (944640A b c  + 1140480B b c)x  + (922880A b c + 394240B b  )x
+--R         + 
+--R                    10
+--R           322560A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                11           10  22               10           2 9  20
+--R       (- 128A c   + 176B b c  )x   + (- 7744A b c   + 10648B b c )x
+--R     + 
+--R                  2 9            3 8  18               3 8            4 7  16
+--R       (- 75504A b c  + 103818B b c )x   + (- 264264A b c  + 363363B b c )x
+--R     + 
+--R                   4 7            5 6  14               5 6            6 5  12
+--R       (- 401115A b c  + 551100B b c )x   + (- 254386A b c  + 322927B b c )x
+--R     + 
+--R                  6 5            7 4  10               7 4             8 3  8
+--R       (- 61523A b c  - 210364B b c )x   + (- 207988A b c  - 1001264B b c )x
+--R     + 
+--R                   8 3             9 2  6                9 2             10   4
+--R       (- 800272A b c  - 1692416B b c )x  + (- 1365760A b c  - 1337600B b  c)x
+--R     + 
+--R                    10             11  2            11
+--R       (- 1084160A b  c - 394240B b  )x  - 322560A b
+--R  /
+--R                5 5 21          6 4 19           7 3 17           8 2 15
+--R           3465b c x   + 207900b c x   + 1940400b c x   + 6209280b c x
+--R         + 
+--R                   9   13           10 11
+--R           7983360b c x   + 3548160b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                   5 5 21          6 4 19           7 3 17           8 2 15
+--R           - 38115b c x   - 762300b c x   - 4268880b c x   - 9757440b c x
+--R         + 
+--R                     9   13           10 11
+--R           - 9757440b c x   - 3548160b  x
+--R      *
+--R          +-+
+--R         \|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 793
+
+--S 794 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      10           9  20             9           2 8  18
+--R               (128A c   - 176B b c )x   + (7616A b c  - 10472B b c )x
+--R             + 
+--R                        2 8           3 7  16             3 7            4 6  14
+--R               (67888A b c  - 93346B b c )x   + (196376A b c  - 270017B b c )x
+--R             + 
+--R                         4 6            5 5  12            5 5           6 4  10
+--R               (204739A b c  - 281083B b c )x   + (49647A b c  - 41844B b c )x
+--R             + 
+--R                        6 4            7 3  8             7 3            8 2  6
+--R               (11876A b c  + 252208B b c )x  + (196112A b c  + 749056B b c )x
+--R             + 
+--R                         8 2            9   4             9             10  2
+--R               (604160A b c  + 943360B b c)x  + (761600A b c + 394240B b  )x
+--R             + 
+--R                        10
+--R               322560A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                         10            9  20                9           2 8  18
+--R               (- 1408A c   + 1936B b c )x   + (- 27456A b c  + 37752B b c )x
+--R             + 
+--R                           2 8            3 7  16
+--R               (- 144144A b c  + 198198B b c )x
+--R             + 
+--R                           3 7            4 6  14
+--R               (- 291720A b c  + 401115B b c )x
+--R             + 
+--R                           4 6            5 5  12
+--R               (- 230945A b c  + 312785B b c )x
+--R             + 
+--R                          5 5           6 4  10
+--R               (- 47901A b c  - 34188B b c )x
+--R             + 
+--R                          6 4            7 3  8
+--R               (- 69412A b c  - 533456B b c )x
+--R             + 
+--R                           7 3             8 2  6
+--R               (- 423152A b c  - 1171456B b c )x
+--R             + 
+--R                           8 2             9   4
+--R               (- 944640A b c  - 1140480B b c)x
+--R             + 
+--R                           9             10  2            10
+--R               (- 922880A b c - 394240B b  )x  - 322560A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                   10            9  21              9           2 8  19
+--R           (1408A c   - 1936B b c )x   + (27456A b c  - 37752B b c )x
+--R         + 
+--R                     2 8            3 7  17             3 7            4 6  15
+--R           (144144A b c  - 198198B b c )x   + (291720A b c  - 401115B b c )x
+--R         + 
+--R                     4 6            5 5  13            5 5           6 4  11
+--R           (230945A b c  - 312785B b c )x   + (47901A b c  + 34188B b c )x
+--R         + 
+--R                    6 4            7 3  9             7 3             8 2  7
+--R           (69412A b c  + 533456B b c )x  + (423152A b c  + 1171456B b c )x
+--R         + 
+--R                     8 2             9   5             9             10  3
+--R           (944640A b c  + 1140480B b c)x  + (922880A b c + 394240B b  )x
+--R         + 
+--R                    10
+--R           322560A b  x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                11           10  23               10           2 9  21
+--R       (- 128A c   + 176B b c  )x   + (- 7744A b c   + 10648B b c )x
+--R     + 
+--R                  2 9            3 8  19               3 8            4 7  17
+--R       (- 75504A b c  + 103818B b c )x   + (- 264264A b c  + 363363B b c )x
+--R     + 
+--R                   4 7            5 6  15               5 6            6 5  13
+--R       (- 401115A b c  + 551100B b c )x   + (- 254386A b c  + 322927B b c )x
+--R     + 
+--R                  6 5            7 4  11               7 4             8 3  9
+--R       (- 61523A b c  - 210364B b c )x   + (- 207988A b c  - 1001264B b c )x
+--R     + 
+--R                   8 3             9 2  7                9 2             10   5
+--R       (- 800272A b c  - 1692416B b c )x  + (- 1365760A b c  - 1337600B b  c)x
+--R     + 
+--R                    10             11  3            11
+--R       (- 1084160A b  c - 394240B b  )x  - 322560A b  x
+--R  /
+--R                5 5 22          6 4 20           7 3 18           8 2 16
+--R           3465b c x   + 207900b c x   + 1940400b c x   + 6209280b c x
+--R         + 
+--R                   9   14           10 12
+--R           7983360b c x   + 3548160b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                   5 5 22          6 4 20           7 3 18           8 2 16
+--R           - 38115b c x   - 762300b c x   - 4268880b c x   - 9757440b c x
+--R         + 
+--R                     9   14           10 12
+--R           - 9757440b c x   - 3548160b  x
+--R      *
+--R          +-+
+--R         \|b
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      11 24           11            10  22
+--R               - 22B c  x   + (- 22A c   - 1782B b c  )x
+--R             + 
+--R                           10           2 9  20
+--R               (- 1782A b c   - 42944B b c )x
+--R             + 
+--R                          2 9            3 8  18
+--R               (- 42944A b c  - 480480B b c )x
+--R             + 
+--R                           3 8             4 7  16
+--R               (- 480480A b c  - 3001856B b c )x
+--R             + 
+--R                            4 7              5 6  14
+--R               (- 3001856A b c  - 11508224B b c )x
+--R             + 
+--R                             5 6              6 5  12
+--R               (- 11508224A b c  - 28442624B b c )x
+--R             + 
+--R                             6 5              7 4  10
+--R               (- 28442624A b c  - 46235648B b c )x
+--R             + 
+--R                             7 4              8 3  8
+--R               (- 46235648A b c  - 49152000B b c )x
+--R             + 
+--R                             8 3              9 2  6
+--R               (- 49152000A b c  - 32899072B b c )x
+--R             + 
+--R                             9 2              10   4
+--R               (- 32899072A b c  - 12582912B b  c)x
+--R             + 
+--R                             10              11  2             11
+--R               (- 12582912A b  c - 2097152B b  )x  - 2097152A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              12 26       12           11  24            11          2 10  22
+--R           B c  x   + (A c   + 243B b c  )x   + (243A b c   + 9922B b c  )x
+--R         + 
+--R                   2 10            3 9  20             3 9             4 8  18
+--R           (9922A b c   + 160688B b c )x   + (160688A b c  + 1359072B b c )x
+--R         + 
+--R                      4 8             5 7  16
+--R           (1359072A b c  + 6845696B b c )x
+--R         + 
+--R                      5 7              6 6  14
+--R           (6845696A b c  + 22038016B b c )x
+--R         + 
+--R                       6 6              7 5  12
+--R           (22038016A b c  + 47038464B b c )x
+--R         + 
+--R                       7 5              8 4  10
+--R           (47038464A b c  + 67403776B b c )x
+--R         + 
+--R                       8 4              9 3  8
+--R           (67403776A b c  + 64159744B b c )x
+--R         + 
+--R                       9 3              10 2  6
+--R           (64159744A b c  + 38928384B b  c )x
+--R         + 
+--R                       10 2              11   4
+--R           (38928384A b  c  + 13631488B b  c)x
+--R         + 
+--R                       11              12  2             12
+--R           (13631488A b  c + 2097152B b  )x  + 2097152A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                12 27         12           11  25
+--R           - B c  x   + (- A c   - 243B b c  )x
+--R         + 
+--R                      11          2 10  23             2 10            3 9  21
+--R           (- 243A b c   - 9922B b c  )x   + (- 9922A b c   - 160688B b c )x
+--R         + 
+--R                       3 9             4 8  19
+--R           (- 160688A b c  - 1359072B b c )x
+--R         + 
+--R                        4 8             5 7  17
+--R           (- 1359072A b c  - 6845696B b c )x
+--R         + 
+--R                        5 7              6 6  15
+--R           (- 6845696A b c  - 22038016B b c )x
+--R         + 
+--R                         6 6              7 5  13
+--R           (- 22038016A b c  - 47038464B b c )x
+--R         + 
+--R                         7 5              8 4  11
+--R           (- 47038464A b c  - 67403776B b c )x
+--R         + 
+--R                         8 4              9 3  9
+--R           (- 67403776A b c  - 64159744B b c )x
+--R         + 
+--R                         9 3              10 2  7
+--R           (- 64159744A b c  - 38928384B b  c )x
+--R         + 
+--R                         10 2              11   5
+--R           (- 38928384A b  c  - 13631488B b  c)x
+--R         + 
+--R                         11              12  3             12
+--R           (- 13631488A b  c - 2097152B b  )x  - 2097152A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                12 27         12            11  25
+--R           22B c  x   + (22A c   + 1804B b c  )x
+--R         + 
+--R                     11           2 10  23            2 10            3 9  21
+--R           (1804A b c   + 44726B b c  )x   + (44726A b c   + 523424B b c )x
+--R         + 
+--R                     3 9             4 8  19
+--R           (523424A b c  + 3482336B b c )x
+--R         + 
+--R                      4 8              5 7  17
+--R           (3482336A b c  + 14510080B b c )x
+--R         + 
+--R                       5 7              6 6  15
+--R           (14510080A b c  + 39950848B b c )x
+--R         + 
+--R                       6 6              7 5  13
+--R           (39950848A b c  + 74678272B b c )x
+--R         + 
+--R                       7 5              8 4  11
+--R           (74678272A b c  + 95387648B b c )x
+--R         + 
+--R                       8 4              9 3  9
+--R           (95387648A b c  + 82051072B b c )x
+--R         + 
+--R                       9 3              10 2  7
+--R           (82051072A b c  + 45481984B b  c )x
+--R         + 
+--R                       10 2              11   5
+--R           (45481984A b  c  + 14680064B b  c)x
+--R         + 
+--R                       11              12  3             12
+--R           (14680064A b  c + 2097152B b  )x  + 2097152A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              11 34         10 32        2 9 30          3 8 28           4 7 26
+--R             c  x   + 242b c  x   + 9680b c x   + 151008b c x   + 1208064b c x
+--R           + 
+--R                     5 6 24            6 5 22            7 4 20
+--R             5637632b c x   + 16400384b c x   + 30638080b c x
+--R           + 
+--R                    8 3 18            9 2 16            10   14           11 12
+--R           36765696b c x   + 27394048b c x   + 11534336b  c x   + 2097152b  x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  11 34          10 32         2 9 30          3 8 28
+--R             - 22c  x   - 1782b c  x   - 42944b c x   - 480480b c x
+--R           + 
+--R                       4 7 26            5 6 24            6 5 22
+--R             - 3001856b c x   - 11508224b c x   - 28442624b c x
+--R           + 
+--R                        7 4 20            8 3 18            9 2 16
+--R             - 46235648b c x   - 49152000b c x   - 32899072b c x
+--R           + 
+--R                        10   14           11 12
+--R             - 12582912b  c x   - 2097152b  x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 795
+
+)clear all
+
+--S 796 of 3139
+t0:=x^4*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      +-----------+
+--R            6      4  |   4      2
+--R   (1)  (B x  + A x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 3139
+r0:=-8/315*b^2*(2*b*B-3*A*c)*(b*x^2+c*x^4)^(3/2)/(c^4*x^3)+_
+   4/105*b*(2*b*B-3*A*c)*(b*x^2+c*x^4)^(3/2)/(c^3*x)-1/21*(2*b*B-_
+   3*A*c)*x*(b*x^2+c*x^4)^(3/2)/c^2+1/9*B*x^3*(b*x^2+c*x^4)^(3/2)/c
+--R 
+--R
+--R   (2)
+--R              4 8         4         3  6          3       2 2  4
+--R         35B c x  + (45A c  + 5B b c )x  + (9A b c  - 6B b c )x
+--R       + 
+--R                 2 2       3   2        3         4
+--R         (- 12A b c  + 8B b c)x  + 24A b c - 16B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         4
+--R     315c x
+--R                                                    Type: Expression(Integer)
+--E 797
+
+--S 798 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     4 16              4          2 3  14
+--R           - 315B b c x   + (- 405A b c  - 4245B b c )x
+--R         + 
+--R                     2 3           3 2  12              3 2           4   10
+--R           (- 5481A b c  - 15666B b c )x   + (- 20412A b c  - 21672B b c)x
+--R         + 
+--R                      4            5  8           5 6
+--R           (- 28560A b c - 10080B b )x  - 13440A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                5 18         5            4  16             4          2 3  14
+--R           35B c x   + (45A c  + 1440B b c )x   + (1854A b c  + 9999B b c )x
+--R         + 
+--R                    2 3           3 2  12            3 2           4   10
+--R           (12957A b c  + 25242B b c )x   + (33012A b c  + 26712B b c)x
+--R         + 
+--R                    4            5  8           5 6
+--R           (35280A b c + 10080B b )x  + 13440A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              4 8           3 6         2 2 4          3   2         4  +-+
+--R         (315c x  + 12600b c x  + 75600b c x  + 141120b c x  + 80640b )\|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                4 8         2 3 6          3 2 4          4   2         5
+--R       - 2835b c x  - 37800b c x  - 136080b c x  - 181440b c x  - 80640b
+--R                                         Type: Union(Expression(Integer),...)
+--E 798
+
+--S 799 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      8 16           8            7  14
+--R               - 35B c x   + (- 45A c  - 1405B b c )x
+--R             + 
+--R                           7          2 6  12              2 6           3 5  10
+--R               (- 1809A b c  - 8594B b c )x   + (- 11148A b c  - 16648B b c )x
+--R             + 
+--R                          3 5           4 4  8              4 4         5 3  6
+--R               (- 21864A b c  - 10064B b c )x  + (- 13632A b c  + 128B b c )x
+--R             + 
+--R                         5 3          6 2  4             6 2          7   2
+--R               (- 2688A b c  + 1792B b c )x  + (- 7680A b c  + 5120B b c)x
+--R             + 
+--R                        7           8
+--R               - 6144A b c + 4096B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   8 16            8          2 7  14
+--R           315B b c x   + (405A b c  + 4245B b c )x
+--R         + 
+--R                   2 7           3 6  12            3 6           4 5  10
+--R           (5481A b c  + 15666B b c )x   + (20412A b c  + 21672B b c )x
+--R         + 
+--R                    4 5           5 4  8            5 4         6 3  6
+--R           (28584A b c  + 10064B b c )x  + (14400A b c  - 640B b c )x
+--R         + 
+--R                   6 3          7 2  4            7 2          8   2          8
+--R           (5760A b c  - 3840B b c )x  + (10752A b c  - 7168B b c)x  + 6144A b c
+--R         + 
+--R                    9
+--R           - 4096B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                     8 17              8          2 7  15
+--R           - 315B b c x   + (- 405A b c  - 4245B b c )x
+--R         + 
+--R                     2 7           3 6  13              3 6           4 5  11
+--R           (- 5481A b c  - 15666B b c )x   + (- 20412A b c  - 21672B b c )x
+--R         + 
+--R                      4 5           5 4  9           5 4 7
+--R           (- 28560A b c  - 10080B b c )x  - 13440A b c x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                9 19         9            8  17             8          2 7  15
+--R           35B c x   + (45A c  + 1440B b c )x   + (1854A b c  + 9999B b c )x
+--R         + 
+--R                    2 7           3 6  13            3 6           4 5  11
+--R           (12957A b c  + 25242B b c )x   + (33012A b c  + 26712B b c )x
+--R         + 
+--R                    4 5           5 4  9           5 4 7
+--R           (35280A b c  + 10080B b c )x  + 13440A b c x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              8 9           7 7         2 6 5          3 5 3         4 4   +-+
+--R         (315c x  + 12600b c x  + 75600b c x  + 141120b c x  + 80640b c x)\|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                8 9         2 7 7          3 6 5          4 5 3         5 4
+--R       - 2835b c x  - 37800b c x  - 136080b c x  - 181440b c x  - 80640b c x
+--R                                                    Type: Expression(Integer)
+--E 799
+
+--S 800 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      9 25           9           8  23
+--R               - 18B c x   + (- 18A c  - 978B b c )x
+--R             + 
+--R                          8           2 7  21
+--R               (- 978A b c  - 15744B b c )x
+--R             + 
+--R                          2 7            3 6  19
+--R               (- 15744A b c  - 116160B b c )x
+--R             + 
+--R                           3 6            4 5  17
+--R               (- 116160A b c  - 467456B b c )x
+--R             + 
+--R                           4 5             5 4  15
+--R               (- 467456A b c  - 1111552B b c )x
+--R             + 
+--R                            5 4             6 3  13
+--R               (- 1111552A b c  - 1605632B b c )x
+--R             + 
+--R                            6 3             7 2  11
+--R               (- 1605632A b c  - 1384448B b c )x
+--R             + 
+--R                            7 2            8   9
+--R               (- 1384448A b c  - 655360B b c)x
+--R             + 
+--R                           8             9  7            9 5
+--R               (- 655360A b c - 131072B b )x  - 131072A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              10 27       10           9  25            9          2 8  23
+--R           B c  x   + (A c   + 163B b c )x   + (163A b c  + 4482B b c )x
+--R         + 
+--R                   2 8           3 7  21            3 7            4 6  19
+--R           (4482A b c  + 48672B b c )x   + (48672A b c  + 272448B b c )x
+--R         + 
+--R                     4 6            5 5  17             5 5             6 4  15
+--R           (272448A b c  + 887040B b c )x   + (887040A b c  + 1777152B b c )x
+--R         + 
+--R                      6 4             7 3  13
+--R           (1777152A b c  + 2224128B b c )x
+--R         + 
+--R                      7 3             8 2  11              8 2            9   9
+--R           (2224128A b c  + 1695744B b c )x   + (1695744A b c  + 720896B b c)x
+--R         + 
+--R                     9             10  7            10 5
+--R           (720896A b c + 131072B b  )x  + 131072A b  x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                10 28         10           9  26              9          2 8  24
+--R           - B c  x   + (- A c   - 163B b c )x   + (- 163A b c  - 4482B b c )x
+--R         + 
+--R                     2 8           3 7  22              3 7            4 6  20
+--R           (- 4482A b c  - 48672B b c )x   + (- 48672A b c  - 272448B b c )x
+--R         + 
+--R                       4 6            5 5  18
+--R           (- 272448A b c  - 887040B b c )x
+--R         + 
+--R                       5 5             6 4  16
+--R           (- 887040A b c  - 1777152B b c )x
+--R         + 
+--R                        6 4             7 3  14
+--R           (- 1777152A b c  - 2224128B b c )x
+--R         + 
+--R                        7 3             8 2  12
+--R           (- 2224128A b c  - 1695744B b c )x
+--R         + 
+--R                        8 2            9   10               9             10  8
+--R           (- 1695744A b c  - 720896B b c)x   + (- 720896A b c - 131072B b  )x
+--R         + 
+--R                      10 6
+--R           - 131072A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                10 28         10           9  26            9           2 8  24
+--R           18B c  x   + (18A c   + 996B b c )x   + (996A b c  + 16722B b c )x
+--R         + 
+--R                    2 8            3 7  22             3 7            4 6  20
+--R           (16722A b c  + 131904B b c )x   + (131904A b c  + 583616B b c )x
+--R         + 
+--R                     4 6             5 5  18
+--R           (583616A b c  + 1579008B b c )x
+--R         + 
+--R                      5 5             6 4  16
+--R           (1579008A b c  + 2717184B b c )x
+--R         + 
+--R                      6 4             7 3  14
+--R           (2717184A b c  + 2990080B b c )x
+--R         + 
+--R                      7 3             8 2  12              8 2            9   10
+--R           (2990080A b c  + 2039808B b c )x   + (2039808A b c  + 786432B b c)x
+--R         + 
+--R                     9             10  8            10 6
+--R           (786432A b c + 131072B b  )x  + 131072A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              9 18         8 16        2 7 14         3 6 12          4 5 10
+--R             c x   + 162b c x   + 4320b c x   + 44352b c x   + 228096b c x
+--R           + 
+--R                    5 4 8           6 3 6           7 2 4          8   2
+--R             658944b c x  + 1118208b c x  + 1105920b c x  + 589824b c x
+--R           + 
+--R                    9
+--R             131072b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  9 18         8 16         2 7 14          3 6 12
+--R             - 18c x   - 978b c x   - 15744b c x   - 116160b c x
+--R           + 
+--R                      4 5 10           5 4 8           6 3 6           7 2 4
+--R             - 467456b c x   - 1111552b c x  - 1605632b c x  - 1384448b c x
+--R           + 
+--R                      8   2          9
+--R             - 655360b c x  - 131072b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 800
+
+)clear all
+
+--S 801 of 3139
+t0:=x^2*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      +-----------+
+--R            4      2  |   4      2
+--R   (1)  (B x  + A x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 801
+
+--S 802 of 3139
+r0:=2/105*b*(4*b*B-7*A*c)*(b*x^2+c*x^4)^(3/2)/(c^3*x^3)-_
+   1/35*(4*b*B-7*A*c)*(b*x^2+c*x^4)^(3/2)/(c^2*x)+1/7*B*x*_
+   (b*x^2+c*x^4)^(3/2)/c
+--R 
+--R
+--R   (2)
+--R                3 6         3         2  4          2       2   2        2
+--R           15B c x  + (21A c  + 3B b c )x  + (7A b c  - 4B b c)x  - 14A b c
+--R         + 
+--R               3
+--R           8B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         3
+--R     105c x
+--R                                                    Type: Expression(Integer)
+--E 802
+
+--S 803 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     3 12              3         2 2  10
+--R           - 105B b c x   + (- 147A b c  - 861B b c )x
+--R         + 
+--R                   2 2          3   8             3           4  6          4 4
+--R         (- 1225A b c  - 1820B b c)x  + (- 2660A b c - 1120B b )x  - 1680A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                4 14         4           3  12            3          2 2  10
+--R           15B c x   + (21A c  + 378B b c )x   + (532A b c  + 1631B b c )x
+--R         + 
+--R                   2 2          3   8           3           4  6          4 4
+--R           (2345A b c  + 2380B b c)x  + (3500A b c + 1120B b )x  + 1680A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                        +--------+
+--R            3 6          2 4        2   2        3  +-+ |   2              3 6
+--R       (105c x  + 2520b c x  + 8400b c x  + 6720b )\|b \|c x  + b  - 735b c x
+--R     + 
+--R              2 2 4         3   2        4
+--R       - 5880b c x  - 11760b c x  - 6720b
+--R                                         Type: Union(Expression(Integer),...)
+--E 803
+
+--S 804 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      6 12           6           5  10
+--R               - 15B c x   + (- 21A c  - 363B b c )x
+--R             + 
+--R                          5          2 4  8             2 4          3 3  6
+--R               (- 511A b c  - 1268B b c )x  + (- 1834A b c  - 1112B b c )x
+--R             + 
+--R                         3 3        4 2  4          4 2         5   2         5
+--R               (- 1568A b c  - 64B b c )x  + (672A b c  - 384B b c)x  + 896A b c
+--R             + 
+--R                       6
+--R               - 512B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   6 12            6         2 5  10
+--R           105B b c x   + (147A b c  + 861B b c )x
+--R         + 
+--R                   2 5          3 4  8           3 4          4 3  6
+--R           (1225A b c  + 1820B b c )x  + (2646A b c  + 1128B b c )x
+--R         + 
+--R                   4 3         5 2  4             5 2         6   2         6
+--R           (1344A b c  + 192B b c )x  + (- 1120A b c  + 640B b c)x  - 896A b c
+--R         + 
+--R                 7
+--R           512B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                     6 13              6         2 5  11
+--R           - 105B b c x   + (- 147A b c  - 861B b c )x
+--R         + 
+--R                     2 5          3 4  9             3 4          4 3  7
+--R           (- 1225A b c  - 1820B b c )x  + (- 2660A b c  - 1120B b c )x
+--R         + 
+--R                    4 3 5
+--R           - 1680A b c x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 15         7           6  13            6          2 5  11
+--R           15B c x   + (21A c  + 378B b c )x   + (532A b c  + 1631B b c )x
+--R         + 
+--R                   2 5          3 4  9           3 4          4 3  7
+--R           (2345A b c  + 2380B b c )x  + (3500A b c  + 1120B b c )x
+--R         + 
+--R                  4 3 5
+--R           1680A b c x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                           +--------+
+--R            6 7          5 5        2 4 3        3 3   +-+ |   2
+--R       (105c x  + 2520b c x  + 8400b c x  + 6720b c x)\|b \|c x  + b
+--R     + 
+--R               6 7        2 5 5         3 4 3        4 3
+--R       - 735b c x  - 5880b c x  - 11760b c x  - 6720b c x
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      7 19           7           6  17
+--R               - 14B c x   + (- 14A c  - 462B b c )x
+--R             + 
+--R                          6          2 5  15             2 5           3 4  13
+--R               (- 462A b c  - 4480B b c )x   + (- 4480A b c  - 19392B b c )x
+--R             + 
+--R                          3 4           4 3  11
+--R               (- 19392A b c  - 43520B b c )x
+--R             + 
+--R                          4 3           5 2  9              5 2           6   7
+--R               (- 43520A b c  - 52736B b c )x  + (- 52736A b c  - 32768B b c)x
+--R             + 
+--R                          6           7  5          7 3
+--R               (- 32768A b c - 8192B b )x  - 8192A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              8 21       8          7  19           7          2 6  17
+--R           B c x   + (A c  + 99B b c )x   + (99A b c  + 1666B b c )x
+--R         + 
+--R                   2 6           3 5  15            3 5           4 4  13
+--R           (1666A b c  + 10976B b c )x   + (10976A b c  + 36288B b c )x
+--R         + 
+--R                    4 4           5 3  11            5 3           6 2  9
+--R           (36288A b c  + 66304B b c )x   + (66304A b c  + 68096B b c )x
+--R         + 
+--R                  6 2           7   7            7           8  5          8 3
+--R         (68096A b c  + 36864B b c)x  + (36864A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                8 22         8          7  20             7          2 6  18
+--R           - B c x   + (- A c  - 99B b c )x   + (- 99A b c  - 1666B b c )x
+--R         + 
+--R                     2 6           3 5  16              3 5           4 4  14
+--R           (- 1666A b c  - 10976B b c )x   + (- 10976A b c  - 36288B b c )x
+--R         + 
+--R                      4 4           5 3  12              5 3           6 2  10
+--R           (- 36288A b c  - 66304B b c )x   + (- 66304A b c  - 68096B b c )x
+--R         + 
+--R                      6 2           7   8              7           8  6
+--R           (- 68096A b c  - 36864B b c)x  + (- 36864A b c - 8192B b )x
+--R         + 
+--R                    8 4
+--R           - 8192A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                8 22         8           7  20            7          2 6  18
+--R           14B c x   + (14A c  + 476B b c )x   + (476A b c  + 4942B b c )x
+--R         + 
+--R                   2 6           3 5  16            3 5           4 4  14
+--R           (4942A b c  + 23872B b c )x   + (23872A b c  + 62912B b c )x
+--R         + 
+--R                    4 4           5 3  12            5 3           6 2  10
+--R           (62912A b c  + 96256B b c )x   + (96256A b c  + 85504B b c )x
+--R         + 
+--R                  6 2           7   8            7           8  6          8 4
+--R         (85504A b c  + 40960B b c)x  + (40960A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              7 14        6 12        2 5 10        3 4 8         4 3 6
+--R             c x   + 98b c x   + 1568b c x   + 9408b c x  + 26880b c x
+--R           + 
+--R                   5 2 4         6   2        7
+--R             39424b c x  + 28672b c x  + 8192b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  7 14         6 12        2 5 10         3 4 8         4 3 6
+--R             - 14c x   - 462b c x   - 4480b c x   - 19392b c x  - 43520b c x
+--R           + 
+--R                     5 2 4         6   2        7
+--R             - 52736b c x  - 32768b c x  - 8192b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 805
+
+)clear all
+
+--S 806 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R   (1)  (B x  + A)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 3139
+r0:=-1/15*(2*b*B-5*A*c)*(b*x^2+c*x^4)^(3/2)/(c^2*x^3)+_
+   1/5*B*(b*x^2+c*x^4)^(3/2)/(c*x)
+--R 
+--R
+--R                                                       +-----------+
+--R             2 4        2          2                2  |   4      2
+--R        (3B c x  + (5A c  + B b c)x  + 5A b c - 2B b )\|c x  + b x
+--R   (2)  ------------------------------------------------------------
+--R                                       2
+--R                                    15c x
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    2 8             2        2   6            2         3  4
+--R           - 15B b c x  + (- 25A b c  - 65B b c)x  + (- 120A b c - 60B b )x
+--R         + 
+--R                   3 2
+--R           - 120A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               3 10        3          2  8           2        2   6
+--R           3B c x   + (5A c  + 40B b c )x  + (70A b c  + 95B b c)x
+--R         + 
+--R                  2         3  4         3 2
+--R           (180A b c + 60B b )x  + 120A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                      +--------+
+--R         2 4           2       2  +-+ |   2             2 4       2   2       3
+--R     (15c x  + 180b c x  + 240b )\|b \|c x  + b  - 75b c x  - 300b c x  - 240b
+--R                                         Type: Union(Expression(Integer),...)
+--E 808
+
+--S 809 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     4 8          4          3  6             3        2 2  4
+--R               - 3B c x  + (- 5A c  - 37B b c )x  + (- 65A b c  - 58B b c )x
+--R             + 
+--R                        2 2       3   2        3         4
+--R               (- 140A b c  + 8B b c)x  - 80A b c + 32B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  4 8           4        2 3  6          2 3        3 2  4
+--R           15B b c x  + (25A b c  + 65B b c )x  + (125A b c  + 58B b c )x
+--R         + 
+--R                  3 2        4   2        4         5
+--R           (180A b c  - 24B b c)x  + 80A b c - 32B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    4 9             4        2 3  7            2 3        3 2  5
+--R           - 15B b c x  + (- 25A b c  - 65B b c )x  + (- 120A b c  - 60B b c )x
+--R         + 
+--R                   3 2 3
+--R           - 120A b c x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               5 11        5          4  9           4        2 3  7
+--R           3B c x   + (5A c  + 40B b c )x  + (70A b c  + 95B b c )x
+--R         + 
+--R                  2 3        3 2  5         3 2 3
+--R           (180A b c  + 60B b c )x  + 120A b c x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                           +--------+
+--R           4 5         3 3       2 2   +-+ |   2             4 5       2 3 3
+--R       (15c x  + 180b c x  + 240b c x)\|b \|c x  + b  - 75b c x  - 300b c x
+--R     + 
+--R             3 2
+--R       - 240b c x
+--R                                                    Type: Expression(Integer)
+--E 809
+
+--S 810 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      5 13           5           4  11
+--R               - 10B c x   + (- 10A c  - 170B b c )x
+--R             + 
+--R                          4         2 3  9            2 3          3 2  7
+--R               (- 170A b c  - 832B b c )x  + (- 832A b c  - 1696B b c )x
+--R             + 
+--R                       3 2          4   5             4          5  3         5
+--R             (- 1696A b c  - 1536B b c)x  + (- 1536A b c - 512B b )x  - 512A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              6 15       6          5  13           5         2 4  11
+--R           B c x   + (A c  + 51B b c )x   + (51A b c  + 450B b c )x
+--R         + 
+--R                  2 4          3 3  9           3 3          4 2  7
+--R           (450A b c  + 1520B b c )x  + (1520A b c  + 2400B b c )x
+--R         + 
+--R                   4 2          5   5           5          6  3         6
+--R           (2400A b c  + 1792B b c)x  + (1792A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                6 16         6          5  14             5         2 4  12
+--R           - B c x   + (- A c  - 51B b c )x   + (- 51A b c  - 450B b c )x
+--R         + 
+--R                    2 4          3 3  10             3 3          4 2  8
+--R           (- 450A b c  - 1520B b c )x   + (- 1520A b c  - 2400B b c )x
+--R         + 
+--R                     4 2          5   6             5          6  4         6 2
+--R           (- 2400A b c  - 1792B b c)x  + (- 1792A b c - 512B b )x  - 512A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                6 16         6           5  14            5          2 4  12
+--R           10B c x   + (10A c  + 180B b c )x   + (180A b c  + 1002B b c )x
+--R         + 
+--R                   2 4          3 3  10           3 3          4 2  8
+--R           (1002A b c  + 2528B b c )x   + (2528A b c  + 3232B b c )x
+--R         + 
+--R                   4 2          5   6           5          6  4         6 2
+--R           (3232A b c  + 2048B b c)x  + (2048A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R             5 10        4 8       2 3 6        3 2 4        4   2       5
+--R           (c x   + 50b c x  + 400b c x  + 1120b c x  + 1280b c x  + 512b )
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R             5 10         4 8       2 3 6        3 2 4        4   2       5  +-+
+--R       (- 10c x   - 170b c x  - 832b c x  - 1696b c x  - 1536b c x  - 512b )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 810
+
+)clear all
+
+--S 811 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    2
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 3139
+r0:=1/3*B*(b*x^2+c*x^4)^(3/2)/(c*x^3)-A*atanh(x*sqrt(b)/_
+   sqrt(b*x^2+c*x^4))*sqrt(b)+A*sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R   (2)
+--R                            +-+                              +-----------+
+--R            +-+           x\|b               2               |   4      2
+--R   - 3A c x\|b atanh(--------------) + (B c x  + 3A c + B b)\|c x  + b x
+--R                      +-----------+
+--R                      |   4      2
+--R                     \|c x  + b x
+--R   -----------------------------------------------------------------------
+--R                                     3c x
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                               +--------+
+--R                   2        2  |   2                   2        2  +-+
+--R         ((3A b c x  + 12A b )\|c x  + b  + (- 9A b c x  - 12A b )\|b )
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                            +--------+
+--R                  4                   2  2  |   2
+--R       (- 3B b c x  + (- 6A b c - 6B b )x )\|c x  + b
+--R     + 
+--R           2 6        2           4                 2  2  +-+
+--R       (B c x  + (3A c  + 6B b c)x  + (6A b c + 6B b )x )\|b
+--R  /
+--R                       +--------+
+--R          2        +-+ |   2              2      2
+--R     (3c x  + 12b)\|b \|c x  + b  - 9b c x  - 12b
+--R                                         Type: Union(Expression(Integer),...)
+--E 813
+
+--S 814 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  +--------+
+--R                 2 3        2     |   2                 2 3        2     +-+
+--R         ((3A b c x  + 12A b c x)\|c x  + b  + (- 9A b c x  - 12A b c x)\|b )
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                  +--------+
+--R                 2 3        2     |   2                 2 3        2     +-+
+--R         ((3A b c x  + 12A b c x)\|c x  + b  + (- 9A b c x  - 12A b c x)\|b )
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                                                   +--------+
+--R                 2 4          2           2                 2  +-+ |   2
+--R           (- B c x  + (- 3A c  - 5B b c)x  - 12A b c - 4B b )\|b \|c x  + b
+--R         + 
+--R                 2 4          2       2   2        2        3
+--R           3B b c x  + (9A b c  + 7B b c)x  + 12A b c + 4B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                              +--------+
+--R                2 5            2       2   3  |   2
+--R       (- 3B b c x  + (- 6A b c  - 6B b c)x )\|c x  + b
+--R     + 
+--R           3 7        3         2  5          2       2   3  +-+
+--R       (B c x  + (3A c  + 6B b c )x  + (6A b c  + 6B b c)x )\|b
+--R  /
+--R                           +--------+
+--R        2 3            +-+ |   2            2 3      2
+--R     (3c x  + 12b c x)\|b \|c x  + b  - 9b c x  - 12b c x
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    4 10         4          3  8             3         2 2  6
+--R               - B c x   + (- A c  - 25B b c )x  + (- 25A b c  - 104B b c )x
+--R             + 
+--R                        2 2         3   4            3         4  2        4
+--R               (- 104A b c  - 144B b c)x  + (- 144A b c - 64B b )x  - 64A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                   4 10        4          3  8           3         2 2  6
+--R               7B c x   + (7A c  + 63B b c )x  + (63A b c  + 168B b c )x
+--R             + 
+--R                      2 2         3   4          3         4  2        4
+--R               (168A b c  + 176B b c)x  + (176A b c + 64B b )x  + 64A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 4 11          4          3  9             3         2 2  7
+--R           - 7B c x   + (- 7A c  - 63B b c )x  + (- 63A b c  - 168B b c )x
+--R         + 
+--R                    2 2         3   5            3         4  3        4
+--R           (- 168A b c  - 176B b c)x  + (- 176A b c - 64B b )x  - 64A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          5 13       5          4  11           4         2 3  9
+--R       B c x   + (A c  + 26B b c )x   + (26A b c  + 129B b c )x
+--R     + 
+--R              2 3         3 2  7          3 2         4   5
+--R       (129A b c  + 248B b c )x  + (248A b c  + 208B b c)x
+--R     + 
+--R              4         5  3        5
+--R       (208A b c + 64B b )x  + 64A b x
+--R  /
+--R                                                    +--------+
+--R            3 7        2 5       2   3      3   +-+ |   2         4 9        3 7
+--R         (7c x  + 56b c x  + 112b c x  + 64b x)\|b \|c x  + b  - c x  - 25b c x
+--R       + 
+--R               2 2 5       3   3      4
+--R         - 104b c x  - 144b c x  - 64b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 815
+
+)clear all
+
+--S 816 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^4
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    4
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 3139
+r0:=-1/2*A*(b*x^2+c*x^4)^(3/2)/(b*x^5)-1/2*(2*b*B+A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/sqrt(b)+1/2*(2*b*B+A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*x)
+--R 
+--R
+--R                                     +-+                        +-----------+
+--R                       3           x\|b              2      +-+ |   4      2
+--R        (- A c - 2B b)x atanh(--------------) + (2B x  - A)\|b \|c x  + b x
+--R                               +-----------+
+--R                               |   4      2
+--R                              \|c x  + b x
+--R   (2)  ---------------------------------------------------------------------
+--R                                         3 +-+
+--R                                       2x \|b
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                    +--------+
+--R                2           4                 2  2  |   2
+--R           ((A c  + 2B b c)x  + (4A b c + 8B b )x )\|c x  + b
+--R         + 
+--R                   2           4                   2  2  +-+
+--R           ((- 3A c  - 6B b c)x  + (- 4A b c - 8B b )x )\|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                         +--------+
+--R                  4           2       2  |   2
+--R       (- 4B b c x  + 3A b c x  + 4A b )\|c x  + b
+--R     + 
+--R            2 6         2           4           2       2  +-+
+--R       (2B c x  + (- A c  + 4B b c)x  - 5A b c x  - 4A b )\|b
+--R  /
+--R                         +--------+
+--R          4       2  +-+ |   2              4     2 2
+--R     (2c x  + 8b x )\|b \|c x  + b  - 6b c x  - 8b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 818
+
+--S 819 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                        +--------+
+--R                2           5                 2  3  +-+ |   2
+--R           ((A c  + 2B b c)x  + (4A b c + 8B b )x )\|b \|c x  + b
+--R         + 
+--R                    2       2   5          2        3  3
+--R           (- 3A b c  - 6B b c)x  + (- 4A b c - 8B b )x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                                        +--------+
+--R                2           5                 2  3  +-+ |   2
+--R           ((A c  + 2B b c)x  + (4A b c + 8B b )x )\|b \|c x  + b
+--R         + 
+--R                    2       2   5          2        3  3
+--R           (- 3A b c  - 6B b c)x  + (- 4A b c - 8B b )x
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                                     +--------+
+--R                      4                2  2       2  |   2
+--R           (- 2B b c x  + (A b c - 8B b )x  + 4A b )\|c x  + b
+--R         + 
+--R                    4                   2  2       2  +-+
+--R           (6B b c x  + (- 3A b c + 8B b )x  - 4A b )\|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                              +--------+
+--R                  5           3       2   +-+ |   2              2 7
+--R       (- 4B b c x  + 3A b c x  + 4A b x)\|b \|c x  + b  + 2B b c x
+--R     + 
+--R               2       2   5       2   3       3
+--R       (- A b c  + 4B b c)x  - 5A b c x  - 4A b x
+--R  /
+--R                       +--------+
+--R            5     2 3  |   2                 5     2 3  +-+
+--R     (2b c x  + 8b x )\|c x  + b  + (- 6b c x  - 8b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    4 10         4          3  8             3         2 2  6
+--R               - B c x   + (- A c  - 25B b c )x  + (- 25A b c  - 104B b c )x
+--R             + 
+--R                        2 2         3   4            3         4  2        4
+--R               (- 104A b c  - 144B b c)x  + (- 144A b c - 64B b )x  - 64A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                   4 10        4          3  8           3         2 2  6
+--R               7B c x   + (7A c  + 63B b c )x  + (63A b c  + 168B b c )x
+--R             + 
+--R                      2 2         3   4          3         4  2        4
+--R               (168A b c  + 176B b c)x  + (176A b c + 64B b )x  + 64A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 4 11          4          3  9             3         2 2  7
+--R           - 7B c x   + (- 7A c  - 63B b c )x  + (- 63A b c  - 168B b c )x
+--R         + 
+--R                    2 2         3   5            3         4  3        4
+--R           (- 168A b c  - 176B b c)x  + (- 176A b c - 64B b )x  - 64A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          5 13       5          4  11           4         2 3  9
+--R       B c x   + (A c  + 26B b c )x   + (26A b c  + 129B b c )x
+--R     + 
+--R              2 3         3 2  7          3 2         4   5
+--R       (129A b c  + 248B b c )x  + (248A b c  + 208B b c)x
+--R     + 
+--R              4         5  3        5
+--R       (208A b c + 64B b )x  + 64A b x
+--R  /
+--R                                                     +--------+
+--R            3 9        2 7       2   5      3 3  +-+ |   2         4 11
+--R         (7c x  + 56b c x  + 112b c x  + 64b x )\|b \|c x  + b  - c x
+--R       + 
+--R                3 9       2 2 7       3   5      4 3
+--R         - 25b c x  - 104b c x  - 144b c x  - 64b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 820
+
+)clear all
+
+--S 821 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^6
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    6
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 3139
+r0:=-1/4*A*(b*x^2+c*x^4)^(3/2)/(b*x^7)-1/8*c*(4*b*B-A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-1/8*(4*b*B-A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R   (2)
+--R                                     +-+
+--R           2           5           x\|b
+--R       (A c  - 4B b c)x atanh(--------------)
+--R                               +-----------+
+--R                               |   4      2
+--R                              \|c x  + b x
+--R     + 
+--R                                     +-----------+
+--R                       2         +-+ |   4      2
+--R       ((- A c - 4B b)x  - 2A b)\|b \|c x  + b x
+--R  /
+--R         5 +-+
+--R     8b x \|b
+--R                                                    Type: Expression(Integer)
+--E 822
+
+--S 823 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                +--------+
+--R                     3        2 2  6          2 2        3   4  |   2
+--R           ((- 4A b c  + 16B b c )x  + (- 8A b c  + 32B b c)x )\|c x  + b
+--R         + 
+--R                     4         3  8          3        2 2  6
+--R                 (A c  - 4B b c )x  + (8A b c  - 32B b c )x
+--R               + 
+--R                      2 2        3   4
+--R                 (8A b c  - 32B b c)x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                 3       2 2  6         2 2        3   4         3         4  2
+--R           (A b c  + 4B b c )x  + (10A b c  + 32B b c)x  + (24A b c + 32B b )x
+--R         + 
+--R                4
+--R           16A b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                    3        2 2  6           2 2        3   4
+--R           (- 4A b c  - 16B b c )x  + (- 20A b c  - 48B b c)x
+--R         + 
+--R                   3         4  2        4
+--R           (- 32A b c - 32B b )x  - 16A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                             +--------+
+--R         2   6      3 4  +-+ |   2          2 2 8      3   6      4 4
+--R     (32b c x  + 64b x )\|b \|c x  + b  - 8b c x  - 64b c x  - 64b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 823
+
+--S 824 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                  +--------+
+--R                   3          2  7            2        2   5  +-+ |   2
+--R           ((- 4A c  + 16B b c )x  + (- 8A b c  + 32B b c)x )\|b \|c x  + b
+--R         + 
+--R               4         3  9          3        2 2  7        2 2        3   5
+--R           (A c  - 4B b c )x  + (8A b c  - 32B b c )x  + (8A b c  - 32B b c)x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                                                  +--------+
+--R                   3          2  7            2        2   5  +-+ |   2
+--R           ((- 4A c  + 16B b c )x  + (- 8A b c  + 32B b c)x )\|b \|c x  + b
+--R         + 
+--R               4         3  9          3        2 2  7        2 2        3   5
+--R           (A c  - 4B b c )x  + (8A b c  - 32B b c )x  + (8A b c  - 32B b c)x
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                                                   +--------+
+--R                   2        2   4         2         3  2        3  |   2
+--R           ((4A b c  + 16B b c)x  + (16A b c + 32B b )x  + 16A b )\|c x  + b
+--R         + 
+--R                     3         2  6             2        2   4
+--R               (- A c  - 4B b c )x  + (- 10A b c  - 32B b c)x
+--R             + 
+--R                       2         3  2        3
+--R               (- 24A b c - 32B b )x  - 16A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R               3         2  7           2        2   5         2         3  3
+--R           (A c  + 4B b c )x  + (10A b c  + 32B b c)x  + (24A b c + 32B b )x
+--R         + 
+--R                3
+--R           16A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                3        2 2  7           2 2        3   5
+--R       (- 4A b c  - 16B b c )x  + (- 20A b c  - 48B b c)x
+--R     + 
+--R               3         4  3        4
+--R       (- 32A b c - 32B b )x  - 16A b x
+--R  /
+--R                         +--------+
+--R         2   7      3 5  |   2               2 9      2   7      3 5  +-+
+--R     (32b c x  + 64b x )\|c x  + b  + (- 8b c x  - 64b c x  - 64b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 824
+
+--S 825 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    5 12         5          4  10             4         2 3  8
+--R               - B c x   + (- A c  - 41B b c )x   + (- 41A b c  - 280B b c )x
+--R             + 
+--R                        2 3         3 2  6            3 2         4   4
+--R               (- 280A b c  - 688B b c )x  + (- 688A b c  - 704B b c)x
+--R             + 
+--R                        4          5  2         5
+--R               (- 704A b c - 256B b )x  - 256A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                   5 12        5           4  10            4         2 3  8
+--R               9B c x   + (9A c  + 129B b c )x   + (129A b c  + 552B b c )x
+--R             + 
+--R                      2 3          3 2  6           3 2         4   4
+--R               (552A b c  + 1008B b c )x  + (1008A b c  + 832B b c)x
+--R             + 
+--R                      4          5  2         5
+--R               (832A b c + 256B b )x  + 256A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 5 13          5           4  11              4         2 3  9
+--R           - 9B c x   + (- 9A c  - 129B b c )x   + (- 129A b c  - 552B b c )x
+--R         + 
+--R                    2 3          3 2  7             3 2         4   5
+--R           (- 552A b c  - 1008B b c )x  + (- 1008A b c  - 832B b c)x
+--R         + 
+--R                    4          5  3         5
+--R           (- 832A b c - 256B b )x  - 256A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          6 15       6          5  13           5         2 4  11
+--R       B c x   + (A c  + 42B b c )x   + (42A b c  + 321B b c )x
+--R     + 
+--R              2 4         3 3  9          3 3          4 2  7
+--R       (321A b c  + 968B b c )x  + (968A b c  + 1392B b c )x
+--R     + 
+--R               4 2         5   5          5          6  3         6
+--R       (1392A b c  + 960B b c)x  + (960A b c + 256B b )x  + 256A b x
+--R  /
+--R                                                                     +--------+
+--R            4 13         3 11       2 2 9       3   7       4 5  +-+ |   2
+--R         (9c x   + 120b c x   + 432b c x  + 576b c x  + 256b x )\|b \|c x  + b
+--R       + 
+--R            5 15        4 13       2 3 11       3 2 9       4   7       5 5
+--R         - c x   - 41b c x   - 280b c x   - 688b c x  - 704b c x  - 256b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 825
+
+)clear all
+
+--S 826 of 3139
+t0:=x^5*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                           +-----------+
+--R              11               9        7  |   4      2
+--R   (1)  (B c x   + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 3139
+r0:=-1/168*(9*b*B-14*A*c)*x^6*(b*x^2+c*x^4)^(3/2)/c+_
+   1/14*B*x^4*(b*x^2+c*x^4)^(5/2)/c-1/2048*b^6*(9*b*B-14*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(11/2)+1/2048*b^5*(9*b*B-_
+   14*A*c)*sqrt(b*x^2+c*x^4)/c^5-1/3072*b^4*(9*b*B-14*A*c)*x^2*_
+   sqrt(b*x^2+c*x^4)/c^4+1/3840*b^3*(9*b*B-14*A*c)*x^4*sqrt(b*x^2+_
+   c*x^4)/c^3-1/4480*b^2*(9*b*B-14*A*c)*x^6*sqrt(b*x^2+c*x^4)/c^2-_
+   1/560*b*(9*b*B-14*A*c)*x^8*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                       2 +-+
+--R               6          7           x \|c
+--R       (1470A b c - 945B b )atanh(--------------)
+--R                                   +-----------+
+--R                                   |   4      2
+--R                                  \|c x  + b x
+--R     + 
+--R                   6 12            6             5  10
+--R           15360B c x   + (17920A c  + 19200B b c )x
+--R         + 
+--R                      5         2 4  8          2 4         3 3  6
+--R           (23296A b c  + 384B b c )x  + (672A b c  - 432B b c )x
+--R         + 
+--R                    3 3         4 2  4          4 2         5   2          5
+--R           (- 784A b c  + 504B b c )x  + (980A b c  - 630B b c)x  - 1470A b c
+--R         + 
+--R                 6
+--R           945B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R            5 +-+
+--R     215040c \|c
+--R                                                    Type: Expression(Integer)
+--E 827
+
+--S 828 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          6 7           7 6  12
+--R                 (20580A b c  - 13230B b c )x
+--R               + 
+--R                           7 6            8 5  10
+--R                 (658560A b c  - 423360B b c )x
+--R               + 
+--R                            8 5             9 4  8
+--R                 (5927040A b c  - 3810240B b c )x
+--R               + 
+--R                             9 4              10 3  6
+--R                 (22579200A b c  - 14515200B b  c )x
+--R               + 
+--R                             10 3              11 2  4
+--R                 (41395200A b  c  - 26611200B b  c )x
+--R               + 
+--R                             11 2              12   2              12
+--R                 (36126720A b  c  - 23224320B b  c)x  + 12042240A b  c
+--R               + 
+--R                             13
+--R                 - 7741440B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                       6 8         7 7  14               7 7           8 6  12
+--R             (- 1470A b c  + 945B b c )x   + (- 144060A b c  + 92610B b c )x
+--R           + 
+--R                          8 6             9 5  10
+--R             (- 2304960A b c  + 1481760B b c )x
+--R           + 
+--R                           9 5             10 4  8
+--R             (- 13829760A b c  + 8890560B b  c )x
+--R           + 
+--R                           10 4              11 3  6
+--R             (- 39513600A b  c  + 25401600B b  c )x
+--R           + 
+--R                           11 3              12 2  4
+--R             (- 57953280A b  c  + 37255680B b  c )x
+--R           + 
+--R                           12 2              13   2              13
+--R             (- 42147840A b  c  + 27095040B b  c)x  - 12042240A b  c
+--R           + 
+--R                       14
+--R             7741440B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                       13 27              13               12  25
+--R             - 15360B c  x   + (- 17920A c   - 1524480B b c  )x
+--R           + 
+--R                            12              2 11  23
+--R             (- 1779456A b c   - 25966464B b c  )x
+--R           + 
+--R                           2 11               3 10  21
+--R             (- 30382240A b c   - 174649680B b c  )x
+--R           + 
+--R                            3 10               4 9  19
+--R             (- 205184560A b c   - 594070680B b c )x
+--R           + 
+--R                            4 9                5 8  17
+--R             (- 701836212A b c  - 1124632698B b c )x
+--R           + 
+--R                             5 8                6 7  15
+--R             (- 1337861994A b c  - 1204329861B b c )x
+--R           + 
+--R                             6 7               7 6  13
+--R             (- 1444303812A b c  - 683704578B b c )x
+--R           + 
+--R                            7 6               8 5  11
+--R             (- 827077440A b c  - 160367520B b c )x
+--R           + 
+--R                            8 5             9 4  9
+--R             (- 191712640A b c  - 2585280B b c )x
+--R           + 
+--R                         9 4              10 3  7
+--R             (17851904A b c  - 11476224B b  c )x
+--R           + 
+--R                         10 3              11 2  5
+--R             (36277248A b  c  - 23321088B b  c )x
+--R           + 
+--R                         11 2              12   3
+--R             (34119680A b  c  - 21934080B b  c)x
+--R           + 
+--R                         12              13
+--R             (12042240A b  c - 7741440B b  )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                      13 27             13               12  25
+--R             215040B c  x   + (250880A c   + 7365120B b c  )x
+--R           + 
+--R                          12              2 11  23
+--R             (8605184A b c   + 77688576B b c  )x
+--R           + 
+--R                         2 11               3 10  21
+--R             (91053760A b c   + 384048480B b c  )x
+--R           + 
+--R                          3 10                4 9  19
+--R             (452170208A b c   + 1042321392B b c )x
+--R           + 
+--R                           4 9                5 8  17
+--R             (1234296504A b c  + 1651344156B b c )x
+--R           + 
+--R                           5 8                6 7  15
+--R             (1968822324A b c  + 1526162106B b c )x
+--R           + 
+--R                           6 7               7 6  13
+--R             (1833493788A b c  + 763812462B b c )x
+--R           + 
+--R                          7 6               8 5  11
+--R             (923901440A b c  + 161038080B b c )x
+--R           + 
+--R                          8 5             9 4  9
+--R             (185659264A b c  + 6476736B b c )x
+--R           + 
+--R                           9 4              10 3  7
+--R             (- 32478208A b c  + 20878848B b  c )x
+--R           + 
+--R                           10 3              11 2  5
+--R             (- 51831808A b  c  + 33320448B b  c )x
+--R           + 
+--R                           11 2              12   3
+--R             (- 40140800A b  c  + 25804800B b  c)x
+--R           + 
+--R                           12              13
+--R             (- 12042240A b  c + 7741440B b  )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                     11 12              10 10             2 9 8
+--R             3010560c  x   + 96337920b c  x   + 867041280b c x
+--R           + 
+--R                        3 8 6              4 7 4              5 6 2
+--R             3303014400b c x  + 6055526400b c x  + 5284823040b c x
+--R           + 
+--R                        6 5
+--R             1761607680b c
+--R        *
+--R                    +--------+
+--R            +-+ +-+ |   2
+--R           \|b \|c \|c x  + b
+--R       + 
+--R                      12 14              11 12             2 10 10
+--R             - 215040c  x   - 21073920b c  x   - 337182720b c  x
+--R           + 
+--R                          3 9 8              4 8 6              5 7 4
+--R             - 2023096320b c x  - 5780275200b c x  - 8477736960b c x
+--R           + 
+--R                          6 6 2              7 5
+--R             - 6165626880b c x  - 1761607680b c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                          6 7           7 6  12
+--R                 (41160A b c  - 26460B b c )x
+--R               + 
+--R                            7 6            8 5  10
+--R                 (1317120A b c  - 846720B b c )x
+--R               + 
+--R                             8 5             9 4  8
+--R                 (11854080A b c  - 7620480B b c )x
+--R               + 
+--R                             9 4              10 3  6
+--R                 (45158400A b c  - 29030400B b  c )x
+--R               + 
+--R                             10 3              11 2  4
+--R                 (82790400A b  c  - 53222400B b  c )x
+--R               + 
+--R                             11 2              12   2              12
+--R                 (72253440A b  c  - 46448640B b  c)x  + 24084480A b  c
+--R               + 
+--R                              13
+--R                 - 15482880B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                       6 8          7 7  14               7 7            8 6  12
+--R             (- 2940A b c  + 1890B b c )x   + (- 288120A b c  + 185220B b c )x
+--R           + 
+--R                          8 6             9 5  10
+--R             (- 4609920A b c  + 2963520B b c )x
+--R           + 
+--R                           9 5              10 4  8
+--R             (- 27659520A b c  + 17781120B b  c )x
+--R           + 
+--R                           10 4              11 3  6
+--R             (- 79027200A b  c  + 50803200B b  c )x
+--R           + 
+--R                            11 3              12 2  4
+--R             (- 115906560A b  c  + 74511360B b  c )x
+--R           + 
+--R                           12 2              13   2              13
+--R             (- 84295680A b  c  + 54190080B b  c)x  - 24084480A b  c
+--R           + 
+--R                        14
+--R             15482880B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                       13 27              13               12  25
+--R             - 15360B c  x   + (- 17920A c   - 1524480B b c  )x
+--R           + 
+--R                            12              2 11  23
+--R             (- 1779456A b c   - 25966464B b c  )x
+--R           + 
+--R                           2 11               3 10  21
+--R             (- 30382240A b c   - 174649680B b c  )x
+--R           + 
+--R                            3 10               4 9  19
+--R             (- 205184560A b c   - 594070680B b c )x
+--R           + 
+--R                            4 9                5 8  17
+--R             (- 701836212A b c  - 1124632698B b c )x
+--R           + 
+--R                             5 8                6 7  15
+--R             (- 1337861994A b c  - 1204329861B b c )x
+--R           + 
+--R                             6 7               7 6  13
+--R             (- 1444303812A b c  - 683704578B b c )x
+--R           + 
+--R                            7 6               8 5  11
+--R             (- 827077440A b c  - 160367520B b c )x
+--R           + 
+--R                            8 5             9 4  9
+--R             (- 191712640A b c  - 2585280B b c )x
+--R           + 
+--R                         9 4              10 3  7
+--R             (17851904A b c  - 11476224B b  c )x
+--R           + 
+--R                         10 3              11 2  5
+--R             (36277248A b  c  - 23321088B b  c )x
+--R           + 
+--R                         11 2              12   3
+--R             (34119680A b  c  - 21934080B b  c)x
+--R           + 
+--R                         12              13
+--R             (12042240A b  c - 7741440B b  )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                      13 27             13               12  25
+--R             215040B c  x   + (250880A c   + 7365120B b c  )x
+--R           + 
+--R                          12              2 11  23
+--R             (8605184A b c   + 77688576B b c  )x
+--R           + 
+--R                         2 11               3 10  21
+--R             (91053760A b c   + 384048480B b c  )x
+--R           + 
+--R                          3 10                4 9  19
+--R             (452170208A b c   + 1042321392B b c )x
+--R           + 
+--R                           4 9                5 8  17
+--R             (1234296504A b c  + 1651344156B b c )x
+--R           + 
+--R                           5 8                6 7  15
+--R             (1968822324A b c  + 1526162106B b c )x
+--R           + 
+--R                           6 7               7 6  13
+--R             (1833493788A b c  + 763812462B b c )x
+--R           + 
+--R                          7 6               8 5  11
+--R             (923901440A b c  + 161038080B b c )x
+--R           + 
+--R                          8 5             9 4  9
+--R             (185659264A b c  + 6476736B b c )x
+--R           + 
+--R                           9 4              10 3  7
+--R             (- 32478208A b c  + 20878848B b  c )x
+--R           + 
+--R                           10 3              11 2  5
+--R             (- 51831808A b  c  + 33320448B b  c )x
+--R           + 
+--R                           11 2              12   3
+--R             (- 40140800A b  c  + 25804800B b  c)x
+--R           + 
+--R                           12              13
+--R             (- 12042240A b  c + 7741440B b  )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                     11 12              10 10             2 9 8
+--R             3010560c  x   + 96337920b c  x   + 867041280b c x
+--R           + 
+--R                        3 8 6              4 7 4              5 6 2
+--R             3303014400b c x  + 6055526400b c x  + 5284823040b c x
+--R           + 
+--R                        6 5
+--R             1761607680b c
+--R        *
+--R                      +--------+
+--R            +---+ +-+ |   2
+--R           \|- c \|b \|c x  + b
+--R       + 
+--R                      12 14              11 12             2 10 10
+--R             - 215040c  x   - 21073920b c  x   - 337182720b c  x
+--R           + 
+--R                          3 9 8              4 8 6              5 7 4
+--R             - 2023096320b c x  - 5780275200b c x  - 8477736960b c x
+--R           + 
+--R                          6 6 2              7 5
+--R             - 6165626880b c x  - 1761607680b c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 828
+
+--S 829 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        6 7           7 6  12             7 6            8 5  10
+--R               (20580A b c  - 13230B b c )x   + (658560A b c  - 423360B b c )x
+--R             + 
+--R                          8 5             9 4  8
+--R               (5927040A b c  - 3810240B b c )x
+--R             + 
+--R                           9 4              10 3  6
+--R               (22579200A b c  - 14515200B b  c )x
+--R             + 
+--R                           10 3              11 2  4
+--R               (41395200A b  c  - 26611200B b  c )x
+--R             + 
+--R                           11 2              12   2              12
+--R               (36126720A b  c  - 23224320B b  c)x  + 12042240A b  c
+--R             + 
+--R                           13
+--R               - 7741440B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                     6 8         7 7  14               7 7           8 6  12
+--R           (- 1470A b c  + 945B b c )x   + (- 144060A b c  + 92610B b c )x
+--R         + 
+--R                        8 6             9 5  10
+--R           (- 2304960A b c  + 1481760B b c )x
+--R         + 
+--R                         9 5             10 4  8
+--R           (- 13829760A b c  + 8890560B b  c )x
+--R         + 
+--R                         10 4              11 3  6
+--R           (- 39513600A b  c  + 25401600B b  c )x
+--R         + 
+--R                         11 3              12 2  4
+--R           (- 57953280A b  c  + 37255680B b  c )x
+--R         + 
+--R                       12 2              13   2              13              14
+--R         (- 42147840A b  c  + 27095040B b  c)x  - 12042240A b  c + 7741440B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                          6 7           7 6  12
+--R               (- 20580A b c  + 13230B b c )x
+--R             + 
+--R                           7 6            8 5  10
+--R               (- 658560A b c  + 423360B b c )x
+--R             + 
+--R                            8 5             9 4  8
+--R               (- 5927040A b c  + 3810240B b c )x
+--R             + 
+--R                             9 4              10 3  6
+--R               (- 22579200A b c  + 14515200B b  c )x
+--R             + 
+--R                             10 3              11 2  4
+--R               (- 41395200A b  c  + 26611200B b  c )x
+--R             + 
+--R                             11 2              12   2              12
+--R               (- 36126720A b  c  + 23224320B b  c)x  - 12042240A b  c
+--R             + 
+--R                         13
+--R               7741440B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   6 8         7 7  14             7 7           8 6  12
+--R           (1470A b c  - 945B b c )x   + (144060A b c  - 92610B b c )x
+--R         + 
+--R                      8 6             9 5  10
+--R           (2304960A b c  - 1481760B b c )x
+--R         + 
+--R                       9 5             10 4  8
+--R           (13829760A b c  - 8890560B b  c )x
+--R         + 
+--R                       10 4              11 3  6
+--R           (39513600A b  c  - 25401600B b  c )x
+--R         + 
+--R                       11 3              12 2  4
+--R           (57953280A b  c  - 37255680B b  c )x
+--R         + 
+--R                       12 2              13   2              13              14
+--R           (42147840A b  c  - 27095040B b  c)x  + 12042240A b  c - 7741440B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                          12 24               12               11  22
+--R               - 215040B c  x   + (- 250880A c   - 7150080B b c  )x
+--R             + 
+--R                              11              2 10  20
+--R               (- 8354304A b c   - 70538496B b c  )x
+--R             + 
+--R                             2 10               3 9  18
+--R               (- 82699456A b c   - 313509984B b c )x
+--R             + 
+--R                              3 9               4 8  16
+--R               (- 369470752A b c  - 728811408B b c )x
+--R             + 
+--R                              4 8               5 7  14
+--R               (- 864825752A b c  - 922532748B b c )x
+--R             + 
+--R                               5 7               6 6  12
+--R               (- 1103996572A b c  - 603629358B b c )x
+--R             + 
+--R                              6 6               7 5  10
+--R               (- 729497216A b c  - 160183104B b c )x
+--R             + 
+--R                              7 5            8 4  8
+--R               (- 194404224A b c  - 854976B b c )x
+--R             + 
+--R                          8 4             9 3  6
+--R               (8744960A b c  - 5621760B b c )x
+--R             + 
+--R                           9 3              10 2  4
+--R               (23733248A b c  - 15257088B b  c )x
+--R             + 
+--R                           10 2              11   2              11
+--R               (28098560A b  c  - 18063360B b  c)x  + 12042240A b  c
+--R             + 
+--R                           12
+--R               - 7741440B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                       13 26            13               12  24
+--R               15360B c  x   + (17920A c   + 1524480B b c  )x
+--R             + 
+--R                            12              2 11  22
+--R               (1779456A b c   + 25966464B b c  )x
+--R             + 
+--R                           2 11               3 10  20
+--R               (30382240A b c   + 174649680B b c  )x
+--R             + 
+--R                            3 10               4 9  18
+--R               (205184560A b c   + 594070680B b c )x
+--R             + 
+--R                            4 9                5 8  16
+--R               (701836212A b c  + 1124632698B b c )x
+--R             + 
+--R                             5 8                6 7  14
+--R               (1337861994A b c  + 1204329861B b c )x
+--R             + 
+--R                             6 7               7 6  12
+--R               (1444303812A b c  + 683704578B b c )x
+--R             + 
+--R                            7 6               8 5  10
+--R               (827077440A b c  + 160367520B b c )x
+--R             + 
+--R                            8 5             9 4  8
+--R               (191712640A b c  + 2585280B b c )x
+--R             + 
+--R                             9 4              10 3  6
+--R               (- 17851904A b c  + 11476224B b  c )x
+--R             + 
+--R                             10 3              11 2  4
+--R               (- 36277248A b  c  + 23321088B b  c )x
+--R             + 
+--R                             11 2              12   2              12
+--R               (- 34119680A b  c  + 21934080B b  c)x  - 12042240A b  c
+--R             + 
+--R                         13
+--R               7741440B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                     13 27              13               12  25
+--R           - 15360B c  x   + (- 17920A c   - 1524480B b c  )x
+--R         + 
+--R                          12              2 11  23
+--R           (- 1779456A b c   - 25966464B b c  )x
+--R         + 
+--R                         2 11               3 10  21
+--R           (- 30382240A b c   - 174649680B b c  )x
+--R         + 
+--R                          3 10               4 9  19
+--R           (- 205184560A b c   - 594070680B b c )x
+--R         + 
+--R                          4 9                5 8  17
+--R           (- 701836212A b c  - 1124632698B b c )x
+--R         + 
+--R                           5 8                6 7  15
+--R           (- 1337861994A b c  - 1204329861B b c )x
+--R         + 
+--R                           6 7               7 6  13
+--R           (- 1444303812A b c  - 683704578B b c )x
+--R         + 
+--R                          7 6               8 5  11
+--R           (- 827077440A b c  - 160367520B b c )x
+--R         + 
+--R                          8 5             9 4  9
+--R           (- 191712640A b c  - 2585280B b c )x
+--R         + 
+--R                       9 4              10 3  7
+--R           (17851904A b c  - 11476224B b  c )x
+--R         + 
+--R                       10 3              11 2  5
+--R           (36277248A b  c  - 23321088B b  c )x
+--R         + 
+--R                     11 2              12   3               12              13
+--R         (34119680A b  c  - 21934080B b  c)x  + (12042240A b  c - 7741440B b  )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                    13 27             13               12  25
+--R           215040B c  x   + (250880A c   + 7365120B b c  )x
+--R         + 
+--R                        12              2 11  23
+--R           (8605184A b c   + 77688576B b c  )x
+--R         + 
+--R                       2 11               3 10  21
+--R           (91053760A b c   + 384048480B b c  )x
+--R         + 
+--R                        3 10                4 9  19
+--R           (452170208A b c   + 1042321392B b c )x
+--R         + 
+--R                         4 9                5 8  17
+--R           (1234296504A b c  + 1651344156B b c )x
+--R         + 
+--R                         5 8                6 7  15
+--R           (1968822324A b c  + 1526162106B b c )x
+--R         + 
+--R                         6 7               7 6  13
+--R           (1833493788A b c  + 763812462B b c )x
+--R         + 
+--R                        7 6               8 5  11
+--R           (923901440A b c  + 161038080B b c )x
+--R         + 
+--R                        8 5             9 4  9
+--R           (185659264A b c  + 6476736B b c )x
+--R         + 
+--R                         9 4              10 3  7
+--R           (- 32478208A b c  + 20878848B b  c )x
+--R         + 
+--R                         10 3              11 2  5
+--R           (- 51831808A b  c  + 33320448B b  c )x
+--R         + 
+--R                         11 2              12   3
+--R           (- 40140800A b  c  + 25804800B b  c)x
+--R         + 
+--R                         12              13
+--R           (- 12042240A b  c + 7741440B b  )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                   11 12              10 10             2 9 8              3 8 6
+--R           3010560c  x   + 96337920b c  x   + 867041280b c x  + 3303014400b c x
+--R         + 
+--R                      4 7 4              5 6 2              6 5
+--R           6055526400b c x  + 5284823040b c x  + 1761607680b c
+--R      *
+--R                  +--------+
+--R          +-+ +-+ |   2
+--R         \|b \|c \|c x  + b
+--R     + 
+--R                    12 14              11 12             2 10 10
+--R           - 215040c  x   - 21073920b c  x   - 337182720b c  x
+--R         + 
+--R                        3 9 8              4 8 6              5 7 4
+--R           - 2023096320b c x  - 5780275200b c x  - 8477736960b c x
+--R         + 
+--R                        6 6 2              7 5
+--R           - 6165626880b c x  - 1761607680b c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          17 44           17            16  42
+--R                   - 31B c  x   + (- 31A c   - 5022B b c  )x
+--R                 + 
+--R                               16            2 15  40
+--R                   (- 5022A b c   - 246047B b c  )x
+--R                 + 
+--R                               2 15             3 14  38
+--R                   (- 246047A b c   - 5738720B b c  )x
+--R                 + 
+--R                                3 14              4 13  36
+--R                   (- 5738720A b c   - 77405760B b c  )x
+--R                 + 
+--R                                 4 13               5 12  34
+--R                   (- 77405760A b c   - 671726848B b c  )x
+--R                 + 
+--R                                  5 12                6 11  32
+--R                   (- 671726848A b c   - 4003918336B b c  )x
+--R                 + 
+--R                                   6 11                 7 10  30
+--R                   (- 4003918336A b c   - 17102524416B b c  )x
+--R                 + 
+--R                                    7 10                 8 9  28
+--R                   (- 17102524416A b c   - 53823856640B b c )x
+--R                 + 
+--R                                    8 9                  9 8  26
+--R                   (- 53823856640A b c  - 126991237120B b c )x
+--R                 + 
+--R                                     9 8                  10 7  24
+--R                   (- 126991237120A b c  - 226673491968B b  c )x
+--R                 + 
+--R                                     10 7                  11 6  22
+--R                   (- 226673491968A b  c  - 306562727936B b  c )x
+--R                 + 
+--R                                     11 6                  12 5  20
+--R                   (- 306562727936A b  c  - 312121229312B b  c )x
+--R                 + 
+--R                                     12 5                  13 4  18
+--R                   (- 312121229312A b  c  - 235342397440B b  c )x
+--R                 + 
+--R                                     13 4                  14 3  16
+--R                   (- 235342397440A b  c  - 127422955520B b  c )x
+--R                 + 
+--R                                     14 3                 15 2  14
+--R                   (- 127422955520A b  c  - 46841987072B b  c )x
+--R                 + 
+--R                                    15 2                 16   12
+--R                   (- 46841987072A b  c  - 10468982784B b  c)x
+--R                 + 
+--R                                  16                 17  10                17 8
+--R                 (- 10468982784A b  c - 1073741824B b  )x   - 1073741824A b  x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  18 45       18           17  43
+--R               B c  x   + (A c   + 482B b c  )x
+--R             + 
+--R                        17           2 16  41
+--R               (482A b c   + 39041B b c  )x
+--R             + 
+--R                        2 16             3 15  39
+--R               (39041A b c   + 1264736B b c  )x
+--R             + 
+--R                          3 15              4 14  37
+--R               (1264736A b c   + 21763264B b c  )x
+--R             + 
+--R                           4 14               5 13  35
+--R               (21763264A b c   + 229076224B b c  )x
+--R             + 
+--R                            5 13                6 12  33
+--R               (229076224A b c   + 1601666560B b c  )x
+--R             + 
+--R                             6 12                7 11  31
+--R               (1601666560A b c   + 7836176384B b c  )x
+--R             + 
+--R                             7 11                 8 10  29
+--R               (7836176384A b c   + 27748769792B b c  )x
+--R             + 
+--R                              8 10                 9 9  27
+--R               (27748769792A b c   + 72655863808B b c )x
+--R             + 
+--R                              9 9                  10 8  25
+--R               (72655863808A b c  + 142344519680B b  c )x
+--R             + 
+--R                               10 8                  11 7  23
+--R               (142344519680A b  c  + 209410064384B b  c )x
+--R             + 
+--R                               11 7                  12 6  21
+--R               (209410064384A b  c  + 230193889280B b  c )x
+--R             + 
+--R                               12 6                  13 5  19
+--R               (230193889280A b  c  + 186218708992B b  c )x
+--R             + 
+--R                               13 5                  14 4  17
+--R               (186218708992A b  c  + 107592286208B b  c )x
+--R             + 
+--R                               14 4                 15 3  15
+--R               (107592286208A b  c  + 42010148864B b  c )x
+--R             + 
+--R                              15 3                16 2  13
+--R               (42010148864A b  c  + 9932111872B b  c )x
+--R             + 
+--R                             16 2                17   11                17   9
+--R               (9932111872A b  c  + 1073741824B b  c)x   + 1073741824A b  c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  18 46       18           17  44
+--R               B c  x   + (A c   + 483B b c  )x
+--R             + 
+--R                        17           2 16  42
+--R               (483A b c   + 39523B b c  )x
+--R             + 
+--R                        2 16             3 15  40
+--R               (39523A b c   + 1303777B b c  )x
+--R             + 
+--R                          3 15              4 14  38
+--R               (1303777A b c   + 23028000B b c  )x
+--R             + 
+--R                           4 14               5 13  36
+--R               (23028000A b c   + 250839488B b c  )x
+--R             + 
+--R                            5 13                6 12  34
+--R               (250839488A b c   + 1830742784B b c  )x
+--R             + 
+--R                             6 12                7 11  32
+--R               (1830742784A b c   + 9437842944B b c  )x
+--R             + 
+--R                             7 11                 8 10  30
+--R               (9437842944A b c   + 35584946176B b c  )x
+--R             + 
+--R                              8 10                  9 9  28
+--R               (35584946176A b c   + 100404633600B b c )x
+--R             + 
+--R                               9 9                  10 8  26
+--R               (100404633600A b c  + 215000383488B b  c )x
+--R             + 
+--R                               10 8                  11 7  24
+--R               (215000383488A b  c  + 351754584064B b  c )x
+--R             + 
+--R                               11 7                  12 6  22
+--R               (351754584064A b  c  + 439603953664B b  c )x
+--R             + 
+--R                               12 6                  13 5  20
+--R               (439603953664A b  c  + 416412598272B b  c )x
+--R             + 
+--R                               13 5                  14 4  18
+--R               (416412598272A b  c  + 293810995200B b  c )x
+--R             + 
+--R                               14 4                  15 3  16
+--R               (293810995200A b  c  + 149602435072B b  c )x
+--R             + 
+--R                               15 3                 16 2  14
+--R               (149602435072A b  c  + 51942260736B b  c )x
+--R             + 
+--R                              16 2                 17   12
+--R               (51942260736A b  c  + 11005853696B b  c)x
+--R             + 
+--R                              17                 18  10                18 8
+--R               (11005853696A b  c + 1073741824B b  )x   + 1073741824A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      18 45           18            17  43
+--R               - 31B c  x   + (- 31A c   - 5022B b c  )x
+--R             + 
+--R                           17            2 16  41
+--R               (- 5022A b c   - 246047B b c  )x
+--R             + 
+--R                           2 16             3 15  39
+--R               (- 246047A b c   - 5738720B b c  )x
+--R             + 
+--R                            3 15              4 14  37
+--R               (- 5738720A b c   - 77405760B b c  )x
+--R             + 
+--R                             4 14               5 13  35
+--R               (- 77405760A b c   - 671726848B b c  )x
+--R             + 
+--R                              5 13                6 12  33
+--R               (- 671726848A b c   - 4003918336B b c  )x
+--R             + 
+--R                               6 12                 7 11  31
+--R               (- 4003918336A b c   - 17102524416B b c  )x
+--R             + 
+--R                                7 11                 8 10  29
+--R               (- 17102524416A b c   - 53823856640B b c  )x
+--R             + 
+--R                                8 10                  9 9  27
+--R               (- 53823856640A b c   - 126991237120B b c )x
+--R             + 
+--R                                 9 9                  10 8  25
+--R               (- 126991237120A b c  - 226673491968B b  c )x
+--R             + 
+--R                                 10 8                  11 7  23
+--R               (- 226673491968A b  c  - 306562727936B b  c )x
+--R             + 
+--R                                 11 7                  12 6  21
+--R               (- 306562727936A b  c  - 312121229312B b  c )x
+--R             + 
+--R                                 12 6                  13 5  19
+--R               (- 312121229312A b  c  - 235342397440B b  c )x
+--R             + 
+--R                                 13 5                  14 4  17
+--R               (- 235342397440A b  c  - 127422955520B b  c )x
+--R             + 
+--R                                 14 4                 15 3  15
+--R               (- 127422955520A b  c  - 46841987072B b  c )x
+--R             + 
+--R                                15 3                 16 2  13
+--R               (- 46841987072A b  c  - 10468982784B b  c )x
+--R             + 
+--R                              16 2                17   11                17   9
+--R             (- 10468982784A b  c  - 1073741824B b  c)x   - 1073741824A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    18 47         18           17  45
+--R               - B c  x   + (- A c   - 483B b c  )x
+--R             + 
+--R                          17           2 16  43
+--R               (- 483A b c   - 39523B b c  )x
+--R             + 
+--R                          2 16             3 15  41
+--R               (- 39523A b c   - 1303777B b c  )x
+--R             + 
+--R                            3 15              4 14  39
+--R               (- 1303777A b c   - 23028000B b c  )x
+--R             + 
+--R                             4 14               5 13  37
+--R               (- 23028000A b c   - 250839488B b c  )x
+--R             + 
+--R                              5 13                6 12  35
+--R               (- 250839488A b c   - 1830742784B b c  )x
+--R             + 
+--R                               6 12                7 11  33
+--R               (- 1830742784A b c   - 9437842944B b c  )x
+--R             + 
+--R                               7 11                 8 10  31
+--R               (- 9437842944A b c   - 35584946176B b c  )x
+--R             + 
+--R                                8 10                  9 9  29
+--R               (- 35584946176A b c   - 100404633600B b c )x
+--R             + 
+--R                                 9 9                  10 8  27
+--R               (- 100404633600A b c  - 215000383488B b  c )x
+--R             + 
+--R                                 10 8                  11 7  25
+--R               (- 215000383488A b  c  - 351754584064B b  c )x
+--R             + 
+--R                                 11 7                  12 6  23
+--R               (- 351754584064A b  c  - 439603953664B b  c )x
+--R             + 
+--R                                 12 6                  13 5  21
+--R               (- 439603953664A b  c  - 416412598272B b  c )x
+--R             + 
+--R                                 13 5                  14 4  19
+--R               (- 416412598272A b  c  - 293810995200B b  c )x
+--R             + 
+--R                                 14 4                  15 3  17
+--R               (- 293810995200A b  c  - 149602435072B b  c )x
+--R             + 
+--R                                 15 3                 16 2  15
+--R               (- 149602435072A b  c  - 51942260736B b  c )x
+--R             + 
+--R                                16 2                 17   13
+--R               (- 51942260736A b  c  - 11005853696B b  c)x
+--R             + 
+--R                                17                 18  11                18 9
+--R               (- 11005853696A b  c - 1073741824B b  )x   - 1073741824A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    18 46         18            17  44
+--R               31B c  x   + (31A c   + 5022B b c  )x
+--R             + 
+--R                         17            2 16  42
+--R               (5022A b c   + 246047B b c  )x
+--R             + 
+--R                         2 16             3 15  40
+--R               (246047A b c   + 5738720B b c  )x
+--R             + 
+--R                          3 15              4 14  38
+--R               (5738720A b c   + 77405760B b c  )x
+--R             + 
+--R                           4 14               5 13  36
+--R               (77405760A b c   + 671726848B b c  )x
+--R             + 
+--R                            5 13                6 12  34
+--R               (671726848A b c   + 4003918336B b c  )x
+--R             + 
+--R                             6 12                 7 11  32
+--R               (4003918336A b c   + 17102524416B b c  )x
+--R             + 
+--R                              7 11                 8 10  30
+--R               (17102524416A b c   + 53823856640B b c  )x
+--R             + 
+--R                              8 10                  9 9  28
+--R               (53823856640A b c   + 126991237120B b c )x
+--R             + 
+--R                               9 9                  10 8  26
+--R               (126991237120A b c  + 226673491968B b  c )x
+--R             + 
+--R                               10 8                  11 7  24
+--R               (226673491968A b  c  + 306562727936B b  c )x
+--R             + 
+--R                               11 7                  12 6  22
+--R               (306562727936A b  c  + 312121229312B b  c )x
+--R             + 
+--R                               12 6                  13 5  20
+--R               (312121229312A b  c  + 235342397440B b  c )x
+--R             + 
+--R                               13 5                  14 4  18
+--R               (235342397440A b  c  + 127422955520B b  c )x
+--R             + 
+--R                               14 4                 15 3  16
+--R               (127422955520A b  c  + 46841987072B b  c )x
+--R             + 
+--R                              15 3                 16 2  14
+--R               (46841987072A b  c  + 10468982784B b  c )x
+--R             + 
+--R                            16 2                17   12                17   10
+--R             (10468982784A b  c  + 1073741824B b  c)x   + 1073741824A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                18 47         18            17  45
+--R           31B c  x   + (31A c   + 5053B b c  )x
+--R         + 
+--R                     17            2 16  43
+--R           (5053A b c   + 251069B b c  )x
+--R         + 
+--R                     2 16             3 15  41
+--R           (251069A b c   + 5984767B b c  )x
+--R         + 
+--R                      3 15              4 14  39
+--R           (5984767A b c   + 83144480B b c  )x
+--R         + 
+--R                       4 14               5 13  37
+--R           (83144480A b c   + 749132608B b c  )x
+--R         + 
+--R                        5 13                6 12  35
+--R           (749132608A b c   + 4675645184B b c  )x
+--R         + 
+--R                         6 12                 7 11  33
+--R           (4675645184A b c   + 21106442752B b c  )x
+--R         + 
+--R                          7 11                 8 10  31
+--R           (21106442752A b c   + 70926381056B b c  )x
+--R         + 
+--R                          8 10                  9 9  29
+--R           (70926381056A b c   + 180815093760B b c )x
+--R         + 
+--R                           9 9                  10 8  27
+--R           (180815093760A b c  + 353664729088B b  c )x
+--R         + 
+--R                           10 8                  11 7  25
+--R           (353664729088A b  c  + 533236219904B b  c )x
+--R         + 
+--R                           11 7                  12 6  23
+--R           (533236219904A b  c  + 618683957248B b  c )x
+--R         + 
+--R                           12 6                  13 5  21
+--R           (618683957248A b  c  + 547463626752B b  c )x
+--R         + 
+--R                           13 5                  14 4  19
+--R           (547463626752A b  c  + 362765352960B b  c )x
+--R         + 
+--R                           14 4                  15 3  17
+--R           (362765352960A b  c  + 174264942592B b  c )x
+--R         + 
+--R                           15 3                 16 2  15
+--R           (174264942592A b  c  + 57310969856B b  c )x
+--R         + 
+--R                          16 2                 17   13
+--R           (57310969856A b  c  + 11542724608B b  c)x
+--R         + 
+--R                          17                 18  11                18 9
+--R           (11542724608A b  c + 1073741824B b  )x   + 1073741824A b  x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            19 48         19           18  46              18           2 17  44
+--R       - B c  x   + (- A c   - 483B b c  )x   + (- 483A b c   - 39523B b c  )x
+--R     + 
+--R                  2 17             3 16  42
+--R       (- 39523A b c   - 1303777B b c  )x
+--R     + 
+--R                    3 16              4 15  40
+--R       (- 1303777A b c   - 23028000B b c  )x
+--R     + 
+--R                     4 15               5 14  38
+--R       (- 23028000A b c   - 250839488B b c  )x
+--R     + 
+--R                      5 14                6 13  36
+--R       (- 250839488A b c   - 1830742784B b c  )x
+--R     + 
+--R                       6 13                7 12  34
+--R       (- 1830742784A b c   - 9437842944B b c  )x
+--R     + 
+--R                       7 12                 8 11  32
+--R       (- 9437842944A b c   - 35584946176B b c  )x
+--R     + 
+--R                        8 11                  9 10  30
+--R       (- 35584946176A b c   - 100404633600B b c  )x
+--R     + 
+--R                         9 10                  10 9  28
+--R       (- 100404633600A b c   - 215000383488B b  c )x
+--R     + 
+--R                         10 9                  11 8  26
+--R       (- 215000383488A b  c  - 351754584064B b  c )x
+--R     + 
+--R                         11 8                  12 7  24
+--R       (- 351754584064A b  c  - 439603953664B b  c )x
+--R     + 
+--R                         12 7                  13 6  22
+--R       (- 439603953664A b  c  - 416412598272B b  c )x
+--R     + 
+--R                         13 6                  14 5  20
+--R       (- 416412598272A b  c  - 293810995200B b  c )x
+--R     + 
+--R                         14 5                  15 4  18
+--R       (- 293810995200A b  c  - 149602435072B b  c )x
+--R     + 
+--R                         15 4                 16 3  16
+--R       (- 149602435072A b  c  - 51942260736B b  c )x
+--R     + 
+--R                        16 3                 17 2  14
+--R       (- 51942260736A b  c  - 11005853696B b  c )x
+--R     + 
+--R                        17 2                18   12                18   10
+--R       (- 11005853696A b  c  - 1073741824B b  c)x   - 1073741824A b  c x
+--R  /
+--R                  16 32         15 30         2 14 28           3 13 26
+--R                 c  x   + 481b c  x   + 38560b c  x   + 1226176b c  x
+--R               + 
+--R                          4 12 24             5 11 22              6 10 20
+--R                 20537088b c  x   + 208539136b c  x   + 1393127424b c  x
+--R               + 
+--R                            7 9 18               8 8 16               9 7 14
+--R                 6443048960b c x   + 21305720832b c x   + 51350142976b c x
+--R               + 
+--R                             10 6 12                11 5 10
+--R                 90994376704b  c x   + 118415687680b  c x
+--R               + 
+--R                              12 4 8               13 3 6               14 2 4
+--R                 111778201600b  c x  + 74440507392b  c x  + 33151778816b  c x
+--R               + 
+--R                            15   2              16
+--R                 8858370048b  c x  + 1073741824b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                      16 31          15 29          2 14 27           3 13 25
+--R                 - 31c  x   - 4960b c  x   - 236096b c  x   - 5261568b c  x
+--R               + 
+--R                            4 12 23             5 11 21              6 10 19
+--R                 - 66646528b c  x   - 533172224b c  x   - 2870927360b c  x
+--R               + 
+--R                               7 9 17               8 8 15               9 7 13
+--R                 - 10827497472b c x   - 29297934336b c x   - 57567870976b c x
+--R               + 
+--R                               10 6 11               11 5 9               12 4 7
+--R                 - 82239815680b  c x   - 84515225600b  c x  - 60850962432b  c x
+--R               + 
+--R                               13 3 5              14 2 3              15
+--R                 - 29125246976b  c x  - 8321499136b  c x  - 1073741824b  c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  16 32          15 30          2 14 28           3 13 26
+--R             - 31c  x   - 4991b c  x   - 241056b c  x   - 5497664b c  x
+--R           + 
+--R                        4 12 24             5 11 22              6 10 20
+--R             - 71908096b c  x   - 599818752b c  x   - 3404099584b c  x
+--R           + 
+--R                           7 9 18               8 8 16               9 7 14
+--R             - 13698424832b c x   - 40125431808b c x   - 86865805312b c x
+--R           + 
+--R                            10 6 12                11 5 10                12 4 8
+--R             - 139807686656b  c x   - 166755041280b  c x   - 145366188032b  c x
+--R           + 
+--R                           13 3 6               14 2 4              15   2
+--R             - 89976209408b  c x  - 37446746112b  c x  - 9395240960b  c x
+--R           + 
+--R                          16
+--R             - 1073741824b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          17 33         16 31         2 15 29           3 14 27
+--R         c  x   + 481b c  x   + 38560b c  x   + 1226176b c  x
+--R       + 
+--R                  4 13 25             5 12 23              6 11 21
+--R         20537088b c  x   + 208539136b c  x   + 1393127424b c  x
+--R       + 
+--R                    7 10 19               8 9 17               9 8 15
+--R         6443048960b c  x   + 21305720832b c x   + 51350142976b c x
+--R       + 
+--R                     10 7 13                11 6 11                12 5 9
+--R         90994376704b  c x   + 118415687680b  c x   + 111778201600b  c x
+--R       + 
+--R                     13 4 7               14 3 5              15 2 3
+--R         74440507392b  c x  + 33151778816b  c x  + 8858370048b  c x
+--R       + 
+--R                    16
+--R         1073741824b  c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 830
+
+--S 831 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          6 7           7 6  12
+--R               (- 20580A b c  + 13230B b c )x
+--R             + 
+--R                           7 6            8 5  10
+--R               (- 658560A b c  + 423360B b c )x
+--R             + 
+--R                            8 5             9 4  8
+--R               (- 5927040A b c  + 3810240B b c )x
+--R             + 
+--R                             9 4              10 3  6
+--R               (- 22579200A b c  + 14515200B b  c )x
+--R             + 
+--R                             10 3              11 2  4
+--R               (- 41395200A b  c  + 26611200B b  c )x
+--R             + 
+--R                             11 2              12   2              12
+--R               (- 36126720A b  c  + 23224320B b  c)x  - 12042240A b  c
+--R             + 
+--R                         13
+--R               7741440B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                       6 8         7 7  14             7 7           8 6  12
+--R               (1470A b c  - 945B b c )x   + (144060A b c  - 92610B b c )x
+--R             + 
+--R                          8 6             9 5  10
+--R               (2304960A b c  - 1481760B b c )x
+--R             + 
+--R                           9 5             10 4  8
+--R               (13829760A b c  - 8890560B b  c )x
+--R             + 
+--R                           10 4              11 3  6
+--R               (39513600A b  c  - 25401600B b  c )x
+--R             + 
+--R                           11 3              12 2  4
+--R               (57953280A b  c  - 37255680B b  c )x
+--R             + 
+--R                           12 2              13   2              13
+--R               (42147840A b  c  - 27095040B b  c)x  + 12042240A b  c
+--R             + 
+--R                           14
+--R               - 7741440B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                        6 7           7 6  12
+--R               (41160A b c  - 26460B b c )x
+--R             + 
+--R                          7 6            8 5  10
+--R               (1317120A b c  - 846720B b c )x
+--R             + 
+--R                           8 5             9 4  8
+--R               (11854080A b c  - 7620480B b c )x
+--R             + 
+--R                           9 4              10 3  6
+--R               (45158400A b c  - 29030400B b  c )x
+--R             + 
+--R                           10 3              11 2  4
+--R               (82790400A b  c  - 53222400B b  c )x
+--R             + 
+--R                           11 2              12   2              12
+--R               (72253440A b  c  - 46448640B b  c)x  + 24084480A b  c
+--R             + 
+--R                            13
+--R               - 15482880B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                         6 8          7 7  14
+--R               (- 2940A b c  + 1890B b c )x
+--R             + 
+--R                           7 7            8 6  12
+--R               (- 288120A b c  + 185220B b c )x
+--R             + 
+--R                            8 6             9 5  10
+--R               (- 4609920A b c  + 2963520B b c )x
+--R             + 
+--R                             9 5              10 4  8
+--R               (- 27659520A b c  + 17781120B b  c )x
+--R             + 
+--R                             10 4              11 3  6
+--R               (- 79027200A b  c  + 50803200B b  c )x
+--R             + 
+--R                              11 3              12 2  4
+--R               (- 115906560A b  c  + 74511360B b  c )x
+--R             + 
+--R                             12 2              13   2              13
+--R               (- 84295680A b  c  + 54190080B b  c)x  - 24084480A b  c
+--R             + 
+--R                          14
+--R               15482880B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                          12 24               12               11  22
+--R               - 215040B c  x   + (- 250880A c   - 7150080B b c  )x
+--R             + 
+--R                              11              2 10  20
+--R               (- 8354304A b c   - 70538496B b c  )x
+--R             + 
+--R                             2 10               3 9  18
+--R               (- 82699456A b c   - 313509984B b c )x
+--R             + 
+--R                              3 9               4 8  16
+--R               (- 369470752A b c  - 728811408B b c )x
+--R             + 
+--R                              4 8               5 7  14
+--R               (- 864825752A b c  - 922532748B b c )x
+--R             + 
+--R                               5 7               6 6  12
+--R               (- 1103996572A b c  - 603629358B b c )x
+--R             + 
+--R                              6 6               7 5  10
+--R               (- 729497216A b c  - 160183104B b c )x
+--R             + 
+--R                              7 5            8 4  8
+--R               (- 194404224A b c  - 854976B b c )x
+--R             + 
+--R                          8 4             9 3  6
+--R               (8744960A b c  - 5621760B b c )x
+--R             + 
+--R                           9 3              10 2  4
+--R               (23733248A b c  - 15257088B b  c )x
+--R             + 
+--R                           10 2              11   2              11
+--R               (28098560A b  c  - 18063360B b  c)x  + 12042240A b  c
+--R             + 
+--R                           12
+--R               - 7741440B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                       13 26            13               12  24
+--R               15360B c  x   + (17920A c   + 1524480B b c  )x
+--R             + 
+--R                            12              2 11  22
+--R               (1779456A b c   + 25966464B b c  )x
+--R             + 
+--R                           2 11               3 10  20
+--R               (30382240A b c   + 174649680B b c  )x
+--R             + 
+--R                            3 10               4 9  18
+--R               (205184560A b c   + 594070680B b c )x
+--R             + 
+--R                            4 9                5 8  16
+--R               (701836212A b c  + 1124632698B b c )x
+--R             + 
+--R                             5 8                6 7  14
+--R               (1337861994A b c  + 1204329861B b c )x
+--R             + 
+--R                             6 7               7 6  12
+--R               (1444303812A b c  + 683704578B b c )x
+--R             + 
+--R                            7 6               8 5  10
+--R               (827077440A b c  + 160367520B b c )x
+--R             + 
+--R                            8 5             9 4  8
+--R               (191712640A b c  + 2585280B b c )x
+--R             + 
+--R                             9 4              10 3  6
+--R               (- 17851904A b c  + 11476224B b  c )x
+--R             + 
+--R                             10 3              11 2  4
+--R               (- 36277248A b  c  + 23321088B b  c )x
+--R             + 
+--R                             11 2              12   2              12
+--R               (- 34119680A b  c  + 21934080B b  c)x  - 12042240A b  c
+--R             + 
+--R                         13
+--R               7741440B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                     13 27              13               12  25
+--R           - 15360B c  x   + (- 17920A c   - 1524480B b c  )x
+--R         + 
+--R                          12              2 11  23
+--R           (- 1779456A b c   - 25966464B b c  )x
+--R         + 
+--R                         2 11               3 10  21
+--R           (- 30382240A b c   - 174649680B b c  )x
+--R         + 
+--R                          3 10               4 9  19
+--R           (- 205184560A b c   - 594070680B b c )x
+--R         + 
+--R                          4 9                5 8  17
+--R           (- 701836212A b c  - 1124632698B b c )x
+--R         + 
+--R                           5 8                6 7  15
+--R           (- 1337861994A b c  - 1204329861B b c )x
+--R         + 
+--R                           6 7               7 6  13
+--R           (- 1444303812A b c  - 683704578B b c )x
+--R         + 
+--R                          7 6               8 5  11
+--R           (- 827077440A b c  - 160367520B b c )x
+--R         + 
+--R                          8 5             9 4  9
+--R           (- 191712640A b c  - 2585280B b c )x
+--R         + 
+--R                       9 4              10 3  7
+--R           (17851904A b c  - 11476224B b  c )x
+--R         + 
+--R                       10 3              11 2  5
+--R           (36277248A b  c  - 23321088B b  c )x
+--R         + 
+--R                     11 2              12   3               12              13
+--R         (34119680A b  c  - 21934080B b  c)x  + (12042240A b  c - 7741440B b  )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                    13 27             13               12  25
+--R           215040B c  x   + (250880A c   + 7365120B b c  )x
+--R         + 
+--R                        12              2 11  23
+--R           (8605184A b c   + 77688576B b c  )x
+--R         + 
+--R                       2 11               3 10  21
+--R           (91053760A b c   + 384048480B b c  )x
+--R         + 
+--R                        3 10                4 9  19
+--R           (452170208A b c   + 1042321392B b c )x
+--R         + 
+--R                         4 9                5 8  17
+--R           (1234296504A b c  + 1651344156B b c )x
+--R         + 
+--R                         5 8                6 7  15
+--R           (1968822324A b c  + 1526162106B b c )x
+--R         + 
+--R                         6 7               7 6  13
+--R           (1833493788A b c  + 763812462B b c )x
+--R         + 
+--R                        7 6               8 5  11
+--R           (923901440A b c  + 161038080B b c )x
+--R         + 
+--R                        8 5             9 4  9
+--R           (185659264A b c  + 6476736B b c )x
+--R         + 
+--R                         9 4              10 3  7
+--R           (- 32478208A b c  + 20878848B b  c )x
+--R         + 
+--R                         10 3              11 2  5
+--R           (- 51831808A b  c  + 33320448B b  c )x
+--R         + 
+--R                         11 2              12   3
+--R           (- 40140800A b  c  + 25804800B b  c)x
+--R         + 
+--R                         12              13
+--R           (- 12042240A b  c + 7741440B b  )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R                   11 12              10 10             2 9 8              3 8 6
+--R           3010560c  x   + 96337920b c  x   + 867041280b c x  + 3303014400b c x
+--R         + 
+--R                      4 7 4              5 6 2              6 5
+--R           6055526400b c x  + 5284823040b c x  + 1761607680b c
+--R      *
+--R                        +--------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|b \|c \|c x  + b
+--R     + 
+--R                    12 14              11 12             2 10 10
+--R           - 215040c  x   - 21073920b c  x   - 337182720b c  x
+--R         + 
+--R                        3 9 8              4 8 6              5 7 4
+--R           - 2023096320b c x  - 5780275200b c x  - 8477736960b c x
+--R         + 
+--R                        6 6 2              7 5
+--R           - 6165626880b c x  - 1761607680b c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      15 40           15            14  38
+--R               - 28B c  x   + (- 28A c   - 3696B b c  )x
+--R             + 
+--R                           14            2 13  36
+--R               (- 3696A b c   - 147084B b c  )x
+--R             + 
+--R                           2 13             3 12  34
+--R               (- 147084A b c   - 2772536B b c  )x
+--R             + 
+--R                            3 12              4 11  32
+--R               (- 2772536A b c   - 30011904B b c  )x
+--R             + 
+--R                             4 11               5 10  30
+--R               (- 30011904A b c   - 207068160B b c  )x
+--R             + 
+--R                              5 10               6 9  28
+--R               (- 207068160A b c   - 969521152B b c )x
+--R             + 
+--R                              6 9                7 8  26
+--R               (- 969521152A b c  - 3203002368B b c )x
+--R             + 
+--R                               7 8                8 7  24
+--R               (- 3203002368A b c  - 7642939392B b c )x
+--R             + 
+--R                               8 7                 9 6  22
+--R               (- 7642939392A b c  - 13323993088B b c )x
+--R             + 
+--R                                9 6                 10 5  20
+--R               (- 13323993088A b c  - 16981426176B b  c )x
+--R             + 
+--R                                10 5                 11 4  18
+--R               (- 16981426176A b  c  - 15648423936B b  c )x
+--R             + 
+--R                                11 4                 12 3  16
+--R               (- 15648423936A b  c  - 10150215680B b  c )x
+--R             + 
+--R                                12 3                13 2  14
+--R               (- 10150215680A b  c  - 4395630592B b  c )x
+--R             + 
+--R                               13 2                14   12
+--R               (- 4395630592A b  c  - 1140850688B b  c)x
+--R             + 
+--R                               14                15  10               15 8
+--R               (- 1140850688A b  c - 134217728B b  )x   - 134217728A b  x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              16 42       16           15  40            15           2 14  38
+--R           B c  x   + (A c   + 394B b c  )x   + (394A b c   + 26265B b c  )x
+--R         + 
+--R                    2 14            3 13  36
+--R           (26265A b c   + 703640B b c  )x
+--R         + 
+--R                     3 13              4 12  34
+--R           (703640A b c   + 10042760B b c  )x
+--R         + 
+--R                       4 12              5 11  32
+--R           (10042760A b c   + 87779328B b c  )x
+--R         + 
+--R                       5 11               6 10  30
+--R           (87779328A b c   + 509297152B b c  )x
+--R         + 
+--R                        6 10                7 9  28
+--R           (509297152A b c   + 2062151680B b c )x
+--R         + 
+--R                         7 9                8 8  26
+--R           (2062151680A b c  + 6013071360B b c )x
+--R         + 
+--R                         8 8                 9 7  24
+--R           (6013071360A b c  + 12862750720B b c )x
+--R         + 
+--R                          9 7                 10 6  22
+--R           (12862750720A b c  + 20349779968B b  c )x
+--R         + 
+--R                          10 6                 11 5  20
+--R           (20349779968A b  c  + 23770693632B b  c )x
+--R         + 
+--R                          11 5                 12 4  18
+--R           (23770693632A b  c  + 20240138240B b  c )x
+--R         + 
+--R                          12 4                 13 3  16
+--R           (20240138240A b  c  + 12213813248B b  c )x
+--R         + 
+--R                          13 3                14 2  14
+--R           (12213813248A b  c  + 4949278720B b  c )x
+--R         + 
+--R                         14 2                15   12
+--R           (4949278720A b  c  + 1207959552B b  c)x
+--R         + 
+--R                         15                16  10               16 8
+--R           (1207959552A b  c + 134217728B b  )x   + 134217728A b  x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                16 43         16           15  41
+--R           - B c  x   + (- A c   - 394B b c  )x
+--R         + 
+--R                      15           2 14  39
+--R           (- 394A b c   - 26265B b c  )x
+--R         + 
+--R                      2 14            3 13  37
+--R           (- 26265A b c   - 703640B b c  )x
+--R         + 
+--R                       3 13              4 12  35
+--R           (- 703640A b c   - 10042760B b c  )x
+--R         + 
+--R                         4 12              5 11  33
+--R           (- 10042760A b c   - 87779328B b c  )x
+--R         + 
+--R                         5 11               6 10  31
+--R           (- 87779328A b c   - 509297152B b c  )x
+--R         + 
+--R                          6 10                7 9  29
+--R           (- 509297152A b c   - 2062151680B b c )x
+--R         + 
+--R                           7 9                8 8  27
+--R           (- 2062151680A b c  - 6013071360B b c )x
+--R         + 
+--R                           8 8                 9 7  25
+--R           (- 6013071360A b c  - 12862750720B b c )x
+--R         + 
+--R                            9 7                 10 6  23
+--R           (- 12862750720A b c  - 20349779968B b  c )x
+--R         + 
+--R                            10 6                 11 5  21
+--R           (- 20349779968A b  c  - 23770693632B b  c )x
+--R         + 
+--R                            11 5                 12 4  19
+--R           (- 23770693632A b  c  - 20240138240B b  c )x
+--R         + 
+--R                            12 4                 13 3  17
+--R           (- 20240138240A b  c  - 12213813248B b  c )x
+--R         + 
+--R                            13 3                14 2  15
+--R           (- 12213813248A b  c  - 4949278720B b  c )x
+--R         + 
+--R                           14 2                15   13
+--R           (- 4949278720A b  c  - 1207959552B b  c)x
+--R         + 
+--R                           15                16  11               16 9
+--R           (- 1207959552A b  c - 134217728B b  )x   - 134217728A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                16 43         16            15  41
+--R           28B c  x   + (28A c   + 3724B b c  )x
+--R         + 
+--R                     15            2 14  39
+--R           (3724A b c   + 150780B b c  )x
+--R         + 
+--R                     2 14             3 13  37
+--R           (150780A b c   + 2919620B b c  )x
+--R         + 
+--R                      3 13              4 12  35
+--R           (2919620A b c   + 32784440B b c  )x
+--R         + 
+--R                       4 12               5 11  33
+--R           (32784440A b c   + 237080064B b c  )x
+--R         + 
+--R                        5 11                6 10  31
+--R           (237080064A b c   + 1176589312B b c  )x
+--R         + 
+--R                         6 10                7 9  29
+--R           (1176589312A b c   + 4172523520B b c )x
+--R         + 
+--R                         7 9                 8 8  27
+--R           (4172523520A b c  + 10845941760B b c )x
+--R         + 
+--R                          8 8                 9 7  25
+--R           (10845941760A b c  + 20966932480B b c )x
+--R         + 
+--R                          9 7                 10 6  23
+--R           (20966932480A b c  + 30305419264B b  c )x
+--R         + 
+--R                          10 6                 11 5  21
+--R           (30305419264A b  c  + 32629850112B b  c )x
+--R         + 
+--R                          11 5                 12 4  19
+--R           (32629850112A b  c  + 25798639616B b  c )x
+--R         + 
+--R                          12 4                 13 3  17
+--R           (25798639616A b  c  + 14545846272B b  c )x
+--R         + 
+--R                          13 3                14 2  15
+--R           (14545846272A b  c  + 5536481280B b  c )x
+--R         + 
+--R                         14 2                15   13
+--R           (5536481280A b  c  + 1275068416B b  c)x
+--R         + 
+--R                         15                16  11               16 9
+--R           (1275068416A b  c + 134217728B b  )x   + 134217728A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              14 28         13 26         2 12 24          3 11 22
+--R             c  x   + 392b c  x   + 25480b c  x   + 652288b c  x
+--R           + 
+--R                     4 10 20            5 9 18             6 8 16
+--R             8712704b c  x   + 69701632b c x   + 361181184b c x
+--R           + 
+--R                        7 7 14              8 6 12              9 5 10
+--R             1270087680b c x   + 3111714816b c x   + 5369233408b c x
+--R           + 
+--R                        10 4 8              11 3 6              12 2 4
+--R             6499598336b  c x  + 5402263552b  c x  + 2936012800b  c x
+--R           + 
+--R                       13   2             14
+--R             939524096b  c x  + 134217728b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  14 28          13 26          2 12 24           3 11 22
+--R             - 28c  x   - 3668b c  x   - 143416b c  x   - 2629120b c  x
+--R           + 
+--R                        4 10 20             5 9 18             6 8 16
+--R             - 27382784b c  x   - 179685376b c x   - 789835776b c x
+--R           + 
+--R                          7 7 14              8 6 12              9 5 10
+--R             - 2413166592b c x   - 5229772800b c x   - 8094220288b c x
+--R           + 
+--R                          10 4 8              11 3 6              12 2 4
+--R             - 8887205888b  c x  - 6761218048b  c x  - 3388997632b  c x
+--R           + 
+--R                          13   2             14
+--R             - 1006632960b  c x  - 134217728b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 832
+
+)clear all
+
+--S 833 of 3139
+t0:=x^4*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                           +-----------+
+--R              10               8        6  |   4      2
+--R   (1)  (B c x   + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 833
+
+--S 834 of 3139
+r0:=16/15015*b^3*(8*b*B-13*A*c)*(b*x^2+c*x^4)^(5/2)/(c^5*x^5)-_
+   8/3003*b^2*(8*b*B-13*A*c)*(b*x^2+c*x^4)^(5/2)/(c^4*x^3)+2/429*b*_
+   (8*b*B-13*A*c)*(b*x^2+c*x^4)^(5/2)/(c^3*x)-1/143*(8*b*B-13*A*c)*x*_
+   (b*x^2+c*x^4)^(5/2)/c^2+1/13*B*x^3*(b*x^2+c*x^4)^(5/2)/c
+--R 
+--R
+--R   (2)
+--R                6 12           6            5  10             5        2 4  8
+--R         1155B c x   + (1365A c  + 1470B b c )x   + (1820A b c  + 35B b c )x
+--R       + 
+--R               2 4        3 3  6           3 3        4 2  4
+--R         (65A b c  - 40B b c )x  + (- 78A b c  + 48B b c )x
+--R       + 
+--R                4 2        5   2         5          6
+--R         (104A b c  - 64B b c)x  - 208A b c + 128B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R           5
+--R     15015c x
+--R                                                    Type: Expression(Integer)
+--E 834
+
+--S 835 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       7 24                7            2 6  22
+--R           - 15015B b c x   + (- 17745A b c  - 439530B b c )x
+--R         + 
+--R                       2 6             3 5  20
+--R           (- 520520A b c  - 3898895B b c )x
+--R         + 
+--R                        3 5              4 4  18
+--R           (- 4638205A b c  - 15824380B b c )x
+--R         + 
+--R                         4 4              5 3  16
+--R           (- 18950646A b c  - 33983664B b c )x
+--R         + 
+--R                         5 3              6 2  14
+--R           (- 41046720A b c  - 40085760B b c )x
+--R         + 
+--R                         6 2              7   12
+--R           (- 48912864A b c  - 24600576B b c)x
+--R         + 
+--R                         7              8  10             8 8
+--R           (- 30366336A b c - 6150144B b )x   - 7687680A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                  8 26           8             7  24
+--R           1155B c x   + (1365A c  + 99645B b c )x
+--R         + 
+--R                       7             2 6  22
+--R           (117845A b c  + 1515605B b c )x
+--R         + 
+--R                      2 6             3 5  20
+--R           (1798225A b c  + 9275695B b c )x
+--R         + 
+--R                       3 5              4 4  18
+--R           (11063767A b c  + 29102788B b c )x
+--R         + 
+--R                       4 4              5 3  16
+--R           (34957494A b c  + 51335856B b c )x
+--R         + 
+--R                       5 3              6 2  14
+--R           (62187840A b c  + 51617280B b c )x
+--R         + 
+--R                       6 2              7   12
+--R           (63135072A b c  + 27675648B b c)x
+--R         + 
+--R                       7              8  10             8 8
+--R           (34210176A b c + 6150144B b )x   + 7687680A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                 6 12             5 10            2 4 8            3 3 6
+--R           15015c x   + 1261260b c x   + 16816800b c x  + 80720640b c x
+--R         + 
+--R                     4 2 4             5   2            6
+--R           172972800b c x  + 169128960b c x  + 61501440b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                  6 12           2 5 10            3 4 8             4 3 6
+--R       - 195195b c x   - 5465460b c x   - 43723680b c x  - 149909760b c x
+--R     + 
+--R                   5 2 4             6   2            7
+--R       - 249849600b c x  - 199879680b c x  - 61501440b
+--R                                         Type: Union(Expression(Integer),...)
+--E 835
+
+--S 836 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        12 24             12             11  22
+--R               - 1155B c  x   + (- 1365A c   - 98490B b c  )x
+--R             + 
+--R                             11             2 10  20
+--R               (- 116480A b c   - 1417115B b c  )x
+--R             + 
+--R                            2 10             3 9  18
+--R               (- 1681745A b c   - 7858580B b c )x
+--R             + 
+--R                            3 9              4 8  16
+--R               (- 9382022A b c  - 21244208B b c )x
+--R             + 
+--R                             4 8              5 7  14
+--R               (- 25575472A b c  - 30091648B b c )x
+--R             + 
+--R                             5 7              6 6  12
+--R               (- 36612368A b c  - 21525632B b c )x
+--R             + 
+--R                             6 6             7 5  10
+--R               (- 26520000A b c  - 6151680B b c )x
+--R             + 
+--R                            7 5           8 4  8
+--R               (- 7614464A b c  - 45056B b c )x
+--R             + 
+--R                         8 4            9 3  6
+--R               (532480A b c  - 327680B b c )x
+--R             + 
+--R                          9 3            10 2  4
+--R               (1544192A b c  - 950272B b  c )x
+--R             + 
+--R                          10 2             11   2            11             12
+--R               (1916928A b  c  - 1179648B b  c)x  + 851968A b  c - 524288B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                     12 24              12            2 11  22
+--R           15015B b c  x   + (17745A b c   + 439530B b c  )x
+--R         + 
+--R                     2 11             3 10  20
+--R           (520520A b c   + 3898895B b c  )x
+--R         + 
+--R                      3 10              4 9  18
+--R           (4638205A b c   + 15824380B b c )x
+--R         + 
+--R                       4 9              5 8  16
+--R           (18950646A b c  + 33983664B b c )x
+--R         + 
+--R                       5 8              6 7  14
+--R           (41046720A b c  + 40085760B b c )x
+--R         + 
+--R                       6 7              7 6  12
+--R           (48912656A b c  + 24600704B b c )x
+--R         + 
+--R                       7 6             8 5  10
+--R           (30348864A b c  + 6160896B b c )x
+--R         + 
+--R                      8 5            9 4  8
+--R           (7454720A b c  + 143360B b c )x
+--R         + 
+--R                        9 4            10 3  6
+--R           (- 1118208A b c  + 688128B b  c )x
+--R         + 
+--R                        10 3             11 2  4
+--R           (- 2396160A b  c  + 1474560B b  c )x
+--R         + 
+--R                        11 2             12   2            12             13
+--R           (- 2342912A b  c  + 1441792B b  c)x  - 851968A b  c + 524288B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                       12 25                12            2 11  23
+--R           - 15015B b c  x   + (- 17745A b c   - 439530B b c  )x
+--R         + 
+--R                       2 11             3 10  21
+--R           (- 520520A b c   - 3898895B b c  )x
+--R         + 
+--R                        3 10              4 9  19
+--R           (- 4638205A b c   - 15824380B b c )x
+--R         + 
+--R                         4 9              5 8  17
+--R           (- 18950646A b c  - 33983664B b c )x
+--R         + 
+--R                         5 8              6 7  15
+--R           (- 41046720A b c  - 40085760B b c )x
+--R         + 
+--R                         6 7              7 6  13
+--R           (- 48912864A b c  - 24600576B b c )x
+--R         + 
+--R                         7 6             8 5  11             8 5 9
+--R           (- 30366336A b c  - 6150144B b c )x   - 7687680A b c x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                  13 27           13             12  25
+--R           1155B c  x   + (1365A c   + 99645B b c  )x
+--R         + 
+--R                       12             2 11  23
+--R           (117845A b c   + 1515605B b c  )x
+--R         + 
+--R                      2 11             3 10  21
+--R           (1798225A b c   + 9275695B b c  )x
+--R         + 
+--R                       3 10              4 9  19
+--R           (11063767A b c   + 29102788B b c )x
+--R         + 
+--R                       4 9              5 8  17
+--R           (34957494A b c  + 51335856B b c )x
+--R         + 
+--R                       5 8              6 7  15
+--R           (62187840A b c  + 51617280B b c )x
+--R         + 
+--R                       6 7              7 6  13
+--R           (63135072A b c  + 27675648B b c )x
+--R         + 
+--R                       7 6             8 5  11             8 5 9
+--R           (34210176A b c  + 6150144B b c )x   + 7687680A b c x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                 11 13             10 11            2 9 9            3 8 7
+--R           15015c  x   + 1261260b c  x   + 16816800b c x  + 80720640b c x
+--R         + 
+--R                     4 7 5             5 6 3            6 5
+--R           172972800b c x  + 169128960b c x  + 61501440b c x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                  11 13           2 10 11            3 9 9             4 8 7
+--R       - 195195b c  x   - 5465460b c  x   - 43723680b c x  - 149909760b c x
+--R     + 
+--R                   5 7 5             6 6 3            7 5
+--R       - 249849600b c x  - 199879680b c x  - 61501440b c x
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      14 37           14            13  35
+--R               - 26B c  x   + (- 26A c   - 2964B b c  )x
+--R             + 
+--R                           13            2 12  33
+--R               (- 2964A b c   - 101946B b c  )x
+--R             + 
+--R                           2 12             3 11  31
+--R               (- 101946A b c   - 1659424B b c  )x
+--R             + 
+--R                            3 11              4 10  29
+--R               (- 1659424A b c   - 15471456B b c  )x
+--R             + 
+--R                             4 10              5 9  27
+--R               (- 15471456A b c   - 91533312B b c )x
+--R             + 
+--R                             5 9               6 8  25
+--R               (- 91533312A b c  - 365063168B b c )x
+--R             + 
+--R                              6 8                7 7  23
+--R               (- 365063168A b c  - 1017741312B b c )x
+--R             + 
+--R                               7 7                8 6  21
+--R               (- 1017741312A b c  - 2022801408B b c )x
+--R             + 
+--R                               8 6                9 5  19
+--R               (- 2022801408A b c  - 2884370432B b c )x
+--R             + 
+--R                               9 5                10 4  17
+--R               (- 2884370432A b c  - 2929852416B b  c )x
+--R             + 
+--R                               10 4                11 3  15
+--R               (- 2929852416A b  c  - 2069889024B b  c )x
+--R             + 
+--R                               11 3               12 2  13
+--R               (- 2069889024A b  c  - 966787072B b  c )x
+--R             + 
+--R                              12 2               13   11
+--R               (- 966787072A b  c  - 268435456B b  c)x
+--R             + 
+--R                              13               14  9              14 7
+--R               (- 268435456A b  c - 33554432B b  )x  - 33554432A b  x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              15 39       15           14  37            14           2 13  35
+--R           B c  x   + (A c   + 340B b c  )x   + (340A b c   + 19605B b c  )x
+--R         + 
+--R                    2 13            3 12  33
+--R           (19605A b c   + 454610B b c  )x
+--R         + 
+--R                     3 12             4 11  31
+--R           (454610A b c   + 5610800B b c  )x
+--R         + 
+--R                      4 11              5 10  29
+--R           (5610800A b c   + 42295968B b c  )x
+--R         + 
+--R                       5 10               6 9  27
+--R           (42295968A b c   + 210695680B b c )x
+--R         + 
+--R                        6 9               7 8  25
+--R           (210695680A b c  + 727567360B b c )x
+--R         + 
+--R                        7 8                8 7  23
+--R           (727567360A b c  + 1792327680B b c )x
+--R         + 
+--R                         8 7                9 6  21
+--R           (1792327680A b c  + 3197009920B b c )x
+--R         + 
+--R                         9 6                10 5  19
+--R           (3197009920A b c  + 4141416448B b  c )x
+--R         + 
+--R                         10 5                11 4  17
+--R           (4141416448A b  c  + 3859415040B b  c )x
+--R         + 
+--R                         11 4                12 3  15
+--R           (3859415040A b  c  + 2521825280B b  c )x
+--R         + 
+--R                         12 3                13 2  13
+--R           (2521825280A b  c  + 1096810496B b  c )x
+--R         + 
+--R                         13 2               14   11
+--R           (1096810496A b  c  + 285212672B b  c)x
+--R         + 
+--R                        14               15  9              15 7
+--R           (285212672A b  c + 33554432B b  )x  + 33554432A b  x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                15 40         15           14  38
+--R           - B c  x   + (- A c   - 340B b c  )x
+--R         + 
+--R                      14           2 13  36
+--R           (- 340A b c   - 19605B b c  )x
+--R         + 
+--R                      2 13            3 12  34
+--R           (- 19605A b c   - 454610B b c  )x
+--R         + 
+--R                       3 12             4 11  32
+--R           (- 454610A b c   - 5610800B b c  )x
+--R         + 
+--R                        4 11              5 10  30
+--R           (- 5610800A b c   - 42295968B b c  )x
+--R         + 
+--R                         5 10               6 9  28
+--R           (- 42295968A b c   - 210695680B b c )x
+--R         + 
+--R                          6 9               7 8  26
+--R           (- 210695680A b c  - 727567360B b c )x
+--R         + 
+--R                          7 8                8 7  24
+--R           (- 727567360A b c  - 1792327680B b c )x
+--R         + 
+--R                           8 7                9 6  22
+--R           (- 1792327680A b c  - 3197009920B b c )x
+--R         + 
+--R                           9 6                10 5  20
+--R           (- 3197009920A b c  - 4141416448B b  c )x
+--R         + 
+--R                           10 5                11 4  18
+--R           (- 4141416448A b  c  - 3859415040B b  c )x
+--R         + 
+--R                           11 4                12 3  16
+--R           (- 3859415040A b  c  - 2521825280B b  c )x
+--R         + 
+--R                           12 3                13 2  14
+--R           (- 2521825280A b  c  - 1096810496B b  c )x
+--R         + 
+--R                           13 2               14   12
+--R           (- 1096810496A b  c  - 285212672B b  c)x
+--R         + 
+--R                          14               15  10              15 8
+--R           (- 285212672A b  c - 33554432B b  )x   - 33554432A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                15 40         15            14  38
+--R           26B c  x   + (26A c   + 2990B b c  )x
+--R         + 
+--R                     14            2 13  36
+--R           (2990A b c   + 104910B b c  )x
+--R         + 
+--R                     2 13             3 12  34
+--R           (104910A b c   + 1761370B b c  )x
+--R         + 
+--R                      3 12              4 11  32
+--R           (1761370A b c   + 17130880B b c  )x
+--R         + 
+--R                       4 11               5 10  30
+--R           (17130880A b c   + 107004768B b c  )x
+--R         + 
+--R                        5 10               6 9  28
+--R           (107004768A b c   + 456596480B b c )x
+--R         + 
+--R                        6 9                7 8  26
+--R           (456596480A b c  + 1382804480B b c )x
+--R         + 
+--R                         7 8                8 7  24
+--R           (1382804480A b c  + 3040542720B b c )x
+--R         + 
+--R                         8 7                9 6  22
+--R           (3040542720A b c  + 4907171840B b c )x
+--R         + 
+--R                         9 6                10 5  20
+--R           (4907171840A b c  + 5814222848B b  c )x
+--R         + 
+--R                         10 5                11 4  18
+--R           (5814222848A b  c  + 4999741440B b  c )x
+--R         + 
+--R                         11 4                12 3  16
+--R           (4999741440A b  c  + 3036676096B b  c )x
+--R         + 
+--R                         12 3                13 2  14
+--R           (3036676096A b  c  + 1235222528B b  c )x
+--R         + 
+--R                         13 2               14   12
+--R           (1235222528A b  c  + 301989888B b  c)x
+--R         + 
+--R                        14               15  10              15 8
+--R           (301989888A b  c + 33554432B b  )x   + 33554432A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              13 26         12 24         2 11 22          3 10 20
+--R             c  x   + 338b c  x   + 18928b c  x   + 416416b c  x
+--R           + 
+--R                     4 9 18            5 8 16             6 7 14
+--R             4759040b c x   + 32361472b c x   + 141213696b c x
+--R           + 
+--R                       7 6 12             8 5 10              9 4 8
+--R             412778496b c x   + 825556992b c x   + 1133117440b c x
+--R           + 
+--R                      10 3 6             11 2 4             12   2            13
+--R           1049624576b  c x  + 627048448b  c x  + 218103808b  c x  + 33554432b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  13 26          12 24         2 11 22           3 10 20
+--R             - 26c  x   - 2938b c  x   - 99008b c  x   - 1560416b c  x
+--R           + 
+--R                        4 9 18            5 8 16             6 7 14
+--R             - 13911040b c x   - 77622272b c x   - 287440896b c x
+--R           + 
+--R                         7 6 12              8 5 10              9 4 8
+--R             - 730300416b c x   - 1292500992b c x   - 1591869440b c x
+--R           + 
+--R                          10 3 6             11 2 4             12   2
+--R             - 1337982976b  c x  - 731906048b  c x  - 234881024b  c x
+--R           + 
+--R                        13
+--R             - 33554432b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 837
+
+)clear all
+
+--S 838 of 3139
+t0:=x^3*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                          +-----------+
+--R              9               7        5  |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 838
+
+--S 839 of 3139
+r0:=-1/120*(7*b*B-12*A*c)*x^4*(b*x^2+c*x^4)^(3/2)/c+1/12*B*x^2*_
+   (b*x^2+c*x^4)^(5/2)/c+1/1024*b^5*(7*b*B-12*A*c)*atanh(x^2*sqrt(c)/_
+   sqrt(b*x^2+c*x^4))/c^(9/2)-1/1024*b^4*(7*b*B-12*A*c)*sqrt(b*x^2+_
+   c*x^4)/c^4+1/1536*b^3*(7*b*B-12*A*c)*x^2*sqrt(b*x^2+c*x^4)/c^3-_
+   1/1920*b^2*(7*b*B-12*A*c)*x^4*sqrt(b*x^2+c*x^4)/c^2-1/320*b*(7*b*B-_
+   12*A*c)*x^6*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                        2 +-+
+--R                5          6           x \|c
+--R       (- 180A b c + 105B b )atanh(--------------)
+--R                                    +-----------+
+--R                                    |   4      2
+--R                                   \|c x  + b x
+--R     + 
+--R                  5 10           5            4  8             4        2 3  6
+--R           1280B c x   + (1536A c  + 1664B b c )x  + (2112A b c  + 48B b c )x
+--R         + 
+--R                 2 3        3 2  4            3 2        4   2         4
+--R           (96A b c  - 56B b c )x  + (- 120A b c  + 70B b c)x  + 180A b c
+--R         + 
+--R                   5
+--R           - 105B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R           4 +-+
+--R     15360c \|c
+--R                                                    Type: Expression(Integer)
+--E 839
+
+--S 840 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         5 6          6 5  10            6 5           7 4  8
+--R                 (2160A b c  - 1260B b c )x   + (50400A b c  - 29400B b c )x
+--R               + 
+--R                           7 4            8 3  6
+--R                 (322560A b c  - 188160B b c )x
+--R               + 
+--R                           8 3            9 2  4
+--R                 (829440A b c  - 483840B b c )x
+--R               + 
+--R                           9 2            10   2            10             11
+--R                 (921600A b c  - 537600B b  c)x  + 368640A b  c - 215040B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                      5 7         6 6  12              6 6          7 5  10
+--R             (- 180A b c  + 105B b c )x   + (- 12960A b c  + 7560B b c )x
+--R           + 
+--R                         7 5           8 4  8
+--R             (- 151200A b c  + 88200B b c )x
+--R           + 
+--R                         8 4            9 3  6
+--R             (- 645120A b c  + 376320B b c )x
+--R           + 
+--R                          9 3            10 2  4
+--R             (- 1244160A b c  + 725760B b  c )x
+--R           + 
+--R                          10 2            11   2            11             12
+--R             (- 1105920A b  c  + 645120B b  c)x  - 368640A b  c + 215040B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                      11 23             11             10  21
+--R             - 1280B c  x   + (- 1536A c   - 93824B b c  )x
+--R           + 
+--R                           10             2 9  19
+--R             (- 112704A b c   - 1195056B b c )x
+--R           + 
+--R                          2 9             3 8  17
+--R             (- 1442400A b c  - 5988680B b c )x
+--R           + 
+--R                          3 8              4 7  15
+--R             (- 7285896A b c  - 14847494B b c )x
+--R           + 
+--R                           4 7              5 6  13
+--R             (- 18258420A b c  - 19495815B b c )x
+--R           + 
+--R                           5 6              6 5  11
+--R             (- 24291552A b c  - 13027368B b c )x
+--R           + 
+--R                           6 5             7 4  9
+--R             (- 16506528A b c  - 3478392B b c )x
+--R           + 
+--R                          7 4            8 3  7
+--R             (- 4730880A b c  + 138240B b c )x
+--R           + 
+--R                         8 3            9 2  5
+--R             (- 703488A b c  + 410368B b c )x
+--R           + 
+--R                       9 2            10   3               10             11
+--R           (- 860160A b c  + 501760B b  c)x  + (- 368640A b  c + 215040B b  )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                     11 23            11              10  21
+--R             15360B c  x   + (18432A c   + 393728B b c  )x
+--R           + 
+--R                         10             2 9  19
+--R             (473856A b c   + 3138624B b c )x
+--R           + 
+--R                        2 9              3 8  17
+--R             (3800448A b c  + 11653152B b c )x
+--R           + 
+--R                         3 8              4 7  15
+--R             (14233056A b c  + 23185384B b c )x
+--R           + 
+--R                         4 7              5 6  13
+--R             (28625040A b c  + 25572780B b c )x
+--R           + 
+--R                         5 6              6 5  11
+--R             (31973904A b c  + 14771916B b c )x
+--R           + 
+--R                         6 5             7 4  9
+--R             (18823392A b c  + 3437608B b c )x
+--R           + 
+--R                        7 4            8 3  7              8 3            9 2  5
+--R             (4998144A b c  - 294144B b c )x  + (1087488A b c  - 634368B b c )x
+--R           + 
+--R                        9 2            10   3             10             11
+--R             (1044480A b c  - 609280B b  c)x  + (368640A b  c - 215040B b  )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                    9 10             8 8            2 7 6            3 6 4
+--R             184320c x   + 4300800b c x  + 27525120b c x  + 70778880b c x
+--R           + 
+--R                      4 5 2            5 4
+--R             78643200b c x  + 31457280b c
+--R        *
+--R                    +--------+
+--R            +-+ +-+ |   2
+--R           \|b \|c \|c x  + b
+--R       + 
+--R                     10 12             9 10            2 8 8            3 7 6
+--R             - 15360c  x   - 1105920b c x   - 12902400b c x  - 55050240b c x
+--R           + 
+--R                         4 6 4            5 5 2            6 4
+--R             - 106168320b c x  - 94371840b c x  - 31457280b c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                           5 6          6 5  10
+--R                 (- 4320A b c  + 2520B b c )x
+--R               + 
+--R                             6 5           7 4  8
+--R                 (- 100800A b c  + 58800B b c )x
+--R               + 
+--R                             7 4            8 3  6
+--R                 (- 645120A b c  + 376320B b c )x
+--R               + 
+--R                              8 3            9 2  4
+--R                 (- 1658880A b c  + 967680B b c )x
+--R               + 
+--R                            9 2             10   2            10             11
+--R               (- 1843200A b c  + 1075200B b  c)x  - 737280A b  c + 430080B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                    5 7         6 6  12            6 6           7 5  10
+--R             (360A b c  - 210B b c )x   + (25920A b c  - 15120B b c )x
+--R           + 
+--R                       7 5            8 4  8              8 4            9 3  6
+--R             (302400A b c  - 176400B b c )x  + (1290240A b c  - 752640B b c )x
+--R           + 
+--R                        9 3             10 2  4
+--R             (2488320A b c  - 1451520B b  c )x
+--R           + 
+--R                        10 2             11   2            11             12
+--R             (2211840A b  c  - 1290240B b  c)x  + 737280A b  c - 430080B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                      11 23             11             10  21
+--R             - 1280B c  x   + (- 1536A c   - 93824B b c  )x
+--R           + 
+--R                           10             2 9  19
+--R             (- 112704A b c   - 1195056B b c )x
+--R           + 
+--R                          2 9             3 8  17
+--R             (- 1442400A b c  - 5988680B b c )x
+--R           + 
+--R                          3 8              4 7  15
+--R             (- 7285896A b c  - 14847494B b c )x
+--R           + 
+--R                           4 7              5 6  13
+--R             (- 18258420A b c  - 19495815B b c )x
+--R           + 
+--R                           5 6              6 5  11
+--R             (- 24291552A b c  - 13027368B b c )x
+--R           + 
+--R                           6 5             7 4  9
+--R             (- 16506528A b c  - 3478392B b c )x
+--R           + 
+--R                          7 4            8 3  7
+--R             (- 4730880A b c  + 138240B b c )x
+--R           + 
+--R                         8 3            9 2  5
+--R             (- 703488A b c  + 410368B b c )x
+--R           + 
+--R                       9 2            10   3               10             11
+--R           (- 860160A b c  + 501760B b  c)x  + (- 368640A b  c + 215040B b  )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                     11 23            11              10  21
+--R             15360B c  x   + (18432A c   + 393728B b c  )x
+--R           + 
+--R                         10             2 9  19
+--R             (473856A b c   + 3138624B b c )x
+--R           + 
+--R                        2 9              3 8  17
+--R             (3800448A b c  + 11653152B b c )x
+--R           + 
+--R                         3 8              4 7  15
+--R             (14233056A b c  + 23185384B b c )x
+--R           + 
+--R                         4 7              5 6  13
+--R             (28625040A b c  + 25572780B b c )x
+--R           + 
+--R                         5 6              6 5  11
+--R             (31973904A b c  + 14771916B b c )x
+--R           + 
+--R                         6 5             7 4  9
+--R             (18823392A b c  + 3437608B b c )x
+--R           + 
+--R                        7 4            8 3  7              8 3            9 2  5
+--R             (4998144A b c  - 294144B b c )x  + (1087488A b c  - 634368B b c )x
+--R           + 
+--R                        9 2            10   3             10             11
+--R             (1044480A b c  - 609280B b  c)x  + (368640A b  c - 215040B b  )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                    9 10             8 8            2 7 6            3 6 4
+--R             184320c x   + 4300800b c x  + 27525120b c x  + 70778880b c x
+--R           + 
+--R                      4 5 2            5 4
+--R             78643200b c x  + 31457280b c
+--R        *
+--R                      +--------+
+--R            +---+ +-+ |   2
+--R           \|- c \|b \|c x  + b
+--R       + 
+--R                     10 12             9 10            2 8 8            3 7 6
+--R             - 15360c  x   - 1105920b c x   - 12902400b c x  - 55050240b c x
+--R           + 
+--R                         4 6 4            5 5 2            6 4
+--R             - 106168320b c x  - 94371840b c x  - 31457280b c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 840
+
+--S 841 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       5 6          6 5  10            6 5           7 4  8
+--R               (2160A b c  - 1260B b c )x   + (50400A b c  - 29400B b c )x
+--R             + 
+--R                         7 4            8 3  6             8 3            9 2  4
+--R               (322560A b c  - 188160B b c )x  + (829440A b c  - 483840B b c )x
+--R             + 
+--R                         9 2            10   2            10             11
+--R               (921600A b c  - 537600B b  c)x  + 368640A b  c - 215040B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                    5 7         6 6  12              6 6          7 5  10
+--R           (- 180A b c  + 105B b c )x   + (- 12960A b c  + 7560B b c )x
+--R         + 
+--R                       7 5           8 4  8               8 4            9 3  6
+--R           (- 151200A b c  + 88200B b c )x  + (- 645120A b c  + 376320B b c )x
+--R         + 
+--R                        9 3            10 2  4
+--R           (- 1244160A b c  + 725760B b  c )x
+--R         + 
+--R                        10 2            11   2            11             12
+--R           (- 1105920A b  c  + 645120B b  c)x  - 368640A b  c + 215040B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                       5 6          6 5  10            6 5           7 4  8
+--R               (2160A b c  - 1260B b c )x   + (50400A b c  - 29400B b c )x
+--R             + 
+--R                         7 4            8 3  6             8 3            9 2  4
+--R               (322560A b c  - 188160B b c )x  + (829440A b c  - 483840B b c )x
+--R             + 
+--R                         9 2            10   2            10             11
+--R               (921600A b c  - 537600B b  c)x  + 368640A b  c - 215040B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                    5 7         6 6  12              6 6          7 5  10
+--R           (- 180A b c  + 105B b c )x   + (- 12960A b c  + 7560B b c )x
+--R         + 
+--R                       7 5           8 4  8               8 4            9 3  6
+--R           (- 151200A b c  + 88200B b c )x  + (- 645120A b c  + 376320B b c )x
+--R         + 
+--R                        9 3            10 2  4
+--R           (- 1244160A b c  + 725760B b  c )x
+--R         + 
+--R                        10 2            11   2            11             12
+--R           (- 1105920A b  c  + 645120B b  c)x  - 368640A b  c + 215040B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                         10 20              10              9  18
+--R               - 15360B c  x   + (- 18432A c   - 378368B b c )x
+--R             + 
+--R                             9             2 8  16
+--R               (- 455424A b c  - 2760256B b c )x
+--R             + 
+--R                            2 8             3 7  14
+--R               (- 3345024A b c  - 8892896B b c )x
+--R             + 
+--R                             3 7              4 6  12
+--R               (- 10888032A b c  - 14292488B b c )x
+--R             + 
+--R                             4 6              5 5  10
+--R               (- 17737008A b c  - 11280292B b c )x
+--R             + 
+--R                             5 5             6 4  8
+--R               (- 14236896A b c  - 3491624B b c )x
+--R             + 
+--R                            6 4           7 3  6
+--R               (- 4586496A b c  + 54016B b c )x
+--R             + 
+--R                           7 3            8 2  4
+--R               (- 411648A b c  + 240128B b c )x
+--R             + 
+--R                           8 2            9   2            9             10
+--R               (- 675840A b c  + 394240B b c)x  - 368640A b c + 215040B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                      11 22           11             10  20
+--R               1280B c  x   + (1536A c   + 93824B b c  )x
+--R             + 
+--R                           10             2 9  18
+--R               (112704A b c   + 1195056B b c )x
+--R             + 
+--R                          2 9             3 8  16
+--R               (1442400A b c  + 5988680B b c )x
+--R             + 
+--R                          3 8              4 7  14
+--R               (7285896A b c  + 14847494B b c )x
+--R             + 
+--R                           4 7              5 6  12
+--R               (18258420A b c  + 19495815B b c )x
+--R             + 
+--R                           5 6              6 5  10
+--R               (24291552A b c  + 13027368B b c )x
+--R             + 
+--R                           6 5             7 4  8
+--R               (16506528A b c  + 3478392B b c )x
+--R             + 
+--R                          7 4            8 3  6
+--R               (4730880A b c  - 138240B b c )x
+--R             + 
+--R                         8 3            9 2  4             9 2            10   2
+--R               (703488A b c  - 410368B b c )x  + (860160A b c  - 501760B b  c)x
+--R             + 
+--R                        10             11
+--R               368640A b  c - 215040B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    11 23             11             10  21
+--R           - 1280B c  x   + (- 1536A c   - 93824B b c  )x
+--R         + 
+--R                         10             2 9  19
+--R           (- 112704A b c   - 1195056B b c )x
+--R         + 
+--R                        2 9             3 8  17
+--R           (- 1442400A b c  - 5988680B b c )x
+--R         + 
+--R                        3 8              4 7  15
+--R           (- 7285896A b c  - 14847494B b c )x
+--R         + 
+--R                         4 7              5 6  13
+--R           (- 18258420A b c  - 19495815B b c )x
+--R         + 
+--R                         5 6              6 5  11
+--R           (- 24291552A b c  - 13027368B b c )x
+--R         + 
+--R                         6 5             7 4  9
+--R           (- 16506528A b c  - 3478392B b c )x
+--R         + 
+--R                        7 4            8 3  7
+--R           (- 4730880A b c  + 138240B b c )x
+--R         + 
+--R                       8 3            9 2  5               9 2            10   3
+--R           (- 703488A b c  + 410368B b c )x  + (- 860160A b c  + 501760B b  c)x
+--R         + 
+--R                       10             11
+--R           (- 368640A b  c + 215040B b  )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                   11 23            11              10  21
+--R           15360B c  x   + (18432A c   + 393728B b c  )x
+--R         + 
+--R                       10             2 9  19
+--R           (473856A b c   + 3138624B b c )x
+--R         + 
+--R                      2 9              3 8  17
+--R           (3800448A b c  + 11653152B b c )x
+--R         + 
+--R                       3 8              4 7  15
+--R           (14233056A b c  + 23185384B b c )x
+--R         + 
+--R                       4 7              5 6  13
+--R           (28625040A b c  + 25572780B b c )x
+--R         + 
+--R                       5 6              6 5  11
+--R           (31973904A b c  + 14771916B b c )x
+--R         + 
+--R                       6 5             7 4  9              7 4            8 3  7
+--R           (18823392A b c  + 3437608B b c )x  + (4998144A b c  - 294144B b c )x
+--R         + 
+--R                      8 3            9 2  5              9 2            10   3
+--R           (1087488A b c  - 634368B b c )x  + (1044480A b c  - 609280B b  c)x
+--R         + 
+--R                     10             11
+--R           (368640A b  c - 215040B b  )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                  9 10             8 8            2 7 6            3 6 4
+--R           184320c x   + 4300800b c x  + 27525120b c x  + 70778880b c x
+--R         + 
+--R                    4 5 2            5 4
+--R           78643200b c x  + 31457280b c
+--R      *
+--R                  +--------+
+--R          +-+ +-+ |   2
+--R         \|b \|c \|c x  + b
+--R     + 
+--R                   10 12             9 10            2 8 8            3 7 6
+--R           - 15360c  x   - 1105920b c x   - 12902400b c x  - 55050240b c x
+--R         + 
+--R                       4 6 4            5 5 2            6 4
+--R           - 106168320b c x  - 94371840b c x  - 31457280b c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 841
+
+--S 842 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          15 38           15            14  36
+--R                   - 27B c  x   + (- 27A c   - 3330B b c  )x
+--R                 + 
+--R                               14            2 13  34
+--R                   (- 3330A b c   - 124515B b c  )x
+--R                 + 
+--R                               2 13             3 12  32
+--R                   (- 124515A b c   - 2215980B b c  )x
+--R                 + 
+--R                                3 12              4 11  30
+--R                   (- 2215980A b c   - 22741680B b c  )x
+--R                 + 
+--R                                 4 11               5 10  28
+--R                   (- 22741680A b c   - 149300736B b c  )x
+--R                 + 
+--R                                  5 10               6 9  26
+--R                   (- 149300736A b c   - 667292160B b c )x
+--R                 + 
+--R                                  6 9                7 8  24
+--R                   (- 667292160A b c  - 2110371840B b c )x
+--R                 + 
+--R                                   7 8                8 7  22
+--R                   (- 2110371840A b c  - 4832870400B b c )x
+--R                 + 
+--R                                   8 7                9 6  20
+--R                   (- 4832870400A b c  - 8104181760B b c )x
+--R                 + 
+--R                                   9 6                10 5  18
+--R                   (- 8104181760A b c  - 9955639296B b  c )x
+--R                 + 
+--R                                   10 5                11 4  16
+--R                   (- 9955639296A b  c  - 8859156480B b  c )x
+--R                 + 
+--R                                   11 4                12 3  14
+--R                   (- 8859156480A b  c  - 5558501376B b  c )x
+--R                 + 
+--R                                   12 3                13 2  12
+--R                   (- 5558501376A b  c  - 2332033024B b  c )x
+--R                 + 
+--R                                   13 2               14   10
+--R                   (- 2332033024A b  c  - 587202560B b  c)x
+--R                 + 
+--R                                  14               15  8              15 6
+--R                   (- 587202560A b  c - 67108864B b  )x  - 67108864A b  x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                    16 39         16           15  37
+--R               - B c  x   + (- A c   - 366B b c  )x
+--R             + 
+--R                          15           2 14  35
+--R               (- 366A b c   - 22569B b c  )x
+--R             + 
+--R                          2 14            3 13  33
+--R               (- 22569A b c   - 556556B b c  )x
+--R             + 
+--R                           3 13             4 12  31
+--R               (- 556556A b c   - 7270224B b c  )x
+--R             + 
+--R                            4 12              5 11  29
+--R               (- 7270224A b c   - 57767424B b c  )x
+--R             + 
+--R                             5 11               6 10  27
+--R               (- 57767424A b c   - 302228992B b c  )x
+--R             + 
+--R                              6 10                7 9  25
+--R               (- 302228992A b c   - 1092630528B b c )x
+--R             + 
+--R                               7 9                8 8  23
+--R               (- 1092630528A b c  - 2810068992B b c )x
+--R             + 
+--R                               8 8                9 7  21
+--R               (- 2810068992A b c  - 5219811328B b c )x
+--R             + 
+--R                               9 7                10 6  19
+--R               (- 5219811328A b c  - 7025786880B b  c )x
+--R             + 
+--R                               10 6                11 5  17
+--R               (- 7025786880A b  c  - 6789267456B b  c )x
+--R             + 
+--R                               11 5                12 4  15
+--R               (- 6789267456A b  c  - 4591714304B b  c )x
+--R             + 
+--R                               12 4                13 3  13
+--R               (- 4591714304A b  c  - 2063597568B b  c )x
+--R             + 
+--R                               13 3               14 2  11
+--R               (- 2063597568A b  c  - 553648128B b  c )x
+--R             + 
+--R                              14 2              15   9              15   7
+--R               (- 553648128A b  c  - 67108864B b  c)x  - 67108864A b  c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  16 40       16           15  38
+--R               B c  x   + (A c   + 367B b c  )x
+--R             + 
+--R                        15           2 14  36
+--R               (367A b c   + 22935B b c  )x
+--R             + 
+--R                        2 14            3 13  34
+--R               (22935A b c   + 579125B b c  )x
+--R             + 
+--R                         3 13             4 12  32
+--R               (579125A b c   + 7826780B b c  )x
+--R             + 
+--R                          4 12              5 11  30
+--R               (7826780A b c   + 65037648B b c  )x
+--R             + 
+--R                           5 11               6 10  28
+--R               (65037648A b c   + 359996416B b c  )x
+--R             + 
+--R                            6 10                7 9  26
+--R               (359996416A b c   + 1394859520B b c )x
+--R             + 
+--R                             7 9                8 8  24
+--R               (1394859520A b c  + 3902699520B b c )x
+--R             + 
+--R                             8 8                9 7  22
+--R               (3902699520A b c  + 8029880320B b c )x
+--R             + 
+--R                             9 7                 10 6  20
+--R               (8029880320A b c  + 12245598208B b  c )x
+--R             + 
+--R                              10 6                 11 5  18
+--R               (12245598208A b  c  + 13815054336B b  c )x
+--R             + 
+--R                              11 5                 12 4  16
+--R               (13815054336A b  c  + 11380981760B b  c )x
+--R             + 
+--R                              12 4                13 3  14
+--R               (11380981760A b  c  + 6655311872B b  c )x
+--R             + 
+--R                             13 3                14 2  12
+--R               (6655311872A b  c  + 2617245696B b  c )x
+--R             + 
+--R                             14 2               15   10
+--R               (2617245696A b  c  + 620756992B b  c)x
+--R             + 
+--R                            15               16  8              16 6
+--R               (620756992A b  c + 67108864B b  )x  + 67108864A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    16 39         16            15  37
+--R               27B c  x   + (27A c   + 3330B b c  )x
+--R             + 
+--R                         15            2 14  35
+--R               (3330A b c   + 124515B b c  )x
+--R             + 
+--R                         2 14             3 13  33
+--R               (124515A b c   + 2215980B b c  )x
+--R             + 
+--R                          3 13              4 12  31
+--R               (2215980A b c   + 22741680B b c  )x
+--R             + 
+--R                           4 12               5 11  29
+--R               (22741680A b c   + 149300736B b c  )x
+--R             + 
+--R                            5 11               6 10  27
+--R               (149300736A b c   + 667292160B b c  )x
+--R             + 
+--R                            6 10                7 9  25
+--R               (667292160A b c   + 2110371840B b c )x
+--R             + 
+--R                             7 9                8 8  23
+--R               (2110371840A b c  + 4832870400B b c )x
+--R             + 
+--R                             8 8                9 7  21
+--R               (4832870400A b c  + 8104181760B b c )x
+--R             + 
+--R                             9 7                10 6  19
+--R               (8104181760A b c  + 9955639296B b  c )x
+--R             + 
+--R                             10 6                11 5  17
+--R               (9955639296A b  c  + 8859156480B b  c )x
+--R             + 
+--R                             11 5                12 4  15
+--R               (8859156480A b  c  + 5558501376B b  c )x
+--R             + 
+--R                             12 4                13 3  13
+--R               (5558501376A b  c  + 2332033024B b  c )x
+--R             + 
+--R                             13 3               14 2  11
+--R               (2332033024A b  c  + 587202560B b  c )x
+--R             + 
+--R                            14 2              15   9              15   7
+--R               (587202560A b  c  + 67108864B b  c)x  + 67108864A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    16 41         16           15  39
+--R               - B c  x   + (- A c   - 367B b c  )x
+--R             + 
+--R                          15           2 14  37
+--R               (- 367A b c   - 22935B b c  )x
+--R             + 
+--R                          2 14            3 13  35
+--R               (- 22935A b c   - 579125B b c  )x
+--R             + 
+--R                           3 13             4 12  33
+--R               (- 579125A b c   - 7826780B b c  )x
+--R             + 
+--R                            4 12              5 11  31
+--R               (- 7826780A b c   - 65037648B b c  )x
+--R             + 
+--R                             5 11               6 10  29
+--R               (- 65037648A b c   - 359996416B b c  )x
+--R             + 
+--R                              6 10                7 9  27
+--R               (- 359996416A b c   - 1394859520B b c )x
+--R             + 
+--R                               7 9                8 8  25
+--R               (- 1394859520A b c  - 3902699520B b c )x
+--R             + 
+--R                               8 8                9 7  23
+--R               (- 3902699520A b c  - 8029880320B b c )x
+--R             + 
+--R                               9 7                 10 6  21
+--R               (- 8029880320A b c  - 12245598208B b  c )x
+--R             + 
+--R                                10 6                 11 5  19
+--R               (- 12245598208A b  c  - 13815054336B b  c )x
+--R             + 
+--R                                11 5                 12 4  17
+--R               (- 13815054336A b  c  - 11380981760B b  c )x
+--R             + 
+--R                                12 4                13 3  15
+--R               (- 11380981760A b  c  - 6655311872B b  c )x
+--R             + 
+--R                               13 3                14 2  13
+--R               (- 6655311872A b  c  - 2617245696B b  c )x
+--R             + 
+--R                               14 2               15   11
+--R               (- 2617245696A b  c  - 620756992B b  c)x
+--R             + 
+--R                              15               16  9              16 7
+--R               (- 620756992A b  c - 67108864B b  )x  - 67108864A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      16 40           16            15  38
+--R               - 27B c  x   + (- 27A c   - 3330B b c  )x
+--R             + 
+--R                           15            2 14  36
+--R               (- 3330A b c   - 124515B b c  )x
+--R             + 
+--R                           2 14             3 13  34
+--R               (- 124515A b c   - 2215980B b c  )x
+--R             + 
+--R                            3 13              4 12  32
+--R               (- 2215980A b c   - 22741680B b c  )x
+--R             + 
+--R                             4 12               5 11  30
+--R               (- 22741680A b c   - 149300736B b c  )x
+--R             + 
+--R                              5 11               6 10  28
+--R               (- 149300736A b c   - 667292160B b c  )x
+--R             + 
+--R                              6 10                7 9  26
+--R               (- 667292160A b c   - 2110371840B b c )x
+--R             + 
+--R                               7 9                8 8  24
+--R               (- 2110371840A b c  - 4832870400B b c )x
+--R             + 
+--R                               8 8                9 7  22
+--R               (- 4832870400A b c  - 8104181760B b c )x
+--R             + 
+--R                               9 7                10 6  20
+--R               (- 8104181760A b c  - 9955639296B b  c )x
+--R             + 
+--R                               10 6                11 5  18
+--R               (- 9955639296A b  c  - 8859156480B b  c )x
+--R             + 
+--R                               11 5                12 4  16
+--R               (- 8859156480A b  c  - 5558501376B b  c )x
+--R             + 
+--R                               12 4                13 3  14
+--R               (- 5558501376A b  c  - 2332033024B b  c )x
+--R             + 
+--R                               13 3               14 2  12
+--R               (- 2332033024A b  c  - 587202560B b  c )x
+--R             + 
+--R                              14 2              15   10              15   8
+--R               (- 587202560A b  c  - 67108864B b  c)x   - 67108864A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                16 41         16            15  39
+--R           27B c  x   + (27A c   + 3357B b c  )x
+--R         + 
+--R                     15            2 14  37
+--R           (3357A b c   + 127845B b c  )x
+--R         + 
+--R                     2 14             3 13  35
+--R           (127845A b c   + 2340495B b c  )x
+--R         + 
+--R                      3 13              4 12  33
+--R           (2340495A b c   + 24957660B b c  )x
+--R         + 
+--R                       4 12               5 11  31
+--R           (24957660A b c   + 172042416B b c  )x
+--R         + 
+--R                        5 11               6 10  29
+--R           (172042416A b c   + 816592896B b c  )x
+--R         + 
+--R                        6 10                7 9  27
+--R           (816592896A b c   + 2777664000B b c )x
+--R         + 
+--R                         7 9                8 8  25
+--R           (2777664000A b c  + 6943242240B b c )x
+--R         + 
+--R                         8 8                 9 7  23
+--R           (6943242240A b c  + 12937052160B b c )x
+--R         + 
+--R                          9 7                 10 6  21
+--R           (12937052160A b c  + 18059821056B b  c )x
+--R         + 
+--R                          10 6                 11 5  19
+--R           (18059821056A b  c  + 18814795776B b  c )x
+--R         + 
+--R                          11 5                 12 4  17
+--R           (18814795776A b  c  + 14417657856B b  c )x
+--R         + 
+--R                          12 4                13 3  15
+--R           (14417657856A b  c  + 7890534400B b  c )x
+--R         + 
+--R                         13 3                14 2  13
+--R           (7890534400A b  c  + 2919235584B b  c )x
+--R         + 
+--R                         14 2               15   11
+--R           (2919235584A b  c  + 654311424B b  c)x
+--R         + 
+--R                        15               16  9              16 7
+--R           (654311424A b  c + 67108864B b  )x  + 67108864A b  x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R          17 42       17           16  40            16           2 15  38
+--R       B c  x   + (A c   + 367B b c  )x   + (367A b c   + 22935B b c  )x
+--R     + 
+--R                2 15            3 14  36             3 14             4 13  34
+--R       (22935A b c   + 579125B b c  )x   + (579125A b c   + 7826780B b c  )x
+--R     + 
+--R                  4 13              5 12  32
+--R       (7826780A b c   + 65037648B b c  )x
+--R     + 
+--R                   5 12               6 11  30
+--R       (65037648A b c   + 359996416B b c  )x
+--R     + 
+--R                    6 11                7 10  28
+--R       (359996416A b c   + 1394859520B b c  )x
+--R     + 
+--R                     7 10                8 9  26
+--R       (1394859520A b c   + 3902699520B b c )x
+--R     + 
+--R                     8 9                9 8  24
+--R       (3902699520A b c  + 8029880320B b c )x
+--R     + 
+--R                     9 8                 10 7  22
+--R       (8029880320A b c  + 12245598208B b  c )x
+--R     + 
+--R                      10 7                 11 6  20
+--R       (12245598208A b  c  + 13815054336B b  c )x
+--R     + 
+--R                      11 6                 12 5  18
+--R       (13815054336A b  c  + 11380981760B b  c )x
+--R     + 
+--R                      12 5                13 4  16
+--R       (11380981760A b  c  + 6655311872B b  c )x
+--R     + 
+--R                     13 4                14 3  14
+--R       (6655311872A b  c  + 2617245696B b  c )x
+--R     + 
+--R                     14 3               15 2  12
+--R       (2617245696A b  c  + 620756992B b  c )x
+--R     + 
+--R                    15 2              16   10              16   8
+--R       (620756992A b  c  + 67108864B b  c)x   + 67108864A b  c x
+--R  /
+--R                  14 28         13 26         2 12 24          3 11 22
+--R                 c  x   + 365b c  x   + 22204b c  x   + 534352b c  x
+--R               + 
+--R                         4 10 20            5 9 18             6 8 16
+--R                 6735872b c  x   + 51031552b c x   + 251197440b c x
+--R               + 
+--R                           7 7 14              8 6 12              9 5 10
+--R                 841433088b c x   + 1968635904b c x   + 3251175424b c x
+--R               + 
+--R                            10 4 8              11 3 6              12 2 4
+--R                 3774611456b  c x  + 3014656000b  c x  + 1577058304b  c x
+--R               + 
+--R                           13   2            14
+--R                 486539264b  c x  + 67108864b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                    14 27          13 25          2 12 23           3 11 21
+--R                 27c  x   + 3276b c  x   + 117936b c  x   + 1976832b c  x
+--R               + 
+--R                          4 10 19             5 9 17             6 8 15
+--R                 18670080b c  x   + 109983744b c x   + 428654592b c x
+--R               + 
+--R                            7 7 13              8 6 11              9 5 9
+--R                 1143078912b c x   + 2118057984b c x   + 2724986880b c x
+--R               + 
+--R                            10 4 7              11 3 5             12 2 3
+--R                 2387607552b  c x  + 1358954496b  c x  + 452984832b  c x
+--R               + 
+--R                          13
+--R                 67108864b  c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  14 28          13 26          2 12 24           3 11 22
+--R             - 27c  x   - 3303b c  x   - 121212b c  x   - 2094768b c  x
+--R           + 
+--R                        4 10 20             5 9 18             6 8 16
+--R             - 20646912b c  x   - 128653824b c x   - 538638336b c x
+--R           + 
+--R                          7 7 14              8 6 12              9 5 10
+--R             - 1571733504b c x   - 3261136896b c x   - 4843044864b c x
+--R           + 
+--R                          10 4 8              11 3 6              12 2 4
+--R             - 5112594432b  c x  - 3746562048b  c x  - 1811939328b  c x
+--R           + 
+--R                         13   2            14
+--R             - 520093696b  c x  - 67108864b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R            15 29         14 27         2 13 25          3 12 23
+--R         - c  x   - 365b c  x   - 22204b c  x   - 534352b c  x
+--R       + 
+--R                   4 11 21            5 10 19             6 9 17
+--R         - 6735872b c  x   - 51031552b c  x   - 251197440b c x
+--R       + 
+--R                     7 8 15              8 7 13              9 6 11
+--R         - 841433088b c x   - 1968635904b c x   - 3251175424b c x
+--R       + 
+--R                      10 5 9              11 4 7              12 3 5
+--R         - 3774611456b  c x  - 3014656000b  c x  - 1577058304b  c x
+--R       + 
+--R                     13 2 3            14
+--R         - 486539264b  c x  - 67108864b  c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       5 6          6 5  10            6 5           7 4  8
+--R               (2160A b c  - 1260B b c )x   + (50400A b c  - 29400B b c )x
+--R             + 
+--R                         7 4            8 3  6             8 3            9 2  4
+--R               (322560A b c  - 188160B b c )x  + (829440A b c  - 483840B b c )x
+--R             + 
+--R                         9 2            10   2            10             11
+--R               (921600A b c  - 537600B b  c)x  + 368640A b  c - 215040B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                        5 7         6 6  12              6 6          7 5  10
+--R               (- 180A b c  + 105B b c )x   + (- 12960A b c  + 7560B b c )x
+--R             + 
+--R                           7 5           8 4  8
+--R               (- 151200A b c  + 88200B b c )x
+--R             + 
+--R                           8 4            9 3  6
+--R               (- 645120A b c  + 376320B b c )x
+--R             + 
+--R                            9 3            10 2  4
+--R               (- 1244160A b c  + 725760B b  c )x
+--R             + 
+--R                            10 2            11   2            11             12
+--R               (- 1105920A b  c  + 645120B b  c)x  - 368640A b  c + 215040B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                         5 6          6 5  10               6 5           7 4  8
+--R               (- 4320A b c  + 2520B b c )x   + (- 100800A b c  + 58800B b c )x
+--R             + 
+--R                           7 4            8 3  6
+--R               (- 645120A b c  + 376320B b c )x
+--R             + 
+--R                            8 3            9 2  4
+--R               (- 1658880A b c  + 967680B b c )x
+--R             + 
+--R                            9 2             10   2            10             11
+--R               (- 1843200A b c  + 1075200B b  c)x  - 737280A b  c + 430080B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                      5 7         6 6  12            6 6           7 5  10
+--R               (360A b c  - 210B b c )x   + (25920A b c  - 15120B b c )x
+--R             + 
+--R                         7 5            8 4  8
+--R               (302400A b c  - 176400B b c )x
+--R             + 
+--R                          8 4            9 3  6
+--R               (1290240A b c  - 752640B b c )x
+--R             + 
+--R                          9 3             10 2  4
+--R               (2488320A b c  - 1451520B b  c )x
+--R             + 
+--R                          10 2             11   2            11             12
+--R               (2211840A b  c  - 1290240B b  c)x  + 737280A b  c - 430080B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                         10 20              10              9  18
+--R               - 15360B c  x   + (- 18432A c   - 378368B b c )x
+--R             + 
+--R                             9             2 8  16
+--R               (- 455424A b c  - 2760256B b c )x
+--R             + 
+--R                            2 8             3 7  14
+--R               (- 3345024A b c  - 8892896B b c )x
+--R             + 
+--R                             3 7              4 6  12
+--R               (- 10888032A b c  - 14292488B b c )x
+--R             + 
+--R                             4 6              5 5  10
+--R               (- 17737008A b c  - 11280292B b c )x
+--R             + 
+--R                             5 5             6 4  8
+--R               (- 14236896A b c  - 3491624B b c )x
+--R             + 
+--R                            6 4           7 3  6
+--R               (- 4586496A b c  + 54016B b c )x
+--R             + 
+--R                           7 3            8 2  4
+--R               (- 411648A b c  + 240128B b c )x
+--R             + 
+--R                           8 2            9   2            9             10
+--R               (- 675840A b c  + 394240B b c)x  - 368640A b c + 215040B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                      11 22           11             10  20
+--R               1280B c  x   + (1536A c   + 93824B b c  )x
+--R             + 
+--R                           10             2 9  18
+--R               (112704A b c   + 1195056B b c )x
+--R             + 
+--R                          2 9             3 8  16
+--R               (1442400A b c  + 5988680B b c )x
+--R             + 
+--R                          3 8              4 7  14
+--R               (7285896A b c  + 14847494B b c )x
+--R             + 
+--R                           4 7              5 6  12
+--R               (18258420A b c  + 19495815B b c )x
+--R             + 
+--R                           5 6              6 5  10
+--R               (24291552A b c  + 13027368B b c )x
+--R             + 
+--R                           6 5             7 4  8
+--R               (16506528A b c  + 3478392B b c )x
+--R             + 
+--R                          7 4            8 3  6
+--R               (4730880A b c  - 138240B b c )x
+--R             + 
+--R                         8 3            9 2  4             9 2            10   2
+--R               (703488A b c  - 410368B b c )x  + (860160A b c  - 501760B b  c)x
+--R             + 
+--R                        10             11
+--R               368640A b  c - 215040B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    11 23             11             10  21
+--R           - 1280B c  x   + (- 1536A c   - 93824B b c  )x
+--R         + 
+--R                         10             2 9  19
+--R           (- 112704A b c   - 1195056B b c )x
+--R         + 
+--R                        2 9             3 8  17
+--R           (- 1442400A b c  - 5988680B b c )x
+--R         + 
+--R                        3 8              4 7  15
+--R           (- 7285896A b c  - 14847494B b c )x
+--R         + 
+--R                         4 7              5 6  13
+--R           (- 18258420A b c  - 19495815B b c )x
+--R         + 
+--R                         5 6              6 5  11
+--R           (- 24291552A b c  - 13027368B b c )x
+--R         + 
+--R                         6 5             7 4  9
+--R           (- 16506528A b c  - 3478392B b c )x
+--R         + 
+--R                        7 4            8 3  7
+--R           (- 4730880A b c  + 138240B b c )x
+--R         + 
+--R                       8 3            9 2  5               9 2            10   3
+--R           (- 703488A b c  + 410368B b c )x  + (- 860160A b c  + 501760B b  c)x
+--R         + 
+--R                       10             11
+--R           (- 368640A b  c + 215040B b  )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                   11 23            11              10  21
+--R           15360B c  x   + (18432A c   + 393728B b c  )x
+--R         + 
+--R                       10             2 9  19
+--R           (473856A b c   + 3138624B b c )x
+--R         + 
+--R                      2 9              3 8  17
+--R           (3800448A b c  + 11653152B b c )x
+--R         + 
+--R                       3 8              4 7  15
+--R           (14233056A b c  + 23185384B b c )x
+--R         + 
+--R                       4 7              5 6  13
+--R           (28625040A b c  + 25572780B b c )x
+--R         + 
+--R                       5 6              6 5  11
+--R           (31973904A b c  + 14771916B b c )x
+--R         + 
+--R                       6 5             7 4  9              7 4            8 3  7
+--R           (18823392A b c  + 3437608B b c )x  + (4998144A b c  - 294144B b c )x
+--R         + 
+--R                      8 3            9 2  5              9 2            10   3
+--R           (1087488A b c  - 634368B b c )x  + (1044480A b c  - 609280B b  c)x
+--R         + 
+--R                     10             11
+--R           (368640A b  c - 215040B b  )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R                  9 10             8 8            2 7 6            3 6 4
+--R           184320c x   + 4300800b c x  + 27525120b c x  + 70778880b c x
+--R         + 
+--R                    4 5 2            5 4
+--R           78643200b c x  + 31457280b c
+--R      *
+--R                        +--------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|b \|c \|c x  + b
+--R     + 
+--R                   10 12             9 10            2 8 8            3 7 6
+--R           - 15360c  x   - 1105920b c x   - 12902400b c x  - 55050240b c x
+--R         + 
+--R                       4 6 4            5 5 2            6 4
+--R           - 106168320b c x  - 94371840b c x  - 31457280b c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 843
+
+--S 844 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      13 34           13            12  32
+--R               - 24B c  x   + (- 24A c   - 2336B b c  )x
+--R             + 
+--R                           12           2 11  30
+--R               (- 2336A b c   - 68664B b c  )x
+--R             + 
+--R                          2 11            3 10  28
+--R               (- 68664A b c   - 954096B b c  )x
+--R             + 
+--R                           3 10             4 9  26
+--R               (- 954096A b c   - 7568704B b c )x
+--R             + 
+--R                            4 9              5 8  24
+--R               (- 7568704A b c  - 37884288B b c )x
+--R             + 
+--R                             5 8               6 7  22
+--R               (- 37884288A b c  - 126738432B b c )x
+--R             + 
+--R                              6 7               7 6  20
+--R               (- 126738432A b c  - 292732928B b c )x
+--R             + 
+--R                              7 6               8 5  18
+--R               (- 292732928A b c  - 473628672B b c )x
+--R             + 
+--R                              8 5               9 4  16
+--R               (- 473628672A b c  - 535953408B b c )x
+--R             + 
+--R                              9 4               10 3  14
+--R               (- 535953408A b c  - 415760384B b  c )x
+--R             + 
+--R                              10 3               11 2  12
+--R               (- 415760384A b  c  - 210763776B b  c )x
+--R             + 
+--R                              11 2              12   10
+--R               (- 210763776A b  c  - 62914560B b  c)x
+--R             + 
+--R                             12              13  8             13 6
+--R               (- 62914560A b  c - 8388608B b  )x  - 8388608A b  x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              14 36       14           13  34            13           2 12  32
+--R           B c  x   + (A c   + 290B b c  )x   + (290A b c   + 14305B b c  )x
+--R         + 
+--R                    2 12            3 11  30
+--R           (14305A b c   + 284000B b c  )x
+--R         + 
+--R                     3 11             4 10  28
+--R           (284000A b c   + 2997280B b c  )x
+--R         + 
+--R                      4 10              5 9  26
+--R           (2997280A b c   + 19255808B b c )x
+--R         + 
+--R                       5 9              6 8  24
+--R           (19255808A b c  + 81278080B b c )x
+--R         + 
+--R                       6 8               7 7  22
+--R           (81278080A b c  + 235765760B b c )x
+--R         + 
+--R                        7 7               8 6  20
+--R           (235765760A b c  + 481853440B b c )x
+--R         + 
+--R                        8 6               9 5  18
+--R           (481853440A b c  + 700579840B b c )x
+--R         + 
+--R                        9 5               10 4  16
+--R           (700579840A b c  + 721092608B b  c )x
+--R         + 
+--R                        10 4               11 3  14
+--R           (721092608A b  c  + 513802240B b  c )x
+--R         + 
+--R                        11 3               12 2  12
+--R           (513802240A b  c  + 241172480B b  c )x
+--R         + 
+--R                        12 2              13   10
+--R           (241172480A b  c  + 67108864B b  c)x
+--R         + 
+--R                       13              14  8             14 6
+--R           (67108864A b  c + 8388608B b  )x  + 8388608A b  x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                14 37         14           13  35
+--R           - B c  x   + (- A c   - 290B b c  )x
+--R         + 
+--R                      13           2 12  33
+--R           (- 290A b c   - 14305B b c  )x
+--R         + 
+--R                      2 12            3 11  31
+--R           (- 14305A b c   - 284000B b c  )x
+--R         + 
+--R                       3 11             4 10  29
+--R           (- 284000A b c   - 2997280B b c  )x
+--R         + 
+--R                        4 10              5 9  27
+--R           (- 2997280A b c   - 19255808B b c )x
+--R         + 
+--R                         5 9              6 8  25
+--R           (- 19255808A b c  - 81278080B b c )x
+--R         + 
+--R                         6 8               7 7  23
+--R           (- 81278080A b c  - 235765760B b c )x
+--R         + 
+--R                          7 7               8 6  21
+--R           (- 235765760A b c  - 481853440B b c )x
+--R         + 
+--R                          8 6               9 5  19
+--R           (- 481853440A b c  - 700579840B b c )x
+--R         + 
+--R                          9 5               10 4  17
+--R           (- 700579840A b c  - 721092608B b  c )x
+--R         + 
+--R                          10 4               11 3  15
+--R           (- 721092608A b  c  - 513802240B b  c )x
+--R         + 
+--R                          11 3               12 2  13
+--R           (- 513802240A b  c  - 241172480B b  c )x
+--R         + 
+--R                          12 2              13   11
+--R           (- 241172480A b  c  - 67108864B b  c)x
+--R         + 
+--R                         13              14  9             14 7
+--R           (- 67108864A b  c - 8388608B b  )x  - 8388608A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                14 37         14            13  35
+--R           24B c  x   + (24A c   + 2360B b c  )x
+--R         + 
+--R                     13           2 12  33            2 12             3 11  31
+--R           (2360A b c   + 71000B b c  )x   + (71000A b c   + 1022760B b c  )x
+--R         + 
+--R                      3 11             4 10  29
+--R           (1022760A b c   + 8522800B b c  )x
+--R         + 
+--R                      4 10              5 9  27
+--R           (8522800A b c   + 45452992B b c )x
+--R         + 
+--R                       5 9               6 8  25
+--R           (45452992A b c  + 164622720B b c )x
+--R         + 
+--R                        6 8               7 7  23
+--R           (164622720A b c  + 419471360B b c )x
+--R         + 
+--R                        7 7               8 6  21
+--R           (419471360A b c  + 766361600B b c )x
+--R         + 
+--R                        8 6                9 5  19
+--R           (766361600A b c  + 1009582080B b c )x
+--R         + 
+--R                         9 5               10 4  17
+--R           (1009582080A b c  + 951713792B b  c )x
+--R         + 
+--R                        10 4               11 3  15
+--R           (951713792A b  c  + 626524160B b  c )x
+--R         + 
+--R                        11 3               12 2  13
+--R           (626524160A b  c  + 273678336B b  c )x
+--R         + 
+--R                        12 2              13   11
+--R           (273678336A b  c  + 71303168B b  c)x
+--R         + 
+--R                       13              14  9             14 7
+--R           (71303168A b  c + 8388608B b  )x  + 8388608A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              12 24         11 22         2 10 20          3 9 18
+--R             c  x   + 288b c  x   + 13728b c  x   + 256256b c x
+--R           + 
+--R                     4 8 16            5 7 14            6 6 12
+--R             2471040b c x   + 14057472b c x   + 50692096b c x
+--R           + 
+--R                       7 5 10             8 4 8             9 3 6
+--R             120324096b c x   + 190513152b c x  + 199229440b c x
+--R           + 
+--R                       10 2 4            11   2           12
+--R             132120576b  c x  + 50331648b  c x  + 8388608b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  12 24          11 22         2 10 20          3 9 18
+--R             - 24c  x   - 2312b c  x   - 66352b c  x   - 887744b c x
+--R           + 
+--R                       4 8 16            5 7 14            6 6 12
+--R             - 6680960b c x   - 31203328b c x   - 95535104b c x
+--R           + 
+--R                         7 5 10             8 4 8             9 3 6
+--R             - 197197824b c x   - 276430848b c x  - 259522560b c x
+--R           + 
+--R                         10 2 4            11   2           12
+--R             - 156237824b  c x  - 54525952b  c x  - 8388608b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 844
+
+)clear all
+
+--S 845 of 3139
+t0:=x^2*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                          +-----------+
+--R              8               6        4  |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 845
+
+--S 846 of 3139
+r0:=-8/3465*b^2*(6*b*B-11*A*c)*(b*x^2+c*x^4)^(5/2)/(c^4*x^5)+_
+   4/693*b*(6*b*B-11*A*c)*(b*x^2+c*x^4)^(5/2)/(c^3*x^3)-_
+   1/99*(6*b*B-11*A*c)*(b*x^2+c*x^4)^(5/2)/(c^2*x)+_
+   1/11*B*x*(b*x^2+c*x^4)^(5/2)/c
+--R 
+--R
+--R   (2)
+--R               5 10          5           4  8            4        2 3  6
+--R         315B c x   + (385A c  + 420B b c )x  + (550A b c  + 15B b c )x
+--R       + 
+--R               2 3        3 2  4           3 2        4   2        4         5
+--R         (33A b c  - 18B b c )x  + (- 44A b c  + 24B b c)x  + 88A b c - 48B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R          4
+--R     3465c x
+--R                                                    Type: Expression(Integer)
+--E 846
+
+--S 847 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      6 20               6           2 5  18
+--R           - 3465B b c x   + (- 4235A b c  - 73920B b c )x
+--R         + 
+--R                      2 5            3 4  16
+--R           (- 90750A b c  - 480645B b c )x
+--R         + 
+--R                       3 4             4 3  14
+--R           (- 595683A b c  - 1407582B b c )x
+--R         + 
+--R                        4 3             5 2  12
+--R           (- 1768536A b c  - 2084544B b c )x
+--R         + 
+--R                        5 2             6   10                6             7  8
+--R           (- 2664816A b c  - 1530144B b c)x   + (- 1995840A b c - 443520B b )x
+--R         + 
+--R                      7 6
+--R           - 591360A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                 7 22          7             6  20
+--R           315B c x   + (385A c  + 19635B b c )x
+--R         + 
+--R                      6            2 5  18             2 5             3 4  16
+--R           (24035A b c  + 220935B b c )x   + (272283A b c  + 1002177B b c )x
+--R         + 
+--R                      3 4             4 3  14
+--R           (1248489A b c  + 2286306B b c )x
+--R         + 
+--R                      4 3             5 2  12
+--R           (2888424A b c  + 2794176B b c )x
+--R         + 
+--R                      5 2             6   10              6             7  8
+--R           (3588816A b c  + 1751904B b c)x   + (2291520A b c + 443520B b )x
+--R         + 
+--R                    7 6
+--R           591360A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                5 10            4 8           2 3 6           3 2 4
+--R           3465c x   + 207900b c x  + 1940400b c x  + 6209280b c x
+--R         + 
+--R                   4   2           5
+--R           7983360b c x  + 3548160b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                 5 10          2 4 8           3 3 6           4 2 4
+--R       - 38115b c x   - 762300b c x  - 4268880b c x  - 9757440b c x
+--R     + 
+--R                 5   2           6
+--R       - 9757440b c x  - 3548160b
+--R                                         Type: Union(Expression(Integer),...)
+--E 847
+
+--S 848 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       10 20            10             9  18
+--R               - 315B c  x   + (- 385A c   - 19320B b c )x
+--R             + 
+--R                            9            2 8  16
+--R               (- 23650A b c  - 201615B b c )x
+--R             + 
+--R                           2 8            3 7  14
+--R               (- 248633A b c  - 800562B b c )x
+--R             + 
+--R                           3 7             4 6  12
+--R               (- 999856A b c  - 1485744B b c )x
+--R             + 
+--R                            4 6             5 5  10
+--R               (- 1888568A b c  - 1308432B b c )x
+--R             + 
+--R                            5 5            6 4  8
+--R               (- 1701216A b c  - 442944B b c )x
+--R             + 
+--R                           6 4          7 3  6              7 3           8 2  4
+--R               (- 609664A b c  + 9984B b c )x  + (- 90112A b c  + 49152B b c )x
+--R             + 
+--R                           8 2           9   2           9            10
+--R               (- 157696A b c  + 86016B b c)x  - 90112A b c + 49152B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                    10 20             10           2 9  18
+--R           3465B b c  x   + (4235A b c   + 73920B b c )x
+--R         + 
+--R                    2 9            3 8  16             3 8             4 7  14
+--R           (90750A b c  + 480645B b c )x   + (595683A b c  + 1407582B b c )x
+--R         + 
+--R                      4 7             5 6  12
+--R           (1768536A b c  + 2084544B b c )x
+--R         + 
+--R                      5 6             6 5  10              6 5            7 4  8
+--R           (2664904A b c  + 1530096B b c )x   + (2001120A b c  + 440640B b c )x
+--R         + 
+--R                     7 4           8 3  6             8 3           9 2  4
+--R           (640640A b c  - 26880B b c )x  + (157696A b c  - 86016B b c )x
+--R         + 
+--R                     9 2            10   2           10            11
+--R           (202752A b c  - 110592B b  c)x  + 90112A b  c - 49152B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                      10 21               10           2 9  19
+--R           - 3465B b c  x   + (- 4235A b c   - 73920B b c )x
+--R         + 
+--R                      2 9            3 8  17
+--R           (- 90750A b c  - 480645B b c )x
+--R         + 
+--R                       3 8             4 7  15
+--R           (- 595683A b c  - 1407582B b c )x
+--R         + 
+--R                        4 7             5 6  13
+--R           (- 1768536A b c  - 2084544B b c )x
+--R         + 
+--R                        5 6             6 5  11
+--R           (- 2664816A b c  - 1530144B b c )x
+--R         + 
+--R                        6 5            7 4  9            7 4 7
+--R           (- 1995840A b c  - 443520B b c )x  - 591360A b c x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                 11 23          11             10  21
+--R           315B c  x   + (385A c   + 19635B b c  )x
+--R         + 
+--R                      10            2 9  19             2 9             3 8  17
+--R           (24035A b c   + 220935B b c )x   + (272283A b c  + 1002177B b c )x
+--R         + 
+--R                      3 8             4 7  15
+--R           (1248489A b c  + 2286306B b c )x
+--R         + 
+--R                      4 7             5 6  13
+--R           (2888424A b c  + 2794176B b c )x
+--R         + 
+--R                      5 6             6 5  11              6 5            7 4  9
+--R           (3588816A b c  + 1751904B b c )x   + (2291520A b c  + 443520B b c )x
+--R         + 
+--R                    7 4 7
+--R           591360A b c x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                9 11            8 9           2 7 7           3 6 5
+--R           3465c x   + 207900b c x  + 1940400b c x  + 6209280b c x
+--R         + 
+--R                   4 5 3           5 4
+--R           7983360b c x  + 3548160b c x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                 9 11          2 8 9           3 7 7           4 6 5
+--R       - 38115b c x   - 762300b c x  - 4268880b c x  - 9757440b c x
+--R     + 
+--R                 5 5 3           6 4
+--R       - 9757440b c x  - 3548160b c x
+--R                                                    Type: Expression(Integer)
+--E 848
+
+--S 849 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      12 31           12            11  29
+--R               - 22B c  x   + (- 22A c   - 1804B b c  )x
+--R             + 
+--R                           11           2 10  27
+--R               (- 1804A b c   - 44726B b c  )x
+--R             + 
+--R                          2 10            3 9  25
+--R               (- 44726A b c   - 523424B b c )x
+--R             + 
+--R                           3 9             4 8  23
+--R               (- 523424A b c  - 3482336B b c )x
+--R             + 
+--R                            4 8              5 7  21
+--R               (- 3482336A b c  - 14510080B b c )x
+--R             + 
+--R                             5 7              6 6  19
+--R               (- 14510080A b c  - 39950848B b c )x
+--R             + 
+--R                             6 6              7 5  17
+--R               (- 39950848A b c  - 74678272B b c )x
+--R             + 
+--R                             7 5              8 4  15
+--R               (- 74678272A b c  - 95387648B b c )x
+--R             + 
+--R                             8 4              9 3  13
+--R               (- 95387648A b c  - 82051072B b c )x
+--R             + 
+--R                             9 3              10 2  11
+--R               (- 82051072A b c  - 45481984B b  c )x
+--R             + 
+--R                             10 2              11   9
+--R               (- 45481984A b  c  - 14680064B b  c)x
+--R             + 
+--R                             11              12  7             12 5
+--R               (- 14680064A b  c - 2097152B b  )x  - 2097152A b  x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              13 33       13           12  31            12           2 11  29
+--R           B c  x   + (A c   + 244B b c  )x   + (244A b c   + 10165B b c  )x
+--R         + 
+--R                    2 11            3 10  27
+--R           (10165A b c   + 170610B b c  )x
+--R         + 
+--R                     3 10             4 9  25
+--R           (170610A b c   + 1519760B b c )x
+--R         + 
+--R                      4 9             5 8  23
+--R           (1519760A b c  + 8204768B b c )x
+--R         + 
+--R                      5 8              6 7  21
+--R           (8204768A b c  + 28883712B b c )x
+--R         + 
+--R                       6 7              7 6  19
+--R           (28883712A b c  + 69076480B b c )x
+--R         + 
+--R                       7 6               8 5  17
+--R           (69076480A b c  + 114442240B b c )x
+--R         + 
+--R                        8 5               9 4  15
+--R           (114442240A b c  + 131563520B b c )x
+--R         + 
+--R                        9 4               10 3  13
+--R           (131563520A b c  + 103088128B b  c )x
+--R         + 
+--R                        10 3              11 2  11
+--R           (103088128A b  c  + 52559872B b  c )x
+--R         + 
+--R                       11 2              12   9
+--R           (52559872A b  c  + 15728640B b  c)x
+--R         + 
+--R                       12              13  7             13 5
+--R           (15728640A b  c + 2097152B b  )x  + 2097152A b  x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                13 34         13           12  32
+--R           - B c  x   + (- A c   - 244B b c  )x
+--R         + 
+--R                      12           2 11  30
+--R           (- 244A b c   - 10165B b c  )x
+--R         + 
+--R                      2 11            3 10  28
+--R           (- 10165A b c   - 170610B b c  )x
+--R         + 
+--R                       3 10             4 9  26
+--R           (- 170610A b c   - 1519760B b c )x
+--R         + 
+--R                        4 9             5 8  24
+--R           (- 1519760A b c  - 8204768B b c )x
+--R         + 
+--R                        5 8              6 7  22
+--R           (- 8204768A b c  - 28883712B b c )x
+--R         + 
+--R                         6 7              7 6  20
+--R           (- 28883712A b c  - 69076480B b c )x
+--R         + 
+--R                         7 6               8 5  18
+--R           (- 69076480A b c  - 114442240B b c )x
+--R         + 
+--R                          8 5               9 4  16
+--R           (- 114442240A b c  - 131563520B b c )x
+--R         + 
+--R                          9 4               10 3  14
+--R           (- 131563520A b c  - 103088128B b  c )x
+--R         + 
+--R                          10 3              11 2  12
+--R           (- 103088128A b  c  - 52559872B b  c )x
+--R         + 
+--R                         11 2              12   10
+--R           (- 52559872A b  c  - 15728640B b  c)x
+--R         + 
+--R                         12              13  8             13 6
+--R           (- 15728640A b  c - 2097152B b  )x  - 2097152A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                13 34         13            12  32
+--R           22B c  x   + (22A c   + 1826B b c  )x
+--R         + 
+--R                     12           2 11  30            2 11            3 10  28
+--R           (1826A b c   + 46530B b c  )x   + (46530A b c   + 568150B b c  )x
+--R         + 
+--R                     3 10             4 9  26
+--R           (568150A b c   + 4005760B b c )x
+--R         + 
+--R                      4 9              5 8  24
+--R           (4005760A b c  + 17992416B b c )x
+--R         + 
+--R                       5 8              6 7  22
+--R           (17992416A b c  + 54460928B b c )x
+--R         + 
+--R                       6 7               7 6  20
+--R           (54460928A b c  + 114629120B b c )x
+--R         + 
+--R                        7 6               8 5  18
+--R           (114629120A b c  + 170065920B b c )x
+--R         + 
+--R                        8 5               9 4  16
+--R           (170065920A b c  + 177438720B b c )x
+--R         + 
+--R                        9 4               10 3  14
+--R           (177438720A b c  + 127533056B b  c )x
+--R         + 
+--R                        10 3              11 2  12
+--R           (127533056A b  c  + 60162048B b  c )x
+--R         + 
+--R                       11 2              12   10
+--R           (60162048A b  c  + 16777216B b  c)x
+--R         + 
+--R                       12              13  8             13 6
+--R           (16777216A b  c + 2097152B b  )x  + 2097152A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              11 22         10 20        2 9 18          3 8 16           4 7 14
+--R             c  x   + 242b c  x   + 9680b c x   + 151008b c x   + 1208064b c x
+--R           + 
+--R                     5 6 12            6 5 10            7 4 8            8 3 6
+--R             5637632b c x   + 16400384b c x   + 30638080b c x  + 36765696b c x
+--R           + 
+--R                      9 2 4            10   2           11
+--R             27394048b c x  + 11534336b  c x  + 2097152b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  11 22          10 20         2 9 18          3 8 16
+--R             - 22c  x   - 1782b c  x   - 42944b c x   - 480480b c x
+--R           + 
+--R                       4 7 14            5 6 12            6 5 10
+--R             - 3001856b c x   - 11508224b c x   - 28442624b c x
+--R           + 
+--R                        7 4 8            8 3 6            9 2 4
+--R             - 46235648b c x  - 49152000b c x  - 32899072b c x
+--R           + 
+--R                        10   2           11
+--R             - 12582912b  c x  - 2097152b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 849
+
+)clear all
+
+--S 850 of 3139
+t0:=x*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                          +-----------+
+--R              7               5        3  |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 850
+
+--S 851 of 3139
+r0:=-1/16*(b*B-2*A*c)*x^2*(b*x^2+c*x^4)^(3/2)/c+1/10*B*(b*x^2+_
+   c*x^4)^(5/2)/c-3/256*b^4*(b*B-2*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+_
+   c*x^4))/c^(7/2)+3/256*b^3*(b*B-2*A*c)*sqrt(b*x^2+c*x^4)/c^3-_
+   1/128*b^2*(b*B-2*A*c)*x^2*sqrt(b*x^2+c*x^4)/c^2-1/32*b*(b*B-2*A*c)*_
+   x^4*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                    2 +-+
+--R             4         5           x \|c
+--R       (30A b c - 15B b )atanh(--------------)
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R     + 
+--R                 4 8          4           3  6            3       2 2  4
+--R           128B c x  + (160A c  + 176B b c )x  + (240A b c  + 8B b c )x
+--R         + 
+--R                 2 2        3   2        3         4
+--R           (20A b c  - 10B b c)x  - 30A b c + 15B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R          3 +-+
+--R     1280c \|c
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        4 5         5 4  8           5 4          6 3  6
+--R                 (300A b c  - 150B b c )x  + (4800A b c  - 2400B b c )x
+--R               + 
+--R                          6 3           7 2  4            7 2           8   2
+--R                 (20160A b c  - 10080B b c )x  + (30720A b c  - 15360B b c)x
+--R               + 
+--R                         8           9
+--R                 15360A b c - 7680B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     4 6        5 5  10             5 5         6 4  8
+--R             (- 30A b c  + 15B b c )x   + (- 1500A b c  + 750B b c )x
+--R           + 
+--R                        6 4          7 3  6              7 3           8 2  4
+--R             (- 12000A b c  + 6000B b c )x  + (- 33600A b c  + 16800B b c )x
+--R           + 
+--R                        8 2           9   2           9           10
+--R             (- 38400A b c  + 19200B b c)x  - 15360A b c + 7680B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                     9 19            9            8  17
+--R             - 128B c x   + (- 160A c  - 6576B b c )x
+--R           + 
+--R                         8           2 7  15              2 7            3 6  13
+--R             (- 8240A b c  - 60008B b c )x   + (- 76020A b c  - 214150B b c )x
+--R           + 
+--R                         3 6            4 5  11
+--R             (- 276170A b c  - 363675B b c )x
+--R           + 
+--R                         4 5            5 4  9
+--R             (- 480100A b c  - 296526B b c )x
+--R           + 
+--R                         5 4           6 3  7               6 3          7 2  5
+--R             (- 399520A b c  - 95152B b c )x  + (- 114880A b c  - 8096B b c )x
+--R           + 
+--R                      7 2           8   3            8           9
+--R             (28160A b c  - 14080B b c)x  + (15360A b c - 7680B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                    9 19           9             8  17
+--R             1280B c x   + (1600A c  + 23520B b c )x
+--R           + 
+--R                        8            2 7  15             2 7            3 6  13
+--R             (29600A b c  + 136496B b c )x   + (174120A b c  + 364780B b c )x
+--R           + 
+--R                       3 6            4 5  11             4 5            5 4  9
+--R             (474140A b c  + 500210B b c )x   + (664340A b c  + 343670B b c )x
+--R           + 
+--R                       5 4           6 3  7             6 3           7 2  5
+--R             (459520A b c  + 97920B b c )x  + (102720A b c  + 14176B b c )x
+--R           + 
+--R                        7 2           8   3              8           9
+--R             (- 35840A b c  + 17920B b c)x  + (- 15360A b c + 7680B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                     7 8            6 6          2 5 4           3 4 2
+--R               12800c x  + 204800b c x  + 860160b c x  + 1310720b c x
+--R             + 
+--R                      4 3
+--R               655360b c
+--R        *
+--R                    +--------+
+--R            +-+ +-+ |   2
+--R           \|b \|c \|c x  + b
+--R       + 
+--R                    8 10           7 8          2 6 6           3 5 4
+--R             - 1280c x   - 64000b c x  - 512000b c x  - 1433600b c x
+--R           + 
+--R                       4 4 2          5 3
+--R             - 1638400b c x  - 655360b c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                        4 5         5 4  8           5 4          6 3  6
+--R                 (600A b c  - 300B b c )x  + (9600A b c  - 4800B b c )x
+--R               + 
+--R                          6 3           7 2  4            7 2           8   2
+--R                 (40320A b c  - 20160B b c )x  + (61440A b c  - 30720B b c)x
+--R               + 
+--R                         8            9
+--R                 30720A b c - 15360B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     4 6        5 5  10             5 5          6 4  8
+--R             (- 60A b c  + 30B b c )x   + (- 3000A b c  + 1500B b c )x
+--R           + 
+--R                        6 4           7 3  6              7 3           8 2  4
+--R             (- 24000A b c  + 12000B b c )x  + (- 67200A b c  + 33600B b c )x
+--R           + 
+--R                        8 2           9   2           9            10
+--R             (- 76800A b c  + 38400B b c)x  - 30720A b c + 15360B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                     9 19            9            8  17
+--R             - 128B c x   + (- 160A c  - 6576B b c )x
+--R           + 
+--R                         8           2 7  15              2 7            3 6  13
+--R             (- 8240A b c  - 60008B b c )x   + (- 76020A b c  - 214150B b c )x
+--R           + 
+--R                         3 6            4 5  11
+--R             (- 276170A b c  - 363675B b c )x
+--R           + 
+--R                         4 5            5 4  9
+--R             (- 480100A b c  - 296526B b c )x
+--R           + 
+--R                         5 4           6 3  7               6 3          7 2  5
+--R             (- 399520A b c  - 95152B b c )x  + (- 114880A b c  - 8096B b c )x
+--R           + 
+--R                      7 2           8   3            8           9
+--R             (28160A b c  - 14080B b c)x  + (15360A b c - 7680B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                    9 19           9             8  17
+--R             1280B c x   + (1600A c  + 23520B b c )x
+--R           + 
+--R                        8            2 7  15             2 7            3 6  13
+--R             (29600A b c  + 136496B b c )x   + (174120A b c  + 364780B b c )x
+--R           + 
+--R                       3 6            4 5  11             4 5            5 4  9
+--R             (474140A b c  + 500210B b c )x   + (664340A b c  + 343670B b c )x
+--R           + 
+--R                       5 4           6 3  7             6 3           7 2  5
+--R             (459520A b c  + 97920B b c )x  + (102720A b c  + 14176B b c )x
+--R           + 
+--R                        7 2           8   3              8           9
+--R             (- 35840A b c  + 17920B b c)x  + (- 15360A b c + 7680B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                     7 8            6 6          2 5 4           3 4 2
+--R               12800c x  + 204800b c x  + 860160b c x  + 1310720b c x
+--R             + 
+--R                      4 3
+--R               655360b c
+--R        *
+--R                      +--------+
+--R            +---+ +-+ |   2
+--R           \|- c \|b \|c x  + b
+--R       + 
+--R                    8 10           7 8          2 6 6           3 5 4
+--R             - 1280c x   - 64000b c x  - 512000b c x  - 1433600b c x
+--R           + 
+--R                       4 4 2          5 3
+--R             - 1638400b c x  - 655360b c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 852
+
+--S 853 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      4 5         5 4  8           5 4          6 3  6
+--R               (300A b c  - 150B b c )x  + (4800A b c  - 2400B b c )x
+--R             + 
+--R                        6 3           7 2  4            7 2           8   2
+--R               (20160A b c  - 10080B b c )x  + (30720A b c  - 15360B b c)x
+--R             + 
+--R                       8           9
+--R               15360A b c - 7680B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   4 6        5 5  10             5 5         6 4  8
+--R           (- 30A b c  + 15B b c )x   + (- 1500A b c  + 750B b c )x
+--R         + 
+--R                      6 4          7 3  6              7 3           8 2  4
+--R           (- 12000A b c  + 6000B b c )x  + (- 33600A b c  + 16800B b c )x
+--R         + 
+--R                      8 2           9   2           9           10
+--R           (- 38400A b c  + 19200B b c)x  - 15360A b c + 7680B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                        4 5         5 4  8             5 4          6 3  6
+--R               (- 300A b c  + 150B b c )x  + (- 4800A b c  + 2400B b c )x
+--R             + 
+--R                          6 3           7 2  4              7 2           8   2
+--R               (- 20160A b c  + 10080B b c )x  + (- 30720A b c  + 15360B b c)x
+--R             + 
+--R                         8           9
+--R               - 15360A b c + 7680B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                 4 6        5 5  10           5 5         6 4  8
+--R           (30A b c  - 15B b c )x   + (1500A b c  - 750B b c )x
+--R         + 
+--R                    6 4          7 3  6            7 3           8 2  4
+--R           (12000A b c  - 6000B b c )x  + (33600A b c  - 16800B b c )x
+--R         + 
+--R                    8 2           9   2           9           10
+--R           (38400A b c  - 19200B b c)x  + 15360A b c - 7680B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                        8 16             8             7  14
+--R               - 1280B c x   + (- 1600A c  - 22240B b c )x
+--R             + 
+--R                            7            2 6  12
+--R               (- 28000A b c  - 114256B b c )x
+--R             + 
+--R                           2 6            3 5  10
+--R               (- 146120A b c  - 250524B b c )x
+--R             + 
+--R                           3 5            4 4  8
+--R               (- 328020A b c  - 249686B b c )x
+--R             + 
+--R                           4 4           5 3  6
+--R               (- 336320A b c  - 93984B b c )x
+--R             + 
+--R                           5 3          6 2  4            6 2           7   2
+--R               (- 123200A b c  - 3936B b c )x  + (20480A b c  - 10240B b c)x
+--R             + 
+--R                       7           8
+--R               15360A b c - 7680B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                     9 18          9            8  16
+--R               128B c x   + (160A c  + 6576B b c )x
+--R             + 
+--R                         8           2 7  14            2 7            3 6  12
+--R               (8240A b c  + 60008B b c )x   + (76020A b c  + 214150B b c )x
+--R             + 
+--R                         3 6            4 5  10
+--R               (276170A b c  + 363675B b c )x
+--R             + 
+--R                         4 5            5 4  8             5 4           6 3  6
+--R               (480100A b c  + 296526B b c )x  + (399520A b c  + 95152B b c )x
+--R             + 
+--R                         6 3          7 2  4              7 2           8   2
+--R               (114880A b c  + 8096B b c )x  + (- 28160A b c  + 14080B b c)x
+--R             + 
+--R                         8           9
+--R               - 15360A b c + 7680B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                   9 19            9            8  17
+--R           - 128B c x   + (- 160A c  - 6576B b c )x
+--R         + 
+--R                       8           2 7  15              2 7            3 6  13
+--R           (- 8240A b c  - 60008B b c )x   + (- 76020A b c  - 214150B b c )x
+--R         + 
+--R                       3 6            4 5  11
+--R           (- 276170A b c  - 363675B b c )x
+--R         + 
+--R                       4 5            5 4  9               5 4           6 3  7
+--R           (- 480100A b c  - 296526B b c )x  + (- 399520A b c  - 95152B b c )x
+--R         + 
+--R                       6 3          7 2  5            7 2           8   3
+--R           (- 114880A b c  - 8096B b c )x  + (28160A b c  - 14080B b c)x
+--R         + 
+--R                    8           9
+--R           (15360A b c - 7680B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                  9 19           9             8  17
+--R           1280B c x   + (1600A c  + 23520B b c )x
+--R         + 
+--R                      8            2 7  15             2 7            3 6  13
+--R           (29600A b c  + 136496B b c )x   + (174120A b c  + 364780B b c )x
+--R         + 
+--R                     3 6            4 5  11             4 5            5 4  9
+--R           (474140A b c  + 500210B b c )x   + (664340A b c  + 343670B b c )x
+--R         + 
+--R                     5 4           6 3  7             6 3           7 2  5
+--R           (459520A b c  + 97920B b c )x  + (102720A b c  + 14176B b c )x
+--R         + 
+--R                      7 2           8   3              8           9
+--R           (- 35840A b c  + 17920B b c)x  + (- 15360A b c + 7680B b )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                7 8            6 6          2 5 4           3 4 2          4 3
+--R         (12800c x  + 204800b c x  + 860160b c x  + 1310720b c x  + 655360b c )
+--R      *
+--R                  +--------+
+--R          +-+ +-+ |   2
+--R         \|b \|c \|c x  + b
+--R     + 
+--R                  8 10           7 8          2 6 6           3 5 4
+--R           - 1280c x   - 64000b c x  - 512000b c x  - 1433600b c x
+--R         + 
+--R                     4 4 2          5 3
+--R           - 1638400b c x  - 655360b c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 853
+
+--S 854 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          13 32           13            12  30
+--R                   - 23B c  x   + (- 23A c   - 2070B b c  )x
+--R                 + 
+--R                               12           2 11  28
+--R                   (- 2070A b c   - 56695B b c  )x
+--R                 + 
+--R                              2 11            3 10  26
+--R                   (- 56695A b c   - 738760B b c  )x
+--R                 + 
+--R                               3 10             4 9  24
+--R                   (- 738760A b c   - 5525520B b c )x
+--R                 + 
+--R                                4 9              5 8  22
+--R                   (- 5525520A b c  - 26197184B b c )x
+--R                 + 
+--R                                 5 8              6 7  20
+--R                   (- 26197184A b c  - 83344640B b c )x
+--R                 + 
+--R                                 6 7               7 6  18
+--R                   (- 83344640A b c  - 183705600B b c )x
+--R                 + 
+--R                                  7 6               8 5  16
+--R                   (- 183705600A b c  - 284508160B b c )x
+--R                 + 
+--R                                  8 5               9 4  14
+--R                   (- 284508160A b c  - 309002240B b c )x
+--R                 + 
+--R                                  9 4               10 3  12
+--R                   (- 309002240A b c  - 230621184B b  c )x
+--R                 + 
+--R                                  10 3               11 2  10
+--R                   (- 230621184A b  c  - 112721920B b  c )x
+--R                 + 
+--R                                  11 2              12   8
+--R                   (- 112721920A b  c  - 32505856B b  c)x
+--R                 + 
+--R                                 12              13  6             13 4
+--R                   (- 32505856A b  c - 4194304B b  )x  - 4194304A b  x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  14 33       14           13  31
+--R               B c  x   + (A c   + 266B b c  )x
+--R             + 
+--R                        13           2 12  29
+--R               (266A b c   + 11969B b c  )x
+--R             + 
+--R                        2 12            3 11  27
+--R               (11969A b c   + 215336B b c  )x
+--R             + 
+--R                         3 11             4 10  25
+--R               (215336A b c   + 2043184B b c  )x
+--R             + 
+--R                          4 10              5 9  23
+--R               (2043184A b c   + 11687104B b c )x
+--R             + 
+--R                           5 9              6 8  21
+--R               (11687104A b c  + 43393792B b c )x
+--R             + 
+--R                           6 8               7 7  19
+--R               (43393792A b c  + 109027328B b c )x
+--R             + 
+--R                            7 7               8 6  17
+--R               (109027328A b c  + 189120512B b c )x
+--R             + 
+--R                            8 6               9 5  15
+--R               (189120512A b c  + 226951168B b c )x
+--R             + 
+--R                            9 5               10 4  13
+--R               (226951168A b c  + 185139200B b  c )x
+--R             + 
+--R                            10 4              11 3  11
+--R               (185139200A b  c  + 98041856B b  c )x
+--R             + 
+--R                           11 3              12 2  9
+--R               (98041856A b  c  + 30408704B b  c )x
+--R             + 
+--R                           12 2             13   7             13   5
+--R               (30408704A b  c  + 4194304B b  c)x  + 4194304A b  c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  14 34       14           13  32
+--R               B c  x   + (A c   + 267B b c  )x
+--R             + 
+--R                        13           2 12  30
+--R               (267A b c   + 12235B b c  )x
+--R             + 
+--R                        2 12            3 11  28
+--R               (12235A b c   + 227305B b c  )x
+--R             + 
+--R                         3 11             4 10  26
+--R               (227305A b c   + 2258520B b c  )x
+--R             + 
+--R                          4 10              5 9  24
+--R               (2258520A b c   + 13730288B b c )x
+--R             + 
+--R                           5 9              6 8  22
+--R               (13730288A b c  + 55080896B b c )x
+--R             + 
+--R                           6 8               7 7  20
+--R               (55080896A b c  + 152421120B b c )x
+--R             + 
+--R                            7 7               8 6  18
+--R               (152421120A b c  + 298147840B b c )x
+--R             + 
+--R                            8 6               9 5  16
+--R               (298147840A b c  + 416071680B b c )x
+--R             + 
+--R                            9 5               10 4  14
+--R               (416071680A b c  + 412090368B b  c )x
+--R             + 
+--R                            10 4               11 3  12
+--R               (412090368A b  c  + 283181056B b  c )x
+--R             + 
+--R                            11 3               12 2  10
+--R               (283181056A b  c  + 128450560B b  c )x
+--R             + 
+--R                            12 2              13   8
+--R               (128450560A b  c  + 34603008B b  c)x
+--R             + 
+--R                           13              14  6             14 4
+--R               (34603008A b  c + 4194304B b  )x  + 4194304A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      14 33           14            13  31
+--R               - 23B c  x   + (- 23A c   - 2070B b c  )x
+--R             + 
+--R                           13           2 12  29
+--R               (- 2070A b c   - 56695B b c  )x
+--R             + 
+--R                          2 12            3 11  27
+--R               (- 56695A b c   - 738760B b c  )x
+--R             + 
+--R                           3 11             4 10  25
+--R               (- 738760A b c   - 5525520B b c  )x
+--R             + 
+--R                            4 10              5 9  23
+--R               (- 5525520A b c   - 26197184B b c )x
+--R             + 
+--R                             5 9              6 8  21
+--R               (- 26197184A b c  - 83344640B b c )x
+--R             + 
+--R                             6 8               7 7  19
+--R               (- 83344640A b c  - 183705600B b c )x
+--R             + 
+--R                              7 7               8 6  17
+--R               (- 183705600A b c  - 284508160B b c )x
+--R             + 
+--R                              8 6               9 5  15
+--R               (- 284508160A b c  - 309002240B b c )x
+--R             + 
+--R                              9 5               10 4  13
+--R               (- 309002240A b c  - 230621184B b  c )x
+--R             + 
+--R                              10 4               11 3  11
+--R               (- 230621184A b  c  - 112721920B b  c )x
+--R             + 
+--R                              11 3              12 2  9
+--R               (- 112721920A b  c  - 32505856B b  c )x
+--R             + 
+--R                             12 2             13   7             13   5
+--R               (- 32505856A b  c  - 4194304B b  c)x  - 4194304A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    14 35         14           13  33
+--R               - B c  x   + (- A c   - 267B b c  )x
+--R             + 
+--R                          13           2 12  31
+--R               (- 267A b c   - 12235B b c  )x
+--R             + 
+--R                          2 12            3 11  29
+--R               (- 12235A b c   - 227305B b c  )x
+--R             + 
+--R                           3 11             4 10  27
+--R               (- 227305A b c   - 2258520B b c  )x
+--R             + 
+--R                            4 10              5 9  25
+--R               (- 2258520A b c   - 13730288B b c )x
+--R             + 
+--R                             5 9              6 8  23
+--R               (- 13730288A b c  - 55080896B b c )x
+--R             + 
+--R                             6 8               7 7  21
+--R               (- 55080896A b c  - 152421120B b c )x
+--R             + 
+--R                              7 7               8 6  19
+--R               (- 152421120A b c  - 298147840B b c )x
+--R             + 
+--R                              8 6               9 5  17
+--R               (- 298147840A b c  - 416071680B b c )x
+--R             + 
+--R                              9 5               10 4  15
+--R               (- 416071680A b c  - 412090368B b  c )x
+--R             + 
+--R                              10 4               11 3  13
+--R               (- 412090368A b  c  - 283181056B b  c )x
+--R             + 
+--R                              11 3               12 2  11
+--R               (- 283181056A b  c  - 128450560B b  c )x
+--R             + 
+--R                              12 2              13   9
+--R               (- 128450560A b  c  - 34603008B b  c)x
+--R             + 
+--R                             13              14  7             14 5
+--R               (- 34603008A b  c - 4194304B b  )x  - 4194304A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    14 34         14            13  32
+--R               23B c  x   + (23A c   + 2070B b c  )x
+--R             + 
+--R                         13           2 12  30
+--R               (2070A b c   + 56695B b c  )x
+--R             + 
+--R                        2 12            3 11  28
+--R               (56695A b c   + 738760B b c  )x
+--R             + 
+--R                         3 11             4 10  26
+--R               (738760A b c   + 5525520B b c  )x
+--R             + 
+--R                          4 10              5 9  24
+--R               (5525520A b c   + 26197184B b c )x
+--R             + 
+--R                           5 9              6 8  22
+--R               (26197184A b c  + 83344640B b c )x
+--R             + 
+--R                           6 8               7 7  20
+--R               (83344640A b c  + 183705600B b c )x
+--R             + 
+--R                            7 7               8 6  18
+--R               (183705600A b c  + 284508160B b c )x
+--R             + 
+--R                            8 6               9 5  16
+--R               (284508160A b c  + 309002240B b c )x
+--R             + 
+--R                            9 5               10 4  14
+--R               (309002240A b c  + 230621184B b  c )x
+--R             + 
+--R                            10 4               11 3  12
+--R               (230621184A b  c  + 112721920B b  c )x
+--R             + 
+--R                            11 3              12 2  10
+--R               (112721920A b  c  + 32505856B b  c )x
+--R             + 
+--R                           12 2             13   8             13   6
+--R               (32505856A b  c  + 4194304B b  c)x  + 4194304A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                14 35         14            13  33
+--R           23B c  x   + (23A c   + 2093B b c  )x
+--R         + 
+--R                     13           2 12  31            2 12            3 11  29
+--R           (2093A b c   + 58765B b c  )x   + (58765A b c   + 795455B b c  )x
+--R         + 
+--R                     3 11             4 10  27
+--R           (795455A b c   + 6264280B b c  )x
+--R         + 
+--R                      4 10              5 9  25
+--R           (6264280A b c   + 31722704B b c )x
+--R         + 
+--R                       5 9               6 8  23
+--R           (31722704A b c  + 109541824B b c )x
+--R         + 
+--R                        6 8               7 7  21
+--R           (109541824A b c  + 267050240B b c )x
+--R         + 
+--R                        7 7               8 6  19
+--R           (267050240A b c  + 468213760B b c )x
+--R         + 
+--R                        8 6               9 5  17
+--R           (468213760A b c  + 593510400B b c )x
+--R         + 
+--R                        9 5               10 4  15
+--R           (593510400A b c  + 539623424B b  c )x
+--R         + 
+--R                        10 4               11 3  13
+--R           (539623424A b  c  + 343343104B b  c )x
+--R         + 
+--R                        11 3               12 2  11
+--R           (343343104A b  c  + 145227776B b  c )x
+--R         + 
+--R                        12 2              13   9
+--R           (145227776A b  c  + 36700160B b  c)x
+--R         + 
+--R                       13              14  7             14 5
+--R           (36700160A b  c + 4194304B b  )x  + 4194304A b  x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            15 36         15           14  34              14           2 13  32
+--R       - B c  x   + (- A c   - 267B b c  )x   + (- 267A b c   - 12235B b c  )x
+--R     + 
+--R                  2 13            3 12  30
+--R       (- 12235A b c   - 227305B b c  )x
+--R     + 
+--R                   3 12             4 11  28
+--R       (- 227305A b c   - 2258520B b c  )x
+--R     + 
+--R                    4 11              5 10  26
+--R       (- 2258520A b c   - 13730288B b c  )x
+--R     + 
+--R                     5 10              6 9  24
+--R       (- 13730288A b c   - 55080896B b c )x
+--R     + 
+--R                     6 9               7 8  22
+--R       (- 55080896A b c  - 152421120B b c )x
+--R     + 
+--R                      7 8               8 7  20
+--R       (- 152421120A b c  - 298147840B b c )x
+--R     + 
+--R                      8 7               9 6  18
+--R       (- 298147840A b c  - 416071680B b c )x
+--R     + 
+--R                      9 6               10 5  16
+--R       (- 416071680A b c  - 412090368B b  c )x
+--R     + 
+--R                      10 5               11 4  14
+--R       (- 412090368A b  c  - 283181056B b  c )x
+--R     + 
+--R                      11 4               12 3  12
+--R       (- 283181056A b  c  - 128450560B b  c )x
+--R     + 
+--R                      12 3              13 2  10
+--R       (- 128450560A b  c  - 34603008B b  c )x
+--R     + 
+--R                     13 2             14   8             14   6
+--R       (- 34603008A b  c  - 4194304B b  c)x  - 4194304A b  c x
+--R  /
+--R                  12 24         11 22         2 10 20          3 9 18
+--R                 c  x   + 265b c  x   + 11704b c  x   + 203632b c x
+--R               + 
+--R                         4 8 16           5 7 14            6 6 12
+--R                 1839552b c x   + 9847552b c x   + 33546240b c x
+--R               + 
+--R                          7 5 10             8 4 8             9 3 6
+--R                 75481088b c x   + 113639424b c x  + 113311744b c x
+--R               + 
+--R                          10 2 4            11   2           12
+--R                 71827456b  c x  + 26214400b  c x  + 4194304b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                      12 23          11 21         2 10 19          3 9 17
+--R                 - 23c  x   - 2024b c  x   - 52624b c  x   - 631488b c x
+--R               + 
+--R                           4 8 15            5 7 13            6 6 11
+--R                 - 4209920b c x   - 17145856b c x   - 44843008b c x
+--R               + 
+--R                            7 5 9            8 4 7            9 3 5
+--R                 - 76873728b c x  - 85917696b c x  - 60293120b c x
+--R               + 
+--R                            10 2 3           11
+--R                 - 24117248b  c x  - 4194304b  c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  12 24          11 22         2 10 20          3 9 18
+--R             - 23c  x   - 2047b c  x   - 54648b c  x   - 684112b c x
+--R           + 
+--R                       4 8 16            5 7 14            6 6 12
+--R             - 4841408b c x   - 21355776b c x   - 61988864b c x
+--R           + 
+--R                         7 5 10             8 4 8             9 3 6
+--R             - 121716736b c x   - 162791424b c x  - 146210816b c x
+--R           + 
+--R                        10 2 4            11   2           12
+--R             - 84410368b  c x  - 28311552b  c x  - 4194304b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          13 25         12 23         2 11 21          3 10 19           4 9 17
+--R         c  x   + 265b c  x   + 11704b c  x   + 203632b c  x   + 1839552b c x
+--R       + 
+--R                 5 8 15            6 7 13            7 6 11             8 5 9
+--R         9847552b c x   + 33546240b c x   + 75481088b c x   + 113639424b c x
+--R       + 
+--R                   9 4 7            10 3 5            11 2 3           12
+--R         113311744b c x  + 71827456b  c x  + 26214400b  c x  + 4194304b  c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 854
+
+--S 855 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        4 5         5 4  8             5 4          6 3  6
+--R               (- 300A b c  + 150B b c )x  + (- 4800A b c  + 2400B b c )x
+--R             + 
+--R                          6 3           7 2  4              7 2           8   2
+--R               (- 20160A b c  + 10080B b c )x  + (- 30720A b c  + 15360B b c)x
+--R             + 
+--R                         8           9
+--R               - 15360A b c + 7680B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                     4 6        5 5  10           5 5         6 4  8
+--R               (30A b c  - 15B b c )x   + (1500A b c  - 750B b c )x
+--R             + 
+--R                        6 4          7 3  6            7 3           8 2  4
+--R               (12000A b c  - 6000B b c )x  + (33600A b c  - 16800B b c )x
+--R             + 
+--R                        8 2           9   2           9           10
+--R               (38400A b c  - 19200B b c)x  + 15360A b c - 7680B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                      4 5         5 4  8           5 4          6 3  6
+--R               (600A b c  - 300B b c )x  + (9600A b c  - 4800B b c )x
+--R             + 
+--R                        6 3           7 2  4            7 2           8   2
+--R               (40320A b c  - 20160B b c )x  + (61440A b c  - 30720B b c)x
+--R             + 
+--R                       8            9
+--R               30720A b c - 15360B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                       4 6        5 5  10             5 5          6 4  8
+--R               (- 60A b c  + 30B b c )x   + (- 3000A b c  + 1500B b c )x
+--R             + 
+--R                          6 4           7 3  6              7 3           8 2  4
+--R               (- 24000A b c  + 12000B b c )x  + (- 67200A b c  + 33600B b c )x
+--R             + 
+--R                          8 2           9   2           9            10
+--R               (- 76800A b c  + 38400B b c)x  - 30720A b c + 15360B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                        8 16             8             7  14
+--R               - 1280B c x   + (- 1600A c  - 22240B b c )x
+--R             + 
+--R                            7            2 6  12
+--R               (- 28000A b c  - 114256B b c )x
+--R             + 
+--R                           2 6            3 5  10
+--R               (- 146120A b c  - 250524B b c )x
+--R             + 
+--R                           3 5            4 4  8
+--R               (- 328020A b c  - 249686B b c )x
+--R             + 
+--R                           4 4           5 3  6
+--R               (- 336320A b c  - 93984B b c )x
+--R             + 
+--R                           5 3          6 2  4            6 2           7   2
+--R               (- 123200A b c  - 3936B b c )x  + (20480A b c  - 10240B b c)x
+--R             + 
+--R                       7           8
+--R               15360A b c - 7680B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                     9 18          9            8  16
+--R               128B c x   + (160A c  + 6576B b c )x
+--R             + 
+--R                         8           2 7  14            2 7            3 6  12
+--R               (8240A b c  + 60008B b c )x   + (76020A b c  + 214150B b c )x
+--R             + 
+--R                         3 6            4 5  10
+--R               (276170A b c  + 363675B b c )x
+--R             + 
+--R                         4 5            5 4  8             5 4           6 3  6
+--R               (480100A b c  + 296526B b c )x  + (399520A b c  + 95152B b c )x
+--R             + 
+--R                         6 3          7 2  4              7 2           8   2
+--R               (114880A b c  + 8096B b c )x  + (- 28160A b c  + 14080B b c)x
+--R             + 
+--R                         8           9
+--R               - 15360A b c + 7680B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                   9 19            9            8  17
+--R           - 128B c x   + (- 160A c  - 6576B b c )x
+--R         + 
+--R                       8           2 7  15              2 7            3 6  13
+--R           (- 8240A b c  - 60008B b c )x   + (- 76020A b c  - 214150B b c )x
+--R         + 
+--R                       3 6            4 5  11
+--R           (- 276170A b c  - 363675B b c )x
+--R         + 
+--R                       4 5            5 4  9               5 4           6 3  7
+--R           (- 480100A b c  - 296526B b c )x  + (- 399520A b c  - 95152B b c )x
+--R         + 
+--R                       6 3          7 2  5            7 2           8   3
+--R           (- 114880A b c  - 8096B b c )x  + (28160A b c  - 14080B b c)x
+--R         + 
+--R                    8           9
+--R           (15360A b c - 7680B b )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                  9 19           9             8  17
+--R           1280B c x   + (1600A c  + 23520B b c )x
+--R         + 
+--R                      8            2 7  15             2 7            3 6  13
+--R           (29600A b c  + 136496B b c )x   + (174120A b c  + 364780B b c )x
+--R         + 
+--R                     3 6            4 5  11             4 5            5 4  9
+--R           (474140A b c  + 500210B b c )x   + (664340A b c  + 343670B b c )x
+--R         + 
+--R                     5 4           6 3  7             6 3           7 2  5
+--R           (459520A b c  + 97920B b c )x  + (102720A b c  + 14176B b c )x
+--R         + 
+--R                      7 2           8   3              8           9
+--R           (- 35840A b c  + 17920B b c)x  + (- 15360A b c + 7680B b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R                7 8            6 6          2 5 4           3 4 2          4 3
+--R         (12800c x  + 204800b c x  + 860160b c x  + 1310720b c x  + 655360b c )
+--R      *
+--R                        +--------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|b \|c \|c x  + b
+--R     + 
+--R                  8 10           7 8          2 6 6           3 5 4
+--R           - 1280c x   - 64000b c x  - 512000b c x  - 1433600b c x
+--R         + 
+--R                     4 4 2          5 3
+--R           - 1638400b c x  - 655360b c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 855
+
+--S 856 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      11 28           11            10  26
+--R               - 20B c  x   + (- 20A c   - 1360B b c  )x
+--R             + 
+--R                           10           2 9  24
+--R               (- 1360A b c   - 28004B b c )x
+--R             + 
+--R                          2 9            3 8  22
+--R               (- 28004A b c  - 271656B b c )x
+--R             + 
+--R                           3 8             4 7  20
+--R               (- 271656A b c  - 1489664B b c )x
+--R             + 
+--R                            4 7             5 6  18
+--R               (- 1489664A b c  - 5065216B b c )x
+--R             + 
+--R                            5 6              6 5  16
+--R               (- 5065216A b c  - 11203584B b c )x
+--R             + 
+--R                             6 5              7 4  14
+--R               (- 11203584A b c  - 16427008B b c )x
+--R             + 
+--R                             7 4              8 3  12
+--R               (- 16427008A b c  - 15859712B b c )x
+--R             + 
+--R                             8 3             9 2  10
+--R               (- 15859712A b c  - 9699328B b c )x
+--R             + 
+--R                            9 2             10   8
+--R               (- 9699328A b c  - 3407872B b  c)x
+--R             + 
+--R                            10             11  6            11 4
+--R               (- 3407872A b  c - 524288B b  )x  - 524288A b  x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              12 30       12           11  28            11          2 10  26
+--R           B c  x   + (A c   + 202B b c  )x   + (202A b c   + 7001B b c  )x
+--R         + 
+--R                   2 10           3 9  24            3 9            4 8  22
+--R           (7001A b c   + 97880B b c )x   + (97880A b c  + 724680B b c )x
+--R         + 
+--R                     4 8             5 7  20
+--R           (724680A b c  + 3232768B b c )x
+--R         + 
+--R                      5 7             6 6  18
+--R           (3232768A b c  + 9308416B b c )x
+--R         + 
+--R                      6 6              7 5  16
+--R           (9308416A b c  + 17922048B b c )x
+--R         + 
+--R                       7 5              8 4  14
+--R           (17922048A b c  + 23336960B b c )x
+--R         + 
+--R                       8 4              9 3  12
+--R           (23336960A b c  + 20316160B b c )x
+--R         + 
+--R                       9 3              10 2  10
+--R           (20316160A b c  + 11337728B b  c )x
+--R         + 
+--R                       10 2             11   8              11             12  6
+--R           (11337728A b  c  + 3670016B b  c)x  + (3670016A b  c + 524288B b  )x
+--R         + 
+--R                    12 4
+--R           524288A b  x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                12 31         12           11  29
+--R           - B c  x   + (- A c   - 202B b c  )x
+--R         + 
+--R                      11          2 10  27             2 10           3 9  25
+--R           (- 202A b c   - 7001B b c  )x   + (- 7001A b c   - 97880B b c )x
+--R         + 
+--R                      3 9            4 8  23
+--R           (- 97880A b c  - 724680B b c )x
+--R         + 
+--R                       4 8             5 7  21
+--R           (- 724680A b c  - 3232768B b c )x
+--R         + 
+--R                        5 7             6 6  19
+--R           (- 3232768A b c  - 9308416B b c )x
+--R         + 
+--R                        6 6              7 5  17
+--R           (- 9308416A b c  - 17922048B b c )x
+--R         + 
+--R                         7 5              8 4  15
+--R           (- 17922048A b c  - 23336960B b c )x
+--R         + 
+--R                         8 4              9 3  13
+--R           (- 23336960A b c  - 20316160B b c )x
+--R         + 
+--R                         9 3              10 2  11
+--R           (- 20316160A b c  - 11337728B b  c )x
+--R         + 
+--R                         10 2             11   9
+--R           (- 11337728A b  c  - 3670016B b  c)x
+--R         + 
+--R                        11             12  7            12 5
+--R           (- 3670016A b  c - 524288B b  )x  - 524288A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                12 31         12            11  29
+--R           20B c  x   + (20A c   + 1380B b c  )x
+--R         + 
+--R                     11           2 10  27            2 10            3 9  25
+--R           (1380A b c   + 29364B b c  )x   + (29364A b c   + 299660B b c )x
+--R         + 
+--R                     3 9             4 8  23
+--R           (299660A b c  + 1761320B b c )x
+--R         + 
+--R                      4 8             5 7  21
+--R           (1761320A b c  + 6554880B b c )x
+--R         + 
+--R                      5 7              6 6  19
+--R           (6554880A b c  + 16268800B b c )x
+--R         + 
+--R                       6 6              7 5  17
+--R           (16268800A b c  + 27630592B b c )x
+--R         + 
+--R                       7 5              8 4  15
+--R           (27630592A b c  + 32286720B b c )x
+--R         + 
+--R                       8 4              9 3  13
+--R           (32286720A b c  + 25559040B b c )x
+--R         + 
+--R                       9 3              10 2  11
+--R           (25559040A b c  + 13107200B b  c )x
+--R         + 
+--R                       10 2             11   9              11             12  7
+--R           (13107200A b  c  + 3932160B b  c)x  + (3932160A b  c + 524288B b  )x
+--R         + 
+--R                    12 5
+--R           524288A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              10 20         9 18        2 8 16         3 7 14          4 6 12
+--R             c  x   + 200b c x   + 6600b c x   + 84480b c x   + 549120b c x
+--R           + 
+--R                     5 5 10           6 4 8           7 3 6           8 2 4
+--R             2050048b c x   + 4659200b c x  + 6553600b c x  + 5570560b c x
+--R           + 
+--R                     9   2          10
+--R             2621440b c x  + 524288b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  10 20          9 18         2 8 16          3 7 14
+--R             - 20c  x   - 1340b c x   - 26664b c x   - 244992b c x
+--R           + 
+--R                       4 6 12           5 5 10           6 4 8           7 3 6
+--R             - 1244672b c x   - 3820544b c x   - 7383040b c x  - 9043968b c x
+--R           + 
+--R                       8 2 4           9   2          10
+--R             - 6815744b c x  - 2883584b c x  - 524288b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 856
+
+)clear all
+
+--S 857 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                          +-----------+
+--R              6               4        2  |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 3139
+r0:=2/315*b*(4*b*B-9*A*c)*(b*x^2+c*x^4)^(5/2)/(c^3*x^5)-_
+   1/63*(4*b*B-9*A*c)*(b*x^2+c*x^4)^(5/2)/(c^2*x^3)+_
+   1/9*B*(b*x^2+c*x^4)^(5/2)/(c*x)
+--R 
+--R
+--R   (2)
+--R              4 8         4          3  6           3       2 2  4
+--R         35B c x  + (45A c  + 50B b c )x  + (72A b c  + 3B b c )x
+--R       + 
+--R              2 2       3   2        3        4
+--R         (9A b c  - 4B b c)x  - 18A b c + 8B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         3
+--R     315c x
+--R                                                    Type: Expression(Integer)
+--E 858
+
+--S 859 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     5 16              5          2 4  14
+--R           - 315B b c x   + (- 405A b c  - 4650B b c )x
+--R         + 
+--R                     2 4           3 3  12              3 3           4 2  10
+--R           (- 6048A b c  - 21147B b c )x   + (- 28161A b c  - 42084B b c )x
+--R         + 
+--R                      4 2           5   8              5            6  6
+--R           (- 57960A b c  - 38640B b c)x  + (- 55440A b c - 13440B b )x
+--R         + 
+--R                     6 4
+--R           - 20160A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                6 18         6            5  16             5           2 4  14
+--R           35B c x   + (45A c  + 1485B b c )x   + (1917A b c  + 11853B b c )x
+--R         + 
+--R                    2 4           3 3  12            3 3           4 2  10
+--R           (15561A b c  + 38199B b c )x   + (51471A b c  + 59724B b c )x
+--R         + 
+--R                  4 2           5   8            5            6  6           6 4
+--R         (83160A b c  + 45360B b c)x  + (65520A b c + 13440B b )x  + 20160A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              4 8           3 6         2 2 4          3   2         4  +-+
+--R         (315c x  + 12600b c x  + 75600b c x  + 141120b c x  + 80640b )\|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                4 8         2 3 6          3 2 4          4   2         5
+--R       - 2835b c x  - 37800b c x  - 136080b c x  - 181440b c x  - 80640b
+--R                                         Type: Union(Expression(Integer),...)
+--E 859
+
+--S 860 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      8 16           8            7  14
+--R               - 35B c x   + (- 45A c  - 1450B b c )x
+--R             + 
+--R                           7           2 6  12
+--R               (- 1872A b c  - 10403B b c )x
+--R             + 
+--R                          2 6           3 5  10
+--R               (- 13689A b c  - 27796B b c )x
+--R             + 
+--R                          3 5           4 4  8              4 4           5 3  6
+--R               (- 37782A b c  - 31928B b c )x  + (- 45216A b c  - 13504B b c )x
+--R             + 
+--R                          5 3         6 2  4           6 2          7   2
+--R               (- 18144A b c  - 896B b c )x  + (5760A b c  - 2560B b c)x
+--R             + 
+--R                      7           8
+--R               4608A b c - 2048B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   8 16            8          2 7  14
+--R           315B b c x   + (405A b c  + 4650B b c )x
+--R         + 
+--R                   2 7           3 6  12            3 6           4 5  10
+--R           (6048A b c  + 21147B b c )x   + (28161A b c  + 42084B b c )x
+--R         + 
+--R                    4 5           5 4  8            5 4           6 3  6
+--R           (57942A b c  + 38648B b c )x  + (54720A b c  + 13760B b c )x
+--R         + 
+--R                    6 3          7 2  4             7 2          8   2
+--R           (15840A b c  + 1920B b c )x  + (- 8064A b c  + 3584B b c)x
+--R         + 
+--R                    8           9
+--R           - 4608A b c + 2048B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                     8 17              8          2 7  15
+--R           - 315B b c x   + (- 405A b c  - 4650B b c )x
+--R         + 
+--R                     2 7           3 6  13              3 6           4 5  11
+--R           (- 6048A b c  - 21147B b c )x   + (- 28161A b c  - 42084B b c )x
+--R         + 
+--R                      4 5           5 4  9              5 4           6 3  7
+--R           (- 57960A b c  - 38640B b c )x  + (- 55440A b c  - 13440B b c )x
+--R         + 
+--R                     6 3 5
+--R           - 20160A b c x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                9 19         9            8  17             8           2 7  15
+--R           35B c x   + (45A c  + 1485B b c )x   + (1917A b c  + 11853B b c )x
+--R         + 
+--R                    2 7           3 6  13            3 6           4 5  11
+--R           (15561A b c  + 38199B b c )x   + (51471A b c  + 59724B b c )x
+--R         + 
+--R                    4 5           5 4  9            5 4           6 3  7
+--R           (83160A b c  + 45360B b c )x  + (65520A b c  + 13440B b c )x
+--R         + 
+--R                   6 3 5
+--R           20160A b c x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              7 9           6 7         2 5 5          3 4 3         4 3   +-+
+--R         (315c x  + 12600b c x  + 75600b c x  + 141120b c x  + 80640b c x)\|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 9         2 6 7          3 5 5          4 4 3         5 3
+--R       - 2835b c x  - 37800b c x  - 136080b c x  - 181440b c x  - 80640b c x
+--R                                                    Type: Expression(Integer)
+--E 860
+
+--S 861 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      10 25           10           9  23
+--R               - 18B c  x   + (- 18A c   - 996B b c )x
+--R             + 
+--R                          9           2 8  21
+--R               (- 996A b c  - 16722B b c )x
+--R             + 
+--R                          2 8            3 7  19
+--R               (- 16722A b c  - 131904B b c )x
+--R             + 
+--R                           3 7            4 6  17
+--R               (- 131904A b c  - 583616B b c )x
+--R             + 
+--R                           4 6             5 5  15
+--R               (- 583616A b c  - 1579008B b c )x
+--R             + 
+--R                            5 5             6 4  13
+--R               (- 1579008A b c  - 2717184B b c )x
+--R             + 
+--R                            6 4             7 3  11
+--R               (- 2717184A b c  - 2990080B b c )x
+--R             + 
+--R                            7 3             8 2  9
+--R               (- 2990080A b c  - 2039808B b c )x
+--R             + 
+--R                            8 2            9   7
+--R               (- 2039808A b c  - 786432B b c)x
+--R             + 
+--R                           9             10  5            10 3
+--R               (- 786432A b c - 131072B b  )x  - 131072A b  x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              11 27       11           10  25            10          2 9  23
+--R           B c  x   + (A c   + 164B b c  )x   + (164A b c   + 4645B b c )x
+--R         + 
+--R                   2 9           3 8  21            3 8            4 7  19
+--R           (4645A b c  + 53154B b c )x   + (53154A b c  + 321120B b c )x
+--R         + 
+--R                     4 7             5 6  17
+--R           (321120A b c  + 1159488B b c )x
+--R         + 
+--R                      5 6             6 5  15
+--R           (1159488A b c  + 2664192B b c )x
+--R         + 
+--R                      6 5             7 4  13
+--R           (2664192A b c  + 4001280B b c )x
+--R         + 
+--R                      7 4             8 3  11
+--R           (4001280A b c  + 3919872B b c )x
+--R         + 
+--R                      8 3             9 2  9              9 2            10   7
+--R           (3919872A b c  + 2416640B b c )x  + (2416640A b c  + 851968B b  c)x
+--R         + 
+--R                     10             11  5            11 3
+--R           (851968A b  c + 131072B b  )x  + 131072A b  x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                11 28         11           10  26
+--R           - B c  x   + (- A c   - 164B b c  )x
+--R         + 
+--R                      10          2 9  24             2 9           3 8  22
+--R           (- 164A b c   - 4645B b c )x   + (- 4645A b c  - 53154B b c )x
+--R         + 
+--R                      3 8            4 7  20
+--R           (- 53154A b c  - 321120B b c )x
+--R         + 
+--R                       4 7             5 6  18
+--R           (- 321120A b c  - 1159488B b c )x
+--R         + 
+--R                        5 6             6 5  16
+--R           (- 1159488A b c  - 2664192B b c )x
+--R         + 
+--R                        6 5             7 4  14
+--R           (- 2664192A b c  - 4001280B b c )x
+--R         + 
+--R                        7 4             8 3  12
+--R           (- 4001280A b c  - 3919872B b c )x
+--R         + 
+--R                        8 3             9 2  10
+--R           (- 3919872A b c  - 2416640B b c )x
+--R         + 
+--R                        9 2            10   8               10             11  6
+--R           (- 2416640A b c  - 851968B b  c)x  + (- 851968A b  c - 131072B b  )x
+--R         + 
+--R                      11 4
+--R           - 131072A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                11 28         11            10  26
+--R           18B c  x   + (18A c   + 1014B b c  )x
+--R         + 
+--R                     10           2 9  24            2 9            3 8  22
+--R           (1014A b c   + 17718B b c )x   + (17718A b c  + 148626B b c )x
+--R         + 
+--R                     3 8            4 7  20             4 7             5 6  18
+--R           (148626A b c  + 715520B b c )x   + (715520A b c  + 2162624B b c )x
+--R         + 
+--R                      5 6             6 5  16
+--R           (2162624A b c  + 4296192B b c )x
+--R         + 
+--R                      6 5             7 4  14
+--R           (4296192A b c  + 5707264B b c )x
+--R         + 
+--R                      7 4             8 3  12
+--R           (5707264A b c  + 5029888B b c )x
+--R         + 
+--R                      8 3             9 2  10              9 2            10   8
+--R           (5029888A b c  + 2826240B b c )x   + (2826240A b c  + 917504B b  c)x
+--R         + 
+--R                     10             11  6            11 4
+--R           (917504A b  c + 131072B b  )x  + 131072A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              9 18         8 16        2 7 14         3 6 12          4 5 10
+--R             c x   + 162b c x   + 4320b c x   + 44352b c x   + 228096b c x
+--R           + 
+--R                    5 4 8           6 3 6           7 2 4          8   2
+--R             658944b c x  + 1118208b c x  + 1105920b c x  + 589824b c x
+--R           + 
+--R                    9
+--R             131072b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  9 18         8 16         2 7 14          3 6 12
+--R             - 18c x   - 978b c x   - 15744b c x   - 116160b c x
+--R           + 
+--R                      4 5 10           5 4 8           6 3 6           7 2 4
+--R             - 467456b c x   - 1111552b c x  - 1605632b c x  - 1384448b c x
+--R           + 
+--R                      8   2          9
+--R             - 655360b c x  - 131072b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 861
+
+)clear all
+
+--S 862 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x
+--R 
+--R
+--R                                         +-----------+
+--R              5               3          |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 862
+
+--S 863 of 3139
+r0:=-1/48*(3*b*B-8*A*c)*(b*x^2+c*x^4)^(3/2)/c+1/8*B*(b*x^2+c*x^4)^(5/2)/_
+   (c*x^2)+1/128*b^3*(3*b*B-8*A*c)*atanh(x^2*sqrt(c)/_
+   sqrt(b*x^2+c*x^4))/c^(5/2)-1/128*b^2*(3*b*B-8*A*c)*sqrt(b*x^2+_
+   c*x^4)/c^2-1/64*b*(3*b*B-8*A*c)*x^2*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                     2 +-+
+--R               3        4           x \|c
+--R       (- 24A b c + 9B b )atanh(--------------)
+--R                                 +-----------+
+--R                                 |   4      2
+--R                                \|c x  + b x
+--R     + 
+--R                3 6         3          2  4            2       2   2        2
+--R           48B c x  + (64A c  + 72B b c )x  + (112A b c  + 6B b c)x  + 24A b c
+--R         + 
+--R                 3
+--R           - 9B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R         2 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 863
+
+--S 864 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        3 4        4 3  6           4 3         5 2  4
+--R                 (192A b c  - 72B b c )x  + (1920A b c  - 720B b c )x
+--R               + 
+--R                         5 2          6   2          6           7
+--R                 (4608A b c  - 1728B b c)x  + 3072A b c - 1152B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     3 5       4 4  8            4 4         5 3  6
+--R             (- 24A b c  + 9B b c )x  + (- 768A b c  + 288B b c )x
+--R           + 
+--R                       5 3          6 2  4             6 2          7   2
+--R             (- 3840A b c  + 1440B b c )x  + (- 6144A b c  + 2304B b c)x
+--R           + 
+--R                      7           8
+--R             - 3072A b c + 1152B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                    7 15           7            6  13
+--R             - 48B c x   + (- 64A c  - 1608B b c )x
+--R           + 
+--R                         6          2 5  11              2 5           3 4  9
+--R             (- 2160A b c  - 9990B b c )x   + (- 13848A b c  - 23991B b c )x
+--R           + 
+--R                        3 4           4 3  7              4 3          5 2  5
+--R             (- 35072A b c  - 25248B b c )x  + (- 40704A b c  - 9312B b c )x
+--R           + 
+--R                        5 2          6   3             6           7
+--R             (- 20480A b c  + 1536B b c)x  + (- 3072A b c + 1152B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                   7 15          7            6  13
+--R             384B c x   + (512A c  + 4800B b c )x
+--R           + 
+--R                       6           2 5  11            2 5           3 4  9
+--R             (6528A b c  + 19440B b c )x   + (27456A b c  + 35400B b c )x
+--R           + 
+--R                      3 4           4 3  7            4 3          5 2  5
+--R             (53056A b c  + 30024B b c )x  + (50560A b c  + 8688B b c )x
+--R           + 
+--R                      5 2          6   3           6           7
+--R             (22016A b c  - 2112B b c)x  + (3072A b c - 1152B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                                                                    +--------+
+--R               5 6           4 4         2 3 2         3 2  +-+ +-+ |   2
+--R         (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|b \|c \|c x  + b
+--R       + 
+--R                6 8           5 6         2 4 4         3 3 2         4 2  +-+
+--R         (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|c
+--R     ,
+--R
+--R                          3 4         4 3  6             4 3          5 2  4
+--R                 (- 384A b c  + 144B b c )x  + (- 3840A b c  + 1440B b c )x
+--R               + 
+--R                           5 2          6   2          6           7
+--R                 (- 9216A b c  + 3456B b c)x  - 6144A b c + 2304B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                   3 5        4 4  8           4 4         5 3  6
+--R             (48A b c  - 18B b c )x  + (1536A b c  - 576B b c )x
+--R           + 
+--R                     5 3          6 2  4            6 2          7   2
+--R             (7680A b c  - 2880B b c )x  + (12288A b c  - 4608B b c)x
+--R           + 
+--R                    7           8
+--R             6144A b c - 2304B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                    7 15           7            6  13
+--R             - 48B c x   + (- 64A c  - 1608B b c )x
+--R           + 
+--R                         6          2 5  11              2 5           3 4  9
+--R             (- 2160A b c  - 9990B b c )x   + (- 13848A b c  - 23991B b c )x
+--R           + 
+--R                        3 4           4 3  7              4 3          5 2  5
+--R             (- 35072A b c  - 25248B b c )x  + (- 40704A b c  - 9312B b c )x
+--R           + 
+--R                        5 2          6   3             6           7
+--R             (- 20480A b c  + 1536B b c)x  + (- 3072A b c + 1152B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                   7 15          7            6  13
+--R             384B c x   + (512A c  + 4800B b c )x
+--R           + 
+--R                       6           2 5  11            2 5           3 4  9
+--R             (6528A b c  + 19440B b c )x   + (27456A b c  + 35400B b c )x
+--R           + 
+--R                      3 4           4 3  7            4 3          5 2  5
+--R             (53056A b c  + 30024B b c )x  + (50560A b c  + 8688B b c )x
+--R           + 
+--R                      5 2          6   3           6           7
+--R             (22016A b c  - 2112B b c)x  + (3072A b c - 1152B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                                                                      +--------+
+--R               5 6           4 4         2 3 2         3 2  +---+ +-+ |   2
+--R         (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|- c \|b \|c x  + b
+--R       + 
+--R              6 8           5 6         2 4 4         3 3 2         4 2  +---+
+--R       (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 864
+
+--S 865 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      3 4        4 3  6           4 3         5 2  4
+--R               (192A b c  - 72B b c )x  + (1920A b c  - 720B b c )x
+--R             + 
+--R                       5 2          6   2          6           7
+--R               (4608A b c  - 1728B b c)x  + 3072A b c - 1152B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   3 5       4 4  8            4 4         5 3  6
+--R           (- 24A b c  + 9B b c )x  + (- 768A b c  + 288B b c )x
+--R         + 
+--R                     5 3          6 2  4             6 2          7   2
+--R           (- 3840A b c  + 1440B b c )x  + (- 6144A b c  + 2304B b c)x
+--R         + 
+--R                    7           8
+--R           - 3072A b c + 1152B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                      3 4        4 3  6           4 3         5 2  4
+--R               (192A b c  - 72B b c )x  + (1920A b c  - 720B b c )x
+--R             + 
+--R                       5 2          6   2          6           7
+--R               (4608A b c  - 1728B b c)x  + 3072A b c - 1152B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   3 5       4 4  8            4 4         5 3  6
+--R           (- 24A b c  + 9B b c )x  + (- 768A b c  + 288B b c )x
+--R         + 
+--R                     5 3          6 2  4             6 2          7   2
+--R           (- 3840A b c  + 1440B b c )x  + (- 6144A b c  + 2304B b c)x
+--R         + 
+--R                    7           8
+--R           - 3072A b c + 1152B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                       6 12            6            5  10
+--R               - 384B c x   + (- 512A c  - 4416B b c )x
+--R             + 
+--R                           5           2 4  8              2 4           3 3  6
+--R               (- 6016A b c  - 15024B b c )x  + (- 21440A b c  - 20376B b c )x
+--R             + 
+--R                          3 3          4 2  4              4 2         5   2
+--R               (- 31616A b c  - 9648B b c )x  + (- 18944A b c  + 960B b c)x
+--R             + 
+--R                        5           6
+--R               - 3072A b c + 1152B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                    7 14         7            6  12
+--R               48B c x   + (64A c  + 1608B b c )x
+--R             + 
+--R                         6          2 5  10            2 5           3 4  8
+--R               (2160A b c  + 9990B b c )x   + (13848A b c  + 23991B b c )x
+--R             + 
+--R                        3 4           4 3  6            4 3          5 2  4
+--R               (35072A b c  + 25248B b c )x  + (40704A b c  + 9312B b c )x
+--R             + 
+--R                        5 2          6   2          6           7
+--R               (20480A b c  - 1536B b c)x  + 3072A b c - 1152B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  7 15           7            6  13
+--R           - 48B c x   + (- 64A c  - 1608B b c )x
+--R         + 
+--R                       6          2 5  11              2 5           3 4  9
+--R           (- 2160A b c  - 9990B b c )x   + (- 13848A b c  - 23991B b c )x
+--R         + 
+--R                      3 4           4 3  7              4 3          5 2  5
+--R           (- 35072A b c  - 25248B b c )x  + (- 40704A b c  - 9312B b c )x
+--R         + 
+--R                      5 2          6   3             6           7
+--R           (- 20480A b c  + 1536B b c)x  + (- 3072A b c + 1152B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                 7 15          7            6  13
+--R           384B c x   + (512A c  + 4800B b c )x
+--R         + 
+--R                     6           2 5  11            2 5           3 4  9
+--R           (6528A b c  + 19440B b c )x   + (27456A b c  + 35400B b c )x
+--R         + 
+--R                    3 4           4 3  7            4 3          5 2  5
+--R           (53056A b c  + 30024B b c )x  + (50560A b c  + 8688B b c )x
+--R         + 
+--R                    5 2          6   3           6           7
+--R           (22016A b c  - 2112B b c)x  + (3072A b c - 1152B b )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                                                                  +--------+
+--R             5 6           4 4         2 3 2         3 2  +-+ +-+ |   2
+--R       (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|b \|c \|c x  + b
+--R     + 
+--R              6 8           5 6         2 4 4         3 3 2         4 2  +-+
+--R       (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 865
+
+--S 866 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          11 26           11            10  24
+--R                   - 19B c  x   + (- 19A c   - 1178B b c  )x
+--R                 + 
+--R                               10           2 9  22
+--R                   (- 1178A b c   - 22363B b c )x
+--R                 + 
+--R                              2 9            3 8  20
+--R                   (- 22363A b c  - 201780B b c )x
+--R                 + 
+--R                               3 8             4 7  18
+--R                   (- 201780A b c  - 1036640B b c )x
+--R                 + 
+--R                                4 7             5 6  16
+--R                   (- 1036640A b c  - 3322112B b c )x
+--R                 + 
+--R                                5 6             6 5  14
+--R                   (- 3322112A b c  - 6960384B b c )x
+--R                 + 
+--R                                6 5             7 4  12
+--R                   (- 6960384A b c  - 9708544B b c )x
+--R                 + 
+--R                                7 4             8 3  10
+--R                   (- 9708544A b c  - 8949760B b c )x
+--R                 + 
+--R                                8 3             9 2  8
+--R                   (- 8949760A b c  - 5242880B b c )x
+--R                 + 
+--R                                9 2             10   6
+--R                   (- 5242880A b c  - 1769472B b  c)x
+--R                 + 
+--R                                10             11  4            11 2
+--R                   (- 1769472A b  c - 262144B b  )x  - 262144A b  x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                    12 27         12           11  25
+--R               - B c  x   + (- A c   - 182B b c  )x
+--R             + 
+--R                          11          2 10  23
+--R               (- 182A b c   - 5641B b c  )x
+--R             + 
+--R                         2 10           3 9  21
+--R               (- 5641A b c   - 69876B b c )x
+--R             + 
+--R                          3 9            4 8  19
+--R               (- 69876A b c  - 453024B b c )x
+--R             + 
+--R                           4 8             5 7  17
+--R               (- 453024A b c  - 1743104B b c )x
+--R             + 
+--R                            5 7             6 6  15
+--R               (- 1743104A b c  - 4243200B b c )x
+--R             + 
+--R                            6 6             7 5  13
+--R               (- 4243200A b c  - 6718464B b c )x
+--R             + 
+--R                            7 5             8 4  11
+--R               (- 6718464A b c  - 6909952B b c )x
+--R             + 
+--R                            8 4             9 3  9
+--R               (- 6909952A b c  - 4456448B b c )x
+--R             + 
+--R                            9 3             10 2  7
+--R               (- 4456448A b c  - 1638400B b  c )x
+--R             + 
+--R                            10 2            11   5            11   3
+--R               (- 1638400A b  c  - 262144B b  c)x  - 262144A b  c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  12 28       12           11  26
+--R               B c  x   + (A c   + 183B b c  )x
+--R             + 
+--R                        11          2 10  24           2 10           3 9  22
+--R               (183A b c   + 5823B b c  )x   + (5823A b c   + 75517B b c )x
+--R             + 
+--R                        3 9            4 8  20
+--R               (75517A b c  + 522900B b c )x
+--R             + 
+--R                         4 8             5 7  18
+--R               (522900A b c  + 2196128B b c )x
+--R             + 
+--R                          5 7             6 6  16
+--R               (2196128A b c  + 5986304B b c )x
+--R             + 
+--R                          6 6              7 5  14
+--R               (5986304A b c  + 10961664B b c )x
+--R             + 
+--R                           7 5              8 4  12
+--R               (10961664A b c  + 13628416B b c )x
+--R             + 
+--R                           8 4              9 3  10
+--R               (13628416A b c  + 11366400B b c )x
+--R             + 
+--R                           9 3             10 2  8
+--R               (11366400A b c  + 6094848B b  c )x
+--R             + 
+--R                          10 2             11   6
+--R               (6094848A b  c  + 1900544B b  c)x
+--R             + 
+--R                          11             12  4            12 2
+--R               (1900544A b  c + 262144B b  )x  + 262144A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    12 27         12            11  25
+--R               19B c  x   + (19A c   + 1178B b c  )x
+--R             + 
+--R                         11           2 10  23
+--R               (1178A b c   + 22363B b c  )x
+--R             + 
+--R                        2 10            3 9  21
+--R               (22363A b c   + 201780B b c )x
+--R             + 
+--R                         3 9             4 8  19
+--R               (201780A b c  + 1036640B b c )x
+--R             + 
+--R                          4 8             5 7  17
+--R               (1036640A b c  + 3322112B b c )x
+--R             + 
+--R                          5 7             6 6  15
+--R               (3322112A b c  + 6960384B b c )x
+--R             + 
+--R                          6 6             7 5  13
+--R               (6960384A b c  + 9708544B b c )x
+--R             + 
+--R                          7 5             8 4  11
+--R               (9708544A b c  + 8949760B b c )x
+--R             + 
+--R                          8 4             9 3  9
+--R               (8949760A b c  + 5242880B b c )x
+--R             + 
+--R                          9 3             10 2  7
+--R               (5242880A b c  + 1769472B b  c )x
+--R             + 
+--R                          10 2            11   5            11   3
+--R               (1769472A b  c  + 262144B b  c)x  + 262144A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    12 29         12           11  27
+--R               - B c  x   + (- A c   - 183B b c  )x
+--R             + 
+--R                          11          2 10  25
+--R               (- 183A b c   - 5823B b c  )x
+--R             + 
+--R                         2 10           3 9  23
+--R               (- 5823A b c   - 75517B b c )x
+--R             + 
+--R                          3 9            4 8  21
+--R               (- 75517A b c  - 522900B b c )x
+--R             + 
+--R                           4 8             5 7  19
+--R               (- 522900A b c  - 2196128B b c )x
+--R             + 
+--R                            5 7             6 6  17
+--R               (- 2196128A b c  - 5986304B b c )x
+--R             + 
+--R                            6 6              7 5  15
+--R               (- 5986304A b c  - 10961664B b c )x
+--R             + 
+--R                             7 5              8 4  13
+--R               (- 10961664A b c  - 13628416B b c )x
+--R             + 
+--R                             8 4              9 3  11
+--R               (- 13628416A b c  - 11366400B b c )x
+--R             + 
+--R                             9 3             10 2  9
+--R               (- 11366400A b c  - 6094848B b  c )x
+--R             + 
+--R                            10 2             11   7
+--R               (- 6094848A b  c  - 1900544B b  c)x
+--R             + 
+--R                            11             12  5            12 3
+--R               (- 1900544A b  c - 262144B b  )x  - 262144A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      12 28           12            11  26
+--R               - 19B c  x   + (- 19A c   - 1178B b c  )x
+--R             + 
+--R                           11           2 10  24
+--R               (- 1178A b c   - 22363B b c  )x
+--R             + 
+--R                          2 10            3 9  22
+--R               (- 22363A b c   - 201780B b c )x
+--R             + 
+--R                           3 9             4 8  20
+--R               (- 201780A b c  - 1036640B b c )x
+--R             + 
+--R                            4 8             5 7  18
+--R               (- 1036640A b c  - 3322112B b c )x
+--R             + 
+--R                            5 7             6 6  16
+--R               (- 3322112A b c  - 6960384B b c )x
+--R             + 
+--R                            6 6             7 5  14
+--R               (- 6960384A b c  - 9708544B b c )x
+--R             + 
+--R                            7 5             8 4  12
+--R               (- 9708544A b c  - 8949760B b c )x
+--R             + 
+--R                            8 4             9 3  10
+--R               (- 8949760A b c  - 5242880B b c )x
+--R             + 
+--R                            9 3             10 2  8
+--R               (- 5242880A b c  - 1769472B b  c )x
+--R             + 
+--R                            10 2            11   6            11   4
+--R               (- 1769472A b  c  - 262144B b  c)x  - 262144A b  c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                12 29         12            11  27
+--R           19B c  x   + (19A c   + 1197B b c  )x
+--R         + 
+--R                     11           2 10  25            2 10            3 9  23
+--R           (1197A b c   + 23541B b c  )x   + (23541A b c   + 224143B b c )x
+--R         + 
+--R                     3 9             4 8  21
+--R           (224143A b c  + 1238420B b c )x
+--R         + 
+--R                      4 8             5 7  19
+--R           (1238420A b c  + 4358752B b c )x
+--R         + 
+--R                      5 7              6 6  17
+--R           (4358752A b c  + 10282496B b c )x
+--R         + 
+--R                       6 6              7 5  15
+--R           (10282496A b c  + 16668928B b c )x
+--R         + 
+--R                       7 5              8 4  13
+--R           (16668928A b c  + 18658304B b c )x
+--R         + 
+--R                       8 4              9 3  11
+--R           (18658304A b c  + 14192640B b c )x
+--R         + 
+--R                       9 3             10 2  9
+--R           (14192640A b c  + 7012352B b  c )x
+--R         + 
+--R                      10 2             11   7              11             12  5
+--R           (7012352A b  c  + 2031616B b  c)x  + (2031616A b  c + 262144B b  )x
+--R         + 
+--R                    12 3
+--R           262144A b  x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R          13 30       13           12  28            12          2 11  26
+--R       B c  x   + (A c   + 183B b c  )x   + (183A b c   + 5823B b c  )x
+--R     + 
+--R               2 11           3 10  24            3 10            4 9  22
+--R       (5823A b c   + 75517B b c  )x   + (75517A b c   + 522900B b c )x
+--R     + 
+--R                 4 9             5 8  20              5 8             6 7  18
+--R       (522900A b c  + 2196128B b c )x   + (2196128A b c  + 5986304B b c )x
+--R     + 
+--R                  6 7              7 6  16
+--R       (5986304A b c  + 10961664B b c )x
+--R     + 
+--R                   7 6              8 5  14
+--R       (10961664A b c  + 13628416B b c )x
+--R     + 
+--R                   8 5              9 4  12
+--R       (13628416A b c  + 11366400B b c )x
+--R     + 
+--R                   9 4             10 3  10
+--R       (11366400A b c  + 6094848B b  c )x
+--R     + 
+--R                  10 3             11 2  8              11 2            12   6
+--R       (6094848A b  c  + 1900544B b  c )x  + (1900544A b  c  + 262144B b  c)x
+--R     + 
+--R                12   4
+--R       262144A b  c x
+--R  /
+--R                  10 20         9 18        2 8 16         3 7 14
+--R                 c  x   + 181b c x   + 5460b c x   + 64416b c x
+--R               + 
+--R                        4 6 12           5 5 10           6 4 8           7 3 6
+--R                 388608b c x   + 1354496b c x   + 2888704b c x  + 3829760b c x
+--R               + 
+--R                         8 2 4           9   2          10
+--R                 3080192b c x  + 1376256b c x  + 262144b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                    10 19          9 17         2 8 15          3 7 13
+--R                 19c  x   + 1140b c x   + 20064b c x   + 160512b c x
+--R               + 
+--R                        4 6 11           5 5 9           6 4 7           7 3 5
+--R                 695552b c x   + 1770496b c x  + 2723840b c x  + 2490368b c x
+--R               + 
+--R                         8 2 3          9
+--R                 1245184b c x  + 262144b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  10 20          9 18         2 8 16          3 7 14
+--R             - 19c  x   - 1159b c x   - 21204b c x   - 180576b c x
+--R           + 
+--R                      4 6 12           5 5 10           6 4 8           7 3 6
+--R             - 856064b c x   - 2466048b c x   - 4494336b c x  - 5214208b c x
+--R           + 
+--R                       8 2 4           9   2          10
+--R             - 3735552b c x  - 1507328b c x  - 262144b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R            11 21         10 19        2 9 17         3 8 15          4 7 13
+--R         - c  x   - 181b c  x   - 5460b c x   - 64416b c x   - 388608b c x
+--R       + 
+--R                   5 6 11           6 5 9           7 4 7           8 3 5
+--R         - 1354496b c x   - 2888704b c x  - 3829760b c x  - 3080192b c x
+--R       + 
+--R                   9 2 3          10
+--R         - 1376256b c x  - 262144b  c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      3 4        4 3  6           4 3         5 2  4
+--R               (192A b c  - 72B b c )x  + (1920A b c  - 720B b c )x
+--R             + 
+--R                       5 2          6   2          6           7
+--R               (4608A b c  - 1728B b c)x  + 3072A b c - 1152B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                       3 5       4 4  8            4 4         5 3  6
+--R               (- 24A b c  + 9B b c )x  + (- 768A b c  + 288B b c )x
+--R             + 
+--R                         5 3          6 2  4             6 2          7   2
+--R               (- 3840A b c  + 1440B b c )x  + (- 6144A b c  + 2304B b c)x
+--R             + 
+--R                        7           8
+--R               - 3072A b c + 1152B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                        3 4         4 3  6             4 3          5 2  4
+--R               (- 384A b c  + 144B b c )x  + (- 3840A b c  + 1440B b c )x
+--R             + 
+--R                         5 2          6   2          6           7
+--R               (- 9216A b c  + 3456B b c)x  - 6144A b c + 2304B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                     3 5        4 4  8           4 4         5 3  6
+--R               (48A b c  - 18B b c )x  + (1536A b c  - 576B b c )x
+--R             + 
+--R                       5 3          6 2  4            6 2          7   2
+--R               (7680A b c  - 2880B b c )x  + (12288A b c  - 4608B b c)x
+--R             + 
+--R                      7           8
+--R               6144A b c - 2304B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                       6 12            6            5  10
+--R               - 384B c x   + (- 512A c  - 4416B b c )x
+--R             + 
+--R                           5           2 4  8              2 4           3 3  6
+--R               (- 6016A b c  - 15024B b c )x  + (- 21440A b c  - 20376B b c )x
+--R             + 
+--R                          3 3          4 2  4              4 2         5   2
+--R               (- 31616A b c  - 9648B b c )x  + (- 18944A b c  + 960B b c)x
+--R             + 
+--R                        5           6
+--R               - 3072A b c + 1152B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                    7 14         7            6  12
+--R               48B c x   + (64A c  + 1608B b c )x
+--R             + 
+--R                         6          2 5  10            2 5           3 4  8
+--R               (2160A b c  + 9990B b c )x   + (13848A b c  + 23991B b c )x
+--R             + 
+--R                        3 4           4 3  6            4 3          5 2  4
+--R               (35072A b c  + 25248B b c )x  + (40704A b c  + 9312B b c )x
+--R             + 
+--R                        5 2          6   2          6           7
+--R               (20480A b c  - 1536B b c)x  + 3072A b c - 1152B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  7 15           7            6  13
+--R           - 48B c x   + (- 64A c  - 1608B b c )x
+--R         + 
+--R                       6          2 5  11              2 5           3 4  9
+--R           (- 2160A b c  - 9990B b c )x   + (- 13848A b c  - 23991B b c )x
+--R         + 
+--R                      3 4           4 3  7              4 3          5 2  5
+--R           (- 35072A b c  - 25248B b c )x  + (- 40704A b c  - 9312B b c )x
+--R         + 
+--R                      5 2          6   3             6           7
+--R           (- 20480A b c  + 1536B b c)x  + (- 3072A b c + 1152B b )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                 7 15          7            6  13
+--R           384B c x   + (512A c  + 4800B b c )x
+--R         + 
+--R                     6           2 5  11            2 5           3 4  9
+--R           (6528A b c  + 19440B b c )x   + (27456A b c  + 35400B b c )x
+--R         + 
+--R                    3 4           4 3  7            4 3          5 2  5
+--R           (53056A b c  + 30024B b c )x  + (50560A b c  + 8688B b c )x
+--R         + 
+--R                    5 2          6   3           6           7
+--R           (22016A b c  - 2112B b c)x  + (3072A b c - 1152B b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R               5 6           4 4         2 3 2         3 2  +---+ +-+ +-+
+--R         (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|- c \|b \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R            6 8           5 6         2 4 4         3 3 2         4 2  +---+ +-+
+--R     (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      9 22           9           8  20
+--R               - 16B c x   + (- 16A c  - 704B b c )x
+--R             + 
+--R                          8          2 7  18             2 7           3 6  16
+--R               (- 704A b c  - 9424B b c )x   + (- 9424A b c  - 59040B b c )x
+--R             + 
+--R                          3 6            4 5  14
+--R               (- 59040A b c  - 205184B b c )x
+--R             + 
+--R                           4 5            5 4  12
+--R               (- 205184A b c  - 427264B b c )x
+--R             + 
+--R                           5 4            6 3  10
+--R               (- 427264A b c  - 546816B b c )x
+--R             + 
+--R                           6 3            7 2  8
+--R               (- 546816A b c  - 421888B b c )x
+--R             + 
+--R                           7 2            8   6               8            9  4
+--R               (- 421888A b c  - 180224B b c)x  + (- 180224A b c - 32768B b )x
+--R             + 
+--R                         9 2
+--R               - 32768A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              10 24       10           9  22            9          2 8  20
+--R           B c  x   + (A c   + 130B b c )x   + (130A b c  + 2945B b c )x
+--R         + 
+--R                   2 8           3 7  18            3 7            4 6  16
+--R           (2945A b c  + 27008B b c )x   + (27008A b c  + 130176B b c )x
+--R         + 
+--R                     4 6            5 5  14             5 5            6 4  12
+--R           (130176A b c  + 370688B b c )x   + (370688A b c  + 657920B b c )x
+--R         + 
+--R                     6 4            7 3  10             7 3            8 2  8
+--R           (657920A b c  + 737280B b c )x   + (737280A b c  + 507904B b c )x
+--R         + 
+--R                     8 2            9   6             9            10  4
+--R           (507904A b c  + 196608B b c)x  + (196608A b c + 32768B b  )x
+--R         + 
+--R                   10 2
+--R           32768A b  x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                10 25         10           9  23              9          2 8  21
+--R           - B c  x   + (- A c   - 130B b c )x   + (- 130A b c  - 2945B b c )x
+--R         + 
+--R                     2 8           3 7  19              3 7            4 6  17
+--R           (- 2945A b c  - 27008B b c )x   + (- 27008A b c  - 130176B b c )x
+--R         + 
+--R                       4 6            5 5  15
+--R           (- 130176A b c  - 370688B b c )x
+--R         + 
+--R                       5 5            6 4  13
+--R           (- 370688A b c  - 657920B b c )x
+--R         + 
+--R                       6 4            7 3  11
+--R           (- 657920A b c  - 737280B b c )x
+--R         + 
+--R                       7 3            8 2  9               8 2            9   7
+--R           (- 737280A b c  - 507904B b c )x  + (- 507904A b c  - 196608B b c)x
+--R         + 
+--R                       9            10  5           10 3
+--R           (- 196608A b c - 32768B b  )x  - 32768A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                10 25         10           9  23            9           2 8  21
+--R           16B c  x   + (16A c   + 720B b c )x   + (720A b c  + 10128B b c )x
+--R         + 
+--R                    2 8           3 7  19            3 7            4 6  17
+--R           (10128A b c  + 68464B b c )x   + (68464A b c  + 264224B b c )x
+--R         + 
+--R                     4 6            5 5  15             5 5            6 4  13
+--R           (264224A b c  + 632448B b c )x   + (632448A b c  + 974080B b c )x
+--R         + 
+--R                     6 4            7 3  11             7 3            8 2  9
+--R           (974080A b c  + 968704B b c )x   + (968704A b c  + 602112B b c )x
+--R         + 
+--R                     8 2            9   7             9            10  5
+--R           (602112A b c  + 212992B b c)x  + (212992A b c + 32768B b  )x
+--R         + 
+--R                   10 3
+--R           32768A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              8 16         7 14        2 6 12         3 5 10         4 4 8
+--R             c x   + 128b c x   + 2688b c x   + 21504b c x   + 84480b c x
+--R           + 
+--R                    5 3 6          6 2 4          7   2         8
+--R             180224b c x  + 212992b c x  + 131072b c x  + 32768b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  8 16         7 14        2 6 12         3 5 10          4 4 8
+--R             - 16c x   - 688b c x   - 8736b c x   - 50304b c x   - 154880b c x
+--R           + 
+--R                      5 3 6          6 2 4          7   2         8
+--R             - 272384b c x  - 274432b c x  - 147456b c x  - 32768b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 868
+
+)clear all
+
+--S 869 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^2
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 869
+
+--S 870 of 3139
+r0:=-1/35*(2*b*B-7*A*c)*(b*x^2+c*x^4)^(5/2)/(c^2*x^5)+_
+   1/7*B*(b*x^2+c*x^4)^(5/2)/(c*x^3)
+--R 
+--R
+--R   (2)
+--R            3 6        3         2  4           2      2   2       2        3
+--R       (5B c x  + (7A c  + 8B b c )x  + (14A b c  + B b c)x  + 7A b c - 2B b )
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R        2
+--R     35c x
+--R                                                    Type: Expression(Integer)
+--E 870
+
+--S 871 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    4 12             4         2 3  10
+--R           - 35B b c x   + (- 49A b c  - 336B b c )x
+--R         + 
+--R                    2 3          3 2  8             3 2          4   6
+--R           (- 490A b c  - 1015B b c )x  + (- 1610A b c  - 1260B b c)x
+--R         + 
+--R                     4          5  4          5 2
+--R           (- 2240A b c - 560B b )x  - 1120A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               5 14        5           4  12            4         2 3  10
+--R           5B c x   + (7A c  + 133B b c )x   + (189A b c  + 721B b c )x
+--R         + 
+--R                   2 3          3 2  8           3 2          4   6
+--R           (1085A b c  + 1575B b c )x  + (2590A b c  + 1540B b c)x
+--R         + 
+--R                   4          5  4          5 2
+--R           (2800A b c + 560B b )x  + 1120A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                      +--------+
+--R           3 6         2 4        2   2        3  +-+ |   2              3 6
+--R       (35c x  + 840b c x  + 2800b c x  + 2240b )\|b \|c x  + b  - 245b c x
+--R     + 
+--R              2 2 4        3   2        4
+--R       - 1960b c x  - 3920b c x  - 2240b
+--R                                         Type: Union(Expression(Integer),...)
+--E 871
+
+--S 872 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     6 12          6           5  10
+--R               - 5B c x   + (- 7A c  - 128B b c )x
+--R             + 
+--R                          5         2 4  8            2 4         3 3  6
+--R               (- 182A b c  - 593B b c )x  + (- 903A b c  - 982B b c )x
+--R             + 
+--R                         3 3         4 2  4             4 2        5   2
+--R               (- 1736A b c  - 544B b c )x  + (- 1456A b c  + 96B b c)x
+--R             + 
+--R                       5          6
+--R               - 448A b c + 128B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  6 12           6         2 5  10          2 5          3 4  8
+--R           35B b c x   + (49A b c  + 336B b c )x   + (490A b c  + 1015B b c )x
+--R         + 
+--R                   3 4          4 3  6           4 3         5 2  4
+--R           (1617A b c  + 1258B b c )x  + (2408A b c  + 512B b c )x
+--R         + 
+--R                   5 2         6   2         6          7
+--R           (1680A b c  - 160B b c)x  + 448A b c - 128B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    6 13             6         2 5  11
+--R           - 35B b c x   + (- 49A b c  - 336B b c )x
+--R         + 
+--R                    2 5          3 4  9             3 4          4 3  7
+--R           (- 490A b c  - 1015B b c )x  + (- 1610A b c  - 1260B b c )x
+--R         + 
+--R                     4 3         5 2  5          5 2 3
+--R           (- 2240A b c  - 560B b c )x  - 1120A b c x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               7 15        7           6  13            6         2 5  11
+--R           5B c x   + (7A c  + 133B b c )x   + (189A b c  + 721B b c )x
+--R         + 
+--R                   2 5          3 4  9           3 4          4 3  7
+--R           (1085A b c  + 1575B b c )x  + (2590A b c  + 1540B b c )x
+--R         + 
+--R                   4 3         5 2  5          5 2 3
+--R           (2800A b c  + 560B b c )x  + 1120A b c x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                         +--------+
+--R           5 7         4 5        2 3 3        3 2   +-+ |   2              5 7
+--R       (35c x  + 840b c x  + 2800b c x  + 2240b c x)\|b \|c x  + b  - 245b c x
+--R     + 
+--R              2 4 5        3 3 3        4 2
+--R       - 1960b c x  - 3920b c x  - 2240b c x
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      8 19           8           7  17
+--R               - 14B c x   + (- 14A c  - 476B b c )x
+--R             + 
+--R                          7          2 6  15             2 6           3 5  13
+--R               (- 476A b c  - 4942B b c )x   + (- 4942A b c  - 23872B b c )x
+--R             + 
+--R                          3 5           4 4  11
+--R               (- 23872A b c  - 62912B b c )x
+--R             + 
+--R                          4 4           5 3  9              5 3           6 2  7
+--R               (- 62912A b c  - 96256B b c )x  + (- 96256A b c  - 85504B b c )x
+--R             + 
+--R                          6 2           7   5              7           8  3
+--R               (- 85504A b c  - 40960B b c)x  + (- 40960A b c - 8192B b )x
+--R             + 
+--R                        8
+--R               - 8192A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              9 21       9           8  19            8          2 7  17
+--R           B c x   + (A c  + 100B b c )x   + (100A b c  + 1765B b c )x
+--R         + 
+--R                   2 7           3 6  15            3 6           4 5  13
+--R           (1765A b c  + 12642B b c )x   + (12642A b c  + 47264B b c )x
+--R         + 
+--R                    4 5            5 4  11             5 4            6 3  9
+--R           (47264A b c  + 102592B b c )x   + (102592A b c  + 134400B b c )x
+--R         + 
+--R                     6 3            7 2  7             7 2           8   5
+--R           (134400A b c  + 104960B b c )x  + (104960A b c  + 45056B b c)x
+--R         + 
+--R                    8           9  3          9
+--R           (45056A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                9 22         9           8  20              8          2 7  18
+--R           - B c x   + (- A c  - 100B b c )x   + (- 100A b c  - 1765B b c )x
+--R         + 
+--R                     2 7           3 6  16              3 6           4 5  14
+--R           (- 1765A b c  - 12642B b c )x   + (- 12642A b c  - 47264B b c )x
+--R         + 
+--R                      4 5            5 4  12
+--R           (- 47264A b c  - 102592B b c )x
+--R         + 
+--R                       5 4            6 3  10
+--R           (- 102592A b c  - 134400B b c )x
+--R         + 
+--R                       6 3            7 2  8               7 2           8   6
+--R           (- 134400A b c  - 104960B b c )x  + (- 104960A b c  - 45056B b c)x
+--R         + 
+--R                      8           9  4          9 2
+--R           (- 45056A b c - 8192B b )x  - 8192A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                9 22         9           8  20            8          2 7  18
+--R           14B c x   + (14A c  + 490B b c )x   + (490A b c  + 5418B b c )x
+--R         + 
+--R                   2 7           3 6  16            3 6           4 5  14
+--R           (5418A b c  + 28814B b c )x   + (28814A b c  + 86784B b c )x
+--R         + 
+--R                    4 5            5 4  12             5 4            6 3  10
+--R           (86784A b c  + 159168B b c )x   + (159168A b c  + 181760B b c )x
+--R         + 
+--R                     6 3            7 2  8             7 2           8   6
+--R           (181760A b c  + 126464B b c )x  + (126464A b c  + 49152B b c)x
+--R         + 
+--R                    8           9  4          9 2
+--R           (49152A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              7 14        6 12        2 5 10        3 4 8         4 3 6
+--R             c x   + 98b c x   + 1568b c x   + 9408b c x  + 26880b c x
+--R           + 
+--R                   5 2 4         6   2        7
+--R             39424b c x  + 28672b c x  + 8192b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  7 14         6 12        2 5 10         3 4 8         4 3 6
+--R             - 14c x   - 462b c x   - 4480b c x   - 19392b c x  - 43520b c x
+--R           + 
+--R                     5 2 4         6   2        7
+--R             - 52736b c x  - 32768b c x  - 8192b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 873
+
+)clear all
+
+--S 874 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^3
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              x
+--R                                                    Type: Expression(Integer)
+--E 874
+
+--S 875 of 3139
+r0:=-1/24*(b*B-6*A*c)*(b*x^2+c*x^4)^(3/2)/(c*x^2)+_
+   1/6*B*(b*x^2+c*x^4)^(5/2)/(c*x^4)-1/16*b^2*(b*B-6*A*c)*atanh(x^2*_
+   sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)-1/16*b*(b*B-6*A*c)*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                   2 +-+
+--R             2        3           x \|c
+--R       (18A b c - 3B b )atanh(--------------)
+--R                               +-----------+
+--R                               |   4      2
+--R                              \|c x  + b x
+--R     + 
+--R                                                              +-----------+
+--R            2 4         2            2                 2  +-+ |   4      2
+--R       (8B c x  + (12A c  + 14B b c)x  + 30A b c + 3B b )\|c \|c x  + b x
+--R  /
+--R         +-+
+--R     48c\|c
+--R                                                    Type: Expression(Integer)
+--E 875
+
+--S 876 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        2 3        3 2  4          3 2        4   2         4
+--R                 (108A b c  - 18B b c )x  + (576A b c  - 96B b c)x  + 576A b c
+--R               + 
+--R                        5
+--R                 - 96B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     2 4       3 3  6            3 3        4 2  4
+--R             (- 18A b c  + 3B b c )x  + (- 324A b c  + 54B b c )x
+--R           + 
+--R                      4 2         5   2         5         6
+--R             (- 864A b c  + 144B b c)x  - 576A b c + 96B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                   5 11           5           4  9              4         2 3  7
+--R             - 8B c x   + (- 12A c  - 158B b c )x  + (- 246A b c  - 639B b c )x
+--R           + 
+--R                       2 3         3 2  5             3 2         4   3
+--R             (- 1116A b c  - 982B b c )x  + (- 1824A b c  - 592B b c)x
+--R           + 
+--R                      4         5
+--R             (- 960A b c - 96B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                  5 11         5           4  9            4          2 3  7
+--R             48B c x   + (72A c  + 388B b c )x  + (636A b c  + 1062B b c )x
+--R           + 
+--R                     2 3          3 2  5           3 2         4   3
+--R             (1908A b c  + 1266B b c )x  + (2304A b c  + 640B b c)x
+--R           + 
+--R                    4         5
+--R             (960A b c + 96B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                                                  +--------+
+--R              3 4          2 2        2   +-+ +-+ |   2
+--R         (288c x  + 1536b c x  + 1536b c)\|b \|c \|c x  + b
+--R       + 
+--R               4 6         3 4        2 2 2        3   +-+
+--R         (- 48c x  - 864b c x  - 2304b c x  - 1536b c)\|c
+--R     ,
+--R
+--R                        2 3        3 2  4           3 2         4   2
+--R                 (216A b c  - 36B b c )x  + (1152A b c  - 192B b c)x
+--R               + 
+--R                        4          5
+--R                 1152A b c - 192B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     2 4       3 3  6            3 3         4 2  4
+--R             (- 36A b c  + 6B b c )x  + (- 648A b c  + 108B b c )x
+--R           + 
+--R                       4 2         5   2          5          6
+--R             (- 1728A b c  + 288B b c)x  - 1152A b c + 192B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                   5 11           5           4  9              4         2 3  7
+--R             - 8B c x   + (- 12A c  - 158B b c )x  + (- 246A b c  - 639B b c )x
+--R           + 
+--R                       2 3         3 2  5             3 2         4   3
+--R             (- 1116A b c  - 982B b c )x  + (- 1824A b c  - 592B b c)x
+--R           + 
+--R                      4         5
+--R             (- 960A b c - 96B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                  5 11         5           4  9            4          2 3  7
+--R             48B c x   + (72A c  + 388B b c )x  + (636A b c  + 1062B b c )x
+--R           + 
+--R                     2 3          3 2  5           3 2         4   3
+--R             (1908A b c  + 1266B b c )x  + (2304A b c  + 640B b c)x
+--R           + 
+--R                    4         5
+--R             (960A b c + 96B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                                                    +--------+
+--R              3 4          2 2        2   +---+ +-+ |   2
+--R         (288c x  + 1536b c x  + 1536b c)\|- c \|b \|c x  + b
+--R       + 
+--R               4 6         3 4        2 2 2        3   +---+
+--R         (- 48c x  - 864b c x  - 2304b c x  - 1536b c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 876
+
+--S 877 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2 3        3 2  4          3 2        4   2         4
+--R               (108A b c  - 18B b c )x  + (576A b c  - 96B b c)x  + 576A b c
+--R             + 
+--R                      5
+--R               - 96B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   2 4       3 3  6            3 3        4 2  4
+--R           (- 18A b c  + 3B b c )x  + (- 324A b c  + 54B b c )x
+--R         + 
+--R                    4 2         5   2         5         6
+--R           (- 864A b c  + 144B b c)x  - 576A b c + 96B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                        2 3        3 2  4            3 2        4   2         4
+--R               (- 108A b c  + 18B b c )x  + (- 576A b c  + 96B b c)x  - 576A b c
+--R             + 
+--R                    5
+--R               96B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                 2 4       3 3  6          3 3        4 2  4
+--R           (18A b c  - 3B b c )x  + (324A b c  - 54B b c )x
+--R         + 
+--R                  4 2         5   2         5         6
+--R           (864A b c  - 144B b c)x  + 576A b c - 96B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                      4 8           4           3  6
+--R               - 48B c x  + (- 72A c  - 340B b c )x
+--R             + 
+--R                          3         2 2  4             2 2         3   2
+--R               (- 564A b c  - 722B b c )x  + (- 1344A b c  - 544B b c)x
+--R             + 
+--R                       3         4
+--R               - 960A b c - 96B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                   5 10         5           4  8            4         2 3  6
+--R               8B c x   + (12A c  + 158B b c )x  + (246A b c  + 639B b c )x
+--R             + 
+--R                       2 3         3 2  4           3 2         4   2         4
+--R               (1116A b c  + 982B b c )x  + (1824A b c  + 592B b c)x  + 960A b c
+--R             + 
+--R                    5
+--R               96B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 5 11           5           4  9              4         2 3  7
+--R           - 8B c x   + (- 12A c  - 158B b c )x  + (- 246A b c  - 639B b c )x
+--R         + 
+--R                     2 3         3 2  5             3 2         4   3
+--R           (- 1116A b c  - 982B b c )x  + (- 1824A b c  - 592B b c)x
+--R         + 
+--R                    4         5
+--R           (- 960A b c - 96B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                5 11         5           4  9            4          2 3  7
+--R           48B c x   + (72A c  + 388B b c )x  + (636A b c  + 1062B b c )x
+--R         + 
+--R                   2 3          3 2  5           3 2         4   3
+--R           (1908A b c  + 1266B b c )x  + (2304A b c  + 640B b c)x
+--R         + 
+--R                  4         5
+--R           (960A b c + 96B b )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                                                +--------+
+--R            3 4          2 2        2   +-+ +-+ |   2
+--R       (288c x  + 1536b c x  + 1536b c)\|b \|c \|c x  + b
+--R     + 
+--R             4 6         3 4        2 2 2        3   +-+
+--R       (- 48c x  - 864b c x  - 2304b c x  - 1536b c)\|c
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--S 878 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          9 20           9           8  18
+--R                   - 15B c x   + (- 15A c  - 590B b c )x
+--R                 + 
+--R                              8          2 7  16
+--R                   (- 590A b c  - 7183B b c )x
+--R                 + 
+--R                             2 7           3 6  14
+--R                   (- 7183A b c  - 41456B b c )x
+--R                 + 
+--R                              3 6            4 5  12
+--R                   (- 41456A b c  - 134048B b c )x
+--R                 + 
+--R                               4 5            5 4  10
+--R                   (- 134048A b c  - 261760B b c )x
+--R                 + 
+--R                               5 4            6 3  8
+--R                   (- 261760A b c  - 316160B b c )x
+--R                 + 
+--R                               6 3            7 2  6
+--R                   (- 316160A b c  - 231424B b c )x
+--R                 + 
+--R                               7 2           8   4
+--R                   (- 231424A b c  - 94208B b c)x
+--R                 + 
+--R                              8            9  2           9
+--R                   (- 94208A b c - 16384B b )x  - 16384A b
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  10 21       10           9  19            9          2 8  17
+--R               B c  x   + (A c   + 114B b c )x   + (114A b c  + 2241B b c )x
+--R             + 
+--R                       2 8           3 7  15            3 7           4 6  13
+--R               (2241A b c  + 17584B b c )x   + (17584A b c  + 71136B b c )x
+--R             + 
+--R                        4 6            5 5  11             5 5            6 4  9
+--R               (71136A b c  + 165504B b c )x   + (165504A b c  + 230656B b c )x
+--R             + 
+--R                         6 4            7 3  7             7 3           8 2  5
+--R               (230656A b c  + 190464B b c )x  + (190464A b c  + 86016B b c )x
+--R             + 
+--R                        8 2           9   3           9
+--R               (86016A b c  + 16384B b c)x  + 16384A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  10 22       10           9  20            9          2 8  18
+--R               B c  x   + (A c   + 115B b c )x   + (115A b c  + 2355B b c )x
+--R             + 
+--R                       2 8           3 7  16            3 7           4 6  14
+--R               (2355A b c  + 19825B b c )x   + (19825A b c  + 88720B b c )x
+--R             + 
+--R                        4 6            5 5  12
+--R               (88720A b c  + 236640B b c )x
+--R             + 
+--R                         5 5            6 4  10
+--R               (236640A b c  + 396160B b c )x
+--R             + 
+--R                         6 4            7 3  8             7 3            8 2  6
+--R               (396160A b c  + 421120B b c )x  + (421120A b c  + 276480B b c )x
+--R             + 
+--R                         8 2            9   4             9            10  2
+--R               (276480A b c  + 102400B b c)x  + (102400A b c + 16384B b  )x
+--R             + 
+--R                       10
+--R               16384A b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      10 21           10           9  19
+--R               - 15B c  x   + (- 15A c   - 590B b c )x
+--R             + 
+--R                          9          2 8  17             2 8           3 7  15
+--R               (- 590A b c  - 7183B b c )x   + (- 7183A b c  - 41456B b c )x
+--R             + 
+--R                          3 7            4 6  13
+--R               (- 41456A b c  - 134048B b c )x
+--R             + 
+--R                           4 6            5 5  11
+--R               (- 134048A b c  - 261760B b c )x
+--R             + 
+--R                           5 5            6 4  9
+--R               (- 261760A b c  - 316160B b c )x
+--R             + 
+--R                           6 4            7 3  7
+--R               (- 316160A b c  - 231424B b c )x
+--R             + 
+--R                           7 3           8 2  5              8 2           9   3
+--R               (- 231424A b c  - 94208B b c )x  + (- 94208A b c  - 16384B b c)x
+--R             + 
+--R                         9
+--R               - 16384A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    10 23         10           9  21
+--R               - B c  x   + (- A c   - 115B b c )x
+--R             + 
+--R                          9          2 8  19             2 8           3 7  17
+--R               (- 115A b c  - 2355B b c )x   + (- 2355A b c  - 19825B b c )x
+--R             + 
+--R                          3 7           4 6  15
+--R               (- 19825A b c  - 88720B b c )x
+--R             + 
+--R                          4 6            5 5  13
+--R               (- 88720A b c  - 236640B b c )x
+--R             + 
+--R                           5 5            6 4  11
+--R               (- 236640A b c  - 396160B b c )x
+--R             + 
+--R                           6 4            7 3  9
+--R               (- 396160A b c  - 421120B b c )x
+--R             + 
+--R                           7 3            8 2  7
+--R               (- 421120A b c  - 276480B b c )x
+--R             + 
+--R                           8 2            9   5               9            10  3
+--R               (- 276480A b c  - 102400B b c)x  + (- 102400A b c - 16384B b  )x
+--R             + 
+--R                         10
+--R               - 16384A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    10 22         10           9  20
+--R               15B c  x   + (15A c   + 590B b c )x
+--R             + 
+--R                        9          2 8  18           2 8           3 7  16
+--R               (590A b c  + 7183B b c )x   + (7183A b c  + 41456B b c )x
+--R             + 
+--R                        3 7            4 6  14
+--R               (41456A b c  + 134048B b c )x
+--R             + 
+--R                         4 6            5 5  12
+--R               (134048A b c  + 261760B b c )x
+--R             + 
+--R                         5 5            6 4  10
+--R               (261760A b c  + 316160B b c )x
+--R             + 
+--R                         6 4            7 3  8             7 3           8 2  6
+--R               (316160A b c  + 231424B b c )x  + (231424A b c  + 94208B b c )x
+--R             + 
+--R                        8 2           9   4           9   2
+--R               (94208A b c  + 16384B b c)x  + 16384A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                10 23         10           9  21            9          2 8  19
+--R           15B c  x   + (15A c   + 605B b c )x   + (605A b c  + 7773B b c )x
+--R         + 
+--R                   2 8           3 7  17            3 7            4 6  15
+--R           (7773A b c  + 48639B b c )x   + (48639A b c  + 175504B b c )x
+--R         + 
+--R                     4 6            5 5  13             5 5            6 4  11
+--R           (175504A b c  + 395808B b c )x   + (395808A b c  + 577920B b c )x
+--R         + 
+--R                     6 4            7 3  9             7 3            8 2  7
+--R           (577920A b c  + 547584B b c )x  + (547584A b c  + 325632B b c )x
+--R         + 
+--R                     8 2            9   5             9            10  3
+--R           (325632A b c  + 110592B b c)x  + (110592A b c + 16384B b  )x
+--R         + 
+--R                   10
+--R           16384A b  x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            11 24         11           10  22              10          2 9  20
+--R       - B c  x   + (- A c   - 115B b c  )x   + (- 115A b c   - 2355B b c )x
+--R     + 
+--R                 2 9           3 8  18              3 8           4 7  16
+--R       (- 2355A b c  - 19825B b c )x   + (- 19825A b c  - 88720B b c )x
+--R     + 
+--R                  4 7            5 6  14               5 6            6 5  12
+--R       (- 88720A b c  - 236640B b c )x   + (- 236640A b c  - 396160B b c )x
+--R     + 
+--R                   6 5            7 4  10               7 4            8 3  8
+--R       (- 396160A b c  - 421120B b c )x   + (- 421120A b c  - 276480B b c )x
+--R     + 
+--R                   8 3            9 2  6               9 2           10   4
+--R       (- 276480A b c  - 102400B b c )x  + (- 102400A b c  - 16384B b  c)x
+--R     + 
+--R                 10   2
+--R       - 16384A b  c x
+--R  /
+--R                  8 16         7 14        2 6 12         3 5 10         4 4 8
+--R                 c x   + 113b c x   + 2128b c x   + 15456b c x   + 55680b c x
+--R               + 
+--R                        5 3 6          6 2 4         7   2         8
+--R                 109824b c x  + 120832b c x  + 69632b c x  + 16384b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                      8 15         7 13        2 6 11         3 5 9
+--R                 - 15c x   - 560b c x   - 6048b c x   - 28800b c x
+--R               + 
+--R                         4 4 7         5 3 5         6 2 3         7
+--R                 - 70400b c x  - 92160b c x  - 61440b c x  - 16384b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  8 16         7 14        2 6 12         3 5 10         4 4 8
+--R             - 15c x   - 575b c x   - 6608b c x   - 34848b c x   - 99200b c x
+--R           + 
+--R                      5 3 6          6 2 4         7   2         8
+--R             - 162560b c x  - 153600b c x  - 77824b c x  - 16384b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          9 17         8 15        2 7 13         3 6 11         4 5 9
+--R         c x   + 113b c x   + 2128b c x   + 15456b c x   + 55680b c x
+--R       + 
+--R                5 4 7          6 3 5         7 2 3         8
+--R         109824b c x  + 120832b c x  + 69632b c x  + 16384b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 878
+
+--S 879 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        2 3        3 2  4            3 2        4   2         4
+--R               (- 108A b c  + 18B b c )x  + (- 576A b c  + 96B b c)x  - 576A b c
+--R             + 
+--R                    5
+--R               96B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                     2 4       3 3  6          3 3        4 2  4
+--R               (18A b c  - 3B b c )x  + (324A b c  - 54B b c )x
+--R             + 
+--R                      4 2         5   2         5         6
+--R               (864A b c  - 144B b c)x  + 576A b c - 96B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                      2 3        3 2  4           3 2         4   2          4
+--R               (216A b c  - 36B b c )x  + (1152A b c  - 192B b c)x  + 1152A b c
+--R             + 
+--R                       5
+--R               - 192B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                       2 4       3 3  6            3 3         4 2  4
+--R               (- 36A b c  + 6B b c )x  + (- 648A b c  + 108B b c )x
+--R             + 
+--R                         4 2         5   2          5          6
+--R               (- 1728A b c  + 288B b c)x  - 1152A b c + 192B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                      4 8           4           3  6
+--R               - 48B c x  + (- 72A c  - 340B b c )x
+--R             + 
+--R                          3         2 2  4             2 2         3   2
+--R               (- 564A b c  - 722B b c )x  + (- 1344A b c  - 544B b c)x
+--R             + 
+--R                       3         4
+--R               - 960A b c - 96B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                   5 10         5           4  8            4         2 3  6
+--R               8B c x   + (12A c  + 158B b c )x  + (246A b c  + 639B b c )x
+--R             + 
+--R                       2 3         3 2  4           3 2         4   2         4
+--R               (1116A b c  + 982B b c )x  + (1824A b c  + 592B b c)x  + 960A b c
+--R             + 
+--R                    5
+--R               96B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 5 11           5           4  9              4         2 3  7
+--R           - 8B c x   + (- 12A c  - 158B b c )x  + (- 246A b c  - 639B b c )x
+--R         + 
+--R                     2 3         3 2  5             3 2         4   3
+--R           (- 1116A b c  - 982B b c )x  + (- 1824A b c  - 592B b c)x
+--R         + 
+--R                    4         5
+--R           (- 960A b c - 96B b )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                5 11         5           4  9            4          2 3  7
+--R           48B c x   + (72A c  + 388B b c )x  + (636A b c  + 1062B b c )x
+--R         + 
+--R                   2 3          3 2  5           3 2         4   3
+--R           (1908A b c  + 1266B b c )x  + (2304A b c  + 640B b c)x
+--R         + 
+--R                  4         5
+--R           (960A b c + 96B b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R                                                      +--------+
+--R            3 4          2 2        2   +---+ +-+ +-+ |   2
+--R       (288c x  + 1536b c x  + 1536b c)\|- c \|b \|c \|c x  + b
+--R     + 
+--R             4 6         3 4        2 2 2        3   +---+ +-+
+--R       (- 48c x  - 864b c x  - 2304b c x  - 1536b c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 879
+
+--S 880 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      7 16           7           6  14
+--R               - 12B c x   + (- 12A c  - 304B b c )x
+--R             + 
+--R                          6          2 5  12             2 5          3 4  10
+--R               (- 304A b c  - 2364B b c )x   + (- 2364A b c  - 8472B b c )x
+--R             + 
+--R                         3 4           4 3  8              4 3           5 2  6
+--R               (- 8472A b c  - 16128B b c )x  + (- 16128A b c  - 16896B b c )x
+--R             + 
+--R                          5 2          6   4             6           7  2
+--R               (- 16896A b c  - 9216B b c)x  + (- 9216A b c - 2048B b )x
+--R             + 
+--R                        7
+--R               - 2048A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              8 18       8          7  16           7         2 6  14
+--R           B c x   + (A c  + 74B b c )x   + (74A b c  + 985B b c )x
+--R         + 
+--R                  2 6          3 5  12           3 5           4 4  10
+--R           (985A b c  + 5336B b c )x   + (5336A b c  + 14920B b c )x
+--R         + 
+--R                    4 4           5 3  8            5 3           6 2  6
+--R           (14920A b c  + 23552B b c )x  + (23552A b c  + 21248B b c )x
+--R         + 
+--R                    6 2           7   4            7           8  2          8
+--R           (21248A b c  + 10240B b c)x  + (10240A b c + 2048B b )x  + 2048A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                8 19         8          7  17             7         2 6  15
+--R           - B c x   + (- A c  - 74B b c )x   + (- 74A b c  - 985B b c )x
+--R         + 
+--R                    2 6          3 5  13             3 5           4 4  11
+--R           (- 985A b c  - 5336B b c )x   + (- 5336A b c  - 14920B b c )x
+--R         + 
+--R                      4 4           5 3  9              5 3           6 2  7
+--R           (- 14920A b c  - 23552B b c )x  + (- 23552A b c  - 21248B b c )x
+--R         + 
+--R                      6 2           7   5              7           8  3
+--R           (- 21248A b c  - 10240B b c)x  + (- 10240A b c - 2048B b )x
+--R         + 
+--R                    8
+--R           - 2048A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                8 19         8           7  17            7          2 6  15
+--R           12B c x   + (12A c  + 316B b c )x   + (316A b c  + 2668B b c )x
+--R         + 
+--R                   2 6           3 5  13            3 5           4 4  11
+--R           (2668A b c  + 10836B b c )x   + (10836A b c  + 24600B b c )x
+--R         + 
+--R                    4 4           5 3  9            5 3           6 2  7
+--R           (24600A b c  + 33024B b c )x  + (33024A b c  + 26112B b c )x
+--R         + 
+--R                    6 2           7   5            7           8  3          8
+--R           (26112A b c  + 11264B b c)x  + (11264A b c + 2048B b )x  + 2048A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              6 12        5 10       2 4 8        3 3 6        4 2 4
+--R             c x   + 72b c x   + 840b c x  + 3584b c x  + 6912b c x
+--R           + 
+--R                  5   2        6
+--R             6144b c x  + 2048b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  6 12         5 10        2 4 8        3 3 6        4 2 4
+--R             - 12c x   - 292b c x   - 2072b c x  - 6400b c x  - 9728b c x
+--R           + 
+--R                    5   2        6
+--R             - 7168b c x  - 2048b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 880
+
+)clear all
+
+--S 881 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^4
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              2
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 881
+
+--S 882 of 3139
+r0:=1/3*A*(b*x^2+c*x^4)^(3/2)/x^3+1/5*B*(b*x^2+c*x^4)^(5/2)/(c*x^5)-_
+   A*b^(3/2)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))+A*b*sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R   (2)
+--R                                   +-+
+--R                   +-+           x\|b
+--R       - 15A b c x\|b atanh(--------------)
+--R                             +-----------+
+--R                             |   4      2
+--R                            \|c x  + b x
+--R     + 
+--R                                                        +-----------+
+--R            2 4        2           2                 2  |   4      2
+--R       (3B c x  + (5A c  + 6B b c)x  + 20A b c + 3B b )\|c x  + b x
+--R  /
+--R     15c x
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                +--------+
+--R                 2 2 4         3   2         4  |   2
+--R           (15A b c x  + 180A b c x  + 240A b )\|c x  + b
+--R         + 
+--R                   2 2 4         3   2         4  +-+
+--R           (- 75A b c x  - 300A b c x  - 240A b )\|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                    3 8             3        2 2  6            2 2         3   4
+--R           - 15B b c x  + (- 25A b c  - 90B b c )x  + (- 180A b c  - 180B b c)x
+--R         + 
+--R                    3          4  2
+--R           (- 240A b c - 120B b )x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               4 10        4          3  8           3         2 2  6
+--R           3B c x   + (5A c  + 45B b c )x  + (85A b c  + 165B b c )x
+--R         + 
+--R                  2 2         3   4          3          4  2
+--R           (300A b c  + 240B b c)x  + (240A b c + 120B b )x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                      +--------+
+--R         2 4           2       2  +-+ |   2             2 4       2   2       3
+--R     (15c x  + 180b c x  + 240b )\|b \|c x  + b  - 75b c x  - 300b c x  - 240b
+--R                                         Type: Union(Expression(Integer),...)
+--E 883
+
+--S 884 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                   +--------+
+--R                 2 3 5         3 2 3         4     |   2
+--R           (15A b c x  + 180A b c x  + 240A b c x)\|c x  + b
+--R         + 
+--R                   2 3 5         3 2 3         4     +-+
+--R           (- 75A b c x  - 300A b c x  - 240A b c x)\|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                                   +--------+
+--R                 2 3 5         3 2 3         4     |   2
+--R           (15A b c x  + 180A b c x  + 240A b c x)\|c x  + b
+--R         + 
+--R                   2 3 5         3 2 3         4     +-+
+--R           (- 75A b c x  - 300A b c x  - 240A b c x)\|b
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                     4 8          4          3  6             3         2 2  4
+--R               - 3B c x  + (- 5A c  - 42B b c )x  + (- 80A b c  - 123B b c )x
+--R             + 
+--R                        2 2         3   2         3         4
+--R               (- 320A b c  - 132B b c)x  - 320A b c - 48B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  4 8           4        2 3  6          2 3         3 2  4
+--R           15B b c x  + (25A b c  + 90B b c )x  + (200A b c  + 183B b c )x
+--R         + 
+--R                  3 2         4   2         4         5
+--R           (480A b c  + 156B b c)x  + 320A b c + 48B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    4 9             4        2 3  7
+--R           - 15B b c x  + (- 25A b c  - 90B b c )x
+--R         + 
+--R                    2 3         3 2  5            3 2         4   3
+--R           (- 180A b c  - 180B b c )x  + (- 240A b c  - 120B b c)x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               5 11        5          4  9           4         2 3  7
+--R           3B c x   + (5A c  + 45B b c )x  + (85A b c  + 165B b c )x
+--R         + 
+--R                  2 3         3 2  5          3 2         4   3
+--R           (300A b c  + 240B b c )x  + (240A b c  + 120B b c)x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                           +--------+
+--R           3 5         2 3       2     +-+ |   2             3 5       2 2 3
+--R       (15c x  + 180b c x  + 240b c x)\|b \|c x  + b  - 75b c x  - 300b c x
+--R     + 
+--R             3
+--R       - 240b c x
+--R                                                    Type: Expression(Integer)
+--E 884
+
+--S 885 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    7 16         7          6  14             6         2 5  12
+--R               - B c x   + (- A c  - 62B b c )x   + (- 62A b c  - 681B b c )x
+--R             + 
+--R                        2 5          3 4  10             3 4          4 3  8
+--R               (- 681A b c  - 2972B b c )x   + (- 2972A b c  - 6448B b c )x
+--R             + 
+--R                         4 3          5 2  6             5 2          6   4
+--R               (- 6448A b c  - 7424B b c )x  + (- 7424A b c  - 4352B b c)x
+--R             + 
+--R                         6           7  2          7
+--R               (- 4352A b c - 1024B b )x  - 1024A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    7 16         7           6  14            6          2 5  12
+--R               11B c x   + (11A c  + 242B b c )x   + (242A b c  + 1683B b c )x
+--R             + 
+--R                       2 5          3 4  10           3 4          4 3  8
+--R               (1683A b c  + 5500B b c )x   + (5500A b c  + 9680B b c )x
+--R             + 
+--R                       4 3          5 2  6           5 2          6   4
+--R               (9680A b c  + 9472B b c )x  + (9472A b c  + 4864B b c)x
+--R             + 
+--R                       6           7  2          7
+--R               (4864A b c + 1024B b )x  + 1024A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  7 17           7           6  15
+--R           - 11B c x   + (- 11A c  - 242B b c )x
+--R         + 
+--R                      6          2 5  13             2 5          3 4  11
+--R           (- 242A b c  - 1683B b c )x   + (- 1683A b c  - 5500B b c )x
+--R         + 
+--R                     3 4          4 3  9             4 3          5 2  7
+--R           (- 5500A b c  - 9680B b c )x  + (- 9680A b c  - 9472B b c )x
+--R         + 
+--R                   5 2          6   5             6           7  3          7
+--R         (- 9472A b c  - 4864B b c)x  + (- 4864A b c - 1024B b )x  - 1024A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          8 19       8          7  17           7         2 6  15
+--R       B c x   + (A c  + 63B b c )x   + (63A b c  + 743B b c )x
+--R     + 
+--R              2 6          3 5  13           3 5          4 4  11
+--R       (743A b c  + 3653B b c )x   + (3653A b c  + 9420B b c )x
+--R     + 
+--R               4 4           5 3  9            5 3           6 2  7
+--R       (9420A b c  + 13872B b c )x  + (13872A b c  + 11776B b c )x
+--R     + 
+--R                6 2          7   5           7           8  3          8
+--R       (11776A b c  + 5376B b c)x  + (5376A b c + 1024B b )x  + 1024A b x
+--R  /
+--R                  5 11         4 9        2 3 7        3 2 5        4   3
+--R               11c x   + 220b c x  + 1232b c x  + 2816b c x  + 2816b c x
+--R             + 
+--R                    5
+--R               1024b x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R            6 13        5 11       2 4 9        3 3 7        4 2 5        5   3
+--R         - c x   - 61b c x   - 620b c x  - 2352b c x  - 4096b c x  - 3328b c x
+--R       + 
+--R                6
+--R         - 1024b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 885
+
+)clear all
+
+--S 886 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^5
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              3
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 886
+
+--S 887 of 3139
+r0:=1/4*(b*B+4*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^2)-A*(b*x^2+c*x^4)^(5/2)/_
+   (b*x^6)+3/8*b*(b*B+4*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/_
+   sqrt(c)+3/8*(b*B+4*A*c)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R   (2)
+--R                                     2 +-+
+--R                      2  2          x \|c
+--R       (12A b c + 3B b )x atanh(--------------)
+--R                                 +-----------+
+--R                                 |   4      2
+--R                                \|c x  + b x
+--R     + 
+--R                                              +-----------+
+--R              4                 2         +-+ |   4      2
+--R       (2B c x  + (4A c + 5B b)x  - 8A b)\|c \|c x  + b x
+--R  /
+--R       2 +-+
+--R     8x \|c
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         3       2 2  5          2 2        3   3
+--R                 (12A b c  + 3B b c )x  + (144A b c  + 36B b c)x
+--R               + 
+--R                        3         4
+--R                 (192A b c + 48B b )x
+--R            *
+--R                +--------+
+--R                |   2
+--R               \|c x  + b
+--R           + 
+--R                           3        2 2  5            2 2        3   3
+--R                 (- 60A b c  - 15B b c )x  + (- 240A b c  - 60B b c)x
+--R               + 
+--R                          3         4
+--R                 (- 192A b c - 48B b )x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                    3 8           3          2  6             2         2   4
+--R             - 10B c x  + (- 20A c  - 65B b c )x  + (- 40A b c  - 132B b c)x
+--R           + 
+--R                   2         3  2         3
+--R             (96A b c - 80B b )x  + 128A b
+--R        *
+--R                    +--------+
+--R            +-+ +-+ |   2
+--R           \|b \|c \|c x  + b
+--R       + 
+--R                 4 10        4          3  8           3         2 2  6
+--R             2B c x   + (4A c  + 31B b c )x  + (44A b c  + 121B b c )x
+--R           + 
+--R                  2 2         3   4            3         4  2         4
+--R             (8A b c  + 172B b c)x  + (- 160A b c + 80B b )x  - 128A b
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                                         +--------+
+--R            2 5          3       2   +-+ |   2
+--R         (8c x  + 96b c x  + 128b x)\|c \|c x  + b
+--R       + 
+--R               2 5           3       2   +-+ +-+
+--R         (- 40c x  - 160b c x  - 128b x)\|b \|c
+--R     ,
+--R
+--R                         3       2 2  5          2 2        3   3
+--R                 (24A b c  + 6B b c )x  + (288A b c  + 72B b c)x
+--R               + 
+--R                        3         4
+--R                 (384A b c + 96B b )x
+--R            *
+--R                +--------+
+--R                |   2
+--R               \|c x  + b
+--R           + 
+--R                            3        2 2  5            2 2         3   3
+--R                 (- 120A b c  - 30B b c )x  + (- 480A b c  - 120B b c)x
+--R               + 
+--R                          3         4
+--R                 (- 384A b c - 96B b )x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                    3 8           3          2  6             2         2   4
+--R             - 10B c x  + (- 20A c  - 65B b c )x  + (- 40A b c  - 132B b c)x
+--R           + 
+--R                   2         3  2         3
+--R             (96A b c - 80B b )x  + 128A b
+--R        *
+--R                      +--------+
+--R            +---+ +-+ |   2
+--R           \|- c \|b \|c x  + b
+--R       + 
+--R                 4 10        4          3  8           3         2 2  6
+--R             2B c x   + (4A c  + 31B b c )x  + (44A b c  + 121B b c )x
+--R           + 
+--R                  2 2         3   4            3         4  2         4
+--R             (8A b c  + 172B b c)x  + (- 160A b c + 80B b )x  - 128A b
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                                           +--------+
+--R            2 5          3       2   +---+ |   2
+--R         (8c x  + 96b c x  + 128b x)\|- c \|c x  + b
+--R       + 
+--R               2 5           3       2   +---+ +-+
+--R         (- 40c x  - 160b c x  - 128b x)\|- c \|b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 888
+
+--S 889 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       3       2 2  6          2 2        3   4
+--R               (12A b c  + 3B b c )x  + (144A b c  + 36B b c)x
+--R             + 
+--R                      3         4  2
+--R               (192A b c + 48B b )x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                         3        2 2  6            2 2        3   4
+--R               (- 60A b c  - 15B b c )x  + (- 240A b c  - 60B b c)x
+--R             + 
+--R                        3         4  2
+--R               (- 192A b c - 48B b )x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                         3       2 2  6            2 2        3   4
+--R               (- 12A b c  - 3B b c )x  + (- 144A b c  - 36B b c)x
+--R             + 
+--R                        3         4  2
+--R               (- 192A b c - 48B b )x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                       3        2 2  6          2 2        3   4
+--R               (60A b c  + 15B b c )x  + (240A b c  + 60B b c)x
+--R             + 
+--R                      3         4  2
+--R               (192A b c + 48B b )x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                     3 8          3          2  6             2        2   4
+--R               - 2B c x  + (- 4A c  - 29B b c )x  + (- 40A b c  - 92B b c)x
+--R             + 
+--R                     2         3  2         3
+--R               (32A b c - 80B b )x  + 128A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|c x  + b
+--R         + 
+--R                    3 8         3          2  6           2         2   4
+--R               10B c x  + (20A c  + 65B b c )x  + (40A b c  + 132B b c)x
+--R             + 
+--R                       2         3  2         3
+--R               (- 96A b c + 80B b )x  - 128A b
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  3 9           3          2  7             2         2   5
+--R           - 10B c x  + (- 20A c  - 65B b c )x  + (- 40A b c  - 132B b c)x
+--R         + 
+--R                 2         3  3         3
+--R           (96A b c - 80B b )x  + 128A b x
+--R      *
+--R                  +--------+
+--R          +-+ +-+ |   2
+--R         \|b \|c \|c x  + b
+--R     + 
+--R               4 11        4          3  9           3         2 2  7
+--R           2B c x   + (4A c  + 31B b c )x  + (44A b c  + 121B b c )x
+--R         + 
+--R                2 2         3   5            3         4  3         4
+--R           (8A b c  + 172B b c)x  + (- 160A b c + 80B b )x  - 128A b x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                        +--------+
+--R          2 6          4       2 2  +-+ |   2
+--R       (8c x  + 96b c x  + 128b x )\|c \|c x  + b
+--R     + 
+--R             2 6           4       2 2  +-+ +-+
+--R       (- 40c x  - 160b c x  - 128b x )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 889
+
+--S 890 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          8 18           8           7  16
+--R                   - 13B c x   + (- 13A c  - 390B b c )x
+--R                 + 
+--R                              7          2 6  14
+--R                   (- 390A b c  - 3653B b c )x
+--R                 + 
+--R                             2 6           3 5  12
+--R                   (- 3653A b c  - 16172B b c )x
+--R                 + 
+--R                              3 5           4 4  10
+--R                   (- 16172A b c  - 39520B b c )x
+--R                 + 
+--R                              4 4           5 3  8
+--R                   (- 39520A b c  - 56576B b c )x
+--R                 + 
+--R                              5 3           6 2  6
+--R                   (- 56576A b c  - 47360B b c )x
+--R                 + 
+--R                              6 2           7   4              7           8  2
+--R                   (- 47360A b c  - 21504B b c)x  + (- 21504A b c - 4096B b )x
+--R                 + 
+--R                            8
+--R                   - 4096A b
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  9 19       9          8  17           8          2 7  15
+--R               B c x   + (A c  + 86B b c )x   + (86A b c  + 1289B b c )x
+--R             + 
+--R                       2 7          3 6  13           3 6           4 5  11
+--R               (1289A b c  + 7700B b c )x   + (7700A b c  + 23392B b c )x
+--R             + 
+--R                        4 5           5 4  9            5 4           6 3  7
+--R               (23392A b c  + 39680B b c )x  + (39680A b c  + 38144B b c )x
+--R             + 
+--R                        6 3           7 2  5            7 2          8   3
+--R               (38144A b c  + 19456B b c )x  + (19456A b c  + 4096B b c)x
+--R             + 
+--R                      8
+--R               4096A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  9 20       9          8  18           8          2 7  16
+--R               B c x   + (A c  + 87B b c )x   + (87A b c  + 1375B b c )x
+--R             + 
+--R                       2 7          3 6  14           3 6           4 5  12
+--R               (1375A b c  + 8989B b c )x   + (8989A b c  + 31092B b c )x
+--R             + 
+--R                        4 5           5 4  10            5 4           6 3  8
+--R               (31092A b c  + 63072B b c )x   + (63072A b c  + 77824B b c )x
+--R             + 
+--R                        6 3           7 2  6            7 2           8   4
+--R               (77824A b c  + 57600B b c )x  + (57600A b c  + 23552B b c)x
+--R             + 
+--R                        8           9  2          9
+--R               (23552A b c + 4096B b )x  + 4096A b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      9 19           9           8  17
+--R               - 13B c x   + (- 13A c  - 390B b c )x
+--R             + 
+--R                          8          2 7  15             2 7           3 6  13
+--R               (- 390A b c  - 3653B b c )x   + (- 3653A b c  - 16172B b c )x
+--R             + 
+--R                          3 6           4 5  11
+--R               (- 16172A b c  - 39520B b c )x
+--R             + 
+--R                          4 5           5 4  9              5 4           6 3  7
+--R               (- 39520A b c  - 56576B b c )x  + (- 56576A b c  - 47360B b c )x
+--R             + 
+--R                          6 3           7 2  5              7 2          8   3
+--R               (- 47360A b c  - 21504B b c )x  + (- 21504A b c  - 4096B b c)x
+--R             + 
+--R                        8
+--R               - 4096A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    9 21         9          8  19             8          2 7  17
+--R               - B c x   + (- A c  - 87B b c )x   + (- 87A b c  - 1375B b c )x
+--R             + 
+--R                         2 7          3 6  15             3 6           4 5  13
+--R               (- 1375A b c  - 8989B b c )x   + (- 8989A b c  - 31092B b c )x
+--R             + 
+--R                          4 5           5 4  11
+--R               (- 31092A b c  - 63072B b c )x
+--R             + 
+--R                          5 4           6 3  9              6 3           7 2  7
+--R               (- 63072A b c  - 77824B b c )x  + (- 77824A b c  - 57600B b c )x
+--R             + 
+--R                          7 2           8   5              8           9  3
+--R               (- 57600A b c  - 23552B b c)x  + (- 23552A b c - 4096B b )x
+--R             + 
+--R                        9
+--R               - 4096A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    9 20         9           8  18            8          2 7  16
+--R               13B c x   + (13A c  + 390B b c )x   + (390A b c  + 3653B b c )x
+--R             + 
+--R                       2 7           3 6  14            3 6           4 5  12
+--R               (3653A b c  + 16172B b c )x   + (16172A b c  + 39520B b c )x
+--R             + 
+--R                        4 5           5 4  10            5 4           6 3  8
+--R               (39520A b c  + 56576B b c )x   + (56576A b c  + 47360B b c )x
+--R             + 
+--R                        6 3           7 2  6            7 2          8   4
+--R               (47360A b c  + 21504B b c )x  + (21504A b c  + 4096B b c)x
+--R             + 
+--R                      8   2
+--R               4096A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                9 21         9           8  19            8          2 7  17
+--R           13B c x   + (13A c  + 403B b c )x   + (403A b c  + 4043B b c )x
+--R         + 
+--R                   2 7           3 6  15            3 6           4 5  13
+--R           (4043A b c  + 19825B b c )x   + (19825A b c  + 55692B b c )x
+--R         + 
+--R                    4 5           5 4  11            5 4            6 3  9
+--R           (55692A b c  + 96096B b c )x   + (96096A b c  + 103936B b c )x
+--R         + 
+--R                     6 3           7 2  7            7 2           8   5
+--R           (103936A b c  + 68864B b c )x  + (68864A b c  + 25600B b c)x
+--R         + 
+--R                    8           9  3          9
+--R           (25600A b c + 4096B b )x  + 4096A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            10 22         10          9  20             9          2 8  18
+--R       - B c  x   + (- A c   - 87B b c )x   + (- 87A b c  - 1375B b c )x
+--R     + 
+--R                 2 8          3 7  16             3 7           4 6  14
+--R       (- 1375A b c  - 8989B b c )x   + (- 8989A b c  - 31092B b c )x
+--R     + 
+--R                  4 6           5 5  12              5 5           6 4  10
+--R       (- 31092A b c  - 63072B b c )x   + (- 63072A b c  - 77824B b c )x
+--R     + 
+--R                  6 4           7 3  8              7 3           8 2  6
+--R       (- 77824A b c  - 57600B b c )x  + (- 57600A b c  - 23552B b c )x
+--R     + 
+--R                  8 2          9   4          9   2
+--R       (- 23552A b c  - 4096B b c)x  - 4096A b c x
+--R  /
+--R                  7 16        6 14        2 5 12        3 4 10         4 3 8
+--R                 c x   + 85b c x   + 1204b c x   + 6496b c x   + 16896b c x
+--R               + 
+--R                       5 2 6         6   4        7 2
+--R                 22784b c x  + 15360b c x  + 4096b x
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                      7 15         6 13        2 5 11        3 4 9         4 3 7
+--R                 - 13c x   - 364b c x   - 2912b c x   - 9984b c x  - 16640b c x
+--R               + 
+--R                         5 2 5        6   3
+--R                 - 13312b c x  - 4096b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  7 16         6 14        2 5 12         3 4 10         4 3 8
+--R             - 13c x   - 377b c x   - 3276b c x   - 12896b c x   - 26624b c x
+--R           + 
+--R                     5 2 6         6   4        7 2
+--R             - 29952b c x  - 17408b c x  - 4096b x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          8 17        7 15        2 6 13        3 5 11         4 4 9
+--R         c x   + 85b c x   + 1204b c x   + 6496b c x   + 16896b c x
+--R       + 
+--R               5 3 7         6 2 5        7   3
+--R         22784b c x  + 15360b c x  + 4096b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 890
+
+--S 891 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         3       2 2  6            2 2        3   4
+--R               (- 12A b c  - 3B b c )x  + (- 144A b c  - 36B b c)x
+--R             + 
+--R                        3         4  2
+--R               (- 192A b c - 48B b )x
+--R          *
+--R                    +--------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b
+--R         + 
+--R                       3        2 2  6          2 2        3   4
+--R               (60A b c  + 15B b c )x  + (240A b c  + 60B b c)x
+--R             + 
+--R                      3         4  2
+--R               (192A b c + 48B b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                       3       2 2  6          2 2        3   4
+--R               (24A b c  + 6B b c )x  + (288A b c  + 72B b c)x
+--R             + 
+--R                      3         4  2
+--R               (384A b c + 96B b )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|c x  + b
+--R         + 
+--R                          3        2 2  6            2 2         3   4
+--R               (- 120A b c  - 30B b c )x  + (- 480A b c  - 120B b c)x
+--R             + 
+--R                        3         4  2
+--R               (- 384A b c - 96B b )x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                     3 8          3          2  6             2        2   4
+--R               - 2B c x  + (- 4A c  - 29B b c )x  + (- 40A b c  - 92B b c)x
+--R             + 
+--R                     2         3  2         3
+--R               (32A b c - 80B b )x  + 128A b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b
+--R         + 
+--R                    3 8         3          2  6           2         2   4
+--R               10B c x  + (20A c  + 65B b c )x  + (40A b c  + 132B b c)x
+--R             + 
+--R                       2         3  2         3
+--R               (- 96A b c + 80B b )x  - 128A b
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|b \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  3 9           3          2  7             2         2   5
+--R           - 10B c x  + (- 20A c  - 65B b c )x  + (- 40A b c  - 132B b c)x
+--R         + 
+--R                 2         3  3         3
+--R           (96A b c - 80B b )x  + 128A b x
+--R      *
+--R                        +--------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|b \|c \|c x  + b
+--R     + 
+--R               4 11        4          3  9           3         2 2  7
+--R           2B c x   + (4A c  + 31B b c )x  + (44A b c  + 121B b c )x
+--R         + 
+--R                2 2         3   5            3         4  3         4
+--R           (8A b c  + 172B b c)x  + (- 160A b c + 80B b )x  - 128A b x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                                              +--------+
+--R          2 6          4       2 2  +---+ +-+ |   2
+--R       (8c x  + 96b c x  + 128b x )\|- c \|c \|c x  + b
+--R     + 
+--R             2 6           4       2 2  +---+ +-+ +-+
+--R       (- 40c x  - 160b c x  - 128b x )\|- c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 891
+
+--S 892 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      6 14           6           5  12
+--R               - 10B c x   + (- 10A c  - 180B b c )x
+--R             + 
+--R                          5          2 4  10             2 4          3 3  8
+--R               (- 180A b c  - 1002B b c )x   + (- 1002A b c  - 2528B b c )x
+--R             + 
+--R                         3 3          4 2  6             4 2          5   4
+--R               (- 2528A b c  - 3232B b c )x  + (- 3232A b c  - 2048B b c)x
+--R             + 
+--R                         5          6  2         6
+--R               (- 2048A b c - 512B b )x  - 512A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              7 16       7          6  14           6         2 5  12
+--R           B c x   + (A c  + 52B b c )x   + (52A b c  + 501B b c )x
+--R         + 
+--R                  2 5          3 4  10           3 4          4 3  8
+--R           (501A b c  + 1970B b c )x   + (1970A b c  + 3920B b c )x
+--R         + 
+--R                   4 3          5 2  6           5 2          6   4
+--R           (3920A b c  + 4192B b c )x  + (4192A b c  + 2304B b c)x
+--R         + 
+--R                   6          7  2         7
+--R           (2304A b c + 512B b )x  + 512A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                7 17         7          6  15             6         2 5  13
+--R           - B c x   + (- A c  - 52B b c )x   + (- 52A b c  - 501B b c )x
+--R         + 
+--R                    2 5          3 4  11             3 4          4 3  9
+--R           (- 501A b c  - 1970B b c )x   + (- 1970A b c  - 3920B b c )x
+--R         + 
+--R                     4 3          5 2  7             5 2          6   5
+--R           (- 3920A b c  - 4192B b c )x  + (- 4192A b c  - 2304B b c)x
+--R         + 
+--R                     6          7  3         7
+--R           (- 2304A b c - 512B b )x  - 512A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 17         7           6  15            6          2 5  13
+--R           10B c x   + (10A c  + 190B b c )x   + (190A b c  + 1182B b c )x
+--R         + 
+--R                   2 5          3 4  11           3 4          4 3  9
+--R           (1182A b c  + 3530B b c )x   + (3530A b c  + 5760B b c )x
+--R         + 
+--R                   4 3          5 2  7           5 2          6   5
+--R           (5760A b c  + 5280B b c )x  + (5280A b c  + 2560B b c)x
+--R         + 
+--R                   6          7  3         7
+--R           (2560A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R             5 12        4 10       2 3 8        3 2 6        4   4       5 2
+--R           (c x   + 50b c x   + 400b c x  + 1120b c x  + 1280b c x  + 512b x )
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  5 12         4 10       2 3 8        3 2 6        4   4
+--R             - 10c x   - 170b c x   - 832b c x  - 1696b c x  - 1536b c x
+--R           + 
+--R                   5 2
+--R             - 512b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 892
+
+)clear all
+
+--S 893 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^6
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              4
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 893
+
+--S 894 of 3139
+r0:=1/6*(2*b*B+3*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^3)-_
+   1/2*A*(b*x^2+c*x^4)^(5/2)/(b*x^7)-1/2*(2*b*B+3*A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))*sqrt(b)+1/2*(2*b*B+3*A*c)*_
+   sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R   (2)
+--R                                         +-+
+--R                       3 +-+           x\|b
+--R       (- 9A c - 6B b)x \|b atanh(--------------)
+--R                                   +-----------+
+--R                                   |   4      2
+--R                                  \|c x  + b x
+--R     + 
+--R                                          +-----------+
+--R              4                 2         |   4      2
+--R       (2B c x  + (6A c + 8B b)x  - 3A b)\|c x  + b x
+--R  /
+--R       3
+--R     6x
+--R                                                    Type: Expression(Integer)
+--E 894
+
+--S 895 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      3       2 2  6          2 2        3   4
+--R               (9A b c  + 6B b c )x  + (108A b c  + 72B b c)x
+--R             + 
+--R                      3         4  2
+--R               (144A b c + 96B b )x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                         3        2 2  6            2 2         3   4
+--R               (- 45A b c  - 30B b c )x  + (- 180A b c  - 120B b c)x
+--R             + 
+--R                        3         4  2
+--R               (- 144A b c - 96B b )x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                    3 8             3        2 2  6           2 2        3   4
+--R           - 10B b c x  + (- 24A b c  - 72B b c )x  + (- 33A b c  - 96B b c)x
+--R         + 
+--R                3   2        4
+--R           60A b c x  + 48A b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               4 10        4          3  8           3         2 2  6
+--R           2B c x   + (6A c  + 34B b c )x  + (45A b c  + 120B b c )x
+--R         + 
+--R                2 2        3   4        3   2        4
+--R           (9A b c  + 96B b c)x  - 84A b c x  - 48A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                     +--------+
+--R        2 6          4      2 2  +-+ |   2             2 6       2   4      3 2
+--R     (6c x  + 72b c x  + 96b x )\|b \|c x  + b  - 30b c x  - 120b c x  - 96b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 895
+
+--S 896 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      3       2 2  7          2 2        3   5
+--R               (9A b c  + 6B b c )x  + (108A b c  + 72B b c)x
+--R             + 
+--R                      3         4  3
+--R               (144A b c + 96B b )x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                         3        2 2  7            2 2         3   5
+--R               (- 45A b c  - 30B b c )x  + (- 180A b c  - 120B b c)x
+--R             + 
+--R                        3         4  3
+--R               (- 144A b c - 96B b )x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                      3       2 2  7          2 2        3   5
+--R               (9A b c  + 6B b c )x  + (108A b c  + 72B b c)x
+--R             + 
+--R                      3         4  3
+--R               (144A b c + 96B b )x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                         3        2 2  7            2 2         3   5
+--R               (- 45A b c  - 30B b c )x  + (- 180A b c  - 120B b c)x
+--R             + 
+--R                        3         4  3
+--R               (- 144A b c - 96B b )x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                     3 8          3          2  6             2         2   4
+--R               - 2B c x  + (- 6A c  - 32B b c )x  + (- 69A b c  - 128B b c)x
+--R             + 
+--R                       2          3  2        3
+--R               (- 60A b c - 128B b )x  + 48A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  3 8           3        2 2  6          2 2         3   4
+--R           10B b c x  + (30A b c  + 80B b c )x  + (105A b c  + 192B b c)x
+--R         + 
+--R                 3          4  2        4
+--R           (36A b c + 128B b )x  - 48A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    3 9             3        2 2  7           2 2        3   5
+--R           - 10B b c x  + (- 24A b c  - 72B b c )x  + (- 33A b c  - 96B b c)x
+--R         + 
+--R                3   3        4
+--R           60A b c x  + 48A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               4 11        4          3  9           3         2 2  7
+--R           2B c x   + (6A c  + 34B b c )x  + (45A b c  + 120B b c )x
+--R         + 
+--R                2 2        3   5        3   3        4
+--R           (9A b c  + 96B b c)x  - 84A b c x  - 48A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                     +--------+
+--R        2 7          5      2 3  +-+ |   2             2 7       2   5      3 3
+--R     (6c x  + 72b c x  + 96b x )\|b \|c x  + b  - 30b c x  - 120b c x  - 96b x
+--R                                                    Type: Expression(Integer)
+--E 896
+
+--S 897 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    7 16         7          6  14             6         2 5  12
+--R               - B c x   + (- A c  - 62B b c )x   + (- 62A b c  - 681B b c )x
+--R             + 
+--R                        2 5          3 4  10             3 4          4 3  8
+--R               (- 681A b c  - 2972B b c )x   + (- 2972A b c  - 6448B b c )x
+--R             + 
+--R                         4 3          5 2  6             5 2          6   4
+--R               (- 6448A b c  - 7424B b c )x  + (- 7424A b c  - 4352B b c)x
+--R             + 
+--R                         6           7  2          7
+--R               (- 4352A b c - 1024B b )x  - 1024A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    7 16         7           6  14            6          2 5  12
+--R               11B c x   + (11A c  + 242B b c )x   + (242A b c  + 1683B b c )x
+--R             + 
+--R                       2 5          3 4  10           3 4          4 3  8
+--R               (1683A b c  + 5500B b c )x   + (5500A b c  + 9680B b c )x
+--R             + 
+--R                       4 3          5 2  6           5 2          6   4
+--R               (9680A b c  + 9472B b c )x  + (9472A b c  + 4864B b c)x
+--R             + 
+--R                       6           7  2          7
+--R               (4864A b c + 1024B b )x  + 1024A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  7 17           7           6  15
+--R           - 11B c x   + (- 11A c  - 242B b c )x
+--R         + 
+--R                      6          2 5  13             2 5          3 4  11
+--R           (- 242A b c  - 1683B b c )x   + (- 1683A b c  - 5500B b c )x
+--R         + 
+--R                     3 4          4 3  9             4 3          5 2  7
+--R           (- 5500A b c  - 9680B b c )x  + (- 9680A b c  - 9472B b c )x
+--R         + 
+--R                   5 2          6   5             6           7  3          7
+--R         (- 9472A b c  - 4864B b c)x  + (- 4864A b c - 1024B b )x  - 1024A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          8 19       8          7  17           7         2 6  15
+--R       B c x   + (A c  + 63B b c )x   + (63A b c  + 743B b c )x
+--R     + 
+--R              2 6          3 5  13           3 5          4 4  11
+--R       (743A b c  + 3653B b c )x   + (3653A b c  + 9420B b c )x
+--R     + 
+--R               4 4           5 3  9            5 3           6 2  7
+--R       (9420A b c  + 13872B b c )x  + (13872A b c  + 11776B b c )x
+--R     + 
+--R                6 2          7   5           7           8  3          8
+--R       (11776A b c  + 5376B b c)x  + (5376A b c + 1024B b )x  + 1024A b x
+--R  /
+--R                5 13         4 11        2 3 9        3 2 7        4   5
+--R             11c x   + 220b c x   + 1232b c x  + 2816b c x  + 2816b c x
+--R           + 
+--R                  5 3
+--R             1024b x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R            6 15        5 13       2 4 11        3 3 9        4 2 7        5   5
+--R         - c x   - 61b c x   - 620b c x   - 2352b c x  - 4096b c x  - 3328b c x
+--R       + 
+--R                6 3
+--R         - 1024b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 897
+
+)clear all
+
+--S 898 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^7
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              5
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 898
+
+--S 899 of 3139
+r0:=-1/3*(3*b*B+2*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^4)-_
+   1/3*A*(b*x^2+c*x^4)^(5/2)/(b*x^8)+1/2*(3*b*B+2*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))*sqrt(c)+1/2*c*(3*b*B+2*A*c)*_
+   sqrt(b*x^2+c*x^4)/b
+--R 
+--R
+--R   (2)
+--R                                     2 +-+
+--R                     4 +-+          x \|c
+--R       (6A c + 9B b)x \|c atanh(--------------)
+--R                                 +-----------+
+--R                                 |   4      2
+--R                                \|c x  + b x
+--R     + 
+--R                                            +-----------+
+--R              4                   2         |   4      2
+--R       (3B c x  + (- 8A c - 6B b)x  - 2A b)\|c x  + b x
+--R  /
+--R       4
+--R     6x
+--R                                                    Type: Expression(Integer)
+--E 899
+
+--S 900 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3         2  7           2         2   5
+--R                 (6A c  + 9B b c )x  + (72A b c  + 108B b c)x
+--R               + 
+--R                       2          3  3
+--R                 (96A b c + 144B b )x
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|c \|c x  + b
+--R           + 
+--R                         3          2  7              2         2   5
+--R                 (- 30A c  - 45B b c )x  + (- 120A b c  - 180B b c)x
+--R               + 
+--R                         2          3  3
+--R                 (- 96A b c - 144B b )x
+--R            *
+--R                +-+ +-+
+--R               \|b \|c
+--R        *
+--R                                +--------+
+--R                    +-+    +-+  |   2          +-+ +-+      2
+--R               (- x\|c  + \|b )\|c x  + b  + x\|b \|c  - c x  - b
+--R           log(--------------------------------------------------)
+--R                                    +--------+
+--R                                +-+ |   2
+--R                               \|b \|c x  + b  - b
+--R       + 
+--R                    3 8         3          2  6            2        2   4
+--R             - 15B c x  + (40A c  - 30B b c )x  + (170A b c  + 72B b c)x
+--R           + 
+--R                    2         3  2        3
+--R             (168A b c + 96B b )x  + 32A b
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R             4 10          4          3  8              3       2 2  6
+--R         3B c x   + (- 8A c  + 33B b c )x  + (- 106A b c  + 6B b c )x
+--R       + 
+--R                  2 2         3   4            3         4  2        4
+--R         (- 250A b c  - 120B b c)x  + (- 184A b c - 96B b )x  - 32A b
+--R    /
+--R                                     +--------+
+--R            2 7          5      2 3  |   2
+--R         (6c x  + 72b c x  + 96b x )\|c x  + b
+--R       + 
+--R               2 7           5      2 3  +-+
+--R         (- 30c x  - 120b c x  - 96b x )\|b
+--R     ,
+--R
+--R                       3          2  7            2         2   5
+--R                 (12A c  + 18B b c )x  + (144A b c  + 216B b c)x
+--R               + 
+--R                        2          3  3
+--R                 (192A b c + 288B b )x
+--R            *
+--R                      +--------+
+--R                +---+ |   2
+--R               \|- c \|c x  + b
+--R           + 
+--R                         3          2  7              2         2   5
+--R                 (- 60A c  - 90B b c )x  + (- 240A b c  - 360B b c)x
+--R               + 
+--R                          2          3  3
+--R                 (- 192A b c - 288B b )x
+--R            *
+--R                +---+ +-+
+--R               \|- c \|b
+--R        *
+--R                 +--------+
+--R                 |   2         +-+
+--R                \|c x  + b  - \|b
+--R           atan(------------------)
+--R                        +---+
+--R                      x\|- c
+--R       + 
+--R                    3 8         3          2  6            2        2   4
+--R             - 15B c x  + (40A c  - 30B b c )x  + (170A b c  + 72B b c)x
+--R           + 
+--R                    2         3  2        3
+--R             (168A b c + 96B b )x  + 32A b
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R             4 10          4          3  8              3       2 2  6
+--R         3B c x   + (- 8A c  + 33B b c )x  + (- 106A b c  + 6B b c )x
+--R       + 
+--R                  2 2         3   4            3         4  2        4
+--R         (- 250A b c  - 120B b c)x  + (- 184A b c - 96B b )x  - 32A b
+--R    /
+--R                                     +--------+
+--R            2 7          5      2 3  |   2
+--R         (6c x  + 72b c x  + 96b x )\|c x  + b
+--R       + 
+--R               2 7           5      2 3  +-+
+--R         (- 30c x  - 120b c x  - 96b x )\|b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 900
+
+--S 901 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3         2  8           2         2   6
+--R               (6A c  + 9B b c )x  + (72A b c  + 108B b c)x
+--R             + 
+--R                     2          3  4
+--R               (96A b c + 144B b )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|c x  + b
+--R         + 
+--R                       3          2  8              2         2   6
+--R               (- 30A c  - 45B b c )x  + (- 120A b c  - 180B b c)x
+--R             + 
+--R                       2          3  4
+--R               (- 96A b c - 144B b )x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R      *
+--R                              +--------+
+--R                  +-+    +-+  |   2          +-+ +-+      2
+--R             (- x\|c  + \|b )\|c x  + b  + x\|b \|c  - c x  - b
+--R         log(--------------------------------------------------)
+--R                                  +--------+
+--R                              +-+ |   2
+--R                             \|b \|c x  + b  - b
+--R     + 
+--R                      3         2  8             2         2   6
+--R               (- 6A c  - 9B b c )x  + (- 72A b c  - 108B b c)x
+--R             + 
+--R                       2          3  4
+--R               (- 96A b c - 144B b )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|c x  + b
+--R         + 
+--R                     3          2  8            2         2   6
+--R               (30A c  + 45B b c )x  + (120A b c  + 180B b c)x
+--R             + 
+--R                     2          3  4
+--R               (96A b c + 144B b )x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                     3 8        3          2  6           2        2   4
+--R               - 3B c x  + (8A c  - 30B b c )x  + (98A b c  + 24B b c)x
+--R             + 
+--R                      2         3  2        3
+--R               (152A b c + 96B b )x  + 32A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    3 8           3          2  6              2        2   4
+--R               15B c x  + (- 40A c  + 30B b c )x  + (- 170A b c  - 72B b c)x
+--R             + 
+--R                        2         3  2        3
+--R               (- 168A b c - 96B b )x  - 32A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  3 9         3          2  7            2        2   5
+--R           - 15B c x  + (40A c  - 30B b c )x  + (170A b c  + 72B b c)x
+--R         + 
+--R                  2         3  3        3
+--R           (168A b c + 96B b )x  + 32A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R           4 11          4          3  9              3       2 2  7
+--R       3B c x   + (- 8A c  + 33B b c )x  + (- 106A b c  + 6B b c )x
+--R     + 
+--R                2 2         3   5            3         4  3        4
+--R       (- 250A b c  - 120B b c)x  + (- 184A b c - 96B b )x  - 32A b x
+--R  /
+--R                                   +--------+
+--R          2 8          6      2 4  |   2
+--R       (6c x  + 72b c x  + 96b x )\|c x  + b
+--R     + 
+--R             2 8           6      2 4  +-+
+--R       (- 30c x  - 120b c x  - 96b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        8 19         8          7  17
+--R                   - B c x   + (- A c  - 86B b c )x
+--R                 + 
+--R                             7          2 6  15             2 6          3 5  13
+--R                   (- 86A b c  - 1289B b c )x   + (- 1289A b c  - 7700B b c )x
+--R                 + 
+--R                             3 5           4 4  11
+--R                   (- 7700A b c  - 23392B b c )x
+--R                 + 
+--R                              4 4           5 3  9
+--R                   (- 23392A b c  - 39680B b c )x
+--R                 + 
+--R                              5 3           6 2  7
+--R                   (- 39680A b c  - 38144B b c )x
+--R                 + 
+--R                              6 2           7   5              7           8  3
+--R                   (- 38144A b c  - 19456B b c)x  + (- 19456A b c - 4096B b )x
+--R                 + 
+--R                            8
+--R                   - 4096A b x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                        8 18         8           7  16
+--R                   13B c x   + (13A c  + 390B b c )x
+--R                 + 
+--R                            7          2 6  14           2 6           3 5  12
+--R                   (390A b c  + 3653B b c )x   + (3653A b c  + 16172B b c )x
+--R                 + 
+--R                            3 5           4 4  10
+--R                   (16172A b c  + 39520B b c )x
+--R                 + 
+--R                            4 4           5 3  8            5 3           6 2  6
+--R                   (39520A b c  + 56576B b c )x  + (56576A b c  + 47360B b c )x
+--R                 + 
+--R                            6 2           7   4            7           8  2
+--R                   (47360A b c  + 21504B b c)x  + (21504A b c + 4096B b )x
+--R                 + 
+--R                          8
+--R                   4096A b
+--R              *
+--R                  +-+
+--R                 \|b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    8 19         8           7  17            7          2 6  15
+--R               13B c x   + (13A c  + 390B b c )x   + (390A b c  + 3653B b c )x
+--R             + 
+--R                       2 6           3 5  13            3 5           4 4  11
+--R               (3653A b c  + 16172B b c )x   + (16172A b c  + 39520B b c )x
+--R             + 
+--R                        4 4           5 3  9            5 3           6 2  7
+--R               (39520A b c  + 56576B b c )x  + (56576A b c  + 47360B b c )x
+--R             + 
+--R                        6 2           7   5            7           8  3
+--R               (47360A b c  + 21504B b c)x  + (21504A b c + 4096B b )x
+--R             + 
+--R                      8
+--R               4096A b x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R         + 
+--R                9 20         9          8  18             8          2 7  16
+--R           - B c x   + (- A c  - 87B b c )x   + (- 87A b c  - 1375B b c )x
+--R         + 
+--R                     2 7          3 6  14             3 6           4 5  12
+--R           (- 1375A b c  - 8989B b c )x   + (- 8989A b c  - 31092B b c )x
+--R         + 
+--R                      4 5           5 4  10              5 4           6 3  8
+--R           (- 31092A b c  - 63072B b c )x   + (- 63072A b c  - 77824B b c )x
+--R         + 
+--R                      6 3           7 2  6              7 2           8   4
+--R           (- 77824A b c  - 57600B b c )x  + (- 57600A b c  - 23552B b c)x
+--R         + 
+--R                      8           9  2          9
+--R           (- 23552A b c - 4096B b )x  - 4096A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                      8 20           8           7  18
+--R               - 13B c x   + (- 13A c  - 390B b c )x
+--R             + 
+--R                          7          2 6  16             2 6           3 5  14
+--R               (- 390A b c  - 3653B b c )x   + (- 3653A b c  - 16172B b c )x
+--R             + 
+--R                          3 5           4 4  12
+--R               (- 16172A b c  - 39520B b c )x
+--R             + 
+--R                          4 4           5 3  10
+--R               (- 39520A b c  - 56576B b c )x
+--R             + 
+--R                          5 3           6 2  8              6 2           7   6
+--R               (- 56576A b c  - 47360B b c )x  + (- 47360A b c  - 21504B b c)x
+--R             + 
+--R                          7           8  4          8 2
+--R               (- 21504A b c - 4096B b )x  - 4096A b x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R         + 
+--R              9 21       9          8  19           8          2 7  17
+--R           B c x   + (A c  + 87B b c )x   + (87A b c  + 1375B b c )x
+--R         + 
+--R                   2 7          3 6  15           3 6           4 5  13
+--R           (1375A b c  + 8989B b c )x   + (8989A b c  + 31092B b c )x
+--R         + 
+--R                    4 5           5 4  11            5 4           6 3  9
+--R           (31092A b c  + 63072B b c )x   + (63072A b c  + 77824B b c )x
+--R         + 
+--R                    6 3           7 2  7            7 2           8   5
+--R           (77824A b c  + 57600B b c )x  + (57600A b c  + 23552B b c)x
+--R         + 
+--R                    8           9  3          9
+--R           (23552A b c + 4096B b )x  + 4096A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R              9 22       9          8  20           8          2 7  18
+--R           B c x   + (A c  + 87B b c )x   + (87A b c  + 1375B b c )x
+--R         + 
+--R                   2 7          3 6  16           3 6           4 5  14
+--R           (1375A b c  + 8989B b c )x   + (8989A b c  + 31092B b c )x
+--R         + 
+--R                    4 5           5 4  12            5 4           6 3  10
+--R           (31092A b c  + 63072B b c )x   + (63072A b c  + 77824B b c )x
+--R         + 
+--R                    6 3           7 2  8            7 2           8   6
+--R           (77824A b c  + 57600B b c )x  + (57600A b c  + 23552B b c)x
+--R         + 
+--R                    8           9  4          9 2
+--R           (23552A b c + 4096B b )x  + 4096A b x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                  9 21           9           8  19
+--R           - 13B c x   + (- 13A c  - 403B b c )x
+--R         + 
+--R                      8          2 7  17             2 7           3 6  15
+--R           (- 403A b c  - 4043B b c )x   + (- 4043A b c  - 19825B b c )x
+--R         + 
+--R                      3 6           4 5  13              4 5           5 4  11
+--R           (- 19825A b c  - 55692B b c )x   + (- 55692A b c  - 96096B b c )x
+--R         + 
+--R                      5 4            6 3  9               6 3           7 2  7
+--R           (- 96096A b c  - 103936B b c )x  + (- 103936A b c  - 68864B b c )x
+--R         + 
+--R                      7 2           8   5              8           9  3
+--R           (- 68864A b c  - 25600B b c)x  + (- 25600A b c - 4096B b )x
+--R         + 
+--R                    9
+--R           - 4096A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                    6 17         5 15        2 4 13        3 3 11         4 2 9
+--R                 13c x   + 364b c x   + 2912b c x   + 9984b c x   + 16640b c x
+--R               + 
+--R                       5   7        6 5
+--R                 13312b c x  + 4096b x
+--R            *
+--R                +-+ +-+
+--R               \|b \|c
+--R           + 
+--R                7 18        6 16        2 5 14        3 4 12         4 3 10
+--R             - c x   - 85b c x   - 1204b c x   - 6496b c x   - 16896b c x
+--R           + 
+--R                     5 2 8         6   6        7 4
+--R             - 22784b c x  - 15360b c x  - 4096b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                7 19        6 17        2 5 15        3 4 13         4 3 11
+--R             - c x   - 85b c x   - 1204b c x   - 6496b c x   - 16896b c x
+--R           + 
+--R                     5 2 9         6   7        7 5
+--R             - 22784b c x  - 15360b c x  - 4096b x
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                7 18         6 16        2 5 14         3 4 12         4 3 10
+--R             13c x   + 377b c x   + 3276b c x   + 12896b c x   + 26624b c x
+--R           + 
+--R                   5 2 8         6   6        7 4
+--R             29952b c x  + 17408b c x  + 4096b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 902
+
+--S 903 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      3         2  8             2         2   6
+--R               (- 6A c  - 9B b c )x  + (- 72A b c  - 108B b c)x
+--R             + 
+--R                       2          3  4
+--R               (- 96A b c - 144B b )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|c x  + b
+--R         + 
+--R                     3          2  8            2         2   6
+--R               (30A c  + 45B b c )x  + (120A b c  + 180B b c)x
+--R             + 
+--R                     2          3  4
+--R               (96A b c + 144B b )x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                     3          2  8            2         2   6
+--R               (12A c  + 18B b c )x  + (144A b c  + 216B b c)x
+--R             + 
+--R                      2          3  4
+--R               (192A b c + 288B b )x
+--R          *
+--R                    +--------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b
+--R         + 
+--R                       3          2  8              2         2   6
+--R               (- 60A c  - 90B b c )x  + (- 240A b c  - 360B b c)x
+--R             + 
+--R                        2          3  4
+--R               (- 192A b c - 288B b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|b
+--R      *
+--R               +--------+
+--R               |   2         +-+
+--R              \|c x  + b  - \|b
+--R         atan(------------------)
+--R                      +---+
+--R                    x\|- c
+--R     + 
+--R                     3 8        3          2  6           2        2   4
+--R               - 3B c x  + (8A c  - 30B b c )x  + (98A b c  + 24B b c)x
+--R             + 
+--R                      2         3  2        3
+--R               (152A b c + 96B b )x  + 32A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    3 8           3          2  6              2        2   4
+--R               15B c x  + (- 40A c  + 30B b c )x  + (- 170A b c  - 72B b c)x
+--R             + 
+--R                        2         3  2        3
+--R               (- 168A b c - 96B b )x  - 32A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  3 9         3          2  7            2        2   5
+--R           - 15B c x  + (40A c  - 30B b c )x  + (170A b c  + 72B b c)x
+--R         + 
+--R                  2         3  3        3
+--R           (168A b c + 96B b )x  + 32A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R           4 11          4          3  9              3       2 2  7
+--R       3B c x   + (- 8A c  + 33B b c )x  + (- 106A b c  + 6B b c )x
+--R     + 
+--R                2 2         3   5            3         4  3        4
+--R       (- 250A b c  - 120B b c)x  + (- 184A b c - 96B b )x  - 32A b x
+--R  /
+--R                                   +--------+
+--R          2 8          6      2 4  |   2
+--R       (6c x  + 72b c x  + 96b x )\|c x  + b
+--R     + 
+--R             2 8           6      2 4  +-+
+--R       (- 30c x  - 120b c x  - 96b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 903
+
+--S 904 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      6 14           6           5  12
+--R               - 10B c x   + (- 10A c  - 180B b c )x
+--R             + 
+--R                          5          2 4  10             2 4          3 3  8
+--R               (- 180A b c  - 1002B b c )x   + (- 1002A b c  - 2528B b c )x
+--R             + 
+--R                         3 3          4 2  6             4 2          5   4
+--R               (- 2528A b c  - 3232B b c )x  + (- 3232A b c  - 2048B b c)x
+--R             + 
+--R                         5          6  2         6
+--R               (- 2048A b c - 512B b )x  - 512A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              7 16       7          6  14           6         2 5  12
+--R           B c x   + (A c  + 52B b c )x   + (52A b c  + 501B b c )x
+--R         + 
+--R                  2 5          3 4  10           3 4          4 3  8
+--R           (501A b c  + 1970B b c )x   + (1970A b c  + 3920B b c )x
+--R         + 
+--R                   4 3          5 2  6           5 2          6   4
+--R           (3920A b c  + 4192B b c )x  + (4192A b c  + 2304B b c)x
+--R         + 
+--R                   6          7  2         7
+--R           (2304A b c + 512B b )x  + 512A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                7 17         7          6  15             6         2 5  13
+--R           - B c x   + (- A c  - 52B b c )x   + (- 52A b c  - 501B b c )x
+--R         + 
+--R                    2 5          3 4  11             3 4          4 3  9
+--R           (- 501A b c  - 1970B b c )x   + (- 1970A b c  - 3920B b c )x
+--R         + 
+--R                     4 3          5 2  7             5 2          6   5
+--R           (- 3920A b c  - 4192B b c )x  + (- 4192A b c  - 2304B b c)x
+--R         + 
+--R                     6          7  3         7
+--R           (- 2304A b c - 512B b )x  - 512A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 17         7           6  15            6          2 5  13
+--R           10B c x   + (10A c  + 190B b c )x   + (190A b c  + 1182B b c )x
+--R         + 
+--R                   2 5          3 4  11           3 4          4 3  9
+--R           (1182A b c  + 3530B b c )x   + (3530A b c  + 5760B b c )x
+--R         + 
+--R                   4 3          5 2  7           5 2          6   5
+--R           (5760A b c  + 5280B b c )x  + (5280A b c  + 2560B b c)x
+--R         + 
+--R                   6          7  3         7
+--R           (2560A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R             5 14        4 12       2 3 10        3 2 8        4   6       5 4
+--R           (c x   + 50b c x   + 400b c x   + 1120b c x  + 1280b c x  + 512b x )
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  5 14         4 12       2 3 10        3 2 8        4   6
+--R             - 10c x   - 170b c x   - 832b c x   - 1696b c x  - 1536b c x
+--R           + 
+--R                   5 4
+--R             - 512b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 904
+
+)clear all
+
+--S 905 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^8
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              6
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 905
+
+--S 906 of 3139
+r0:=-1/8*(4*b*B+A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^5)-_
+   1/4*A*(b*x^2+c*x^4)^(5/2)/(b*x^9)-3/8*c*(4*b*B+A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/sqrt(b)+3/8*c*(4*b*B+A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*x)
+--R 
+--R
+--R   (2)
+--R                                         +-+
+--R              2            5           x\|b
+--R       (- 3A c  - 12B b c)x atanh(--------------)
+--R                                   +-----------+
+--R                                   |   4      2
+--R                                  \|c x  + b x
+--R     + 
+--R                                                +-----------+
+--R              4                   2         +-+ |   4      2
+--R       (8B c x  + (- 5A c - 4B b)x  - 2A b)\|b \|c x  + b x
+--R  /
+--R       5 +-+
+--R     8x \|b
+--R                                                    Type: Expression(Integer)
+--E 906
+
+--S 907 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    4          3  8           3         2 2  6
+--R               (3A c  + 12B b c )x  + (36A b c  + 144B b c )x
+--R             + 
+--R                     2 2         3   4
+--R               (48A b c  + 192B b c)x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                       4          3  8             3         2 2  6
+--R               (- 15A c  - 60B b c )x  + (- 60A b c  - 240B b c )x
+--R             + 
+--R                       2 2         3   4
+--R               (- 48A b c  - 192B b c)x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                    3 8           3        2 2  6          2 2        3   4
+--R           - 32B b c x  + (25A b c  - 44B b c )x  + (110A b c  + 80B b c)x
+--R         + 
+--R                  3         4  2        4
+--R           (120A b c + 64B b )x  + 32A b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               4 10          4          3  8             3        2 2  6
+--R           8B c x   + (- 5A c  + 60B b c )x  + (- 67A b c  + 12B b c )x
+--R         + 
+--R                    2 2         3   4            3         4  2        4
+--R           (- 166A b c  - 112B b c)x  + (- 136A b c - 64B b )x  - 32A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                        +--------+
+--R          2 8          6       2 4  +-+ |   2             2 8       2   6
+--R       (8c x  + 96b c x  + 128b x )\|b \|c x  + b  - 40b c x  - 160b c x
+--R     + 
+--R             3 4
+--R       - 128b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 907
+
+--S 908 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    4          3  9           3         2 2  7
+--R               (3A c  + 12B b c )x  + (36A b c  + 144B b c )x
+--R             + 
+--R                     2 2         3   5
+--R               (48A b c  + 192B b c)x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                     4        2 3  9           2 3         3 2  7
+--R           (- 15A b c  - 60B b c )x  + (- 60A b c  - 240B b c )x
+--R         + 
+--R                   3 2         4   5
+--R           (- 48A b c  - 192B b c)x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                    4          3  9           3         2 2  7
+--R               (3A c  + 12B b c )x  + (36A b c  + 144B b c )x
+--R             + 
+--R                     2 2         3   5
+--R               (48A b c  + 192B b c)x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                     4        2 3  9           2 3         3 2  7
+--R           (- 15A b c  - 60B b c )x  + (- 60A b c  - 240B b c )x
+--R         + 
+--R                   3 2         4   5
+--R           (- 48A b c  - 192B b c)x
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                       3 8          3        2 2  6         2 2        3   4
+--R               - 8B b c x  + (5A b c  - 92B b c )x  + (62A b c  - 80B b c)x
+--R             + 
+--R                      3         4  2        4
+--R               (104A b c + 64B b )x  + 32A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                      3 8             3         2 2  6
+--R               40B b c x  + (- 25A b c  + 140B b c )x
+--R             + 
+--R                        2 2        3   4            3         4  2        4
+--R               (- 110A b c  + 48B b c)x  + (- 120A b c - 64B b )x  - 32A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    3 9           3        2 2  7          2 2        3   5
+--R           - 32B b c x  + (25A b c  - 44B b c )x  + (110A b c  + 80B b c)x
+--R         + 
+--R                  3         4  3        4
+--R           (120A b c + 64B b )x  + 32A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R             4 11            4        2 3  9           2 3        3 2  7
+--R       8B b c x   + (- 5A b c  + 60B b c )x  + (- 67A b c  + 12B b c )x
+--R     + 
+--R                3 2         4   5            4         5  3        5
+--R       (- 166A b c  - 112B b c)x  + (- 136A b c - 64B b )x  - 32A b x
+--R  /
+--R                                      +--------+
+--R            2 9      2   7       3 5  |   2
+--R       (8b c x  + 96b c x  + 128b x )\|c x  + b
+--R     + 
+--R               2 9       2   7       3 5  +-+
+--R       (- 40b c x  - 160b c x  - 128b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 908
+
+--S 909 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    7 16         7          6  14             6         2 5  12
+--R               - B c x   + (- A c  - 62B b c )x   + (- 62A b c  - 681B b c )x
+--R             + 
+--R                        2 5          3 4  10             3 4          4 3  8
+--R               (- 681A b c  - 2972B b c )x   + (- 2972A b c  - 6448B b c )x
+--R             + 
+--R                         4 3          5 2  6             5 2          6   4
+--R               (- 6448A b c  - 7424B b c )x  + (- 7424A b c  - 4352B b c)x
+--R             + 
+--R                         6           7  2          7
+--R               (- 4352A b c - 1024B b )x  - 1024A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    7 16         7           6  14            6          2 5  12
+--R               11B c x   + (11A c  + 242B b c )x   + (242A b c  + 1683B b c )x
+--R             + 
+--R                       2 5          3 4  10           3 4          4 3  8
+--R               (1683A b c  + 5500B b c )x   + (5500A b c  + 9680B b c )x
+--R             + 
+--R                       4 3          5 2  6           5 2          6   4
+--R               (9680A b c  + 9472B b c )x  + (9472A b c  + 4864B b c)x
+--R             + 
+--R                       6           7  2          7
+--R               (4864A b c + 1024B b )x  + 1024A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  7 17           7           6  15
+--R           - 11B c x   + (- 11A c  - 242B b c )x
+--R         + 
+--R                      6          2 5  13             2 5          3 4  11
+--R           (- 242A b c  - 1683B b c )x   + (- 1683A b c  - 5500B b c )x
+--R         + 
+--R                     3 4          4 3  9             4 3          5 2  7
+--R           (- 5500A b c  - 9680B b c )x  + (- 9680A b c  - 9472B b c )x
+--R         + 
+--R                   5 2          6   5             6           7  3          7
+--R         (- 9472A b c  - 4864B b c)x  + (- 4864A b c - 1024B b )x  - 1024A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          8 19       8          7  17           7         2 6  15
+--R       B c x   + (A c  + 63B b c )x   + (63A b c  + 743B b c )x
+--R     + 
+--R              2 6          3 5  13           3 5          4 4  11
+--R       (743A b c  + 3653B b c )x   + (3653A b c  + 9420B b c )x
+--R     + 
+--R               4 4           5 3  9            5 3           6 2  7
+--R       (9420A b c  + 13872B b c )x  + (13872A b c  + 11776B b c )x
+--R     + 
+--R                6 2          7   5           7           8  3          8
+--R       (11776A b c  + 5376B b c)x  + (5376A b c + 1024B b )x  + 1024A b x
+--R  /
+--R                5 15         4 13        2 3 11        3 2 9        4   7
+--R             11c x   + 220b c x   + 1232b c x   + 2816b c x  + 2816b c x
+--R           + 
+--R                  5 5
+--R             1024b x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R            6 17        5 15       2 4 13        3 3 11        4 2 9
+--R         - c x   - 61b c x   - 620b c x   - 2352b c x   - 4096b c x
+--R       + 
+--R                5   7        6 5
+--R         - 3328b c x  - 1024b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 909
+
+)clear all
+
+--S 910 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^9
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              7
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 910
+
+--S 911 of 3139
+r0:=-1/3*B*(b*x^2+c*x^4)^(3/2)/x^6-1/5*A*(b*x^2+c*x^4)^(5/2)/(b*x^10)+_
+   B*c^(3/2)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))-B*c*sqrt(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                                2 +-+
+--R                6 +-+          x \|c
+--R       15B b c x \|c atanh(--------------)
+--R                            +-----------+
+--R                            |   4      2
+--R                           \|c x  + b x
+--R     + 
+--R                                                              +-----------+
+--R               2            4                   2  2       2  |   4      2
+--R       ((- 3A c  - 20B b c)x  + (- 6A b c - 5B b )x  - 3A b )\|c x  + b x
+--R  /
+--R          6
+--R     15b x
+--R                                                    Type: Expression(Integer)
+--E 911
+
+--S 912 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                          +--------+
+--R                     3 9         2 2 7         3   5  +-+ |   2
+--R             (15B b c x  + 180B b c x  + 240B b c x )\|c \|c x  + b
+--R           + 
+--R                       3 9         2 2 7         3   5  +-+ +-+
+--R             (- 75B b c x  - 300B b c x  - 240B b c x )\|b \|c
+--R        *
+--R                                +--------+
+--R                    +-+    +-+  |   2          +-+ +-+      2
+--R               (- x\|c  + \|b )\|c x  + b  + x\|b \|c  - c x  - b
+--R           log(--------------------------------------------------)
+--R                                    +--------+
+--R                                +-+ |   2
+--R                               \|b \|c x  + b  - b
+--R       + 
+--R                   4           3  8           3         2 2  6
+--R             (15A c  + 100B b c )x  + (90A b c  + 425B b c )x
+--R           + 
+--R                    2 2         3   4          3         4  2        4
+--R             (183A b c  + 420B b c)x  + (156A b c + 80B b )x  + 48A b
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R                5          4  10             4         2 3  8
+--R         (- 3A c  - 20B b c )x   + (- 45A b c  - 265B b c )x
+--R       + 
+--R                  2 3         3 2  6            3 2         4   4
+--R         (- 165A b c  - 625B b c )x  + (- 255A b c  - 460B b c)x
+--R       + 
+--R                  4         5  2        5
+--R         (- 180A b c - 80B b )x  - 48A b
+--R    /
+--R                                          +--------+
+--R               2 9       2   7       3 5  |   2
+--R         (15b c x  + 180b c x  + 240b x )\|c x  + b
+--R       + 
+--R                 2 9       2   7       3 5  +-+
+--R         (- 75b c x  - 300b c x  - 240b x )\|b
+--R     ,
+--R
+--R                                                            +--------+
+--R                     3 9         2 2 7         3   5  +---+ |   2
+--R             (30B b c x  + 360B b c x  + 480B b c x )\|- c \|c x  + b
+--R           + 
+--R                        3 9         2 2 7         3   5  +---+ +-+
+--R             (- 150B b c x  - 600B b c x  - 480B b c x )\|- c \|b
+--R        *
+--R                 +--------+
+--R                 |   2         +-+
+--R                \|c x  + b  - \|b
+--R           atan(------------------)
+--R                        +---+
+--R                      x\|- c
+--R       + 
+--R                   4           3  8           3         2 2  6
+--R             (15A c  + 100B b c )x  + (90A b c  + 425B b c )x
+--R           + 
+--R                    2 2         3   4          3         4  2        4
+--R             (183A b c  + 420B b c)x  + (156A b c + 80B b )x  + 48A b
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R                5          4  10             4         2 3  8
+--R         (- 3A c  - 20B b c )x   + (- 45A b c  - 265B b c )x
+--R       + 
+--R                  2 3         3 2  6            3 2         4   4
+--R         (- 165A b c  - 625B b c )x  + (- 255A b c  - 460B b c)x
+--R       + 
+--R                  4         5  2        5
+--R         (- 180A b c - 80B b )x  - 48A b
+--R    /
+--R                                          +--------+
+--R               2 9       2   7       3 5  |   2
+--R         (15b c x  + 180b c x  + 240b x )\|c x  + b
+--R       + 
+--R                 2 9       2   7       3 5  +-+
+--R         (- 75b c x  - 300b c x  - 240b x )\|b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 912
+
+--S 913 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                         +--------+
+--R                   3 10         2 2 8         3   6  +-+ |   2
+--R           (15B b c x   + 180B b c x  + 240B b c x )\|c \|c x  + b
+--R         + 
+--R                     3 10         2 2 8         3   6  +-+ +-+
+--R           (- 75B b c x   - 300B b c x  - 240B b c x )\|b \|c
+--R      *
+--R                              +--------+
+--R                  +-+    +-+  |   2          +-+ +-+      2
+--R             (- x\|c  + \|b )\|c x  + b  + x\|b \|c  - c x  - b
+--R         log(--------------------------------------------------)
+--R                                  +--------+
+--R                              +-+ |   2
+--R                             \|b \|c x  + b  - b
+--R     + 
+--R                                                           +--------+
+--R                     3 10         2 2 8         3   6  +-+ |   2
+--R           (- 15B b c x   - 180B b c x  - 240B b c x )\|c \|c x  + b
+--R         + 
+--R                   3 10         2 2 8         3   6  +-+ +-+
+--R           (75B b c x   + 300B b c x  + 240B b c x )\|b \|c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                    4          3  8           3         2 2  6
+--R               (3A c  + 20B b c )x  + (42A b c  + 245B b c )x
+--R             + 
+--R                      2 2         3   4          3         4  2        4
+--R               (123A b c  + 380B b c)x  + (132A b c + 80B b )x  + 48A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                       4           3  8             3         2 2  6
+--R               (- 15A c  - 100B b c )x  + (- 90A b c  - 425B b c )x
+--R             + 
+--R                        2 2         3   4            3         4  2        4
+--R               (- 183A b c  - 420B b c)x  + (- 156A b c - 80B b )x  - 48A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 4           3  9           3         2 2  7
+--R           (15A c  + 100B b c )x  + (90A b c  + 425B b c )x
+--R         + 
+--R                  2 2         3   5          3         4  3        4
+--R           (183A b c  + 420B b c)x  + (156A b c + 80B b )x  + 48A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              5          4  11             4         2 3  9
+--R       (- 3A c  - 20B b c )x   + (- 45A b c  - 265B b c )x
+--R     + 
+--R                2 3         3 2  7            3 2         4   5
+--R       (- 165A b c  - 625B b c )x  + (- 255A b c  - 460B b c)x
+--R     + 
+--R                4         5  3        5
+--R       (- 180A b c - 80B b )x  - 48A b x
+--R  /
+--R                                         +--------+
+--R             2 10       2   8       3 6  |   2
+--R       (15b c x   + 180b c x  + 240b x )\|c x  + b
+--R     + 
+--R               2 10       2   8       3 6  +-+
+--R       (- 75b c x   - 300b c x  - 240b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 913
+
+--S 914 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        8 19         8          7  17
+--R                   - B c x   + (- A c  - 86B b c )x
+--R                 + 
+--R                             7          2 6  15             2 6          3 5  13
+--R                   (- 86A b c  - 1289B b c )x   + (- 1289A b c  - 7700B b c )x
+--R                 + 
+--R                             3 5           4 4  11
+--R                   (- 7700A b c  - 23392B b c )x
+--R                 + 
+--R                              4 4           5 3  9
+--R                   (- 23392A b c  - 39680B b c )x
+--R                 + 
+--R                              5 3           6 2  7
+--R                   (- 39680A b c  - 38144B b c )x
+--R                 + 
+--R                              6 2           7   5              7           8  3
+--R                   (- 38144A b c  - 19456B b c)x  + (- 19456A b c - 4096B b )x
+--R                 + 
+--R                            8
+--R                   - 4096A b x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                        8 18         8           7  16
+--R                   13B c x   + (13A c  + 390B b c )x
+--R                 + 
+--R                            7          2 6  14           2 6           3 5  12
+--R                   (390A b c  + 3653B b c )x   + (3653A b c  + 16172B b c )x
+--R                 + 
+--R                            3 5           4 4  10
+--R                   (16172A b c  + 39520B b c )x
+--R                 + 
+--R                            4 4           5 3  8            5 3           6 2  6
+--R                   (39520A b c  + 56576B b c )x  + (56576A b c  + 47360B b c )x
+--R                 + 
+--R                            6 2           7   4            7           8  2
+--R                   (47360A b c  + 21504B b c)x  + (21504A b c + 4096B b )x
+--R                 + 
+--R                          8
+--R                   4096A b
+--R              *
+--R                  +-+
+--R                 \|b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    8 19         8           7  17            7          2 6  15
+--R               13B c x   + (13A c  + 390B b c )x   + (390A b c  + 3653B b c )x
+--R             + 
+--R                       2 6           3 5  13            3 5           4 4  11
+--R               (3653A b c  + 16172B b c )x   + (16172A b c  + 39520B b c )x
+--R             + 
+--R                        4 4           5 3  9            5 3           6 2  7
+--R               (39520A b c  + 56576B b c )x  + (56576A b c  + 47360B b c )x
+--R             + 
+--R                        6 2           7   5            7           8  3
+--R               (47360A b c  + 21504B b c)x  + (21504A b c + 4096B b )x
+--R             + 
+--R                      8
+--R               4096A b x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R         + 
+--R                9 20         9          8  18             8          2 7  16
+--R           - B c x   + (- A c  - 87B b c )x   + (- 87A b c  - 1375B b c )x
+--R         + 
+--R                     2 7          3 6  14             3 6           4 5  12
+--R           (- 1375A b c  - 8989B b c )x   + (- 8989A b c  - 31092B b c )x
+--R         + 
+--R                      4 5           5 4  10              5 4           6 3  8
+--R           (- 31092A b c  - 63072B b c )x   + (- 63072A b c  - 77824B b c )x
+--R         + 
+--R                      6 3           7 2  6              7 2           8   4
+--R           (- 77824A b c  - 57600B b c )x  + (- 57600A b c  - 23552B b c)x
+--R         + 
+--R                      8           9  2          9
+--R           (- 23552A b c - 4096B b )x  - 4096A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                      8 20           8           7  18
+--R               - 13B c x   + (- 13A c  - 390B b c )x
+--R             + 
+--R                          7          2 6  16             2 6           3 5  14
+--R               (- 390A b c  - 3653B b c )x   + (- 3653A b c  - 16172B b c )x
+--R             + 
+--R                          3 5           4 4  12
+--R               (- 16172A b c  - 39520B b c )x
+--R             + 
+--R                          4 4           5 3  10
+--R               (- 39520A b c  - 56576B b c )x
+--R             + 
+--R                          5 3           6 2  8              6 2           7   6
+--R               (- 56576A b c  - 47360B b c )x  + (- 47360A b c  - 21504B b c)x
+--R             + 
+--R                          7           8  4          8 2
+--R               (- 21504A b c - 4096B b )x  - 4096A b x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R         + 
+--R              9 21       9          8  19           8          2 7  17
+--R           B c x   + (A c  + 87B b c )x   + (87A b c  + 1375B b c )x
+--R         + 
+--R                   2 7          3 6  15           3 6           4 5  13
+--R           (1375A b c  + 8989B b c )x   + (8989A b c  + 31092B b c )x
+--R         + 
+--R                    4 5           5 4  11            5 4           6 3  9
+--R           (31092A b c  + 63072B b c )x   + (63072A b c  + 77824B b c )x
+--R         + 
+--R                    6 3           7 2  7            7 2           8   5
+--R           (77824A b c  + 57600B b c )x  + (57600A b c  + 23552B b c)x
+--R         + 
+--R                    8           9  3          9
+--R           (23552A b c + 4096B b )x  + 4096A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R              9 22       9          8  20           8          2 7  18
+--R           B c x   + (A c  + 87B b c )x   + (87A b c  + 1375B b c )x
+--R         + 
+--R                   2 7          3 6  16           3 6           4 5  14
+--R           (1375A b c  + 8989B b c )x   + (8989A b c  + 31092B b c )x
+--R         + 
+--R                    4 5           5 4  12            5 4           6 3  10
+--R           (31092A b c  + 63072B b c )x   + (63072A b c  + 77824B b c )x
+--R         + 
+--R                    6 3           7 2  8            7 2           8   6
+--R           (77824A b c  + 57600B b c )x  + (57600A b c  + 23552B b c)x
+--R         + 
+--R                    8           9  4          9 2
+--R           (23552A b c + 4096B b )x  + 4096A b x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                  9 21           9           8  19
+--R           - 13B c x   + (- 13A c  - 403B b c )x
+--R         + 
+--R                      8          2 7  17             2 7           3 6  15
+--R           (- 403A b c  - 4043B b c )x   + (- 4043A b c  - 19825B b c )x
+--R         + 
+--R                      3 6           4 5  13              4 5           5 4  11
+--R           (- 19825A b c  - 55692B b c )x   + (- 55692A b c  - 96096B b c )x
+--R         + 
+--R                      5 4            6 3  9               6 3           7 2  7
+--R           (- 96096A b c  - 103936B b c )x  + (- 103936A b c  - 68864B b c )x
+--R         + 
+--R                      7 2           8   5              8           9  3
+--R           (- 68864A b c  - 25600B b c)x  + (- 25600A b c - 4096B b )x
+--R         + 
+--R                    9
+--R           - 4096A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                    6 19         5 17        2 4 15        3 3 13         4 2 11
+--R                 13c x   + 364b c x   + 2912b c x   + 9984b c x   + 16640b c x
+--R               + 
+--R                       5   9        6 7
+--R                 13312b c x  + 4096b x
+--R            *
+--R                +-+ +-+
+--R               \|b \|c
+--R           + 
+--R                7 20        6 18        2 5 16        3 4 14         4 3 12
+--R             - c x   - 85b c x   - 1204b c x   - 6496b c x   - 16896b c x
+--R           + 
+--R                     5 2 10         6   8        7 6
+--R             - 22784b c x   - 15360b c x  - 4096b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                7 21        6 19        2 5 17        3 4 15         4 3 13
+--R             - c x   - 85b c x   - 1204b c x   - 6496b c x   - 16896b c x
+--R           + 
+--R                     5 2 11         6   9        7 7
+--R             - 22784b c x   - 15360b c x  - 4096b x
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                7 20         6 18        2 5 16         3 4 14         4 3 12
+--R             13c x   + 377b c x   + 3276b c x   + 12896b c x   + 26624b c x
+--R           + 
+--R                   5 2 10         6   8        7 6
+--R             29952b c x   + 17408b c x  + 4096b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 914
+
+--S 915 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                           +--------+
+--R                     3 10         2 2 8         3   6  +-+ |   2
+--R           (- 15B b c x   - 180B b c x  - 240B b c x )\|c \|c x  + b
+--R         + 
+--R                   3 10         2 2 8         3   6  +-+ +-+
+--R           (75B b c x   + 300B b c x  + 240B b c x )\|b \|c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                                           +--------+
+--R                   3 10         2 2 8         3   6  +---+ |   2
+--R           (30B b c x   + 360B b c x  + 480B b c x )\|- c \|c x  + b
+--R         + 
+--R                      3 10         2 2 8         3   6  +---+ +-+
+--R           (- 150B b c x   - 600B b c x  - 480B b c x )\|- c \|b
+--R      *
+--R               +--------+
+--R               |   2         +-+
+--R              \|c x  + b  - \|b
+--R         atan(------------------)
+--R                      +---+
+--R                    x\|- c
+--R     + 
+--R                    4          3  8           3         2 2  6
+--R               (3A c  + 20B b c )x  + (42A b c  + 245B b c )x
+--R             + 
+--R                      2 2         3   4          3         4  2        4
+--R               (123A b c  + 380B b c)x  + (132A b c + 80B b )x  + 48A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                       4           3  8             3         2 2  6
+--R               (- 15A c  - 100B b c )x  + (- 90A b c  - 425B b c )x
+--R             + 
+--R                        2 2         3   4            3         4  2        4
+--R               (- 183A b c  - 420B b c)x  + (- 156A b c - 80B b )x  - 48A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 4           3  9           3         2 2  7
+--R           (15A c  + 100B b c )x  + (90A b c  + 425B b c )x
+--R         + 
+--R                  2 2         3   5          3         4  3        4
+--R           (183A b c  + 420B b c)x  + (156A b c + 80B b )x  + 48A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              5          4  11             4         2 3  9
+--R       (- 3A c  - 20B b c )x   + (- 45A b c  - 265B b c )x
+--R     + 
+--R                2 3         3 2  7            3 2         4   5
+--R       (- 165A b c  - 625B b c )x  + (- 255A b c  - 460B b c)x
+--R     + 
+--R                4         5  3        5
+--R       (- 180A b c - 80B b )x  - 48A b x
+--R  /
+--R                                         +--------+
+--R             2 10       2   8       3 6  |   2
+--R       (15b c x   + 180b c x  + 240b x )\|c x  + b
+--R     + 
+--R               2 10       2   8       3 6  +-+
+--R       (- 75b c x   - 300b c x  - 240b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 915
+
+--S 916 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      6 14           6           5  12
+--R               - 10B c x   + (- 10A c  - 180B b c )x
+--R             + 
+--R                          5          2 4  10             2 4          3 3  8
+--R               (- 180A b c  - 1002B b c )x   + (- 1002A b c  - 2528B b c )x
+--R             + 
+--R                         3 3          4 2  6             4 2          5   4
+--R               (- 2528A b c  - 3232B b c )x  + (- 3232A b c  - 2048B b c)x
+--R             + 
+--R                         5          6  2         6
+--R               (- 2048A b c - 512B b )x  - 512A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              7 16       7          6  14           6         2 5  12
+--R           B c x   + (A c  + 52B b c )x   + (52A b c  + 501B b c )x
+--R         + 
+--R                  2 5          3 4  10           3 4          4 3  8
+--R           (501A b c  + 1970B b c )x   + (1970A b c  + 3920B b c )x
+--R         + 
+--R                   4 3          5 2  6           5 2          6   4
+--R           (3920A b c  + 4192B b c )x  + (4192A b c  + 2304B b c)x
+--R         + 
+--R                   6          7  2         7
+--R           (2304A b c + 512B b )x  + 512A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                7 17         7          6  15             6         2 5  13
+--R           - B c x   + (- A c  - 52B b c )x   + (- 52A b c  - 501B b c )x
+--R         + 
+--R                    2 5          3 4  11             3 4          4 3  9
+--R           (- 501A b c  - 1970B b c )x   + (- 1970A b c  - 3920B b c )x
+--R         + 
+--R                     4 3          5 2  7             5 2          6   5
+--R           (- 3920A b c  - 4192B b c )x  + (- 4192A b c  - 2304B b c)x
+--R         + 
+--R                     6          7  3         7
+--R           (- 2304A b c - 512B b )x  - 512A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 17         7           6  15            6          2 5  13
+--R           10B c x   + (10A c  + 190B b c )x   + (190A b c  + 1182B b c )x
+--R         + 
+--R                   2 5          3 4  11           3 4          4 3  9
+--R           (1182A b c  + 3530B b c )x   + (3530A b c  + 5760B b c )x
+--R         + 
+--R                   4 3          5 2  7           5 2          6   5
+--R           (5760A b c  + 5280B b c )x  + (5280A b c  + 2560B b c)x
+--R         + 
+--R                   6          7  3         7
+--R           (2560A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R             5 16        4 14       2 3 12        3 2 10        4   8       5 6
+--R           (c x   + 50b c x   + 400b c x   + 1120b c x   + 1280b c x  + 512b x )
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  5 16         4 14       2 3 12        3 2 10        4   8
+--R             - 10c x   - 170b c x   - 832b c x   - 1696b c x   - 1536b c x
+--R           + 
+--R                   5 6
+--R             - 512b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 916
+
+)clear all
+
+--S 917 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^10
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              8
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 917
+
+--S 918 of 3139
+r0:=-1/24*(6*b*B-A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^7)-_
+   1/6*A*(b*x^2+c*x^4)^(5/2)/(b*x^11)-1/16*c^2*(6*b*B-A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-1/16*c*(6*b*B-A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R   (2)
+--R                                        +-+
+--R            3          2  7           x\|b
+--R       (3A c  - 18B b c )x atanh(--------------)
+--R                                  +-----------+
+--R                                  |   4      2
+--R                                 \|c x  + b x
+--R     + 
+--R                                                                  +-----------+
+--R             2            4                     2  2       2  +-+ |   4      2
+--R     ((- 3A c  - 30B b c)x  + (- 14A b c - 12B b )x  - 8A b )\|b \|c x  + b x
+--R  /
+--R          7 +-+
+--R     48b x \|b
+--R                                                    Type: Expression(Integer)
+--E 918
+
+--S 919 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         5         2 4  10           2 4         3 3  8
+--R               (- 18A b c  + 108B b c )x   + (- 96A b c  + 576B b c )x
+--R             + 
+--R                       3 3         4 2  6
+--R               (- 96A b c  + 576B b c )x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    6          5  12           5         2 4  10
+--R               (3A c  - 18B b c )x   + (54A b c  - 324B b c )x
+--R             + 
+--R                      2 4         3 3  8         3 3         4 2  6
+--R               (144A b c  - 864B b c )x  + (96A b c  - 576B b c )x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                  5        2 4  10         2 4         3 3  8
+--R           (3A b c  + 30B b c )x   + (68A b c  + 552B b c )x
+--R         + 
+--R                  3 3          4 2  6          4 2          5   4
+--R           (404A b c  + 1656B b c )x  + (912A b c  + 1536B b c)x
+--R         + 
+--R                  5          6  2         6
+--R           (832A b c + 384B b )x  + 256A b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                     5         2 4  10            2 4          3 3  8
+--R           (- 18A b c  - 180B b c )x   + (- 198A b c  - 1212B b c )x
+--R         + 
+--R                    3 3          4 2  6             4 2          5   4
+--R           (- 772A b c  - 2376B b c )x  + (- 1296A b c  - 1728B b c)x
+--R         + 
+--R                    5          6  2         6
+--R           (- 960A b c - 384B b )x  - 256A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                +--------+
+--R            2 2 10        3   8        4 6  +-+ |   2           2 3 12
+--R       (288b c x   + 1536b c x  + 1536b x )\|b \|c x  + b  - 48b c x
+--R     + 
+--R             3 2 10        4   8        5 6
+--R       - 864b c x   - 2304b c x  - 1536b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 919
+
+--S 920 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       5           4  11             4         2 3  9
+--R               (- 18A c  + 108B b c )x   + (- 96A b c  + 576B b c )x
+--R             + 
+--R                       2 3         3 2  7
+--R               (- 96A b c  + 576B b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                6          5  13           5         2 4  11
+--R           (3A c  - 18B b c )x   + (54A b c  - 324B b c )x
+--R         + 
+--R                  2 4         3 3  9         3 3         4 2  7
+--R           (144A b c  - 864B b c )x  + (96A b c  - 576B b c )x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                       5           4  11             4         2 3  9
+--R               (- 18A c  + 108B b c )x   + (- 96A b c  + 576B b c )x
+--R             + 
+--R                       2 3         3 2  7
+--R               (- 96A b c  + 576B b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                6          5  13           5         2 4  11
+--R           (3A c  - 18B b c )x   + (54A b c  - 324B b c )x
+--R         + 
+--R                  2 4         3 3  9         3 3         4 2  7
+--R           (144A b c  - 864B b c )x  + (96A b c  - 576B b c )x
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                       4         2 3  8          2 3          3 2  6
+--R               (18A b c  + 180B b c )x  + (180A b c  + 1032B b c )x
+--R             + 
+--R                      3 2          4   4          4          5  2         5
+--R               (592A b c  + 1344B b c)x  + (704A b c + 384B b )x  + 256A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                      5          4  10             4         2 3  8
+--R               (- 3A c  - 30B b c )x   + (- 68A b c  - 552B b c )x
+--R             + 
+--R                        2 3          3 2  6            3 2          4   4
+--R               (- 404A b c  - 1656B b c )x  + (- 912A b c  - 1536B b c)x
+--R             + 
+--R                        4          5  2         5
+--R               (- 832A b c - 384B b )x  - 256A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                5          4  11           4         2 3  9
+--R           (3A c  + 30B b c )x   + (68A b c  + 552B b c )x
+--R         + 
+--R                  2 3          3 2  7          3 2          4   5
+--R           (404A b c  + 1656B b c )x  + (912A b c  + 1536B b c)x
+--R         + 
+--R                  4          5  3         5
+--R           (832A b c + 384B b )x  + 256A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                 5         2 4  11            2 4          3 3  9
+--R       (- 18A b c  - 180B b c )x   + (- 198A b c  - 1212B b c )x
+--R     + 
+--R                3 3          4 2  7             4 2          5   5
+--R       (- 772A b c  - 2376B b c )x  + (- 1296A b c  - 1728B b c)x
+--R     + 
+--R                5          6  3         6
+--R       (- 960A b c - 384B b )x  - 256A b x
+--R  /
+--R                                            +--------+
+--R            2 2 11        3   9        4 7  |   2
+--R       (288b c x   + 1536b c x  + 1536b x )\|c x  + b
+--R     + 
+--R               3 13       2 2 11        3   9        4 7  +-+
+--R       (- 48b c x   - 864b c x   - 2304b c x  - 1536b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 920
+
+--S 921 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    8 18         8          7  16             7          2 6  14
+--R               - B c x   + (- A c  - 86B b c )x   + (- 86A b c  - 1289B b c )x
+--R             + 
+--R                         2 6          3 5  12             3 5           4 4  10
+--R               (- 1289A b c  - 7700B b c )x   + (- 7700A b c  - 23392B b c )x
+--R             + 
+--R                          4 4           5 3  8              5 3           6 2  6
+--R               (- 23392A b c  - 39680B b c )x  + (- 39680A b c  - 38144B b c )x
+--R             + 
+--R                          6 2           7   4              7           8  2
+--R               (- 38144A b c  - 19456B b c)x  + (- 19456A b c - 4096B b )x
+--R             + 
+--R                        8
+--R               - 4096A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    8 18         8           7  16            7          2 6  14
+--R               13B c x   + (13A c  + 390B b c )x   + (390A b c  + 3653B b c )x
+--R             + 
+--R                       2 6           3 5  12            3 5           4 4  10
+--R               (3653A b c  + 16172B b c )x   + (16172A b c  + 39520B b c )x
+--R             + 
+--R                        4 4           5 3  8            5 3           6 2  6
+--R               (39520A b c  + 56576B b c )x  + (56576A b c  + 47360B b c )x
+--R             + 
+--R                      6 2           7   4            7           8  2          8
+--R             (47360A b c  + 21504B b c)x  + (21504A b c + 4096B b )x  + 4096A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  8 19           8           7  17
+--R           - 13B c x   + (- 13A c  - 390B b c )x
+--R         + 
+--R                      7          2 6  15             2 6           3 5  13
+--R           (- 390A b c  - 3653B b c )x   + (- 3653A b c  - 16172B b c )x
+--R         + 
+--R                      3 5           4 4  11              4 4           5 3  9
+--R           (- 16172A b c  - 39520B b c )x   + (- 39520A b c  - 56576B b c )x
+--R         + 
+--R                      5 3           6 2  7              6 2           7   5
+--R           (- 56576A b c  - 47360B b c )x  + (- 47360A b c  - 21504B b c)x
+--R         + 
+--R                      7           8  3          8
+--R           (- 21504A b c - 4096B b )x  - 4096A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          9 21       9          8  19           8          2 7  17
+--R       B c x   + (A c  + 87B b c )x   + (87A b c  + 1375B b c )x
+--R     + 
+--R               2 7          3 6  15           3 6           4 5  13
+--R       (1375A b c  + 8989B b c )x   + (8989A b c  + 31092B b c )x
+--R     + 
+--R                4 5           5 4  11            5 4           6 3  9
+--R       (31092A b c  + 63072B b c )x   + (63072A b c  + 77824B b c )x
+--R     + 
+--R                6 3           7 2  7            7 2           8   5
+--R       (77824A b c  + 57600B b c )x  + (57600A b c  + 23552B b c)x
+--R     + 
+--R                8           9  3          9
+--R       (23552A b c + 4096B b )x  + 4096A b x
+--R  /
+--R                6 19         5 17        2 4 15        3 3 13         4 2 11
+--R             13c x   + 364b c x   + 2912b c x   + 9984b c x   + 16640b c x
+--R           + 
+--R                   5   9        6 7
+--R             13312b c x  + 4096b x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R            7 21        6 19        2 5 17        3 4 15         4 3 13
+--R         - c x   - 85b c x   - 1204b c x   - 6496b c x   - 16896b c x
+--R       + 
+--R                 5 2 11         6   9        7 7
+--R         - 22784b c x   - 15360b c x  - 4096b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 921
+
+)clear all
+
+--S 922 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^11
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              9
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 3139
+r0:=-1/7*A*(b*x^2+c*x^4)^(5/2)/(b*x^12)-1/35*(7*b*B-2*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^10)
+--R 
+--R
+--R   (2)
+--R              3         2  6           2        2   4          2        3  2
+--R         (2A c  - 7B b c )x  + (- A b c  - 14B b c)x  + (- 8A b c - 7B b )x
+--R       + 
+--R               3
+--R         - 5A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R        2 8
+--R     35b x
+--R                                                    Type: Expression(Integer)
+--E 923
+
+--S 924 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   6          5  12              5         2 4  10
+--R           (- 14A c  + 49B b c )x   + (- 105A b c  + 490B b c )x
+--R         + 
+--R                    2 4          3 3  8          3 3          4 2  6
+--R           (- 112A b c  + 1617B b c )x  + (467A b c  + 2408B b c )x
+--R         + 
+--R                   4 2          5   4           5          6  2         6
+--R           (1240A b c  + 1680B b c)x  + (1072A b c + 448B b )x  + 320A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R            7         6  14           6         2 5  12
+--R       (2A c  - 7B b c )x   + (49A b c  - 189B b c )x
+--R     + 
+--R              2 5          3 4  10           3 4          4 3  8
+--R       (175A b c  - 1085B b c )x   + (- 21A b c  - 2639B b c )x
+--R     + 
+--R                4 3          5 2  6             5 2          6   4
+--R       (- 973A b c  - 3192B b c )x  + (- 1736A b c  - 1904B b c)x
+--R     + 
+--R                 6          7  2         7
+--R       (- 1232A b c - 448B b )x  - 320A b
+--R  /
+--R                                                        +--------+
+--R           2 3 13       3 2 11        4   9        5 7  |   2
+--R       (35b c x   + 840b c x   + 2800b c x  + 2240b x )\|c x  + b
+--R     + 
+--R              2 3 13        3 2 11        4   9        5 7  +-+
+--R       (- 245b c x   - 1960b c x   - 3920b c x  - 2240b x )\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 924
+
+--S 925 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      6         5  12             5         2 4  10
+--R               (- 2A c  + 7B b c )x   + (- 47A b c  + 182B b c )x
+--R             + 
+--R                        2 4         3 3  8          3 3          4 2  6
+--R               (- 128A b c  + 903B b c )x  + (149A b c  + 1736B b c )x
+--R             + 
+--R                      4 2          5   4          5          6  2         6
+--R               (824A b c  + 1456B b c)x  + (912A b c + 448B b )x  + 320A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                     6          5  12            5         2 4  10
+--R               (14A c  - 49B b c )x   + (105A b c  - 490B b c )x
+--R             + 
+--R                      2 4          3 3  8            3 3          4 2  6
+--R               (112A b c  - 1617B b c )x  + (- 467A b c  - 2408B b c )x
+--R             + 
+--R                       4 2          5   4             5          6  2         6
+--R             (- 1240A b c  - 1680B b c)x  + (- 1072A b c - 448B b )x  - 320A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                   6          5  13              5         2 4  11
+--R           (- 14A c  + 49B b c )x   + (- 105A b c  + 490B b c )x
+--R         + 
+--R                    2 4          3 3  9          3 3          4 2  7
+--R           (- 112A b c  + 1617B b c )x  + (467A b c  + 2408B b c )x
+--R         + 
+--R                   4 2          5   5           5          6  3         6
+--R           (1240A b c  + 1680B b c)x  + (1072A b c + 448B b )x  + 320A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R            7         6  15           6         2 5  13
+--R       (2A c  - 7B b c )x   + (49A b c  - 189B b c )x
+--R     + 
+--R              2 5          3 4  11           3 4          4 3  9
+--R       (175A b c  - 1085B b c )x   + (- 21A b c  - 2639B b c )x
+--R     + 
+--R                4 3          5 2  7             5 2          6   5
+--R       (- 973A b c  - 3192B b c )x  + (- 1736A b c  - 1904B b c)x
+--R     + 
+--R                 6          7  3         7
+--R       (- 1232A b c - 448B b )x  - 320A b x
+--R  /
+--R                                                         +--------+
+--R           2 3 14       3 2 12        4   10        5 8  |   2
+--R       (35b c x   + 840b c x   + 2800b c x   + 2240b x )\|c x  + b
+--R     + 
+--R              2 3 14        3 2 12        4   10        5 8  +-+
+--R       (- 245b c x   - 1960b c x   - 3920b c x   - 2240b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 925
+
+--S 926 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      8 18           8           7  16
+--R               - 14B c x   + (- 14A c  - 476B b c )x
+--R             + 
+--R                          7          2 6  14             2 6           3 5  12
+--R               (- 476A b c  - 4942B b c )x   + (- 4942A b c  - 23872B b c )x
+--R             + 
+--R                          3 5           4 4  10
+--R               (- 23872A b c  - 62912B b c )x
+--R             + 
+--R                          4 4           5 3  8              5 3           6 2  6
+--R               (- 62912A b c  - 96256B b c )x  + (- 96256A b c  - 85504B b c )x
+--R             + 
+--R                          6 2           7   4              7           8  2
+--R               (- 85504A b c  - 40960B b c)x  + (- 40960A b c - 8192B b )x
+--R             + 
+--R                        8
+--R               - 8192A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              9 20       9           8  18            8          2 7  16
+--R           B c x   + (A c  + 100B b c )x   + (100A b c  + 1765B b c )x
+--R         + 
+--R                   2 7           3 6  14            3 6           4 5  12
+--R           (1765A b c  + 12642B b c )x   + (12642A b c  + 47264B b c )x
+--R         + 
+--R                    4 5            5 4  10             5 4            6 3  8
+--R           (47264A b c  + 102592B b c )x   + (102592A b c  + 134400B b c )x
+--R         + 
+--R                     6 3            7 2  6             7 2           8   4
+--R           (134400A b c  + 104960B b c )x  + (104960A b c  + 45056B b c)x
+--R         + 
+--R                    8           9  2          9
+--R           (45056A b c + 8192B b )x  + 8192A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                9 21         9           8  19              8          2 7  17
+--R           - B c x   + (- A c  - 100B b c )x   + (- 100A b c  - 1765B b c )x
+--R         + 
+--R                     2 7           3 6  15              3 6           4 5  13
+--R           (- 1765A b c  - 12642B b c )x   + (- 12642A b c  - 47264B b c )x
+--R         + 
+--R                      4 5            5 4  11               5 4            6 3  9
+--R           (- 47264A b c  - 102592B b c )x   + (- 102592A b c  - 134400B b c )x
+--R         + 
+--R                       6 3            7 2  7               7 2           8   5
+--R           (- 134400A b c  - 104960B b c )x  + (- 104960A b c  - 45056B b c)x
+--R         + 
+--R                      8           9  3          9
+--R           (- 45056A b c - 8192B b )x  - 8192A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                9 21         9           8  19            8          2 7  17
+--R           14B c x   + (14A c  + 490B b c )x   + (490A b c  + 5418B b c )x
+--R         + 
+--R                   2 7           3 6  15            3 6           4 5  13
+--R           (5418A b c  + 28814B b c )x   + (28814A b c  + 86784B b c )x
+--R         + 
+--R                    4 5            5 4  11             5 4            6 3  9
+--R           (86784A b c  + 159168B b c )x   + (159168A b c  + 181760B b c )x
+--R         + 
+--R                     6 3            7 2  7             7 2           8   5
+--R           (181760A b c  + 126464B b c )x  + (126464A b c  + 49152B b c)x
+--R         + 
+--R                    8           9  3          9
+--R           (49152A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              7 22        6 20        2 5 18        3 4 16         4 3 14
+--R             c x   + 98b c x   + 1568b c x   + 9408b c x   + 26880b c x
+--R           + 
+--R                   5 2 12         6   10        7 8
+--R             39424b c x   + 28672b c x   + 8192b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  7 22         6 20        2 5 18         3 4 16         4 3 14
+--R             - 14c x   - 462b c x   - 4480b c x   - 19392b c x   - 43520b c x
+--R           + 
+--R                     5 2 12         6   10        7 8
+--R             - 52736b c x   - 32768b c x   - 8192b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 926
+
+)clear all
+
+--S 927 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^12
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              10
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 927
+
+--S 928 of 3139
+r0:=1/192*c*(8*b*B-3*A*c)*(b*x^2+c*x^4)^(3/2)/(b^2*x^7)-_
+   1/8*A*(b*x^2+c*x^4)^(5/2)/(b*x^13)-1/48*(8*b*B-3*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^11)+1/128*c^3*(8*b*B-3*A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)+1/128*c^2*(8*b*B-3*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^3)
+--R 
+--R
+--R   (2)
+--R                                          +-+
+--R              4          3  9           x\|b
+--R       (- 9A c  + 24B b c )x atanh(--------------)
+--R                                    +-----------+
+--R                                    |   4      2
+--R                                   \|c x  + b x
+--R     + 
+--R                3          2  6            2         2   4
+--R           (9A c  - 24B b c )x  + (- 6A b c  - 112B b c)x
+--R         + 
+--R                   2         3  2        3
+--R           (- 72A b c - 64B b )x  - 48A b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|b \|c x  + b x
+--R  /
+--R         2 9 +-+
+--R     384b x \|b
+--R                                                    Type: Expression(Integer)
+--E 928
+
+--S 929 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       7         2 6  14          2 6          3 5  12
+--R               (72A b c  - 192B b c )x   + (720A b c  - 1920B b c )x
+--R             + 
+--R                       3 5          4 4  10           4 4          5 3  8
+--R               (1728A b c  - 4608B b c )x   + (1152A b c  - 3072B b c )x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                      8          7  16              7         2 6  14
+--R               (- 9A c  + 24B b c )x   + (- 288A b c  + 768B b c )x
+--R             + 
+--R                         2 6          3 5  12             3 5          4 4  10
+--R               (- 1440A b c  + 3840B b c )x   + (- 2304A b c  + 6144B b c )x
+--R             + 
+--R                         4 4          5 3  8
+--R               (- 1152A b c  + 3072B b c )x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                    7        2 6  14            2 6         3 5  12
+--R           (- 9A b c  + 24B b c )x   + (- 282A b c  + 880B b c )x
+--R         + 
+--R                     3 5          4 4  10           4 4           5 3  8
+--R           (- 1176A b c  + 7488B b c )x   + (1008A b c  + 26112B b c )x
+--R         + 
+--R                    5 3           6 2  6            6 2           7   4
+--R           (13440A b c  + 41984B b c )x  + (26880A b c  + 30720B b c)x
+--R         + 
+--R                    7           8  2          8
+--R           (21504A b c + 8192B b )x  + 6144A b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                   7         2 6  14          2 6          3 5  12
+--R           (72A b c  - 192B b c )x   + (744A b c  - 3008B b c )x
+--R         + 
+--R                   3 5           4 4  10             4 4           5 3  8
+--R           (1344A b c  - 16896B b c )x   + (- 5472A b c  - 43776B b c )x
+--R         + 
+--R                      5 3           6 2  6              6 2           7   4
+--R           (- 24576A b c  - 56320B b c )x  + (- 36864A b c  - 34816B b c)x
+--R         + 
+--R                      7           8  2          8
+--R           (- 24576A b c - 8192B b )x  - 6144A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                                   +--------+
+--R             3 3 14         4 2 12         5   10         6 8  +-+ |   2
+--R       (3072b c x   + 30720b c x   + 73728b c x   + 49152b x )\|b \|c x  + b
+--R     + 
+--R             3 4 16         4 3 14         5 2 12         6   10         7 8
+--R       - 384b c x   - 12288b c x   - 61440b c x   - 98304b c x   - 49152b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 929
+
+--S 930 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     7           6  15            6          2 5  13
+--R               (72A c  - 192B b c )x   + (720A b c  - 1920B b c )x
+--R             + 
+--R                       2 5          3 4  11           3 4          4 3  9
+--R               (1728A b c  - 4608B b c )x   + (1152A b c  - 3072B b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  8          7  17              7         2 6  15
+--R           (- 9A c  + 24B b c )x   + (- 288A b c  + 768B b c )x
+--R         + 
+--R                     2 6          3 5  13             3 5          4 4  11
+--R           (- 1440A b c  + 3840B b c )x   + (- 2304A b c  + 6144B b c )x
+--R         + 
+--R                     4 4          5 3  9
+--R           (- 1152A b c  + 3072B b c )x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                     7           6  15            6          2 5  13
+--R               (72A c  - 192B b c )x   + (720A b c  - 1920B b c )x
+--R             + 
+--R                       2 5          3 4  11           3 4          4 3  9
+--R               (1728A b c  - 4608B b c )x   + (1152A b c  - 3072B b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  8          7  17              7         2 6  15
+--R           (- 9A c  + 24B b c )x   + (- 288A b c  + 768B b c )x
+--R         + 
+--R                     2 6          3 5  13             3 5          4 4  11
+--R           (- 1440A b c  + 3840B b c )x   + (- 2304A b c  + 6144B b c )x
+--R         + 
+--R                     4 4          5 3  9
+--R           (- 1152A b c  + 3072B b c )x
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                         6         2 5  12            2 5          3 4  10
+--R               (- 72A b c  + 192B b c )x   + (- 672A b c  + 2816B b c )x
+--R             + 
+--R                        3 4           4 3  8           4 3           5 2  6
+--R               (- 672A b c  + 14080B b c )x  + (6144A b c  + 29696B b c )x
+--R             + 
+--R                      5 2           6   4            6           7  2          7
+--R             (18432A b c  + 26624B b c)x  + (18432A b c + 8192B b )x  + 6144A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    7          6  14            6         2 5  12
+--R               (9A c  - 24B b c )x   + (282A b c  - 880B b c )x
+--R             + 
+--R                       2 5          3 4  10             3 4           4 3  8
+--R               (1176A b c  - 7488B b c )x   + (- 1008A b c  - 26112B b c )x
+--R             + 
+--R                          4 3           5 2  6              5 2           6   4
+--R               (- 13440A b c  - 41984B b c )x  + (- 26880A b c  - 30720B b c)x
+--R             + 
+--R                          6           7  2          7
+--R               (- 21504A b c - 8192B b )x  - 6144A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  7          6  15              6         2 5  13
+--R           (- 9A c  + 24B b c )x   + (- 282A b c  + 880B b c )x
+--R         + 
+--R                     2 5          3 4  11           3 4           4 3  9
+--R           (- 1176A b c  + 7488B b c )x   + (1008A b c  + 26112B b c )x
+--R         + 
+--R                    4 3           5 2  7            5 2           6   5
+--R           (13440A b c  + 41984B b c )x  + (26880A b c  + 30720B b c)x
+--R         + 
+--R                    6           7  3          7
+--R           (21504A b c + 8192B b )x  + 6144A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R               7         2 6  15          2 6          3 5  13
+--R       (72A b c  - 192B b c )x   + (744A b c  - 3008B b c )x
+--R     + 
+--R               3 5           4 4  11             4 4           5 3  9
+--R       (1344A b c  - 16896B b c )x   + (- 5472A b c  - 43776B b c )x
+--R     + 
+--R                  5 3           6 2  7              6 2           7   5
+--R       (- 24576A b c  - 56320B b c )x  + (- 36864A b c  - 34816B b c)x
+--R     + 
+--R                  7           8  3          8
+--R       (- 24576A b c - 8192B b )x  - 6144A b x
+--R  /
+--R                                                               +--------+
+--R             3 3 15         4 2 13         5   11         6 9  |   2
+--R       (3072b c x   + 30720b c x   + 73728b c x   + 49152b x )\|c x  + b
+--R     + 
+--R            2 4 17         3 3 15         4 2 13         5   11         6 9  +-+
+--R     (- 384b c x   - 12288b c x   - 61440b c x   - 98304b c x   - 49152b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 930
+
+--S 931 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    10 22         10           9  20
+--R               - B c  x   + (- A c   - 146B b c )x
+--R             + 
+--R                          9          2 8  18             2 8           3 7  16
+--R               (- 146A b c  - 3649B b c )x   + (- 3649A b c  - 36432B b c )x
+--R             + 
+--R                          3 7            4 6  14
+--R               (- 36432A b c  - 189216B b c )x
+--R             + 
+--R                           4 6            5 5  12
+--R               (- 189216A b c  - 575872B b c )x
+--R             + 
+--R                           5 5             6 4  10
+--R               (- 575872A b c  - 1085184B b c )x
+--R             + 
+--R                            6 4             7 3  8
+--R               (- 1085184A b c  - 1284096B b c )x
+--R             + 
+--R                            7 3            8 2  6
+--R               (- 1284096A b c  - 929792B b c )x
+--R             + 
+--R                           8 2            9   4               9            10  2
+--R               (- 929792A b c  - 376832B b c)x  + (- 376832A b c - 65536B b  )x
+--R             + 
+--R                         10
+--R               - 65536A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    10 22         10           9  20
+--R               17B c  x   + (17A c   + 850B b c )x
+--R             + 
+--R                        9           2 8  18            2 8           3 7  16
+--R               (850A b c  + 13073B b c )x   + (13073A b c  + 95472B b c )x
+--R             + 
+--R                        3 7            4 6  14
+--R               (95472A b c  + 394400B b c )x
+--R             + 
+--R                         4 6             5 5  12
+--R               (394400A b c  + 1003136B b c )x
+--R             + 
+--R                          5 5             6 4  10
+--R               (1003136A b c  + 1632000B b c )x
+--R             + 
+--R                          6 4             7 3  8
+--R               (1632000A b c  + 1705984B b c )x
+--R             + 
+--R                          7 3             8 2  6
+--R               (1705984A b c  + 1110016B b c )x
+--R             + 
+--R                          8 2            9   4             9            10  2
+--R               (1110016A b c  + 409600B b c)x  + (409600A b c + 65536B b  )x
+--R             + 
+--R                       10
+--R               65536A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  10 23           10           9  21
+--R           - 17B c  x   + (- 17A c   - 850B b c )x
+--R         + 
+--R                      9           2 8  19              2 8           3 7  17
+--R           (- 850A b c  - 13073B b c )x   + (- 13073A b c  - 95472B b c )x
+--R         + 
+--R                      3 7            4 6  15
+--R           (- 95472A b c  - 394400B b c )x
+--R         + 
+--R                       4 6             5 5  13
+--R           (- 394400A b c  - 1003136B b c )x
+--R         + 
+--R                        5 5             6 4  11
+--R           (- 1003136A b c  - 1632000B b c )x
+--R         + 
+--R                        6 4             7 3  9
+--R           (- 1632000A b c  - 1705984B b c )x
+--R         + 
+--R                        7 3             8 2  7
+--R           (- 1705984A b c  - 1110016B b c )x
+--R         + 
+--R                        8 2            9   5               9            10  3
+--R           (- 1110016A b c  - 409600B b c)x  + (- 409600A b c - 65536B b  )x
+--R         + 
+--R                     10
+--R           - 65536A b  x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          11 25       11           10  23            10          2 9  21
+--R       B c  x   + (A c   + 147B b c  )x   + (147A b c   + 3795B b c )x
+--R     + 
+--R               2 9           3 8  19            3 8            4 7  17
+--R       (3795A b c  + 40081B b c )x   + (40081A b c  + 225648B b c )x
+--R     + 
+--R                 4 7            5 6  15             5 6             6 5  13
+--R       (225648A b c  + 765088B b c )x   + (765088A b c  + 1661056B b c )x
+--R     + 
+--R                  6 5             7 4  11              7 4             8 3  9
+--R       (1661056A b c  + 2369280B b c )x   + (2369280A b c  + 2213888B b c )x
+--R     + 
+--R                  8 3             9 2  7              9 2            10   5
+--R       (2213888A b c  + 1306624B b c )x  + (1306624A b c  + 442368B b  c)x
+--R     + 
+--R                 10            11  3           11
+--R       (442368A b  c + 65536B b  )x  + 65536A b  x
+--R  /
+--R                8 25         7 23         2 6 21         3 5 19          4 4 17
+--R             17c x   + 816b c x   + 11424b c x   + 71808b c x   + 239360b c x
+--R           + 
+--R                    5 3 15          6 2 13          7   11         8 9
+--R             452608b c x   + 487424b c x   + 278528b c x   + 65536b x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R            9 27         8 25        2 7 23         3 6 21          4 5 19
+--R         - c x   - 145b c x   - 3504b c x   - 32928b c x   - 156288b c x
+--R       + 
+--R                  5 4 17          6 3 15          7 2 13          8   11
+--R         - 419584b c x   - 665600b c x   - 618496b c x   - 311296b c x
+--R       + 
+--R                 9 9
+--R         - 65536b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 931
+
+)clear all
+
+--S 932 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^13
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              11
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 932
+
+--S 933 of 3139
+r0:=-1/9*A*(b*x^2+c*x^4)^(5/2)/(b*x^14)-1/63*(9*b*B-4*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^12)+2/315*c*(9*b*B-4*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^3*x^10)
+--R 
+--R
+--R   (2)
+--R                4          3  8          3       2 2  6
+--R         (- 8A c  + 18B b c )x  + (4A b c  - 9B b c )x
+--R       + 
+--R                2 2        3   4           3         4  2        4
+--R         (- 3A b c  - 72B b c)x  + (- 50A b c - 45B b )x  - 35A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         3 10
+--R     315b x
+--R                                                    Type: Expression(Integer)
+--E 933
+
+--S 934 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 8           7  16            7          2 6  14
+--R           (72A c  - 162B b c )x   + (924A b c  - 2079B b c )x
+--R         + 
+--R                   2 6          3 5  12           3 5          4 4  10
+--R           (3003A b c  - 6048B b c )x   + (3690A b c  + 2565B b c )x
+--R         + 
+--R                   4 4           5 3  8            5 3           6 2  6
+--R           (7355A b c  + 37080B b c )x  + (26504A b c  + 63216B b c )x
+--R         + 
+--R                    6 2           7   4            7            8  2          8
+--R           (44688A b c  + 44352B b c)x  + (32960A b c + 11520B b )x  + 8960A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              9          8  18              8         2 7  16
+--R       (- 8A c  + 18B b c )x   + (- 324A b c  + 729B b c )x
+--R     + 
+--R                 2 7          3 6  14             3 6          4 5  12
+--R       (- 2079A b c  + 4599B b c )x   + (- 4557A b c  + 6867B b c )x
+--R     + 
+--R                 4 5           5 4  10              5 4           6 3  8
+--R       (- 5805A b c  - 15525B b c )x   + (- 16731A b c  - 63864B b c )x
+--R     + 
+--R                  6 3           7 2  6              7 2           8   4
+--R       (- 45288A b c  - 83952B b c )x  + (- 60048A b c  - 50112B b c)x
+--R     + 
+--R                  8            9  2          9
+--R       (- 37440A b c - 11520B b )x  - 8960A b
+--R  /
+--R              3 4 17         4 3 15         5 2 13          6   11         7 9
+--R         (315b c x   + 12600b c x   + 75600b c x   + 141120b c x   + 80640b x )
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                  3 4 17         4 3 15          5 2 13          6   11
+--R           - 2835b c x   - 37800b c x   - 136080b c x   - 181440b c x
+--R         + 
+--R                   7 9
+--R           - 80640b x
+--R      *
+--R          +-+
+--R         \|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 934
+
+--S 935 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    8          7  16            7         2 6  14
+--R               (8A c  - 18B b c )x   + (316A b c  - 711B b c )x
+--R             + 
+--R                       2 6          3 5  12           3 5          4 4  10
+--R               (1763A b c  - 3888B b c )x   + (2794A b c  - 2979B b c )x
+--R             + 
+--R                       4 4           5 3  8            5 3           6 2  6
+--R               (3011A b c  + 18504B b c )x  + (13720A b c  + 45360B b c )x
+--R             + 
+--R                        6 2           7   4            7            8  2
+--R               (31568A b c  + 38592B b c)x  + (28480A b c + 11520B b )x
+--R             + 
+--R                      8
+--R               8960A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                       8           7  16              7          2 6  14
+--R               (- 72A c  + 162B b c )x   + (- 924A b c  + 2079B b c )x
+--R             + 
+--R                         2 6          3 5  12             3 5          4 4  10
+--R               (- 3003A b c  + 6048B b c )x   + (- 3690A b c  - 2565B b c )x
+--R             + 
+--R                         4 4           5 3  8              5 3           6 2  6
+--R               (- 7355A b c  - 37080B b c )x  + (- 26504A b c  - 63216B b c )x
+--R             + 
+--R                          6 2           7   4              7            8  2
+--R               (- 44688A b c  - 44352B b c)x  + (- 32960A b c - 11520B b )x
+--R             + 
+--R                        8
+--R               - 8960A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 8           7  17            7          2 6  15
+--R           (72A c  - 162B b c )x   + (924A b c  - 2079B b c )x
+--R         + 
+--R                   2 6          3 5  13           3 5          4 4  11
+--R           (3003A b c  - 6048B b c )x   + (3690A b c  + 2565B b c )x
+--R         + 
+--R                   4 4           5 3  9            5 3           6 2  7
+--R           (7355A b c  + 37080B b c )x  + (26504A b c  + 63216B b c )x
+--R         + 
+--R                  6 2           7   5            7            8  3          8
+--R         (44688A b c  + 44352B b c)x  + (32960A b c + 11520B b )x  + 8960A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              9          8  19              8         2 7  17
+--R       (- 8A c  + 18B b c )x   + (- 324A b c  + 729B b c )x
+--R     + 
+--R                 2 7          3 6  15             3 6          4 5  13
+--R       (- 2079A b c  + 4599B b c )x   + (- 4557A b c  + 6867B b c )x
+--R     + 
+--R                 4 5           5 4  11              5 4           6 3  9
+--R       (- 5805A b c  - 15525B b c )x   + (- 16731A b c  - 63864B b c )x
+--R     + 
+--R                  6 3           7 2  7              7 2           8   5
+--R       (- 45288A b c  - 83952B b c )x  + (- 60048A b c  - 50112B b c)x
+--R     + 
+--R                  8            9  3          9
+--R       (- 37440A b c - 11520B b )x  - 8960A b x
+--R  /
+--R              3 4 18         4 3 16         5 2 14          6   12         7 10
+--R         (315b c x   + 12600b c x   + 75600b c x   + 141120b c x   + 80640b x  )
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                  3 4 18         4 3 16          5 2 14          6   12
+--R           - 2835b c x   - 37800b c x   - 136080b c x   - 181440b c x
+--R         + 
+--R                   7 10
+--R           - 80640b x
+--R      *
+--R          +-+
+--R         \|b
+--R                                                    Type: Expression(Integer)
+--E 935
+
+--S 936 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      10 22           10           9  20
+--R               - 18B c  x   + (- 18A c   - 996B b c )x
+--R             + 
+--R                          9           2 8  18
+--R               (- 996A b c  - 16722B b c )x
+--R             + 
+--R                          2 8            3 7  16
+--R               (- 16722A b c  - 131904B b c )x
+--R             + 
+--R                           3 7            4 6  14
+--R               (- 131904A b c  - 583616B b c )x
+--R             + 
+--R                           4 6             5 5  12
+--R               (- 583616A b c  - 1579008B b c )x
+--R             + 
+--R                            5 5             6 4  10
+--R               (- 1579008A b c  - 2717184B b c )x
+--R             + 
+--R                            6 4             7 3  8
+--R               (- 2717184A b c  - 2990080B b c )x
+--R             + 
+--R                            7 3             8 2  6
+--R               (- 2990080A b c  - 2039808B b c )x
+--R             + 
+--R                            8 2            9   4
+--R               (- 2039808A b c  - 786432B b c)x
+--R             + 
+--R                           9             10  2            10
+--R               (- 786432A b c - 131072B b  )x  - 131072A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              11 24       11           10  22            10          2 9  20
+--R           B c  x   + (A c   + 164B b c  )x   + (164A b c   + 4645B b c )x
+--R         + 
+--R                   2 9           3 8  18            3 8            4 7  16
+--R           (4645A b c  + 53154B b c )x   + (53154A b c  + 321120B b c )x
+--R         + 
+--R                     4 7             5 6  14
+--R           (321120A b c  + 1159488B b c )x
+--R         + 
+--R                      5 6             6 5  12
+--R           (1159488A b c  + 2664192B b c )x
+--R         + 
+--R                      6 5             7 4  10
+--R           (2664192A b c  + 4001280B b c )x
+--R         + 
+--R                      7 4             8 3  8              8 3             9 2  6
+--R           (4001280A b c  + 3919872B b c )x  + (3919872A b c  + 2416640B b c )x
+--R         + 
+--R                      9 2            10   4             10             11  2
+--R           (2416640A b c  + 851968B b  c)x  + (851968A b  c + 131072B b  )x
+--R         + 
+--R                    11
+--R           131072A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                11 25         11           10  23
+--R           - B c  x   + (- A c   - 164B b c  )x
+--R         + 
+--R                      10          2 9  21             2 9           3 8  19
+--R           (- 164A b c   - 4645B b c )x   + (- 4645A b c  - 53154B b c )x
+--R         + 
+--R                      3 8            4 7  17
+--R           (- 53154A b c  - 321120B b c )x
+--R         + 
+--R                       4 7             5 6  15
+--R           (- 321120A b c  - 1159488B b c )x
+--R         + 
+--R                        5 6             6 5  13
+--R           (- 1159488A b c  - 2664192B b c )x
+--R         + 
+--R                        6 5             7 4  11
+--R           (- 2664192A b c  - 4001280B b c )x
+--R         + 
+--R                        7 4             8 3  9
+--R           (- 4001280A b c  - 3919872B b c )x
+--R         + 
+--R                        8 3             9 2  7
+--R           (- 3919872A b c  - 2416640B b c )x
+--R         + 
+--R                        9 2            10   5               10             11  3
+--R           (- 2416640A b c  - 851968B b  c)x  + (- 851968A b  c - 131072B b  )x
+--R         + 
+--R                      11
+--R           - 131072A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                11 25         11            10  23
+--R           18B c  x   + (18A c   + 1014B b c  )x
+--R         + 
+--R                     10           2 9  21            2 9            3 8  19
+--R           (1014A b c   + 17718B b c )x   + (17718A b c  + 148626B b c )x
+--R         + 
+--R                     3 8            4 7  17             4 7             5 6  15
+--R           (148626A b c  + 715520B b c )x   + (715520A b c  + 2162624B b c )x
+--R         + 
+--R                      5 6             6 5  13
+--R           (2162624A b c  + 4296192B b c )x
+--R         + 
+--R                      6 5             7 4  11
+--R           (4296192A b c  + 5707264B b c )x
+--R         + 
+--R                      7 4             8 3  9              8 3             9 2  7
+--R           (5707264A b c  + 5029888B b c )x  + (5029888A b c  + 2826240B b c )x
+--R         + 
+--R                      9 2            10   5             10             11  3
+--R           (2826240A b c  + 917504B b  c)x  + (917504A b  c + 131072B b  )x
+--R         + 
+--R                    11
+--R           131072A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              9 28         8 26        2 7 24         3 6 22          4 5 20
+--R             c x   + 162b c x   + 4320b c x   + 44352b c x   + 228096b c x
+--R           + 
+--R                    5 4 18           6 3 16           7 2 14          8   12
+--R             658944b c x   + 1118208b c x   + 1105920b c x   + 589824b c x
+--R           + 
+--R                    9 10
+--R             131072b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  9 28         8 26         2 7 24          3 6 22
+--R             - 18c x   - 978b c x   - 15744b c x   - 116160b c x
+--R           + 
+--R                      4 5 20           5 4 18           6 3 16           7 2 14
+--R             - 467456b c x   - 1111552b c x   - 1605632b c x   - 1384448b c x
+--R           + 
+--R                      8   12          9 10
+--R             - 655360b c x   - 131072b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 936
+
+)clear all
+
+--S 937 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^14
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              12
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 937
+
+--S 938 of 3139
+r0:=-1/128*c^2*(2*b*B-A*c)*(b*x^2+c*x^4)^(3/2)/(b^3*x^7)-_
+   1/10*A*(b*x^2+c*x^4)^(5/2)/(b*x^15)-1/16*(2*b*B-A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^13)+1/32*c*(2*b*B-A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^3*x^11)-3/256*c^4*(2*b*B-A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(7/2)-3/256*c^3*(2*b*B-A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^3*x^3)
+--R 
+--R
+--R   (2)
+--R                                          +-+
+--R             5          4  11           x\|b
+--R       (15A c  - 30B b c )x  atanh(--------------)
+--R                                    +-----------+
+--R                                    |   4      2
+--R                                   \|c x  + b x
+--R     + 
+--R                   4          3  8           3        2 2  6
+--R           (- 15A c  + 30B b c )x  + (10A b c  - 20B b c )x
+--R         + 
+--R                  2 2         3   4            3          4  2         4
+--R           (- 8A b c  - 240B b c)x  + (- 176A b c - 160B b )x  - 128A b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|b \|c x  + b x
+--R  /
+--R          3 11 +-+
+--R     1280b x  \|b
+--R                                                    Type: Expression(Integer)
+--E 938
+
+--S 939 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          9         2 8  18             2 8          3 7  16
+--R               (- 150A b c  + 300B b c )x   + (- 2400A b c  + 4800B b c )x
+--R             + 
+--R                          3 7           4 6  14
+--R               (- 10080A b c  + 20160B b c )x
+--R             + 
+--R                        4 6           5 5  12             5 5           6 4  10
+--R             (- 15360A b c  + 30720B b c )x   + (- 7680A b c  + 15360B b c )x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                     10          9  20            9          2 8  18
+--R               (15A c   - 30B b c )x   + (750A b c  - 1500B b c )x
+--R             + 
+--R                       2 8           3 7  16            3 7           4 6  14
+--R               (6000A b c  - 12000B b c )x   + (16800A b c  - 33600B b c )x
+--R             + 
+--R                        4 6           5 5  12           5 5           6 4  10
+--R               (19200A b c  - 38400B b c )x   + (7680A b c  - 15360B b c )x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                   9        2 8  18          2 8          3 7  16
+--R           (15A b c  - 30B b c )x   + (740A b c  - 1480B b c )x
+--R         + 
+--R                   3 7           4 6  14            4 6           5 5  12
+--R           (5508A b c  - 10760B b c )x   + (13376A b c  - 13440B b c )x
+--R         + 
+--R                    5 5           6 4  10            6 4            7 3  8
+--R           (20128A b c  + 88000B b c )x   + (80640A b c  + 343040B b c )x
+--R         + 
+--R                     7 3            8 2  6             8 2            9   4
+--R           (253440A b c  + 496640B b c )x  + (372736A b c  + 327680B b c)x
+--R         + 
+--R                     9            10  2           10
+--R           (253952A b c + 81920B b  )x  + 65536A b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                      9         2 8  18             2 8          3 7  16
+--R           (- 150A b c  + 300B b c )x   + (- 2450A b c  + 4900B b c )x
+--R         + 
+--R                      3 7           4 6  14              4 6          5 5  12
+--R           (- 10860A b c  + 19160B b c )x   + (- 20240A b c  - 8160B b c )x
+--R         + 
+--R                      5 5            6 4  10               6 4            7 3  8
+--R           (- 43936A b c  - 214720B b c )x   + (- 174080A b c  - 555520B b c )x
+--R         + 
+--R                       7 3            8 2  6               8 2            9   4
+--R           (- 412160A b c  - 650240B b c )x  + (- 491520A b c  - 368640B b c)x
+--R         + 
+--R                       9            10  2           10
+--R           (- 286720A b c - 81920B b  )x  - 65536A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                 4 4 18          5 3 16          6 2 14           7   12
+--R           12800b c x   + 204800b c x   + 860160b c x   + 1310720b c x
+--R         + 
+--R                  8 10
+--R           655360b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              4 5 20         5 4 18          6 3 16           7 2 14
+--R       - 1280b c x   - 64000b c x   - 512000b c x   - 1433600b c x
+--R     + 
+--R                 8   12          9 10
+--R       - 1638400b c x   - 655360b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 939
+
+--S 940 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        9           8  19               8          2 7  17
+--R               (- 150A c  + 300B b c )x   + (- 2400A b c  + 4800B b c )x
+--R             + 
+--R                          2 7           3 6  15
+--R               (- 10080A b c  + 20160B b c )x
+--R             + 
+--R                        3 6           4 5  13             4 5           5 4  11
+--R             (- 15360A b c  + 30720B b c )x   + (- 7680A b c  + 15360B b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                 10          9  21            9          2 8  19
+--R           (15A c   - 30B b c )x   + (750A b c  - 1500B b c )x
+--R         + 
+--R                   2 8           3 7  17            3 7           4 6  15
+--R           (6000A b c  - 12000B b c )x   + (16800A b c  - 33600B b c )x
+--R         + 
+--R                    4 6           5 5  13           5 5           6 4  11
+--R           (19200A b c  - 38400B b c )x   + (7680A b c  - 15360B b c )x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                        9           8  19               8          2 7  17
+--R               (- 150A c  + 300B b c )x   + (- 2400A b c  + 4800B b c )x
+--R             + 
+--R                          2 7           3 6  15
+--R               (- 10080A b c  + 20160B b c )x
+--R             + 
+--R                        3 6           4 5  13             4 5           5 4  11
+--R             (- 15360A b c  + 30720B b c )x   + (- 7680A b c  + 15360B b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                 10          9  21            9          2 8  19
+--R           (15A c   - 30B b c )x   + (750A b c  - 1500B b c )x
+--R         + 
+--R                   2 8           3 7  17            3 7           4 6  15
+--R           (6000A b c  - 12000B b c )x   + (16800A b c  - 33600B b c )x
+--R         + 
+--R                    4 6           5 5  13           5 5           6 4  11
+--R           (19200A b c  - 38400B b c )x   + (7680A b c  - 15360B b c )x
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                        8         2 7  16           2 7          3 6  14
+--R               (150A b c  - 300B b c )x   + (2300A b c  - 4600B b c )x
+--R             + 
+--R                       3 6           4 5  12            4 5           5 4  10
+--R               (8560A b c  - 14560B b c )x   + (11680A b c  + 22720B b c )x
+--R             + 
+--R                        5 4            6 3  8             6 3            7 2  6
+--R               (32256A b c  + 192000B b c )x  + (141824A b c  + 363520B b c )x
+--R             + 
+--R                         7 2            8   4             8            9  2
+--R               (270336A b c  + 286720B b c)x  + (221184A b c + 81920B b )x
+--R             + 
+--R                       9
+--R               65536A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                       9          8  18              8          2 7  16
+--R               (- 15A c  + 30B b c )x   + (- 740A b c  + 1480B b c )x
+--R             + 
+--R                         2 7           3 6  14
+--R               (- 5508A b c  + 10760B b c )x
+--R             + 
+--R                          3 6           4 5  12
+--R               (- 13376A b c  + 13440B b c )x
+--R             + 
+--R                          4 5           5 4  10
+--R               (- 20128A b c  - 88000B b c )x
+--R             + 
+--R                          5 4            6 3  8
+--R               (- 80640A b c  - 343040B b c )x
+--R             + 
+--R                           6 3            7 2  6
+--R               (- 253440A b c  - 496640B b c )x
+--R             + 
+--R                           7 2            8   4               8            9  2
+--R               (- 372736A b c  - 327680B b c)x  + (- 253952A b c - 81920B b )x
+--R             + 
+--R                         9
+--R               - 65536A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 9          8  19            8          2 7  17
+--R           (15A c  - 30B b c )x   + (740A b c  - 1480B b c )x
+--R         + 
+--R                   2 7           3 6  15            3 6           4 5  13
+--R           (5508A b c  - 10760B b c )x   + (13376A b c  - 13440B b c )x
+--R         + 
+--R                    4 5           5 4  11            5 4            6 3  9
+--R           (20128A b c  + 88000B b c )x   + (80640A b c  + 343040B b c )x
+--R         + 
+--R                     6 3            7 2  7             7 2            8   5
+--R           (253440A b c  + 496640B b c )x  + (372736A b c  + 327680B b c)x
+--R         + 
+--R                     8            9  3           9
+--R           (253952A b c + 81920B b )x  + 65536A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                  9         2 8  19             2 8          3 7  17
+--R       (- 150A b c  + 300B b c )x   + (- 2450A b c  + 4900B b c )x
+--R     + 
+--R                  3 7           4 6  15              4 6          5 5  13
+--R       (- 10860A b c  + 19160B b c )x   + (- 20240A b c  - 8160B b c )x
+--R     + 
+--R                  5 5            6 4  11               6 4            7 3  9
+--R       (- 43936A b c  - 214720B b c )x   + (- 174080A b c  - 555520B b c )x
+--R     + 
+--R                   7 3            8 2  7               8 2            9   5
+--R       (- 412160A b c  - 650240B b c )x  + (- 491520A b c  - 368640B b c)x
+--R     + 
+--R                   9            10  3           10
+--R       (- 286720A b c - 81920B b  )x  - 65536A b  x
+--R  /
+--R                 4 4 19          5 3 17          6 2 15           7   13
+--R           12800b c x   + 204800b c x   + 860160b c x   + 1310720b c x
+--R         + 
+--R                  8 11
+--R           655360b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                  3 5 21         4 4 19          5 3 17           6 2 15
+--R           - 1280b c x   - 64000b c x   - 512000b c x   - 1433600b c x
+--R         + 
+--R                     7   13          8 11
+--R           - 1638400b c x   - 655360b x
+--R      *
+--R          +-+
+--R         \|b
+--R                                                    Type: Expression(Integer)
+--E 940
+
+--S 941 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    12 26         12           11  24
+--R               - B c  x   + (- A c   - 222B b c  )x
+--R             + 
+--R                          11          2 10  22
+--R               (- 222A b c   - 8361B b c  )x
+--R             + 
+--R                         2 10            3 9  20
+--R               (- 8361A b c   - 125884B b c )x
+--R             + 
+--R                           3 9            4 8  18
+--R               (- 125884A b c  - 996336B b c )x
+--R             + 
+--R                           4 8             5 7  16
+--R               (- 996336A b c  - 4722432B b c )x
+--R             + 
+--R                            5 7              6 6  14
+--R               (- 4722432A b c  - 14373632B b c )x
+--R             + 
+--R                             6 6              7 5  12
+--R               (- 14373632A b c  - 29125632B b c )x
+--R             + 
+--R                             7 5              8 4  10
+--R               (- 29125632A b c  - 39763968B b c )x
+--R             + 
+--R                             8 4              9 3  8
+--R               (- 39763968A b c  - 36175872B b c )x
+--R             + 
+--R                             9 3              10 2  6
+--R               (- 36175872A b c  - 21037056B b  c )x
+--R             + 
+--R                             10 2             11   4
+--R               (- 21037056A b  c  - 7077888B b  c)x
+--R             + 
+--R                            11              12  2             12
+--R               (- 7077888A b  c - 1048576B b  )x  - 1048576A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    12 26         12            11  24
+--R               21B c  x   + (21A c   + 1582B b c  )x
+--R             + 
+--R                         11           2 10  22
+--R               (1582A b c   + 36365B b c  )x
+--R             + 
+--R                        2 10            3 9  20
+--R               (36365A b c   + 397540B b c )x
+--R             + 
+--R                         3 9             4 8  18
+--R               (397540A b c  + 2486000B b c )x
+--R             + 
+--R                          4 8             5 7  16
+--R               (2486000A b c  + 9787648B b c )x
+--R             + 
+--R                          5 7              6 6  14
+--R               (9787648A b c  + 25577216B b c )x
+--R             + 
+--R                           6 6              7 5  12
+--R               (25577216A b c  + 45552640B b c )x
+--R             + 
+--R                           7 5              8 4  10
+--R               (45552640A b c  + 55623680B b c )x
+--R             + 
+--R                           8 4              9 3  8
+--R               (55623680A b c  + 45875200B b c )x
+--R             + 
+--R                           9 3              10 2  6
+--R               (45875200A b c  + 24444928B b  c )x
+--R             + 
+--R                           10 2             11   4
+--R               (24444928A b  c  + 7602176B b  c)x
+--R             + 
+--R                          11              12  2             12
+--R               (7602176A b  c + 1048576B b  )x  + 1048576A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  12 27           12            11  25
+--R           - 21B c  x   + (- 21A c   - 1582B b c  )x
+--R         + 
+--R                       11           2 10  23
+--R           (- 1582A b c   - 36365B b c  )x
+--R         + 
+--R                      2 10            3 9  21
+--R           (- 36365A b c   - 397540B b c )x
+--R         + 
+--R                       3 9             4 8  19
+--R           (- 397540A b c  - 2486000B b c )x
+--R         + 
+--R                        4 8             5 7  17
+--R           (- 2486000A b c  - 9787648B b c )x
+--R         + 
+--R                        5 7              6 6  15
+--R           (- 9787648A b c  - 25577216B b c )x
+--R         + 
+--R                         6 6              7 5  13
+--R           (- 25577216A b c  - 45552640B b c )x
+--R         + 
+--R                         7 5              8 4  11
+--R           (- 45552640A b c  - 55623680B b c )x
+--R         + 
+--R                         8 4              9 3  9
+--R           (- 55623680A b c  - 45875200B b c )x
+--R         + 
+--R                         9 3              10 2  7
+--R           (- 45875200A b c  - 24444928B b  c )x
+--R         + 
+--R                         10 2             11   5
+--R           (- 24444928A b  c  - 7602176B b  c)x
+--R         + 
+--R                        11              12  3             12
+--R           (- 7602176A b  c - 1048576B b  )x  - 1048576A b  x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          13 29       13           12  27            12          2 11  25
+--R       B c  x   + (A c   + 223B b c  )x   + (223A b c   + 8583B b c  )x
+--R     + 
+--R               2 11            3 10  23             3 10             4 9  21
+--R       (8583A b c   + 134245B b c  )x   + (134245A b c   + 1122220B b c )x
+--R     + 
+--R                  4 9             5 8  19              5 8              6 7  17
+--R       (1122220A b c  + 5718768B b c )x   + (5718768A b c  + 19096064B b c )x
+--R     + 
+--R                   6 7              7 6  15
+--R       (19096064A b c  + 43499264B b c )x
+--R     + 
+--R                   7 6              8 5  13
+--R       (43499264A b c  + 68889600B b c )x
+--R     + 
+--R                   8 5              9 4  11
+--R       (68889600A b c  + 75939840B b c )x
+--R     + 
+--R                   9 4              10 3  9
+--R       (75939840A b c  + 57212928B b  c )x
+--R     + 
+--R                   10 3              11 2  7
+--R       (57212928A b  c  + 28114944B b  c )x
+--R     + 
+--R                   11 2             12   5              12              13  3
+--R       (28114944A b  c  + 8126464B b  c)x  + (8126464A b  c + 1048576B b  )x
+--R     + 
+--R                 13
+--R       1048576A b  x
+--R  /
+--R                10 31          9 29         2 8 27          3 7 25
+--R             21c  x   + 1540b c x   + 33264b c x   + 329472b c x
+--R           + 
+--R                     4 6 23           5 5 21            6 4 19            7 3 17
+--R             1793792b c x   + 5870592b c x   + 12042240b c x   + 15597568b c x
+--R           + 
+--R                      8 2 15           9   13           10 11
+--R             12386304b c x   + 5505024b c x   + 1048576b  x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R            11 33         10 31        2 9 29          3 8 27          4 7 25
+--R         - c  x   - 221b c  x   - 8140b c x   - 117744b c x   - 878592b c x
+--R       + 
+--R                   5 6 23            6 5 21            7 4 19            8 3 17
+--R         - 3843840b c x   - 10529792b c x   - 18595840b c x   - 21168128b c x
+--R       + 
+--R                    9 2 15           10   13           11 11
+--R         - 15007744b c x   - 6029312b  c x   - 1048576b  x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 941
+
+)clear all
+
+--S 942 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^15
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              13
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 942
+
+--S 943 of 3139
+r0:=-1/11*A*(b*x^2+c*x^4)^(5/2)/(b*x^16)-1/99*(11*b*B-6*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^14)+4/693*c*(11*b*B-6*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^3*x^12)-8/3465*c^2*(11*b*B-6*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^4*x^10)
+--R 
+--R
+--R   (2)
+--R               5          4  10             4        2 3  8
+--R         (48A c  - 88B b c )x   + (- 24A b c  + 44B b c )x
+--R       + 
+--R               2 3        3 2  6           3 2         4   4
+--R         (18A b c  - 33B b c )x  + (- 15A b c  - 550B b c)x
+--R       + 
+--R                  4          5  2         5
+--R         (- 420A b c - 385B b )x  - 315A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R          4 12
+--R     3465b x
+--R                                                    Type: Expression(Integer)
+--E 943
+
+--S 944 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    10           9  20                9           2 8  18
+--R           (- 528A c   + 968B b c )x   + (- 10296A b c  + 18876B b c )x
+--R         + 
+--R                      2 8           3 7  16               3 7            4 6  14
+--R           (- 54054A b c  + 99099B b c )x   + (- 109395A b c  + 206910B b c )x
+--R         + 
+--R                      4 6            5 5  12            5 5            6 4  10
+--R           (- 81840A b c  + 289795B b c )x   + (82089A b c  + 821436B b c )x
+--R         + 
+--R                     6 4             7 3  8              7 3             8 2  6
+--R           (602868A b c  + 2070992B b c )x  + (1594608A b c  + 2666752B b c )x
+--R         + 
+--R                      8 2             9   4              9             10  2
+--R           (2085120A b c  + 1647360B b c)x  + (1317120A b c + 394240B b  )x
+--R         + 
+--R                    10
+--R           322560A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R             11          10  22             10          2 9  20
+--R       (48A c   - 88B b c  )x   + (2904A b c   - 5324B b c )x
+--R     + 
+--R                2 9           3 8  18            3 8            4 7  16
+--R       (28314A b c  - 51909B b c )x   + (99099A b c  - 182259B b c )x
+--R     + 
+--R                 4 7            5 6  14            5 6            6 5  12
+--R       (149985A b c  - 311355B b c )x   + (68541A b c  - 554741B b c )x
+--R     + 
+--R                   6 5             7 4  10                7 4             8 3  8
+--R       (- 271887A b c  - 1611148B b c )x   + (- 1209252A b c  - 3223088B b c )x
+--R     + 
+--R                    8 3             9 2  6                9 2             10   4
+--R       (- 2492688A b c  - 3441152B b c )x  + (- 2703360A b c  - 1844480B b  c)x
+--R     + 
+--R                    10             11  2            11
+--R       (- 1478400A b  c - 394240B b  )x  - 322560A b
+--R  /
+--R                4 5 21          5 4 19           6 3 17           7 2 15
+--R           3465b c x   + 207900b c x   + 1940400b c x   + 6209280b c x
+--R         + 
+--R                   8   13           9 11
+--R           7983360b c x   + 3548160b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                   4 5 21          5 4 19           6 3 17           7 2 15
+--R           - 38115b c x   - 762300b c x   - 4268880b c x   - 9757440b c x
+--R         + 
+--R                     8   13           9 11
+--R           - 9757440b c x   - 3548160b x
+--R      *
+--R          +-+
+--R         \|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 944
+
+--S 945 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       10          9  20               9          2 8  18
+--R               (- 48A c   + 88B b c )x   + (- 2856A b c  + 5236B b c )x
+--R             + 
+--R                          2 8           3 7  16
+--R               (- 25458A b c  + 46673B b c )x
+--R             + 
+--R                          3 7            4 6  14
+--R               (- 73641A b c  + 135586B b c )x
+--R             + 
+--R                          4 6            5 5  12
+--R               (- 76344A b c  + 175769B b c )x
+--R             + 
+--R                       5 5            6 4  10             6 4             7 3  8
+--R               (7803A b c  + 378972B b c )x   + (264084A b c  + 1232176B b c )x
+--R             + 
+--R                         7 3             8 2  6
+--R               (945168A b c  + 1990912B b c )x
+--R             + 
+--R                          8 2             9   4              9             10  2
+--R               (1547520A b c  + 1450240B b c)x  + (1155840A b c + 394240B b  )x
+--R             + 
+--R                        10
+--R               322560A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                      10           9  20              9           2 8  18
+--R               (528A c   - 968B b c )x   + (10296A b c  - 18876B b c )x
+--R             + 
+--R                        2 8           3 7  16             3 7            4 6  14
+--R               (54054A b c  - 99099B b c )x   + (109395A b c  - 206910B b c )x
+--R             + 
+--R                        4 6            5 5  12
+--R               (81840A b c  - 289795B b c )x
+--R             + 
+--R                          5 5            6 4  10
+--R               (- 82089A b c  - 821436B b c )x
+--R             + 
+--R                           6 4             7 3  8
+--R               (- 602868A b c  - 2070992B b c )x
+--R             + 
+--R                            7 3             8 2  6
+--R               (- 1594608A b c  - 2666752B b c )x
+--R             + 
+--R                            8 2             9   4
+--R               (- 2085120A b c  - 1647360B b c)x
+--R             + 
+--R                            9             10  2            10
+--R               (- 1317120A b c - 394240B b  )x  - 322560A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    10           9  21                9           2 8  19
+--R           (- 528A c   + 968B b c )x   + (- 10296A b c  + 18876B b c )x
+--R         + 
+--R                      2 8           3 7  17               3 7            4 6  15
+--R           (- 54054A b c  + 99099B b c )x   + (- 109395A b c  + 206910B b c )x
+--R         + 
+--R                      4 6            5 5  13            5 5            6 4  11
+--R           (- 81840A b c  + 289795B b c )x   + (82089A b c  + 821436B b c )x
+--R         + 
+--R                     6 4             7 3  9              7 3             8 2  7
+--R           (602868A b c  + 2070992B b c )x  + (1594608A b c  + 2666752B b c )x
+--R         + 
+--R                      8 2             9   5              9             10  3
+--R           (2085120A b c  + 1647360B b c)x  + (1317120A b c + 394240B b  )x
+--R         + 
+--R                    10
+--R           322560A b  x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R             11          10  23             10          2 9  21
+--R       (48A c   - 88B b c  )x   + (2904A b c   - 5324B b c )x
+--R     + 
+--R                2 9           3 8  19            3 8            4 7  17
+--R       (28314A b c  - 51909B b c )x   + (99099A b c  - 182259B b c )x
+--R     + 
+--R                 4 7            5 6  15            5 6            6 5  13
+--R       (149985A b c  - 311355B b c )x   + (68541A b c  - 554741B b c )x
+--R     + 
+--R                   6 5             7 4  11                7 4             8 3  9
+--R       (- 271887A b c  - 1611148B b c )x   + (- 1209252A b c  - 3223088B b c )x
+--R     + 
+--R                    8 3             9 2  7                9 2             10   5
+--R       (- 2492688A b c  - 3441152B b c )x  + (- 2703360A b c  - 1844480B b  c)x
+--R     + 
+--R                    10             11  3            11
+--R       (- 1478400A b  c - 394240B b  )x  - 322560A b  x
+--R  /
+--R                4 5 22          5 4 20           6 3 18           7 2 16
+--R           3465b c x   + 207900b c x   + 1940400b c x   + 6209280b c x
+--R         + 
+--R                   8   14           9 12
+--R           7983360b c x   + 3548160b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                   4 5 22          5 4 20           6 3 18           7 2 16
+--R           - 38115b c x   - 762300b c x   - 4268880b c x   - 9757440b c x
+--R         + 
+--R                     8   14           9 12
+--R           - 9757440b c x   - 3548160b x
+--R      *
+--R          +-+
+--R         \|b
+--R                                                    Type: Expression(Integer)
+--E 945
+
+--S 946 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      12 26           12            11  24
+--R               - 22B c  x   + (- 22A c   - 1804B b c  )x
+--R             + 
+--R                           11           2 10  22
+--R               (- 1804A b c   - 44726B b c  )x
+--R             + 
+--R                          2 10            3 9  20
+--R               (- 44726A b c   - 523424B b c )x
+--R             + 
+--R                           3 9             4 8  18
+--R               (- 523424A b c  - 3482336B b c )x
+--R             + 
+--R                            4 8              5 7  16
+--R               (- 3482336A b c  - 14510080B b c )x
+--R             + 
+--R                             5 7              6 6  14
+--R               (- 14510080A b c  - 39950848B b c )x
+--R             + 
+--R                             6 6              7 5  12
+--R               (- 39950848A b c  - 74678272B b c )x
+--R             + 
+--R                             7 5              8 4  10
+--R               (- 74678272A b c  - 95387648B b c )x
+--R             + 
+--R                             8 4              9 3  8
+--R               (- 95387648A b c  - 82051072B b c )x
+--R             + 
+--R                             9 3              10 2  6
+--R               (- 82051072A b c  - 45481984B b  c )x
+--R             + 
+--R                             10 2              11   4
+--R               (- 45481984A b  c  - 14680064B b  c)x
+--R             + 
+--R                             11              12  2             12
+--R               (- 14680064A b  c - 2097152B b  )x  - 2097152A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              13 28       13           12  26            12           2 11  24
+--R           B c  x   + (A c   + 244B b c  )x   + (244A b c   + 10165B b c  )x
+--R         + 
+--R                    2 11            3 10  22
+--R           (10165A b c   + 170610B b c  )x
+--R         + 
+--R                     3 10             4 9  20
+--R           (170610A b c   + 1519760B b c )x
+--R         + 
+--R                      4 9             5 8  18
+--R           (1519760A b c  + 8204768B b c )x
+--R         + 
+--R                      5 8              6 7  16
+--R           (8204768A b c  + 28883712B b c )x
+--R         + 
+--R                       6 7              7 6  14
+--R           (28883712A b c  + 69076480B b c )x
+--R         + 
+--R                       7 6               8 5  12
+--R           (69076480A b c  + 114442240B b c )x
+--R         + 
+--R                        8 5               9 4  10
+--R           (114442240A b c  + 131563520B b c )x
+--R         + 
+--R                        9 4               10 3  8
+--R           (131563520A b c  + 103088128B b  c )x
+--R         + 
+--R                        10 3              11 2  6
+--R           (103088128A b  c  + 52559872B b  c )x
+--R         + 
+--R                       11 2              12   4
+--R           (52559872A b  c  + 15728640B b  c)x
+--R         + 
+--R                       12              13  2             13
+--R           (15728640A b  c + 2097152B b  )x  + 2097152A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                13 29         13           12  27
+--R           - B c  x   + (- A c   - 244B b c  )x
+--R         + 
+--R                      12           2 11  25
+--R           (- 244A b c   - 10165B b c  )x
+--R         + 
+--R                      2 11            3 10  23
+--R           (- 10165A b c   - 170610B b c  )x
+--R         + 
+--R                       3 10             4 9  21
+--R           (- 170610A b c   - 1519760B b c )x
+--R         + 
+--R                        4 9             5 8  19
+--R           (- 1519760A b c  - 8204768B b c )x
+--R         + 
+--R                        5 8              6 7  17
+--R           (- 8204768A b c  - 28883712B b c )x
+--R         + 
+--R                         6 7              7 6  15
+--R           (- 28883712A b c  - 69076480B b c )x
+--R         + 
+--R                         7 6               8 5  13
+--R           (- 69076480A b c  - 114442240B b c )x
+--R         + 
+--R                          8 5               9 4  11
+--R           (- 114442240A b c  - 131563520B b c )x
+--R         + 
+--R                          9 4               10 3  9
+--R           (- 131563520A b c  - 103088128B b  c )x
+--R         + 
+--R                          10 3              11 2  7
+--R           (- 103088128A b  c  - 52559872B b  c )x
+--R         + 
+--R                         11 2              12   5
+--R           (- 52559872A b  c  - 15728640B b  c)x
+--R         + 
+--R                         12              13  3             13
+--R           (- 15728640A b  c - 2097152B b  )x  - 2097152A b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                13 29         13            12  27
+--R           22B c  x   + (22A c   + 1826B b c  )x
+--R         + 
+--R                     12           2 11  25            2 11            3 10  23
+--R           (1826A b c   + 46530B b c  )x   + (46530A b c   + 568150B b c  )x
+--R         + 
+--R                     3 10             4 9  21
+--R           (568150A b c   + 4005760B b c )x
+--R         + 
+--R                      4 9              5 8  19
+--R           (4005760A b c  + 17992416B b c )x
+--R         + 
+--R                       5 8              6 7  17
+--R           (17992416A b c  + 54460928B b c )x
+--R         + 
+--R                       6 7               7 6  15
+--R           (54460928A b c  + 114629120B b c )x
+--R         + 
+--R                        7 6               8 5  13
+--R           (114629120A b c  + 170065920B b c )x
+--R         + 
+--R                        8 5               9 4  11
+--R           (170065920A b c  + 177438720B b c )x
+--R         + 
+--R                        9 4               10 3  9
+--R           (177438720A b c  + 127533056B b  c )x
+--R         + 
+--R                        10 3              11 2  7
+--R           (127533056A b  c  + 60162048B b  c )x
+--R         + 
+--R                       11 2              12   5
+--R           (60162048A b  c  + 16777216B b  c)x
+--R         + 
+--R                       12              13  3             13
+--R           (16777216A b  c + 2097152B b  )x  + 2097152A b  x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              11 34         10 32        2 9 30          3 8 28           4 7 26
+--R             c  x   + 242b c  x   + 9680b c x   + 151008b c x   + 1208064b c x
+--R           + 
+--R                     5 6 24            6 5 22            7 4 20
+--R             5637632b c x   + 16400384b c x   + 30638080b c x
+--R           + 
+--R                    8 3 18            9 2 16            10   14           11 12
+--R           36765696b c x   + 27394048b c x   + 11534336b  c x   + 2097152b  x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  11 34          10 32         2 9 30          3 8 28
+--R             - 22c  x   - 1782b c  x   - 42944b c x   - 480480b c x
+--R           + 
+--R                       4 7 26            5 6 24            6 5 22
+--R             - 3001856b c x   - 11508224b c x   - 28442624b c x
+--R           + 
+--R                        7 4 20            8 3 18            9 2 16
+--R             - 46235648b c x   - 49152000b c x   - 32899072b c x
+--R           + 
+--R                        10   14           11 12
+--R             - 12582912b  c x   - 2097152b  x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 946
+
+)clear all
+
+--S 947 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^16
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              14
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 947
+
+--S 948 of 3139
+r0:=1/1536*c^3*(12*b*B-7*A*c)*(b*x^2+c*x^4)^(3/2)/(b^4*x^7)-_
+   1/12*A*(b*x^2+c*x^4)^(5/2)/(b*x^17)-1/120*(12*b*B-7*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^15)+1/192*c*(12*b*B-7*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^3*x^13)-1/384*c^2*(12*b*B-7*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^4*x^11)+1/1024*c^5*(12*b*B-7*A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(9/2)+_
+   1/1024*c^4*(12*b*B-7*A*c)*sqrt(b*x^2+c*x^4)/(b^4*x^3)
+--R 
+--R
+--R   (2)
+--R                                              +-+
+--R                6           5  13           x\|b
+--R       (- 105A c  + 180B b c )x  atanh(--------------)
+--R                                        +-----------+
+--R                                        |   4      2
+--R                                       \|c x  + b x
+--R     + 
+--R                  5           4  10             4         2 3  8
+--R           (105A c  - 180B b c )x   + (- 70A b c  + 120B b c )x
+--R         + 
+--R                 2 3        3 2  6           3 2          4   4
+--R           (56A b c  - 96B b c )x  + (- 48A b c  - 2112B b c)x
+--R         + 
+--R                     4           5  2          5
+--R           (- 1664A b c - 1536B b )x  - 1280A b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|b \|c x  + b x
+--R  /
+--R           4 13 +-+
+--R     15360b x  \|b
+--R                                                    Type: Expression(Integer)
+--E 948
+
+--S 949 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         11          2 10  22            2 10           3 9  20
+--R               (1260A b c   - 2160B b c  )x   + (29400A b c   - 50400B b c )x
+--R             + 
+--R                         3 9            4 8  18
+--R               (188160A b c  - 322560B b c )x
+--R             + 
+--R                         4 8            5 7  16
+--R               (483840A b c  - 829440B b c )x
+--R             + 
+--R                       5 7            6 6  14             6 6            7 5  12
+--R             (537600A b c  - 921600B b c )x   + (215040A b c  - 368640B b c )x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                        12           11  24               11           2 10  22
+--R               (- 105A c   + 180B b c  )x   + (- 7560A b c   + 12960B b c  )x
+--R             + 
+--R                          2 10            3 9  20
+--R               (- 88200A b c   + 151200B b c )x
+--R             + 
+--R                           3 9            4 8  18
+--R               (- 376320A b c  + 645120B b c )x
+--R             + 
+--R                           4 8             5 7  16
+--R               (- 725760A b c  + 1244160B b c )x
+--R             + 
+--R                           5 7             6 6  14
+--R               (- 645120A b c  + 1105920B b c )x
+--R             + 
+--R                           6 6            7 5  12
+--R               (- 215040A b c  + 368640B b c )x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                      11         2 10  22             2 10           3 9  20
+--R           (- 105A b c   + 180B b c  )x   + (- 7490A b c   + 12840B b c )x
+--R         + 
+--R                      3 9            4 8  18
+--R           (- 83216A b c  + 142656B b c )x
+--R         + 
+--R                       4 8            5 7  16
+--R           (- 321504A b c  + 553344B b c )x
+--R         + 
+--R                       5 7             6 6  14
+--R           (- 516800A b c  + 1048320B b c )x
+--R         + 
+--R                       6 6             7 5  12
+--R           (- 200576A b c  + 2505216B b c )x
+--R         + 
+--R                      7 5             8 4  10
+--R           (1489920A b c  + 9154560B b c )x
+--R         + 
+--R                      8 4              9 3  8
+--R           (7170048A b c  + 20447232B b c )x
+--R         + 
+--R                       9 3              10 2  6
+--R           (16269312A b c  + 23789568B b  c )x
+--R         + 
+--R                       10 2              11   4
+--R           (19169280A b  c  + 13762560B b  c)x
+--R         + 
+--R                       11              12  2             12
+--R           (11272192A b  c + 3145728B b  )x  + 2621440A b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                     11          2 10  22            2 10           3 9  20
+--R           (1260A b c   - 2160B b c  )x   + (29820A b c   - 51120B b c )x
+--R         + 
+--R                     3 9            4 8  18             4 8            5 7  16
+--R           (197792A b c  - 339072B b c )x   + (542736A b c  - 956736B b c )x
+--R         + 
+--R                     5 7             6 6  14
+--R           (655488A b c  - 1817088B b c )x
+--R         + 
+--R                       6 6             7 5  12
+--R           (- 170624A b c  - 5561856B b c )x
+--R         + 
+--R                        7 5              8 4  10
+--R           (- 3870720A b c  - 17141760B b c )x
+--R         + 
+--R                         8 4              9 3  8
+--R           (- 13510656A b c  - 30818304B b c )x
+--R         + 
+--R                         9 3              10 2  6
+--R           (- 24608768A b c  - 30277632B b  c )x
+--R         + 
+--R                         10 2              11   4
+--R           (- 24477696A b  c  - 15335424B b  c)x
+--R         + 
+--R                         11              12  2             12
+--R           (- 12582912A b  c - 3145728B b  )x  - 2621440A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                  5 5 22           6 4 20            7 3 18            8 2 16
+--R           184320b c x   + 4300800b c x   + 27525120b c x   + 70778880b c x
+--R         + 
+--R                    9   14            10 12
+--R           78643200b c x   + 31457280b  x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R               5 6 24           6 5 22            7 4 20            8 3 18
+--R       - 15360b c x   - 1105920b c x   - 12902400b c x   - 55050240b c x
+--R     + 
+--R                   9 2 16            10   14            11 12
+--R       - 106168320b c x   - 94371840b  c x   - 31457280b  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 949
+
+--S 950 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       11            10  23              10           2 9  21
+--R               (1260A c   - 2160B b c  )x   + (29400A b c   - 50400B b c )x
+--R             + 
+--R                         2 9            3 8  19
+--R               (188160A b c  - 322560B b c )x
+--R             + 
+--R                         3 8            4 7  17
+--R               (483840A b c  - 829440B b c )x
+--R             + 
+--R                       4 7            5 6  15             5 6            6 5  13
+--R             (537600A b c  - 921600B b c )x   + (215040A b c  - 368640B b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                    12           11  25               11           2 10  23
+--R           (- 105A c   + 180B b c  )x   + (- 7560A b c   + 12960B b c  )x
+--R         + 
+--R                      2 10            3 9  21
+--R           (- 88200A b c   + 151200B b c )x
+--R         + 
+--R                       3 9            4 8  19
+--R           (- 376320A b c  + 645120B b c )x
+--R         + 
+--R                       4 8             5 7  17
+--R           (- 725760A b c  + 1244160B b c )x
+--R         + 
+--R                       5 7             6 6  15
+--R           (- 645120A b c  + 1105920B b c )x
+--R         + 
+--R                       6 6            7 5  13
+--R           (- 215040A b c  + 368640B b c )x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                       11            10  23              10           2 9  21
+--R               (1260A c   - 2160B b c  )x   + (29400A b c   - 50400B b c )x
+--R             + 
+--R                         2 9            3 8  19
+--R               (188160A b c  - 322560B b c )x
+--R             + 
+--R                         3 8            4 7  17
+--R               (483840A b c  - 829440B b c )x
+--R             + 
+--R                       4 7            5 6  15             5 6            6 5  13
+--R             (537600A b c  - 921600B b c )x   + (215040A b c  - 368640B b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                    12           11  25               11           2 10  23
+--R           (- 105A c   + 180B b c  )x   + (- 7560A b c   + 12960B b c  )x
+--R         + 
+--R                      2 10            3 9  21
+--R           (- 88200A b c   + 151200B b c )x
+--R         + 
+--R                       3 9            4 8  19
+--R           (- 376320A b c  + 645120B b c )x
+--R         + 
+--R                       4 8             5 7  17
+--R           (- 725760A b c  + 1244160B b c )x
+--R         + 
+--R                       5 7             6 6  15
+--R           (- 645120A b c  + 1105920B b c )x
+--R         + 
+--R                       6 6            7 5  13
+--R           (- 215040A b c  + 368640B b c )x
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                           10          2 9  20
+--R               (- 1260A b c   + 2160B b c )x
+--R             + 
+--R                          2 9           3 8  18
+--R               (- 28560A b c  + 48960B b c )x
+--R             + 
+--R                           3 8            4 7  16
+--R               (- 169232A b c  + 290112B b c )x
+--R             + 
+--R                           4 7            5 6  14
+--R               (- 373504A b c  + 666624B b c )x
+--R             + 
+--R                           5 6             6 5  12
+--R               (- 281984A b c  + 1150464B b c )x
+--R             + 
+--R                         6 5             7 4  10
+--R               (452608A b c  + 4411392B b c )x
+--R             + 
+--R                          7 4              8 3  8
+--R               (3418112A b c  + 12730368B b c )x
+--R             + 
+--R                           8 3              9 2  6
+--R               (10092544A b c  + 18087936B b c )x
+--R             + 
+--R                           9 2              10   4
+--R               (14516224A b c  + 12189696B b  c)x
+--R             + 
+--R                          10              11  2             11
+--R               (9961472A b  c + 3145728B b  )x  + 2621440A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                      11           10  22             10           2 9  20
+--R               (105A c   - 180B b c  )x   + (7490A b c   - 12840B b c )x
+--R             + 
+--R                        2 9            3 8  18
+--R               (83216A b c  - 142656B b c )x
+--R             + 
+--R                         3 8            4 7  16
+--R               (321504A b c  - 553344B b c )x
+--R             + 
+--R                         4 7             5 6  14
+--R               (516800A b c  - 1048320B b c )x
+--R             + 
+--R                         5 6             6 5  12
+--R               (200576A b c  - 2505216B b c )x
+--R             + 
+--R                            6 5             7 4  10
+--R               (- 1489920A b c  - 9154560B b c )x
+--R             + 
+--R                            7 4              8 3  8
+--R               (- 7170048A b c  - 20447232B b c )x
+--R             + 
+--R                             8 3              9 2  6
+--R               (- 16269312A b c  - 23789568B b c )x
+--R             + 
+--R                             9 2              10   4
+--R               (- 19169280A b c  - 13762560B b  c)x
+--R             + 
+--R                             10              11  2             11
+--R               (- 11272192A b  c - 3145728B b  )x  - 2621440A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    11           10  23               10           2 9  21
+--R           (- 105A c   + 180B b c  )x   + (- 7490A b c   + 12840B b c )x
+--R         + 
+--R                      2 9            3 8  19
+--R           (- 83216A b c  + 142656B b c )x
+--R         + 
+--R                       3 8            4 7  17
+--R           (- 321504A b c  + 553344B b c )x
+--R         + 
+--R                       4 7             5 6  15
+--R           (- 516800A b c  + 1048320B b c )x
+--R         + 
+--R                       5 6             6 5  13
+--R           (- 200576A b c  + 2505216B b c )x
+--R         + 
+--R                      6 5             7 4  11
+--R           (1489920A b c  + 9154560B b c )x
+--R         + 
+--R                      7 4              8 3  9
+--R           (7170048A b c  + 20447232B b c )x
+--R         + 
+--R                       8 3              9 2  7
+--R           (16269312A b c  + 23789568B b c )x
+--R         + 
+--R                       9 2              10   5
+--R           (19169280A b c  + 13762560B b  c)x
+--R         + 
+--R                       10              11  3             11
+--R           (11272192A b  c + 3145728B b  )x  + 2621440A b  x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                 11          2 10  23            2 10           3 9  21
+--R       (1260A b c   - 2160B b c  )x   + (29820A b c   - 51120B b c )x
+--R     + 
+--R                 3 9            4 8  19             4 8            5 7  17
+--R       (197792A b c  - 339072B b c )x   + (542736A b c  - 956736B b c )x
+--R     + 
+--R                 5 7             6 6  15               6 6             7 5  13
+--R       (655488A b c  - 1817088B b c )x   + (- 170624A b c  - 5561856B b c )x
+--R     + 
+--R                    7 5              8 4  11
+--R       (- 3870720A b c  - 17141760B b c )x
+--R     + 
+--R                     8 4              9 3  9
+--R       (- 13510656A b c  - 30818304B b c )x
+--R     + 
+--R                     9 3              10 2  7
+--R       (- 24608768A b c  - 30277632B b  c )x
+--R     + 
+--R                     10 2              11   5
+--R       (- 24477696A b  c  - 15335424B b  c)x
+--R     + 
+--R                     11              12  3             12
+--R       (- 12582912A b  c - 3145728B b  )x  - 2621440A b  x
+--R  /
+--R                  5 5 23           6 4 21            7 3 19            8 2 17
+--R           184320b c x   + 4300800b c x   + 27525120b c x   + 70778880b c x
+--R         + 
+--R                    9   15            10 13
+--R           78643200b c x   + 31457280b  x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                   4 6 25           5 5 23            6 4 21            7 3 19
+--R           - 15360b c x   - 1105920b c x   - 12902400b c x   - 55050240b c x
+--R         + 
+--R                       8 2 17            9   15            10 13
+--R           - 106168320b c x   - 94371840b c x   - 31457280b  x
+--R      *
+--R          +-+
+--R         \|b
+--R                                                    Type: Expression(Integer)
+--E 950
+
+--S 951 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    14 30         14           13  28
+--R               - B c  x   + (- A c   - 314B b c  )x
+--R             + 
+--R                          13           2 12  26
+--R               (- 314A b c   - 16641B b c  )x
+--R             + 
+--R                          2 12            3 11  24
+--R               (- 16641A b c   - 352664B b c  )x
+--R             + 
+--R                           3 11             4 10  22
+--R               (- 352664A b c   - 3951376B b c  )x
+--R             + 
+--R                            4 10              5 9  20
+--R               (- 3951376A b c   - 26824512B b c )x
+--R             + 
+--R                             5 9               6 8  18
+--R               (- 26824512A b c  - 119162368B b c )x
+--R             + 
+--R                              6 8               7 7  16
+--R               (- 119162368A b c  - 362504192B b c )x
+--R             + 
+--R                              7 7               8 6  14
+--R               (- 362504192A b c  - 774586368B b c )x
+--R             + 
+--R                              8 6                9 5  12
+--R               (- 774586368A b c  - 1174208512B b c )x
+--R             + 
+--R                               9 5                10 4  10
+--R               (- 1174208512A b c  - 1257046016B b  c )x
+--R             + 
+--R                               10 4               11 3  8
+--R               (- 1257046016A b  c  - 929562624B b  c )x
+--R             + 
+--R                              11 3               12 2  6
+--R               (- 929562624A b  c  - 451936256B b  c )x
+--R             + 
+--R                              12 2               13   4
+--R               (- 451936256A b  c  - 130023424B b  c)x
+--R             + 
+--R                              13               14  2              14
+--R               (- 130023424A b  c - 16777216B b  )x  - 16777216A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    14 30         14            13  28
+--R               25B c  x   + (25A c   + 2650B b c  )x
+--R             + 
+--R                         13           2 12  26
+--R               (2650A b c   + 85305B b c  )x
+--R             + 
+--R                        2 12             3 11  24
+--R               (85305A b c   + 1306760B b c  )x
+--R             + 
+--R                          3 11              4 10  22
+--R               (1306760A b c   + 11520080B b c  )x
+--R             + 
+--R                           4 10              5 9  20
+--R               (11520080A b c   + 64708800B b c )x
+--R             + 
+--R                           5 9               6 8  18
+--R               (64708800A b c  + 245900800B b c )x
+--R             + 
+--R                            6 8               7 7  16
+--R               (245900800A b c  + 655237120B b c )x
+--R             + 
+--R                            7 7                8 6  14
+--R               (655237120A b c  + 1248215040B b c )x
+--R             + 
+--R                             8 6                9 5  12
+--R               (1248215040A b c  + 1710161920B b c )x
+--R             + 
+--R                             9 5                10 4  10
+--R               (1710161920A b c  + 1672806400B b  c )x
+--R             + 
+--R                             10 4                11 3  8
+--R               (1672806400A b  c  + 1140326400B b  c )x
+--R             + 
+--R                             11 3               12 2  6
+--R               (1140326400A b  c  + 514850816B b  c )x
+--R             + 
+--R                            12 2               13   4
+--R               (514850816A b  c  + 138412032B b  c)x
+--R             + 
+--R                            13               14  2              14
+--R               (138412032A b  c + 16777216B b  )x  + 16777216A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  14 31           14            13  29
+--R           - 25B c  x   + (- 25A c   - 2650B b c  )x
+--R         + 
+--R                       13           2 12  27
+--R           (- 2650A b c   - 85305B b c  )x
+--R         + 
+--R                      2 12             3 11  25
+--R           (- 85305A b c   - 1306760B b c  )x
+--R         + 
+--R                        3 11              4 10  23
+--R           (- 1306760A b c   - 11520080B b c  )x
+--R         + 
+--R                         4 10              5 9  21
+--R           (- 11520080A b c   - 64708800B b c )x
+--R         + 
+--R                         5 9               6 8  19
+--R           (- 64708800A b c  - 245900800B b c )x
+--R         + 
+--R                          6 8               7 7  17
+--R           (- 245900800A b c  - 655237120B b c )x
+--R         + 
+--R                          7 7                8 6  15
+--R           (- 655237120A b c  - 1248215040B b c )x
+--R         + 
+--R                           8 6                9 5  13
+--R           (- 1248215040A b c  - 1710161920B b c )x
+--R         + 
+--R                           9 5                10 4  11
+--R           (- 1710161920A b c  - 1672806400B b  c )x
+--R         + 
+--R                           10 4                11 3  9
+--R           (- 1672806400A b  c  - 1140326400B b  c )x
+--R         + 
+--R                           11 3               12 2  7
+--R           (- 1140326400A b  c  - 514850816B b  c )x
+--R         + 
+--R                          12 2               13   5
+--R           (- 514850816A b  c  - 138412032B b  c)x
+--R         + 
+--R                          13               14  3              14
+--R           (- 138412032A b  c - 16777216B b  )x  - 16777216A b  x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          15 33       15           14  31            14           2 13  29
+--R       B c  x   + (A c   + 315B b c  )x   + (315A b c   + 16955B b c  )x
+--R     + 
+--R                2 13            3 12  27             3 12             4 11  25
+--R       (16955A b c   + 369305B b c  )x   + (369305A b c   + 4304040B b c  )x
+--R     + 
+--R                  4 11              5 10  23
+--R       (4304040A b c   + 30775888B b c  )x
+--R     + 
+--R                   5 10               6 9  21
+--R       (30775888A b c   + 145986880B b c )x
+--R     + 
+--R                    6 9               7 8  19
+--R       (145986880A b c  + 481666560B b c )x
+--R     + 
+--R                    7 8                8 7  17
+--R       (481666560A b c  + 1137090560B b c )x
+--R     + 
+--R                     8 7                9 6  15
+--R       (1137090560A b c  + 1948794880B b c )x
+--R     + 
+--R                     9 6                10 5  13
+--R       (1948794880A b c  + 2431254528B b  c )x
+--R     + 
+--R                     10 5                11 4  11
+--R       (2431254528A b  c  + 2186608640B b  c )x
+--R     + 
+--R                     11 4                12 3  9
+--R       (2186608640A b  c  + 1381498880B b  c )x
+--R     + 
+--R                     12 3               13 2  7
+--R       (1381498880A b  c  + 581959680B b  c )x
+--R     + 
+--R                    13 2               14   5
+--R       (581959680A b  c  + 146800640B b  c)x
+--R     + 
+--R                    14               15  3              15
+--R       (146800640A b  c + 16777216B b  )x  + 16777216A b  x
+--R  /
+--R                12 37          11 35         2 10 33           3 9 31
+--R             25c  x   + 2600b c  x   + 80080b c  x   + 1144000b c x
+--R           + 
+--R                     4 8 29            5 7 27             6 6 25
+--R             9152000b c x   + 45260800b c x   + 146227200b c x
+--R           + 
+--R                       7 5 23             8 4 21             9 3 19
+--R             317521920b c x   + 466944000b c x   + 458752000b c x
+--R           + 
+--R                       10 2 17             11   15            12 13
+--R             288358400b  c x   + 104857600b  c x   + 16777216b  x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R            13 39         12 37         2 11 35          3 10 33
+--R         - c  x   - 313b c  x   - 16328b c  x   - 336336b c  x
+--R       + 
+--R                   4 9 31            5 8 29            6 7 27             7 6 25
+--R         - 3615040b c x   - 23209472b c x   - 95952896b c x   - 266551296b c x
+--R       + 
+--R                     8 5 23             9 4 21             10 3 19
+--R         - 508035072b c x   - 666173440b c x   - 590872576b  c x
+--R       + 
+--R                     11 2 17             12   15            13 13
+--R         - 338690048b  c x   - 113246208b  c x   - 16777216b  x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 951
+
+)clear all
+
+--S 952 of 3139
+t0:=x^7*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             9      7
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 952
+
+--S 953 of 3139
+r0:=5/128*b^3*(7*b*B-8*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(9/2)-_
+   5/128*b^2*(7*b*B-8*A*c)*sqrt(b*x^2+c*x^4)/c^4+5/192*b*(7*b*B-8*A*c)*_
+   x^2*sqrt(b*x^2+c*x^4)/c^3-1/48*(7*b*B-8*A*c)*x^4*sqrt(b*x^2+c*x^4)/c^2+_
+   1/8*B*x^6*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                        2 +-+
+--R                3          4           x \|c
+--R       (- 120A b c + 105B b )atanh(--------------)
+--R                                    +-----------+
+--R                                    |   4      2
+--R                                   \|c x  + b x
+--R     + 
+--R                3 6         3          2  4             2        2   2
+--R           48B c x  + (64A c  - 56B b c )x  + (- 80A b c  + 70B b c)x
+--R         + 
+--R                 2          3
+--R           120A b c - 105B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R         4 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 953
+
+--S 954 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        3 4         4 3  6           4 3          5 2  4
+--R                 (960A b c  - 840B b c )x  + (9600A b c  - 8400B b c )x
+--R               + 
+--R                          5 2           6   2           6            7
+--R                 (23040A b c  - 20160B b c)x  + 15360A b c - 13440B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                      3 5         4 4  8             4 4          5 3  6
+--R             (- 120A b c  + 105B b c )x  + (- 3840A b c  + 3360B b c )x
+--R           + 
+--R                        5 3           6 2  4              6 2           7   2
+--R             (- 19200A b c  + 16800B b c )x  + (- 30720A b c  + 26880B b c)x
+--R           + 
+--R                       7            8
+--R             - 15360A b c + 13440B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                    7 15           7            6  13
+--R             - 48B c x   + (- 64A c  - 1480B b c )x
+--R           + 
+--R                         6          2 5  11             2 5          3 4  9
+--R             (- 1968A b c  - 5958B b c )x   + (- 7800A b c  - 5463B b c )x
+--R           + 
+--R                       3 4         4 3  7             4 3          5 2  5
+--R             (- 7424A b c  + 352B b c )x  + (- 6912A b c  + 6048B b c )x
+--R           + 
+--R                        5 2           6   3              6            7
+--R             (- 20480A b c  + 17920B b c)x  + (- 15360A b c + 13440B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                   7 15          7            6  13
+--R             384B c x   + (512A c  + 3776B b c )x
+--R           + 
+--R                       6          2 5  11            2 5          3 4  9
+--R             (4992A b c  + 8688B b c )x   + (11328A b c  + 5448B b c )x
+--R           + 
+--R                     3 4          4 3  7            4 3           5 2  5
+--R             (9280A b c  - 1976B b c )x  + (15232A b c  - 13328B b c )x
+--R           + 
+--R                      5 2           6   3            6            7
+--R             (28160A b c  - 24640B b c)x  + (15360A b c - 13440B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                                                                    +--------+
+--R               7 6           6 4         2 5 2         3 4  +-+ +-+ |   2
+--R         (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|b \|c \|c x  + b
+--R       + 
+--R                8 8           7 6         2 6 4         3 5 2         4 4  +-+
+--R         (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|c
+--R     ,
+--R
+--R                           3 4          4 3  6              4 3           5 2  4
+--R                 (- 1920A b c  + 1680B b c )x  + (- 19200A b c  + 16800B b c )x
+--R               + 
+--R                            5 2           6   2           6            7
+--R                 (- 46080A b c  + 40320B b c)x  - 30720A b c + 26880B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                    3 5         4 4  8           4 4          5 3  6
+--R             (240A b c  - 210B b c )x  + (7680A b c  - 6720B b c )x
+--R           + 
+--R                      5 3           6 2  4            6 2           7   2
+--R             (38400A b c  - 33600B b c )x  + (61440A b c  - 53760B b c)x
+--R           + 
+--R                     7            8
+--R             30720A b c - 26880B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                    7 15           7            6  13
+--R             - 48B c x   + (- 64A c  - 1480B b c )x
+--R           + 
+--R                         6          2 5  11             2 5          3 4  9
+--R             (- 1968A b c  - 5958B b c )x   + (- 7800A b c  - 5463B b c )x
+--R           + 
+--R                       3 4         4 3  7             4 3          5 2  5
+--R             (- 7424A b c  + 352B b c )x  + (- 6912A b c  + 6048B b c )x
+--R           + 
+--R                        5 2           6   3              6            7
+--R             (- 20480A b c  + 17920B b c)x  + (- 15360A b c + 13440B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                   7 15          7            6  13
+--R             384B c x   + (512A c  + 3776B b c )x
+--R           + 
+--R                       6          2 5  11            2 5          3 4  9
+--R             (4992A b c  + 8688B b c )x   + (11328A b c  + 5448B b c )x
+--R           + 
+--R                     3 4          4 3  7            4 3           5 2  5
+--R             (9280A b c  - 1976B b c )x  + (15232A b c  - 13328B b c )x
+--R           + 
+--R                      5 2           6   3            6            7
+--R             (28160A b c  - 24640B b c)x  + (15360A b c - 13440B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                                                                      +--------+
+--R               7 6           6 4         2 5 2         3 4  +---+ +-+ |   2
+--R         (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|- c \|b \|c x  + b
+--R       + 
+--R              8 8           7 6         2 6 4         3 5 2         4 4  +---+
+--R       (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 954
+
+--S 955 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      3 4         4 3  6           4 3          5 2  4
+--R               (960A b c  - 840B b c )x  + (9600A b c  - 8400B b c )x
+--R             + 
+--R                        5 2           6   2           6            7
+--R               (23040A b c  - 20160B b c)x  + 15360A b c - 13440B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                    3 5         4 4  8             4 4          5 3  6
+--R           (- 120A b c  + 105B b c )x  + (- 3840A b c  + 3360B b c )x
+--R         + 
+--R                      5 3           6 2  4              6 2           7   2
+--R           (- 19200A b c  + 16800B b c )x  + (- 30720A b c  + 26880B b c)x
+--R         + 
+--R                     7            8
+--R           - 15360A b c + 13440B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                      3 4         4 3  6           4 3          5 2  4
+--R               (960A b c  - 840B b c )x  + (9600A b c  - 8400B b c )x
+--R             + 
+--R                        5 2           6   2           6            7
+--R               (23040A b c  - 20160B b c)x  + 15360A b c - 13440B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                    3 5         4 4  8             4 4          5 3  6
+--R           (- 120A b c  + 105B b c )x  + (- 3840A b c  + 3360B b c )x
+--R         + 
+--R                      5 3           6 2  4              6 2           7   2
+--R           (- 19200A b c  + 16800B b c )x  + (- 30720A b c  + 26880B b c)x
+--R         + 
+--R                     7            8
+--R           - 15360A b c + 13440B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                       6 12            6            5  10
+--R               - 384B c x   + (- 512A c  - 3392B b c )x
+--R             + 
+--R                           5          2 4  8             2 4         3 3  6
+--R               (- 4480A b c  - 5296B b c )x  + (- 6848A b c  - 152B b c )x
+--R             + 
+--R                         3 3          4 2  4              4 2           5   2
+--R               (- 2432A b c  + 2128B b c )x  + (- 12800A b c  + 11200B b c)x
+--R             + 
+--R                         5            6
+--R               - 15360A b c + 13440B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                    7 14         7            6  12
+--R               48B c x   + (64A c  + 1480B b c )x
+--R             + 
+--R                         6          2 5  10           2 5          3 4  8
+--R               (1968A b c  + 5958B b c )x   + (7800A b c  + 5463B b c )x
+--R             + 
+--R                       3 4         4 3  6           4 3          5 2  4
+--R               (7424A b c  - 352B b c )x  + (6912A b c  - 6048B b c )x
+--R             + 
+--R                        5 2           6   2           6            7
+--R               (20480A b c  - 17920B b c)x  + 15360A b c - 13440B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  7 15           7            6  13
+--R           - 48B c x   + (- 64A c  - 1480B b c )x
+--R         + 
+--R                       6          2 5  11             2 5          3 4  9
+--R           (- 1968A b c  - 5958B b c )x   + (- 7800A b c  - 5463B b c )x
+--R         + 
+--R                     3 4         4 3  7             4 3          5 2  5
+--R           (- 7424A b c  + 352B b c )x  + (- 6912A b c  + 6048B b c )x
+--R         + 
+--R                      5 2           6   3              6            7
+--R           (- 20480A b c  + 17920B b c)x  + (- 15360A b c + 13440B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                 7 15          7            6  13             6          2 5  11
+--R           384B c x   + (512A c  + 3776B b c )x   + (4992A b c  + 8688B b c )x
+--R         + 
+--R                    2 5          3 4  9           3 4          4 3  7
+--R           (11328A b c  + 5448B b c )x  + (9280A b c  - 1976B b c )x
+--R         + 
+--R                    4 3           5 2  5            5 2           6   3
+--R           (15232A b c  - 13328B b c )x  + (28160A b c  - 24640B b c)x
+--R         + 
+--R                    6            7
+--R           (15360A b c - 13440B b )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                                                                  +--------+
+--R             7 6           6 4         2 5 2         3 4  +-+ +-+ |   2
+--R       (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|b \|c \|c x  + b
+--R     + 
+--R              8 8           7 6         2 6 4         3 5 2         4 4  +-+
+--R       (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 955
+
+--S 956 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          9 26           9            8  24
+--R                   - 19B c x   + (- 19A c  - 1140B b c )x
+--R                 + 
+--R                               8           2 7  22
+--R                   (- 1140A b c  - 20064B b c )x
+--R                 + 
+--R                              2 7            3 6  20
+--R                   (- 20064A b c  - 160512B b c )x
+--R                 + 
+--R                               3 6            4 5  18
+--R                   (- 160512A b c  - 695552B b c )x
+--R                 + 
+--R                               4 5             5 4  16
+--R                   (- 695552A b c  - 1770496B b c )x
+--R                 + 
+--R                                5 4             6 3  14
+--R                   (- 1770496A b c  - 2723840B b c )x
+--R                 + 
+--R                                6 3             7 2  12
+--R                   (- 2723840A b c  - 2490368B b c )x
+--R                 + 
+--R                                7 2             8   10
+--R                   (- 2490368A b c  - 1245184B b c)x
+--R                 + 
+--R                                8             9  8            9 6
+--R                   (- 1245184A b c - 262144B b )x  - 262144A b x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                    10 27         10           9  25
+--R               - B c  x   + (- A c   - 180B b c )x
+--R             + 
+--R                          9          2 8  23             2 8           3 7  21
+--R               (- 180A b c  - 5280B b c )x   + (- 5280A b c  - 59136B b c )x
+--R             + 
+--R                          3 7            4 6  19
+--R               (- 59136A b c  - 329472B b c )x
+--R             + 
+--R                           4 6             5 5  17
+--R               (- 329472A b c  - 1025024B b c )x
+--R             + 
+--R                            5 5             6 4  15
+--R               (- 1025024A b c  - 1863680B b c )x
+--R             + 
+--R                            6 4             7 3  13
+--R               (- 1863680A b c  - 1966080B b c )x
+--R             + 
+--R                            7 3             8 2  11
+--R               (- 1966080A b c  - 1114112B b c )x
+--R             + 
+--R                            8 2            9   9            9   7
+--R               (- 1114112A b c  - 262144B b c)x  - 262144A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  10 28       10           9  26            9          2 8  24
+--R               B c  x   + (A c   + 181B b c )x   + (181A b c  + 5460B b c )x
+--R             + 
+--R                       2 8           3 7  22            3 7            4 6  20
+--R               (5460A b c  + 64416B b c )x   + (64416A b c  + 388608B b c )x
+--R             + 
+--R                         4 6             5 5  18
+--R               (388608A b c  + 1354496B b c )x
+--R             + 
+--R                          5 5             6 4  16
+--R               (1354496A b c  + 2888704B b c )x
+--R             + 
+--R                          6 4             7 3  14
+--R               (2888704A b c  + 3829760B b c )x
+--R             + 
+--R                          7 3             8 2  12
+--R               (3829760A b c  + 3080192B b c )x
+--R             + 
+--R                          8 2             9   10
+--R               (3080192A b c  + 1376256B b c)x
+--R             + 
+--R                          9             10  8            10 6
+--R               (1376256A b c + 262144B b  )x  + 262144A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    10 27         10            9  25
+--R               19B c  x   + (19A c   + 1140B b c )x
+--R             + 
+--R                         9           2 8  23            2 8            3 7  21
+--R               (1140A b c  + 20064B b c )x   + (20064A b c  + 160512B b c )x
+--R             + 
+--R                         3 7            4 6  19
+--R               (160512A b c  + 695552B b c )x
+--R             + 
+--R                         4 6             5 5  17
+--R               (695552A b c  + 1770496B b c )x
+--R             + 
+--R                          5 5             6 4  15
+--R               (1770496A b c  + 2723840B b c )x
+--R             + 
+--R                          6 4             7 3  13
+--R               (2723840A b c  + 2490368B b c )x
+--R             + 
+--R                          7 3             8 2  11
+--R               (2490368A b c  + 1245184B b c )x
+--R             + 
+--R                          8 2            9   9            9   7
+--R               (1245184A b c  + 262144B b c)x  + 262144A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    10 29         10           9  27
+--R               - B c  x   + (- A c   - 181B b c )x
+--R             + 
+--R                          9          2 8  25             2 8           3 7  23
+--R               (- 181A b c  - 5460B b c )x   + (- 5460A b c  - 64416B b c )x
+--R             + 
+--R                          3 7            4 6  21
+--R               (- 64416A b c  - 388608B b c )x
+--R             + 
+--R                           4 6             5 5  19
+--R               (- 388608A b c  - 1354496B b c )x
+--R             + 
+--R                            5 5             6 4  17
+--R               (- 1354496A b c  - 2888704B b c )x
+--R             + 
+--R                            6 4             7 3  15
+--R               (- 2888704A b c  - 3829760B b c )x
+--R             + 
+--R                            7 3             8 2  13
+--R               (- 3829760A b c  - 3080192B b c )x
+--R             + 
+--R                            8 2             9   11
+--R               (- 3080192A b c  - 1376256B b c)x
+--R             + 
+--R                            9             10  9            10 7
+--R               (- 1376256A b c - 262144B b  )x  - 262144A b  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      10 28           10            9  26
+--R               - 19B c  x   + (- 19A c   - 1140B b c )x
+--R             + 
+--R                           9           2 8  24
+--R               (- 1140A b c  - 20064B b c )x
+--R             + 
+--R                          2 8            3 7  22
+--R               (- 20064A b c  - 160512B b c )x
+--R             + 
+--R                           3 7            4 6  20
+--R               (- 160512A b c  - 695552B b c )x
+--R             + 
+--R                           4 6             5 5  18
+--R               (- 695552A b c  - 1770496B b c )x
+--R             + 
+--R                            5 5             6 4  16
+--R               (- 1770496A b c  - 2723840B b c )x
+--R             + 
+--R                            6 4             7 3  14
+--R               (- 2723840A b c  - 2490368B b c )x
+--R             + 
+--R                            7 3             8 2  12
+--R               (- 2490368A b c  - 1245184B b c )x
+--R             + 
+--R                            8 2            9   10            9   8
+--R               (- 1245184A b c  - 262144B b c)x   - 262144A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                10 29         10            9  27
+--R           19B c  x   + (19A c   + 1159B b c )x
+--R         + 
+--R                     9           2 8  25            2 8            3 7  23
+--R           (1159A b c  + 21204B b c )x   + (21204A b c  + 180576B b c )x
+--R         + 
+--R                     3 7            4 6  21             4 6             5 5  19
+--R           (180576A b c  + 856064B b c )x   + (856064A b c  + 2466048B b c )x
+--R         + 
+--R                      5 5             6 4  17
+--R           (2466048A b c  + 4494336B b c )x
+--R         + 
+--R                      6 4             7 3  15
+--R           (4494336A b c  + 5214208B b c )x
+--R         + 
+--R                      7 3             8 2  13
+--R           (5214208A b c  + 3735552B b c )x
+--R         + 
+--R                      8 2             9   11              9             10  9
+--R           (3735552A b c  + 1507328B b c)x   + (1507328A b c + 262144B b  )x
+--R         + 
+--R                    10 7
+--R           262144A b  x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R          11 30       11           10  28            10          2 9  26
+--R       B c  x   + (A c   + 181B b c  )x   + (181A b c   + 5460B b c )x
+--R     + 
+--R               2 9           3 8  24            3 8            4 7  22
+--R       (5460A b c  + 64416B b c )x   + (64416A b c  + 388608B b c )x
+--R     + 
+--R                 4 7             5 6  20              5 6             6 5  18
+--R       (388608A b c  + 1354496B b c )x   + (1354496A b c  + 2888704B b c )x
+--R     + 
+--R                  6 5             7 4  16              7 4             8 3  14
+--R       (2888704A b c  + 3829760B b c )x   + (3829760A b c  + 3080192B b c )x
+--R     + 
+--R                  8 3             9 2  12              9 2            10   10
+--R       (3080192A b c  + 1376256B b c )x   + (1376256A b c  + 262144B b  c)x
+--R     + 
+--R                10   8
+--R       262144A b  c x
+--R  /
+--R                  10 20         9 18        2 8 16         3 7 14
+--R                 c  x   + 181b c x   + 5460b c x   + 64416b c x
+--R               + 
+--R                        4 6 12           5 5 10           6 4 8           7 3 6
+--R                 388608b c x   + 1354496b c x   + 2888704b c x  + 3829760b c x
+--R               + 
+--R                         8 2 4           9   2          10
+--R                 3080192b c x  + 1376256b c x  + 262144b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                    10 19          9 17         2 8 15          3 7 13
+--R                 19c  x   + 1140b c x   + 20064b c x   + 160512b c x
+--R               + 
+--R                        4 6 11           5 5 9           6 4 7           7 3 5
+--R                 695552b c x   + 1770496b c x  + 2723840b c x  + 2490368b c x
+--R               + 
+--R                         8 2 3          9
+--R                 1245184b c x  + 262144b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  10 20          9 18         2 8 16          3 7 14
+--R             - 19c  x   - 1159b c x   - 21204b c x   - 180576b c x
+--R           + 
+--R                      4 6 12           5 5 10           6 4 8           7 3 6
+--R             - 856064b c x   - 2466048b c x   - 4494336b c x  - 5214208b c x
+--R           + 
+--R                       8 2 4           9   2          10
+--R             - 3735552b c x  - 1507328b c x  - 262144b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R            11 21         10 19        2 9 17         3 8 15          4 7 13
+--R         - c  x   - 181b c  x   - 5460b c x   - 64416b c x   - 388608b c x
+--R       + 
+--R                   5 6 11           6 5 9           7 4 7           8 3 5
+--R         - 1354496b c x   - 2888704b c x  - 3829760b c x  - 3080192b c x
+--R       + 
+--R                   9 2 3          10
+--R         - 1376256b c x  - 262144b  c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      3 4         4 3  6           4 3          5 2  4
+--R               (960A b c  - 840B b c )x  + (9600A b c  - 8400B b c )x
+--R             + 
+--R                        5 2           6   2           6            7
+--R               (23040A b c  - 20160B b c)x  + 15360A b c - 13440B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                        3 5         4 4  8             4 4          5 3  6
+--R               (- 120A b c  + 105B b c )x  + (- 3840A b c  + 3360B b c )x
+--R             + 
+--R                          5 3           6 2  4              6 2           7   2
+--R               (- 19200A b c  + 16800B b c )x  + (- 30720A b c  + 26880B b c)x
+--R             + 
+--R                         7            8
+--R               - 15360A b c + 13440B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                         3 4          4 3  6              4 3           5 2  4
+--R               (- 1920A b c  + 1680B b c )x  + (- 19200A b c  + 16800B b c )x
+--R             + 
+--R                          5 2           6   2           6            7
+--R               (- 46080A b c  + 40320B b c)x  - 30720A b c + 26880B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                      3 5         4 4  8           4 4          5 3  6
+--R               (240A b c  - 210B b c )x  + (7680A b c  - 6720B b c )x
+--R             + 
+--R                        5 3           6 2  4            6 2           7   2
+--R               (38400A b c  - 33600B b c )x  + (61440A b c  - 53760B b c)x
+--R             + 
+--R                       7            8
+--R               30720A b c - 26880B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                       6 12            6            5  10
+--R               - 384B c x   + (- 512A c  - 3392B b c )x
+--R             + 
+--R                           5          2 4  8             2 4         3 3  6
+--R               (- 4480A b c  - 5296B b c )x  + (- 6848A b c  - 152B b c )x
+--R             + 
+--R                         3 3          4 2  4              4 2           5   2
+--R               (- 2432A b c  + 2128B b c )x  + (- 12800A b c  + 11200B b c)x
+--R             + 
+--R                         5            6
+--R               - 15360A b c + 13440B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                    7 14         7            6  12
+--R               48B c x   + (64A c  + 1480B b c )x
+--R             + 
+--R                         6          2 5  10           2 5          3 4  8
+--R               (1968A b c  + 5958B b c )x   + (7800A b c  + 5463B b c )x
+--R             + 
+--R                       3 4         4 3  6           4 3          5 2  4
+--R               (7424A b c  - 352B b c )x  + (6912A b c  - 6048B b c )x
+--R             + 
+--R                        5 2           6   2           6            7
+--R               (20480A b c  - 17920B b c)x  + 15360A b c - 13440B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  7 15           7            6  13
+--R           - 48B c x   + (- 64A c  - 1480B b c )x
+--R         + 
+--R                       6          2 5  11             2 5          3 4  9
+--R           (- 1968A b c  - 5958B b c )x   + (- 7800A b c  - 5463B b c )x
+--R         + 
+--R                     3 4         4 3  7             4 3          5 2  5
+--R           (- 7424A b c  + 352B b c )x  + (- 6912A b c  + 6048B b c )x
+--R         + 
+--R                      5 2           6   3              6            7
+--R           (- 20480A b c  + 17920B b c)x  + (- 15360A b c + 13440B b )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                 7 15          7            6  13             6          2 5  11
+--R           384B c x   + (512A c  + 3776B b c )x   + (4992A b c  + 8688B b c )x
+--R         + 
+--R                    2 5          3 4  9           3 4          4 3  7
+--R           (11328A b c  + 5448B b c )x  + (9280A b c  - 1976B b c )x
+--R         + 
+--R                    4 3           5 2  5            5 2           6   3
+--R           (15232A b c  - 13328B b c )x  + (28160A b c  - 24640B b c)x
+--R         + 
+--R                    6            7
+--R           (15360A b c - 13440B b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R               7 6           6 4         2 5 2         3 4  +---+ +-+ +-+
+--R         (3072c x  + 30720b c x  + 73728b c x  + 49152b c )\|- c \|b \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R            8 8           7 6         2 6 4         3 5 2         4 4  +---+ +-+
+--R     (- 384c x  - 12288b c x  - 61440b c x  - 98304b c x  - 49152b c )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 957
+
+--S 958 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      7 22           7           6  20
+--R               - 16B c x   + (- 16A c  - 672B b c )x
+--R             + 
+--R                          6          2 5  18             2 5           3 4  16
+--R               (- 672A b c  - 8064B b c )x   + (- 8064A b c  - 42240B b c )x
+--R             + 
+--R                          3 4            4 3  14
+--R               (- 42240A b c  - 112640B b c )x
+--R             + 
+--R                           4 3            5 2  12
+--R               (- 112640A b c  - 159744B b c )x
+--R             + 
+--R                           5 2            6   10               6            7  8
+--R               (- 159744A b c  - 114688B b c)x   + (- 114688A b c - 32768B b )x
+--R             + 
+--R                         7 6
+--R               - 32768A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              8 24       8           7  22            7          2 6  20
+--R           B c x   + (A c  + 128B b c )x   + (128A b c  + 2688B b c )x
+--R         + 
+--R                   2 6           3 5  18            3 5           4 4  16
+--R           (2688A b c  + 21504B b c )x   + (21504A b c  + 84480B b c )x
+--R         + 
+--R                    4 4            5 3  14             5 3            6 2  12
+--R           (84480A b c  + 180224B b c )x   + (180224A b c  + 212992B b c )x
+--R         + 
+--R                     6 2            7   10             7            8  8
+--R           (212992A b c  + 131072B b c)x   + (131072A b c + 32768B b )x
+--R         + 
+--R                   8 6
+--R           32768A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                8 25         8           7  23              7          2 6  21
+--R           - B c x   + (- A c  - 128B b c )x   + (- 128A b c  - 2688B b c )x
+--R         + 
+--R                     2 6           3 5  19              3 5           4 4  17
+--R           (- 2688A b c  - 21504B b c )x   + (- 21504A b c  - 84480B b c )x
+--R         + 
+--R                      4 4            5 3  15
+--R           (- 84480A b c  - 180224B b c )x
+--R         + 
+--R                       5 3            6 2  13
+--R           (- 180224A b c  - 212992B b c )x
+--R         + 
+--R                       6 2            7   11               7            8  9
+--R           (- 212992A b c  - 131072B b c)x   + (- 131072A b c - 32768B b )x
+--R         + 
+--R                     8 7
+--R           - 32768A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                8 25         8           7  23            7          2 6  21
+--R           16B c x   + (16A c  + 688B b c )x   + (688A b c  + 8736B b c )x
+--R         + 
+--R                   2 6           3 5  19            3 5            4 4  17
+--R           (8736A b c  + 50304B b c )x   + (50304A b c  + 154880B b c )x
+--R         + 
+--R                     4 4            5 3  15             5 3            6 2  13
+--R           (154880A b c  + 272384B b c )x   + (272384A b c  + 274432B b c )x
+--R         + 
+--R                     6 2            7   11             7            8  9
+--R           (274432A b c  + 147456B b c)x   + (147456A b c + 32768B b )x
+--R         + 
+--R                   8 7
+--R           32768A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              8 16         7 14        2 6 12         3 5 10         4 4 8
+--R             c x   + 128b c x   + 2688b c x   + 21504b c x   + 84480b c x
+--R           + 
+--R                    5 3 6          6 2 4          7   2         8
+--R             180224b c x  + 212992b c x  + 131072b c x  + 32768b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  8 16         7 14        2 6 12         3 5 10          4 4 8
+--R             - 16c x   - 688b c x   - 8736b c x   - 50304b c x   - 154880b c x
+--R           + 
+--R                      5 3 6          6 2 4          7   2         8
+--R             - 272384b c x  - 274432b c x  - 147456b c x  - 32768b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 958
+
+)clear all
+
+--S 959 of 3139
+t0:=x^5*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             7      5
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 959
+
+--S 960 of 3139
+r0:=-1/16*b^2*(5*b*B-6*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(7/2)+_
+   1/16*b*(5*b*B-6*A*c)*sqrt(b*x^2+c*x^4)/c^3-1/24*(5*b*B-6*A*c)*x^2*_
+   sqrt(b*x^2+c*x^4)/c^2+1/6*B*x^4*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                    2 +-+
+--R             2         3           x \|c
+--R       (18A b c - 15B b )atanh(--------------)
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R     + 
+--R                                                               +-----------+
+--R            2 4         2            2                  2  +-+ |   4      2
+--R       (8B c x  + (12A c  - 10B b c)x  - 18A b c + 15B b )\|c \|c x  + b x
+--R  /
+--R        3 +-+
+--R     48c \|c
+--R                                                    Type: Expression(Integer)
+--E 960
+
+--S 961 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        2 3        3 2  4          3 2         4   2         4
+--R                 (108A b c  - 90B b c )x  + (576A b c  - 480B b c)x  + 576A b c
+--R               + 
+--R                         5
+--R                 - 480B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     2 4        3 3  6            3 3         4 2  4
+--R             (- 18A b c  + 15B b c )x  + (- 324A b c  + 270B b c )x
+--R           + 
+--R                      4 2         5   2         5          6
+--R             (- 864A b c  + 720B b c)x  - 576A b c + 480B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                   5 11           5           4  9              4         2 3  7
+--R             - 8B c x   + (- 12A c  - 134B b c )x  + (- 198A b c  - 219B b c )x
+--R           + 
+--R                      2 3        3 2  5          3 2         4   3
+--R             (- 252A b c  - 46B b c )x  + (480A b c  - 400B b c)x
+--R           + 
+--R                    4          5
+--R             (576A b c - 480B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                  5 11         5           4  9            4         2 3  7
+--R             48B c x   + (72A c  + 244B b c )x  + (348A b c  + 222B b c )x
+--R           + 
+--R                   2 3         3 2  5            3 2         4   3
+--R             (84A b c  + 186B b c )x  + (- 768A b c  + 640B b c)x
+--R           + 
+--R                      4          5
+--R             (- 576A b c + 480B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                                                   +--------+
+--R              5 4          4 2        2 3  +-+ +-+ |   2
+--R         (288c x  + 1536b c x  + 1536b c )\|b \|c \|c x  + b
+--R       + 
+--R               6 6         5 4        2 4 2        3 3  +-+
+--R         (- 48c x  - 864b c x  - 2304b c x  - 1536b c )\|c
+--R     ,
+--R
+--R                        2 3         3 2  4           3 2         4   2
+--R                 (216A b c  - 180B b c )x  + (1152A b c  - 960B b c)x
+--R               + 
+--R                        4          5
+--R                 1152A b c - 960B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     2 4        3 3  6            3 3         4 2  4
+--R             (- 36A b c  + 30B b c )x  + (- 648A b c  + 540B b c )x
+--R           + 
+--R                       4 2          5   2          5          6
+--R             (- 1728A b c  + 1440B b c)x  - 1152A b c + 960B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                   5 11           5           4  9              4         2 3  7
+--R             - 8B c x   + (- 12A c  - 134B b c )x  + (- 198A b c  - 219B b c )x
+--R           + 
+--R                      2 3        3 2  5          3 2         4   3
+--R             (- 252A b c  - 46B b c )x  + (480A b c  - 400B b c)x
+--R           + 
+--R                    4          5
+--R             (576A b c - 480B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                  5 11         5           4  9            4         2 3  7
+--R             48B c x   + (72A c  + 244B b c )x  + (348A b c  + 222B b c )x
+--R           + 
+--R                   2 3         3 2  5            3 2         4   3
+--R             (84A b c  + 186B b c )x  + (- 768A b c  + 640B b c)x
+--R           + 
+--R                      4          5
+--R             (- 576A b c + 480B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                                                     +--------+
+--R              5 4          4 2        2 3  +---+ +-+ |   2
+--R         (288c x  + 1536b c x  + 1536b c )\|- c \|b \|c x  + b
+--R       + 
+--R               6 6         5 4        2 4 2        3 3  +---+
+--R         (- 48c x  - 864b c x  - 2304b c x  - 1536b c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 961
+
+--S 962 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2 3        3 2  4          3 2         4   2         4
+--R               (108A b c  - 90B b c )x  + (576A b c  - 480B b c)x  + 576A b c
+--R             + 
+--R                       5
+--R               - 480B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   2 4        3 3  6            3 3         4 2  4
+--R           (- 18A b c  + 15B b c )x  + (- 324A b c  + 270B b c )x
+--R         + 
+--R                    4 2         5   2         5          6
+--R           (- 864A b c  + 720B b c)x  - 576A b c + 480B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                        2 3        3 2  4            3 2         4   2
+--R               (- 108A b c  + 90B b c )x  + (- 576A b c  + 480B b c)x
+--R             + 
+--R                       4          5
+--R               - 576A b c + 480B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                 2 4        3 3  6          3 3         4 2  4
+--R           (18A b c  - 15B b c )x  + (324A b c  - 270B b c )x
+--R         + 
+--R                  4 2         5   2         5          6
+--R           (864A b c  - 720B b c)x  + 576A b c - 480B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                      4 8           4           3  6
+--R               - 48B c x  + (- 72A c  - 196B b c )x
+--R             + 
+--R                          3        2 2  4          2 2         3   2         3
+--R               (- 276A b c  - 26B b c )x  + (192A b c  - 160B b c)x  + 576A b c
+--R             + 
+--R                       4
+--R               - 480B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                   5 10         5           4  8            4         2 3  6
+--R               8B c x   + (12A c  + 134B b c )x  + (198A b c  + 219B b c )x
+--R             + 
+--R                      2 3        3 2  4            3 2         4   2         4
+--R               (252A b c  + 46B b c )x  + (- 480A b c  + 400B b c)x  - 576A b c
+--R             + 
+--R                     5
+--R               480B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 5 11           5           4  9              4         2 3  7
+--R           - 8B c x   + (- 12A c  - 134B b c )x  + (- 198A b c  - 219B b c )x
+--R         + 
+--R                    2 3        3 2  5          3 2         4   3
+--R           (- 252A b c  - 46B b c )x  + (480A b c  - 400B b c)x
+--R         + 
+--R                  4          5
+--R           (576A b c - 480B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R                5 11         5           4  9            4         2 3  7
+--R           48B c x   + (72A c  + 244B b c )x  + (348A b c  + 222B b c )x
+--R         + 
+--R                 2 3         3 2  5            3 2         4   3
+--R           (84A b c  + 186B b c )x  + (- 768A b c  + 640B b c)x
+--R         + 
+--R                    4          5
+--R           (- 576A b c + 480B b )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                                                 +--------+
+--R            5 4          4 2        2 3  +-+ +-+ |   2
+--R       (288c x  + 1536b c x  + 1536b c )\|b \|c \|c x  + b
+--R     + 
+--R             6 6         5 4        2 4 2        3 3  +-+
+--R       (- 48c x  - 864b c x  - 2304b c x  - 1536b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          7 20           7           6  18
+--R                   - 15B c x   + (- 15A c  - 560B b c )x
+--R                 + 
+--R                              6          2 5  16
+--R                   (- 560A b c  - 6048B b c )x
+--R                 + 
+--R                             2 5           3 4  14
+--R                   (- 6048A b c  - 28800B b c )x
+--R                 + 
+--R                              3 4           4 3  12
+--R                   (- 28800A b c  - 70400B b c )x
+--R                 + 
+--R                              4 3           5 2  10
+--R                   (- 70400A b c  - 92160B b c )x
+--R                 + 
+--R                              5 2           6   8              6            7  6
+--R                   (- 92160A b c  - 61440B b c)x  + (- 61440A b c - 16384B b )x
+--R                 + 
+--R                             7 4
+--R                   - 16384A b x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  8 21       8           7  19            7          2 6  17
+--R               B c x   + (A c  + 112B b c )x   + (112A b c  + 2016B b c )x
+--R             + 
+--R                       2 6           3 5  15            3 5           4 4  13
+--R               (2016A b c  + 13440B b c )x   + (13440A b c  + 42240B b c )x
+--R             + 
+--R                        4 4           5 3  11            5 3           6 2  9
+--R               (42240A b c  + 67584B b c )x   + (67584A b c  + 53248B b c )x
+--R             + 
+--R                        6 2           7   7           7   5
+--R               (53248A b c  + 16384B b c)x  + 16384A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  8 22       8           7  20            7          2 6  18
+--R               B c x   + (A c  + 113B b c )x   + (113A b c  + 2128B b c )x
+--R             + 
+--R                       2 6           3 5  16            3 5           4 4  14
+--R               (2128A b c  + 15456B b c )x   + (15456A b c  + 55680B b c )x
+--R             + 
+--R                        4 4            5 3  12
+--R               (55680A b c  + 109824B b c )x
+--R             + 
+--R                         5 3            6 2  10             6 2           7   8
+--R               (109824A b c  + 120832B b c )x   + (120832A b c  + 69632B b c)x
+--R             + 
+--R                        7            8  6           8 4
+--R               (69632A b c + 16384B b )x  + 16384A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      8 21           8           7  19
+--R               - 15B c x   + (- 15A c  - 560B b c )x
+--R             + 
+--R                          7          2 6  17             2 6           3 5  15
+--R               (- 560A b c  - 6048B b c )x   + (- 6048A b c  - 28800B b c )x
+--R             + 
+--R                          3 5           4 4  13
+--R               (- 28800A b c  - 70400B b c )x
+--R             + 
+--R                          4 4           5 3  11
+--R               (- 70400A b c  - 92160B b c )x
+--R             + 
+--R                          5 3           6 2  9              6 2           7   7
+--R               (- 92160A b c  - 61440B b c )x  + (- 61440A b c  - 16384B b c)x
+--R             + 
+--R                         7   5
+--R               - 16384A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    8 23         8           7  21
+--R               - B c x   + (- A c  - 113B b c )x
+--R             + 
+--R                          7          2 6  19             2 6           3 5  17
+--R               (- 113A b c  - 2128B b c )x   + (- 2128A b c  - 15456B b c )x
+--R             + 
+--R                          3 5           4 4  15
+--R               (- 15456A b c  - 55680B b c )x
+--R             + 
+--R                          4 4            5 3  13
+--R               (- 55680A b c  - 109824B b c )x
+--R             + 
+--R                           5 3            6 2  11
+--R               (- 109824A b c  - 120832B b c )x
+--R             + 
+--R                           6 2           7   9              7            8  7
+--R               (- 120832A b c  - 69632B b c)x  + (- 69632A b c - 16384B b )x
+--R             + 
+--R                         8 5
+--R               - 16384A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    8 22         8           7  20            7          2 6  18
+--R               15B c x   + (15A c  + 560B b c )x   + (560A b c  + 6048B b c )x
+--R             + 
+--R                       2 6           3 5  16            3 5           4 4  14
+--R               (6048A b c  + 28800B b c )x   + (28800A b c  + 70400B b c )x
+--R             + 
+--R                        4 4           5 3  12            5 3           6 2  10
+--R               (70400A b c  + 92160B b c )x   + (92160A b c  + 61440B b c )x
+--R             + 
+--R                        6 2           7   8           7   6
+--R               (61440A b c  + 16384B b c)x  + 16384A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                8 23         8           7  21            7          2 6  19
+--R           15B c x   + (15A c  + 575B b c )x   + (575A b c  + 6608B b c )x
+--R         + 
+--R                   2 6           3 5  17            3 5           4 4  15
+--R           (6608A b c  + 34848B b c )x   + (34848A b c  + 99200B b c )x
+--R         + 
+--R                    4 4            5 3  13             5 3            6 2  11
+--R           (99200A b c  + 162560B b c )x   + (162560A b c  + 153600B b c )x
+--R         + 
+--R                     6 2           7   9            7            8  7
+--R           (153600A b c  + 77824B b c)x  + (77824A b c + 16384B b )x
+--R         + 
+--R                   8 5
+--R           16384A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            9 24         9           8  22              8          2 7  20
+--R       - B c x   + (- A c  - 113B b c )x   + (- 113A b c  - 2128B b c )x
+--R     + 
+--R                 2 7           3 6  18              3 6           4 5  16
+--R       (- 2128A b c  - 15456B b c )x   + (- 15456A b c  - 55680B b c )x
+--R     + 
+--R                  4 5            5 4  14               5 4            6 3  12
+--R       (- 55680A b c  - 109824B b c )x   + (- 109824A b c  - 120832B b c )x
+--R     + 
+--R                   6 3           7 2  10              7 2           8   8
+--R       (- 120832A b c  - 69632B b c )x   + (- 69632A b c  - 16384B b c)x
+--R     + 
+--R                 8   6
+--R       - 16384A b c x
+--R  /
+--R                  8 16         7 14        2 6 12         3 5 10         4 4 8
+--R                 c x   + 113b c x   + 2128b c x   + 15456b c x   + 55680b c x
+--R               + 
+--R                        5 3 6          6 2 4         7   2         8
+--R                 109824b c x  + 120832b c x  + 69632b c x  + 16384b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                      8 15         7 13        2 6 11         3 5 9
+--R                 - 15c x   - 560b c x   - 6048b c x   - 28800b c x
+--R               + 
+--R                         4 4 7         5 3 5         6 2 3         7
+--R                 - 70400b c x  - 92160b c x  - 61440b c x  - 16384b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  8 16         7 14        2 6 12         3 5 10         4 4 8
+--R             - 15c x   - 575b c x   - 6608b c x   - 34848b c x   - 99200b c x
+--R           + 
+--R                      5 3 6          6 2 4         7   2         8
+--R             - 162560b c x  - 153600b c x  - 77824b c x  - 16384b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          9 17         8 15        2 7 13         3 6 11         4 5 9
+--R         c x   + 113b c x   + 2128b c x   + 15456b c x   + 55680b c x
+--R       + 
+--R                5 4 7          6 3 5         7 2 3         8
+--R         109824b c x  + 120832b c x  + 69632b c x  + 16384b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 963
+
+--S 964 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        2 3        3 2  4            3 2         4   2
+--R               (- 108A b c  + 90B b c )x  + (- 576A b c  + 480B b c)x
+--R             + 
+--R                       4          5
+--R               - 576A b c + 480B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                     2 4        3 3  6          3 3         4 2  4
+--R               (18A b c  - 15B b c )x  + (324A b c  - 270B b c )x
+--R             + 
+--R                      4 2         5   2         5          6
+--R               (864A b c  - 720B b c)x  + 576A b c - 480B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                      2 3         3 2  4           3 2         4   2          4
+--R               (216A b c  - 180B b c )x  + (1152A b c  - 960B b c)x  + 1152A b c
+--R             + 
+--R                       5
+--R               - 960B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                       2 4        3 3  6            3 3         4 2  4
+--R               (- 36A b c  + 30B b c )x  + (- 648A b c  + 540B b c )x
+--R             + 
+--R                         4 2          5   2          5          6
+--R               (- 1728A b c  + 1440B b c)x  - 1152A b c + 960B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                      4 8           4           3  6
+--R               - 48B c x  + (- 72A c  - 196B b c )x
+--R             + 
+--R                          3        2 2  4          2 2         3   2         3
+--R               (- 276A b c  - 26B b c )x  + (192A b c  - 160B b c)x  + 576A b c
+--R             + 
+--R                       4
+--R               - 480B b
+--R          *
+--R                            +--------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|b \|c \|c x  + b
+--R         + 
+--R                   5 10         5           4  8            4         2 3  6
+--R               8B c x   + (12A c  + 134B b c )x  + (198A b c  + 219B b c )x
+--R             + 
+--R                      2 3        3 2  4            3 2         4   2         4
+--R               (252A b c  + 46B b c )x  + (- 480A b c  + 400B b c)x  - 576A b c
+--R             + 
+--R                     5
+--R               480B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 5 11           5           4  9              4         2 3  7
+--R           - 8B c x   + (- 12A c  - 134B b c )x  + (- 198A b c  - 219B b c )x
+--R         + 
+--R                    2 3        3 2  5          3 2         4   3
+--R           (- 252A b c  - 46B b c )x  + (480A b c  - 400B b c)x
+--R         + 
+--R                  4          5
+--R           (576A b c - 480B b )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R                5 11         5           4  9            4         2 3  7
+--R           48B c x   + (72A c  + 244B b c )x  + (348A b c  + 222B b c )x
+--R         + 
+--R                 2 3         3 2  5            3 2         4   3
+--R           (84A b c  + 186B b c )x  + (- 768A b c  + 640B b c)x
+--R         + 
+--R                    4          5
+--R           (- 576A b c + 480B b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R                                                       +--------+
+--R            5 4          4 2        2 3  +---+ +-+ +-+ |   2
+--R       (288c x  + 1536b c x  + 1536b c )\|- c \|b \|c \|c x  + b
+--R     + 
+--R             6 6         5 4        2 4 2        3 3  +---+ +-+
+--R       (- 48c x  - 864b c x  - 2304b c x  - 1536b c )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 964
+
+--S 965 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      5 16           5           4  14
+--R               - 12B c x   + (- 12A c  - 280B b c )x
+--R             + 
+--R                          4          2 3  12             2 3          3 2  10
+--R               (- 280A b c  - 1792B b c )x   + (- 1792A b c  - 4608B b c )x
+--R             + 
+--R                         3 2          4   8             4           5  6
+--R               (- 4608A b c  - 5120B b c)x  + (- 5120A b c - 2048B b )x
+--R             + 
+--R                        5 4
+--R               - 2048A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              6 18       6          5  16           5         2 4  14
+--R           B c x   + (A c  + 72B b c )x   + (72A b c  + 840B b c )x
+--R         + 
+--R                  2 4          3 3  12           3 3          4 2  10
+--R           (840A b c  + 3584B b c )x   + (3584A b c  + 6912B b c )x
+--R         + 
+--R                   4 2          5   8           5           6  6          6 4
+--R           (6912A b c  + 6144B b c)x  + (6144A b c + 2048B b )x  + 2048A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                6 19         6          5  17             5         2 4  15
+--R           - B c x   + (- A c  - 72B b c )x   + (- 72A b c  - 840B b c )x
+--R         + 
+--R                    2 4          3 3  13             3 3          4 2  11
+--R           (- 840A b c  - 3584B b c )x   + (- 3584A b c  - 6912B b c )x
+--R         + 
+--R                   4 2          5   9             5           6  7          6 5
+--R         (- 6912A b c  - 6144B b c)x  + (- 6144A b c - 2048B b )x  - 2048A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                6 19         6           5  17            5          2 4  15
+--R           12B c x   + (12A c  + 292B b c )x   + (292A b c  + 2072B b c )x
+--R         + 
+--R                   2 4          3 3  13           3 3          4 2  11
+--R           (2072A b c  + 6400B b c )x   + (6400A b c  + 9728B b c )x
+--R         + 
+--R                   4 2          5   9           5           6  7          6 5
+--R           (9728A b c  + 7168B b c)x  + (7168A b c + 2048B b )x  + 2048A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              6 12        5 10       2 4 8        3 3 6        4 2 4
+--R             c x   + 72b c x   + 840b c x  + 3584b c x  + 6912b c x
+--R           + 
+--R                  5   2        6
+--R             6144b c x  + 2048b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  6 12         5 10        2 4 8        3 3 6        4 2 4
+--R             - 12c x   - 292b c x   - 2072b c x  - 6400b c x  - 9728b c x
+--R           + 
+--R                    5   2        6
+--R             - 7168b c x  - 2048b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 965
+
+)clear all
+
+--S 966 of 3139
+t0:=x^3*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             5      3
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 966
+
+--S 967 of 3139
+r0:=1/8*b*(3*b*B-4*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(5/2)-_
+   1/8*(3*b*B-4*A*c)*sqrt(b*x^2+c*x^4)/c^2+1/4*B*x^2*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                    2 +-+
+--R                       2           x \|c
+--R       (- 4A b c + 3B b )atanh(--------------)
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R     + 
+--R                                   +-----------+
+--R              2                +-+ |   4      2
+--R       (2B c x  + 4A c - 3B b)\|c \|c x  + b x
+--R  /
+--R       2 +-+
+--R     8c \|c
+--R                                                    Type: Expression(Integer)
+--E 967
+
+--S 968 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                             +--------+
+--R                      2        2   2        2         3  +-+ |   2
+--R             ((16A b c  - 12B b c)x  + 32A b c - 24B b )\|b \|c x  + b
+--R           + 
+--R                    3       2 2  4           2 2        3   2        3         4
+--R           (- 4A b c  + 3B b c )x  + (- 32A b c  + 24B b c)x  - 32A b c + 24B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                   3 7          3          2  5             2       2   3
+--R             - 2B c x  + (- 4A c  - 13B b c )x  + (- 32A b c  + 8B b c)x
+--R           + 
+--R                     2         3
+--R             (- 32A b c + 24B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                 3 7         3          2  5           2        2   3
+--R             8B c x  + (16A c  + 12B b c )x  + (48A b c  - 20B b c)x
+--R           + 
+--R                   2         3
+--R             (32A b c - 24B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                                 +--------+
+--R           3 2        2  +-+ +-+ |   2             4 4        3 2      2 2  +-+
+--R       (32c x  + 64b c )\|b \|c \|c x  + b  + (- 8c x  - 64b c x  - 64b c )\|c
+--R     ,
+--R
+--R                                                               +--------+
+--R                        2        2   2        2         3  +-+ |   2
+--R             ((- 32A b c  + 24B b c)x  - 64A b c + 48B b )\|b \|c x  + b
+--R           + 
+--R                    3       2 2  4         2 2        3   2        3         4
+--R             (8A b c  - 6B b c )x  + (64A b c  - 48B b c)x  + 64A b c - 48B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                   3 7          3          2  5             2       2   3
+--R             - 2B c x  + (- 4A c  - 13B b c )x  + (- 32A b c  + 8B b c)x
+--R           + 
+--R                     2         3
+--R             (- 32A b c + 24B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                 3 7         3          2  5           2        2   3
+--R             8B c x  + (16A c  + 12B b c )x  + (48A b c  - 20B b c)x
+--R           + 
+--R                   2         3
+--R             (32A b c - 24B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                                     +--------+
+--R             3 2        2  +---+ +-+ |   2
+--R         (32c x  + 64b c )\|- c \|b \|c x  + b
+--R       + 
+--R              4 4        3 2      2 2  +---+
+--R         (- 8c x  - 64b c x  - 64b c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 968
+
+--S 969 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                           +--------+
+--R                    2        2   2        2         3  +-+ |   2
+--R           ((16A b c  - 12B b c)x  + 32A b c - 24B b )\|b \|c x  + b
+--R         + 
+--R                  3       2 2  4           2 2        3   2        3         4
+--R         (- 4A b c  + 3B b c )x  + (- 32A b c  + 24B b c)x  - 32A b c + 24B b
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                                                           +--------+
+--R                    2        2   2        2         3  +-+ |   2
+--R           ((16A b c  - 12B b c)x  + 32A b c - 24B b )\|b \|c x  + b
+--R         + 
+--R                  3       2 2  4           2 2        3   2        3         4
+--R         (- 4A b c  + 3B b c )x  + (- 32A b c  + 24B b c)x  - 32A b c + 24B b
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                    2 4           2           2                  2  +-+ +-+
+--R             (- 8B c x  + (- 16A c  - 4B b c)x  - 32A b c + 24B b )\|b \|c
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                   3 6        3          2  4           2       2   2        2
+--R               2B c x  + (4A c  + 13B b c )x  + (32A b c  - 8B b c)x  + 32A b c
+--R             + 
+--R                      3
+--R               - 24B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 3 7          3          2  5             2       2   3
+--R           - 2B c x  + (- 4A c  - 13B b c )x  + (- 32A b c  + 8B b c)x
+--R         + 
+--R                   2         3
+--R           (- 32A b c + 24B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + b
+--R     + 
+--R               3 7         3          2  5           2        2   3
+--R           8B c x  + (16A c  + 12B b c )x  + (48A b c  - 20B b c)x
+--R         + 
+--R                 2         3
+--R           (32A b c - 24B b )x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R  /
+--R                               +--------+
+--R         3 2        2  +-+ +-+ |   2             4 4        3 2      2 2  +-+
+--R     (32c x  + 64b c )\|b \|c \|c x  + b  + (- 8c x  - 64b c x  - 64b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 969
+
+--S 970 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          5 14           5           4  12
+--R                   - 11B c x   + (- 11A c  - 220B b c )x
+--R                 + 
+--R                              4          2 3  10             2 3          3 2  8
+--R                   (- 220A b c  - 1232B b c )x   + (- 1232A b c  - 2816B b c )x
+--R                 + 
+--R                             3 2          4   6             4           5  4
+--R                   (- 2816A b c  - 2816B b c)x  + (- 2816A b c - 1024B b )x
+--R                 + 
+--R                            5 2
+--R                   - 1024A b x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                    6 15         6          5  13             5         2 4  11
+--R               - B c x   + (- A c  - 60B b c )x   + (- 60A b c  - 560B b c )x
+--R             + 
+--R                        2 4          3 3  9             3 3          4 2  7
+--R               (- 560A b c  - 1792B b c )x  + (- 1792A b c  - 2304B b c )x
+--R             + 
+--R                         4 2          5   5          5   3
+--R               (- 2304A b c  - 1024B b c)x  - 1024A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  6 16       6          5  14           5         2 4  12
+--R               B c x   + (A c  + 61B b c )x   + (61A b c  + 620B b c )x
+--R             + 
+--R                      2 4          3 3  10           3 3          4 2  8
+--R               (620A b c  + 2352B b c )x   + (2352A b c  + 4096B b c )x
+--R             + 
+--R                     4 2          5   6           5           6  4          6 2
+--R             (4096A b c  + 3328B b c)x  + (3328A b c + 1024B b )x  + 1024A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    6 15         6           5  13            5          2 4  11
+--R               11B c x   + (11A c  + 220B b c )x   + (220A b c  + 1232B b c )x
+--R             + 
+--R                       2 4          3 3  9           3 3          4 2  7
+--R               (1232A b c  + 2816B b c )x  + (2816A b c  + 2816B b c )x
+--R             + 
+--R                       4 2          5   5          5   3
+--R               (2816A b c  + 1024B b c)x  + 1024A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    6 17         6          5  15             5         2 4  13
+--R               - B c x   + (- A c  - 61B b c )x   + (- 61A b c  - 620B b c )x
+--R             + 
+--R                        2 4          3 3  11             3 3          4 2  9
+--R               (- 620A b c  - 2352B b c )x   + (- 2352A b c  - 4096B b c )x
+--R             + 
+--R                         4 2          5   7             5           6  5
+--R               (- 4096A b c  - 3328B b c)x  + (- 3328A b c - 1024B b )x
+--R             + 
+--R                        6 3
+--R               - 1024A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      6 16           6           5  14
+--R               - 11B c x   + (- 11A c  - 220B b c )x
+--R             + 
+--R                          5          2 4  12             2 4          3 3  10
+--R               (- 220A b c  - 1232B b c )x   + (- 1232A b c  - 2816B b c )x
+--R             + 
+--R                         3 3          4 2  8             4 2          5   6
+--R               (- 2816A b c  - 2816B b c )x  + (- 2816A b c  - 1024B b c)x
+--R             + 
+--R                        5   4
+--R               - 1024A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                6 17         6           5  15            5          2 4  13
+--R           11B c x   + (11A c  + 231B b c )x   + (231A b c  + 1452B b c )x
+--R         + 
+--R                   2 4          3 3  11           3 3          4 2  9
+--R           (1452A b c  + 4048B b c )x   + (4048A b c  + 5632B b c )x
+--R         + 
+--R                   4 2          5   7           5           6  5          6 3
+--R           (5632A b c  + 3840B b c)x  + (3840A b c + 1024B b )x  + 1024A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R          7 18       7          6  16           6         2 5  14
+--R       B c x   + (A c  + 61B b c )x   + (61A b c  + 620B b c )x
+--R     + 
+--R              2 5          3 4  12           3 4          4 3  10
+--R       (620A b c  + 2352B b c )x   + (2352A b c  + 4096B b c )x
+--R     + 
+--R               4 3          5 2  8           5 2          6   6          6   4
+--R       (4096A b c  + 3328B b c )x  + (3328A b c  + 1024B b c)x  + 1024A b c x
+--R  /
+--R                  6 12        5 10       2 4 8        3 3 6        4 2 4
+--R                 c x   + 61b c x   + 620b c x  + 2352b c x  + 4096b c x
+--R               + 
+--R                      5   2        6
+--R                 3328b c x  + 1024b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                    6 11         5 9        2 4 7        3 3 5        4 2 3
+--R                 11c x   + 220b c x  + 1232b c x  + 2816b c x  + 2816b c x
+--R               + 
+--R                      5
+--R                 1024b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  6 12         5 10        2 4 8        3 3 6        4 2 4
+--R             - 11c x   - 231b c x   - 1452b c x  - 4048b c x  - 5632b c x
+--R           + 
+--R                    5   2        6
+--R             - 3840b c x  - 1024b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R            7 13        6 11       2 5 9        3 4 7        4 3 5        5 2 3
+--R         - c x   - 61b c x   - 620b c x  - 2352b c x  - 4096b c x  - 3328b c x
+--R       + 
+--R                6
+--R         - 1024b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 970
+
+--S 971 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                 +--------+
+--R                    2        2   2        2         3  +---+ +-+ |   2
+--R           ((16A b c  - 12B b c)x  + 32A b c - 24B b )\|- c \|b \|c x  + b
+--R         + 
+--R                        3       2 2  4           2 2        3   2        3
+--R               (- 4A b c  + 3B b c )x  + (- 32A b c  + 24B b c)x  - 32A b c
+--R             + 
+--R                    4
+--R               24B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                                                 +--------+
+--R                      2        2   2        2         3  +-+ +-+ |   2
+--R           ((- 32A b c  + 24B b c)x  - 64A b c + 48B b )\|b \|c \|c x  + b
+--R         + 
+--R                 3       2 2  4         2 2        3   2        3         4  +-+
+--R         ((8A b c  - 6B b c )x  + (64A b c  - 48B b c)x  + 64A b c - 48B b )\|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                    2 4           2           2                  2  +---+ +-+
+--R             (- 8B c x  + (- 16A c  - 4B b c)x  - 32A b c + 24B b )\|- c \|b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|c x  + b
+--R         + 
+--R                   3 6        3          2  4           2       2   2        2
+--R               2B c x  + (4A c  + 13B b c )x  + (32A b c  - 8B b c)x  + 32A b c
+--R             + 
+--R                      3
+--R               - 24B b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 3 7          3          2  5             2       2   3
+--R           - 2B c x  + (- 4A c  - 13B b c )x  + (- 32A b c  + 8B b c)x
+--R         + 
+--R                   2         3
+--R           (- 32A b c + 24B b )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b
+--R     + 
+--R               3 7         3          2  5           2        2   3
+--R           8B c x  + (16A c  + 12B b c )x  + (48A b c  - 20B b c)x
+--R         + 
+--R                 2         3
+--R           (32A b c - 24B b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|b \|c
+--R  /
+--R                                       +--------+
+--R           3 2        2  +---+ +-+ +-+ |   2
+--R       (32c x  + 64b c )\|- c \|b \|c \|c x  + b
+--R     + 
+--R            4 4        3 2      2 2  +---+ +-+
+--R       (- 8c x  - 64b c x  - 64b c )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 971
+
+--S 972 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                     3 10          3          2  8             2         2   6
+--R               - 8B c x   + (- 8A c  - 80B b c )x  + (- 80A b c  - 192B b c)x
+--R             + 
+--R                        2          3  4         3 2
+--R               (- 192A b c - 128B b )x  - 128A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              4 12       4          3  10           3         2 2  8
+--R           B c x   + (A c  + 32B b c )x   + (32A b c  + 160B b c )x
+--R         + 
+--R                  2 2         3   6          3          4  4         4 2
+--R           (160A b c  + 256B b c)x  + (256A b c + 128B b )x  + 128A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                4 13         4          3  11             3         2 2  9
+--R           - B c x   + (- A c  - 32B b c )x   + (- 32A b c  - 160B b c )x
+--R         + 
+--R                    2 2         3   7            3          4  5         4 3
+--R           (- 160A b c  - 256B b c)x  + (- 256A b c - 128B b )x  - 128A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               4 13        4          3  11           3         2 2  9
+--R           8B c x   + (8A c  + 88B b c )x   + (88A b c  + 272B b c )x
+--R         + 
+--R                  2 2         3   7          3          4  5         4 3
+--R           (272A b c  + 320B b c)x  + (320A b c + 128B b )x  + 128A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                           +--------+
+--R           4 8        3 6       2 2 4       3   2       4  |   2
+--R         (c x  + 32b c x  + 160b c x  + 256b c x  + 128b )\|c x  + b
+--R       + 
+--R              4 8        3 6       2 2 4       3   2       4  +-+
+--R         (- 8c x  - 88b c x  - 272b c x  - 320b c x  - 128b )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 972
+
+)clear all
+
+--S 973 of 3139
+t0:=x*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             3
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 973
+
+--S 974 of 3139
+r0:=-1/2*(b*B-2*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)+_
+   1/2*B*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                               2 +-+              +-----------+
+--R                              x \|c           +-+ |   4      2
+--R        (2A c - B b)atanh(--------------) + B\|c \|c x  + b x
+--R                           +-----------+
+--R                           |   4      2
+--R                          \|c x  + b x
+--R   (2)  -------------------------------------------------------
+--R                                    +-+
+--R                                 2c\|c
+--R                                                    Type: Expression(Integer)
+--E 974
+
+--S 975 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                              +--------+
+--R                          +-+ |   2               2          2                2
+--R           ((4A c - 2B b)\|b \|c x  + b  + (- 2A c  + B b c)x  - 4A b c + 2B b )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                                 +--------+
+--R                 3           +-+ |   2               3           +-+ +-+
+--R         (- B c x  - 2B b x)\|c \|c x  + b  + (2B c x  + 2B b x)\|b \|c
+--R    /
+--R                  +--------+
+--R          +-+ +-+ |   2             2 2         +-+
+--R       4c\|b \|c \|c x  + b  + (- 2c x  - 4b c)\|c
+--R     ,
+--R
+--R                                 +--------+
+--R                             +-+ |   2               2           2
+--R               (8A c - 4B b)\|b \|c x  + b  + (- 4A c  + 2B b c)x  - 8A b c
+--R             + 
+--R                   2
+--R               4B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                                   +--------+
+--R                 3           +---+ |   2               3           +---+ +-+
+--R         (- B c x  - 2B b x)\|- c \|c x  + b  + (2B c x  + 2B b x)\|- c \|b
+--R    /
+--R                    +--------+
+--R          +---+ +-+ |   2             2 2         +---+
+--R       4c\|- c \|b \|c x  + b  + (- 2c x  - 4b c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 975
+
+--S 976 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            +--------+
+--R                        +-+ |   2               2          2                2
+--R         ((4A c - 2B b)\|b \|c x  + b  + (- 2A c  + B b c)x  - 4A b c + 2B b )
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                              +--------+
+--R                          +-+ |   2             2          2                2
+--R         ((- 4A c + 2B b)\|b \|c x  + b  + (2A c  - B b c)x  + 4A b c - 2B b )
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                     +--------+                        +-----------+
+--R             +-+ +-+ |   2              2         +-+  |   4      2
+--R       (- 2B\|b \|c \|c x  + b  + (B c x  + 2B b)\|c )\|c x  + b x
+--R     + 
+--R                               +--------+
+--R               3           +-+ |   2               3           +-+ +-+
+--R       (- B c x  - 2B b x)\|c \|c x  + b  + (2B c x  + 2B b x)\|b \|c
+--R  /
+--R                +--------+
+--R        +-+ +-+ |   2             2 2         +-+
+--R     4c\|b \|c \|c x  + b  + (- 2c x  - 4b c)\|c
+--R                                                    Type: Expression(Integer)
+--E 976
+
+--S 977 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         3 8          3          2  6
+--R                   - 7B c x  + (- 7A c  - 56B b c )x
+--R                 + 
+--R                             2         2   4            2         3  2        3
+--R                   (- 56A b c  - 112B b c)x  + (- 112A b c - 64B b )x  - 64A b
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  4 9       4          3  7           3        2 2  5
+--R               B c x  + (A c  + 24B b c )x  + (24A b c  + 80B b c )x
+--R             + 
+--R                     2 2        3   3        3
+--R               (80A b c  + 64B b c)x  + 64A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  4 10       4          3  8           3         2 2  6
+--R               B c x   + (A c  + 25B b c )x  + (25A b c  + 104B b c )x
+--R             + 
+--R                      2 2         3   4          3         4  2        4
+--R               (104A b c  + 144B b c)x  + (144A b c + 64B b )x  + 64A b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                     4 9          4          3  7             3         2 2  5
+--R               - 7B c x  + (- 7A c  - 56B b c )x  + (- 56A b c  - 112B b c )x
+--R             + 
+--R                        2 2        3   3        3
+--R               (- 112A b c  - 64B b c)x  - 64A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    4 11         4          3  9             3         2 2  7
+--R               - B c x   + (- A c  - 25B b c )x  + (- 25A b c  - 104B b c )x
+--R             + 
+--R                        2 2         3   5            3         4  3        4
+--R               (- 104A b c  - 144B b c)x  + (- 144A b c - 64B b )x  - 64A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                   4 10        4          3  8           3         2 2  6
+--R               7B c x   + (7A c  + 56B b c )x  + (56A b c  + 112B b c )x
+--R             + 
+--R                      2 2        3   4        3   2
+--R               (112A b c  + 64B b c)x  + 64A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               4 11        4          3  9           3         2 2  7
+--R           7B c x   + (7A c  + 63B b c )x  + (63A b c  + 168B b c )x
+--R         + 
+--R                  2 2         3   5          3         4  3        4
+--R           (168A b c  + 176B b c)x  + (176A b c + 64B b )x  + 64A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            5 12         5          4  10             4         2 3  8
+--R       - B c x   + (- A c  - 25B b c )x   + (- 25A b c  - 104B b c )x
+--R     + 
+--R                2 3         3 2  6            3 2        4   4        4   2
+--R       (- 104A b c  - 144B b c )x  + (- 144A b c  - 64B b c)x  - 64A b c x
+--R  /
+--R               4 8        3 6       2 2 4       3   2      4  +-+
+--R             (c x  + 25b c x  + 104b c x  + 144b c x  + 64b )\|c
+--R           + 
+--R                  4 7        3 5       2 2 3      3     +-+
+--R             (- 7c x  - 56b c x  - 112b c x  - 64b c x)\|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R              4 8        3 6       2 2 4       3   2      4  +-+ +-+    5 9
+--R         (- 7c x  - 63b c x  - 168b c x  - 176b c x  - 64b )\|b \|c  + c x
+--R       + 
+--R              4 7       2 3 5       3 2 3      4
+--R         25b c x  + 104b c x  + 144b c x  + 64b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                     +--------+
+--R                           +---+ +-+ |   2
+--R           (- 4A c + 2B b)\|- c \|b \|c x  + b
+--R         + 
+--R                 2          2                2  +---+
+--R           ((2A c  - B b c)x  + 4A b c - 2B b )\|- c
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                                 +--------+
+--R                         +-+ +-+ |   2
+--R           (8A c - 4B b)\|b \|c \|c x  + b
+--R         + 
+--R                   2           2                2  +-+
+--R           ((- 4A c  + 2B b c)x  - 8A b c + 4B b )\|c
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                           +--------+                              +-----------+
+--R             +---+ +-+ +-+ |   2              2         +---+ +-+  |   4      2
+--R       (- 2B\|- c \|b \|c \|c x  + b  + (B c x  + 2B b)\|- c \|c )\|c x  + b x
+--R     + 
+--R                                   +--------+
+--R             3           +---+ +-+ |   2               3           +---+ +-+ +-+
+--R     (- B c x  - 2B b x)\|- c \|c \|c x  + b  + (2B c x  + 2B b x)\|- c \|b \|c
+--R  /
+--R                      +--------+
+--R        +---+ +-+ +-+ |   2             2 2         +---+ +-+
+--R     4c\|- c \|b \|c \|c x  + b  + (- 2c x  - 4b c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 978
+
+--S 979 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                                      +--------+
+--R                    4                   2         +-+ |   2           2 6
+--R           (- 4B c x  + (- 4A c - 8B b)x  - 8A b)\|b \|c x  + b  + B c x
+--R         + 
+--R               2           4                 2  2       2
+--R           (A c  + 8B b c)x  + (8A b c + 8B b )x  + 8A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R               2 7         2           5                   2  3       2
+--R         (- B c x  + (- A c  - 8B b c)x  + (- 8A b c - 8B b )x  - 8A b x)
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R            2 7        2            5                  2  3       2   +-+
+--R       (4B c x  + (4A c  + 12B b c)x  + (12A b c + 8B b )x  + 8A b x)\|b
+--R  /
+--R                               +--------+
+--R          2 4         2     2  |   2             2 4          2     2  +-+
+--R       ((c x  + 8b c x  + 8b )\|c x  + b  + (- 4c x  - 12b c x  - 8b )\|b )
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 979
+
+)clear all
+
+--S 980 of 3139
+t0:=(A+B*x^2)/(x*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ---------------
+--R          +-----------+
+--R          |   4      2
+--R        x\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 980
+
+--S 981 of 3139
+r0:=B*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/sqrt(c)-A*sqrt(b*x^2+c*x^4)/(b*x^2)
+--R 
+--R
+--R                         2 +-+              +-----------+
+--R             2          x \|c           +-+ |   4      2
+--R        B b x atanh(--------------) - A\|c \|c x  + b x
+--R                     +-----------+
+--R                     |   4      2
+--R                    \|c x  + b x
+--R   (2)  -------------------------------------------------
+--R                                2 +-+
+--R                             b x \|c
+--R                                                    Type: Expression(Integer)
+--E 981
+
+--S 982 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  +--------+
+--R                  |   2              +-+
+--R           (B b x\|c x  + b  - B b x\|b )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                   +--------+
+--R           +-+ +-+ |   2                2        +-+
+--R         A\|b \|c \|c x  + b  + (- A c x  - A b)\|c
+--R    /
+--R               +--------+
+--R           +-+ |   2            +-+ +-+
+--R       b x\|c \|c x  + b  - b x\|b \|c
+--R     ,
+--R
+--R                                                     +--------+
+--R                 +--------+                    +---+ |   2         +---+ +-+
+--R                 |   2               +-+      \|- c \|c x  + b  - \|- c \|b
+--R         (2B b x\|c x  + b  - 2B b x\|b )atan(------------------------------)
+--R                                                            c x
+--R       + 
+--R                     +--------+
+--R           +---+ +-+ |   2                2        +---+
+--R         A\|- c \|b \|c x  + b  + (- A c x  - A b)\|- c
+--R    /
+--R                 +--------+
+--R           +---+ |   2            +---+ +-+
+--R       b x\|- c \|c x  + b  - b x\|- c \|b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 982
+
+--S 983 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 +--------+
+--R               2 |   2             2 +-+
+--R         (B b x \|c x  + b  - B b x \|b )
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                 +--------+                         2 +-+
+--R               2 |   2             2 +-+           x \|c
+--R       (- B b x \|c x  + b  + B b x \|b )atanh(--------------)
+--R                                                +-----------+
+--R                                                |   4      2
+--R                                               \|c x  + b x
+--R     + 
+--R              +--------+              +-----------+               +--------+
+--R          +-+ |   2          +-+ +-+  |   4      2        +-+ +-+ |   2
+--R       (A\|c \|c x  + b  - A\|b \|c )\|c x  + b x   + A x\|b \|c \|c x  + b
+--R     + 
+--R               3          +-+
+--R       (- A c x  - A b x)\|c
+--R  /
+--R              +--------+
+--R        2 +-+ |   2           2 +-+ +-+
+--R     b x \|c \|c x  + b  - b x \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 983
+
+--S 984 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         2 6          2            4                     2  2
+--R                   - 5B c x  + (- 5A c  - 20B b c)x  + (- 20A b c - 16B b )x
+--R                 + 
+--R                          2
+--R                   - 16A b
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                3 7       3          2  5           2        2   3        2
+--R             B c x  + (A c  + 12B b c )x  + (12A b c  + 16B b c)x  + 16A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  3 8       3          2  6           2        2   4
+--R               B c x  + (A c  + 13B b c )x  + (13A b c  + 28B b c)x
+--R             + 
+--R                     2         3  2        3
+--R               (28A b c + 16B b )x  + 16A b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                     3 7          3          2  5             2        2   3
+--R               - 5B c x  + (- 5A c  - 20B b c )x  + (- 20A b c  - 16B b c)x
+--R             + 
+--R                      2
+--R               - 16A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    3 9         3          2  7             2        2   5
+--R               - B c x  + (- A c  - 13B b c )x  + (- 13A b c  - 28B b c)x
+--R             + 
+--R                       2         3  3        3
+--R               (- 28A b c - 16B b )x  - 16A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                   3 8        3          2  6           2        2   4
+--R               5B c x  + (5A c  + 20B b c )x  + (20A b c  + 16B b c)x
+--R             + 
+--R                    2   2
+--R               16A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               3 9        3          2  7           2        2   5
+--R           5B c x  + (5A c  + 25B b c )x  + (25A b c  + 36B b c)x
+--R         + 
+--R                 2         3  3        3
+--R           (36A b c + 16B b )x  + 16A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            4 10         4          3  8             3        2 2  6
+--R       - B c x   + (- A c  - 13B b c )x  + (- 13A b c  - 28B b c )x
+--R     + 
+--R               2 2        3   4        3   2
+--R       (- 28A b c  - 16B b c)x  - 16A b c x
+--R  /
+--R               3 8        2 6      2   4      3 2  +-+
+--R             (c x  + 13b c x  + 28b c x  + 16b x )\|c
+--R           + 
+--R                  3 7        2 5      2   3  +-+
+--R             (- 5c x  - 20b c x  - 16b c x )\|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R              3 8        2 6      2   4      3 2  +-+ +-+    4 9        3 7
+--R         (- 5c x  - 25b c x  - 36b c x  - 16b x )\|b \|c  + c x  + 13b c x
+--R       + 
+--R            2 2 5      3   3
+--R         28b c x  + 16b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 984
+
+--S 985 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +--------+                               2 +-+
+--R               2 +---+ |   2             2 +---+ +-+           x \|c
+--R       (- B b x \|- c \|c x  + b  + B b x \|- c \|b )atanh(--------------)
+--R                                                            +-----------+
+--R                                                            |   4      2
+--R                                                           \|c x  + b x
+--R     + 
+--R                      +--------+
+--R                2 +-+ |   2              2 +-+ +-+
+--R         (2B b x \|c \|c x  + b  - 2B b x \|b \|c )
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                    +--------+                    +-----------+
+--R          +---+ +-+ |   2          +---+ +-+ +-+  |   4      2
+--R       (A\|- c \|c \|c x  + b  - A\|- c \|b \|c )\|c x  + b x
+--R     + 
+--R                         +--------+
+--R           +---+ +-+ +-+ |   2                3          +---+ +-+
+--R       A x\|- c \|b \|c \|c x  + b  + (- A c x  - A b x)\|- c \|c
+--R  /
+--R                    +--------+
+--R        2 +---+ +-+ |   2           2 +---+ +-+ +-+
+--R     b x \|- c \|c \|c x  + b  - b x \|- c \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 985
+
+--S 986 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                             +--------+
+--R                 2       +-+ |   2             4                2
+--R         ((- 2B x  - 2A)\|b \|c x  + b  + B c x  + (A c + 2B b)x  + 2A b)
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                              +--------+
+--R               5                  3           |   2
+--R       (- B c x  + (- A c - 2B b)x  - 2A b x)\|c x  + b
+--R     + 
+--R              5                 3           +-+
+--R       (2B c x  + (2A c + 2B b)x  + 2A b x)\|b
+--R  /
+--R                     +--------+                          +-----------+
+--R          4       2  |   2               4       2  +-+  |   4      2
+--R     ((c x  + 2b x )\|c x  + b  + (- 2c x  - 2b x )\|b )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 986
+
+)clear all
+
+--S 987 of 3139
+t0:=(A+B*x^2)/(x^3*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         3 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 987
+
+--S 988 of 3139
+r0:=-1/3*A*sqrt(b*x^2+c*x^4)/(b*x^4)-1/3*(3*b*B-2*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^2)
+--R 
+--R
+--R                                +-----------+
+--R                       2        |   4      2
+--R        ((2A c - 3B b)x  - A b)\|c x  + b x
+--R   (2)  -------------------------------------
+--R                          2 4
+--R                        3b x
+--R                                                    Type: Expression(Integer)
+--E 988
+
+--S 989 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                  +--------+
+--R               2           4                    2  2       2  +-+ |   2
+--R       ((- 6A c  + 9B b c)x  + (- 5A b c + 12B b )x  + 4A b )\|b \|c x  + b
+--R     + 
+--R          3         2  6          2        2   4        2         3  2       3
+--R     (2A c  - 3B b c )x  + (9A b c  - 15B b c)x  + (3A b c - 12B b )x  - 4A b
+--R  /
+--R                        +--------+
+--R        2   5      3 3  |   2             2   5      3 3  +-+
+--R     (3b c x  + 12b x )\|c x  + b  + (- 9b c x  - 12b x )\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 989
+
+--S 990 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                  +--------+
+--R                   2           4                    2  2       2  |   2
+--R           ((- 2A c  + 3B b c)x  + (- 7A b c + 12B b )x  + 4A b )\|c x  + b
+--R         + 
+--R                 2           4                  2  2       2  +-+
+--R           ((6A c  - 9B b c)x  + (5A b c - 12B b )x  - 4A b )\|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                                   +--------+
+--R               2           5                    2  3       2   +-+ |   2
+--R       ((- 6A c  + 9B b c)x  + (- 5A b c + 12B b )x  + 4A b x)\|b \|c x  + b
+--R     + 
+--R          3         2  7          2        2   5        2         3  3       3
+--R     (2A c  - 3B b c )x  + (9A b c  - 15B b c)x  + (3A b c - 12B b )x  - 4A b x
+--R  /
+--R                        +--------+
+--R        2   6      3 4  |   2             2   6      3 4  +-+
+--R     (3b c x  + 12b x )\|c x  + b  + (- 9b c x  - 12b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 990
+
+--S 991 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       2 6          2            4                     2  2
+--R                 - 6B c x  + (- 6A c  - 32B b c)x  + (- 32A b c - 32B b )x
+--R               + 
+--R                        2
+--R                 - 32A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              3 8       3          2  6           2        2   4
+--R           B c x  + (A c  + 18B b c )x  + (18A b c  + 48B b c)x
+--R         + 
+--R                 2         3  2        3
+--R           (48A b c + 32B b )x  + 32A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                3 9         3          2  7             2        2   5
+--R           - B c x  + (- A c  - 18B b c )x  + (- 18A b c  - 48B b c)x
+--R         + 
+--R                   2         3  3        3
+--R           (- 48A b c - 32B b )x  - 32A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               3 9        3          2  7           2        2   5
+--R           6B c x  + (6A c  + 38B b c )x  + (38A b c  + 64B b c)x
+--R         + 
+--R                 2         3  3        3
+--R           (64A b c + 32B b )x  + 32A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                +--------+
+--R           3 10        2 8      2   6      3 4  |   2
+--R         (c x   + 18b c x  + 48b c x  + 32b x )\|c x  + b
+--R       + 
+--R              3 10        2 8      2   6      3 4  +-+
+--R         (- 6c x   - 38b c x  - 64b c x  - 32b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 991
+
+)clear all
+
+--S 992 of 3139
+t0:=(A+B*x^2)/(x^5*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         5 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 3139
+r0:=-1/5*A*sqrt(b*x^2+c*x^4)/(b*x^6)-1/15*(5*b*B-4*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^4)+2/15*c*(5*b*B-4*A*c)*sqrt(b*x^2+c*x^4)/(b^3*x^2)
+--R 
+--R
+--R                                                             +-----------+
+--R                2            4                 2  2       2  |   4      2
+--R        ((- 8A c  + 10B b c)x  + (4A b c - 5B b )x  - 3A b )\|c x  + b x
+--R   (2)  ------------------------------------------------------------------
+--R                                         3 6
+--R                                      15b x
+--R                                                    Type: Expression(Integer)
+--E 993
+
+--S 994 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 4          3  8            3         2 2  6
+--R           (40A c  - 50B b c )x  + (140A b c  - 175B b c )x
+--R         + 
+--R                 2 2        3   4          3         4  2        4
+--R           (63A b c  - 60B b c)x  + (- 4A b c + 80B b )x  + 48A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              5          4  10              4         2 3  8
+--R       (- 8A c  + 10B b c )x   + (- 100A b c  + 125B b c )x
+--R     + 
+--R                2 3         3 2  6           3 2        4   4
+--R       (- 175A b c  + 215B b c )x  + (- 55A b c  + 20B b c)x
+--R     + 
+--R               4         5  2        5
+--R       (- 20A b c - 80B b )x  - 48A b
+--R  /
+--R                                        +--------+
+--R           3 2 9       4   7       5 5  |   2
+--R       (15b c x  + 180b c x  + 240b x )\|c x  + b
+--R     + 
+--R             3 2 9       4   7       5 5  +-+
+--R       (- 75b c x  - 300b c x  - 240b x )\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 994
+
+--S 995 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    4          3  8           3         2 2  6
+--R               (8A c  - 10B b c )x  + (92A b c  - 115B b c )x
+--R             + 
+--R                     2 2         3   4           3         4  2        4
+--R               (83A b c  - 100B b c)x  + (- 28A b c + 80B b )x  + 48A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                       4          3  8              3         2 2  6
+--R               (- 40A c  + 50B b c )x  + (- 140A b c  + 175B b c )x
+--R             + 
+--R                       2 2        3   4        3         4  2        4
+--R               (- 63A b c  + 60B b c)x  + (4A b c - 80B b )x  - 48A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 4          3  9            3         2 2  7
+--R           (40A c  - 50B b c )x  + (140A b c  - 175B b c )x
+--R         + 
+--R                 2 2        3   5          3         4  3        4
+--R           (63A b c  - 60B b c)x  + (- 4A b c + 80B b )x  + 48A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              5          4  11              4         2 3  9
+--R       (- 8A c  + 10B b c )x   + (- 100A b c  + 125B b c )x
+--R     + 
+--R                2 3         3 2  7           3 2        4   5
+--R       (- 175A b c  + 215B b c )x  + (- 55A b c  + 20B b c)x
+--R     + 
+--R               4         5  3        5
+--R       (- 20A b c - 80B b )x  - 48A b x
+--R  /
+--R                                         +--------+
+--R           3 2 10       4   8       5 6  |   2
+--R       (15b c x   + 180b c x  + 240b x )\|c x  + b
+--R     + 
+--R             3 2 10       4   8       5 6  +-+
+--R       (- 75b c x   - 300b c x  - 240b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 995
+
+--S 996 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      4 10           4           3  8
+--R               - 10B c x   + (- 10A c  - 160B b c )x
+--R             + 
+--R                          3         2 2  6            2 2          3   4
+--R               (- 160A b c  - 672B b c )x  + (- 672A b c  - 1024B b c)x
+--R             + 
+--R                         3          4  2         4
+--R               (- 1024A b c - 512B b )x  - 512A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              5 12       5          4  10           4         2 3  8
+--R           B c x   + (A c  + 50B b c )x   + (50A b c  + 400B b c )x
+--R         + 
+--R                  2 3          3 2  6           3 2          4   4
+--R           (400A b c  + 1120B b c )x  + (1120A b c  + 1280B b c)x
+--R         + 
+--R                   4          5  2         5
+--R           (1280A b c + 512B b )x  + 512A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                5 13         5          4  11             4         2 3  9
+--R           - B c x   + (- A c  - 50B b c )x   + (- 50A b c  - 400B b c )x
+--R         + 
+--R                    2 3          3 2  7             3 2          4   5
+--R           (- 400A b c  - 1120B b c )x  + (- 1120A b c  - 1280B b c)x
+--R         + 
+--R                     4          5  3         5
+--R           (- 1280A b c - 512B b )x  - 512A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                5 13         5           4  11            4         2 3  9
+--R           10B c x   + (10A c  + 170B b c )x   + (170A b c  + 832B b c )x
+--R         + 
+--R                  2 3          3 2  7           3 2          4   5
+--R           (832A b c  + 1696B b c )x  + (1696A b c  + 1536B b c)x
+--R         + 
+--R                   4          5  3         5
+--R           (1536A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R             5 16        4 14       2 3 12        3 2 10        4   8       5 6
+--R           (c x   + 50b c x   + 400b c x   + 1120b c x   + 1280b c x  + 512b x )
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  5 16         4 14       2 3 12        3 2 10        4   8
+--R             - 10c x   - 170b c x   - 832b c x   - 1696b c x   - 1536b c x
+--R           + 
+--R                   5 6
+--R             - 512b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 996
+
+)clear all
+
+--S 997 of 3139
+t0:=(A+B*x^2)/(x^7*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         7 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 3139
+r0:=-1/7*A*sqrt(b*x^2+c*x^4)/(b*x^8)-1/35*(7*b*B-6*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^6)+4/105*c*(7*b*B-6*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^3*x^4)-8/105*c^2*(7*b*B-6*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^4*x^2)
+--R 
+--R
+--R   (2)
+--R               3          2  6             2        2   4         2         3  2
+--R         (48A c  - 56B b c )x  + (- 24A b c  + 28B b c)x  + (18A b c - 21B b )x
+--R       + 
+--R                3
+--R         - 15A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         4 8
+--R     105b x
+--R                                                    Type: Expression(Integer)
+--E 998
+
+--S 999 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    6           5  12               5          2 4  10
+--R           (- 336A c  + 392B b c )x   + (- 2520A b c  + 2940B b c )x
+--R         + 
+--R                     2 4          3 3  8             3 3          4 2  6
+--R           (- 4158A b c  + 4851B b c )x  + (- 1287A b c  + 1624B b c )x
+--R         + 
+--R                  4 2         5   4          5           6  2         6
+--R           (360A b c  + 560B b c)x  + (528A b c + 1344B b )x  + 960A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R             7          6  14             6          2 5  12
+--R       (48A c  - 56B b c )x   + (1176A b c  - 1372B b c )x
+--R     + 
+--R               2 5          3 4  10           3 4          4 3  8
+--R       (4410A b c  - 5145B b c )x   + (4851A b c  - 5677B b c )x
+--R     + 
+--R               4 3          5 2  6            5 2          6   4
+--R       (1113A b c  - 1736B b c )x  + (- 504A b c  - 1232B b c)x
+--R     + 
+--R                 6           7  2         7
+--R       (- 1008A b c - 1344B b )x  - 960A b
+--R  /
+--R                                                          +--------+
+--R            4 3 13        5 2 11        6   9        7 7  |   2
+--R       (105b c x   + 2520b c x   + 8400b c x  + 6720b x )\|c x  + b
+--R     + 
+--R              4 3 13        5 2 11         6   9        7 7  +-+
+--R       (- 735b c x   - 5880b c x   - 11760b c x  - 6720b x )\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 999
+
+--S 1000 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       6          5  12               5          2 4  10
+--R               (- 48A c  + 56B b c )x   + (- 1128A b c  + 1316B b c )x
+--R             + 
+--R                         2 4          3 3  8             3 3          4 2  6
+--R               (- 3282A b c  + 3829B b c )x  + (- 1569A b c  + 1848B b c )x
+--R             + 
+--R                      4 2         5   4         5           6  2         6
+--R               (456A b c  - 112B b c)x  + (48A b c + 1344B b )x  + 960A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                      6           5  12             5          2 4  10
+--R               (336A c  - 392B b c )x   + (2520A b c  - 2940B b c )x
+--R             + 
+--R                       2 4          3 3  8           3 3          4 2  6
+--R               (4158A b c  - 4851B b c )x  + (1287A b c  - 1624B b c )x
+--R             + 
+--R                        4 2         5   4            5           6  2         6
+--R               (- 360A b c  - 560B b c)x  + (- 528A b c - 1344B b )x  - 960A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    6           5  13               5          2 4  11
+--R           (- 336A c  + 392B b c )x   + (- 2520A b c  + 2940B b c )x
+--R         + 
+--R                     2 4          3 3  9             3 3          4 2  7
+--R           (- 4158A b c  + 4851B b c )x  + (- 1287A b c  + 1624B b c )x
+--R         + 
+--R                  4 2         5   5          5           6  3         6
+--R           (360A b c  + 560B b c)x  + (528A b c + 1344B b )x  + 960A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R             7          6  15             6          2 5  13
+--R       (48A c  - 56B b c )x   + (1176A b c  - 1372B b c )x
+--R     + 
+--R               2 5          3 4  11           3 4          4 3  9
+--R       (4410A b c  - 5145B b c )x   + (4851A b c  - 5677B b c )x
+--R     + 
+--R               4 3          5 2  7            5 2          6   5
+--R       (1113A b c  - 1736B b c )x  + (- 504A b c  - 1232B b c)x
+--R     + 
+--R                 6           7  3         7
+--R       (- 1008A b c - 1344B b )x  - 960A b x
+--R  /
+--R                                                           +--------+
+--R            4 3 14        5 2 12        6   10        7 8  |   2
+--R       (105b c x   + 2520b c x   + 8400b c x   + 6720b x )\|c x  + b
+--R     + 
+--R              4 3 14        5 2 12         6   10        7 8  +-+
+--R       (- 735b c x   - 5880b c x   - 11760b c x   - 6720b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+--S 1001 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      6 14           6           5  12
+--R               - 14B c x   + (- 14A c  - 448B b c )x
+--R             + 
+--R                          5          2 4  10             2 4           3 3  8
+--R               (- 448A b c  - 4032B b c )x   + (- 4032A b c  - 15360B b c )x
+--R             + 
+--R                          3 3           4 2  6              4 2           5   4
+--R               (- 15360A b c  - 28160B b c )x  + (- 28160A b c  - 24576B b c)x
+--R             + 
+--R                          5           6  2          6
+--R               (- 24576A b c - 8192B b )x  - 8192A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              7 16       7          6  14           6          2 5  12
+--R           B c x   + (A c  + 98B b c )x   + (98A b c  + 1568B b c )x
+--R         + 
+--R                   2 5          3 4  10           3 4           4 3  8
+--R           (1568A b c  + 9408B b c )x   + (9408A b c  + 26880B b c )x
+--R         + 
+--R                    4 3           5 2  6            5 2           6   4
+--R           (26880A b c  + 39424B b c )x  + (39424A b c  + 28672B b c)x
+--R         + 
+--R                    6           7  2          7
+--R           (28672A b c + 8192B b )x  + 8192A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                7 17         7          6  15             6          2 5  13
+--R           - B c x   + (- A c  - 98B b c )x   + (- 98A b c  - 1568B b c )x
+--R         + 
+--R                     2 5          3 4  11             3 4           4 3  9
+--R           (- 1568A b c  - 9408B b c )x   + (- 9408A b c  - 26880B b c )x
+--R         + 
+--R                      4 3           5 2  7              5 2           6   5
+--R           (- 26880A b c  - 39424B b c )x  + (- 39424A b c  - 28672B b c)x
+--R         + 
+--R                      6           7  3          7
+--R           (- 28672A b c - 8192B b )x  - 8192A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 17         7           6  15            6          2 5  13
+--R           14B c x   + (14A c  + 462B b c )x   + (462A b c  + 4480B b c )x
+--R         + 
+--R                   2 5           3 4  11            3 4           4 3  9
+--R           (4480A b c  + 19392B b c )x   + (19392A b c  + 43520B b c )x
+--R         + 
+--R                    4 3           5 2  7            5 2           6   5
+--R           (43520A b c  + 52736B b c )x  + (52736A b c  + 32768B b c)x
+--R         + 
+--R                    6           7  3          7
+--R           (32768A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              7 22        6 20        2 5 18        3 4 16         4 3 14
+--R             c x   + 98b c x   + 1568b c x   + 9408b c x   + 26880b c x
+--R           + 
+--R                   5 2 12         6   10        7 8
+--R             39424b c x   + 28672b c x   + 8192b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  7 22         6 20        2 5 18         3 4 16         4 3 14
+--R             - 14c x   - 462b c x   - 4480b c x   - 19392b c x   - 43520b c x
+--R           + 
+--R                     5 2 12         6   10        7 8
+--R             - 52736b c x   - 32768b c x   - 8192b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1001
+
+)clear all
+
+--S 1002 of 3139
+t0:=(A+B*x^2)/(x^9*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         9 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+--S 1003 of 3139
+r0:=-1/9*A*sqrt(b*x^2+c*x^4)/(b*x^10)-1/63*(9*b*B-8*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^8)+2/105*c*(9*b*B-8*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^3*x^6)-8/315*c^2*(9*b*B-8*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^4*x^4)+16/315*c^3*(9*b*B-8*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^5*x^2)
+--R 
+--R
+--R   (2)
+--R                  4           3  8           3        2 2  6
+--R         (- 128A c  + 144B b c )x  + (64A b c  - 72B b c )x
+--R       + 
+--R                 2 2        3   4         3         4  2        4
+--R         (- 48A b c  + 54B b c)x  + (40A b c - 45B b )x  - 35A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         5 10
+--R     315b x
+--R                                                    Type: Expression(Integer)
+--E 1003
+
+--S 1004 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   8            7  16              7           2 6  14
+--R           (1152A c  - 1296B b c )x   + (14784A b c  - 16632B b c )x
+--R         + 
+--R                    2 6           3 5  12            3 5           4 4  10
+--R           (48048A b c  - 54054B b c )x   + (51480A b c  - 57915B b c )x
+--R         + 
+--R                    4 4           5 3  8             5 3          6 2  6
+--R           (12155A b c  - 13320B b c )x  + (- 1816A b c  + 6768B b c )x
+--R         + 
+--R                   6 2           7   4           7            8  2          8
+--R           (4368A b c  + 12096B b c)x  + (9920A b c + 11520B b )x  + 8960A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                9           8  18               8          2 7  16
+--R       (- 128A c  + 144B b c )x   + (- 5184A b c  + 5832B b c )x
+--R     + 
+--R                  2 7           3 6  14              3 6           4 5  12
+--R       (- 33264A b c  + 37422B b c )x   + (- 72072A b c  + 81081B b c )x
+--R     + 
+--R                  4 5           5 4  10              5 4           6 3  8
+--R       (- 57915A b c  + 65115B b c )x   + (- 10971A b c  + 10728B b c )x
+--R     + 
+--R              6 3           7 2  6             7 2           8   4
+--R       (312A b c  - 11376B b c )x  + (- 8208A b c  - 17856B b c)x
+--R     + 
+--R                  8            9  2          9
+--R       (- 14400A b c - 11520B b )x  - 8960A b
+--R  /
+--R              5 4 17         6 3 15         7 2 13          8   11         9 9
+--R         (315b c x   + 12600b c x   + 75600b c x   + 141120b c x   + 80640b x )
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                  5 4 17         6 3 15          7 2 13          8   11
+--R           - 2835b c x   - 37800b c x   - 136080b c x   - 181440b c x
+--R         + 
+--R                   9 9
+--R           - 80640b x
+--R      *
+--R          +-+
+--R         \|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1004
+
+--S 1005 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      8           7  16             7          2 6  14
+--R               (128A c  - 144B b c )x   + (5056A b c  - 5688B b c )x
+--R             + 
+--R                        2 6           3 5  12            3 5           4 4  10
+--R               (28208A b c  - 31734B b c )x   + (43864A b c  - 49347B b c )x
+--R             + 
+--R                        4 4           5 3  8             5 3          6 2  6
+--R               (14051A b c  - 15768B b c )x  + (- 3080A b c  + 5040B b c )x
+--R             + 
+--R                     6 2          7   4           7            8  2          8
+--R             (2768A b c  + 6336B b c)x  + (5440A b c + 11520B b )x  + 8960A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                         8            7  16                7           2 6  14
+--R               (- 1152A c  + 1296B b c )x   + (- 14784A b c  + 16632B b c )x
+--R             + 
+--R                          2 6           3 5  12
+--R               (- 48048A b c  + 54054B b c )x
+--R             + 
+--R                          3 5           4 4  10
+--R               (- 51480A b c  + 57915B b c )x
+--R             + 
+--R                          4 4           5 3  8           5 3          6 2  6
+--R               (- 12155A b c  + 13320B b c )x  + (1816A b c  - 6768B b c )x
+--R             + 
+--R                         6 2           7   4             7            8  2
+--R               (- 4368A b c  - 12096B b c)x  + (- 9920A b c - 11520B b )x
+--R             + 
+--R                        8
+--R               - 8960A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                   8            7  17              7           2 6  15
+--R           (1152A c  - 1296B b c )x   + (14784A b c  - 16632B b c )x
+--R         + 
+--R                    2 6           3 5  13            3 5           4 4  11
+--R           (48048A b c  - 54054B b c )x   + (51480A b c  - 57915B b c )x
+--R         + 
+--R                    4 4           5 3  9             5 3          6 2  7
+--R           (12155A b c  - 13320B b c )x  + (- 1816A b c  + 6768B b c )x
+--R         + 
+--R                   6 2           7   5           7            8  3          8
+--R           (4368A b c  + 12096B b c)x  + (9920A b c + 11520B b )x  + 8960A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R                9           8  19               8          2 7  17
+--R       (- 128A c  + 144B b c )x   + (- 5184A b c  + 5832B b c )x
+--R     + 
+--R                  2 7           3 6  15              3 6           4 5  13
+--R       (- 33264A b c  + 37422B b c )x   + (- 72072A b c  + 81081B b c )x
+--R     + 
+--R                  4 5           5 4  11              5 4           6 3  9
+--R       (- 57915A b c  + 65115B b c )x   + (- 10971A b c  + 10728B b c )x
+--R     + 
+--R              6 3           7 2  7             7 2           8   5
+--R       (312A b c  - 11376B b c )x  + (- 8208A b c  - 17856B b c)x
+--R     + 
+--R                  8            9  3          9
+--R       (- 14400A b c - 11520B b )x  - 8960A b x
+--R  /
+--R              5 4 18         6 3 16         7 2 14          8   12         9 10
+--R         (315b c x   + 12600b c x   + 75600b c x   + 141120b c x   + 80640b x  )
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                  5 4 18         6 3 16          7 2 14          8   12
+--R           - 2835b c x   - 37800b c x   - 136080b c x   - 181440b c x
+--R         + 
+--R                   9 10
+--R           - 80640b x
+--R      *
+--R          +-+
+--R         \|b
+--R                                                    Type: Expression(Integer)
+--E 1005
+
+--S 1006 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      8 18           8           7  16
+--R               - 18B c x   + (- 18A c  - 960B b c )x
+--R             + 
+--R                          7           2 6  14
+--R               (- 960A b c  - 14784B b c )x
+--R             + 
+--R                          2 6            3 5  12
+--R               (- 14784A b c  - 101376B b c )x
+--R             + 
+--R                           3 5            4 4  10
+--R               (- 101376A b c  - 366080B b c )x
+--R             + 
+--R                           4 4            5 3  8
+--R               (- 366080A b c  - 745472B b c )x
+--R             + 
+--R                           5 3            6 2  6
+--R               (- 745472A b c  - 860160B b c )x
+--R             + 
+--R                           6 2            7   4               7             8  2
+--R               (- 860160A b c  - 524288B b c)x  + (- 524288A b c - 131072B b )x
+--R             + 
+--R                          8
+--R               - 131072A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              9 20       9           8  18            8          2 7  16
+--R           B c x   + (A c  + 162B b c )x   + (162A b c  + 4320B b c )x
+--R         + 
+--R                   2 7           3 6  14            3 6            4 5  12
+--R           (4320A b c  + 44352B b c )x   + (44352A b c  + 228096B b c )x
+--R         + 
+--R                     4 5            5 4  10             5 4             6 3  8
+--R           (228096A b c  + 658944B b c )x   + (658944A b c  + 1118208B b c )x
+--R         + 
+--R                      6 3             7 2  6              7 2            8   4
+--R           (1118208A b c  + 1105920B b c )x  + (1105920A b c  + 589824B b c)x
+--R         + 
+--R                     8             9  2            9
+--R           (589824A b c + 131072B b )x  + 131072A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                9 21         9           8  19              8          2 7  17
+--R           - B c x   + (- A c  - 162B b c )x   + (- 162A b c  - 4320B b c )x
+--R         + 
+--R                     2 7           3 6  15              3 6            4 5  13
+--R           (- 4320A b c  - 44352B b c )x   + (- 44352A b c  - 228096B b c )x
+--R         + 
+--R                       4 5            5 4  11
+--R           (- 228096A b c  - 658944B b c )x
+--R         + 
+--R                       5 4             6 3  9
+--R           (- 658944A b c  - 1118208B b c )x
+--R         + 
+--R                        6 3             7 2  7
+--R           (- 1118208A b c  - 1105920B b c )x
+--R         + 
+--R                        7 2            8   5               8             9  3
+--R           (- 1105920A b c  - 589824B b c)x  + (- 589824A b c - 131072B b )x
+--R         + 
+--R                      9
+--R           - 131072A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                9 21         9           8  19            8           2 7  17
+--R           18B c x   + (18A c  + 978B b c )x   + (978A b c  + 15744B b c )x
+--R         + 
+--R                    2 7            3 6  15             3 6            4 5  13
+--R           (15744A b c  + 116160B b c )x   + (116160A b c  + 467456B b c )x
+--R         + 
+--R                     4 5             5 4  11              5 4             6 3  9
+--R           (467456A b c  + 1111552B b c )x   + (1111552A b c  + 1605632B b c )x
+--R         + 
+--R                      6 3             7 2  7              7 2            8   5
+--R           (1605632A b c  + 1384448B b c )x  + (1384448A b c  + 655360B b c)x
+--R         + 
+--R                     8             9  3            9
+--R           (655360A b c + 131072B b )x  + 131072A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              9 28         8 26        2 7 24         3 6 22          4 5 20
+--R             c x   + 162b c x   + 4320b c x   + 44352b c x   + 228096b c x
+--R           + 
+--R                    5 4 18           6 3 16           7 2 14          8   12
+--R             658944b c x   + 1118208b c x   + 1105920b c x   + 589824b c x
+--R           + 
+--R                    9 10
+--R             131072b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  9 28         8 26         2 7 24          3 6 22
+--R             - 18c x   - 978b c x   - 15744b c x   - 116160b c x
+--R           + 
+--R                      4 5 20           5 4 18           6 3 16           7 2 14
+--R             - 467456b c x   - 1111552b c x   - 1605632b c x   - 1384448b c x
+--R           + 
+--R                      8   12          9 10
+--R             - 655360b c x   - 131072b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1006
+
+)clear all
+
+--S 1007 of 3139
+t0:=x^6*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             8      6
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1007
+
+--S 1008 of 3139
+r0:=-8/105*b^2*(6*b*B-7*A*c)*sqrt(b*x^2+c*x^4)/(c^4*x)+_
+   4/105*b*(6*b*B-7*A*c)*x*sqrt(b*x^2+c*x^4)/c^3-1/35*(6*b*B-7*A*c)*x^3*_
+   sqrt(b*x^2+c*x^4)/c^2+1/7*B*x^5*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R              3 6         3          2  4             2        2   2        2
+--R         15B c x  + (21A c  - 18B b c )x  + (- 28A b c  + 24B b c)x  + 56A b c
+--R       + 
+--R                3
+--R         - 48B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         4
+--R     105c x
+--R                                                    Type: Expression(Integer)
+--E 1008
+
+--S 1009 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     2 12              2         2   10
+--R           - 105B b c x   + (- 147A b c  - 714B b c)x
+--R         + 
+--R                    2          3  8          3 6
+--R           (- 980A b c - 840B b )x  - 1120A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                3 14         3           2  12            2          2   10
+--R           15B c x   + (21A c  + 357B b c )x   + (497A b c  + 1134B b c)x
+--R         + 
+--R                   2          3  8          3 6
+--R           (1540A b c + 840B b )x  + 1120A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                        +--------+
+--R            3 6          2 4        2   2        3  +-+ |   2              3 6
+--R       (105c x  + 2520b c x  + 8400b c x  + 6720b )\|b \|c x  + b  - 735b c x
+--R     + 
+--R              2 2 4         3   2        4
+--R       - 5880b c x  - 11760b c x  - 6720b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1009
+
+--S 1010 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      6 12           6           5  10
+--R               - 15B c x   + (- 21A c  - 342B b c )x
+--R             + 
+--R                          5         2 4  8             2 4        3 3  6
+--R               (- 476A b c  - 792B b c )x  + (- 1064A b c  - 48B b c )x
+--R             + 
+--R                        3 3         4 2  4             4 2          5   2
+--R               (- 448A b c  + 384B b c )x  + (- 2688A b c  + 2304B b c)x
+--R             + 
+--R                        5           6
+--R               - 3584A b c + 3072B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   6 12            6         2 5  10          2 5         3 4  8
+--R           105B b c x   + (147A b c  + 714B b c )x   + (980A b c  + 840B b c )x
+--R         + 
+--R                   3 4        4 3  6           4 3          5 2  4
+--R           (1176A b c  - 48B b c )x  + (1344A b c  - 1152B b c )x
+--R         + 
+--R                   5 2          6   2          6           7
+--R           (4480A b c  - 3840B b c)x  + 3584A b c - 3072B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                     6 13              6         2 5  11
+--R           - 105B b c x   + (- 147A b c  - 714B b c )x
+--R         + 
+--R                    2 5         3 4  9          3 4 7
+--R           (- 980A b c  - 840B b c )x  - 1120A b c x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 15         7           6  13            6          2 5  11
+--R           15B c x   + (21A c  + 357B b c )x   + (497A b c  + 1134B b c )x
+--R         + 
+--R                   2 5         3 4  9          3 4 7
+--R           (1540A b c  + 840B b c )x  + 1120A b c x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                           +--------+
+--R            7 7          6 5        2 5 3        3 4   +-+ |   2
+--R       (105c x  + 2520b c x  + 8400b c x  + 6720b c x)\|b \|c x  + b
+--R     + 
+--R               7 7        2 6 5         3 5 3        4 4
+--R       - 735b c x  - 5880b c x  - 11760b c x  - 6720b c x
+--R                                                    Type: Expression(Integer)
+--E 1010
+
+--S 1011 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      6 19           6           5  17
+--R               - 14B c x   + (- 14A c  - 448B b c )x
+--R             + 
+--R                          5          2 4  15             2 4           3 3  13
+--R               (- 448A b c  - 4032B b c )x   + (- 4032A b c  - 15360B b c )x
+--R             + 
+--R                          3 3           4 2  11              4 2           5   9
+--R               (- 15360A b c  - 28160B b c )x   + (- 28160A b c  - 24576B b c)x
+--R             + 
+--R                          5           6  7          6 5
+--R               (- 24576A b c - 8192B b )x  - 8192A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              7 21       7          6  19           6          2 5  17
+--R           B c x   + (A c  + 98B b c )x   + (98A b c  + 1568B b c )x
+--R         + 
+--R                   2 5          3 4  15           3 4           4 3  13
+--R           (1568A b c  + 9408B b c )x   + (9408A b c  + 26880B b c )x
+--R         + 
+--R                    4 3           5 2  11            5 2           6   9
+--R           (26880A b c  + 39424B b c )x   + (39424A b c  + 28672B b c)x
+--R         + 
+--R                    6           7  7          7 5
+--R           (28672A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                7 22         7          6  20             6          2 5  18
+--R           - B c x   + (- A c  - 98B b c )x   + (- 98A b c  - 1568B b c )x
+--R         + 
+--R                     2 5          3 4  16             3 4           4 3  14
+--R           (- 1568A b c  - 9408B b c )x   + (- 9408A b c  - 26880B b c )x
+--R         + 
+--R                      4 3           5 2  12              5 2           6   10
+--R           (- 26880A b c  - 39424B b c )x   + (- 39424A b c  - 28672B b c)x
+--R         + 
+--R                      6           7  8          7 6
+--R           (- 28672A b c - 8192B b )x  - 8192A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 22         7           6  20            6          2 5  18
+--R           14B c x   + (14A c  + 462B b c )x   + (462A b c  + 4480B b c )x
+--R         + 
+--R                   2 5           3 4  16            3 4           4 3  14
+--R           (4480A b c  + 19392B b c )x   + (19392A b c  + 43520B b c )x
+--R         + 
+--R                    4 3           5 2  12            5 2           6   10
+--R           (43520A b c  + 52736B b c )x   + (52736A b c  + 32768B b c)x
+--R         + 
+--R                    6           7  8          7 6
+--R           (32768A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              7 14        6 12        2 5 10        3 4 8         4 3 6
+--R             c x   + 98b c x   + 1568b c x   + 9408b c x  + 26880b c x
+--R           + 
+--R                   5 2 4         6   2        7
+--R             39424b c x  + 28672b c x  + 8192b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  7 14         6 12        2 5 10         3 4 8         4 3 6
+--R             - 14c x   - 462b c x   - 4480b c x   - 19392b c x  - 43520b c x
+--R           + 
+--R                     5 2 4         6   2        7
+--R             - 52736b c x  - 32768b c x  - 8192b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1011
+
+)clear all
+
+--S 1012 of 3139
+t0:=x^4*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             6      4
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1012
+
+--S 1013 of 3139
+r0:=2/15*b*(4*b*B-5*A*c)*sqrt(b*x^2+c*x^4)/(c^3*x)-1/15*(4*b*B-5*A*c)*x*_
+   sqrt(b*x^2+c*x^4)/c^2+1/5*B*x^3*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                                                         +-----------+
+--R             2 4        2           2                 2  |   4      2
+--R        (3B c x  + (5A c  - 4B b c)x  - 10A b c + 8B b )\|c x  + b x
+--R   (2)  --------------------------------------------------------------
+--R                                        3
+--R                                     15c x
+--R                                                    Type: Expression(Integer)
+--E 1013
+
+--S 1014 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                          +--------+
+--R                   8                     2  6        2 4  |   2
+--R       (- 15B b c x  + (- 25A b c - 40B b )x  - 60A b x )\|c x  + b
+--R     + 
+--R            2 10        2            8                   2  6        2 4  +-+
+--R       (3B c x   + (5A c  + 35B b c)x  + (55A b c + 40B b )x  + 60A b x )\|b
+--R  /
+--R                                      +--------+
+--R         2 4           2       2  +-+ |   2             2 4       2   2       3
+--R     (15c x  + 180b c x  + 240b )\|b \|c x  + b  - 75b c x  - 300b c x  - 240b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1014
+
+--S 1015 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     4 8          4          3  6             3       2 2  4
+--R               - 3B c x  + (- 5A c  - 32B b c )x  + (- 50A b c  - 8B b c )x
+--R             + 
+--R                     2 2        3   2         3          4
+--R               (40A b c  - 32B b c)x  + 160A b c - 128B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  4 8           4        2 3  6         2 3       3 2  4
+--R           15B b c x  + (25A b c  + 40B b c )x  + (50A b c  + 8B b c )x
+--R         + 
+--R                    3 2        4   2         4          5
+--R           (- 120A b c  + 96B b c)x  - 160A b c + 128B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                               +--------+
+--R                 4 9             4        2 3  7        2 3 5  |   2
+--R       (- 15B b c x  + (- 25A b c  - 40B b c )x  - 60A b c x )\|c x  + b
+--R     + 
+--R                 5 11        5          4  9           4        2 3  7
+--R             3B c x   + (5A c  + 35B b c )x  + (55A b c  + 40B b c )x
+--R           + 
+--R                  2 3 5
+--R             60A b c x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                           +--------+
+--R           5 5         4 3       2 3   +-+ |   2             5 5       2 4 3
+--R       (15c x  + 180b c x  + 240b c x)\|b \|c x  + b  - 75b c x  - 300b c x
+--R     + 
+--R             3 3
+--R       - 240b c x
+--R                                                    Type: Expression(Integer)
+--E 1015
+
+--S 1016 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      4 13           4           3  11
+--R               - 10B c x   + (- 10A c  - 160B b c )x
+--R             + 
+--R                          3         2 2  9            2 2          3   7
+--R               (- 160A b c  - 672B b c )x  + (- 672A b c  - 1024B b c)x
+--R             + 
+--R                         3          4  5         4 3
+--R               (- 1024A b c - 512B b )x  - 512A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              5 15       5          4  13           4         2 3  11
+--R           B c x   + (A c  + 50B b c )x   + (50A b c  + 400B b c )x
+--R         + 
+--R                  2 3          3 2  9           3 2          4   7
+--R           (400A b c  + 1120B b c )x  + (1120A b c  + 1280B b c)x
+--R         + 
+--R                   4          5  5         5 3
+--R           (1280A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                5 16         5          4  14             4         2 3  12
+--R           - B c x   + (- A c  - 50B b c )x   + (- 50A b c  - 400B b c )x
+--R         + 
+--R                    2 3          3 2  10             3 2          4   8
+--R           (- 400A b c  - 1120B b c )x   + (- 1120A b c  - 1280B b c)x
+--R         + 
+--R                     4          5  6         5 4
+--R           (- 1280A b c - 512B b )x  - 512A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                5 16         5           4  14            4         2 3  12
+--R           10B c x   + (10A c  + 170B b c )x   + (170A b c  + 832B b c )x
+--R         + 
+--R                  2 3          3 2  10           3 2          4   8
+--R           (832A b c  + 1696B b c )x   + (1696A b c  + 1536B b c)x
+--R         + 
+--R                   4          5  6         5 4
+--R           (1536A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R             5 10        4 8       2 3 6        3 2 4        4   2       5
+--R           (c x   + 50b c x  + 400b c x  + 1120b c x  + 1280b c x  + 512b )
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R             5 10         4 8       2 3 6        3 2 4        4   2       5  +-+
+--R       (- 10c x   - 170b c x  - 832b c x  - 1696b c x  - 1536b c x  - 512b )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1016
+
+)clear all
+
+--S 1017 of 3139
+t0:=x^2*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             4      2
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1017
+
+--S 1018 of 3139
+r0:=-1/3*(2*b*B-3*A*c)*sqrt(b*x^2+c*x^4)/(c^2*x)+1/3*B*x*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                               +-----------+
+--R              2                |   4      2
+--R        (B c x  + 3A c - 2B b)\|c x  + b x
+--R   (2)  ------------------------------------
+--R                          2
+--R                        3c x
+--R                                                    Type: Expression(Integer)
+--E 1018
+
+--S 1019 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         +--------+
+--R            4         2  |   2              6                 4         2  +-+
+--R   (- 3B b x  - 6A b x )\|c x  + b  + (B c x  + (3A c + 3B b)x  + 6A b x )\|b
+--R   ---------------------------------------------------------------------------
+--R                                    +--------+
+--R                       2        +-+ |   2              2      2
+--R                  (3c x  + 12b)\|b \|c x  + b  - 9b c x  - 12b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1019
+
+--S 1020 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                   +--------+
+--R                 2 4          2           2                 2  +-+ |   2
+--R           (- B c x  + (- 3A c  - 2B b c)x  - 12A b c + 8B b )\|b \|c x  + b
+--R         + 
+--R                 2 4          2       2   2        2        3
+--R           3B b c x  + (9A b c  - 2B b c)x  + 12A b c - 8B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                 +--------+
+--R                2 5         2 3  |   2
+--R       (- 3B b c x  - 6A b c x )\|c x  + b
+--R     + 
+--R           3 7        3         2  5         2 3  +-+
+--R       (B c x  + (3A c  + 3B b c )x  + 6A b c x )\|b
+--R  /
+--R                           +--------+
+--R        3 3        2   +-+ |   2            3 3      2 2
+--R     (3c x  + 12b c x)\|b \|c x  + b  - 9b c x  - 12b c x
+--R                                                    Type: Expression(Integer)
+--E 1020
+
+--S 1021 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     2 7          2            5                     2  3
+--R               - 6B c x  + (- 6A c  - 32B b c)x  + (- 32A b c - 32B b )x
+--R             + 
+--R                      2
+--R               - 32A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              3 9       3          2  7           2        2   5
+--R           B c x  + (A c  + 18B b c )x  + (18A b c  + 48B b c)x
+--R         + 
+--R                 2         3  3        3
+--R           (48A b c + 32B b )x  + 32A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                3 10         3          2  8             2        2   6
+--R           - B c x   + (- A c  - 18B b c )x  + (- 18A b c  - 48B b c)x
+--R         + 
+--R                   2         3  4        3 2
+--R           (- 48A b c - 32B b )x  - 32A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               3 10        3          2  8           2        2   6
+--R           6B c x   + (6A c  + 38B b c )x  + (38A b c  + 64B b c)x
+--R         + 
+--R                 2         3  4        3 2
+--R           (64A b c + 32B b )x  + 32A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                             +--------+
+--R           3 6        2 4      2   2      3  |   2
+--R         (c x  + 18b c x  + 48b c x  + 32b )\|c x  + b
+--R       + 
+--R              3 6        2 4      2   2      3  +-+
+--R         (- 6c x  - 38b c x  - 64b c x  - 32b )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1021
+
+)clear all
+
+--S 1022 of 3139
+t0:=(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R              2
+--R           B x  + A
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1022
+
+--S 1023 of 3139
+r0:=-A*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/sqrt(b)+B*sqrt(b*x^2+c*x^4)/(c*x)
+--R 
+--R
+--R                             +-+              +-----------+
+--R                           x\|b           +-+ |   4      2
+--R        - A c x atanh(--------------) + B\|b \|c x  + b x
+--R                       +-----------+
+--R                       |   4      2
+--R                      \|c x  + b x
+--R   (2)  ---------------------------------------------------
+--R                                  +-+
+--R                              c x\|b
+--R                                                    Type: Expression(Integer)
+--E 1023
+
+--S 1024 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   +--------+
+--R           +--------+              |   2         +-+
+--R           |   2          +-+     \|c x  + b  - \|b        2 +-+
+--R        (A\|c x  + b  - A\|b )log(------------------) + B x \|b
+--R                                           x
+--R   (3)  --------------------------------------------------------
+--R                                +--------+
+--R                            +-+ |   2
+--R                           \|b \|c x  + b  - b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1024
+
+--S 1025 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +--------+
+--R                  +--------+                |   2         +-+
+--R              +-+ |   2                    \|c x  + b  - \|b
+--R       (A c x\|b \|c x  + b  - A b c x)log(------------------)
+--R                                                    x
+--R     + 
+--R                  +--------+                        +-+
+--R              +-+ |   2                           x\|b
+--R       (A c x\|b \|c x  + b  - A b c x)atanh(--------------)
+--R                                              +-----------+
+--R                                              |   4      2
+--R                                             \|c x  + b x
+--R     + 
+--R              +--------+            +-----------+
+--R              |   2            +-+  |   4      2           3
+--R       (- B b\|c x  + b  + B b\|b )\|c x  + b x   + B b c x
+--R  /
+--R           +--------+
+--R           |   2              +-+
+--R     b c x\|c x  + b  - b c x\|b
+--R                                                    Type: Expression(Integer)
+--E 1025
+
+--S 1026 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                             +--------+
+--R                 2       +-+ |   2             4                2
+--R         ((- 2B x  - 2A)\|b \|c x  + b  + B c x  + (A c + 2B b)x  + 2A b)
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                              +--------+
+--R               5                  3           |   2
+--R       (- B c x  + (- A c - 2B b)x  - 2A b x)\|c x  + b
+--R     + 
+--R              5                 3           +-+
+--R       (2B c x  + (2A c + 2B b)x  + 2A b x)\|b
+--R  /
+--R                    +--------+                         +-----------+
+--R          3         |   2               3         +-+  |   4      2
+--R     ((c x  + 2b x)\|c x  + b  + (- 2c x  - 2b x)\|b )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1026
+
+)clear all
+
+--S 1027 of 3139
+t0:=(A+B*x^2)/(x^2*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         2 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1027
+
+--S 1028 of 3139
+r0:=-1/2*(2*b*B-A*c)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-_
+   1/2*A*sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R                                   +-+              +-----------+
+--R                     3           x\|b           +-+ |   4      2
+--R        (A c - 2B b)x atanh(--------------) - A\|b \|c x  + b x
+--R                             +-----------+
+--R                             |   4      2
+--R                            \|c x  + b x
+--R   (2)  ---------------------------------------------------------
+--R                                    3 +-+
+--R                                2b x \|b
+--R                                                    Type: Expression(Integer)
+--E 1028
+
+--S 1029 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                +--------+
+--R                           2  2 |   2
+--R           (- 2A b c + 4B b )x \|c x  + b
+--R         + 
+--R                2           4                 2  2  +-+
+--R           ((A c  - 2B b c)x  + (2A b c - 4B b )x )\|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                          +--------+
+--R               2       2  |   2                   2       2  +-+
+--R       (A b c x  + 2A b )\|c x  + b  + (- 2A b c x  - 2A b )\|b
+--R  /
+--R               +--------+
+--R       2 2 +-+ |   2          2   4     3 2
+--R     4b x \|b \|c x  + b  - 2b c x  - 4b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1029
+
+--S 1030 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------+
+--R                           3 +-+ |   2            2           5
+--R           (- 2A c + 4B b)x \|b \|c x  + b  + (A c  - 2B b c)x
+--R         + 
+--R                         2  3
+--R           (2A b c - 4B b )x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                 +--------+
+--R                           3 +-+ |   2            2           5
+--R           (- 2A c + 4B b)x \|b \|c x  + b  + (A c  - 2B b c)x
+--R         + 
+--R                         2  3
+--R           (2A b c - 4B b )x
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R             +--------+                          +-----------+
+--R             |   2                2         +-+  |   4      2
+--R       (2A b\|c x  + b  + (- A c x  - 2A b)\|b )\|c x  + b x
+--R     + 
+--R                             +--------+
+--R             3           +-+ |   2                3       2
+--R       (A c x  + 2A b x)\|b \|c x  + b  - 2A b c x  - 2A b x
+--R  /
+--R           +--------+
+--R       2 3 |   2                 5     2 3  +-+
+--R     4b x \|c x  + b  + (- 2b c x  - 4b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 1030
+
+--S 1031 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                   2 6         2            4                     2  2        2
+--R             (- B c x  + (- A c  - 12B b c)x  + (- 12A b c - 16B b )x  - 16A b )
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                2 6        2            4                   2  2        2  +-+
+--R           (5B c x  + (5A c  + 20B b c)x  + (20A b c + 16B b )x  + 16A b )\|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                2 7          2            5                     2  3        2
+--R         (- 5B c x  + (- 5A c  - 20B b c)x  + (- 20A b c - 16B b )x  - 16A b x)
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          3 9       3          2  7           2        2   5
+--R       B c x  + (A c  + 13B b c )x  + (13A b c  + 28B b c)x
+--R     + 
+--R             2         3  3        3
+--R       (28A b c + 16B b )x  + 16A b x
+--R  /
+--R                                         +--------+
+--R            2 7          5      2 3  +-+ |   2         3 9        2 7      2   5
+--R         (5c x  + 20b c x  + 16b x )\|b \|c x  + b  - c x  - 13b c x  - 28b c x
+--R       + 
+--R              3 3
+--R         - 16b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1031
+
+)clear all
+
+--S 1032 of 3139
+t0:=(A+B*x^2)/(x^4*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         4 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1032
+
+--S 1033 of 3139
+r0:=1/8*c*(4*b*B-3*A*c)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)-_
+   1/4*A*sqrt(b*x^2+c*x^4)/(b*x^5)-1/8*(4*b*B-3*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^3)
+--R 
+--R
+--R   (2)
+--R                                        +-+
+--R              2           5           x\|b
+--R       (- 3A c  + 4B b c)x atanh(--------------)
+--R                                  +-----------+
+--R                                  |   4      2
+--R                                 \|c x  + b x
+--R     + 
+--R                                    +-----------+
+--R                      2         +-+ |   4      2
+--R       ((3A c - 4B b)x  - 2A b)\|b \|c x  + b x
+--R  /
+--R       2 5 +-+
+--R     8b x \|b
+--R                                                    Type: Expression(Integer)
+--E 1033
+
+--S 1034 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                              +--------+
+--R                    3        2 2  6         2 2        3   4  |   2
+--R           ((12A b c  - 16B b c )x  + (24A b c  - 32B b c)x )\|c x  + b
+--R         + 
+--R                      4         3  8             3        2 2  6
+--R               (- 3A c  + 4B b c )x  + (- 24A b c  + 32B b c )x
+--R             + 
+--R                       2 2        3   4
+--R               (- 24A b c  + 32B b c)x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                    3       2 2  6           2 2        3   4
+--R           (- 3A b c  + 4B b c )x  + (- 22A b c  + 32B b c)x
+--R         + 
+--R                  3         4  2        4
+--R           (- 8A b c + 32B b )x  + 16A b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R              3        2 2  6         2 2        3   4        4 2        4  +-+
+--R     ((12A b c  - 16B b c )x  + (28A b c  - 48B b c)x  - 32B b x  - 16A b )\|b
+--R  /
+--R                             +--------+
+--R         3   6      4 4  +-+ |   2          3 2 8      4   6      5 4
+--R     (32b c x  + 64b x )\|b \|c x  + b  - 8b c x  - 64b c x  - 64b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1034
+
+--S 1035 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                +--------+
+--R                  3          2  7           2        2   5  +-+ |   2
+--R           ((12A c  - 16B b c )x  + (24A b c  - 32B b c)x )\|b \|c x  + b
+--R         + 
+--R                  4         3  9             3        2 2  7
+--R           (- 3A c  + 4B b c )x  + (- 24A b c  + 32B b c )x
+--R         + 
+--R                   2 2        3   5
+--R           (- 24A b c  + 32B b c)x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                                                +--------+
+--R                  3          2  7           2        2   5  +-+ |   2
+--R           ((12A c  - 16B b c )x  + (24A b c  - 32B b c)x )\|b \|c x  + b
+--R         + 
+--R                  4         3  9             3        2 2  7
+--R           (- 3A c  + 4B b c )x  + (- 24A b c  + 32B b c )x
+--R         + 
+--R                   2 2        3   5
+--R           (- 24A b c  + 32B b c)x
+--R      *
+--R                      +-+
+--R                    x\|b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                        2        2   4           2         3  2        3
+--R             ((- 12A b c  + 16B b c)x  + (- 16A b c + 32B b )x  + 16A b )
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    3         2  6           2        2   4
+--R               (3A c  - 4B b c )x  + (22A b c  - 32B b c)x
+--R             + 
+--R                    2         3  2        3
+--R               (8A b c - 32B b )x  - 16A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  3         2  7             2        2   5
+--R           (- 3A c  + 4B b c )x  + (- 22A b c  + 32B b c)x
+--R         + 
+--R                  2         3  3        3
+--R           (- 8A b c + 32B b )x  + 16A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R               3        2 2  7         2 2        3   5        4 3        4
+--R       (12A b c  - 16B b c )x  + (28A b c  - 48B b c)x  - 32B b x  - 16A b x
+--R  /
+--R                         +--------+
+--R         3   7      4 5  |   2             2 2 9      3   7      4 5  +-+
+--R     (32b c x  + 64b x )\|c x  + b  + (- 8b c x  - 64b c x  - 64b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 1035
+
+--S 1036 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    4 10         4          3  8             3         2 2  6
+--R               - B c x   + (- A c  - 40B b c )x  + (- 40A b c  - 240B b c )x
+--R             + 
+--R                        2 2         3   4            3          4  2         4
+--R               (- 240A b c  - 448B b c)x  + (- 448A b c - 256B b )x  - 256A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                   4 10        4           3  8            3         2 2  6
+--R               9B c x   + (9A c  + 120B b c )x  + (120A b c  + 432B b c )x
+--R             + 
+--R                      2 2         3   4          3          4  2         4
+--R               (432A b c  + 576B b c)x  + (576A b c + 256B b )x  + 256A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 4 11          4           3  9              3         2 2  7
+--R           - 9B c x   + (- 9A c  - 120B b c )x  + (- 120A b c  - 432B b c )x
+--R         + 
+--R                    2 2         3   5            3          4  3         4
+--R           (- 432A b c  - 576B b c)x  + (- 576A b c - 256B b )x  - 256A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          5 13       5          4  11           4         2 3  9
+--R       B c x   + (A c  + 41B b c )x   + (41A b c  + 280B b c )x
+--R     + 
+--R              2 3         3 2  7          3 2         4   5
+--R       (280A b c  + 688B b c )x  + (688A b c  + 704B b c)x
+--R     + 
+--R              4          5  3         5
+--R       (704A b c + 256B b )x  + 256A b x
+--R  /
+--R                                                                     +--------+
+--R            4 13         3 11       2 2 9       3   7       4 5  +-+ |   2
+--R         (9c x   + 120b c x   + 432b c x  + 576b c x  + 256b x )\|b \|c x  + b
+--R       + 
+--R            5 15        4 13       2 3 11       3 2 9       4   7       5 5
+--R         - c x   - 41b c x   - 280b c x   - 688b c x  - 704b c x  - 256b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1036
+
+)clear all
+
+--S 1037 of 3139
+t0:=x^9*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  9      7
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1037
+
+--S 1038 of 3139
+r0:=-5/16*b^2*(7*b*B-6*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(9/2)-_
+   (b*B-A*c)*x^8/(b*c*sqrt(b*x^2+c*x^4))+5/16*b*(7*b*B-6*A*c)*_
+   sqrt(b*x^2+c*x^4)/c^4-5/24*(7*b*B-6*A*c)*x^2*sqrt(b*x^2+c*x^4)/c^3+_
+   1/6*(7*b*B-6*A*c)*x^4*sqrt(b*x^2+c*x^4)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R                           +-----------+           2 +-+
+--R             2          3  |   4      2           x \|c
+--R       (90A b c - 105B b )\|c x  + b x  atanh(--------------)
+--R                                               +-----------+
+--R                                               |   4      2
+--R                                              \|c x  + b x
+--R     + 
+--R               3 8         3          2  6             2        2   4
+--R           8B c x  + (12A c  - 14B b c )x  + (- 30A b c  + 35B b c)x
+--R         + 
+--R                   2          3  2
+--R           (- 90A b c + 105B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R              +-----------+
+--R        4 +-+ |   4      2
+--R     48c \|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1038
+
+--S 1039 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        2 4         3 3  6           3 3          4 2  4
+--R                 (630A b c  - 735B b c )x  + (5040A b c  - 5880B b c )x
+--R               + 
+--R                          4 2           5   2          5           6
+--R                 (10080A b c  - 11760B b c)x  + 5760A b c - 6720B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     2 5         3 4  8             3 4          4 3  6
+--R             (- 90A b c  + 105B b c )x  + (- 2250A b c  + 2625B b c )x
+--R           + 
+--R                       4 3           5 2  4              5 2           6   2
+--R             (- 9360A b c  + 10920B b c )x  + (- 12960A b c  + 15120B b c)x
+--R           + 
+--R                      6           7
+--R             - 5760A b c + 6720B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                   6 13           6           5  11
+--R             - 8B c x   + (- 12A c  - 178B b c )x
+--R           + 
+--R                        5         2 4  9            2 4         3 3  7
+--R             (- 258A b c  - 339B b c )x  + (- 150A b c  - 337B b c )x
+--R           + 
+--R                     3 3          4 2  5           4 2           5   3
+--R             (3792A b c  - 4424B b c )x  + (9120A b c  - 10640B b c)x
+--R           + 
+--R                     5           6
+--R             (5760A b c - 6720B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                  6 13         6           5  11            5         2 4  9
+--R             56B c x   + (84A c  + 350B b c )x   + (462A b c  + 357B b c )x
+--R           + 
+--R                      2 4          3 3  7             3 3          4 2  5
+--R             (- 966A b c  + 1639B b c )x  + (- 7632A b c  + 8904B b c )x
+--R           + 
+--R                        4 2           5   3             5           6
+--R             (- 12000A b c  + 14000B b c)x  + (- 5760A b c + 6720B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                                                                +--------+
+--R              7 6          6 4        2 5 2        3 4  +-+ +-+ |   2
+--R         (336c x  + 2688b c x  + 5376b c x  + 3072b c )\|b \|c \|c x  + b
+--R       + 
+--R               8 8          7 6        2 6 4        3 5 2        4 4  +-+
+--R         (- 48c x  - 1200b c x  - 4992b c x  - 6912b c x  - 3072b c )\|c
+--R     ,
+--R
+--R                         2 4          3 3  6            3 3           4 2  4
+--R                 (1260A b c  - 1470B b c )x  + (10080A b c  - 11760B b c )x
+--R               + 
+--R                          4 2           5   2           5            6
+--R                 (20160A b c  - 23520B b c)x  + 11520A b c - 13440B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                      2 5         3 4  8             3 4          4 3  6
+--R             (- 180A b c  + 210B b c )x  + (- 4500A b c  + 5250B b c )x
+--R           + 
+--R                        4 3           5 2  4              5 2           6   2
+--R             (- 18720A b c  + 21840B b c )x  + (- 25920A b c  + 30240B b c)x
+--R           + 
+--R                       6            7
+--R             - 11520A b c + 13440B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                   6 13           6           5  11
+--R             - 8B c x   + (- 12A c  - 178B b c )x
+--R           + 
+--R                        5         2 4  9            2 4         3 3  7
+--R             (- 258A b c  - 339B b c )x  + (- 150A b c  - 337B b c )x
+--R           + 
+--R                     3 3          4 2  5           4 2           5   3
+--R             (3792A b c  - 4424B b c )x  + (9120A b c  - 10640B b c)x
+--R           + 
+--R                     5           6
+--R             (5760A b c - 6720B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                  6 13         6           5  11            5         2 4  9
+--R             56B c x   + (84A c  + 350B b c )x   + (462A b c  + 357B b c )x
+--R           + 
+--R                      2 4          3 3  7             3 3          4 2  5
+--R             (- 966A b c  + 1639B b c )x  + (- 7632A b c  + 8904B b c )x
+--R           + 
+--R                        4 2           5   3             5           6
+--R             (- 12000A b c  + 14000B b c)x  + (- 5760A b c + 6720B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                                                                  +--------+
+--R              7 6          6 4        2 5 2        3 4  +---+ +-+ |   2
+--R         (336c x  + 2688b c x  + 5376b c x  + 3072b c )\|- c \|b \|c x  + b
+--R       + 
+--R               8 8          7 6        2 6 4        3 5 2        4 4  +---+
+--R         (- 48c x  - 1200b c x  - 4992b c x  - 6912b c x  - 3072b c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1039
+
+--S 1040 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2 4         3 3  6           3 3          4 2  4
+--R               (630A b c  - 735B b c )x  + (5040A b c  - 5880B b c )x
+--R             + 
+--R                        4 2           5   2          5           6
+--R               (10080A b c  - 11760B b c)x  + 5760A b c - 6720B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   2 5         3 4  8             3 4          4 3  6
+--R           (- 90A b c  + 105B b c )x  + (- 2250A b c  + 2625B b c )x
+--R         + 
+--R                     4 3           5 2  4              5 2           6   2
+--R           (- 9360A b c  + 10920B b c )x  + (- 12960A b c  + 15120B b c)x
+--R         + 
+--R                    6           7
+--R           - 5760A b c + 6720B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                        2 4         3 3  6             3 3          4 2  4
+--R               (- 630A b c  + 735B b c )x  + (- 5040A b c  + 5880B b c )x
+--R             + 
+--R                          4 2           5   2          5           6
+--R               (- 10080A b c  + 11760B b c)x  - 5760A b c + 6720B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                 2 5         3 4  8           3 4          4 3  6
+--R           (90A b c  - 105B b c )x  + (2250A b c  - 2625B b c )x
+--R         + 
+--R                   4 3           5 2  4            5 2           6   2
+--R           (9360A b c  - 10920B b c )x  + (12960A b c  - 15120B b c)x
+--R         + 
+--R                  6           7
+--R           5760A b c - 6720B b
+--R      *
+--R          +-----------+           2 +-+
+--R          |   4      2           x \|c
+--R         \|c x  + b x  atanh(--------------)
+--R                              +-----------+
+--R                              |   4      2
+--R                             \|c x  + b x
+--R     + 
+--R                     6 13           6           5  11
+--R               - 8B c x   + (- 12A c  - 178B b c )x
+--R             + 
+--R                          5         2 4  9            2 4         3 3  7
+--R               (- 258A b c  - 339B b c )x  + (- 150A b c  - 337B b c )x
+--R             + 
+--R                       3 3          4 2  5           4 2           5   3
+--R               (3792A b c  - 4424B b c )x  + (9120A b c  - 10640B b c)x
+--R             + 
+--R                       5           6
+--R               (5760A b c - 6720B b )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|c x  + b
+--R         + 
+--R                    6 13         6           5  11            5         2 4  9
+--R               56B c x   + (84A c  + 350B b c )x   + (462A b c  + 357B b c )x
+--R             + 
+--R                        2 4          3 3  7             3 3          4 2  5
+--R               (- 966A b c  + 1639B b c )x  + (- 7632A b c  + 8904B b c )x
+--R             + 
+--R                          4 2           5   3             5           6
+--R               (- 12000A b c  + 14000B b c)x  + (- 5760A b c + 6720B b )x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  6 14           6           5  12
+--R           - 56B c x   + (- 84A c  - 350B b c )x
+--R         + 
+--R                      5         2 4  10          2 4          3 3  8
+--R           (- 462A b c  - 357B b c )x   + (966A b c  - 1639B b c )x
+--R         + 
+--R                   3 3          4 2  6            4 2           5   4
+--R           (7632A b c  - 8904B b c )x  + (12000A b c  - 14000B b c)x
+--R         + 
+--R                   5           6  2
+--R           (5760A b c - 6720B b )x
+--R      *
+--R                  +--------+
+--R          +-+ +-+ |   2
+--R         \|b \|c \|c x  + b
+--R     + 
+--R               7 16         7           6  14            6         2 5  12
+--R           8B c x   + (12A c  + 186B b c )x   + (270A b c  + 517B b c )x
+--R         + 
+--R                  2 5         3 4  10             3 4          4 3  8
+--R           (408A b c  + 676B b c )x   + (- 3642A b c  + 4761B b c )x
+--R         + 
+--R                      4 3           5 2  6              5 2           6   4
+--R           (- 12912A b c  + 15064B b c )x  + (- 14880A b c  + 17360B b c)x
+--R         + 
+--R                     6           7  2
+--R           (- 5760A b c + 6720B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                                                +--------+
+--R              7 6          6 4        2 5 2        3 4  +-+ +-+ |   2
+--R         (336c x  + 2688b c x  + 5376b c x  + 3072b c )\|b \|c \|c x  + b
+--R       + 
+--R               8 8          7 6        2 6 4        3 5 2        4 4  +-+
+--R         (- 48c x  - 1200b c x  - 4992b c x  - 6912b c x  - 3072b c )\|c
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1040
+
+--S 1041 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          8 24           8           7  22
+--R                   - 17B c x   + (- 17A c  - 816B b c )x
+--R                 + 
+--R                              7           2 6  20
+--R                   (- 816A b c  - 11424B b c )x
+--R                 + 
+--R                              2 6           3 5  18
+--R                   (- 11424A b c  - 71808B b c )x
+--R                 + 
+--R                              3 5            4 4  16
+--R                   (- 71808A b c  - 239360B b c )x
+--R                 + 
+--R                               4 4            5 3  14
+--R                   (- 239360A b c  - 452608B b c )x
+--R                 + 
+--R                               5 3            6 2  12
+--R                   (- 452608A b c  - 487424B b c )x
+--R                 + 
+--R                               6 2            7   10
+--R                   (- 487424A b c  - 278528B b c)x
+--R                 + 
+--R                               7            8  8           8 6
+--R                   (- 278528A b c - 65536B b )x  - 65536A b x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  9 25       9           8  23            8          2 7  21
+--R               B c x   + (A c  + 144B b c )x   + (144A b c  + 3360B b c )x
+--R             + 
+--R                       2 7           3 6  19            3 6            4 5  17
+--R               (3360A b c  + 29568B b c )x   + (29568A b c  + 126720B b c )x
+--R             + 
+--R                         4 5            5 4  15
+--R               (126720A b c  + 292864B b c )x
+--R             + 
+--R                         5 4            6 3  13
+--R               (292864A b c  + 372736B b c )x
+--R             + 
+--R                         6 3            7 2  11             7 2           8   9
+--R               (372736A b c  + 245760B b c )x   + (245760A b c  + 65536B b c)x
+--R             + 
+--R                       8   7
+--R               65536A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  9 26       9           8  24            8          2 7  22
+--R               B c x   + (A c  + 145B b c )x   + (145A b c  + 3504B b c )x
+--R             + 
+--R                       2 7           3 6  20            3 6            4 5  18
+--R               (3504A b c  + 32928B b c )x   + (32928A b c  + 156288B b c )x
+--R             + 
+--R                         4 5            5 4  16
+--R               (156288A b c  + 419584B b c )x
+--R             + 
+--R                         5 4            6 3  14
+--R               (419584A b c  + 665600B b c )x
+--R             + 
+--R                         6 3            7 2  12
+--R               (665600A b c  + 618496B b c )x
+--R             + 
+--R                         7 2            8   10             8            9  8
+--R               (618496A b c  + 311296B b c)x   + (311296A b c + 65536B b )x
+--R             + 
+--R                       9 6
+--R               65536A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      9 25           9           8  23
+--R               - 17B c x   + (- 17A c  - 816B b c )x
+--R             + 
+--R                          8           2 7  21              2 7           3 6  19
+--R               (- 816A b c  - 11424B b c )x   + (- 11424A b c  - 71808B b c )x
+--R             + 
+--R                          3 6            4 5  17
+--R               (- 71808A b c  - 239360B b c )x
+--R             + 
+--R                           4 5            5 4  15
+--R               (- 239360A b c  - 452608B b c )x
+--R             + 
+--R                           5 4            6 3  13
+--R               (- 452608A b c  - 487424B b c )x
+--R             + 
+--R                           6 3            7 2  11
+--R               (- 487424A b c  - 278528B b c )x
+--R             + 
+--R                           7 2           8   9           8   7
+--R               (- 278528A b c  - 65536B b c)x  - 65536A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    9 27         9           8  25
+--R               - B c x   + (- A c  - 145B b c )x
+--R             + 
+--R                          8          2 7  23             2 7           3 6  21
+--R               (- 145A b c  - 3504B b c )x   + (- 3504A b c  - 32928B b c )x
+--R             + 
+--R                          3 6            4 5  19
+--R               (- 32928A b c  - 156288B b c )x
+--R             + 
+--R                           4 5            5 4  17
+--R               (- 156288A b c  - 419584B b c )x
+--R             + 
+--R                           5 4            6 3  15
+--R               (- 419584A b c  - 665600B b c )x
+--R             + 
+--R                           6 3            7 2  13
+--R               (- 665600A b c  - 618496B b c )x
+--R             + 
+--R                           7 2            8   11               8            9  9
+--R               (- 618496A b c  - 311296B b c)x   + (- 311296A b c - 65536B b )x
+--R             + 
+--R                         9 7
+--R               - 65536A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    9 26         9           8  24
+--R               17B c x   + (17A c  + 816B b c )x
+--R             + 
+--R                        8           2 7  22            2 7           3 6  20
+--R               (816A b c  + 11424B b c )x   + (11424A b c  + 71808B b c )x
+--R             + 
+--R                        3 6            4 5  18
+--R               (71808A b c  + 239360B b c )x
+--R             + 
+--R                         4 5            5 4  16
+--R               (239360A b c  + 452608B b c )x
+--R             + 
+--R                         5 4            6 3  14
+--R               (452608A b c  + 487424B b c )x
+--R             + 
+--R                         6 3            7 2  12             7 2           8   10
+--R               (487424A b c  + 278528B b c )x   + (278528A b c  + 65536B b c)x
+--R             + 
+--R                       8   8
+--R               65536A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                9 27         9           8  25            8           2 7  23
+--R           17B c x   + (17A c  + 833B b c )x   + (833A b c  + 12240B b c )x
+--R         + 
+--R                    2 7           3 6  21            3 6            4 5  19
+--R           (12240A b c  + 83232B b c )x   + (83232A b c  + 311168B b c )x
+--R         + 
+--R                     4 5            5 4  17             5 4            6 3  15
+--R           (311168A b c  + 691968B b c )x   + (691968A b c  + 940032B b c )x
+--R         + 
+--R                     6 3            7 2  13             7 2            8   11
+--R           (940032A b c  + 765952B b c )x   + (765952A b c  + 344064B b c)x
+--R         + 
+--R                     8            9  9           9 7
+--R           (344064A b c + 65536B b )x  + 65536A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            10 28         10           9  26              9          2 8  24
+--R       - B c  x   + (- A c   - 145B b c )x   + (- 145A b c  - 3504B b c )x
+--R     + 
+--R                 2 8           3 7  22              3 7            4 6  20
+--R       (- 3504A b c  - 32928B b c )x   + (- 32928A b c  - 156288B b c )x
+--R     + 
+--R                   4 6            5 5  18               5 5            6 4  16
+--R       (- 156288A b c  - 419584B b c )x   + (- 419584A b c  - 665600B b c )x
+--R     + 
+--R                   6 4            7 3  14               7 3            8 2  12
+--R       (- 665600A b c  - 618496B b c )x   + (- 618496A b c  - 311296B b c )x
+--R     + 
+--R                   8 2           9   10           9   8
+--R       (- 311296A b c  - 65536B b c)x   - 65536A b c x
+--R  /
+--R                  10 20         9 18        2 8 16         3 7 14
+--R                 c  x   + 146b c x   + 3649b c x   + 36432b c x
+--R               + 
+--R                        4 6 12          5 5 10           6 4 8           7 3 6
+--R                 189216b c x   + 575872b c x   + 1085184b c x  + 1284096b c x
+--R               + 
+--R                        8 2 4          9   2         10
+--R                 929792b c x  + 376832b c x  + 65536b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                      10 19         9 17         2 8 15         3 7 13
+--R                 - 17c  x   - 833b c x   - 12240b c x   - 83232b c x
+--R               + 
+--R                          4 6 11          5 5 9          6 4 7          7 3 5
+--R                 - 311168b c x   - 691968b c x  - 940032b c x  - 765952b c x
+--R               + 
+--R                          8 2 3         9
+--R                 - 344064b c x  - 65536b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  10 20         9 18         2 8 16         3 7 14
+--R             - 17c  x   - 850b c x   - 13073b c x   - 95472b c x
+--R           + 
+--R                      4 6 12           5 5 10           6 4 8           7 3 6
+--R             - 394400b c x   - 1003136b c x   - 1632000b c x  - 1705984b c x
+--R           + 
+--R                       8 2 4          9   2         10
+--R             - 1110016b c x  - 409600b c x  - 65536b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          11 21         10 19        2 9 17         3 8 15          4 7 13
+--R         c  x   + 146b c  x   + 3649b c x   + 36432b c x   + 189216b c x
+--R       + 
+--R                5 6 11           6 5 9           7 4 7          8 3 5
+--R         575872b c x   + 1085184b c x  + 1284096b c x  + 929792b c x
+--R       + 
+--R                9 2 3         10
+--R         376832b c x  + 65536b  c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1041
+
+--S 1042 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        2 4         3 3  6             3 3          4 2  4
+--R               (- 630A b c  + 735B b c )x  + (- 5040A b c  + 5880B b c )x
+--R             + 
+--R                          4 2           5   2          5           6
+--R               (- 10080A b c  + 11760B b c)x  - 5760A b c + 6720B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                     2 5         3 4  8           3 4          4 3  6
+--R               (90A b c  - 105B b c )x  + (2250A b c  - 2625B b c )x
+--R             + 
+--R                       4 3           5 2  4            5 2           6   2
+--R               (9360A b c  - 10920B b c )x  + (12960A b c  - 15120B b c)x
+--R             + 
+--R                      6           7
+--R               5760A b c - 6720B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R          +-----------+           2 +-+
+--R          |   4      2           x \|c
+--R         \|c x  + b x  atanh(--------------)
+--R                              +-----------+
+--R                              |   4      2
+--R                             \|c x  + b x
+--R     + 
+--R                       2 4          3 3  6            3 3           4 2  4
+--R               (1260A b c  - 1470B b c )x  + (10080A b c  - 11760B b c )x
+--R             + 
+--R                        4 2           5   2           5            6
+--R               (20160A b c  - 23520B b c)x  + 11520A b c - 13440B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                        2 5         3 4  8             3 4          4 3  6
+--R               (- 180A b c  + 210B b c )x  + (- 4500A b c  + 5250B b c )x
+--R             + 
+--R                          4 3           5 2  4              5 2           6   2
+--R               (- 18720A b c  + 21840B b c )x  + (- 25920A b c  + 30240B b c)x
+--R             + 
+--R                         6            7
+--R               - 11520A b c + 13440B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                   +--------+
+--R          +-----------+      +---+ |   2         +---+ +-+
+--R          |   4      2      \|- c \|c x  + b  - \|- c \|b
+--R         \|c x  + b x  atan(------------------------------)
+--R                                          c x
+--R     + 
+--R                     6 13           6           5  11
+--R               - 8B c x   + (- 12A c  - 178B b c )x
+--R             + 
+--R                          5         2 4  9            2 4         3 3  7
+--R               (- 258A b c  - 339B b c )x  + (- 150A b c  - 337B b c )x
+--R             + 
+--R                       3 3          4 2  5           4 2           5   3
+--R               (3792A b c  - 4424B b c )x  + (9120A b c  - 10640B b c)x
+--R             + 
+--R                       5           6
+--R               (5760A b c - 6720B b )x
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b
+--R         + 
+--R                    6 13         6           5  11            5         2 4  9
+--R               56B c x   + (84A c  + 350B b c )x   + (462A b c  + 357B b c )x
+--R             + 
+--R                        2 4          3 3  7             3 3          4 2  5
+--R               (- 966A b c  + 1639B b c )x  + (- 7632A b c  + 8904B b c )x
+--R             + 
+--R                          4 2           5   3             5           6
+--R               (- 12000A b c  + 14000B b c)x  + (- 5760A b c + 6720B b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|b \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  6 14           6           5  12
+--R           - 56B c x   + (- 84A c  - 350B b c )x
+--R         + 
+--R                      5         2 4  10          2 4          3 3  8
+--R           (- 462A b c  - 357B b c )x   + (966A b c  - 1639B b c )x
+--R         + 
+--R                   3 3          4 2  6            4 2           5   4
+--R           (7632A b c  - 8904B b c )x  + (12000A b c  - 14000B b c)x
+--R         + 
+--R                   5           6  2
+--R           (5760A b c - 6720B b )x
+--R      *
+--R                        +--------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|b \|c \|c x  + b
+--R     + 
+--R               7 16         7           6  14            6         2 5  12
+--R           8B c x   + (12A c  + 186B b c )x   + (270A b c  + 517B b c )x
+--R         + 
+--R                  2 5         3 4  10             3 4          4 3  8
+--R           (408A b c  + 676B b c )x   + (- 3642A b c  + 4761B b c )x
+--R         + 
+--R                      4 3           5 2  6              5 2           6   4
+--R           (- 12912A b c  + 15064B b c )x  + (- 14880A b c  + 17360B b c)x
+--R         + 
+--R                     6           7  2
+--R           (- 5760A b c + 6720B b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                                                                      +--------+
+--R              7 6          6 4        2 5 2        3 4  +---+ +-+ +-+ |   2
+--R         (336c x  + 2688b c x  + 5376b c x  + 3072b c )\|- c \|b \|c \|c x  + b
+--R       + 
+--R               8 8          7 6        2 6 4        3 5 2        4 4  +---+ +-+
+--R         (- 48c x  - 1200b c x  - 4992b c x  - 6912b c x  - 3072b c )\|- c \|c
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1042
+
+--S 1043 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      6 20           6           5  18
+--R               - 14B c x   + (- 14A c  - 448B b c )x
+--R             + 
+--R                          5          2 4  16             2 4           3 3  14
+--R               (- 448A b c  - 4032B b c )x   + (- 4032A b c  - 15360B b c )x
+--R             + 
+--R                          3 3           4 2  12
+--R               (- 15360A b c  - 28160B b c )x
+--R             + 
+--R                          4 2           5   10              5           6  8
+--R               (- 28160A b c  - 24576B b c)x   + (- 24576A b c - 8192B b )x
+--R             + 
+--R                        6 6
+--R               - 8192A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              7 22       7          6  20           6          2 5  18
+--R           B c x   + (A c  + 98B b c )x   + (98A b c  + 1568B b c )x
+--R         + 
+--R                   2 5          3 4  16           3 4           4 3  14
+--R           (1568A b c  + 9408B b c )x   + (9408A b c  + 26880B b c )x
+--R         + 
+--R                    4 3           5 2  12            5 2           6   10
+--R           (26880A b c  + 39424B b c )x   + (39424A b c  + 28672B b c)x
+--R         + 
+--R                    6           7  8          7 6
+--R           (28672A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                7 23         7          6  21             6          2 5  19
+--R           - B c x   + (- A c  - 98B b c )x   + (- 98A b c  - 1568B b c )x
+--R         + 
+--R                     2 5          3 4  17             3 4           4 3  15
+--R           (- 1568A b c  - 9408B b c )x   + (- 9408A b c  - 26880B b c )x
+--R         + 
+--R                      4 3           5 2  13              5 2           6   11
+--R           (- 26880A b c  - 39424B b c )x   + (- 39424A b c  - 28672B b c)x
+--R         + 
+--R                      6           7  9          7 7
+--R           (- 28672A b c - 8192B b )x  - 8192A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 23         7           6  21            6          2 5  19
+--R           14B c x   + (14A c  + 462B b c )x   + (462A b c  + 4480B b c )x
+--R         + 
+--R                   2 5           3 4  17            3 4           4 3  15
+--R           (4480A b c  + 19392B b c )x   + (19392A b c  + 43520B b c )x
+--R         + 
+--R                    4 3           5 2  13            5 2           6   11
+--R           (43520A b c  + 52736B b c )x   + (52736A b c  + 32768B b c)x
+--R         + 
+--R                    6           7  9          7 7
+--R           (32768A b c + 8192B b )x  + 8192A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              8 16        7 14        2 6 12         3 5 10         4 4 8
+--R             c x   + 99b c x   + 1666b c x   + 10976b c x   + 36288b c x
+--R           + 
+--R                   5 3 6         6 2 4         7   2        8
+--R             66304b c x  + 68096b c x  + 36864b c x  + 8192b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  8 16         7 14        2 6 12         3 5 10         4 4 8
+--R             - 14c x   - 476b c x   - 4942b c x   - 23872b c x   - 62912b c x
+--R           + 
+--R                     5 3 6         6 2 4         7   2        8
+--R             - 96256b c x  - 85504b c x  - 40960b c x  - 8192b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1043
+
+)clear all
+
+--S 1044 of 3139
+t0:=x^7*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  7      5
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1044
+
+--S 1045 of 3139
+r0:=3/8*b*(5*b*B-4*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(7/2)-_
+   (b*B-A*c)*x^6/(b*c*sqrt(b*x^2+c*x^4))-3/8*(5*b*B-4*A*c)*_
+   sqrt(b*x^2+c*x^4)/c^3+1/4*(5*b*B-4*A*c)*x^2*sqrt(b*x^2+c*x^4)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R                            +-----------+           2 +-+
+--R                         2  |   4      2           x \|c
+--R       (- 12A b c + 15B b )\|c x  + b x  atanh(--------------)
+--R                                                +-----------+
+--R                                                |   4      2
+--R                                               \|c x  + b x
+--R     + 
+--R            2 6        2           4                   2  2  +-+
+--R       (2B c x  + (4A c  - 5B b c)x  + (12A b c - 15B b )x )\|c
+--R  /
+--R             +-----------+
+--R       3 +-+ |   4      2
+--R     8c \|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1045
+
+--S 1046 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         3        2 2  4          2 2         3   2         3
+--R                 (60A b c  - 75B b c )x  + (240A b c  - 300B b c)x  + 192A b c
+--R               + 
+--R                         4
+--R                 - 240B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                       4        2 3  6            2 3         3 2  4
+--R             (- 12A b c  + 15B b c )x  + (- 156A b c  + 195B b c )x
+--R           + 
+--R                      3 2         4   2         4          5
+--R             (- 336A b c  + 420B b c)x  - 192A b c + 240B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                   4 9          4          3  7             3        2 2  5
+--R             - 2B c x  + (- 4A c  - 19B b c )x  + (- 60A b c  + 43B b c )x
+--R           + 
+--R                      2 2         3   3            3          4
+--R             (- 208A b c  + 260B b c)x  + (- 192A b c + 240B b )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|c \|c x  + b
+--R       + 
+--R                  4 9         4          3  7            3         2 2  5
+--R             10B c x  + (20A c  + 15B b c )x  + (140A b c  - 143B b c )x
+--R           + 
+--R                    2 2         3   3          3          4
+--R             (304A b c  - 380B b c)x  + (192A b c - 240B b )x
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R    /
+--R                                                +--------+
+--R             5 4         4 2       2 3  +-+ +-+ |   2
+--R         (40c x  + 160b c x  + 128b c )\|b \|c \|c x  + b
+--R       + 
+--R              6 6         5 4       2 4 2       3 3  +-+
+--R         (- 8c x  - 104b c x  - 224b c x  - 128b c )\|c
+--R     ,
+--R
+--R                            3         2 2  4            2 2         3   2
+--R                 (- 120A b c  + 150B b c )x  + (- 480A b c  + 600B b c)x
+--R               + 
+--R                         3          4
+--R                 - 384A b c + 480B b
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|b \|c x  + b
+--R           + 
+--R                     4        2 3  6          2 3         3 2  4
+--R             (24A b c  - 30B b c )x  + (312A b c  - 390B b c )x
+--R           + 
+--R                    3 2         4   2         4          5
+--R             (672A b c  - 840B b c)x  + 384A b c - 480B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                   4 9          4          3  7             3        2 2  5
+--R             - 2B c x  + (- 4A c  - 19B b c )x  + (- 60A b c  + 43B b c )x
+--R           + 
+--R                      2 2         3   3            3          4
+--R             (- 208A b c  + 260B b c)x  + (- 192A b c + 240B b )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b
+--R       + 
+--R                  4 9         4          3  7            3         2 2  5
+--R             10B c x  + (20A c  + 15B b c )x  + (140A b c  - 143B b c )x
+--R           + 
+--R                    2 2         3   3          3          4
+--R             (304A b c  - 380B b c)x  + (192A b c - 240B b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|b
+--R    /
+--R                                                  +--------+
+--R             5 4         4 2       2 3  +---+ +-+ |   2
+--R         (40c x  + 160b c x  + 128b c )\|- c \|b \|c x  + b
+--R       + 
+--R              6 6         5 4       2 4 2       3 3  +---+
+--R         (- 8c x  - 104b c x  - 224b c x  - 128b c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1046
+
+--S 1047 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       3        2 2  4          2 2         3   2         3
+--R               (60A b c  - 75B b c )x  + (240A b c  - 300B b c)x  + 192A b c
+--R             + 
+--R                       4
+--R               - 240B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                     4        2 3  6            2 3         3 2  4
+--R           (- 12A b c  + 15B b c )x  + (- 156A b c  + 195B b c )x
+--R         + 
+--R                    3 2         4   2         4          5
+--R           (- 336A b c  + 420B b c)x  - 192A b c + 240B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  + c x)\|c x  + b  + (- c x  - b)\|c  - c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                       3        2 2  4          2 2         3   2         3
+--R               (60A b c  - 75B b c )x  + (240A b c  - 300B b c)x  + 192A b c
+--R             + 
+--R                       4
+--R               - 240B b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                     4        2 3  6            2 3         3 2  4
+--R           (- 12A b c  + 15B b c )x  + (- 156A b c  + 195B b c )x
+--R         + 
+--R                    3 2         4   2         4          5
+--R           (- 336A b c  + 420B b c)x  - 192A b c + 240B b
+--R      *
+--R          +-----------+           2 +-+
+--R          |   4      2           x \|c
+--R         \|c x  + b x  atanh(--------------)
+--R                              +-----------+
+--R                              |   4      2
+--R                             \|c x  + b x
+--R     + 
+--R                     4 9          4          3  7             3        2 2  5
+--R               - 2B c x  + (- 4A c  - 19B b c )x  + (- 60A b c  + 43B b c )x
+--R             + 
+--R                        2 2         3   3            3          4
+--R               (- 208A b c  + 260B b c)x  + (- 192A b c + 240B b )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|c x  + b
+--R         + 
+--R                    4 9         4          3  7            3         2 2  5
+--R               10B c x  + (20A c  + 15B b c )x  + (140A b c  - 143B b c )x
+--R             + 
+--R                      2 2         3   3          3          4
+--R               (304A b c  - 380B b c)x  + (192A b c - 240B b )x
+--R          *
+--R              +-+ +-+
+--R             \|b \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  4 10           4          3  8              3         2 2  6
+--R           - 10B c x   + (- 20A c  - 15B b c )x  + (- 140A b c  + 143B b c )x
+--R         + 
+--R                    2 2         3   4            3          4  2
+--R           (- 304A b c  + 380B b c)x  + (- 192A b c + 240B b )x
+--R      *
+--R                  +--------+
+--R          +-+ +-+ |   2
+--R         \|b \|c \|c x  + b
+--R     + 
+--R               5 12        5          4  10           4        2 3  8
+--R           2B c x   + (4A c  + 21B b c )x   + (64A b c  - 24B b c )x
+--R         + 
+--R                  2 3         3 2  6          3 2         4   4
+--R           (268A b c  - 303B b c )x  + (400A b c  - 500B b c)x
+--R         + 
+--R                  4          5  2
+--R           (192A b c - 240B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                                +--------+
+--R             5 4         4 2       2 3  +-+ +-+ |   2
+--R         (40c x  + 160b c x  + 128b c )\|b \|c \|c x  + b
+--R       + 
+--R              6 6         5 4       2 4 2       3 3  +-+
+--R         (- 8c x  - 104b c x  - 224b c x  - 128b c )\|c
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1047
+
+--S 1048 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          6 18           6           5  16
+--R                   - 13B c x   + (- 13A c  - 364B b c )x
+--R                 + 
+--R                              5          2 4  14
+--R                   (- 364A b c  - 2912B b c )x
+--R                 + 
+--R                             2 4          3 3  12
+--R                   (- 2912A b c  - 9984B b c )x
+--R                 + 
+--R                             3 3           4 2  10
+--R                   (- 9984A b c  - 16640B b c )x
+--R                 + 
+--R                              4 2           5   8              5           6  6
+--R                   (- 16640A b c  - 13312B b c)x  + (- 13312A b c - 4096B b )x
+--R                 + 
+--R                            6 4
+--R                   - 4096A b x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                    7 19         7          6  17             6          2 5  15
+--R               - B c x   + (- A c  - 84B b c )x   + (- 84A b c  - 1120B b c )x
+--R             + 
+--R                         2 5          3 4  13             3 4           4 3  11
+--R               (- 1120A b c  - 5376B b c )x   + (- 5376A b c  - 11520B b c )x
+--R             + 
+--R                          4 3           5 2  9              5 2          6   7
+--R               (- 11520A b c  - 11264B b c )x  + (- 11264A b c  - 4096B b c)x
+--R             + 
+--R                        6   5
+--R               - 4096A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  7 20       7          6  18           6          2 5  16
+--R               B c x   + (A c  + 85B b c )x   + (85A b c  + 1204B b c )x
+--R             + 
+--R                       2 5          3 4  14           3 4           4 3  12
+--R               (1204A b c  + 6496B b c )x   + (6496A b c  + 16896B b c )x
+--R             + 
+--R                        4 3           5 2  10            5 2           6   8
+--R               (16896A b c  + 22784B b c )x   + (22784A b c  + 15360B b c)x
+--R             + 
+--R                        6           7  6          7 4
+--R               (15360A b c + 4096B b )x  + 4096A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    7 19         7           6  17            6          2 5  15
+--R               13B c x   + (13A c  + 364B b c )x   + (364A b c  + 2912B b c )x
+--R             + 
+--R                       2 5          3 4  13           3 4           4 3  11
+--R               (2912A b c  + 9984B b c )x   + (9984A b c  + 16640B b c )x
+--R             + 
+--R                        4 3           5 2  9            5 2          6   7
+--R               (16640A b c  + 13312B b c )x  + (13312A b c  + 4096B b c)x
+--R             + 
+--R                      6   5
+--R               4096A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    7 21         7          6  19             6          2 5  17
+--R               - B c x   + (- A c  - 85B b c )x   + (- 85A b c  - 1204B b c )x
+--R             + 
+--R                         2 5          3 4  15             3 4           4 3  13
+--R               (- 1204A b c  - 6496B b c )x   + (- 6496A b c  - 16896B b c )x
+--R             + 
+--R                          4 3           5 2  11              5 2           6   9
+--R               (- 16896A b c  - 22784B b c )x   + (- 22784A b c  - 15360B b c)x
+--R             + 
+--R                          6           7  7          7 5
+--R               (- 15360A b c - 4096B b )x  - 4096A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      7 20           7           6  18
+--R               - 13B c x   + (- 13A c  - 364B b c )x
+--R             + 
+--R                          6          2 5  16             2 5          3 4  14
+--R               (- 364A b c  - 2912B b c )x   + (- 2912A b c  - 9984B b c )x
+--R             + 
+--R                         3 4           4 3  12
+--R               (- 9984A b c  - 16640B b c )x
+--R             + 
+--R                          4 3           5 2  10              5 2          6   8
+--R               (- 16640A b c  - 13312B b c )x   + (- 13312A b c  - 4096B b c)x
+--R             + 
+--R                        6   6
+--R               - 4096A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                7 21         7           6  19            6          2 5  17
+--R           13B c x   + (13A c  + 377B b c )x   + (377A b c  + 3276B b c )x
+--R         + 
+--R                   2 5           3 4  15            3 4           4 3  13
+--R           (3276A b c  + 12896B b c )x   + (12896A b c  + 26624B b c )x
+--R         + 
+--R                    4 3           5 2  11            5 2           6   9
+--R           (26624A b c  + 29952B b c )x   + (29952A b c  + 17408B b c)x
+--R         + 
+--R                    6           7  7          7 5
+--R           (17408A b c + 4096B b )x  + 4096A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R          8 22       8          7  20           7          2 6  18
+--R       B c x   + (A c  + 85B b c )x   + (85A b c  + 1204B b c )x
+--R     + 
+--R               2 6          3 5  16           3 5           4 4  14
+--R       (1204A b c  + 6496B b c )x   + (6496A b c  + 16896B b c )x
+--R     + 
+--R                4 4           5 3  12            5 3           6 2  10
+--R       (16896A b c  + 22784B b c )x   + (22784A b c  + 15360B b c )x
+--R     + 
+--R                6 2          7   8          7   6
+--R       (15360A b c  + 4096B b c)x  + 4096A b c x
+--R  /
+--R                  8 16        7 14        2 6 12        3 5 10         4 4 8
+--R                 c x   + 86b c x   + 1289b c x   + 7700b c x   + 23392b c x
+--R               + 
+--R                       5 3 6         6 2 4         7   2        8
+--R                 39680b c x  + 38144b c x  + 19456b c x  + 4096b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                    8 15         7 13        2 6 11         3 5 9         4 4 7
+--R                 13c x   + 377b c x   + 3276b c x   + 12896b c x  + 26624b c x
+--R               + 
+--R                       5 3 5         6 2 3        7
+--R                 29952b c x  + 17408b c x  + 4096b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  8 16         7 14        2 6 12         3 5 10         4 4 8
+--R             - 13c x   - 390b c x   - 3653b c x   - 16172b c x   - 39520b c x
+--R           + 
+--R                     5 3 6         6 2 4         7   2        8
+--R             - 56576b c x  - 47360b c x  - 21504b c x  - 4096b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R            9 17        8 15        2 7 13        3 6 11         4 5 9
+--R         - c x   - 86b c x   - 1289b c x   - 7700b c x   - 23392b c x
+--R       + 
+--R                 5 4 7         6 3 5         7 2 3        8
+--R         - 39680b c x  - 38144b c x  - 19456b c x  - 4096b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1048
+
+--S 1049 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       3        2 2  4          2 2         3   2         3
+--R               (60A b c  - 75B b c )x  + (240A b c  - 300B b c)x  + 192A b c
+--R             + 
+--R                       4
+--R               - 240B b
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|b \|c x  + b
+--R         + 
+--R                         4        2 3  6            2 3         3 2  4
+--R               (- 12A b c  + 15B b c )x  + (- 156A b c  + 195B b c )x
+--R             + 
+--R                        3 2         4   2         4          5
+--R               (- 336A b c  + 420B b c)x  - 192A b c + 240B b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R          +-----------+           2 +-+
+--R          |   4      2           x \|c
+--R         \|c x  + b x  atanh(--------------)
+--R                              +-----------+
+--R                              |   4      2
+--R                             \|c x  + b x
+--R     + 
+--R                          3         2 2  4            2 2         3   2
+--R               (- 120A b c  + 150B b c )x  + (- 480A b c  + 600B b c)x
+--R             + 
+--R                       3          4
+--R               - 384A b c + 480B b
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|b \|c \|c x  + b
+--R         + 
+--R                       4        2 3  6          2 3         3 2  4
+--R               (24A b c  - 30B b c )x  + (312A b c  - 390B b c )x
+--R             + 
+--R                      3 2         4   2         4          5
+--R               (672A b c  - 840B b c)x  + 384A b c - 480B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                   +--------+
+--R          +-----------+      +---+ |   2         +---+ +-+
+--R          |   4      2      \|- c \|c x  + b  - \|- c \|b
+--R         \|c x  + b x  atan(------------------------------)
+--R                                          c x
+--R     + 
+--R                     4 9          4          3  7             3        2 2  5
+--R               - 2B c x  + (- 4A c  - 19B b c )x  + (- 60A b c  + 43B b c )x
+--R             + 
+--R                        2 2         3   3            3          4
+--R               (- 208A b c  + 260B b c)x  + (- 192A b c + 240B b )x
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b
+--R         + 
+--R                    4 9         4          3  7            3         2 2  5
+--R               10B c x  + (20A c  + 15B b c )x  + (140A b c  - 143B b c )x
+--R             + 
+--R                      2 2         3   3          3          4
+--R               (304A b c  - 380B b c)x  + (192A b c - 240B b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|b \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  4 10           4          3  8              3         2 2  6
+--R           - 10B c x   + (- 20A c  - 15B b c )x  + (- 140A b c  + 143B b c )x
+--R         + 
+--R                    2 2         3   4            3          4  2
+--R           (- 304A b c  + 380B b c)x  + (- 192A b c + 240B b )x
+--R      *
+--R                        +--------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|b \|c \|c x  + b
+--R     + 
+--R               5 12        5          4  10           4        2 3  8
+--R           2B c x   + (4A c  + 21B b c )x   + (64A b c  - 24B b c )x
+--R         + 
+--R                  2 3         3 2  6          3 2         4   4
+--R           (268A b c  - 303B b c )x  + (400A b c  - 500B b c)x
+--R         + 
+--R                  4          5  2
+--R           (192A b c - 240B b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                                                      +--------+
+--R             5 4         4 2       2 3  +---+ +-+ +-+ |   2
+--R         (40c x  + 160b c x  + 128b c )\|- c \|b \|c \|c x  + b
+--R       + 
+--R              6 6         5 4       2 4 2       3 3  +---+ +-+
+--R         (- 8c x  - 104b c x  - 224b c x  - 128b c )\|- c \|c
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1049
+
+--S 1050 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      4 14           4           3  12
+--R               - 10B c x   + (- 10A c  - 160B b c )x
+--R             + 
+--R                          3         2 2  10            2 2          3   8
+--R               (- 160A b c  - 672B b c )x   + (- 672A b c  - 1024B b c)x
+--R             + 
+--R                         3          4  6         4 4
+--R               (- 1024A b c - 512B b )x  - 512A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              5 16       5          4  14           4         2 3  12
+--R           B c x   + (A c  + 50B b c )x   + (50A b c  + 400B b c )x
+--R         + 
+--R                  2 3          3 2  10           3 2          4   8
+--R           (400A b c  + 1120B b c )x   + (1120A b c  + 1280B b c)x
+--R         + 
+--R                   4          5  6         5 4
+--R           (1280A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                5 17         5          4  15             4         2 3  13
+--R           - B c x   + (- A c  - 50B b c )x   + (- 50A b c  - 400B b c )x
+--R         + 
+--R                    2 3          3 2  11             3 2          4   9
+--R           (- 400A b c  - 1120B b c )x   + (- 1120A b c  - 1280B b c)x
+--R         + 
+--R                     4          5  7         5 5
+--R           (- 1280A b c - 512B b )x  - 512A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                5 17         5           4  15            4         2 3  13
+--R           10B c x   + (10A c  + 170B b c )x   + (170A b c  + 832B b c )x
+--R         + 
+--R                  2 3          3 2  11           3 2          4   9
+--R           (832A b c  + 1696B b c )x   + (1696A b c  + 1536B b c)x
+--R         + 
+--R                   4          5  7         5 5
+--R           (1536A b c + 512B b )x  + 512A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              6 12        5 10       2 4 8        3 3 6        4 2 4
+--R             c x   + 51b c x   + 450b c x  + 1520b c x  + 2400b c x
+--R           + 
+--R                  5   2       6
+--R             1792b c x  + 512b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  6 12         5 10        2 4 8        3 3 6        4 2 4
+--R             - 10c x   - 180b c x   - 1002b c x  - 2528b c x  - 3232b c x
+--R           + 
+--R                    5   2       6
+--R             - 2048b c x  - 512b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1050
+
+)clear all
+
+--S 1051 of 3139
+t0:=x^5*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  5      3
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1051
+
+--S 1052 of 3139
+r0:=-1/2*(3*b*B-2*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(5/2)-_
+   (b*B-A*c)*x^4/(b*c*sqrt(b*x^2+c*x^4))+1/2*(3*b*B-2*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R                     +-----------+           2 +-+
+--R                     |   4      2           x \|c
+--R       (2A c - 3B b)\|c x  + b x  atanh(--------------)
+--R                                         +-----------+
+--R                                         |   4      2
+--R                                        \|c x  + b x
+--R     + 
+--R             4                   2  +-+
+--R       (B c x  + (- 2A c + 3B b)x )\|c
+--R  /
+--R             +-----------+
+--R       2 +-+ |   4      2
+--R     2c \|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1052
+
+--S 1053 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                        +--------+
+--R                   2           2                 2  +-+ |   2
+--R             ((6A c  - 9B b c)x  + 8A b c - 12B b )\|b \|c x  + b
+--R           + 
+--R                    3         2  4             2        2   2       2         3
+--R             (- 2A c  + 3B b c )x  + (- 10A b c  + 15B b c)x  - 8A b c + 12B b
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                                                                  +--------+
+--R               2 5        2           3                  2    +-+ |   2
+--R         (- B c x  + (2A c  - 7B b c)x  + (8A b c - 12B b )x)\|c \|c x  + b
+--R       + 
+--R              2 5          2            3                    2    +-+ +-+
+--R         (3B c x  + (- 6A c  + 13B b c)x  + (- 8A b c + 12B b )x)\|b \|c
+--R    /
+--R                               +--------+
+--R          3 2       2  +-+ +-+ |   2             4 4        3 2     2 2  +-+
+--R       (6c x  + 8b c )\|b \|c \|c x  + b  + (- 2c x  - 10b c x  - 8b c )\|c
+--R     ,
+--R
+--R                                                           +--------+
+--R                    2            2                  2  +-+ |   2
+--R             ((12A c  - 18B b c)x  + 16A b c - 24B b )\|b \|c x  + b
+--R           + 
+--R                  3         2  4             2        2   2        2         3
+--R           (- 4A c  + 6B b c )x  + (- 20A b c  + 30B b c)x  - 16A b c + 24B b
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                                                                    +--------+
+--R               2 5        2           3                  2    +---+ |   2
+--R         (- B c x  + (2A c  - 7B b c)x  + (8A b c - 12B b )x)\|- c \|c x  + b
+--R       + 
+--R              2 5          2            3                    2    +---+ +-+
+--R         (3B c x  + (- 6A c  + 13B b c)x  + (- 8A b c + 12B b )x)\|- c \|b
+--R    /
+--R                                 +--------+
+--R          3 2       2  +---+ +-+ |   2             4 4        3 2     2 2  +---+
+--R       (6c x  + 8b c )\|- c \|b \|c x  + b  + (- 2c x  - 10b c x  - 8b c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1053
+
+--S 1054 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                      +--------+
+--R                 2           2                 2  +-+ |   2
+--R           ((6A c  - 9B b c)x  + 8A b c - 12B b )\|b \|c x  + b
+--R         + 
+--R                  3         2  4             2        2   2       2         3
+--R           (- 2A c  + 3B b c )x  + (- 10A b c  + 15B b c)x  - 8A b c + 12B b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                                                        +--------+
+--R                   2           2                 2  +-+ |   2
+--R           ((- 6A c  + 9B b c)x  - 8A b c + 12B b )\|b \|c x  + b
+--R         + 
+--R                3         2  4           2        2   2       2         3
+--R           (2A c  - 3B b c )x  + (10A b c  - 15B b c)x  + 8A b c - 12B b
+--R      *
+--R          +-----------+           2 +-+
+--R          |   4      2           x \|c
+--R         \|c x  + b x  atanh(--------------)
+--R                              +-----------+
+--R                              |   4      2
+--R                             \|c x  + b x
+--R     + 
+--R                                                                    +--------+
+--R                 2 5        2           3                  2    +-+ |   2
+--R           (- B c x  + (2A c  - 7B b c)x  + (8A b c - 12B b )x)\|c \|c x  + b
+--R         + 
+--R                2 5          2            3                    2    +-+ +-+
+--R           (3B c x  + (- 6A c  + 13B b c)x  + (- 8A b c + 12B b )x)\|b \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                2 6        2            4                  2  2  +-+ +-+
+--R         (- 3B c x  + (6A c  - 13B b c)x  + (8A b c - 12B b )x )\|b \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R              3 8          3         2  6             2        2   4
+--R           B c x  + (- 2A c  + 8B b c )x  + (- 10A b c  + 19B b c)x
+--R         + 
+--R                  2         3  2
+--R           (- 8A b c + 12B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                +--------+
+--R           3 2       2  +-+ +-+ |   2             4 4        3 2     2 2  +-+
+--R       ((6c x  + 8b c )\|b \|c \|c x  + b  + (- 2c x  - 10b c x  - 8b c )\|c )
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1054
+
+--S 1055 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         4 12          4           3  10
+--R                   - 9B c x   + (- 9A c  - 120B b c )x
+--R                 + 
+--R                              3         2 2  8            2 2         3   6
+--R                   (- 120A b c  - 432B b c )x  + (- 432A b c  - 576B b c)x
+--R                 + 
+--R                            3          4  4         4 2
+--R                   (- 576A b c - 256B b )x  - 256A b x
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                  5 13       5          4  11           4         2 3  9
+--R               B c x   + (A c  + 40B b c )x   + (40A b c  + 240B b c )x
+--R             + 
+--R                    2 3         3 2  7          3 2         4   5         4   3
+--R             (240A b c  + 448B b c )x  + (448A b c  + 256B b c)x  + 256A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  5 14       5          4  12           4         2 3  10
+--R               B c x   + (A c  + 41B b c )x   + (41A b c  + 280B b c )x
+--R             + 
+--R                      2 3         3 2  8          3 2         4   6
+--R               (280A b c  + 688B b c )x  + (688A b c  + 704B b c)x
+--R             + 
+--R                      4          5  4         5 2
+--R               (704A b c + 256B b )x  + 256A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                     5 13          5           4  11
+--R               - 9B c x   + (- 9A c  - 120B b c )x
+--R             + 
+--R                          4         2 3  9            2 3         3 2  7
+--R               (- 120A b c  - 432B b c )x  + (- 432A b c  - 576B b c )x
+--R             + 
+--R                        3 2         4   5         4   3
+--R               (- 576A b c  - 256B b c)x  - 256A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    5 15         5          4  13             4         2 3  11
+--R               - B c x   + (- A c  - 41B b c )x   + (- 41A b c  - 280B b c )x
+--R             + 
+--R                        2 3         3 2  9            3 2         4   7
+--R               (- 280A b c  - 688B b c )x  + (- 688A b c  - 704B b c)x
+--R             + 
+--R                        4          5  5         5 3
+--R               (- 704A b c - 256B b )x  - 256A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                   5 14        5           4  12            4         2 3  10
+--R               9B c x   + (9A c  + 120B b c )x   + (120A b c  + 432B b c )x
+--R             + 
+--R                    2 3         3 2  8          3 2         4   6         4   4
+--R             (432A b c  + 576B b c )x  + (576A b c  + 256B b c)x  + 256A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               5 15        5           4  13            4         2 3  11
+--R           9B c x   + (9A c  + 129B b c )x   + (129A b c  + 552B b c )x
+--R         + 
+--R                  2 3          3 2  9           3 2         4   7
+--R           (552A b c  + 1008B b c )x  + (1008A b c  + 832B b c)x
+--R         + 
+--R                  4          5  5         5 3
+--R           (832A b c + 256B b )x  + 256A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            6 16         6          5  14             5         2 4  12
+--R       - B c x   + (- A c  - 41B b c )x   + (- 41A b c  - 280B b c )x
+--R     + 
+--R                2 4         3 3  10            3 3         4 2  8
+--R       (- 280A b c  - 688B b c )x   + (- 688A b c  - 704B b c )x
+--R     + 
+--R                4 2         5   6         5   4
+--R       (- 704A b c  - 256B b c)x  - 256A b c x
+--R  /
+--R                  6 12        5 10       2 4 8       3 3 6        4 2 4
+--R                 c x   + 42b c x   + 321b c x  + 968b c x  + 1392b c x
+--R               + 
+--R                     5   2       6
+--R                 960b c x  + 256b
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                     6 11         5 9       2 4 7        3 3 5       4 2 3
+--R                 - 9c x   - 129b c x  - 552b c x  - 1008b c x  - 832b c x
+--R               + 
+--R                       5
+--R                 - 256b c x
+--R            *
+--R                +-+
+--R               \|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                 6 12         5 10       2 4 8        3 3 6        4 2 4
+--R             - 9c x   - 138b c x   - 681b c x  - 1560b c x  - 1840b c x
+--R           + 
+--R                    5   2       6
+--R             - 1088b c x  - 256b
+--R        *
+--R            +-+ +-+
+--R           \|b \|c
+--R       + 
+--R          7 13        6 11       2 5 9       3 4 7        4 3 5       5 2 3
+--R         c x   + 42b c x   + 321b c x  + 968b c x  + 1392b c x  + 960b c x
+--R       + 
+--R             6
+--R         256b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1055
+
+--S 1056 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                              +--------+
+--R                   2           2                 2  +---+ +-+ |   2
+--R           ((- 6A c  + 9B b c)x  - 8A b c + 12B b )\|- c \|b \|c x  + b
+--R         + 
+--R               3         2  4           2        2   2       2         3  +---+
+--R         ((2A c  - 3B b c )x  + (10A b c  - 15B b c)x  + 8A b c - 12B b )\|- c
+--R      *
+--R          +-----------+           2 +-+
+--R          |   4      2           x \|c
+--R         \|c x  + b x  atanh(--------------)
+--R                              +-----------+
+--R                              |   4      2
+--R                             \|c x  + b x
+--R     + 
+--R                                                             +--------+
+--R                  2            2                  2  +-+ +-+ |   2
+--R           ((12A c  - 18B b c)x  + 16A b c - 24B b )\|b \|c \|c x  + b
+--R         + 
+--R                        3         2  4             2        2   2        2
+--R                 (- 4A c  + 6B b c )x  + (- 20A b c  + 30B b c)x  - 16A b c
+--R               + 
+--R                      3
+--R                 24B b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                   +--------+
+--R          +-----------+      +---+ |   2         +---+ +-+
+--R          |   4      2      \|- c \|c x  + b  - \|- c \|b
+--R         \|c x  + b x  atan(------------------------------)
+--R                                          c x
+--R     + 
+--R                   2 5        2           3                  2    +---+ +-+
+--R             (- B c x  + (2A c  - 7B b c)x  + (8A b c - 12B b )x)\|- c \|c
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R              2 5          2            3                    2    +---+ +-+ +-+
+--R         (3B c x  + (- 6A c  + 13B b c)x  + (- 8A b c + 12B b )x)\|- c \|b \|c
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                2 6        2            4                  2  2  +---+ +-+ +-+
+--R         (- 3B c x  + (6A c  - 13B b c)x  + (8A b c - 12B b )x )\|- c \|b \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R              3 8          3         2  6             2        2   4
+--R           B c x  + (- 2A c  + 8B b c )x  + (- 10A b c  + 19B b c)x
+--R         + 
+--R                  2         3  2
+--R           (- 8A b c + 12B b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                                       +--------+
+--R            3 2       2  +---+ +-+ +-+ |   2
+--R         (6c x  + 8b c )\|- c \|b \|c \|c x  + b
+--R       + 
+--R              4 4        3 2     2 2  +---+ +-+
+--R         (- 2c x  - 10b c x  - 8b c )\|- c \|c
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1056
+
+--S 1057 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                     2 8          2            6                     2  4
+--R               - 6B c x  + (- 6A c  - 32B b c)x  + (- 32A b c - 32B b )x
+--R             + 
+--R                      2 2
+--R               - 32A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              3 10       3          2  8           2        2   6
+--R           B c x   + (A c  + 18B b c )x  + (18A b c  + 48B b c)x
+--R         + 
+--R                 2         3  4        3 2
+--R           (48A b c + 32B b )x  + 32A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                3 11         3          2  9             2        2   7
+--R           - B c x   + (- A c  - 18B b c )x  + (- 18A b c  - 48B b c)x
+--R         + 
+--R                   2         3  5        3 3
+--R           (- 48A b c - 32B b )x  - 32A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               3 11        3          2  9           2        2   7
+--R           6B c x   + (6A c  + 38B b c )x  + (38A b c  + 64B b c)x
+--R         + 
+--R                 2         3  5        3 3
+--R           (64A b c + 32B b )x  + 32A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                        +--------+
+--R           4 8        3 6      2 2 4      3   2      4  |   2
+--R         (c x  + 19b c x  + 66b c x  + 80b c x  + 32b )\|c x  + b
+--R       + 
+--R              4 8        3 6       2 2 4      3   2      4  +-+
+--R         (- 6c x  - 44b c x  - 102b c x  - 96b c x  - 32b )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1057
+
+)clear all
+
+--S 1058 of 3139
+t0:=x^3*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  3
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1058
+
+--S 1059 of 3139
+r0:=B*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)-(b*B-A*c)*x^2/_
+   (b*c*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R            +-----------+           2 +-+
+--R            |   4      2           x \|c                     2 +-+
+--R        B b\|c x  + b x  atanh(--------------) + (A c - B b)x \|c
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R   (2)  ----------------------------------------------------------
+--R                                   +-----------+
+--R                               +-+ |   4      2
+--R                           b c\|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1059
+
+--S 1060 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    +--------+
+--R                +-+ |   2               2      2
+--R           (B b\|b \|c x  + b  - B b c x  - B b )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|b \|c x  + b  - b
+--R       + 
+--R                            +--------+
+--R                        +-+ |   2                     +-+ +-+
+--R         (- A c + B b)x\|c \|c x  + b  + (A c - B b)x\|b \|c
+--R    /
+--R                   +--------+
+--R           +-+ +-+ |   2              2 2    2   +-+
+--R       b c\|b \|c \|c x  + b  + (- b c x  - b c)\|c
+--R     ,
+--R
+--R                     +--------+
+--R                 +-+ |   2                2       2
+--R           (2B b\|b \|c x  + b  - 2B b c x  - 2B b )
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- c \|c x  + b  - \|- c \|b
+--R           atan(------------------------------)
+--R                              c x
+--R       + 
+--R                              +--------+
+--R                        +---+ |   2                     +---+ +-+
+--R         (- A c + B b)x\|- c \|c x  + b  + (A c - B b)x\|- c \|b
+--R    /
+--R                     +--------+
+--R           +---+ +-+ |   2              2 2    2   +---+
+--R       b c\|- c \|b \|c x  + b  + (- b c x  - b c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1060
+
+--S 1061 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  +--------+                    +-----------+
+--R              +-+ |   2               2      2  |   4      2
+--R         (B b\|b \|c x  + b  - B b c x  - B b )\|c x  + b x
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|b \|c  - c x)\|c x  + b  + (- c x  - b)\|c  + c x\|b
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|b \|c x  + b  - b
+--R     + 
+--R                    +--------+                    +-----------+
+--R                +-+ |   2               2      2  |   4      2
+--R         (- B b\|b \|c x  + b  + B b c x  + B b )\|c x  + b x
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                           +--------+                         +-----------+
+--R                       +-+ |   2                     +-+ +-+  |   4      2
+--R       ((- A c + B b)x\|c \|c x  + b  + (A c - B b)x\|b \|c )\|c x  + b x
+--R     + 
+--R                               +--------+
+--R                     2 +-+ +-+ |   2
+--R       (- A c + B b)x \|b \|c \|c x  + b
+--R     + 
+--R            2          4               2  2  +-+
+--R       ((A c  - B b c)x  + (A b c - B b )x )\|c
+--R  /
+--R                  +--------+                         +-----------+
+--R          +-+ +-+ |   2              2 2    2   +-+  |   4      2
+--R     (b c\|b \|c \|c x  + b  + (- b c x  - b c)\|c )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1061
+
+--S 1062 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         2 6          2            4                     2  2
+--R                   - 5B c x  + (- 5A c  - 20B b c)x  + (- 20A b c - 16B b )x
+--R                 + 
+--R                          2
+--R                   - 16A b
+--R              *
+--R                  +-+ +-+
+--R                 \|b \|c
+--R             + 
+--R                3 7       3          2  5           2        2   3        2
+--R             B c x  + (A c  + 12B b c )x  + (12A b c  + 16B b c)x  + 16A b c x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                  3 8       3          2  6           2        2   4
+--R               B c x  + (A c  + 13B b c )x  + (13A b c  + 28B b c)x
+--R             + 
+--R                     2         3  2        3
+--R               (28A b c + 16B b )x  + 16A b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                     3 7          3          2  5             2        2   3
+--R               - 5B c x  + (- 5A c  - 20B b c )x  + (- 20A b c  - 16B b c)x
+--R             + 
+--R                      2
+--R               - 16A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    3 9         3          2  7             2        2   5
+--R               - B c x  + (- A c  - 13B b c )x  + (- 13A b c  - 28B b c)x
+--R             + 
+--R                       2         3  3        3
+--R               (- 28A b c - 16B b )x  - 16A b x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                   3 8        3          2  6           2        2   4
+--R               5B c x  + (5A c  + 20B b c )x  + (20A b c  + 16B b c)x
+--R             + 
+--R                    2   2
+--R               16A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               3 9        3          2  7           2        2   5
+--R           5B c x  + (5A c  + 25B b c )x  + (25A b c  + 36B b c)x
+--R         + 
+--R                 2         3  3        3
+--R           (36A b c + 16B b )x  + 16A b x
+--R      *
+--R          +-+ +-+
+--R         \|b \|c
+--R     + 
+--R            4 10         4          3  8             3        2 2  6
+--R       - B c x   + (- A c  - 13B b c )x  + (- 13A b c  - 28B b c )x
+--R     + 
+--R               2 2        3   4        3   2
+--R       (- 28A b c  - 16B b c)x  - 16A b c x
+--R  /
+--R               4 8        3 6      2 2 4      3   2      4  +-+
+--R             (c x  + 14b c x  + 41b c x  + 44b c x  + 16b )\|c
+--R           + 
+--R                  4 7        3 5      2 2 3      3     +-+
+--R             (- 5c x  - 25b c x  - 36b c x  - 16b c x)\|b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R              4 8        3 6      2 2 4      3   2      4  +-+ +-+    5 9
+--R         (- 5c x  - 30b c x  - 61b c x  - 52b c x  - 16b )\|b \|c  + c x
+--R       + 
+--R              4 7      2 3 5      3 2 3      4
+--R         14b c x  + 41b c x  + 44b c x  + 16b c x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1062
+
+--S 1063 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          +--------+                            +-----------+
+--R                +---+ +-+ |   2                2      2  +---+  |   4      2
+--R         (- B b\|- c \|b \|c x  + b  + (B b c x  + B b )\|- c )\|c x  + b x
+--R      *
+--R                    2 +-+
+--R                   x \|c
+--R         atanh(--------------)
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R     + 
+--R                       +--------+                              +-----------+
+--R               +-+ +-+ |   2                   2       2  +-+  |   4      2
+--R         (2B b\|b \|c \|c x  + b  + (- 2B b c x  - 2B b )\|c )\|c x  + b x
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- c \|c x  + b  - \|- c \|b
+--R         atan(------------------------------)
+--R                            c x
+--R     + 
+--R                                   +--------+
+--R                         +---+ +-+ |   2                     +---+ +-+ +-+
+--R         ((- A c + B b)x\|- c \|c \|c x  + b  + (A c - B b)x\|- c \|b \|c )
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                     +--------+
+--R                     2 +---+ +-+ +-+ |   2
+--R       (- A c + B b)x \|- c \|b \|c \|c x  + b
+--R     + 
+--R            2          4               2  2  +---+ +-+
+--R       ((A c  - B b c)x  + (A b c - B b )x )\|- c \|c
+--R  /
+--R                        +--------+                               +-----------+
+--R          +---+ +-+ +-+ |   2              2 2    2   +---+ +-+  |   4      2
+--R     (b c\|- c \|b \|c \|c x  + b  + (- b c x  - b c)\|- c \|c )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1063
+
+--S 1064 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                             +--------+
+--R                 2       +-+ |   2             4                2
+--R         ((- 2B x  - 2A)\|b \|c x  + b  + B c x  + (A c + 2B b)x  + 2A b)
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                              +--------+
+--R               5                  3           |   2
+--R       (- B c x  + (- A c - 2B b)x  - 2A b x)\|c x  + b
+--R     + 
+--R              5                 3           +-+
+--R       (2B c x  + (2A c + 2B b)x  + 2A b x)\|b
+--R  /
+--R                               +--------+
+--R          2 4         2     2  |   2             2 4         2     2  +-+
+--R       ((c x  + 3b c x  + 2b )\|c x  + b  + (- 2c x  - 4b c x  - 2b )\|b )
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1064
+
+)clear all
+
+--S 1065 of 3139
+t0:=x*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    2
+--R                 B x  + A
+--R   (1)  --------------------------
+--R                     +-----------+
+--R            3        |   4      2
+--R        (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1065
+
+--S 1066 of 3139
+r0:=-A/(b*sqrt(b*x^2+c*x^4))+(b*B-2*A*c)*x^2/(b^2*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                       2
+--R        (- 2A c + B b)x  - A b
+--R   (2)  ----------------------
+--R              +-----------+
+--R            2 |   4      2
+--R           b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1066
+
+--S 1067 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                    +--------+
+--R                      2         +-+ |   2               2          4
+--R       ((4A c - 2B b)x  + 2A b)\|b \|c x  + b  + (- 2A c  + B b c)x
+--R     + 
+--R                       2  2       2
+--R       (- 5A b c + 2B b )x  - 2A b
+--R  /
+--R                     +--------+
+--R       2   3     3   |   2             2   3     3   +-+
+--R     (b c x  + 2b x)\|c x  + b  + (- 2b c x  - 2b x)\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1067
+
+--S 1068 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                        +--------+
+--R                          2         +-+ |   2               2          4
+--R           ((4A c - 2B b)x  + 2A b)\|b \|c x  + b  + (- 2A c  + B b c)x
+--R         + 
+--R                           2  2       2
+--R           (- 5A b c + 2B b )x  - 2A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                         +--------+
+--R             2          5                 2  3       2   |   2
+--R       ((2A c  - B b c)x  + (5A b c - 2B b )x  + 2A b x)\|c x  + b
+--R     + 
+--R               2           5                   2  3       2   +-+
+--R       ((- 4A c  + 2B b c)x  + (- 6A b c + 2B b )x  - 2A b x)\|b
+--R  /
+--R                      +--------+                           +-----------+
+--R        2   3     3   |   2             2   3     3   +-+  |   4      2
+--R     ((b c x  + 2b x)\|c x  + b  + (- 2b c x  - 2b x)\|b )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1068
+
+--S 1069 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                      +--------+
+--R                    4                   2         +-+ |   2           2 6
+--R           (- 4B c x  + (- 4A c - 8B b)x  - 8A b)\|b \|c x  + b  + B c x
+--R         + 
+--R               2           4                 2  2       2
+--R           (A c  + 8B b c)x  + (8A b c + 8B b )x  + 8A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R               2 7         2           5                   2  3       2
+--R         (- B c x  + (- A c  - 8B b c)x  + (- 8A b c - 8B b )x  - 8A b x)
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R            2 7        2            5                  2  3       2   +-+
+--R       (4B c x  + (4A c  + 12B b c)x  + (12A b c + 8B b )x  + 8A b x)\|b
+--R  /
+--R                                             +--------+
+--R           3 8       2 6      2   4     3 2  |   2
+--R         (c x  + 9b c x  + 16b c x  + 8b x )\|c x  + b
+--R       + 
+--R              3 8        2 6      2   4     3 2  +-+
+--R         (- 4c x  - 16b c x  - 20b c x  - 8b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1069
+
+)clear all
+
+--S 1070 of 3139
+t0:=(A+B*x^2)/(x*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            5      3  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1070
+
+--S 1071 of 3139
+r0:=1/3*(3*b*B-4*A*c)/(b^2*sqrt(b*x^2+c*x^4))-1/3*A/(b*x^2*sqrt(b*x^2+_
+   c*x^4))-2/3*(3*b*B-4*A*c)*sqrt(b*x^2+c*x^4)/(b^3*x^2)
+--R 
+--R
+--R             2           4                 2  2      2
+--R        (8A c  - 6B b c)x  + (4A b c - 3B b )x  - A b
+--R   (2)  ----------------------------------------------
+--R                            +-----------+
+--R                        3 2 |   4      2
+--R                      3b x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1071
+
+--S 1072 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   3          2  6             2        2   4
+--R           (- 32A c  + 24B b c )x  + (- 80A b c  + 60B b c)x
+--R         + 
+--R                   2         3  2       3
+--R           (- 28A b c + 24B b )x  + 8A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R            4         3  8           3        2 2  6         2 2        3   4
+--R       (8A c  - 6B b c )x  + (68A b c  - 51B b c )x  + (95A b c  - 72B b c)x
+--R     + 
+--R             3         4  2       4
+--R       (24A b c - 24B b )x  - 8A b
+--R  /
+--R                                     +--------+
+--R          3 2 7      4   5      5 3  |   2
+--R       (3b c x  + 24b c x  + 24b x )\|c x  + b
+--R     + 
+--R             3 2 7      4   5      5 3  +-+
+--R       (- 12b c x  - 36b c x  - 24b x )\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1072
+
+--S 1073 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       3          2  6             2        2   4
+--R               (- 32A c  + 24B b c )x  + (- 80A b c  + 60B b c)x
+--R             + 
+--R                       2         3  2       3
+--R               (- 28A b c + 24B b )x  + 8A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                4         3  8           3        2 2  6
+--R           (8A c  - 6B b c )x  + (68A b c  - 51B b c )x
+--R         + 
+--R                 2 2        3   4         3         4  2       4
+--R           (95A b c  - 72B b c)x  + (24A b c - 24B b )x  - 8A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  4         3  9             3        2 2  7
+--R           (- 8A c  + 6B b c )x  + (- 68A b c  + 51B b c )x
+--R         + 
+--R                   2 2        3   5           3         4  3       4
+--R           (- 95A b c  + 72B b c)x  + (- 24A b c + 24B b )x  + 8A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                 4          3  9            3        2 2  7
+--R           (32A c  - 24B b c )x  + (112A b c  - 84B b c )x
+--R         + 
+--R                  2 2        3   5         3         4  3       4
+--R           (108A b c  - 84B b c)x  + (20A b c - 24B b )x  - 8A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                       +--------+
+--R            3 2 7      4   5      5 3  |   2
+--R         (3b c x  + 24b c x  + 24b x )\|c x  + b
+--R       + 
+--R               3 2 7      4   5      5 3  +-+
+--R         (- 12b c x  - 36b c x  - 24b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1073
+
+--S 1074 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     3 8          3          2  6             2         2   4
+--R               - 8B c x  + (- 8A c  - 80B b c )x  + (- 80A b c  - 192B b c)x
+--R             + 
+--R                        2          3  2         3
+--R               (- 192A b c - 128B b )x  - 128A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              4 10       4          3  8           3         2 2  6
+--R           B c x   + (A c  + 32B b c )x  + (32A b c  + 160B b c )x
+--R         + 
+--R                  2 2         3   4          3          4  2         4
+--R           (160A b c  + 256B b c)x  + (256A b c + 128B b )x  + 128A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                4 11         4          3  9             3         2 2  7
+--R           - B c x   + (- A c  - 32B b c )x  + (- 32A b c  - 160B b c )x
+--R         + 
+--R                    2 2         3   5            3          4  3         4
+--R           (- 160A b c  - 256B b c)x  + (- 256A b c - 128B b )x  - 128A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               4 11        4          3  9           3         2 2  7
+--R           8B c x   + (8A c  + 88B b c )x  + (88A b c  + 272B b c )x
+--R         + 
+--R                  2 2         3   5          3          4  3         4
+--R           (272A b c  + 320B b c)x  + (320A b c + 128B b )x  + 128A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R             5 14        4 12       2 3 10       3 2 8       4   6       5 4
+--R           (c x   + 33b c x   + 192b c x   + 416b c x  + 384b c x  + 128b x )
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R            5 14        4 12       2 3 10       3 2 8       4   6       5 4  +-+
+--R       (- 8c x   - 96b c x   - 360b c x   - 592b c x  - 448b c x  - 128b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1074
+
+)clear all
+
+--S 1075 of 3139
+t0:=(A+B*x^2)/(x^3*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            7      5  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1075
+
+--S 1076 of 3139
+r0:=-1/5*A/(b*x^4*sqrt(b*x^2+c*x^4))+1/5*(5*b*B-6*A*c)/(b^2*x^2*_
+   sqrt(b*x^2+c*x^4))-4/15*(5*b*B-6*A*c)*sqrt(b*x^2+c*x^4)/(b^3*x^4)+_
+   8/15*c*(5*b*B-6*A*c)*sqrt(b*x^2+c*x^4)/(b^4*x^2)
+--R 
+--R
+--R   (2)
+--R               3          2  6             2        2   4        2        3  2
+--R       (- 48A c  + 40B b c )x  + (- 24A b c  + 20B b c)x  + (6A b c - 5B b )x
+--R     + 
+--R             3
+--R       - 3A b
+--R  /
+--R            +-----------+
+--R        4 4 |   4      2
+--R     15b x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1076
+
+--S 1077 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  5           4  10             4          2 3  8
+--R           (288A c  - 240B b c )x   + (1680A b c  - 1400B b c )x
+--R         + 
+--R                   2 3          3 2  6          3 2         4   4
+--R           (2268A b c  - 1890B b c )x  + (594A b c  - 480B b c)x
+--R         + 
+--R                   4          5  2        5
+--R           (- 96A b c + 160B b )x  + 96A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R               6          5  12              5         2 4  10
+--R       (- 48A c  + 40B b c )x   + (- 888A b c  + 740B b c )x
+--R     + 
+--R                 2 4          3 3  8             3 3          4 2  6
+--R       (- 2730A b c  + 2275B b c )x  + (- 2583A b c  + 2150B b c )x
+--R     + 
+--R                4 2         5   4         5          6  2        6
+--R       (- 534A b c  + 400B b c)x  + (48A b c - 160B b )x  - 96A b
+--R  /
+--R                                                     +--------+
+--R           4 3 11       5 2 9       6   7       7 5  |   2
+--R       (15b c x   + 270b c x  + 720b c x  + 480b x )\|c x  + b
+--R     + 
+--R             4 3 11       5 2 9       6   7       7 5  +-+
+--R       (- 90b c x   - 570b c x  - 960b c x  - 480b x )\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1077
+
+--S 1078 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      5           4  10             4          2 3  8
+--R               (288A c  - 240B b c )x   + (1680A b c  - 1400B b c )x
+--R             + 
+--R                       2 3          3 2  6          3 2         4   4
+--R               (2268A b c  - 1890B b c )x  + (594A b c  - 480B b c)x
+--R             + 
+--R                       4          5  2        5
+--R               (- 96A b c + 160B b )x  + 96A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   6          5  12              5         2 4  10
+--R           (- 48A c  + 40B b c )x   + (- 888A b c  + 740B b c )x
+--R         + 
+--R                     2 4          3 3  8             3 3          4 2  6
+--R           (- 2730A b c  + 2275B b c )x  + (- 2583A b c  + 2150B b c )x
+--R         + 
+--R                    4 2         5   4         5          6  2        6
+--R           (- 534A b c  + 400B b c)x  + (48A b c - 160B b )x  - 96A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 6          5  13            5         2 4  11
+--R           (48A c  - 40B b c )x   + (888A b c  - 740B b c )x
+--R         + 
+--R                   2 4          3 3  9           3 3          4 2  7
+--R           (2730A b c  - 2275B b c )x  + (2583A b c  - 2150B b c )x
+--R         + 
+--R                  4 2         5   5           5          6  3        6
+--R           (534A b c  - 400B b c)x  + (- 48A b c + 160B b )x  + 96A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                    6           5  13               5          2 4  11
+--R           (- 288A c  + 240B b c )x   + (- 1968A b c  + 1640B b c )x
+--R         + 
+--R                     2 4          3 3  9             3 3          4 2  7
+--R           (- 3948A b c  + 3290B b c )x  + (- 2862A b c  + 2370B b c )x
+--R         + 
+--R                    4 2         5   5         6 3        6
+--R           (- 498A b c  + 320B b c)x  - 160B b x  - 96A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                       +--------+
+--R             4 3 11       5 2 9       6   7       7 5  |   2
+--R         (15b c x   + 270b c x  + 720b c x  + 480b x )\|c x  + b
+--R       + 
+--R               4 3 11       5 2 9       6   7       7 5  +-+
+--R         (- 90b c x   - 570b c x  - 960b c x  - 480b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1078
+
+--S 1079 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      5 12           5           4  10
+--R               - 12B c x   + (- 12A c  - 280B b c )x
+--R             + 
+--R                          4          2 3  8             2 3          3 2  6
+--R               (- 280A b c  - 1792B b c )x  + (- 1792A b c  - 4608B b c )x
+--R             + 
+--R                         3 2          4   4             4           5  2
+--R               (- 4608A b c  - 5120B b c)x  + (- 5120A b c - 2048B b )x
+--R             + 
+--R                        5
+--R               - 2048A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              6 14       6          5  12           5         2 4  10
+--R           B c x   + (A c  + 72B b c )x   + (72A b c  + 840B b c )x
+--R         + 
+--R                  2 4          3 3  8           3 3          4 2  6
+--R           (840A b c  + 3584B b c )x  + (3584A b c  + 6912B b c )x
+--R         + 
+--R                   4 2          5   4           5           6  2          6
+--R           (6912A b c  + 6144B b c)x  + (6144A b c + 2048B b )x  + 2048A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                6 15         6          5  13             5         2 4  11
+--R           - B c x   + (- A c  - 72B b c )x   + (- 72A b c  - 840B b c )x
+--R         + 
+--R                    2 4          3 3  9             3 3          4 2  7
+--R           (- 840A b c  - 3584B b c )x  + (- 3584A b c  - 6912B b c )x
+--R         + 
+--R                   4 2          5   5             5           6  3          6
+--R         (- 6912A b c  - 6144B b c)x  + (- 6144A b c - 2048B b )x  - 2048A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                6 15         6           5  13            5          2 4  11
+--R           12B c x   + (12A c  + 292B b c )x   + (292A b c  + 2072B b c )x
+--R         + 
+--R                   2 4          3 3  9           3 3          4 2  7
+--R           (2072A b c  + 6400B b c )x  + (6400A b c  + 9728B b c )x
+--R         + 
+--R                   4 2          5   5           5           6  3          6
+--R           (9728A b c  + 7168B b c)x  + (7168A b c + 2048B b )x  + 2048A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              7 20        6 18       2 5 16        3 4 14         4 3 12
+--R             c x   + 73b c x   + 912b c x   + 4424b c x   + 10496b c x
+--R           + 
+--R                   5 2 10        6   8        7 6
+--R             13056b c x   + 8192b c x  + 2048b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  7 20         6 18        2 5 16        3 4 14         4 3 12
+--R             - 12c x   - 304b c x   - 2364b c x   - 8472b c x   - 16128b c x
+--R           + 
+--R                     5 2 10        6   8        7 6
+--R             - 16896b c x   - 9216b c x  - 2048b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1079
+
+)clear all
+
+--S 1080 of 3139
+t0:=(A+B*x^2)/(x^5*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            9      7  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1080
+
+--S 1081 of 3139
+r0:=-1/7*A/(b*x^6*sqrt(b*x^2+c*x^4))+1/7*(7*b*B-8*A*c)/(b^2*x^4*_
+   sqrt(b*x^2+c*x^4))-6/35*(7*b*B-8*A*c)*sqrt(b*x^2+c*x^4)/(b^3*x^6)+_
+   8/35*c*(7*b*B-8*A*c)*sqrt(b*x^2+c*x^4)/(b^4*x^4)-16/35*c^2*(7*b*B-_
+   8*A*c)*sqrt(b*x^2+c*x^4)/(b^5*x^2)
+--R 
+--R
+--R   (2)
+--R              4           3  8           3        2 2  6
+--R       (128A c  - 112B b c )x  + (64A b c  - 56B b c )x
+--R     + 
+--R               2 2        3   4        3        4  2       4
+--R       (- 16A b c  + 14B b c)x  + (8A b c - 7B b )x  - 5A b
+--R  /
+--R            +-----------+
+--R        5 6 |   4      2
+--R     35b x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1081
+
+--S 1082 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     7           6  14                6          2 5  12
+--R           (- 1024A c  + 896B b c )x   + (- 10752A b c  + 9408B b c )x
+--R         + 
+--R                      2 5           3 4  10              3 4           4 3  8
+--R           (- 29568A b c  + 25872B b c )x   + (- 27456A b c  + 24024B b c )x
+--R         + 
+--R                     4 3          5 2  6          5 2         6   4
+--R           (- 5720A b c  + 5040B b c )x  + (912A b c  - 448B b c)x
+--R         + 
+--R                   6          7  2         7
+--R           (- 64A b c + 896B b )x  + 640A b
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              8           7  16             7          2 6  14
+--R       (128A c  - 112B b c )x   + (4160A b c  - 3640B b c )x
+--R     + 
+--R                2 6           3 5  12            3 5           4 4  10
+--R       (22512A b c  - 19698B b c )x   + (42504A b c  - 37191B b c )x
+--R     + 
+--R                4 4           5 3  8           5 3          6 2  6         6 2 4
+--R       (30459A b c  - 26656B b c )x  + (5216A b c  - 4704B b c )x  - 800A b c x
+--R     + 
+--R                7          8  2         8
+--R       (- 256A b c - 896B b )x  - 640A b
+--R  /
+--R             5 4 15        6 3 13        7 2 11        8   9        9 7
+--R         (35b c x   + 1120b c x   + 5600b c x   + 8960b c x  + 4480b x )
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R              5 4 15        6 3 13        7 2 11         8   9        9 7  +-+
+--R       (- 280b c x   - 3080b c x   - 9520b c x   - 11200b c x  - 4480b x )\|b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1082
+
+--S 1083 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         7           6  14                6          2 5  12
+--R               (- 1024A c  + 896B b c )x   + (- 10752A b c  + 9408B b c )x
+--R             + 
+--R                          2 5           3 4  10
+--R               (- 29568A b c  + 25872B b c )x
+--R             + 
+--R                          3 4           4 3  8             4 3          5 2  6
+--R               (- 27456A b c  + 24024B b c )x  + (- 5720A b c  + 5040B b c )x
+--R             + 
+--R                      5 2         6   4           6          7  2         7
+--R               (912A b c  - 448B b c)x  + (- 64A b c + 896B b )x  + 640A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  8           7  16             7          2 6  14
+--R           (128A c  - 112B b c )x   + (4160A b c  - 3640B b c )x
+--R         + 
+--R                    2 6           3 5  12            3 5           4 4  10
+--R           (22512A b c  - 19698B b c )x   + (42504A b c  - 37191B b c )x
+--R         + 
+--R                    4 4           5 3  8           5 3          6 2  6
+--R           (30459A b c  - 26656B b c )x  + (5216A b c  - 4704B b c )x
+--R         + 
+--R                   6 2 4            7          8  2         8
+--R           - 800A b c x  + (- 256A b c - 896B b )x  - 640A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                    8           7  17               7          2 6  15
+--R           (- 128A c  + 112B b c )x   + (- 4160A b c  + 3640B b c )x
+--R         + 
+--R                      2 6           3 5  13              3 5           4 4  11
+--R           (- 22512A b c  + 19698B b c )x   + (- 42504A b c  + 37191B b c )x
+--R         + 
+--R                      4 4           5 3  9             5 3          6 2  7
+--R           (- 30459A b c  + 26656B b c )x  + (- 5216A b c  + 4704B b c )x
+--R         + 
+--R                 6 2 5          7          8  3         8
+--R           800A b c x  + (256A b c + 896B b )x  + 640A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                   8           7  17              7           2 6  15
+--R           (1024A c  - 896B b c )x   + (11776A b c  - 10304B b c )x
+--R         + 
+--R                    2 6           3 5  13            3 5           4 4  11
+--R           (40320A b c  - 35280B b c )x   + (57024A b c  - 49896B b c )x
+--R         + 
+--R                    4 4           5 3  9           5 3          6 2  7
+--R           (33176A b c  - 29064B b c )x  + (4808A b c  - 4592B b c )x
+--R         + 
+--R                    6 2         7   5            7          8  3         8
+--R           (- 848A b c  - 448B b c)x  + (- 576A b c - 896B b )x  - 640A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R               5 4 15        6 3 13        7 2 11        8   9        9 7
+--R           (35b c x   + 1120b c x   + 5600b c x   + 8960b c x  + 4480b x )
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R              5 4 15        6 3 13        7 2 11         8   9        9 7  +-+
+--R       (- 280b c x   - 3080b c x   - 9520b c x   - 11200b c x  - 4480b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1083
+
+--S 1084 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      7 16           7           6  14
+--R               - 16B c x   + (- 16A c  - 672B b c )x
+--R             + 
+--R                          6          2 5  12             2 5           3 4  10
+--R               (- 672A b c  - 8064B b c )x   + (- 8064A b c  - 42240B b c )x
+--R             + 
+--R                          3 4            4 3  8
+--R               (- 42240A b c  - 112640B b c )x
+--R             + 
+--R                           4 3            5 2  6
+--R               (- 112640A b c  - 159744B b c )x
+--R             + 
+--R                           5 2            6   4               6            7  2
+--R               (- 159744A b c  - 114688B b c)x  + (- 114688A b c - 32768B b )x
+--R             + 
+--R                         7
+--R               - 32768A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              8 18       8           7  16            7          2 6  14
+--R           B c x   + (A c  + 128B b c )x   + (128A b c  + 2688B b c )x
+--R         + 
+--R                   2 6           3 5  12            3 5           4 4  10
+--R           (2688A b c  + 21504B b c )x   + (21504A b c  + 84480B b c )x
+--R         + 
+--R                    4 4            5 3  8             5 3            6 2  6
+--R           (84480A b c  + 180224B b c )x  + (180224A b c  + 212992B b c )x
+--R         + 
+--R                     6 2            7   4             7            8  2
+--R           (212992A b c  + 131072B b c)x  + (131072A b c + 32768B b )x
+--R         + 
+--R                   8
+--R           32768A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                8 19         8           7  17              7          2 6  15
+--R           - B c x   + (- A c  - 128B b c )x   + (- 128A b c  - 2688B b c )x
+--R         + 
+--R                     2 6           3 5  13              3 5           4 4  11
+--R           (- 2688A b c  - 21504B b c )x   + (- 21504A b c  - 84480B b c )x
+--R         + 
+--R                      4 4            5 3  9               5 3            6 2  7
+--R           (- 84480A b c  - 180224B b c )x  + (- 180224A b c  - 212992B b c )x
+--R         + 
+--R                       6 2            7   5               7            8  3
+--R           (- 212992A b c  - 131072B b c)x  + (- 131072A b c - 32768B b )x
+--R         + 
+--R                     8
+--R           - 32768A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                8 19         8           7  17            7          2 6  15
+--R           16B c x   + (16A c  + 688B b c )x   + (688A b c  + 8736B b c )x
+--R         + 
+--R                   2 6           3 5  13            3 5            4 4  11
+--R           (8736A b c  + 50304B b c )x   + (50304A b c  + 154880B b c )x
+--R         + 
+--R                     4 4            5 3  9             5 3            6 2  7
+--R           (154880A b c  + 272384B b c )x  + (272384A b c  + 274432B b c )x
+--R         + 
+--R                     6 2            7   5             7            8  3
+--R           (274432A b c  + 147456B b c)x  + (147456A b c + 32768B b )x
+--R         + 
+--R                   8
+--R           32768A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              9 26         8 24        2 7 22         3 6 20          4 5 18
+--R             c x   + 129b c x   + 2816b c x   + 24192b c x   + 105984b c x
+--R           + 
+--R                    5 4 16          6 3 14          7 2 12          8   10
+--R             264704b c x   + 393216b c x   + 344064b c x   + 163840b c x
+--R           + 
+--R                   9 8
+--R             32768b x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  9 26         8 24        2 7 22         3 6 20          4 5 18
+--R             - 16c x   - 704b c x   - 9424b c x   - 59040b c x   - 205184b c x
+--R           + 
+--R                      5 4 16          6 3 14          7 2 12          8   10
+--R             - 427264b c x   - 546816b c x   - 421888b c x   - 180224b c x
+--R           + 
+--R                     9 8
+--R             - 32768b x
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1084
+
+)clear all
+
+--S 1085 of 3139
+t0:=x^8*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  8      6
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1085
+
+--S 1086 of 3139
+r0:=-(b*B-A*c)*x^7/(b*c*sqrt(b*x^2+c*x^4))+8/15*b*(6*b*B-5*A*c)*_
+   sqrt(b*x^2+c*x^4)/(c^4*x)-4/15*(6*b*B-5*A*c)*x*sqrt(b*x^2+c*x^4)/c^3+_
+   1/5*(6*b*B-5*A*c)*x^3*sqrt(b*x^2+c*x^4)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R           3 7        3         2  5             2        2   3
+--R       3B c x  + (5A c  - 6B b c )x  + (- 20A b c  + 24B b c)x
+--R     + 
+--R               2         3
+--R       (- 40A b c + 48B b )x
+--R  /
+--R          +-----------+
+--R        4 |   4      2
+--R     15c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1086
+
+--S 1087 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                           +--------+
+--R                   10                     2  8        2 6  |   2
+--R       (- 18B b c x   + (- 30A b c - 60B b )x  - 80A b x )\|c x  + b
+--R     + 
+--R            2 12        2            10                   2  8        2 6  +-+
+--R       (3B c x   + (5A c  + 48B b c)x   + (70A b c + 60B b )x  + 80A b x )\|b
+--R  /
+--R                                                    +--------+
+--R           3 6         2 4       2   2       3  +-+ |   2             3 6
+--R       (15c x  + 270b c x  + 720b c x  + 480b )\|b \|c x  + b  - 90b c x
+--R     + 
+--R             2 2 4       3   2       4
+--R       - 570b c x  - 960b c x  - 480b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1087
+
+--S 1088 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                    +--------+
+--R                     5 10             5        2 4  8        2 4 6  |   2
+--R           (- 18B b c x   + (- 30A b c  - 60B b c )x  - 80A b c x )\|c x  + b
+--R         + 
+--R                   6 12        6          5  10           5        2 4  8
+--R               3B c x   + (5A c  + 48B b c )x   + (70A b c  + 60B b c )x
+--R             + 
+--R                    2 4 6
+--R               80A b c x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 6 13          6          5  11             5        2 4  9
+--R           - 3B c x   + (- 5A c  - 48B b c )x   + (- 70A b c  - 60B b c )x
+--R         + 
+--R                  2 4         3 3  7           3 3          4 2  5
+--R           (160A b c  - 288B b c )x  + (1520A b c  - 1824B b c )x
+--R         + 
+--R                   4 2          5   3           5           6
+--R           (2560A b c  - 3072B b c)x  + (1280A b c - 1536B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R              6 13           6        2 5  11         2 5         3 4  9
+--R       18B b c x   + (30A b c  + 78B b c )x   + (70A b c  + 108B b c )x
+--R     + 
+--R                3 4         4 3  7             4 3          5 2  5
+--R       (- 680A b c  + 912B b c )x  + (- 2640A b c  + 3168B b c )x
+--R     + 
+--R                 5 2          6   3             6           7
+--R       (- 3200A b c  + 3840B b c)x  + (- 1280A b c + 1536B b )x
+--R  /
+--R                                                        +--------+
+--R             7 6         6 4       2 5 2       3 4  +-+ |   2             7 6
+--R         (15c x  + 270b c x  + 720b c x  + 480b c )\|b \|c x  + b  - 90b c x
+--R       + 
+--R               2 6 4       3 5 2       4 4
+--R         - 570b c x  - 960b c x  - 480b c
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1088
+
+--S 1089 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      5 17           5           4  15
+--R               - 12B c x   + (- 12A c  - 280B b c )x
+--R             + 
+--R                          4          2 3  13             2 3          3 2  11
+--R               (- 280A b c  - 1792B b c )x   + (- 1792A b c  - 4608B b c )x
+--R             + 
+--R                         3 2          4   9             4           5  7
+--R               (- 4608A b c  - 5120B b c)x  + (- 5120A b c - 2048B b )x
+--R             + 
+--R                        5 5
+--R               - 2048A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              6 19       6          5  17           5         2 4  15
+--R           B c x   + (A c  + 72B b c )x   + (72A b c  + 840B b c )x
+--R         + 
+--R                  2 4          3 3  13           3 3          4 2  11
+--R           (840A b c  + 3584B b c )x   + (3584A b c  + 6912B b c )x
+--R         + 
+--R                   4 2          5   9           5           6  7          6 5
+--R           (6912A b c  + 6144B b c)x  + (6144A b c + 2048B b )x  + 2048A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                6 20         6          5  18             5         2 4  16
+--R           - B c x   + (- A c  - 72B b c )x   + (- 72A b c  - 840B b c )x
+--R         + 
+--R                    2 4          3 3  14             3 3          4 2  12
+--R           (- 840A b c  - 3584B b c )x   + (- 3584A b c  - 6912B b c )x
+--R         + 
+--R                   4 2          5   10             5           6  8          6 6
+--R         (- 6912A b c  - 6144B b c)x   + (- 6144A b c - 2048B b )x  - 2048A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                6 20         6           5  18            5          2 4  16
+--R           12B c x   + (12A c  + 292B b c )x   + (292A b c  + 2072B b c )x
+--R         + 
+--R                   2 4          3 3  14           3 3          4 2  12
+--R           (2072A b c  + 6400B b c )x   + (6400A b c  + 9728B b c )x
+--R         + 
+--R                   4 2          5   10           5           6  8          6 6
+--R           (9728A b c  + 7168B b c)x   + (7168A b c + 2048B b )x  + 2048A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              7 14        6 12       2 5 10        3 4 8         4 3 6
+--R             c x   + 73b c x   + 912b c x   + 4424b c x  + 10496b c x
+--R           + 
+--R                   5 2 4        6   2        7
+--R             13056b c x  + 8192b c x  + 2048b
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R                  7 14         6 12        2 5 10        3 4 8         4 3 6
+--R             - 12c x   - 304b c x   - 2364b c x   - 8472b c x  - 16128b c x
+--R           + 
+--R                     5 2 4        6   2        7
+--R             - 16896b c x  - 9216b c x  - 2048b
+--R        *
+--R            +-+
+--R           \|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1089
+
+)clear all
+
+--S 1090 of 3139
+t0:=x^6*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  6      4
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1090
+
+--S 1091 of 3139
+r0:=-(b*B-A*c)*x^5/(b*c*sqrt(b*x^2+c*x^4))-2/3*(4*b*B-3*A*c)*_
+   sqrt(b*x^2+c*x^4)/(c^3*x)+1/3*(4*b*B-3*A*c)*x*sqrt(b*x^2+c*x^4)/(b*c^2)
+--R 
+--R
+--R           2 5        2           3                 2
+--R        B c x  + (3A c  - 4B b c)x  + (6A b c - 8B b )x
+--R   (2)  -----------------------------------------------
+--R                           +-----------+
+--R                         3 |   4      2
+--R                       3c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1091
+
+--S 1092 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         +--------+
+--R            6         4  |   2              8                 6         4  +-+
+--R   (- 4B b x  - 6A b x )\|c x  + b  + (B c x  + (3A c + 4B b)x  + 6A b x )\|b
+--R   ---------------------------------------------------------------------------
+--R                                    +--------+
+--R         2 4          2      2  +-+ |   2             2 4      2   2      3
+--R      (3c x  + 24b c x  + 24b )\|b \|c x  + b  - 12b c x  - 36b c x  - 24b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1092
+
+--S 1093 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     +--------+
+--R                    3 6         3 4  |   2
+--R           (- 4B b c x  - 6A b c x )\|c x  + b
+--R         + 
+--R               4 8        4         3  6         3 4  +-+
+--R           (B c x  + (3A c  + 4B b c )x  + 6A b c x )\|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                4 9          4         3  7             3        2 2  5
+--R           - B c x  + (- 3A c  - 4B b c )x  + (- 30A b c  + 32B b c )x
+--R         + 
+--R                   2 2        3   3           3         4
+--R           (- 72A b c  + 96B b c)x  + (- 48A b c + 64B b )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R             4 9           4       2 3  7         2 3        3 2  5
+--R       4B b c x  + (12A b c  - 4B b c )x  + (60A b c  - 72B b c )x
+--R     + 
+--R             3 2         4   3         4         5
+--R       (96A b c  - 128B b c)x  + (48A b c - 64B b )x
+--R  /
+--R                                           +--------+
+--R              5 4        4 2      2 3  +-+ |   2             5 4      2 4 2
+--R           (3c x  + 24b c x  + 24b c )\|b \|c x  + b  - 12b c x  - 36b c x
+--R         + 
+--R                3 3
+--R           - 24b c
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1093
+
+--S 1094 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     3 11          3          2  9             2         2   7
+--R               - 8B c x   + (- 8A c  - 80B b c )x  + (- 80A b c  - 192B b c)x
+--R             + 
+--R                        2          3  5         3 3
+--R               (- 192A b c - 128B b )x  - 128A b x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R              4 13       4          3  11           3         2 2  9
+--R           B c x   + (A c  + 32B b c )x   + (32A b c  + 160B b c )x
+--R         + 
+--R                  2 2         3   7          3          4  5         4 3
+--R           (160A b c  + 256B b c)x  + (256A b c + 128B b )x  + 128A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                4 14         4          3  12             3         2 2  10
+--R           - B c x   + (- A c  - 32B b c )x   + (- 32A b c  - 160B b c )x
+--R         + 
+--R                    2 2         3   8            3          4  6         4 4
+--R           (- 160A b c  - 256B b c)x  + (- 256A b c - 128B b )x  - 128A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R               4 14        4          3  12           3         2 2  10
+--R           8B c x   + (8A c  + 88B b c )x   + (88A b c  + 272B b c )x
+--R         + 
+--R                  2 2         3   8          3          4  6         4 4
+--R           (272A b c  + 320B b c)x  + (320A b c + 128B b )x  + 128A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R             5 10        4 8       2 3 6       3 2 4       4   2       5
+--R           (c x   + 33b c x  + 192b c x  + 416b c x  + 384b c x  + 128b )
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|c x  + b
+--R       + 
+--R              5 10        4 8       2 3 6       3 2 4       4   2       5  +-+
+--R         (- 8c x   - 96b c x  - 360b c x  - 592b c x  - 448b c x  - 128b )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1094
+
+)clear all
+
+--S 1095 of 3139
+t0:=x^4*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  4      2
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1095
+
+--S 1096 of 3139
+r0:=-(b*B-A*c)*x^3/(b*c*sqrt(b*x^2+c*x^4))+(2*b*B-A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*c^2*x)
+--R 
+--R
+--R             3
+--R        B c x  + (- A c + 2B b)x
+--R   (2)  ------------------------
+--R               +-----------+
+--R             2 |   4      2
+--R            c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1096
+
+--S 1097 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +--------+
+--R                2 |   2            4      2  +-+
+--R           - A x \|c x  + b  + (B x  + A x )\|b
+--R   (3)  ------------------------------------------
+--R                        +--------+
+--R            2       +-+ |   2              2     2
+--R        (c x  + 2b)\|b \|c x  + b  - 2b c x  - 2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1097
+
+--S 1098 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 +--------+                          +-----------+
+--R             2 2 |   2            2 4      2 2  +-+  |   4      2
+--R       (- A c x \|c x  + b  + (B c x  + A c x )\|b )\|c x  + b x
+--R     + 
+--R                                                              +--------+
+--R             2 5       2           3                 2    +-+ |   2
+--R       (- B c x  + (A c  - 4B b c)x  + (2A b c - 4B b )x)\|b \|c x  + b
+--R     + 
+--R             2 5            2       2   3          2        3
+--R       2B b c x  + (- 2A b c  + 6B b c)x  + (- 2A b c + 4B b )x
+--R  /
+--R                         +--------+                    +-----------+
+--R        3 2       2  +-+ |   2            3 2     2 2  |   4      2
+--R     ((c x  + 2b c )\|b \|c x  + b  - 2b c x  - 2b c )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1098
+
+--S 1099 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                        +--------+
+--R                    5                   3           +-+ |   2           2 7
+--R           (- 4B c x  + (- 4A c - 8B b)x  - 8A b x)\|b \|c x  + b  + B c x
+--R         + 
+--R               2           5                 2  3       2
+--R           (A c  + 8B b c)x  + (8A b c + 8B b )x  + 8A b x
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R               2 8         2           6                   2  4       2 2
+--R         (- B c x  + (- A c  - 8B b c)x  + (- 8A b c - 8B b )x  - 8A b x )
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R            2 8        2            6                  2  4       2 2  +-+
+--R       (4B c x  + (4A c  + 12B b c)x  + (12A b c + 8B b )x  + 8A b x )\|b
+--R  /
+--R                                           +--------+
+--R           3 6       2 4      2   2     3  |   2
+--R         (c x  + 9b c x  + 16b c x  + 8b )\|c x  + b
+--R       + 
+--R              3 6        2 4      2   2     3  +-+
+--R         (- 4c x  - 16b c x  - 20b c x  - 8b )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1099
+
+)clear all
+
+--S 1100 of 3139
+t0:=x^2*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                   2
+--R                B x  + A
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1100
+
+--S 1101 of 3139
+r0:=-A*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-_
+   (b*B-A*c)*x/(b*c*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R              +-----------+             +-+
+--R              |   4      2            x\|b                      +-+
+--R        - A c\|c x  + b x  atanh(--------------) + (A c - B b)x\|b
+--R                                  +-----------+
+--R                                  |   4      2
+--R                                 \|c x  + b x
+--R   (2)  -----------------------------------------------------------
+--R                                   +-----------+
+--R                               +-+ |   4      2
+--R                           b c\|b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1101
+
+--S 1102 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                   +--------+
+--R            +--------+                             |   2         +-+
+--R            |   2                2        +-+     \|c x  + b  - \|b
+--R       (A b\|c x  + b  + (- A c x  - A b)\|b )log(------------------)
+--R                                                           x
+--R     + 
+--R                     2 +-+
+--R       (- A c + B b)x \|b
+--R  /
+--R            +--------+
+--R      2 +-+ |   2         2   2    3
+--R     b \|b \|c x  + b  - b c x  - b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1102
+
+--S 1103 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +--------+                   +-----------+
+--R              +-+ |   2           2 2          |   4      2
+--R         (A c\|b \|c x  + b  - A c x  - A b c)\|c x  + b x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                +--------+                   +-----------+             +-+
+--R            +-+ |   2           2 2          |   4      2            x\|b
+--R       (A c\|b \|c x  + b  - A c x  - A b c)\|c x  + b x  atanh(--------------)
+--R                                                                 +-----------+
+--R                                                                 |   4      2
+--R                                                                \|c x  + b x
+--R     + 
+--R                          +-----------+                     +--------+
+--R             2          2 |   4      2                  2   |   2
+--R       (- A c  + B b c)x \|c x  + b x   + (- A b c + B b )x\|c x  + b
+--R     + 
+--R            2          3               2    +-+
+--R       ((A c  - B b c)x  + (A b c - B b )x)\|b
+--R  /
+--R          +--------+                         +-----------+
+--R       2  |   2              2 2    2   +-+  |   4      2
+--R     (b c\|c x  + b  + (- b c x  - b c)\|b )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1103
+
+--S 1104 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                             +--------+
+--R                 2       +-+ |   2             4                2
+--R         ((- 2B x  - 2A)\|b \|c x  + b  + B c x  + (A c + 2B b)x  + 2A b)
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                              +--------+
+--R               5                  3           |   2
+--R       (- B c x  + (- A c - 2B b)x  - 2A b x)\|c x  + b
+--R     + 
+--R              5                 3           +-+
+--R       (2B c x  + (2A c + 2B b)x  + 2A b x)\|b
+--R  /
+--R                                +--------+
+--R          2 5         3     2   |   2             2 5         3     2   +-+
+--R       ((c x  + 3b c x  + 2b x)\|c x  + b  + (- 2c x  - 4b c x  - 2b x)\|b )
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1104
+
+)clear all
+
+--S 1105 of 3139
+t0:=(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            4      2  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1105
+
+--S 1106 of 3139
+r0:=-1/2*(2*b*B-3*A*c)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)-_
+   1/3*B/(c*x*sqrt(b*x^2+c*x^4))+1/3*(-2*b*B+3*A*c)/(b*c*x*_
+   sqrt(b*x^2+c*x^4))+1/2*(2*b*B-3*A*c)*sqrt(b*x^2+c*x^4)/(b^2*c*x^3)
+--R 
+--R
+--R   (2)
+--R                      +-----------+             +-+
+--R                      |   4      2            x\|b
+--R       (3A c - 2B b)x\|c x  + b x  atanh(--------------)
+--R                                          +-----------+
+--R                                          |   4      2
+--R                                         \|c x  + b x
+--R     + 
+--R                        2        +-+
+--R       ((- 3A c + 2B b)x  - A b)\|b
+--R  /
+--R              +-----------+
+--R       2  +-+ |   4      2
+--R     2b x\|b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1106
+
+--S 1107 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                            +--------+
+--R                     2       2   4           2        3  2  |   2
+--R           ((- 9A b c  + 6B b c)x  + (- 12A b c + 8B b )x )\|c x  + b
+--R         + 
+--R                      3         2  6           2        2   4
+--R                 (3A c  - 2B b c )x  + (15A b c  - 10B b c)x
+--R               + 
+--R                       2        3  2
+--R                 (12A b c - 8B b )x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                                    +--------+
+--R                 2       2   4       2   2       3  |   2
+--R       ((- 3A b c  + 4B b c)x  + 5A b c x  + 4A b )\|c x  + b
+--R     + 
+--R             3         2  6         2       2   4       2   2       3  +-+
+--R       ((2A c  - 2B b c )x  + (A b c  - 4B b c)x  - 7A b c x  - 4A b )\|b
+--R  /
+--R                           +--------+
+--R        3   4     4 2  +-+ |   2          3 2 6      4   4     5 2
+--R     (6b c x  + 8b x )\|b \|c x  + b  - 2b c x  - 10b c x  - 8b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1107
+
+--S 1108 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                              +--------+
+--R                   2           4                    2  2  +-+ |   2
+--R           ((- 9A c  + 6B b c)x  + (- 12A b c + 8B b )x )\|b \|c x  + b
+--R         + 
+--R                3         2  6           2        2   4         2        3  2
+--R           (3A c  - 2B b c )x  + (15A b c  - 10B b c)x  + (12A b c - 8B b )x
+--R      *
+--R                            +--------+
+--R          +-----------+     |   2         +-+
+--R          |   4      2     \|c x  + b  - \|b
+--R         \|c x  + b x  log(------------------)
+--R                                    x
+--R     + 
+--R                                                              +--------+
+--R                   2           4                    2  2  +-+ |   2
+--R           ((- 9A c  + 6B b c)x  + (- 12A b c + 8B b )x )\|b \|c x  + b
+--R         + 
+--R                3         2  6           2        2   4         2        3  2
+--R           (3A c  - 2B b c )x  + (15A b c  - 10B b c)x  + (12A b c - 8B b )x
+--R      *
+--R          +-----------+             +-+
+--R          |   4      2            x\|b
+--R         \|c x  + b x  atanh(--------------)
+--R                              +-----------+
+--R                              |   4      2
+--R                             \|c x  + b x
+--R     + 
+--R                                                          +--------+
+--R                   2           4           2       2  +-+ |   2
+--R           ((- 3A c  + 4B b c)x  + 5A b c x  + 4A b )\|b \|c x  + b
+--R         + 
+--R                3         2  6         2       2   4       2   2       3
+--R           (2A c  - 2B b c )x  + (A b c  - 4B b c)x  - 7A b c x  - 4A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                                                             +--------+
+--R               2       2   5         2        3  3       3   |   2
+--R       ((9A b c  - 6B b c)x  + (15A b c - 8B b )x  + 4A b x)\|c x  + b
+--R     + 
+--R                  3         2  7             2        2   5
+--R           (- 3A c  + 2B b c )x  + (- 16A b c  + 10B b c)x
+--R         + 
+--R                   2        3  3       3
+--R           (- 17A b c + 8B b )x  - 4A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                          +--------+
+--R           3   4     4 2  |   2             2 2 6      3   4     4 2  +-+
+--R       ((6b c x  + 8b x )\|c x  + b  + (- 2b c x  - 10b c x  - 8b x )\|b )
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1108
+
+--S 1109 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    3 8         3          2  6             2        2   4
+--R               - B c x  + (- A c  - 24B b c )x  + (- 24A b c  - 80B b c)x
+--R             + 
+--R                       2         3  2        3
+--R               (- 80A b c - 64B b )x  - 64A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                   3 8        3          2  6           2         2   4
+--R               7B c x  + (7A c  + 56B b c )x  + (56A b c  + 112B b c)x
+--R             + 
+--R                      2         3  2        3
+--R               (112A b c + 64B b )x  + 64A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                 3 9          3          2  7             2         2   5
+--R           - 7B c x  + (- 7A c  - 56B b c )x  + (- 56A b c  - 112B b c)x
+--R         + 
+--R                    2         3  3        3
+--R           (- 112A b c - 64B b )x  - 64A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          4 11       4          3  9           3         2 2  7
+--R       B c x   + (A c  + 25B b c )x  + (25A b c  + 104B b c )x
+--R     + 
+--R              2 2         3   5          3         4  3        4
+--R       (104A b c  + 144B b c)x  + (144A b c + 64B b )x  + 64A b x
+--R  /
+--R                                                                  +--------+
+--R            4 11        3 9       2 2 7       3   5      4 3  +-+ |   2
+--R         (7c x   + 63b c x  + 168b c x  + 176b c x  + 64b x )\|b \|c x  + b
+--R       + 
+--R            5 13        4 11       2 3 9       3 2 7       4   5      5 3
+--R         - c x   - 26b c x   - 129b c x  - 248b c x  - 208b c x  - 64b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1109
+
+)clear all
+
+--S 1110 of 3139
+t0:=(A+B*x^2)/(x^2*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            6      4  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1110
+
+--S 1111 of 3139
+r0:=3/8*c*(4*b*B-5*A*c)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(7/2)-_
+   1/4*A/(b*x^3*sqrt(b*x^2+c*x^4))+1/4*(4*b*B-5*A*c)/(b^2*x*_
+   sqrt(b*x^2+c*x^4))-3/8*(4*b*B-5*A*c)*sqrt(b*x^2+c*x^4)/(b^3*x^3)
+--R 
+--R
+--R   (2)
+--R                              +-----------+             +-+
+--R               2            3 |   4      2            x\|b
+--R       (- 15A c  + 12B b c)x \|c x  + b x  atanh(--------------)
+--R                                                  +-----------+
+--R                                                  |   4      2
+--R                                                 \|c x  + b x
+--R     + 
+--R              2            4                 2  2       2  +-+
+--R       ((15A c  - 12B b c)x  + (5A b c - 4B b )x  - 2A b )\|b
+--R  /
+--R               +-----------+
+--R       3 3 +-+ |   4      2
+--R     8b x \|b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1111
+
+--S 1112 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       4        2 3  8          2 3         3 2  6
+--R               (75A b c  - 60B b c )x  + (300A b c  - 240B b c )x
+--R             + 
+--R                      3 2         4   4
+--R               (240A b c  - 192B b c)x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                       5          4  10              4         2 3  8
+--R               (- 15A c  + 12B b c )x   + (- 195A b c  + 156B b c )x
+--R             + 
+--R                        2 3         3 2  6            3 2         4   4
+--R               (- 420A b c  + 336B b c )x  + (- 240A b c  + 192B b c)x
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|c x  + b  - \|b
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                   4        2 3  8           2 3        3 2  6
+--R           (25A b c  - 28B b c )x  + (- 25A b c  - 12B b c )x
+--R         + 
+--R                    3 2         4   4           4         5  2        5
+--R           (- 170A b c  + 112B b c)x  + (- 56A b c + 64B b )x  + 32A b
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                  5         4  10             4        2 3  8
+--R           (- 8A c  + 8B b c )x   + (- 29A b c  + 44B b c )x
+--R         + 
+--R                  2 3        3 2  6          3 2         4   4
+--R           (101A b c  - 36B b c )x  + (202A b c  - 144B b c)x
+--R         + 
+--R                 4         5  2        5
+--R           (40A b c - 64B b )x  - 32A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                            +--------+
+--R           4 2 8       5   6       6 4  +-+ |   2          4 3 10       5 2 8
+--R       (40b c x  + 160b c x  + 128b x )\|b \|c x  + b  - 8b c x   - 104b c x
+--R     + 
+--R             6   6       7 4
+--R       - 224b c x  - 128b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1112
+
+--S 1113 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     4          3  8            3         2 2  6
+--R               (75A c  - 60B b c )x  + (300A b c  - 240B b c )x
+--R             + 
+--R                      2 2         3   4
+--R               (240A b c  - 192B b c)x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   5          4  10              4         2 3  8
+--R           (- 15A c  + 12B b c )x   + (- 195A b c  + 156B b c )x
+--R         + 
+--R                    2 3         3 2  6            3 2         4   4
+--R           (- 420A b c  + 336B b c )x  + (- 240A b c  + 192B b c)x
+--R      *
+--R                            +--------+
+--R          +-----------+     |   2         +-+
+--R          |   4      2     \|c x  + b  - \|b
+--R         \|c x  + b x  log(------------------)
+--R                                    x
+--R     + 
+--R                     4          3  8            3         2 2  6
+--R               (75A c  - 60B b c )x  + (300A b c  - 240B b c )x
+--R             + 
+--R                      2 2         3   4
+--R               (240A b c  - 192B b c)x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                   5          4  10              4         2 3  8
+--R           (- 15A c  + 12B b c )x   + (- 195A b c  + 156B b c )x
+--R         + 
+--R                    2 3         3 2  6            3 2         4   4
+--R           (- 420A b c  + 336B b c )x  + (- 240A b c  + 192B b c)x
+--R      *
+--R          +-----------+             +-+
+--R          |   4      2            x\|b
+--R         \|c x  + b x  atanh(--------------)
+--R                              +-----------+
+--R                              |   4      2
+--R                             \|c x  + b x
+--R     + 
+--R                     4          3  8             3        2 2  6
+--R               (25A c  - 28B b c )x  + (- 25A b c  - 12B b c )x
+--R             + 
+--R                        2 2         3   4           3         4  2        4
+--R               (- 170A b c  + 112B b c)x  + (- 56A b c + 64B b )x  + 32A b
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|b \|c x  + b
+--R         + 
+--R                  5         4  10             4        2 3  8
+--R           (- 8A c  + 8B b c )x   + (- 29A b c  + 44B b c )x
+--R         + 
+--R                  2 3        3 2  6          3 2         4   4
+--R           (101A b c  - 36B b c )x  + (202A b c  - 144B b c)x
+--R         + 
+--R                 4         5  2        5
+--R           (40A b c - 64B b )x  - 32A b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                     4        2 3  9            2 3         3 2  7
+--R           (- 75A b c  + 60B b c )x  + (- 325A b c  + 260B b c )x
+--R         + 
+--R                    3 2         4   5           4         5  3        5
+--R           (- 330A b c  + 272B b c)x  + (- 40A b c + 64B b )x  + 32A b x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|c x  + b
+--R     + 
+--R                 5          4  11            4         2 3  9
+--R           (15A c  - 12B b c )x   + (200A b c  - 160B b c )x
+--R         + 
+--R                  2 3         3 2  7          3 2         4   5
+--R           (483A b c  - 388B b c )x  + (354A b c  - 304B b c)x
+--R         + 
+--R                 4         5  3        5
+--R           (24A b c - 64B b )x  - 32A b x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                          +--------+
+--R             4 2 8       5   6       6 4  |   2
+--R         (40b c x  + 160b c x  + 128b x )\|c x  + b
+--R       + 
+--R              3 3 10       4 2 8       5   6       6 4  +-+
+--R         (- 8b c x   - 104b c x  - 224b c x  - 128b x )\|b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1113
+
+--S 1114 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    5 12         5          4  10             4         2 3  8
+--R               - B c x   + (- A c  - 60B b c )x   + (- 60A b c  - 560B b c )x
+--R             + 
+--R                        2 3          3 2  6             3 2          4   4
+--R               (- 560A b c  - 1792B b c )x  + (- 1792A b c  - 2304B b c)x
+--R             + 
+--R                         4           5  2          5
+--R               (- 2304A b c - 1024B b )x  - 1024A b
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + b
+--R         + 
+--R                    5 12         5           4  10            4          2 3  8
+--R               11B c x   + (11A c  + 220B b c )x   + (220A b c  + 1232B b c )x
+--R             + 
+--R                       2 3          3 2  6           3 2          4   4
+--R               (1232A b c  + 2816B b c )x  + (2816A b c  + 2816B b c)x
+--R             + 
+--R                       4           5  2          5
+--R               (2816A b c + 1024B b )x  + 1024A b
+--R          *
+--R              +-+
+--R             \|b
+--R      *
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R     + 
+--R                  5 13           5           4  11
+--R           - 11B c x   + (- 11A c  - 220B b c )x
+--R         + 
+--R                      4          2 3  9             2 3          3 2  7
+--R           (- 220A b c  - 1232B b c )x  + (- 1232A b c  - 2816B b c )x
+--R         + 
+--R                   3 2          4   5             4           5  3          5
+--R         (- 2816A b c  - 2816B b c)x  + (- 2816A b c - 1024B b )x  - 1024A b x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|b \|c x  + b
+--R     + 
+--R          6 15       6          5  13           5         2 4  11
+--R       B c x   + (A c  + 61B b c )x   + (61A b c  + 620B b c )x
+--R     + 
+--R              2 4          3 3  9           3 3          4 2  7
+--R       (620A b c  + 2352B b c )x  + (2352A b c  + 4096B b c )x
+--R     + 
+--R               4 2          5   5           5           6  3          6
+--R       (4096A b c  + 3328B b c)x  + (3328A b c + 1024B b )x  + 1024A b x
+--R  /
+--R                6 17         5 15        2 4 13        3 3 11        4 2 9
+--R             11c x   + 231b c x   + 1452b c x   + 4048b c x   + 5632b c x
+--R           + 
+--R                  5   7        6 5
+--R             3840b c x  + 1024b x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|b \|c x  + b
+--R       + 
+--R            7 19        6 17       2 5 15        3 4 13        4 3 11
+--R         - c x   - 62b c x   - 681b c x   - 2972b c x   - 6448b c x
+--R       + 
+--R                5 2 9        6   7        7 5
+--R         - 7424b c x  - 4352b c x  - 1024b x
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1114
+
+)clear all
+
+--S 1115 of 3139
+t0:=x^(7/2)*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R              9               7        5  +-+
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1115
+
+--S 1116 of 3139
+r0:=2/13*A*b*x^(13/2)+2/17*(b*B+A*c)*x^(17/2)+2/21*B*c*x^(21/2)
+--R 
+--R
+--R                 10                     8           6  +-+
+--R        (442B c x   + (546A c + 546B b)x  + 714A b x )\|x
+--R   (2)  --------------------------------------------------
+--R                               4641
+--R                                                    Type: Expression(Integer)
+--E 1116
+
+--S 1117 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 10                     8           6  +-+
+--R        (442B c x   + (546A c + 546B b)x  + 714A b x )\|x
+--R   (3)  --------------------------------------------------
+--R                               4641
+--R                                         Type: Union(Expression(Integer),...)
+--E 1117
+
+--S 1118 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1118
+
+--S 1119 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1119
+
+)clear all
+
+--S 1120 of 3139
+t0:=x^(5/2)*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R              8               6        4  +-+
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1120
+
+--S 1121 of 3139
+r0:=2/11*A*b*x^(11/2)+2/15*(b*B+A*c)*x^(15/2)+2/19*B*c*x^(19/2)
+--R 
+--R
+--R                 9                     7           5  +-+
+--R        (330B c x  + (418A c + 418B b)x  + 570A b x )\|x
+--R   (2)  -------------------------------------------------
+--R                               3135
+--R                                                    Type: Expression(Integer)
+--E 1121
+
+--S 1122 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 9                     7           5  +-+
+--R        (330B c x  + (418A c + 418B b)x  + 570A b x )\|x
+--R   (3)  -------------------------------------------------
+--R                               3135
+--R                                         Type: Union(Expression(Integer),...)
+--E 1122
+
+--S 1123 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1123
+
+--S 1124 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1124
+
+)clear all
+
+--S 1125 of 3139
+t0:=x^(3/2)*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R              7               5        3  +-+
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1125
+
+--S 1126 of 3139
+r0:=2/9*A*b*x^(9/2)+2/13*(b*B+A*c)*x^(13/2)+2/17*B*c*x^(17/2)
+--R 
+--R
+--R                 8                     6           4  +-+
+--R        (234B c x  + (306A c + 306B b)x  + 442A b x )\|x
+--R   (2)  -------------------------------------------------
+--R                               1989
+--R                                                    Type: Expression(Integer)
+--E 1126
+
+--S 1127 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 8                     6           4  +-+
+--R        (234B c x  + (306A c + 306B b)x  + 442A b x )\|x
+--R   (3)  -------------------------------------------------
+--R                               1989
+--R                                         Type: Union(Expression(Integer),...)
+--E 1127
+
+--S 1128 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1128
+
+--S 1129 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1129
+
+)clear all
+
+--S 1130 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)*sqrt(x)
+--R 
+--R
+--R              6               4        2  +-+
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1130
+
+--S 1131 of 3139
+r0:=2/7*A*b*x^(7/2)+2/11*(b*B+A*c)*x^(11/2)+2/15*B*c*x^(15/2)
+--R 
+--R
+--R                 7                     5           3  +-+
+--R        (154B c x  + (210A c + 210B b)x  + 330A b x )\|x
+--R   (2)  -------------------------------------------------
+--R                               1155
+--R                                                    Type: Expression(Integer)
+--E 1131
+
+--S 1132 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 7                     5           3  +-+
+--R        (154B c x  + (210A c + 210B b)x  + 330A b x )\|x
+--R   (3)  -------------------------------------------------
+--R                               1155
+--R                                         Type: Union(Expression(Integer),...)
+--E 1132
+
+--S 1133 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1133
+
+--S 1134 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1134
+
+)clear all
+
+--S 1135 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/sqrt(x)
+--R 
+--R
+--R             6               4        2
+--R        B c x  + (A c + B b)x  + A b x
+--R   (1)  -------------------------------
+--R                       +-+
+--R                      \|x
+--R                                                    Type: Expression(Integer)
+--E 1135
+
+--S 1136 of 3139
+r0:=2/5*A*b*x^(5/2)+2/9*(b*B+A*c)*x^(9/2)+2/13*B*c*x^(13/2)
+--R 
+--R
+--R                6                     4           2  +-+
+--R        (90B c x  + (130A c + 130B b)x  + 234A b x )\|x
+--R   (2)  ------------------------------------------------
+--R                               585
+--R                                                    Type: Expression(Integer)
+--E 1136
+
+--S 1137 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                6                     4           2  +-+
+--R        (90B c x  + (130A c + 130B b)x  + 234A b x )\|x
+--R   (3)  ------------------------------------------------
+--R                               585
+--R                                         Type: Union(Expression(Integer),...)
+--E 1137
+
+--S 1138 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1138
+
+--S 1139 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1139
+
+)clear all
+
+--S 1140 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^(3/2)
+--R 
+--R
+--R             5               3
+--R        B c x  + (A c + B b)x  + A b x
+--R   (1)  ------------------------------
+--R                      +-+
+--R                     \|x
+--R                                                    Type: Expression(Integer)
+--E 1140
+
+--S 1141 of 3139
+r0:=2/3*A*b*x^(3/2)+2/7*(b*B+A*c)*x^(7/2)+2/11*B*c*x^(11/2)
+--R 
+--R
+--R                5                   3             +-+
+--R        (42B c x  + (66A c + 66B b)x  + 154A b x)\|x
+--R   (2)  ---------------------------------------------
+--R                             231
+--R                                                    Type: Expression(Integer)
+--E 1141
+
+--S 1142 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                5                   3             +-+
+--R        (42B c x  + (66A c + 66B b)x  + 154A b x)\|x
+--R   (3)  ---------------------------------------------
+--R                             231
+--R                                         Type: Union(Expression(Integer),...)
+--E 1142
+
+--S 1143 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1143
+
+--S 1144 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1144
+
+)clear all
+
+--S 1145 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^(5/2)
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                     +-+
+--R                    \|x
+--R                                                    Type: Expression(Integer)
+--E 1145
+
+--S 1146 of 3139
+r0:=2/5*(b*B+A*c)*x^(5/2)+2/9*B*c*x^(9/2)+2*A*b*sqrt(x)
+--R 
+--R
+--R                4                   2          +-+
+--R        (10B c x  + (18A c + 18B b)x  + 90A b)\|x
+--R   (2)  ------------------------------------------
+--R                            45
+--R                                                    Type: Expression(Integer)
+--E 1146
+
+--S 1147 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                4                   2          +-+
+--R        (10B c x  + (18A c + 18B b)x  + 90A b)\|x
+--R   (3)  ------------------------------------------
+--R                            45
+--R                                         Type: Union(Expression(Integer),...)
+--E 1147
+
+--S 1148 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1148
+
+--S 1149 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1149
+
+)clear all
+
+--S 1150 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^(7/2)
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      +-+
+--R                    x\|x
+--R                                                    Type: Expression(Integer)
+--E 1150
+
+--S 1151 of 3139
+r0:=2/3*(b*B+A*c)*x^(3/2)+2/7*B*c*x^(7/2)-2*A*b/sqrt(x)
+--R 
+--R
+--R              4                   2
+--R        6B c x  + (14A c + 14B b)x  - 42A b
+--R   (2)  -----------------------------------
+--R                          +-+
+--R                       21\|x
+--R                                                    Type: Expression(Integer)
+--E 1151
+
+--S 1152 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4                   2
+--R        6B c x  + (14A c + 14B b)x  - 42A b
+--R   (3)  -----------------------------------
+--R                          +-+
+--R                       21\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1152
+
+--S 1153 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1153
+
+--S 1154 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1154
+
+)clear all
+
+--S 1155 of 3139
+t0:=x^(7/2)*(A+B*x^2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R            2 13       2           11                2  9      2 7  +-+
+--R   (1)  (B c x   + (A c  + 2B b c)x   + (2A b c + B b )x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1155
+
+--S 1156 of 3139
+r0:=2/17*A*b^2*x^(17/2)+2/21*b*(b*B+2*A*c)*x^(21/2)+_
+   2/25*c*(2*b*B+A*c)*x^(25/2)+2/29*B*c^2*x^(29/2)
+--R 
+--R
+--R   (2)
+--R                 2 14            2               12
+--R         17850B c x   + (20706A c  + 41412B b c)x
+--R       + 
+--R                               2  10           2 8
+--R         (49300A b c + 24650B b )x   + 30450A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     258825
+--R                                                    Type: Expression(Integer)
+--E 1156
+
+--S 1157 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2 14            2               12
+--R         17850B c x   + (20706A c  + 41412B b c)x
+--R       + 
+--R                               2  10           2 8
+--R         (49300A b c + 24650B b )x   + 30450A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     258825
+--R                                         Type: Union(Expression(Integer),...)
+--E 1157
+
+--S 1158 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1158
+
+--S 1159 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1159
+
+)clear all
+
+--S 1160 of 3139
+t0:=x^(5/2)*(A+B*x^2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R            2 12       2           10                2  8      2 6  +-+
+--R   (1)  (B c x   + (A c  + 2B b c)x   + (2A b c + B b )x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1160
+
+--S 1161 of 3139
+r0:=2/15*A*b^2*x^(15/2)+2/19*b*(b*B+2*A*c)*x^(19/2)+_
+   2/23*c*(2*b*B+A*c)*x^(23/2)+2/27*B*c^2*x^(27/2)
+--R 
+--R
+--R   (2)
+--R                2 13           2               11                        2  9
+--R         4370B c x   + (5130A c  + 10260B b c)x   + (12420A b c + 6210B b )x
+--R       + 
+--R                2 7
+--R         7866A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     58995
+--R                                                    Type: Expression(Integer)
+--E 1161
+
+--S 1162 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 13           2               11                        2  9
+--R         4370B c x   + (5130A c  + 10260B b c)x   + (12420A b c + 6210B b )x
+--R       + 
+--R                2 7
+--R         7866A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     58995
+--R                                         Type: Union(Expression(Integer),...)
+--E 1162
+
+--S 1163 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1163
+
+--S 1164 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1164
+
+)clear all
+
+--S 1165 of 3139
+t0:=x^(3/2)*(A+B*x^2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R            2 11       2           9                2  7      2 5  +-+
+--R   (1)  (B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1165
+
+--S 1166 of 3139
+r0:=2/13*A*b^2*x^(13/2)+2/17*b*(b*B+2*A*c)*x^(17/2)+_
+   2/21*c*(2*b*B+A*c)*x^(21/2)+2/25*B*c^2*x^(25/2)
+--R 
+--R
+--R   (2)
+--R                2 12            2               10                         2  8
+--R         9282B c x   + (11050A c  + 22100B b c)x   + (27300A b c + 13650B b )x
+--R       + 
+--R                 2 6
+--R         17850A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     116025
+--R                                                    Type: Expression(Integer)
+--E 1166
+
+--S 1167 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 12            2               10                         2  8
+--R         9282B c x   + (11050A c  + 22100B b c)x   + (27300A b c + 13650B b )x
+--R       + 
+--R                 2 6
+--R         17850A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     116025
+--R                                         Type: Union(Expression(Integer),...)
+--E 1167
+
+--S 1168 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1168
+
+--S 1169 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1169
+
+)clear all
+
+--S 1170 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2*sqrt(x)
+--R 
+--R
+--R            2 10       2           8                2  6      2 4  +-+
+--R   (1)  (B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1170
+
+--S 1171 of 3139
+r0:=2/11*A*b^2*x^(11/2)+2/15*b*(b*B+2*A*c)*x^(15/2)+_
+   2/19*c*(2*b*B+A*c)*x^(19/2)+2/23*B*c^2*x^(23/2)
+--R 
+--R
+--R   (2)
+--R                2 11           2               9                        2  7
+--R         6270B c x   + (7590A c  + 15180B b c)x  + (19228A b c + 9614B b )x
+--R       + 
+--R                 2 5
+--R         13110A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     72105
+--R                                                    Type: Expression(Integer)
+--E 1171
+
+--S 1172 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 11           2               9                        2  7
+--R         6270B c x   + (7590A c  + 15180B b c)x  + (19228A b c + 9614B b )x
+--R       + 
+--R                 2 5
+--R         13110A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     72105
+--R                                         Type: Union(Expression(Integer),...)
+--E 1172
+
+--S 1173 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1173
+
+--S 1174 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1174
+
+)clear all
+
+--S 1175 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/sqrt(x)
+--R 
+--R
+--R           2 10       2           8                2  6      2 4
+--R        B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  --------------------------------------------------------
+--R                                   +-+
+--R                                  \|x
+--R                                                    Type: Expression(Integer)
+--E 1175
+
+--S 1176 of 3139
+r0:=2/9*A*b^2*x^(9/2)+2/13*b*(b*B+2*A*c)*x^(13/2)+_
+   2/17*c*(2*b*B+A*c)*x^(17/2)+2/21*B*c^2*x^(21/2)
+--R 
+--R
+--R   (2)
+--R                2 10           2              8                       2  6
+--R         1326B c x   + (1638A c  + 3276B b c)x  + (4284A b c + 2142B b )x
+--R       + 
+--R                2 4
+--R         3094A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     13923
+--R                                                    Type: Expression(Integer)
+--E 1176
+
+--S 1177 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 10           2              8                       2  6
+--R         1326B c x   + (1638A c  + 3276B b c)x  + (4284A b c + 2142B b )x
+--R       + 
+--R                2 4
+--R         3094A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     13923
+--R                                         Type: Union(Expression(Integer),...)
+--E 1177
+
+--S 1178 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1178
+
+--S 1179 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1179
+
+)clear all
+
+--S 1180 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^(3/2)
+--R 
+--R
+--R           2 9       2           7                2  5      2 3
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                                   +-+
+--R                                  \|x
+--R                                                    Type: Expression(Integer)
+--E 1180
+
+--S 1181 of 3139
+r0:=2/7*A*b^2*x^(7/2)+2/11*b*(b*B+2*A*c)*x^(11/2)+_
+   2/15*c*(2*b*B+A*c)*x^(15/2)+2/19*B*c^2*x^(19/2)
+--R 
+--R
+--R   (2)
+--R                2 9           2              7                       2  5
+--R         2310B c x  + (2926A c  + 5852B b c)x  + (7980A b c + 3990B b )x
+--R       + 
+--R                2 3
+--R         6270A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     21945
+--R                                                    Type: Expression(Integer)
+--E 1181
+
+--S 1182 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 9           2              7                       2  5
+--R         2310B c x  + (2926A c  + 5852B b c)x  + (7980A b c + 3990B b )x
+--R       + 
+--R                2 3
+--R         6270A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     21945
+--R                                         Type: Union(Expression(Integer),...)
+--E 1182
+
+--S 1183 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1183
+
+--S 1184 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1184
+
+)clear all
+
+--S 1185 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^(5/2)
+--R 
+--R
+--R           2 8       2           6                2  4      2 2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                                   +-+
+--R                                  \|x
+--R                                                    Type: Expression(Integer)
+--E 1185
+
+--S 1186 of 3139
+r0:=2/5*A*b^2*x^(5/2)+2/9*b*(b*B+2*A*c)*x^(9/2)+_
+   2/13*c*(2*b*B+A*c)*x^(13/2)+2/17*B*c^2*x^(17/2)
+--R 
+--R
+--R   (2)
+--R                2 8           2              6                       2  4
+--R         1170B c x  + (1530A c  + 3060B b c)x  + (4420A b c + 2210B b )x
+--R       + 
+--R                2 2
+--R         3978A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     9945
+--R                                                    Type: Expression(Integer)
+--E 1186
+
+--S 1187 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 8           2              6                       2  4
+--R         1170B c x  + (1530A c  + 3060B b c)x  + (4420A b c + 2210B b )x
+--R       + 
+--R                2 2
+--R         3978A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     9945
+--R                                         Type: Union(Expression(Integer),...)
+--E 1187
+
+--S 1188 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1188
+
+--S 1189 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1189
+
+)clear all
+
+--S 1190 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^(7/2)
+--R 
+--R
+--R           2 7       2           5                2  3      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  ------------------------------------------------------
+--R                                  +-+
+--R                                 \|x
+--R                                                    Type: Expression(Integer)
+--E 1190
+
+--S 1191 of 3139
+r0:=2/3*A*b^2*x^(3/2)+2/7*b*(b*B+2*A*c)*x^(7/2)+_
+   2/11*c*(2*b*B+A*c)*x^(11/2)+2/15*B*c^2*x^(15/2)
+--R 
+--R
+--R   (2)
+--R          2 7          2             5                     2  3         2   +-+
+--R   (154B c x  + (210A c  + 420B b c)x  + (660A b c + 330B b )x  + 770A b x)\|x
+--R   ----------------------------------------------------------------------------
+--R                                       1155
+--R                                                    Type: Expression(Integer)
+--E 1191
+
+--S 1192 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 7          2             5                     2  3         2   +-+
+--R   (154B c x  + (210A c  + 420B b c)x  + (660A b c + 330B b )x  + 770A b x)\|x
+--R   ----------------------------------------------------------------------------
+--R                                       1155
+--R                                         Type: Union(Expression(Integer),...)
+--E 1192
+
+--S 1193 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1193
+
+--S 1194 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1194
+
+)clear all
+
+--S 1195 of 3139
+t0:=x^(7/2)*(A+B*x^2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R          3 17       3         2  15          2       2   13
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x
+--R     + 
+--R            2       3  11      3 9
+--R       (3A b c + B b )x   + A b x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 1195
+
+--S 1196 of 3139
+r0:=2/21*A*b^3*x^(21/2)+2/25*b^2*(b*B+3*A*c)*x^(25/2)+_
+   6/29*b*c*(b*B+A*c)*x^(29/2)+2/33*c^2*(3*b*B+A*c)*x^(33/2)+_
+   2/37*B*c^3*x^(37/2)
+--R 
+--R
+--R   (2)
+--R                  3 18             3               2  16
+--R         334950B c x   + (375550A c  + 1126650B b c )x
+--R       + 
+--R                      2             2   14              2             3  12
+--R         (1282050A b c  + 1282050B b c)x   + (1487178A b c + 495726B b )x
+--R       + 
+--R                  3 10
+--R         590150A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     6196575
+--R                                                    Type: Expression(Integer)
+--E 1196
+
+--S 1197 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  3 18             3               2  16
+--R         334950B c x   + (375550A c  + 1126650B b c )x
+--R       + 
+--R                      2             2   14              2             3  12
+--R         (1282050A b c  + 1282050B b c)x   + (1487178A b c + 495726B b )x
+--R       + 
+--R                  3 10
+--R         590150A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     6196575
+--R                                         Type: Union(Expression(Integer),...)
+--E 1197
+
+--S 1198 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1198
+
+--S 1199 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1199
+
+)clear all
+
+--S 1200 of 3139
+t0:=x^(5/2)*(A+B*x^2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R          3 16       3         2  14          2       2   12
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x
+--R     + 
+--R            2       3  10      3 8
+--R       (3A b c + B b )x   + A b x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 1200
+
+--S 1201 of 3139
+r0:=2/19*A*b^3*x^(19/2)+2/23*b^2*(b*B+3*A*c)*x^(23/2)+_
+   2/9*b*c*(b*B+A*c)*x^(27/2)+2/31*c^2*(3*b*B+A*c)*x^(31/2)+2/35*B*c^3*x^(35/2)
+--R 
+--R
+--R   (2)
+--R                  3 17             3              2  15
+--R         243846B c x   + (275310A c  + 825930B b c )x
+--R       + 
+--R                     2            2   13              2             3  11
+--R         (948290A b c  + 948290B b c)x   + (1113210A b c + 371070B b )x
+--R       + 
+--R                  3 9
+--R         449190A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     4267305
+--R                                                    Type: Expression(Integer)
+--E 1201
+
+--S 1202 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  3 17             3              2  15
+--R         243846B c x   + (275310A c  + 825930B b c )x
+--R       + 
+--R                     2            2   13              2             3  11
+--R         (948290A b c  + 948290B b c)x   + (1113210A b c + 371070B b )x
+--R       + 
+--R                  3 9
+--R         449190A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     4267305
+--R                                         Type: Union(Expression(Integer),...)
+--E 1202
+
+--S 1203 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1203
+
+--S 1204 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1204
+
+)clear all
+
+--S 1205 of 3139
+t0:=x^(3/2)*(A+B*x^2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R          3 15       3         2  13          2       2   11        2       3  9
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x   + (3A b c + B b )x
+--R     + 
+--R          3 7
+--R       A b x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 1205
+
+--S 1206 of 3139
+r0:=2/17*A*b^3*x^(17/2)+2/21*b^2*(b*B+3*A*c)*x^(21/2)+_
+   6/25*b*c*(b*B+A*c)*x^(25/2)+2/29*c^2*(3*b*B+A*c)*x^(29/2)+_
+   2/33*B*c^3*x^(33/2)
+--R 
+--R
+--R   (2)
+--R                  3 16             3              2  14
+--R         172550B c x   + (196350A c  + 589050B b c )x
+--R       + 
+--R                     2            2   12             2             3  10
+--R         (683298A b c  + 683298B b c)x   + (813450A b c + 271150B b )x
+--R       + 
+--R                  3 8
+--R         334950A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     2847075
+--R                                                    Type: Expression(Integer)
+--E 1206
+
+--S 1207 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  3 16             3              2  14
+--R         172550B c x   + (196350A c  + 589050B b c )x
+--R       + 
+--R                     2            2   12             2             3  10
+--R         (683298A b c  + 683298B b c)x   + (813450A b c + 271150B b )x
+--R       + 
+--R                  3 8
+--R         334950A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     2847075
+--R                                         Type: Union(Expression(Integer),...)
+--E 1207
+
+--S 1208 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1208
+
+--S 1209 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1209
+
+)clear all
+
+--S 1210 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3*sqrt(x)
+--R 
+--R
+--R   (1)
+--R          3 14       3         2  12          2       2   10        2       3  8
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x   + (3A b c + B b )x
+--R     + 
+--R          3 6
+--R       A b x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 1210
+
+--S 1211 of 3139
+r0:=2/15*A*b^3*x^(15/2)+2/19*b^2*(b*B+3*A*c)*x^(19/2)+_
+   6/23*b*c*(b*B+A*c)*x^(23/2)+2/27*c^2*(3*b*B+A*c)*x^(27/2)+_
+   2/31*B*c^3*x^(31/2)
+--R 
+--R
+--R   (2)
+--R                  3 15             3              2  13
+--R         117990B c x   + (135470A c  + 406410B b c )x
+--R       + 
+--R                     2            2   11             2             3  9
+--R         (477090A b c  + 477090B b c)x   + (577530A b c + 192510B b )x
+--R       + 
+--R                  3 7
+--R         243846A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     1828845
+--R                                                    Type: Expression(Integer)
+--E 1211
+
+--S 1212 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  3 15             3              2  13
+--R         117990B c x   + (135470A c  + 406410B b c )x
+--R       + 
+--R                     2            2   11             2             3  9
+--R         (477090A b c  + 477090B b c)x   + (577530A b c + 192510B b )x
+--R       + 
+--R                  3 7
+--R         243846A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     1828845
+--R                                         Type: Union(Expression(Integer),...)
+--E 1212
+
+--S 1213 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1213
+
+--S 1214 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1214
+
+)clear all
+
+--S 1215 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/sqrt(x)
+--R 
+--R
+--R   (1)
+--R          3 14       3         2  12          2       2   10        2       3  8
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x   + (3A b c + B b )x
+--R     + 
+--R          3 6
+--R       A b x
+--R  /
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 1215
+
+--S 1216 of 3139
+r0:=2/13*A*b^3*x^(13/2)+2/17*b^2*(b*B+3*A*c)*x^(17/2)+_
+   2/7*b*c*(b*B+A*c)*x^(21/2)+2/25*c^2*(3*b*B+A*c)*x^(25/2)+2/29*B*c^3*x^(29/2)
+--R 
+--R
+--R   (2)
+--R                 3 14            3              2  12
+--R         77350B c x   + (89726A c  + 269178B b c )x
+--R       + 
+--R                     2            2   10             2             3  8
+--R         (320450A b c  + 320450B b c)x   + (395850A b c + 131950B b )x
+--R       + 
+--R                  3 6
+--R         172550A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     1121575
+--R                                                    Type: Expression(Integer)
+--E 1216
+
+--S 1217 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3 14            3              2  12
+--R         77350B c x   + (89726A c  + 269178B b c )x
+--R       + 
+--R                     2            2   10             2             3  8
+--R         (320450A b c  + 320450B b c)x   + (395850A b c + 131950B b )x
+--R       + 
+--R                  3 6
+--R         172550A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     1121575
+--R                                         Type: Union(Expression(Integer),...)
+--E 1217
+
+--S 1218 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1218
+
+--S 1219 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1219
+
+)clear all
+
+--S 1220 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^(3/2)
+--R 
+--R
+--R   (1)
+--R          3 13       3         2  11          2       2   9        2       3  7
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 5
+--R       A b x
+--R  /
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 1220
+
+--S 1221 of 3139
+r0:=2/11*A*b^3*x^(11/2)+2/15*b^2*(b*B+3*A*c)*x^(15/2)+_
+   6/19*b*c*(b*B+A*c)*x^(19/2)+2/23*c^2*(3*b*B+A*c)*x^(23/2)+_
+   2/27*B*c^3*x^(27/2)
+--R 
+--R
+--R   (2)
+--R                 3 13            3              2  11
+--R         48070B c x   + (56430A c  + 169290B b c )x
+--R       + 
+--R                     2            2   9             2            3  7
+--R         (204930A b c  + 204930B b c)x  + (259578A b c + 86526B b )x
+--R       + 
+--R                  3 5
+--R         117990A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     648945
+--R                                                    Type: Expression(Integer)
+--E 1221
+
+--S 1222 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3 13            3              2  11
+--R         48070B c x   + (56430A c  + 169290B b c )x
+--R       + 
+--R                     2            2   9             2            3  7
+--R         (204930A b c  + 204930B b c)x  + (259578A b c + 86526B b )x
+--R       + 
+--R                  3 5
+--R         117990A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     648945
+--R                                         Type: Union(Expression(Integer),...)
+--E 1222
+
+--S 1223 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1223
+
+--S 1224 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1224
+
+)clear all
+
+--S 1225 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^(5/2)
+--R 
+--R
+--R   (1)
+--R          3 12       3         2  10          2       2   8        2       3  6
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 4
+--R       A b x
+--R  /
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 1225
+
+--S 1226 of 3139
+r0:=2/9*A*b^3*x^(9/2)+2/13*b^2*(b*B+3*A*c)*x^(13/2)+_
+   6/17*b*c*(b*B+A*c)*x^(17/2)+2/21*c^2*(3*b*B+A*c)*x^(21/2)+_
+   2/25*B*c^3*x^(25/2)
+--R 
+--R
+--R   (2)
+--R                 3 12            3             2  10
+--R         27846B c x   + (33150A c  + 99450B b c )x
+--R       + 
+--R                     2            2   8             2            3  6
+--R         (122850A b c  + 122850B b c)x  + (160650A b c + 53550B b )x
+--R       + 
+--R                 3 4
+--R         77350A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     348075
+--R                                                    Type: Expression(Integer)
+--E 1226
+
+--S 1227 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3 12            3             2  10
+--R         27846B c x   + (33150A c  + 99450B b c )x
+--R       + 
+--R                     2            2   8             2            3  6
+--R         (122850A b c  + 122850B b c)x  + (160650A b c + 53550B b )x
+--R       + 
+--R                 3 4
+--R         77350A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     348075
+--R                                         Type: Union(Expression(Integer),...)
+--E 1227
+
+--S 1228 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1228
+
+--S 1229 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1229
+
+)clear all
+
+--S 1230 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^(7/2)
+--R 
+--R
+--R   (1)
+--R          3 11       3         2  9          2       2   7        2       3  5
+--R       B c x   + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 3
+--R       A b x
+--R  /
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 1230
+
+--S 1231 of 3139
+r0:=2/7*A*b^3*x^(7/2)+2/11*b^2*(b*B+3*A*c)*x^(11/2)+_
+   2/5*b*c*(b*B+A*c)*x^(15/2)+2/19*c^2*(3*b*B+A*c)*x^(19/2)+2/23*B*c^3*x^(23/2)
+--R 
+--R
+--R   (2)
+--R                 3 11            3             2  9
+--R         14630B c x   + (17710A c  + 53130B b c )x
+--R       + 
+--R                  2           2   7            2            3  5           3 3
+--R       (67298A b c  + 67298B b c)x  + (91770A b c + 30590B b )x  + 48070A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     168245
+--R                                                    Type: Expression(Integer)
+--E 1231
+
+--S 1232 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3 11            3             2  9
+--R         14630B c x   + (17710A c  + 53130B b c )x
+--R       + 
+--R                  2           2   7            2            3  5           3 3
+--R       (67298A b c  + 67298B b c)x  + (91770A b c + 30590B b )x  + 48070A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     168245
+--R                                         Type: Union(Expression(Integer),...)
+--E 1232
+
+--S 1233 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1233
+
+--S 1234 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1234
+
+)clear all
+
+--S 1235 of 3139
+t0:=x^(13/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            6      4  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R                2
+--R             c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1235
+
+--S 1236 of 3139
+r0:=2/3*b*(b*B-A*c)*x^(3/2)/c^3-2/7*(b*B-A*c)*x^(7/2)/c^2+_
+   2/11*B*x^(11/2)/c+b^(7/4)*(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(c^(15/4)*sqrt(2))-b^(7/4)*(b*B-A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(c^(15/4)*sqrt(2))-1/2*b^(7/4)*(b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(15/4)*_
+   sqrt(2))+1/2*b^(7/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+_
+   b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                           2 4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 231A b c + 231B b )\|b  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                         2 4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (231A b c - 231B b )\|b  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                      +-+4+-+ +-+   4+-+
+--R                         2 4+-+3     \|2 \|c \|x  + \|b
+--R       (462A b c - 462B b )\|b  atan(-------------------)
+--R                                             4+-+
+--R                                             \|b
+--R     + 
+--R                                      +-+4+-+ +-+   4+-+
+--R                         2 4+-+3     \|2 \|c \|x  - \|b
+--R       (462A b c - 462B b )\|b  atan(-------------------)
+--R                                             4+-+
+--R                                             \|b
+--R     + 
+--R           2 5          2             3                       2    +-+4+-+3 +-+
+--R     (84B c x  + (132A c  - 132B b c)x  + (- 308A b c + 308B b )x)\|2 \|c  \|x
+--R  /
+--R         3 +-+4+-+3
+--R     462c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1236
+
+--S 1237 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                +----------------------------------------------------+
+--R                |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R             3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b
+--R         231c   |----------------------------------------------------
+--R               4|                           15
+--R               \|                        16c
+--R      *
+--R         log
+--R                3 5 3     2   6 2       2 7     3 8  +-+
+--R              (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R            + 
+--R                    +----------------------------------------------------+3
+--R                    |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R                11  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b
+--R              8c    |----------------------------------------------------
+--R                   4|                           15
+--R                   \|                        16c
+--R     + 
+--R       -
+--R                   +----------------------------------------------------+
+--R                   |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R                3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b
+--R            231c   |----------------------------------------------------
+--R                  4|                           15
+--R                  \|                        16c
+--R         *
+--R            log
+--R                   3 5 3     2   6 2       2 7     3 8  +-+
+--R                 (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R               + 
+--R                         +----------------------------------------------------+3
+--R                         |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R                     11  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b
+--R                 - 8c    |----------------------------------------------------
+--R                        4|                           15
+--R                        \|                        16c
+--R     + 
+--R                +----------------------------------------------------+
+--R                |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R             3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b
+--R         462c   |----------------------------------------------------
+--R               4|                           15
+--R               \|                        16c
+--R      *
+--R                    +----------------------------------------------------+3
+--R                    |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R                11  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b
+--R              8c    |----------------------------------------------------
+--R                   4|                           15
+--R                   \|                        16c
+--R         atan(------------------------------------------------------------)
+--R                         3 5 3     2   6 2       2 7     3 8  +-+
+--R                       (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R     + 
+--R             2 5         2            3                       2    +-+
+--R       (42B c x  + (66A c  - 66B b c)x  + (- 154A b c + 154B b )x)\|x
+--R  /
+--R         3
+--R     231c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1237
+
+--S 1238 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   2 4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A b c - B b )\|b  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  +----------------------------------------------------+
+--R                  |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R           3 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b   4+-+3
+--R         2c \|2   |---------------------------------------------------- \|c
+--R                 4|                           15
+--R                 \|                        16c
+--R      *
+--R         log
+--R                3 5 3     2   6 2       2 7     3 8  +-+
+--R              (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R            + 
+--R                    +----------------------------------------------------+3
+--R                    |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R                11  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b
+--R              8c    |----------------------------------------------------
+--R                   4|                           15
+--R                   \|                        16c
+--R     + 
+--R       -
+--R                     +----------------------------------------------------+
+--R                     |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R              3 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b   4+-+3
+--R            2c \|2   |---------------------------------------------------- \|c
+--R                    4|                           15
+--R                    \|                        16c
+--R         *
+--R            log
+--R                   3 5 3     2   6 2       2 7     3 8  +-+
+--R                 (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R               + 
+--R                         +----------------------------------------------------+3
+--R                         |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R                     11  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b
+--R                 - 8c    |----------------------------------------------------
+--R                        4|                           15
+--R                        \|                        16c
+--R     + 
+--R                     2 4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A b c + B b )\|b  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                    +-+4+-+ +-+   4+-+
+--R                       2 4+-+3     \|2 \|c \|x  + \|b
+--R       (- 2A b c + 2B b )\|b  atan(-------------------)
+--R                                           4+-+
+--R                                           \|b
+--R     + 
+--R                                    +-+4+-+ +-+   4+-+
+--R                       2 4+-+3     \|2 \|c \|x  - \|b
+--R       (- 2A b c + 2B b )\|b  atan(-------------------)
+--R                                           4+-+
+--R                                           \|b
+--R     + 
+--R                  +----------------------------------------------------+
+--R                  |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R           3 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b   4+-+3
+--R         4c \|2   |---------------------------------------------------- \|c
+--R                 4|                           15
+--R                 \|                        16c
+--R      *
+--R                    +----------------------------------------------------+3
+--R                    |   4 7 4     3   8 3     2 2 9 2       3 10     4 11
+--R                11  |- A b c  + 4A B b c  - 6A B b c  + 4A B b  c - B b
+--R              8c    |----------------------------------------------------
+--R                   4|                           15
+--R                   \|                        16c
+--R         atan(------------------------------------------------------------)
+--R                         3 5 3     2   6 2       2 7     3 8  +-+
+--R                       (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R  /
+--R       3 +-+4+-+3
+--R     2c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1238
+
+--S 1239 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R               2        3  2 +-+ +-+       2 2      3   3        3        4
+--R         ((2A b c - 2B b )x \|b \|c  + (A b c  - B b c)x  + (3A b c - 3B b )x)
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                    2        3   +-+4+-+2         2 2      3   3
+--R             (- 2A b c + 2B b )x\|b \|b   + (- A b c  + B b c)x
+--R           + 
+--R                   3       4
+--R             (- A b c + B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R               2 2       3   2      3       4 4+-+2
+--R       ((- 3A b c  + 3B b c)x  - A b c + B b )\|b
+--R     + 
+--R            2 2      3   2      3       4  +-+
+--R       ((A b c  - B b c)x  + A b c - B b )\|b
+--R  /
+--R             4 3       3   +-+ +-+     5 4       4 2     2 3 4+-+2
+--R         ((4c x  + 4b c x)\|b \|c  + 2c x  + 4b c x  + 2b c )\|c
+--R       + 
+--R              5 3       4  4+-+2
+--R         (- 4c x  - 4b c x)\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1239
+
+)clear all
+
+--S 1240 of 3139
+t0:=x^(11/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            5      3  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R                2
+--R             c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1240
+
+--S 1241 of 3139
+r0:=-2/5*(b*B-A*c)*x^(5/2)/c^2+2/9*B*x^(9/2)/c+b^(5/4)*(b*B-A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(13/4)*sqrt(2))-b^(5/4)*_
+   (b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(13/4)*sqrt(2))+_
+   1/2*b^(5/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(c^(13/4)*sqrt(2))-1/2*b^(5/4)*(b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(13/4)*_
+   sqrt(2))+2*b*(b*B-A*c)*sqrt(x)/c^3
+--R 
+--R
+--R   (2)
+--R                       2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45A b c - 45B b )\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                         2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45A b c + 45B b )\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                       2 4+-+     \|2 \|c \|x  + \|b
+--R       (90A b c - 90B b )\|b atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                       2 4+-+     \|2 \|c \|x  - \|b
+--R       (90A b c - 90B b )\|b atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R             2 4         2            2                    2  +-+4+-+ +-+
+--R       (20B c x  + (36A c  - 36B b c)x  - 180A b c + 180B b )\|2 \|c \|x
+--R  /
+--R        3 +-+4+-+
+--R     90c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1241
+
+--S 1242 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +--------------------------------------------------+
+--R               |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R            3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R         45c   |--------------------------------------------------
+--R              4|                          13
+--R              \|                       16c
+--R      *
+--R         log
+--R                          2  +-+
+--R              (A b c - B b )\|x
+--R            + 
+--R                   +--------------------------------------------------+
+--R                   |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R                3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              2c   |--------------------------------------------------
+--R                  4|                          13
+--R                  \|                       16c
+--R     + 
+--R       -
+--R                  +--------------------------------------------------+
+--R                  |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R               3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R            45c   |--------------------------------------------------
+--R                 4|                          13
+--R                 \|                       16c
+--R         *
+--R            log
+--R                             2  +-+
+--R                 (A b c - B b )\|x
+--R               + 
+--R                        +--------------------------------------------------+
+--R                        |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R                     3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 - 2c   |--------------------------------------------------
+--R                       4|                          13
+--R                       \|                       16c
+--R     + 
+--R       -
+--R                  +--------------------------------------------------+
+--R                  |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R               3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R            90c   |--------------------------------------------------
+--R                 4|                          13
+--R                 \|                       16c
+--R         *
+--R                      +--------------------------------------------------+
+--R                      |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R                   3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 2c   |--------------------------------------------------
+--R                     4|                          13
+--R                     \|                       16c
+--R            atan(--------------------------------------------------------)
+--R                                                2  +-+
+--R                                    (A b c - B b )\|x
+--R     + 
+--R             2 4         2            2                  2  +-+
+--R       (10B c x  + (18A c  - 18B b c)x  - 90A b c + 90B b )\|x
+--R  /
+--R        3
+--R     45c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1242
+
+--S 1243 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A b c + B b )\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  +--------------------------------------------------+
+--R                  |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R           3 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+
+--R         2c \|2   |-------------------------------------------------- \|c
+--R                 4|                          13
+--R                 \|                       16c
+--R      *
+--R         log
+--R                          2  +-+
+--R              (A b c - B b )\|x
+--R            + 
+--R                   +--------------------------------------------------+
+--R                   |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R                3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              2c   |--------------------------------------------------
+--R                  4|                          13
+--R                  \|                       16c
+--R     + 
+--R       -
+--R                     +--------------------------------------------------+
+--R                     |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R              3 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+
+--R            2c \|2   |-------------------------------------------------- \|c
+--R                    4|                          13
+--R                    \|                       16c
+--R         *
+--R            log
+--R                             2  +-+
+--R                 (A b c - B b )\|x
+--R               + 
+--R                        +--------------------------------------------------+
+--R                        |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R                     3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 - 2c   |--------------------------------------------------
+--R                       4|                          13
+--R                       \|                       16c
+--R     + 
+--R                   2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A b c - B b )\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                       2 4+-+     \|2 \|c \|x  + \|b
+--R       (- 2A b c + 2B b )\|b atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                       2 4+-+     \|2 \|c \|x  - \|b
+--R       (- 2A b c + 2B b )\|b atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R       -
+--R                     +--------------------------------------------------+
+--R                     |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R              3 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+
+--R            4c \|2   |-------------------------------------------------- \|c
+--R                    4|                          13
+--R                    \|                       16c
+--R         *
+--R                      +--------------------------------------------------+
+--R                      |   4 5 4     3   6 3     2 2 7 2       3 8     4 9
+--R                   3  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 2c   |--------------------------------------------------
+--R                     4|                          13
+--R                     \|                       16c
+--R            atan(--------------------------------------------------------)
+--R                                                2  +-+
+--R                                    (A b c - B b )\|x
+--R  /
+--R       3 +-+4+-+
+--R     2c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1243
+
+--S 1244 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                        2      2   3       2       3   4+-+2
+--R                 ((A b c  - B b c)x  + (A b c - B b )x)\|b
+--R               + 
+--R                      2        3   +-+
+--R                 (2A b c - 2B b )x\|b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    2      2   2      2       3  +-+4+-+2        2 2       3   2
+--R           ((- A b c  + B b c)x  - A b c + B b )\|b \|b   + (3A b c  - 3B b c)x
+--R         + 
+--R              3       4
+--R           A b c - B b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                2       2   2 +-+4+-+2 +-+
+--R       (- 2A b c  + 2B b c)x \|b \|b  \|c
+--R     + 
+--R                3      2 2  3          2 2       3    4+-+2
+--R       ((- A b c  + B b c )x  + (- 3A b c  + 3B b c)x)\|b
+--R  /
+--R             4 3       3   +-+ +-+     5 4       4 2     2 3 4+-+2
+--R         ((4c x  + 4b c x)\|b \|c  + 2c x  + 4b c x  + 2b c )\|c
+--R       + 
+--R              5 3       4  4+-+2
+--R         (- 4c x  - 4b c x)\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1244
+
+)clear all
+
+--S 1245 of 3139
+t0:=x^(9/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            4      2  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R                2
+--R             c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1245
+
+--S 1246 of 3139
+r0:=-2/3*(b*B-A*c)*x^(3/2)/c^2+2/7*B*x^(7/2)/c-b^(3/4)*(b*B-A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(11/4)*sqrt(2))+b^(3/4)*_
+   (b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(11/4)*sqrt(2))+_
+   1/2*b^(3/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(c^(11/4)*sqrt(2))-1/2*b^(3/4)*(b*B-A*c)*log(sqrt(b)+x*_
+   sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                      4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21A c - 21B b)\|b  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                        4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21A c + 21B b)\|b  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                        4+-+3     \|2 \|c \|x  + \|b
+--R       (- 42A c + 42B b)\|b  atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                        4+-+3     \|2 \|c \|x  - \|b
+--R       (- 42A c + 42B b)\|b  atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R               3                     +-+4+-+3 +-+
+--R       (12B c x  + (28A c - 28B b)x)\|2 \|c  \|x
+--R  /
+--R        2 +-+4+-+3
+--R     42c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1246
+
+--S 1247 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                  +--------------------------------------------------+
+--R                  |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R               2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R            21c   |--------------------------------------------------
+--R                 4|                          11
+--R                 \|                       16c
+--R         *
+--R            log
+--R                   3 2 3     2   3 2       2 4     3 5  +-+
+--R                 (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R               + 
+--R                      +--------------------------------------------------+3
+--R                      |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R                   8  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 8c   |--------------------------------------------------
+--R                     4|                          11
+--R                     \|                       16c
+--R     + 
+--R               +--------------------------------------------------+
+--R               |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R            2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R         21c   |--------------------------------------------------
+--R              4|                          11
+--R              \|                       16c
+--R      *
+--R         log
+--R                3 2 3     2   3 2       2 4     3 5  +-+
+--R              (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R            + 
+--R                     +--------------------------------------------------+3
+--R                     |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R                  8  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              - 8c   |--------------------------------------------------
+--R                    4|                          11
+--R                    \|                       16c
+--R     + 
+--R       -
+--R                  +--------------------------------------------------+
+--R                  |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R               2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R            42c   |--------------------------------------------------
+--R                 4|                          11
+--R                 \|                       16c
+--R         *
+--R                      +--------------------------------------------------+3
+--R                      |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R                   8  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 8c   |--------------------------------------------------
+--R                     4|                          11
+--R                     \|                       16c
+--R            atan(---------------------------------------------------------)
+--R                           3 2 3     2   3 2       2 4     3 5  +-+
+--R                         (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R     + 
+--R              3                     +-+
+--R       (6B c x  + (14A c - 14B b)x)\|x
+--R  /
+--R        2
+--R     21c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1247
+
+--S 1248 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)\|b  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R                     +--------------------------------------------------+
+--R                     |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R              2 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+3
+--R            2c \|2   |-------------------------------------------------- \|c
+--R                    4|                          11
+--R                    \|                       16c
+--R         *
+--R            log
+--R                   3 2 3     2   3 2       2 4     3 5  +-+
+--R                 (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R               + 
+--R                      +--------------------------------------------------+3
+--R                      |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R                   8  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 8c   |--------------------------------------------------
+--R                     4|                          11
+--R                     \|                       16c
+--R     + 
+--R                  +--------------------------------------------------+
+--R                  |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R           2 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+3
+--R         2c \|2   |-------------------------------------------------- \|c
+--R                 4|                          11
+--R                 \|                       16c
+--R      *
+--R         log
+--R                3 2 3     2   3 2       2 4     3 5  +-+
+--R              (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R            + 
+--R                     +--------------------------------------------------+3
+--R                     |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R                  8  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              - 8c   |--------------------------------------------------
+--R                    4|                          11
+--R                    \|                       16c
+--R     + 
+--R                  4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)\|b  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R                    4+-+3     \|2 \|c \|x  + \|b
+--R       (2A c - 2B b)\|b  atan(-------------------)
+--R                                      4+-+
+--R                                      \|b
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R                    4+-+3     \|2 \|c \|x  - \|b
+--R       (2A c - 2B b)\|b  atan(-------------------)
+--R                                      4+-+
+--R                                      \|b
+--R     + 
+--R       -
+--R                     +--------------------------------------------------+
+--R                     |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R              2 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+3
+--R            4c \|2   |-------------------------------------------------- \|c
+--R                    4|                          11
+--R                    \|                       16c
+--R         *
+--R                      +--------------------------------------------------+3
+--R                      |   4 3 4     3   4 3     2 2 5 2       3 6     4 7
+--R                   8  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 8c   |--------------------------------------------------
+--R                     4|                          11
+--R                     \|                       16c
+--R            atan(---------------------------------------------------------)
+--R                           3 2 3     2   3 2       2 4     3 5  +-+
+--R                         (A b c  - 3A B b c  + 3A B b c - B b )\|x
+--R  /
+--R       2 +-+4+-+3
+--R     2c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1248
+
+--S 1249 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                           2  2 +-+ +-+           2      2   3
+--R           (- 2A b c + 2B b )x \|b \|c  + (- A b c  + B b c)x
+--R         + 
+--R                  2        3
+--R           (- 3A b c + 3B b )x
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                      2   +-+4+-+2         2      2   3       2       3    +-+
+--R       ((2A b c - 2B b )x\|b \|b   + (A b c  - B b c)x  + (A b c - B b )x)\|c
+--R     + 
+--R               2       2   2      2       3 4+-+2
+--R       ((3A b c  - 3B b c)x  + A b c - B b )\|b
+--R     + 
+--R                2      2   2      2       3  +-+
+--R       ((- A b c  + B b c)x  - A b c + B b )\|b
+--R  /
+--R             3 3       2   +-+ +-+     4 4       3 2     2 2 4+-+2
+--R         ((4c x  + 4b c x)\|b \|c  + 2c x  + 4b c x  + 2b c )\|c
+--R       + 
+--R              4 3       3  4+-+2
+--R         (- 4c x  - 4b c x)\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1249
+
+)clear all
+
+--S 1250 of 3139
+t0:=x^(7/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            3        +-+
+--R        (B x  + A x)\|x
+--R   (1)  ----------------
+--R               2
+--R            c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1250
+
+--S 1251 of 3139
+r0:=2/5*B*x^(5/2)/c-b^(1/4)*(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(c^(9/4)*sqrt(2))+b^(1/4)*(b*B-A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(c^(9/4)*sqrt(2))-1/2*b^(1/4)*(b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(9/4)*_
+   sqrt(2))+1/2*b^(1/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(c^(9/4)*sqrt(2))-2*(b*B-A*c)*sqrt(x)/c^2
+--R 
+--R
+--R   (2)
+--R                      4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5A c + 5B b)\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5A c - 5B b)\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R                        4+-+     \|2 \|c \|x  + \|b
+--R       (- 10A c + 10B b)\|b atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R                        4+-+     \|2 \|c \|x  - \|b
+--R       (- 10A c + 10B b)\|b atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R              2                  +-+4+-+ +-+
+--R       (4B c x  + 20A c - 20B b)\|2 \|c \|x
+--R  /
+--R        2 +-+4+-+
+--R     10c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1251
+
+--S 1252 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                 +--------------------------------------------------+
+--R                 |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R              2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R            5c   |--------------------------------------------------
+--R                4|                          9
+--R                \|                       16c
+--R         *
+--R            log
+--R                             +-+
+--R                 (A c - B b)\|x
+--R               + 
+--R                      +--------------------------------------------------+
+--R                      |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R                   2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 2c   |--------------------------------------------------
+--R                     4|                          9
+--R                     \|                       16c
+--R     + 
+--R              +--------------------------------------------------+
+--R              |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R           2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R         5c   |--------------------------------------------------
+--R             4|                          9
+--R             \|                       16c
+--R      *
+--R         log
+--R                          +-+
+--R              (A c - B b)\|x
+--R            + 
+--R                     +--------------------------------------------------+
+--R                     |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R                  2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              - 2c   |--------------------------------------------------
+--R                    4|                          9
+--R                    \|                       16c
+--R     + 
+--R               +--------------------------------------------------+
+--R               |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R            2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R         10c   |--------------------------------------------------
+--R              4|                          9
+--R              \|                       16c
+--R      *
+--R                   +--------------------------------------------------+
+--R                   |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R                2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              2c   |--------------------------------------------------
+--R                  4|                          9
+--R                  \|                       16c
+--R         atan(--------------------------------------------------------)
+--R                                               +-+
+--R                                   (A c - B b)\|x
+--R     + 
+--R              2                  +-+
+--R       (2B c x  + 10A c - 10B b)\|x
+--R  /
+--R       2
+--R     5c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1252
+
+--S 1253 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R                     +--------------------------------------------------+
+--R                     |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R              2 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+
+--R            2c \|2   |-------------------------------------------------- \|c
+--R                    4|                          9
+--R                    \|                       16c
+--R         *
+--R            log
+--R                             +-+
+--R                 (A c - B b)\|x
+--R               + 
+--R                      +--------------------------------------------------+
+--R                      |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R                   2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 2c   |--------------------------------------------------
+--R                     4|                          9
+--R                     \|                       16c
+--R     + 
+--R                  +--------------------------------------------------+
+--R                  |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R           2 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+
+--R         2c \|2   |-------------------------------------------------- \|c
+--R                 4|                          9
+--R                 \|                       16c
+--R      *
+--R         log
+--R                          +-+
+--R              (A c - B b)\|x
+--R            + 
+--R                     +--------------------------------------------------+
+--R                     |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R                  2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              - 2c   |--------------------------------------------------
+--R                    4|                          9
+--R                    \|                       16c
+--R     + 
+--R                    4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                              +-+4+-+ +-+   4+-+
+--R                    4+-+     \|2 \|c \|x  + \|b
+--R       (2A c - 2B b)\|b atan(-------------------)
+--R                                     4+-+
+--R                                     \|b
+--R     + 
+--R                              +-+4+-+ +-+   4+-+
+--R                    4+-+     \|2 \|c \|x  - \|b
+--R       (2A c - 2B b)\|b atan(-------------------)
+--R                                     4+-+
+--R                                     \|b
+--R     + 
+--R                  +--------------------------------------------------+
+--R                  |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R           2 +-+  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+
+--R         4c \|2   |-------------------------------------------------- \|c
+--R                 4|                          9
+--R                 \|                       16c
+--R      *
+--R                   +--------------------------------------------------+
+--R                   |   4   4     3   2 3     2 2 3 2       3 4     4 5
+--R                2  |- A b c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              2c   |--------------------------------------------------
+--R                  4|                          9
+--R                  \|                       16c
+--R         atan(--------------------------------------------------------)
+--R                                               +-+
+--R                                   (A c - B b)\|x
+--R  /
+--R       2 +-+4+-+
+--R     2c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1253
+
+--S 1254 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      2          3                 2   4+-+2
+--R               ((- A c  + B b c)x  + (- A b c + B b )x)\|b
+--R             + 
+--R                               2   +-+
+--R               (- 2A b c + 2B b )x\|b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                2          2              2  +-+4+-+2            2       2   2
+--R           ((A c  - B b c)x  + A b c - B b )\|b \|b   + (- 3A b c  + 3B b c)x
+--R         + 
+--R                2       3
+--R           - A b c + B b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R            2           2 +-+4+-+2 +-+
+--R       (2A c  - 2B b c)x \|b \|b  \|c
+--R     + 
+--R            3        2  3          2       2    4+-+2
+--R       ((A c  - B b c )x  + (3A b c  - 3B b c)x)\|b
+--R  /
+--R             3 3       2   +-+ +-+     4 4       3 2     2 2 4+-+2
+--R         ((4c x  + 4b c x)\|b \|c  + 2c x  + 4b c x  + 2b c )\|c
+--R       + 
+--R              4 3       3  4+-+2
+--R         (- 4c x  - 4b c x)\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1254
+
+)clear all
+
+--S 1255 of 3139
+t0:=x^(5/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            2      +-+
+--R        (B x  + A)\|x
+--R   (1)  --------------
+--R              2
+--R           c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1255
+
+--S 1256 of 3139
+r0:=2/3*B*x^(3/2)/c+(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (b^(1/4)*c^(7/4)*sqrt(2))-(b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(1/4)*c^(7/4)*sqrt(2))-1/2*(b*B-A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*c^(7/4)*_
+   sqrt(2))+1/2*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(1/4)*c^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3A c + 3B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3A c - 3B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  + \|b
+--R       (6A c - 6B b)atan(-------------------)
+--R                                 4+-+
+--R                                 \|b
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  - \|b          +-+4+-+4+-+3 +-+
+--R       (6A c - 6B b)atan(-------------------) + 4B x\|2 \|b \|c  \|x
+--R                                 4+-+
+--R                                 \|b
+--R  /
+--R        +-+4+-+4+-+3
+--R     6c\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1256
+
+--S 1257 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +------------------------------------------------+
+--R             |   4 4     3     3     2 2 2 2       3 3     4 4
+--R             |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R         3c  |------------------------------------------------
+--R            4|                          7
+--R            \|                     16b c
+--R      *
+--R         log
+--R                3 3     2     2       2 2     3 3  +-+
+--R              (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R            + 
+--R                     +------------------------------------------------+3
+--R                     |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                  5  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              8b c   |------------------------------------------------
+--R                    4|                          7
+--R                    \|                     16b c
+--R     + 
+--R       -
+--R                +------------------------------------------------+
+--R                |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R            3c  |------------------------------------------------
+--R               4|                          7
+--R               \|                     16b c
+--R         *
+--R            log
+--R                   3 3     2     2       2 2     3 3  +-+
+--R                 (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R               + 
+--R                          +------------------------------------------------+3
+--R                          |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                       5  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 - 8b c   |------------------------------------------------
+--R                         4|                          7
+--R                         \|                     16b c
+--R     + 
+--R             +------------------------------------------------+
+--R             |   4 4     3     3     2 2 2 2       3 3     4 4
+--R             |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R         6c  |------------------------------------------------
+--R            4|                          7
+--R            \|                     16b c
+--R      *
+--R                     +------------------------------------------------+3
+--R                     |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                  5  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              8b c   |------------------------------------------------
+--R                    4|                          7
+--R                    \|                     16b c
+--R         atan(---------------------------------------------------------)
+--R                         3 3     2     2       2 2     3 3  +-+
+--R                       (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R     + 
+--R            +-+
+--R       2B x\|x
+--R  /
+--R     3c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1257
+
+--S 1258 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 +------------------------------------------------+
+--R                 |   4 4     3     3     2 2 2 2       3 3     4 4
+--R            +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+4+-+3
+--R         2c\|2   |------------------------------------------------ \|b \|c
+--R                4|                          7
+--R                \|                     16b c
+--R      *
+--R         log
+--R                3 3     2     2       2 2     3 3  +-+
+--R              (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R            + 
+--R                     +------------------------------------------------+3
+--R                     |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                  5  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              8b c   |------------------------------------------------
+--R                    4|                          7
+--R                    \|                     16b c
+--R     + 
+--R       -
+--R                    +------------------------------------------------+
+--R                    |   4 4     3     3     2 2 2 2       3 3     4 4
+--R               +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+4+-+3
+--R            2c\|2   |------------------------------------------------ \|b \|c
+--R                   4|                          7
+--R                   \|                     16b c
+--R         *
+--R            log
+--R                   3 3     2     2       2 2     3 3  +-+
+--R                 (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R               + 
+--R                          +------------------------------------------------+3
+--R                          |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                       5  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 - 8b c   |------------------------------------------------
+--R                         4|                          7
+--R                         \|                     16b c
+--R     + 
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R                           \|2 \|c \|x  + \|b
+--R       (- 2A c + 2B b)atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R                           \|2 \|c \|x  - \|b
+--R       (- 2A c + 2B b)atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R                 +------------------------------------------------+
+--R                 |   4 4     3     3     2 2 2 2       3 3     4 4
+--R            +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+4+-+3
+--R         4c\|2   |------------------------------------------------ \|b \|c
+--R                4|                          7
+--R                \|                     16b c
+--R      *
+--R                     +------------------------------------------------+3
+--R                     |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                  5  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              8b c   |------------------------------------------------
+--R                    4|                          7
+--R                    \|                     16b c
+--R         atan(---------------------------------------------------------)
+--R                         3 3     2     2       2 2     3 3  +-+
+--R                       (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R  /
+--R        +-+4+-+4+-+3
+--R     2c\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1258
+
+--S 1259 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                         2 +-+4+-+2 +-+
+--R           (2A c - 2B b)x \|b \|b  \|c
+--R         + 
+--R                2          3                 2   4+-+2
+--R           ((A c  - B b c)x  + (3A b c - 3B b )x)\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                    2          3                 2   4+-+2
+--R             ((- A c  + B b c)x  + (- A b c + B b )x)\|b
+--R           + 
+--R                             2   +-+
+--R             (- 2A b c + 2B b )x\|b
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R            2          2              2  +-+4+-+2            2       2   2
+--R       ((A c  - B b c)x  + A b c - B b )\|b \|b   + (- 3A b c  + 3B b c)x
+--R     + 
+--R            2       3
+--R       - A b c + B b
+--R  /
+--R             2 3           +-+4+-+2 +-+      3 4       2 2     2  4+-+2 4+-+2
+--R         ((4c x  + 4b c x)\|b \|b  \|c  + (2c x  + 4b c x  + 2b c)\|b  )\|c
+--R       + 
+--R               3 3     2 2
+--R         - 4b c x  - 4b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1259
+
+)clear all
+
+--S 1260 of 3139
+t0:=x^(3/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            2      +-+
+--R        (B x  + A)\|x
+--R   (1)  --------------
+--R             3
+--R          c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1260
+
+--S 1261 of 3139
+r0:=(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(5/4)*_
+   sqrt(2))-(b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*_
+   c^(5/4)*sqrt(2))+1/2*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(3/4)*c^(5/4)*sqrt(2))-1/2*(b*B-A*c)*log(sqrt(b)+_
+   x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*c^(5/4)*_
+   sqrt(2))+2*B*sqrt(x)/c
+--R 
+--R
+--R   (2)
+--R                       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  + \|b
+--R       (2A c - 2B b)atan(-------------------)
+--R                                 4+-+
+--R                                 \|b
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  - \|b        +-+4+-+3 4+-+ +-+
+--R       (2A c - 2B b)atan(-------------------) + 4B\|2 \|b   \|c \|x
+--R                                 4+-+
+--R                                 \|b
+--R  /
+--R        +-+4+-+3 4+-+
+--R     2c\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1261
+
+--S 1262 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +------------------------------------------------+
+--R            |   4 4     3     3     2 2 2 2       3 3     4 4
+--R            |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R         c  |------------------------------------------------
+--R           4|                        3 5
+--R           \|                     16b c
+--R      *
+--R         log
+--R                          +-+
+--R              (A c - B b)\|x
+--R            + 
+--R                    +------------------------------------------------+
+--R                    |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                    |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              2b c  |------------------------------------------------
+--R                   4|                        3 5
+--R                   \|                     16b c
+--R     + 
+--R       -
+--R               +------------------------------------------------+
+--R               |   4 4     3     3     2 2 2 2       3 3     4 4
+--R               |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R            c  |------------------------------------------------
+--R              4|                        3 5
+--R              \|                     16b c
+--R         *
+--R            log
+--R                             +-+
+--R                 (A c - B b)\|x
+--R               + 
+--R                         +------------------------------------------------+
+--R                         |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                         |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 - 2b c  |------------------------------------------------
+--R                        4|                        3 5
+--R                        \|                     16b c
+--R     + 
+--R       -
+--R                +------------------------------------------------+
+--R                |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R            2c  |------------------------------------------------
+--R               4|                        3 5
+--R               \|                     16b c
+--R         *
+--R                       +------------------------------------------------+
+--R                       |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                       |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 2b c  |------------------------------------------------
+--R                      4|                        3 5
+--R                      \|                     16b c
+--R            atan(-------------------------------------------------------)
+--R                                                 +-+
+--R                                     (A c - B b)\|x
+--R     + 
+--R          +-+
+--R       2B\|x
+--R  /
+--R     c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1262
+
+--S 1263 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 +------------------------------------------------+
+--R                 |   4 4     3     3     2 2 2 2       3 3     4 4
+--R            +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+3 4+-+
+--R         2c\|2   |------------------------------------------------ \|b   \|c
+--R                4|                        3 5
+--R                \|                     16b c
+--R      *
+--R         log
+--R                          +-+
+--R              (A c - B b)\|x
+--R            + 
+--R                    +------------------------------------------------+
+--R                    |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                    |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              2b c  |------------------------------------------------
+--R                   4|                        3 5
+--R                   \|                     16b c
+--R     + 
+--R       -
+--R                    +------------------------------------------------+
+--R                    |   4 4     3     3     2 2 2 2       3 3     4 4
+--R               +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+3 4+-+
+--R            2c\|2   |------------------------------------------------ \|b   \|c
+--R                   4|                        3 5
+--R                   \|                     16b c
+--R         *
+--R            log
+--R                             +-+
+--R                 (A c - B b)\|x
+--R               + 
+--R                         +------------------------------------------------+
+--R                         |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                         |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 - 2b c  |------------------------------------------------
+--R                        4|                        3 5
+--R                        \|                     16b c
+--R     + 
+--R                         +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R                           \|2 \|c \|x  + \|b
+--R       (- 2A c + 2B b)atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R                           \|2 \|c \|x  - \|b
+--R       (- 2A c + 2B b)atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R       -
+--R                    +------------------------------------------------+
+--R                    |   4 4     3     3     2 2 2 2       3 3     4 4
+--R               +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+3 4+-+
+--R            4c\|2   |------------------------------------------------ \|b   \|c
+--R                   4|                        3 5
+--R                   \|                     16b c
+--R         *
+--R                       +------------------------------------------------+
+--R                       |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                       |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 2b c  |------------------------------------------------
+--R                      4|                        3 5
+--R                      \|                     16b c
+--R            atan(-------------------------------------------------------)
+--R                                                 +-+
+--R                                     (A c - B b)\|x
+--R  /
+--R        +-+4+-+3 4+-+
+--R     2c\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1263
+
+--S 1264 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                           +-+4+-+2       2          3               2    +-+
+--R           ((2A c - 2B b)x\|b \|b   + (A c  - B b c)x  + (A b c - B b )x)\|c
+--R         + 
+--R                 2           2              2 4+-+2
+--R           ((3A c  - 3B b c)x  + A b c - B b )\|b
+--R         + 
+--R                  2          2              2  +-+
+--R           ((- A c  + B b c)x  - A b c + B b )\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R            2           2 +-+ +-+         3        2  3            2       2
+--R     (- 2A c  + 2B b c)x \|b \|c  + (- A c  + B b c )x  + (- 3A b c  + 3B b c)x
+--R  /
+--R             2 3           +-+4+-+2 +-+      3 4       2 2     2  4+-+2 4+-+2
+--R         ((4c x  + 4b c x)\|b \|b  \|c  + (2c x  + 4b c x  + 2b c)\|b  )\|c
+--R       + 
+--R               3 3     2 2
+--R         - 4b c x  - 4b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1264
+
+)clear all
+
+--S 1265 of 3139
+t0:=(A+B*x^2)*sqrt(x)/(b*x^2+c*x^4)
+--R 
+--R
+--R            2      +-+
+--R        (B x  + A)\|x
+--R   (1)  --------------
+--R             4      2
+--R          c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1265
+
+--S 1266 of 3139
+r0:=-(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*c^(3/4)*_
+   sqrt(2))+(b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*_
+   c^(3/4)*sqrt(2))+1/2*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(5/4)*c^(3/4)*sqrt(2))-1/2*(b*B-A*c)*log(sqrt(b)+_
+   x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*c^(3/4)*sqrt(2))-_
+   2*A/(b*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                   +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)\|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)\|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                +-+4+-+ +-+   4+-+
+--R                       +-+     \|2 \|c \|x  + \|b
+--R       (- 2A c + 2B b)\|x atan(-------------------)
+--R                                       4+-+
+--R                                       \|b
+--R     + 
+--R                                +-+4+-+ +-+   4+-+
+--R                       +-+     \|2 \|c \|x  - \|b        +-+4+-+4+-+3
+--R       (- 2A c + 2B b)\|x atan(-------------------) - 4A\|2 \|b \|c
+--R                                       4+-+
+--R                                       \|b
+--R  /
+--R        +-+4+-+4+-+3 +-+
+--R     2b\|2 \|b \|c  \|x
+--R                                                    Type: Expression(Integer)
+--E 1266
+
+--S 1267 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R               +------------------------------------------------+
+--R               |   4 4     3     3     2 2 2 2       3 3     4 4
+--R               |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b   +-+
+--R            b  |------------------------------------------------ \|x
+--R              4|                        5 3
+--R              \|                     16b c
+--R         *
+--R            log
+--R                   3 3     2     2       2 2     3 3  +-+
+--R                 (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R               + 
+--R                        +------------------------------------------------+3
+--R                        |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                   4 2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 8b c   |------------------------------------------------
+--R                       4|                        5 3
+--R                       \|                     16b c
+--R     + 
+--R            +------------------------------------------------+
+--R            |   4 4     3     3     2 2 2 2       3 3     4 4
+--R            |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b   +-+
+--R         b  |------------------------------------------------ \|x
+--R           4|                        5 3
+--R           \|                     16b c
+--R      *
+--R         log
+--R                3 3     2     2       2 2     3 3  +-+
+--R              (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R            + 
+--R                       +------------------------------------------------+3
+--R                       |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                  4 2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              - 8b c   |------------------------------------------------
+--R                      4|                        5 3
+--R                      \|                     16b c
+--R     + 
+--R       -
+--R                +------------------------------------------------+
+--R                |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b   +-+
+--R            2b  |------------------------------------------------ \|x
+--R               4|                        5 3
+--R               \|                     16b c
+--R         *
+--R                        +------------------------------------------------+3
+--R                        |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                   4 2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 8b c   |------------------------------------------------
+--R                       4|                        5 3
+--R                       \|                     16b c
+--R            atan(---------------------------------------------------------)
+--R                            3 3     2     2       2 2     3 3  +-+
+--R                          (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R     + 
+--R       - 2A
+--R  /
+--R       +-+
+--R     b\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1267
+
+--S 1268 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R                    +------------------------------------------------+
+--R                    |   4 4     3     3     2 2 2 2       3 3     4 4
+--R               +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+4+-+3
+--R            2b\|2   |------------------------------------------------ \|b \|c
+--R                   4|                        5 3
+--R                   \|                     16b c
+--R         *
+--R            log
+--R                   3 3     2     2       2 2     3 3  +-+
+--R                 (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R               + 
+--R                        +------------------------------------------------+3
+--R                        |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                   4 2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 8b c   |------------------------------------------------
+--R                       4|                        5 3
+--R                       \|                     16b c
+--R     + 
+--R                 +------------------------------------------------+
+--R                 |   4 4     3     3     2 2 2 2       3 3     4 4
+--R            +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+4+-+3
+--R         2b\|2   |------------------------------------------------ \|b \|c
+--R                4|                        5 3
+--R                \|                     16b c
+--R      *
+--R         log
+--R                3 3     2     2       2 2     3 3  +-+
+--R              (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R            + 
+--R                       +------------------------------------------------+3
+--R                       |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                  4 2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              - 8b c   |------------------------------------------------
+--R                      4|                        5 3
+--R                      \|                     16b c
+--R     + 
+--R                         +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  + \|b
+--R       (2A c - 2B b)atan(-------------------)
+--R                                 4+-+
+--R                                 \|b
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  - \|b
+--R       (2A c - 2B b)atan(-------------------)
+--R                                 4+-+
+--R                                 \|b
+--R     + 
+--R       -
+--R                    +------------------------------------------------+
+--R                    |   4 4     3     3     2 2 2 2       3 3     4 4
+--R               +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+4+-+3
+--R            4b\|2   |------------------------------------------------ \|b \|c
+--R                   4|                        5 3
+--R                   \|                     16b c
+--R         *
+--R                        +------------------------------------------------+3
+--R                        |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                   4 2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 8b c   |------------------------------------------------
+--R                       4|                        5 3
+--R                       \|                     16b c
+--R            atan(---------------------------------------------------------)
+--R                            3 3     2     2       2 2     3 3  +-+
+--R                          (A c  - 3A B b c  + 3A B b c - B b )\|x
+--R  /
+--R        +-+4+-+4+-+3
+--R     2b\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1268
+
+--S 1269 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                           2 +-+4+-+2 +-+
+--R           (- 2A c + 2B b)x \|b \|b  \|c
+--R         + 
+--R                  2          3                   2   4+-+2
+--R           ((- A c  + B b c)x  + (- 3A b c + 3B b )x)\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R             2          3               2   4+-+2                 2   +-+  +-+
+--R       (((A c  - B b c)x  + (A b c - B b )x)\|b   + (2A b c - 2B b )x\|b )\|c
+--R     + 
+--R              2          2              2  +-+4+-+2          2       2   2
+--R       ((- A c  + B b c)x  - A b c + B b )\|b \|b   + (3A b c  - 3B b c)x
+--R     + 
+--R          2       3
+--R       A b c - B b
+--R  /
+--R                 3     2   +-+4+-+2 +-+        2 4     2   2     3 4+-+2 4+-+2
+--R         ((4b c x  + 4b x)\|b \|b  \|c  + (2b c x  + 4b c x  + 2b )\|b  )\|c
+--R       + 
+--R             2 2 3     3
+--R         - 4b c x  - 4b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1269
+
+)clear all
+
+--S 1270 of 3139
+t0:=(A+B*x^2)/((b*x^2+c*x^4)*sqrt(x))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R            4      2  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1270
+
+--S 1271 of 3139
+r0:=-2/3*A/(b*x^(3/2))-(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (b^(7/4)*c^(1/4)*sqrt(2))+(b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(7/4)*c^(1/4)*sqrt(2))-1/2*(b*B-A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*c^(1/4)*sqrt(2))+_
+   1/2*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(7/4)*c^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                        +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3A c + 3B b)x\|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                      +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3A c - 3B b)x\|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R                        +-+     \|2 \|c \|x  + \|b
+--R       (- 6A c + 6B b)x\|x atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R                        +-+     \|2 \|c \|x  - \|b        +-+4+-+3 4+-+
+--R       (- 6A c + 6B b)x\|x atan(-------------------) - 4A\|2 \|b   \|c
+--R                                        4+-+
+--R                                        \|b
+--R  /
+--R          +-+4+-+3 4+-+ +-+
+--R     6b x\|2 \|b   \|c \|x
+--R                                                    Type: Expression(Integer)
+--E 1271
+
+--S 1272 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                  +------------------------------------------------+
+--R                  |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b   +-+
+--R            3b x  |------------------------------------------------ \|x
+--R                 4|                         7
+--R                 \|                      16b c
+--R         *
+--R            log
+--R                             +-+
+--R                 (A c - B b)\|x
+--R               + 
+--R                      +------------------------------------------------+
+--R                      |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                   2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 2b   |------------------------------------------------
+--R                     4|                         7
+--R                     \|                      16b c
+--R     + 
+--R               +------------------------------------------------+
+--R               |   4 4     3     3     2 2 2 2       3 3     4 4
+--R               |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b   +-+
+--R         3b x  |------------------------------------------------ \|x
+--R              4|                         7
+--R              \|                      16b c
+--R      *
+--R         log
+--R                          +-+
+--R              (A c - B b)\|x
+--R            + 
+--R                     +------------------------------------------------+
+--R                     |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                  2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              - 2b   |------------------------------------------------
+--R                    4|                         7
+--R                    \|                      16b c
+--R     + 
+--R               +------------------------------------------------+
+--R               |   4 4     3     3     2 2 2 2       3 3     4 4
+--R               |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b   +-+
+--R         6b x  |------------------------------------------------ \|x
+--R              4|                         7
+--R              \|                      16b c
+--R      *
+--R                   +------------------------------------------------+
+--R                   |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              2b   |------------------------------------------------
+--R                  4|                         7
+--R                  \|                      16b c
+--R         atan(------------------------------------------------------)
+--R                                              +-+
+--R                                  (A c - B b)\|x
+--R     + 
+--R       - 2A
+--R  /
+--R          +-+
+--R     3b x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1272
+
+--S 1273 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R                    +------------------------------------------------+
+--R                    |   4 4     3     3     2 2 2 2       3 3     4 4
+--R               +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+3 4+-+
+--R            2b\|2   |------------------------------------------------ \|b   \|c
+--R                   4|                         7
+--R                   \|                      16b c
+--R         *
+--R            log
+--R                             +-+
+--R                 (A c - B b)\|x
+--R               + 
+--R                      +------------------------------------------------+
+--R                      |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                   2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R                 2b   |------------------------------------------------
+--R                     4|                         7
+--R                     \|                      16b c
+--R     + 
+--R                 +------------------------------------------------+
+--R                 |   4 4     3     3     2 2 2 2       3 3     4 4
+--R            +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+3 4+-+
+--R         2b\|2   |------------------------------------------------ \|b   \|c
+--R                4|                         7
+--R                \|                      16b c
+--R      *
+--R         log
+--R                          +-+
+--R              (A c - B b)\|x
+--R            + 
+--R                     +------------------------------------------------+
+--R                     |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                  2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              - 2b   |------------------------------------------------
+--R                    4|                         7
+--R                    \|                      16b c
+--R     + 
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  + \|b
+--R       (2A c - 2B b)atan(-------------------)
+--R                                 4+-+
+--R                                 \|b
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  - \|b
+--R       (2A c - 2B b)atan(-------------------)
+--R                                 4+-+
+--R                                 \|b
+--R     + 
+--R                 +------------------------------------------------+
+--R                 |   4 4     3     3     2 2 2 2       3 3     4 4
+--R            +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b  4+-+3 4+-+
+--R         4b\|2   |------------------------------------------------ \|b   \|c
+--R                4|                         7
+--R                \|                      16b c
+--R      *
+--R                   +------------------------------------------------+
+--R                   |   4 4     3     3     2 2 2 2       3 3     4 4
+--R                2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c - B b
+--R              2b   |------------------------------------------------
+--R                  4|                         7
+--R                  \|                      16b c
+--R         atan(------------------------------------------------------)
+--R                                              +-+
+--R                                  (A c - B b)\|x
+--R  /
+--R        +-+4+-+3 4+-+
+--R     2b\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1273
+
+--S 1274 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                  +-+4+-+2         2          3
+--R                 (- 2A c + 2B b)x\|b \|b   + (- A c  + B b c)x
+--R               + 
+--R                               2
+--R                 (- A b c + B b )x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                   2           2              2 4+-+2
+--R           ((- 3A c  + 3B b c)x  - A b c + B b )\|b
+--R         + 
+--R                2          2              2  +-+
+--R           ((A c  - B b c)x  + A b c - B b )\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R            2           2 +-+ +-+       3        2  3          2       2
+--R       (2A c  - 2B b c)x \|b \|c  + (A c  - B b c )x  + (3A b c  - 3B b c)x
+--R  /
+--R                 3     2   +-+4+-+2 +-+        2 4     2   2     3 4+-+2 4+-+2
+--R         ((4b c x  + 4b x)\|b \|b  \|c  + (2b c x  + 4b c x  + 2b )\|b  )\|c
+--R       + 
+--R             2 2 3     3
+--R         - 4b c x  - 4b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1274
+
+)clear all
+
+--S 1275 of 3139
+t0:=(A+B*x^2)/(x^(3/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R            5      3  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1275
+
+--S 1276 of 3139
+r0:=-2/5*A/(b*x^(5/2))+c^(1/4)*(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(9/4)*sqrt(2))-c^(1/4)*(b*B-A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(9/4)*sqrt(2))-1/2*c^(1/4)*(b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*_
+   sqrt(2))+1/2*c^(1/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(9/4)*sqrt(2))-2*(b*B-A*c)/(b^2*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                       2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5A c + 5B b)x  \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     2 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5A c - 5B b)x  \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R                       2 4+-+ +-+     \|2 \|c \|x  + \|b
+--R       (10A c - 10B b)x  \|c \|x atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R                       2 4+-+ +-+     \|2 \|c \|x  - \|b
+--R       (10A c - 10B b)x  \|c \|x atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R                        2         +-+4+-+
+--R       ((20A c - 20B b)x  - 4A b)\|2 \|b
+--R  /
+--R        2 2 +-+4+-+ +-+
+--R     10b x \|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 1276
+
+--S 1277 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                +--------------------------------------------------+
+--R                |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R           2 2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c  +-+
+--R         5b x   |-------------------------------------------------- \|x
+--R               4|                          9
+--R               \|                       16b
+--R      *
+--R         log
+--R                3 4     2     3       2 2 2    3 3   +-+
+--R              (A c  - 3A B b c  + 3A B b c  - B b c)\|x
+--R            + 
+--R                   +--------------------------------------------------+3
+--R                   |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R                7  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R              8b   |--------------------------------------------------
+--R                  4|                          9
+--R                  \|                       16b
+--R     + 
+--R       -
+--R                   +--------------------------------------------------+
+--R                   |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R              2 2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c  +-+
+--R            5b x   |-------------------------------------------------- \|x
+--R                  4|                          9
+--R                  \|                       16b
+--R         *
+--R            log
+--R                   3 4     2     3       2 2 2    3 3   +-+
+--R                 (A c  - 3A B b c  + 3A B b c  - B b c)\|x
+--R               + 
+--R                        +--------------------------------------------------+3
+--R                        |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R                     7  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R                 - 8b   |--------------------------------------------------
+--R                       4|                          9
+--R                       \|                       16b
+--R     + 
+--R                 +--------------------------------------------------+
+--R                 |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R            2 2  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c  +-+
+--R         10b x   |-------------------------------------------------- \|x
+--R                4|                          9
+--R                \|                       16b
+--R      *
+--R                   +--------------------------------------------------+3
+--R                   |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R                7  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R              8b   |--------------------------------------------------
+--R                  4|                          9
+--R                  \|                       16b
+--R         atan(---------------------------------------------------------)
+--R                        3 4     2     3       2 2 2    3 3   +-+
+--R                      (A c  - 3A B b c  + 3A B b c  - B b c)\|x
+--R     + 
+--R                       2
+--R       (10A c - 10B b)x  - 2A b
+--R  /
+--R       2 2 +-+
+--R     5b x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1277
+
+--S 1278 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)\|c log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  +--------------------------------------------------+
+--R                  |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R           2 +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c 4+-+
+--R         2b \|2   |-------------------------------------------------- \|b
+--R                 4|                          9
+--R                 \|                       16b
+--R      *
+--R         log
+--R                3 4     2     3       2 2 2    3 3   +-+
+--R              (A c  - 3A B b c  + 3A B b c  - B b c)\|x
+--R            + 
+--R                   +--------------------------------------------------+3
+--R                   |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R                7  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R              8b   |--------------------------------------------------
+--R                  4|                          9
+--R                  \|                       16b
+--R     + 
+--R       -
+--R                     +--------------------------------------------------+
+--R                     |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R              2 +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c 4+-+
+--R            2b \|2   |-------------------------------------------------- \|b
+--R                    4|                          9
+--R                    \|                       16b
+--R         *
+--R            log
+--R                   3 4     2     3       2 2 2    3 3   +-+
+--R                 (A c  - 3A B b c  + 3A B b c  - B b c)\|x
+--R               + 
+--R                        +--------------------------------------------------+3
+--R                        |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R                     7  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R                 - 8b   |--------------------------------------------------
+--R                       4|                          9
+--R                       \|                       16b
+--R     + 
+--R                    4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)\|c log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                +-+4+-+ +-+   4+-+
+--R                      4+-+     \|2 \|c \|x  + \|b
+--R       (- 2A c + 2B b)\|c atan(-------------------)
+--R                                       4+-+
+--R                                       \|b
+--R     + 
+--R                                +-+4+-+ +-+   4+-+
+--R                      4+-+     \|2 \|c \|x  - \|b
+--R       (- 2A c + 2B b)\|c atan(-------------------)
+--R                                       4+-+
+--R                                       \|b
+--R     + 
+--R                  +--------------------------------------------------+
+--R                  |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R           2 +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c 4+-+
+--R         4b \|2   |-------------------------------------------------- \|b
+--R                 4|                          9
+--R                 \|                       16b
+--R      *
+--R                   +--------------------------------------------------+3
+--R                   |   4 5     3     4     2 2 2 3       3 3 2    4 4
+--R                7  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R              8b   |--------------------------------------------------
+--R                  4|                          9
+--R                  \|                       16b
+--R         atan(---------------------------------------------------------)
+--R                        3 4     2     3       2 2 2    3 3   +-+
+--R                      (A c  - 3A B b c  + 3A B b c  - B b c)\|x
+--R  /
+--R       2 +-+4+-+
+--R     2b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1278
+
+--S 1279 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                   2          3               2   4+-+2                 2   +-+
+--R             (((A c  - B b c)x  + (A b c - B b )x)\|b   + (2A b c - 2B b )x\|b )
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                  2          2              2  +-+4+-+2          2       2   2
+--R           ((- A c  + B b c)x  - A b c + B b )\|b \|b   + (3A b c  - 3B b c)x
+--R         + 
+--R              2       3
+--R           A b c - B b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R              2           2 +-+4+-+2 +-+
+--R       (- 2A c  + 2B b c)x \|b \|b  \|c
+--R     + 
+--R              3        2  3            2       2    4+-+2
+--R       ((- A c  + B b c )x  + (- 3A b c  + 3B b c)x)\|b
+--R  /
+--R            3   3     4  4+-+2        2   3     3   +-+4+-+2 +-+
+--R         (4b c x  + 4b x)\|c   + (- 4b c x  - 4b x)\|b \|b  \|c
+--R       + 
+--R              2 2 4     3   2     4 4+-+2
+--R         (- 2b c x  - 4b c x  - 2b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1279
+
+)clear all
+
+--S 1280 of 3139
+t0:=(A+B*x^2)/(x^(5/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R            6      4  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1280
+
+--S 1281 of 3139
+r0:=-2/7*A/(b*x^(7/2))-2/3*(b*B-A*c)/(b^2*x^(3/2))+c^(3/4)*(b*B-A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*sqrt(2))-c^(3/4)*_
+   (b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*sqrt(2))+_
+   1/2*c^(3/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(11/4)*sqrt(2))-1/2*c^(3/4)*(b*B-A*c)*log(sqrt(b)+x*_
+   sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                       3 4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21A c - 21B b)x  \|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                         3 4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21A c + 21B b)x  \|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R                       3 4+-+3 +-+     \|2 \|c \|x  + \|b
+--R       (42A c - 42B b)x  \|c  \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|b
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R                       3 4+-+3 +-+     \|2 \|c \|x  - \|b
+--R       (42A c - 42B b)x  \|c  \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|b
+--R     + 
+--R                        2          +-+4+-+3
+--R       ((28A c - 28B b)x  - 12A b)\|2 \|b
+--R  /
+--R        2 3 +-+4+-+3 +-+
+--R     42b x \|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 1281
+
+--S 1282 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 +---------------------------------------------------+
+--R                 |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R            2 3  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c   +-+
+--R         21b x   |--------------------------------------------------- \|x
+--R                4|                          11
+--R                \|                       16b
+--R      *
+--R         log
+--R                  2          +-+
+--R              (A c  - B b c)\|x
+--R            + 
+--R                   +---------------------------------------------------+
+--R                   |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R                3  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R              2b   |---------------------------------------------------
+--R                  4|                          11
+--R                  \|                       16b
+--R     + 
+--R       -
+--R                    +---------------------------------------------------+
+--R                    |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R               2 3  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c   +-+
+--R            21b x   |--------------------------------------------------- \|x
+--R                   4|                          11
+--R                   \|                       16b
+--R         *
+--R            log
+--R                     2          +-+
+--R                 (A c  - B b c)\|x
+--R               + 
+--R                        +---------------------------------------------------+
+--R                        |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R                     3  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R                 - 2b   |---------------------------------------------------
+--R                       4|                          11
+--R                       \|                       16b
+--R     + 
+--R       -
+--R                    +---------------------------------------------------+
+--R                    |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R               2 3  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c   +-+
+--R            42b x   |--------------------------------------------------- \|x
+--R                   4|                          11
+--R                   \|                       16b
+--R         *
+--R                      +---------------------------------------------------+
+--R                      |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R                   3  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R                 2b   |---------------------------------------------------
+--R                     4|                          11
+--R                     \|                       16b
+--R            atan(---------------------------------------------------------)
+--R                                         2          +-+
+--R                                     (A c  - B b c)\|x
+--R     + 
+--R                       2
+--R       (14A c - 14B b)x  - 6A b
+--R  /
+--R        2 3 +-+
+--R     21b x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1282
+
+--S 1283 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)\|c  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  +---------------------------------------------------+
+--R                  |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R           2 +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c  4+-+3
+--R         2b \|2   |--------------------------------------------------- \|b
+--R                 4|                          11
+--R                 \|                       16b
+--R      *
+--R         log
+--R                  2          +-+
+--R              (A c  - B b c)\|x
+--R            + 
+--R                   +---------------------------------------------------+
+--R                   |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R                3  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R              2b   |---------------------------------------------------
+--R                  4|                          11
+--R                  \|                       16b
+--R     + 
+--R       -
+--R                     +---------------------------------------------------+
+--R                     |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R              2 +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c  4+-+3
+--R            2b \|2   |--------------------------------------------------- \|b
+--R                    4|                          11
+--R                    \|                       16b
+--R         *
+--R            log
+--R                     2          +-+
+--R                 (A c  - B b c)\|x
+--R               + 
+--R                        +---------------------------------------------------+
+--R                        |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R                     3  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R                 - 2b   |---------------------------------------------------
+--R                       4|                          11
+--R                       \|                       16b
+--R     + 
+--R                  4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)\|c  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R                      4+-+3     \|2 \|c \|x  + \|b
+--R       (- 2A c + 2B b)\|c  atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R                      4+-+3     \|2 \|c \|x  - \|b
+--R       (- 2A c + 2B b)\|c  atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R       -
+--R                     +---------------------------------------------------+
+--R                     |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R              2 +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c  4+-+3
+--R            4b \|2   |--------------------------------------------------- \|b
+--R                    4|                          11
+--R                    \|                       16b
+--R         *
+--R                      +---------------------------------------------------+
+--R                      |   4 7     3     6     2 2 2 5       3 3 4    4 4 3
+--R                   3  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R                 2b   |---------------------------------------------------
+--R                     4|                          11
+--R                     \|                       16b
+--R            atan(---------------------------------------------------------)
+--R                                         2          +-+
+--R                                     (A c  - B b c)\|x
+--R  /
+--R       2 +-+4+-+3
+--R     2b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1283
+
+--S 1284 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R               2           2 +-+ +-+       3        2  3          2       2
+--R         ((2A c  - 2B b c)x \|b \|c  + (A c  - B b c )x  + (3A b c  - 3B b c)x)
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                  2            +-+4+-+2         3        2  3
+--R           (- 2A c  + 2B b c)x\|b \|b   + (- A c  + B b c )x
+--R         + 
+--R                   2      2
+--R           (- A b c  + B b c)x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R               3         2  2        2      2  4+-+2
+--R       ((- 3A c  + 3B b c )x  - A b c  + B b c)\|b
+--R     + 
+--R            3        2  2        2      2   +-+
+--R       ((A c  - B b c )x  + A b c  - B b c)\|b
+--R  /
+--R            3   3     4  4+-+2        2   3     3   +-+4+-+2 +-+
+--R         (4b c x  + 4b x)\|c   + (- 4b c x  - 4b x)\|b \|b  \|c
+--R       + 
+--R              2 2 4     3   2     4 4+-+2
+--R         (- 2b c x  - 4b c x  - 2b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1284
+
+)clear all
+
+--S 1285 of 3139
+t0:=(A+B*x^2)/(x^(7/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R            7      5  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1285
+
+--S 1286 of 3139
+r0:=-2/9*A/(b*x^(9/2))-2/5*(b*B-A*c)/(b^2*x^(5/2))-c^(5/4)*(b*B-A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*sqrt(2))+c^(5/4)*_
+   (b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*sqrt(2))+_
+   1/2*c^(5/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(13/4)*sqrt(2))-1/2*c^(5/4)*(b*B-A*c)*log(sqrt(b)+x*_
+   sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*sqrt(2))+_
+   2*c*(b*B-A*c)/(b^3*sqrt(x))
+--R 
+--R
+--R   (2)
+--R             2            4 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45A c  - 45B b c)x  \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               2            4 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45A c  + 45B b c)x  \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                            +-+4+-+ +-+   4+-+
+--R               2            4 4+-+ +-+     \|2 \|c \|x  + \|b
+--R       (- 90A c  + 90B b c)x  \|c \|x atan(-------------------)
+--R                                                   4+-+
+--R                                                   \|b
+--R     + 
+--R                                            +-+4+-+ +-+   4+-+
+--R               2            4 4+-+ +-+     \|2 \|c \|x  - \|b
+--R       (- 90A c  + 90B b c)x  \|c \|x atan(-------------------)
+--R                                                   4+-+
+--R                                                   \|b
+--R     + 
+--R                 2             4                   2  2        2  +-+4+-+
+--R       ((- 180A c  + 180B b c)x  + (36A b c - 36B b )x  - 20A b )\|2 \|b
+--R  /
+--R        3 4 +-+4+-+ +-+
+--R     90b x \|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 1286
+
+--S 1287 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                    +---------------------------------------------------+
+--R                    |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R               3 4  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c   +-+
+--R            45b x   |--------------------------------------------------- \|x
+--R                   4|                          13
+--R                   \|                       16b
+--R         *
+--R            log
+--R                   3 7     2     6       2 2 5    3 3 4  +-+
+--R                 (A c  - 3A B b c  + 3A B b c  - B b c )\|x
+--R               + 
+--R                       +---------------------------------------------------+3
+--R                       |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R                   10  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R                 8b    |---------------------------------------------------
+--R                      4|                          13
+--R                      \|                       16b
+--R     + 
+--R                 +---------------------------------------------------+
+--R                 |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R            3 4  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c   +-+
+--R         45b x   |--------------------------------------------------- \|x
+--R                4|                          13
+--R                \|                       16b
+--R      *
+--R         log
+--R                3 7     2     6       2 2 5    3 3 4  +-+
+--R              (A c  - 3A B b c  + 3A B b c  - B b c )\|x
+--R            + 
+--R                      +---------------------------------------------------+3
+--R                      |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R                  10  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R              - 8b    |---------------------------------------------------
+--R                     4|                          13
+--R                     \|                       16b
+--R     + 
+--R       -
+--R                    +---------------------------------------------------+
+--R                    |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R               3 4  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c   +-+
+--R            90b x   |--------------------------------------------------- \|x
+--R                   4|                          13
+--R                   \|                       16b
+--R         *
+--R                       +---------------------------------------------------+3
+--R                       |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R                   10  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R                 8b    |---------------------------------------------------
+--R                      4|                          13
+--R                      \|                       16b
+--R            atan(-----------------------------------------------------------)
+--R                           3 7     2     6       2 2 5    3 3 4  +-+
+--R                         (A c  - 3A B b c  + 3A B b c  - B b c )\|x
+--R     + 
+--R               2            4                   2  2        2
+--R       (- 90A c  + 90B b c)x  + (18A b c - 18B b )x  - 10A b
+--R  /
+--R        3 4 +-+
+--R     45b x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1287
+
+--S 1288 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c  + B b c)\|c log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R                     +---------------------------------------------------+
+--R                     |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R              3 +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c  4+-+
+--R            2b \|2   |--------------------------------------------------- \|b
+--R                    4|                          13
+--R                    \|                       16b
+--R         *
+--R            log
+--R                   3 7     2     6       2 2 5    3 3 4  +-+
+--R                 (A c  - 3A B b c  + 3A B b c  - B b c )\|x
+--R               + 
+--R                       +---------------------------------------------------+3
+--R                       |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R                   10  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R                 8b    |---------------------------------------------------
+--R                      4|                          13
+--R                      \|                       16b
+--R     + 
+--R                  +---------------------------------------------------+
+--R                  |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R           3 +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c  4+-+
+--R         2b \|2   |--------------------------------------------------- \|b
+--R                 4|                          13
+--R                 \|                       16b
+--R      *
+--R         log
+--R                3 7     2     6       2 2 5    3 3 4  +-+
+--R              (A c  - 3A B b c  + 3A B b c  - B b c )\|x
+--R            + 
+--R                      +---------------------------------------------------+3
+--R                      |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R                  10  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R              - 8b    |---------------------------------------------------
+--R                     4|                          13
+--R                     \|                       16b
+--R     + 
+--R           2         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c  - B b c)\|c log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R            2          4+-+     \|2 \|c \|x  + \|b
+--R       (2A c  - 2B b c)\|c atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R            2          4+-+     \|2 \|c \|x  - \|b
+--R       (2A c  - 2B b c)\|c atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R       -
+--R                     +---------------------------------------------------+
+--R                     |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R              3 +-+  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c  4+-+
+--R            4b \|2   |--------------------------------------------------- \|b
+--R                    4|                          13
+--R                    \|                       16b
+--R         *
+--R                       +---------------------------------------------------+3
+--R                       |   4 9     3     8     2 2 2 7       3 3 6    4 4 5
+--R                   10  |- A c  + 4A B b c  - 6A B b c  + 4A B b c  - B b c
+--R                 8b    |---------------------------------------------------
+--R                      4|                          13
+--R                      \|                       16b
+--R            atan(-----------------------------------------------------------)
+--R                           3 7     2     6       2 2 5    3 3 4  +-+
+--R                         (A c  - 3A B b c  + 3A B b c  - B b c )\|x
+--R  /
+--R       3 +-+4+-+
+--R     2b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1288
+
+--S 1289 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      3        2  3           2      2    4+-+2
+--R               ((- A c  + B b c )x  + (- A b c  + B b c)x)\|b
+--R             + 
+--R                        2       2    +-+
+--R               (- 2A b c  + 2B b c)x\|b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                3        2  2        2      2   +-+4+-+2
+--R           ((A c  - B b c )x  + A b c  - B b c)\|b \|b
+--R         + 
+--R                    3       2 2  2      2 2      3
+--R           (- 3A b c  + 3B b c )x  - A b c  + B b c
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R            3         2  2 +-+4+-+2 +-+
+--R       (2A c  - 2B b c )x \|b \|b  \|c
+--R     + 
+--R            4        3  3          3       2 2   4+-+2
+--R       ((A c  - B b c )x  + (3A b c  - 3B b c )x)\|b
+--R  /
+--R            4   3     5  4+-+2        3   3     4   +-+4+-+2 +-+
+--R         (4b c x  + 4b x)\|c   + (- 4b c x  - 4b x)\|b \|b  \|c
+--R       + 
+--R              3 2 4     4   2     5 4+-+2
+--R         (- 2b c x  - 4b c x  - 2b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1289
+
+)clear all
+
+--S 1290 of 3139
+t0:=(A+B*x^2)/(x^(9/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R            8      6  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1290
+
+--S 1291 of 3139
+r0:=-2/11*A/(b*x^(11/2))-2/7*(b*B-A*c)/(b^2*x^(7/2))+2/3*c*(b*B-A*c)/_
+   (b^3*x^(3/2))-c^(7/4)*(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(15/4)*sqrt(2))+c^(7/4)*(b*B-A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(15/4)*sqrt(2))-1/2*c^(7/4)*(b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(15/4)*_
+   sqrt(2))+1/2*c^(7/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                2             5 4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 231A c  + 231B b c)x  \|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              2             5 4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (231A c  - 231B b c)x  \|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                               +-+4+-+ +-+   4+-+
+--R                2             5 4+-+3 +-+     \|2 \|c \|x  + \|b
+--R       (- 462A c  + 462B b c)x  \|c  \|x atan(-------------------)
+--R                                                      4+-+
+--R                                                      \|b
+--R     + 
+--R                                               +-+4+-+ +-+   4+-+
+--R                2             5 4+-+3 +-+     \|2 \|c \|x  - \|b
+--R       (- 462A c  + 462B b c)x  \|c  \|x atan(-------------------)
+--R                                                      4+-+
+--R                                                      \|b
+--R     + 
+--R                 2             4                     2  2        2  +-+4+-+3
+--R       ((- 308A c  + 308B b c)x  + (132A b c - 132B b )x  - 84A b )\|2 \|b
+--R  /
+--R         3 5 +-+4+-+3 +-+
+--R     462b x \|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 1291
+
+--S 1292 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                     +-----------------------------------------------------+
+--R                     |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R                3 5  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c   +-+
+--R            231b x   |----------------------------------------------------- \|x
+--R                    4|                           15
+--R                    \|                        16b
+--R         *
+--R            log
+--R                     3        2  +-+
+--R                 (A c  - B b c )\|x
+--R               + 
+--R                      +-----------------------------------------------------+
+--R                      |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R                   4  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c
+--R                 2b   |-----------------------------------------------------
+--R                     4|                           15
+--R                     \|                        16b
+--R     + 
+--R                  +-----------------------------------------------------+
+--R                  |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R             3 5  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c   +-+
+--R         231b x   |----------------------------------------------------- \|x
+--R                 4|                           15
+--R                 \|                        16b
+--R      *
+--R         log
+--R                  3        2  +-+
+--R              (A c  - B b c )\|x
+--R            + 
+--R                     +-----------------------------------------------------+
+--R                     |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R                  4  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c
+--R              - 2b   |-----------------------------------------------------
+--R                    4|                           15
+--R                    \|                        16b
+--R     + 
+--R                  +-----------------------------------------------------+
+--R                  |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R             3 5  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c   +-+
+--R         462b x   |----------------------------------------------------- \|x
+--R                 4|                           15
+--R                 \|                        16b
+--R      *
+--R                   +-----------------------------------------------------+
+--R                   |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R                4  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c
+--R              2b   |-----------------------------------------------------
+--R                  4|                           15
+--R                  \|                        16b
+--R         atan(-----------------------------------------------------------)
+--R                                      3        2  +-+
+--R                                  (A c  - B b c )\|x
+--R     + 
+--R                2             4                   2  2        2
+--R       (- 154A c  + 154B b c)x  + (66A b c - 66B b )x  - 42A b
+--R  /
+--R         3 5 +-+
+--R     231b x \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1292
+
+--S 1293 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2         4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c  - B b c)\|c  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R                     +-----------------------------------------------------+
+--R                     |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R              3 +-+  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c  4+-+3
+--R            2b \|2   |----------------------------------------------------- \|b
+--R                    4|                           15
+--R                    \|                        16b
+--R         *
+--R            log
+--R                     3        2  +-+
+--R                 (A c  - B b c )\|x
+--R               + 
+--R                      +-----------------------------------------------------+
+--R                      |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R                   4  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c
+--R                 2b   |-----------------------------------------------------
+--R                     4|                           15
+--R                     \|                        16b
+--R     + 
+--R                  +-----------------------------------------------------+
+--R                  |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R           3 +-+  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c  4+-+3
+--R         2b \|2   |----------------------------------------------------- \|b
+--R                 4|                           15
+--R                 \|                        16b
+--R      *
+--R         log
+--R                  3        2  +-+
+--R              (A c  - B b c )\|x
+--R            + 
+--R                     +-----------------------------------------------------+
+--R                     |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R                  4  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c
+--R              - 2b   |-----------------------------------------------------
+--R                    4|                           15
+--R                    \|                        16b
+--R     + 
+--R             2         4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c  + B b c)\|c  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R            2          4+-+3     \|2 \|c \|x  + \|b
+--R       (2A c  - 2B b c)\|c  atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R            2          4+-+3     \|2 \|c \|x  - \|b
+--R       (2A c  - 2B b c)\|c  atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R                  +-----------------------------------------------------+
+--R                  |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R           3 +-+  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c  4+-+3
+--R         4b \|2   |----------------------------------------------------- \|b
+--R                 4|                           15
+--R                 \|                        16b
+--R      *
+--R                   +-----------------------------------------------------+
+--R                   |   4 11     3     10     2 2 2 9       3 3 8    4 4 7
+--R                4  |- A c   + 4A B b c   - 6A B b c  + 4A B b c  - B b c
+--R              2b   |-----------------------------------------------------
+--R                  4|                           15
+--R                  \|                        16b
+--R         atan(-----------------------------------------------------------)
+--R                                      3        2  +-+
+--R                                  (A c  - B b c )\|x
+--R  /
+--R       3 +-+4+-+3
+--R     2b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1293
+
+--S 1294 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  3         2  2 +-+ +-+         4        3  3
+--R           (- 2A c  + 2B b c )x \|b \|c  + (- A c  + B b c )x
+--R         + 
+--R                    3       2 2
+--R           (- 3A b c  + 3B b c )x
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R               3         2   +-+4+-+2       4        3  3         3      2 2
+--R         ((2A c  - 2B b c )x\|b \|b   + (A c  - B b c )x  + (A b c  - B b c )x)
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R             4         3  2        3      2 2 4+-+2
+--R       ((3A c  - 3B b c )x  + A b c  - B b c )\|b
+--R     + 
+--R              4        3  2        3      2 2  +-+
+--R       ((- A c  + B b c )x  - A b c  + B b c )\|b
+--R  /
+--R            4   3     5  4+-+2        3   3     4   +-+4+-+2 +-+
+--R         (4b c x  + 4b x)\|c   + (- 4b c x  - 4b x)\|b \|b  \|c
+--R       + 
+--R              3 2 4     4   2     5 4+-+2
+--R         (- 2b c x  - 4b c x  - 2b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1294
+
+)clear all
+
+--S 1295 of 3139
+t0:=x^(19/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R             7      5  +-+
+--R         (B x  + A x )\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1295
+
+--S 1296 of 3139
+r0:=-1/10*(13*b*B-9*A*c)*x^(5/2)/c^3+1/18*(13*b*B-9*A*c)*x^(9/2)/(b*c^2)-_
+   1/2*(b*B-A*c)*x^(13/2)/(b*c*(b+c*x^2))+1/4*b^(5/4)*(13*b*B-9*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(17/4)*sqrt(2))-_
+   1/4*b^(5/4)*(13*b*B-9*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (c^(17/4)*sqrt(2))+1/8*b^(5/4)*(13*b*B-9*A*c)*log(sqrt(b)+x*sqrt(c)-_
+   b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(17/4)*sqrt(2))-1/8*b^(5/4)*_
+   (13*b*B-9*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(c^(17/4)*sqrt(2))+1/2*b*(13*b*B-9*A*c)*sqrt(x)/c^4
+--R 
+--R
+--R   (2)
+--R                   2         2   2         2          3 4+-+
+--R         ((405A b c  - 585B b c)x  + 405A b c - 585B b )\|b
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     2         2   2         2          3 4+-+
+--R         ((- 405A b c  + 585B b c)x  - 405A b c + 585B b )\|b
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   2          2   2         2           3 4+-+
+--R         ((810A b c  - 1170B b c)x  + 810A b c - 1170B b )\|b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                   2          2   2         2           3 4+-+
+--R         ((810A b c  - 1170B b c)x  + 810A b c - 1170B b )\|b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                3 6          3           2  4               2          2   2
+--R           80B c x  + (144A c  - 208B b c )x  + (- 1296A b c  + 1872B b c)x
+--R         + 
+--R                    2           3
+--R           - 1620A b c + 2340B b
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|c \|x
+--R  /
+--R          5 2         4  +-+4+-+
+--R     (360c x  + 360b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1296
+
+--S 1297 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 2        4
+--R         (90c x  + 90b c )
+--R      *
+--R         ROOT
+--R                       4 5 4         3   6 3         2 2 7 2           3 8
+--R                - 6561A b c  + 37908A B b c  - 82134A B b c  + 79092A B b c
+--R              + 
+--R                        4 9
+--R                - 28561B b
+--R           /
+--R                   17
+--R              4096c
+--R        ,
+--R            4
+--R      *
+--R         log
+--R                             2  +-+
+--R              (9A b c - 13B b )\|x
+--R            + 
+--R                  4
+--R                8c
+--R             *
+--R                ROOT
+--R                              4 5 4         3   6 3         2 2 7 2
+--R                       - 6561A b c  + 37908A B b c  - 82134A B b c
+--R                     + 
+--R                               3 8          4 9
+--R                       79092A B b c - 28561B b
+--R                  /
+--R                          17
+--R                     4096c
+--R               ,
+--R                   4
+--R     + 
+--R               5 2        4
+--R         (- 90c x  - 90b c )
+--R      *
+--R         ROOT
+--R                       4 5 4         3   6 3         2 2 7 2           3 8
+--R                - 6561A b c  + 37908A B b c  - 82134A B b c  + 79092A B b c
+--R              + 
+--R                        4 9
+--R                - 28561B b
+--R           /
+--R                   17
+--R              4096c
+--R        ,
+--R            4
+--R      *
+--R         log
+--R                             2  +-+
+--R              (9A b c - 13B b )\|x
+--R            + 
+--R              -
+--R                     4
+--R                   8c
+--R                *
+--R                   ROOT
+--R                                 4 5 4         3   6 3         2 2 7 2
+--R                          - 6561A b c  + 37908A B b c  - 82134A B b c
+--R                        + 
+--R                                  3 8          4 9
+--R                          79092A B b c - 28561B b
+--R                     /
+--R                             17
+--R                        4096c
+--R                  ,
+--R                      4
+--R     + 
+--R                5 2         4
+--R         (- 180c x  - 180b c )
+--R      *
+--R         ROOT
+--R                       4 5 4         3   6 3         2 2 7 2           3 8
+--R                - 6561A b c  + 37908A B b c  - 82134A B b c  + 79092A B b c
+--R              + 
+--R                        4 9
+--R                - 28561B b
+--R           /
+--R                   17
+--R              4096c
+--R        ,
+--R            4
+--R      *
+--R         atan
+--R                  4
+--R                8c
+--R             *
+--R                ROOT
+--R                              4 5 4         3   6 3         2 2 7 2
+--R                       - 6561A b c  + 37908A B b c  - 82134A B b c
+--R                     + 
+--R                               3 8          4 9
+--R                       79092A B b c - 28561B b
+--R                  /
+--R                          17
+--R                     4096c
+--R               ,
+--R                   4
+--R           /
+--R                             2  +-+
+--R              (9A b c - 13B b )\|x
+--R     + 
+--R                3 6         3          2  4              2         2   2
+--R           20B c x  + (36A c  - 52B b c )x  + (- 324A b c  + 468B b c)x
+--R         + 
+--R                   2          3
+--R           - 405A b c + 585B b
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R        5 2        4
+--R     90c x  + 90b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1297
+
+--S 1298 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 9A b c + 13B b )\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           4 +-+
+--R         8c \|2
+--R      *
+--R         ROOT
+--R                       4 5 4         3   6 3         2 2 7 2           3 8
+--R                - 6561A b c  + 37908A B b c  - 82134A B b c  + 79092A B b c
+--R              + 
+--R                        4 9
+--R                - 28561B b
+--R           /
+--R                   17
+--R              4096c
+--R        ,
+--R            4
+--R      *
+--R         4+-+
+--R         \|c
+--R      *
+--R         log
+--R                             2  +-+
+--R              (9A b c - 13B b )\|x
+--R            + 
+--R                  4
+--R                8c
+--R             *
+--R                ROOT
+--R                              4 5 4         3   6 3         2 2 7 2
+--R                       - 6561A b c  + 37908A B b c  - 82134A B b c
+--R                     + 
+--R                               3 8          4 9
+--R                       79092A B b c - 28561B b
+--R                  /
+--R                          17
+--R                     4096c
+--R               ,
+--R                   4
+--R     + 
+--R       -
+--R              4 +-+
+--R            8c \|2
+--R         *
+--R            ROOT
+--R                          4 5 4         3   6 3         2 2 7 2           3 8
+--R                   - 6561A b c  + 37908A B b c  - 82134A B b c  + 79092A B b c
+--R                 + 
+--R                           4 9
+--R                   - 28561B b
+--R              /
+--R                      17
+--R                 4096c
+--R           ,
+--R               4
+--R         *
+--R            4+-+
+--R            \|c
+--R         *
+--R            log
+--R                                2  +-+
+--R                 (9A b c - 13B b )\|x
+--R               + 
+--R                 -
+--R                        4
+--R                      8c
+--R                   *
+--R                      ROOT
+--R                                    4 5 4         3   6 3         2 2 7 2
+--R                             - 6561A b c  + 37908A B b c  - 82134A B b c
+--R                           + 
+--R                                     3 8          4 9
+--R                             79092A B b c - 28561B b
+--R                        /
+--R                                17
+--R                           4096c
+--R                     ,
+--R                         4
+--R     + 
+--R                      2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (9A b c - 13B b )\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R                         2 4+-+     \|2 \|c \|x  + \|b
+--R       (- 18A b c + 26B b )\|b atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R                         2 4+-+     \|2 \|c \|x  - \|b
+--R       (- 18A b c + 26B b )\|b atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R       -
+--R               4 +-+
+--R            16c \|2
+--R         *
+--R            ROOT
+--R                          4 5 4         3   6 3         2 2 7 2           3 8
+--R                   - 6561A b c  + 37908A B b c  - 82134A B b c  + 79092A B b c
+--R                 + 
+--R                           4 9
+--R                   - 28561B b
+--R              /
+--R                      17
+--R                 4096c
+--R           ,
+--R               4
+--R         *
+--R            4+-+
+--R            \|c
+--R         *
+--R            atan
+--R                     4
+--R                   8c
+--R                *
+--R                   ROOT
+--R                                 4 5 4         3   6 3         2 2 7 2
+--R                          - 6561A b c  + 37908A B b c  - 82134A B b c
+--R                        + 
+--R                                  3 8          4 9
+--R                          79092A B b c - 28561B b
+--R                     /
+--R                             17
+--R                        4096c
+--R                  ,
+--R                      4
+--R              /
+--R                                2  +-+
+--R                 (9A b c - 13B b )\|x
+--R  /
+--R       4 +-+4+-+
+--R     8c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1298
+
+--S 1299 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       2        2   3        2         3   4+-+2
+--R               ((9A b c  - 13B b c)x  + (9A b c - 13B b )x)\|b
+--R             + 
+--R                     2         3   +-+
+--R               (18A b c - 26B b )x\|b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                     2        2   2       2         3  +-+4+-+2
+--R           ((- 9A b c  + 13B b c)x  - 9A b c + 13B b )\|b \|b
+--R         + 
+--R                 2 2        3   2       3         4
+--R           (27A b c  - 39B b c)x  + 9A b c - 13B b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                 2        2   2 +-+4+-+2 +-+
+--R       (- 18A b c  + 26B b c)x \|b \|b  \|c
+--R     + 
+--R                 3        2 2  3           2 2        3    4+-+2
+--R       ((- 9A b c  + 13B b c )x  + (- 27A b c  + 39B b c)x)\|b
+--R  /
+--R              5 3        4   +-+ +-+     6 4        5 2     2 4 4+-+2
+--R         ((16c x  + 16b c x)\|b \|c  + 8c x  + 16b c x  + 8b c )\|c
+--R       + 
+--R               6 3        5  4+-+2
+--R         (- 16c x  - 16b c x)\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1299
+
+)clear all
+
+--S 1300 of 3139
+t0:=x^(17/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R             6      4  +-+
+--R         (B x  + A x )\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1300
+
+--S 1301 of 3139
+r0:=-1/6*(11*b*B-7*A*c)*x^(3/2)/c^3+1/14*(11*b*B-7*A*c)*x^(7/2)/(b*c^2)-_
+   1/2*(b*B-A*c)*x^(11/2)/(b*c*(b+c*x^2))-1/4*b^(3/4)*(11*b*B-7*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(15/4)*sqrt(2))+_
+   1/4*b^(3/4)*(11*b*B-7*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (c^(15/4)*sqrt(2))+1/8*b^(3/4)*(11*b*B-7*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(15/4)*sqrt(2))-_
+   1/8*b^(3/4)*(11*b*B-7*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(c^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 2             2                    2 4+-+3
+--R         ((147A c  - 231B b c)x  + 147A b c - 231B b )\|b
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   2             2                    2 4+-+3
+--R         ((- 147A c  + 231B b c)x  - 147A b c + 231B b )\|b
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   2             2                    2 4+-+3
+--R         ((- 294A c  + 462B b c)x  - 294A b c + 462B b )\|b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                   2             2                    2 4+-+3
+--R         ((- 294A c  + 462B b c)x  - 294A b c + 462B b )\|b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R             2 5          2             3                     2    +-+4+-+3 +-+
+--R       (48B c x  + (112A c  - 176B b c)x  + (196A b c - 308B b )x)\|2 \|c  \|x
+--R  /
+--R          4 2         3  +-+4+-+3
+--R     (168c x  + 168b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1301
+
+--S 1302 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 2        3
+--R         (- 42c x  - 42b c )
+--R      *
+--R         ROOT
+--R                       4 3 4         3   4 3         2 2 5 2           3 6
+--R                - 2401A b c  + 15092A B b c  - 35574A B b c  + 37268A B b c
+--R              + 
+--R                        4 7
+--R                - 14641B b
+--R           /
+--R                   15
+--R              4096c
+--R        ,
+--R            4
+--R      *
+--R         log
+--R                   3 2 3        2   3 2          2 4         3 5  +-+
+--R              (343A b c  - 1617A B b c  + 2541A B b c - 1331B b )\|x
+--R            + 
+--R                    11
+--R                512c
+--R             *
+--R                  ROOT
+--R                                4 3 4         3   4 3         2 2 5 2
+--R                         - 2401A b c  + 15092A B b c  - 35574A B b c
+--R                       + 
+--R                                 3 6          4 7
+--R                         37268A B b c - 14641B b
+--R                    /
+--R                            15
+--R                       4096c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R             4 2        3
+--R         (42c x  + 42b c )
+--R      *
+--R         ROOT
+--R                       4 3 4         3   4 3         2 2 5 2           3 6
+--R                - 2401A b c  + 15092A B b c  - 35574A B b c  + 37268A B b c
+--R              + 
+--R                        4 7
+--R                - 14641B b
+--R           /
+--R                   15
+--R              4096c
+--R        ,
+--R            4
+--R      *
+--R         log
+--R                   3 2 3        2   3 2          2 4         3 5  +-+
+--R              (343A b c  - 1617A B b c  + 2541A B b c - 1331B b )\|x
+--R            + 
+--R              -
+--R                       11
+--R                   512c
+--R                *
+--R                     ROOT
+--R                                   4 3 4         3   4 3         2 2 5 2
+--R                            - 2401A b c  + 15092A B b c  - 35574A B b c
+--R                          + 
+--R                                    3 6          4 7
+--R                            37268A B b c - 14641B b
+--R                       /
+--R                               15
+--R                          4096c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R               4 2        3
+--R         (- 84c x  - 84b c )
+--R      *
+--R         ROOT
+--R                       4 3 4         3   4 3         2 2 5 2           3 6
+--R                - 2401A b c  + 15092A B b c  - 35574A B b c  + 37268A B b c
+--R              + 
+--R                        4 7
+--R                - 14641B b
+--R           /
+--R                   15
+--R              4096c
+--R        ,
+--R            4
+--R      *
+--R         atan
+--R                    11
+--R                512c
+--R             *
+--R                  ROOT
+--R                                4 3 4         3   4 3         2 2 5 2
+--R                         - 2401A b c  + 15092A B b c  - 35574A B b c
+--R                       + 
+--R                                 3 6          4 7
+--R                         37268A B b c - 14641B b
+--R                    /
+--R                            15
+--R                       4096c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                   3 2 3        2   3 2          2 4         3 5  +-+
+--R              (343A b c  - 1617A B b c  + 2541A B b c - 1331B b )\|x
+--R     + 
+--R             2 5         2            3                   2    +-+
+--R       (12B c x  + (28A c  - 44B b c)x  + (49A b c - 77B b )x)\|x
+--R  /
+--R        4 2        3
+--R     42c x  + 42b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1302
+
+--S 1303 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 7A c + 11B b)\|b  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R              3 +-+
+--R            8c \|2
+--R         *
+--R            ROOT
+--R                          4 3 4         3   4 3         2 2 5 2           3 6
+--R                   - 2401A b c  + 15092A B b c  - 35574A B b c  + 37268A B b c
+--R                 + 
+--R                           4 7
+--R                   - 14641B b
+--R              /
+--R                      15
+--R                 4096c
+--R           ,
+--R               4
+--R         *
+--R            4+-+3
+--R            \|c
+--R         *
+--R            log
+--R                      3 2 3        2   3 2          2 4         3 5  +-+
+--R                 (343A b c  - 1617A B b c  + 2541A B b c - 1331B b )\|x
+--R               + 
+--R                       11
+--R                   512c
+--R                *
+--R                     ROOT
+--R                                   4 3 4         3   4 3         2 2 5 2
+--R                            - 2401A b c  + 15092A B b c  - 35574A B b c
+--R                          + 
+--R                                    3 6          4 7
+--R                            37268A B b c - 14641B b
+--R                       /
+--R                               15
+--R                          4096c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R           3 +-+
+--R         8c \|2
+--R      *
+--R         ROOT
+--R                       4 3 4         3   4 3         2 2 5 2           3 6
+--R                - 2401A b c  + 15092A B b c  - 35574A B b c  + 37268A B b c
+--R              + 
+--R                        4 7
+--R                - 14641B b
+--R           /
+--R                   15
+--R              4096c
+--R        ,
+--R            4
+--R      *
+--R         4+-+3
+--R         \|c
+--R      *
+--R         log
+--R                   3 2 3        2   3 2          2 4         3 5  +-+
+--R              (343A b c  - 1617A B b c  + 2541A B b c - 1331B b )\|x
+--R            + 
+--R              -
+--R                       11
+--R                   512c
+--R                *
+--R                     ROOT
+--R                                   4 3 4         3   4 3         2 2 5 2
+--R                            - 2401A b c  + 15092A B b c  - 35574A B b c
+--R                          + 
+--R                                    3 6          4 7
+--R                            37268A B b c - 14641B b
+--R                       /
+--R                               15
+--R                          4096c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R                     4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (7A c - 11B b)\|b  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R                      4+-+3     \|2 \|c \|x  + \|b
+--R       (14A c - 22B b)\|b  atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R                      4+-+3     \|2 \|c \|x  - \|b
+--R       (14A c - 22B b)\|b  atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R       -
+--R               3 +-+
+--R            16c \|2
+--R         *
+--R            ROOT
+--R                          4 3 4         3   4 3         2 2 5 2           3 6
+--R                   - 2401A b c  + 15092A B b c  - 35574A B b c  + 37268A B b c
+--R                 + 
+--R                           4 7
+--R                   - 14641B b
+--R              /
+--R                      15
+--R                 4096c
+--R           ,
+--R               4
+--R         *
+--R            4+-+3
+--R            \|c
+--R         *
+--R            atan
+--R                       11
+--R                   512c
+--R                *
+--R                     ROOT
+--R                                   4 3 4         3   4 3         2 2 5 2
+--R                            - 2401A b c  + 15092A B b c  - 35574A B b c
+--R                          + 
+--R                                    3 6          4 7
+--R                            37268A B b c - 14641B b
+--R                       /
+--R                               15
+--R                          4096c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R              /
+--R                      3 2 3        2   3 2          2 4         3 5  +-+
+--R                 (343A b c  - 1617A B b c  + 2541A B b c - 1331B b )\|x
+--R  /
+--R       3 +-+4+-+3
+--R     8c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1303
+
+--S 1304 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                             2  2 +-+ +-+            2        2   3
+--R           (- 14A b c + 22B b )x \|b \|c  + (- 7A b c  + 11B b c)x
+--R         + 
+--R                   2         3
+--R           (- 21A b c + 33B b )x
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                           2   +-+4+-+2          2        2   3
+--R           (14A b c - 22B b )x\|b \|b   + (7A b c  - 11B b c)x
+--R         + 
+--R                2         3
+--R           (7A b c - 11B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                2        2   2       2         3 4+-+2
+--R       ((21A b c  - 33B b c)x  + 7A b c - 11B b )\|b
+--R     + 
+--R                 2        2   2       2         3  +-+
+--R       ((- 7A b c  + 11B b c)x  - 7A b c + 11B b )\|b
+--R  /
+--R              4 3        3   +-+ +-+     5 4        4 2     2 3 4+-+2
+--R         ((16c x  + 16b c x)\|b \|c  + 8c x  + 16b c x  + 8b c )\|c
+--R       + 
+--R               5 3        4  4+-+2
+--R         (- 16c x  - 16b c x)\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1304
+
+)clear all
+
+--S 1305 of 3139
+t0:=x^(15/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R             5      3  +-+
+--R         (B x  + A x )\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1305
+
+--S 1306 of 3139
+r0:=1/10*(9*b*B-5*A*c)*x^(5/2)/(b*c^2)-1/2*(b*B-A*c)*x^(9/2)/(b*c*_
+   (b+c*x^2))-1/4*b^(1/4)*(9*b*B-5*A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(c^(13/4)*sqrt(2))+1/4*b^(1/4)*(9*b*B-5*A*c)*_
+   atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(13/4)*sqrt(2))-_
+   1/8*b^(1/4)*(9*b*B-5*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(c^(13/4)*sqrt(2))+1/8*b^(1/4)*(9*b*B-5*A*c)*_
+   log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(13/4)*_
+   sqrt(2))-1/2*(9*b*B-5*A*c)*sqrt(x)/c^3
+--R 
+--R
+--R   (2)
+--R                  2            2                  2 4+-+
+--R         ((- 25A c  + 45B b c)x  - 25A b c + 45B b )\|b
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                2            2                  2 4+-+
+--R         ((25A c  - 45B b c)x  + 25A b c - 45B b )\|b
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                            +-+4+-+ +-+   4+-+
+--R                2            2                  2 4+-+     \|2 \|c \|x  + \|b
+--R       ((- 50A c  + 90B b c)x  - 50A b c + 90B b )\|b atan(-------------------)
+--R                                                                   4+-+
+--R                                                                   \|b
+--R     + 
+--R                                                            +-+4+-+ +-+   4+-+
+--R                2            2                  2 4+-+     \|2 \|c \|x  - \|b
+--R       ((- 50A c  + 90B b c)x  - 50A b c + 90B b )\|b atan(-------------------)
+--R                                                                   4+-+
+--R                                                                   \|b
+--R     + 
+--R             2 4         2             2                    2  +-+4+-+ +-+
+--R       (16B c x  + (80A c  - 144B b c)x  + 100A b c - 180B b )\|2 \|c \|x
+--R  /
+--R         4 2        3  +-+4+-+
+--R     (40c x  + 40b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1306
+
+--S 1307 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 2        3
+--R         (- 10c x  - 10b c )
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |      4   4        3   2 3         2 2 3 2           3 4         4 5
+--R          |- 625A b c  + 4500A B b c  - 12150A B b c  + 14580A B b c - 6561B b
+--R          |--------------------------------------------------------------------
+--R         4|                                    13
+--R         \|                               4096c
+--R      *
+--R         log
+--R                            +-+
+--R              (5A c - 9B b)\|x
+--R            + 
+--R                  3
+--R                8c
+--R             *
+--R                ROOT
+--R                             4   4        3   2 3         2 2 3 2           3 4
+--R                       - 625A b c  + 4500A B b c  - 12150A B b c  + 14580A B b c
+--R                     + 
+--R                              4 5
+--R                       - 6561B b
+--R                  /
+--R                          13
+--R                     4096c
+--R               ,
+--R                   4
+--R     + 
+--R             4 2        3
+--R         (10c x  + 10b c )
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |      4   4        3   2 3         2 2 3 2           3 4         4 5
+--R          |- 625A b c  + 4500A B b c  - 12150A B b c  + 14580A B b c - 6561B b
+--R          |--------------------------------------------------------------------
+--R         4|                                    13
+--R         \|                               4096c
+--R      *
+--R         log
+--R                            +-+
+--R              (5A c - 9B b)\|x
+--R            + 
+--R              -
+--R                     3
+--R                   8c
+--R                *
+--R                   ROOT
+--R                                4   4        3   2 3         2 2 3 2
+--R                          - 625A b c  + 4500A B b c  - 12150A B b c
+--R                        + 
+--R                                  3 4         4 5
+--R                          14580A B b c - 6561B b
+--R                     /
+--R                             13
+--R                        4096c
+--R                  ,
+--R                      4
+--R     + 
+--R             4 2        3
+--R         (20c x  + 20b c )
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |      4   4        3   2 3         2 2 3 2           3 4         4 5
+--R          |- 625A b c  + 4500A B b c  - 12150A B b c  + 14580A B b c - 6561B b
+--R          |--------------------------------------------------------------------
+--R         4|                                    13
+--R         \|                               4096c
+--R      *
+--R         atan
+--R                  3
+--R                8c
+--R             *
+--R                ROOT
+--R                             4   4        3   2 3         2 2 3 2           3 4
+--R                       - 625A b c  + 4500A B b c  - 12150A B b c  + 14580A B b c
+--R                     + 
+--R                              4 5
+--R                       - 6561B b
+--R                  /
+--R                          13
+--R                     4096c
+--R               ,
+--R                   4
+--R           /
+--R                            +-+
+--R              (5A c - 9B b)\|x
+--R     + 
+--R            2 4         2            2                  2  +-+
+--R       (4B c x  + (20A c  - 36B b c)x  + 25A b c - 45B b )\|x
+--R  /
+--R        4 2        3
+--R     10c x  + 10b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1307
+
+--S 1308 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5A c - 9B b)\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R              3 +-+
+--R            8c \|2
+--R         *
+--R            ROOT
+--R                         4   4        3   2 3         2 2 3 2           3 4
+--R                   - 625A b c  + 4500A B b c  - 12150A B b c  + 14580A B b c
+--R                 + 
+--R                          4 5
+--R                   - 6561B b
+--R              /
+--R                      13
+--R                 4096c
+--R           ,
+--R               4
+--R         *
+--R            4+-+
+--R            \|c
+--R         *
+--R            log
+--R                               +-+
+--R                 (5A c - 9B b)\|x
+--R               + 
+--R                     3
+--R                   8c
+--R                *
+--R                   ROOT
+--R                                4   4        3   2 3         2 2 3 2
+--R                          - 625A b c  + 4500A B b c  - 12150A B b c
+--R                        + 
+--R                                  3 4         4 5
+--R                          14580A B b c - 6561B b
+--R                     /
+--R                             13
+--R                        4096c
+--R                  ,
+--R                      4
+--R     + 
+--R           3 +-+
+--R         8c \|2
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |      4   4        3   2 3         2 2 3 2           3 4         4 5
+--R          |- 625A b c  + 4500A B b c  - 12150A B b c  + 14580A B b c - 6561B b
+--R          |--------------------------------------------------------------------
+--R         4|                                    13
+--R         \|                               4096c
+--R      *
+--R         4+-+
+--R         \|c
+--R      *
+--R         log
+--R                            +-+
+--R              (5A c - 9B b)\|x
+--R            + 
+--R              -
+--R                     3
+--R                   8c
+--R                *
+--R                   ROOT
+--R                                4   4        3   2 3         2 2 3 2
+--R                          - 625A b c  + 4500A B b c  - 12150A B b c
+--R                        + 
+--R                                  3 4         4 5
+--R                          14580A B b c - 6561B b
+--R                     /
+--R                             13
+--R                        4096c
+--R                  ,
+--R                      4
+--R     + 
+--R                      4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5A c + 9B b)\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                +-+4+-+ +-+   4+-+
+--R                      4+-+     \|2 \|c \|x  + \|b
+--R       (10A c - 18B b)\|b atan(-------------------)
+--R                                       4+-+
+--R                                       \|b
+--R     + 
+--R                                +-+4+-+ +-+   4+-+
+--R                      4+-+     \|2 \|c \|x  - \|b
+--R       (10A c - 18B b)\|b atan(-------------------)
+--R                                       4+-+
+--R                                       \|b
+--R     + 
+--R            3 +-+
+--R         16c \|2
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |      4   4        3   2 3         2 2 3 2           3 4         4 5
+--R          |- 625A b c  + 4500A B b c  - 12150A B b c  + 14580A B b c - 6561B b
+--R          |--------------------------------------------------------------------
+--R         4|                                    13
+--R         \|                               4096c
+--R      *
+--R         4+-+
+--R         \|c
+--R      *
+--R         atan
+--R                  3
+--R                8c
+--R             *
+--R                ROOT
+--R                             4   4        3   2 3         2 2 3 2           3 4
+--R                       - 625A b c  + 4500A B b c  - 12150A B b c  + 14580A B b c
+--R                     + 
+--R                              4 5
+--R                       - 6561B b
+--R                  /
+--R                          13
+--R                     4096c
+--R               ,
+--R                   4
+--R           /
+--R                            +-+
+--R              (5A c - 9B b)\|x
+--R  /
+--R       3 +-+4+-+
+--R     8c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1308
+
+--S 1309 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       2           3                   2   4+-+2
+--R               ((- 5A c  + 9B b c)x  + (- 5A b c + 9B b )x)\|b
+--R             + 
+--R                                 2   +-+
+--R               (- 10A b c + 18B b )x\|b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                 2           2                2  +-+4+-+2
+--R           ((5A c  - 9B b c)x  + 5A b c - 9B b )\|b \|b
+--R         + 
+--R                     2        2   2       2        3
+--R           (- 15A b c  + 27B b c)x  - 5A b c + 9B b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R             2            2 +-+4+-+2 +-+
+--R       (10A c  - 18B b c)x \|b \|b  \|c
+--R     + 
+--R             3         2  3           2        2    4+-+2
+--R       ((5A c  - 9B b c )x  + (15A b c  - 27B b c)x)\|b
+--R  /
+--R              4 3        3   +-+ +-+     5 4        4 2     2 3 4+-+2
+--R         ((16c x  + 16b c x)\|b \|c  + 8c x  + 16b c x  + 8b c )\|c
+--R       + 
+--R               5 3        4  4+-+2
+--R         (- 16c x  - 16b c x)\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1309
+
+)clear all
+
+--S 1310 of 3139
+t0:=x^(13/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R             4      2  +-+
+--R         (B x  + A x )\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1310
+
+--S 1311 of 3139
+r0:=1/6*(7*b*B-3*A*c)*x^(3/2)/(b*c^2)-1/2*(b*B-A*c)*x^(7/2)/(b*c*_
+   (b+c*x^2))+1/4*(7*b*B-3*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(1/4)*c^(11/4)*sqrt(2))-1/4*(7*b*B-3*A*c)*atan(1+_
+   c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(1/4)*c^(11/4)*sqrt(2))-_
+   1/8*(7*b*B-3*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(1/4)*c^(11/4)*sqrt(2))+1/8*(7*b*B-3*A*c)*log(sqrt(b)+_
+   x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*c^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 2            2                 2
+--R         ((- 9A c  + 21B b c)x  - 9A b c + 21B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               2            2                 2
+--R         ((9A c  - 21B b c)x  + 9A b c - 21B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R              2            2                  2      \|2 \|c \|x  + \|b
+--R       ((18A c  - 42B b c)x  + 18A b c - 42B b )atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|b
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R              2            2                  2      \|2 \|c \|x  - \|b
+--R       ((18A c  - 42B b c)x  + 18A b c - 42B b )atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|b
+--R     + 
+--R               3                       +-+4+-+4+-+3 +-+
+--R       (16B c x  + (- 12A c + 28B b)x)\|2 \|b \|c  \|x
+--R  /
+--R         3 2        2  +-+4+-+4+-+3
+--R     (24c x  + 24b c )\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1311
+
+--S 1312 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 2       2
+--R         (6c x  + 6b c )
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |     4 4       3     3        2 2 2 2          3 3         4 4
+--R          |- 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c - 2401B b
+--R          |--------------------------------------------------------------
+--R         4|                                  11
+--R         \|                           4096b c
+--R      *
+--R         log
+--R                  3 3       2     2         2 2        3 3  +-+
+--R              (27A c  - 189A B b c  + 441A B b c - 343B b )\|x
+--R            + 
+--R                      8
+--R                512b c
+--R             *
+--R               +--------------------------------------------------------------+3
+--R               |     4 4       3     3        2 2 2 2          3 3         4 4
+--R               |- 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c - 2401B b
+--R               |--------------------------------------------------------------
+--R              4|                                  11
+--R              \|                           4096b c
+--R     + 
+--R              3 2       2
+--R         (- 6c x  - 6b c )
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |     4 4       3     3        2 2 2 2          3 3         4 4
+--R          |- 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c - 2401B b
+--R          |--------------------------------------------------------------
+--R         4|                                  11
+--R         \|                           4096b c
+--R      *
+--R         log
+--R                  3 3       2     2         2 2        3 3  +-+
+--R              (27A c  - 189A B b c  + 441A B b c - 343B b )\|x
+--R            + 
+--R              -
+--R                         8
+--R                   512b c
+--R                *
+--R                     ROOT
+--R                                 4 4       3     3        2 2 2 2          3 3
+--R                            - 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c
+--R                          + 
+--R                                   4 4
+--R                            - 2401B b
+--R                       /
+--R                                 11
+--R                          4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R             3 2        2
+--R         (12c x  + 12b c )
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |     4 4       3     3        2 2 2 2          3 3         4 4
+--R          |- 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c - 2401B b
+--R          |--------------------------------------------------------------
+--R         4|                                  11
+--R         \|                           4096b c
+--R      *
+--R         atan
+--R                      8
+--R                512b c
+--R             *
+--R               +--------------------------------------------------------------+3
+--R               |     4 4       3     3        2 2 2 2          3 3         4 4
+--R               |- 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c - 2401B b
+--R               |--------------------------------------------------------------
+--R              4|                                  11
+--R              \|                           4096b c
+--R           /
+--R                  3 3       2     2         2 2        3 3  +-+
+--R              (27A c  - 189A B b c  + 441A B b c - 343B b )\|x
+--R     + 
+--R              3                     +-+
+--R       (4B c x  + (- 3A c + 7B b)x)\|x
+--R  /
+--R       3 2       2
+--R     6c x  + 6b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1312
+
+--S 1313 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3A c - 7B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           2 +-+
+--R         8c \|2
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |     4 4       3     3        2 2 2 2          3 3         4 4
+--R          |- 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c - 2401B b  4+-+
+--R          |-------------------------------------------------------------- \|b
+--R         4|                                  11
+--R         \|                           4096b c
+--R      *
+--R         4+-+3
+--R         \|c
+--R      *
+--R         log
+--R                  3 3       2     2         2 2        3 3  +-+
+--R              (27A c  - 189A B b c  + 441A B b c - 343B b )\|x
+--R            + 
+--R                      8
+--R                512b c
+--R             *
+--R               +--------------------------------------------------------------+3
+--R               |     4 4       3     3        2 2 2 2          3 3         4 4
+--R               |- 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c - 2401B b
+--R               |--------------------------------------------------------------
+--R              4|                                  11
+--R              \|                           4096b c
+--R     + 
+--R       -
+--R              2 +-+
+--R            8c \|2
+--R         *
+--R             +--------------------------------------------------------------+
+--R             |     4 4       3     3        2 2 2 2          3 3         4 4
+--R             |- 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c - 2401B b
+--R             |--------------------------------------------------------------
+--R            4|                                  11
+--R            \|                           4096b c
+--R         *
+--R            4+-+4+-+3
+--R            \|b \|c
+--R         *
+--R            log
+--R                     3 3       2     2         2 2        3 3  +-+
+--R                 (27A c  - 189A B b c  + 441A B b c - 343B b )\|x
+--R               + 
+--R                 -
+--R                            8
+--R                      512b c
+--R                   *
+--R                        ROOT
+--R                                    4 4       3     3        2 2 2 2
+--R                               - 81A c  + 756A B b c  - 2646A B b c
+--R                             + 
+--R                                      3 3         4 4
+--R                               4116A B b c - 2401B b
+--R                          /
+--R                                    11
+--R                             4096b c
+--R                       ,
+--R                           4
+--R                     **
+--R                        3
+--R     + 
+--R                             +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3A c + 7B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  + \|b
+--R       (- 6A c + 14B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  - \|b
+--R       (- 6A c + 14B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R            2 +-+
+--R         16c \|2
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |     4 4       3     3        2 2 2 2          3 3         4 4
+--R          |- 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c - 2401B b  4+-+
+--R          |-------------------------------------------------------------- \|b
+--R         4|                                  11
+--R         \|                           4096b c
+--R      *
+--R         4+-+3
+--R         \|c
+--R      *
+--R         atan
+--R                      8
+--R                512b c
+--R             *
+--R               +--------------------------------------------------------------+3
+--R               |     4 4       3     3        2 2 2 2          3 3         4 4
+--R               |- 81A c  + 756A B b c  - 2646A B b c  + 4116A B b c - 2401B b
+--R               |--------------------------------------------------------------
+--R              4|                                  11
+--R              \|                           4096b c
+--R           /
+--R                  3 3       2     2         2 2        3 3  +-+
+--R              (27A c  - 189A B b c  + 441A B b c - 343B b )\|x
+--R  /
+--R       2 +-+4+-+4+-+3
+--R     8c \|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1313
+
+--S 1314 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                          2 +-+4+-+2 +-+
+--R           (6A c - 14B b)x \|b \|b  \|c
+--R         + 
+--R                 2           3                  2   4+-+2
+--R           ((3A c  - 7B b c)x  + (9A b c - 21B b )x)\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                   2           3                   2   4+-+2
+--R           ((- 3A c  + 7B b c)x  + (- 3A b c + 7B b )x)\|b
+--R         + 
+--R                            2   +-+
+--R           (- 6A b c + 14B b )x\|b
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R             2           2                2  +-+4+-+2            2        2   2
+--R       ((3A c  - 7B b c)x  + 3A b c - 7B b )\|b \|b   + (- 9A b c  + 21B b c)x
+--R     + 
+--R             2        3
+--R       - 3A b c + 7B b
+--R  /
+--R                3 3        2   +-+4+-+2 +-+      4 4        3 2     2 2 4+-+2
+--R           ((16c x  + 16b c x)\|b \|b  \|c  + (8c x  + 16b c x  + 8b c )\|b  )
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R                4 3      2 3
+--R         - 16b c x  - 16b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1314
+
+)clear all
+
+--S 1315 of 3139
+t0:=x^(11/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R              3        +-+
+--R          (B x  + A x)\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1315
+
+--S 1316 of 3139
+r0:=-1/2*(b*B-A*c)*x^(5/2)/(b*c*(b+c*x^2))+1/4*(5*b*B-A*c)*atan(1-c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(9/4)*sqrt(2))-1/4*(5*b*B-A*c)*_
+   atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(9/4)*sqrt(2))+_
+   1/8*(5*b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(3/4)*c^(9/4)*sqrt(2))-1/8*(5*b*B-A*c)*log(sqrt(b)+_
+   x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*c^(9/4)*sqrt(2))+_
+   1/2*(5*b*B-A*c)*sqrt(x)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R            2           2               2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       ((A c  - 5B b c)x  + A b c - 5B b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                2           2               2
+--R         ((- A c  + 5B b c)x  - A b c + 5B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R             2            2                 2      \|2 \|c \|x  + \|b
+--R       ((2A c  - 10B b c)x  + 2A b c - 10B b )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|b
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R             2            2                 2      \|2 \|c \|x  - \|b
+--R       ((2A c  - 10B b c)x  + 2A b c - 10B b )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|b
+--R     + 
+--R               2                 +-+4+-+3 4+-+ +-+
+--R       (16B c x  - 4A c + 20B b)\|2 \|b   \|c \|x
+--R  /
+--R        3 2       2  +-+4+-+3 4+-+
+--R     (8c x  + 8b c )\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1316
+
+--S 1317 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 2       2
+--R         (2c x  + 2b c )
+--R      *
+--R          +--------------------------------------------------------+
+--R          |   4 4      3     3       2 2 2 2         3 3        4 4
+--R          |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R          |--------------------------------------------------------
+--R         4|                             3 9
+--R         \|                        4096b c
+--R      *
+--R         log
+--R                           +-+
+--R              (A c - 5B b)\|x
+--R            + 
+--R                     +--------------------------------------------------------+
+--R                     |   4 4      3     3       2 2 2 2         3 3        4 4
+--R                  2  |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R              8b c   |--------------------------------------------------------
+--R                    4|                             3 9
+--R                    \|                        4096b c
+--R     + 
+--R              3 2       2
+--R         (- 2c x  - 2b c )
+--R      *
+--R          +--------------------------------------------------------+
+--R          |   4 4      3     3       2 2 2 2         3 3        4 4
+--R          |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R          |--------------------------------------------------------
+--R         4|                             3 9
+--R         \|                        4096b c
+--R      *
+--R         log
+--R                           +-+
+--R              (A c - 5B b)\|x
+--R            + 
+--R                     +--------------------------------------------------------+
+--R                     |   4 4      3     3       2 2 2 2         3 3        4 4
+--R                  2  |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R            - 8b c   |--------------------------------------------------------
+--R                    4|                             3 9
+--R                    \|                        4096b c
+--R     + 
+--R              3 2       2
+--R         (- 4c x  - 4b c )
+--R      *
+--R          +--------------------------------------------------------+
+--R          |   4 4      3     3       2 2 2 2         3 3        4 4
+--R          |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R          |--------------------------------------------------------
+--R         4|                             3 9
+--R         \|                        4096b c
+--R      *
+--R                     +--------------------------------------------------------+
+--R                     |   4 4      3     3       2 2 2 2         3 3        4 4
+--R                  2  |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R              8b c   |--------------------------------------------------------
+--R                    4|                             3 9
+--R                    \|                        4096b c
+--R         atan(----------------------------------------------------------------)
+--R                                                   +-+
+--R                                      (A c - 5B b)\|x
+--R     + 
+--R              2               +-+
+--R       (4B c x  - A c + 5B b)\|x
+--R  /
+--R       3 2       2
+--R     2c x  + 2b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1317
+
+--S 1318 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + 5B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  +--------------------------------------------------------+
+--R                  |   4 4      3     3       2 2 2 2         3 3        4 4
+--R           2 +-+  |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b  4+-+3
+--R         8c \|2   |-------------------------------------------------------- \|b
+--R                 4|                             3 9
+--R                 \|                        4096b c
+--R      *
+--R         4+-+
+--R         \|c
+--R      *
+--R         log
+--R                           +-+
+--R              (A c - 5B b)\|x
+--R            + 
+--R                     +--------------------------------------------------------+
+--R                     |   4 4      3     3       2 2 2 2         3 3        4 4
+--R                  2  |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R              8b c   |--------------------------------------------------------
+--R                    4|                             3 9
+--R                    \|                        4096b c
+--R     + 
+--R       -
+--R                     +--------------------------------------------------------+
+--R                     |   4 4      3     3       2 2 2 2         3 3        4 4
+--R              2 +-+  |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R            8c \|2   |--------------------------------------------------------
+--R                    4|                             3 9
+--R                    \|                        4096b c
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R            log
+--R                              +-+
+--R                 (A c - 5B b)\|x
+--R               + 
+--R                 -
+--R                          2
+--R                      8b c
+--R                   *
+--R                     +--------------------------------------------------------+
+--R                     |   4 4      3     3       2 2 2 2         3 3        4 4
+--R                     |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R                     |--------------------------------------------------------
+--R                    4|                             3 9
+--R                    \|                        4096b c
+--R     + 
+--R                          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - 5B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  + \|b
+--R       (- 2A c + 10B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  - \|b
+--R       (- 2A c + 10B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R       -
+--R                      +--------------------------------------------------------+
+--R                      |   4 4      3     3       2 2 2 2         3 3        4 4
+--R               2 +-+  |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R            16c \|2   |--------------------------------------------------------
+--R                     4|                             3 9
+--R                     \|                        4096b c
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R                      +--------------------------------------------------------+
+--R                      |   4 4      3     3       2 2 2 2         3 3        4 4
+--R                   2  |- A c  + 20A B b c  - 150A B b c  + 500A B b c - 625B b
+--R               8b c   |--------------------------------------------------------
+--R                     4|                             3 9
+--R                     \|                        4096b c
+--R          atan(----------------------------------------------------------------)
+--R                                                    +-+
+--R                                       (A c - 5B b)\|x
+--R  /
+--R       2 +-+4+-+3 4+-+
+--R     8c \|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1318
+
+--S 1319 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                            +-+4+-+2       2           3                2    +-+
+--R           ((2A c - 10B b)x\|b \|b   + (A c  - 5B b c)x  + (A b c - 5B b )x)\|c
+--R         + 
+--R                 2            2               2 4+-+2
+--R           ((3A c  - 15B b c)x  + A b c - 5B b )\|b
+--R         + 
+--R                  2           2               2  +-+
+--R           ((- A c  + 5B b c)x  - A b c + 5B b )\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R              2            2 +-+ +-+         3         2  3
+--R       (- 2A c  + 10B b c)x \|b \|c  + (- A c  + 5B b c )x
+--R     + 
+--R                2        2
+--R       (- 3A b c  + 15B b c)x
+--R  /
+--R                3 3        2   +-+4+-+2 +-+      4 4        3 2     2 2 4+-+2
+--R           ((16c x  + 16b c x)\|b \|b  \|c  + (8c x  + 16b c x  + 8b c )\|b  )
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R                4 3      2 3
+--R         - 16b c x  - 16b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1319
+
+)clear all
+
+--S 1320 of 3139
+t0:=x^(9/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               2      +-+
+--R           (B x  + A)\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1320
+
+--S 1321 of 3139
+r0:=-1/2*(b*B-A*c)*x^(3/2)/(b*c*(b+c*x^2))-1/4*(3*b*B+A*c)*atan(1-c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*c^(7/4)*sqrt(2))+1/4*(3*b*B+A*c)*_
+   atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*c^(7/4)*sqrt(2))+_
+   1/8*(3*b*B+A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(5/4)*c^(7/4)*sqrt(2))-1/8*(3*b*B+A*c)*log(sqrt(b)+_
+   x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*c^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              2           2               2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       ((- A c  - 3B b c)x  - A b c - 3B b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            2           2               2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       ((A c  + 3B b c)x  + A b c + 3B b )log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2           2                2      \|2 \|c \|x  + \|b
+--R       ((2A c  + 6B b c)x  + 2A b c + 6B b )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|b
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2           2                2      \|2 \|c \|x  - \|b
+--R       ((2A c  + 6B b c)x  + 2A b c + 6B b )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|b
+--R     + 
+--R                      +-+4+-+4+-+3 +-+
+--R       (4A c - 4B b)x\|2 \|b \|c  \|x
+--R  /
+--R          2 2     2   +-+4+-+4+-+3
+--R     (8b c x  + 8b c)\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1321
+
+--S 1322 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 2     2
+--R         (2b c x  + 2b c)
+--R      *
+--R          +------------------------------------------------------+
+--R          |   4 4      3     3      2 2 2 2         3 3       4 4
+--R          |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b
+--R          |------------------------------------------------------
+--R         4|                            5 7
+--R         \|                       4096b c
+--R      *
+--R         log
+--R                3 3     2     2        2 2       3 3  +-+
+--R              (A c  + 9A B b c  + 27A B b c + 27B b )\|x
+--R            + 
+--R                       +------------------------------------------------------+3
+--R                       |   4 4      3     3      2 2 2 2         3 3       4 4
+--R                  4 5  |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b
+--R              512b c   |------------------------------------------------------
+--R                      4|                            5 7
+--R                      \|                       4096b c
+--R     + 
+--R                2 2     2
+--R         (- 2b c x  - 2b c)
+--R      *
+--R          +------------------------------------------------------+
+--R          |   4 4      3     3      2 2 2 2         3 3       4 4
+--R          |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b
+--R          |------------------------------------------------------
+--R         4|                            5 7
+--R         \|                       4096b c
+--R      *
+--R         log
+--R                3 3     2     2        2 2       3 3  +-+
+--R              (A c  + 9A B b c  + 27A B b c + 27B b )\|x
+--R            + 
+--R                       +------------------------------------------------------+3
+--R                       |   4 4      3     3      2 2 2 2         3 3       4 4
+--R                  4 5  |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b
+--R            - 512b c   |------------------------------------------------------
+--R                      4|                            5 7
+--R                      \|                       4096b c
+--R     + 
+--R              2 2     2
+--R         (4b c x  + 4b c)
+--R      *
+--R          +------------------------------------------------------+
+--R          |   4 4      3     3      2 2 2 2         3 3       4 4
+--R          |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b
+--R          |------------------------------------------------------
+--R         4|                            5 7
+--R         \|                       4096b c
+--R      *
+--R                     +------------------------------------------------------+3
+--R                     |   4 4      3     3      2 2 2 2         3 3       4 4
+--R                4 5  |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b
+--R            512b c   |------------------------------------------------------
+--R                    4|                            5 7
+--R                    \|                       4096b c
+--R       atan(-----------------------------------------------------------------)
+--R                         3 3     2     2        2 2       3 3  +-+
+--R                       (A c  + 9A B b c  + 27A B b c + 27B b )\|x
+--R     + 
+--R                    +-+
+--R       (A c - B b)x\|x
+--R  /
+--R         2 2     2
+--R     2b c x  + 2b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1322
+
+--S 1323 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c + 3B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   +------------------------------------------------------+
+--R                   |   4 4      3     3      2 2 2 2         3 3       4 4
+--R              +-+  |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b  4+-+
+--R         8b c\|2   |------------------------------------------------------ \|b
+--R                  4|                            5 7
+--R                  \|                       4096b c
+--R      *
+--R         4+-+3
+--R         \|c
+--R      *
+--R         log
+--R                3 3     2     2        2 2       3 3  +-+
+--R              (A c  + 9A B b c  + 27A B b c + 27B b )\|x
+--R            + 
+--R                       +------------------------------------------------------+3
+--R                       |   4 4      3     3      2 2 2 2         3 3       4 4
+--R                  4 5  |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b
+--R              512b c   |------------------------------------------------------
+--R                      4|                            5 7
+--R                      \|                       4096b c
+--R     + 
+--R       -
+--R                      +------------------------------------------------------+
+--R                      |   4 4      3     3      2 2 2 2         3 3       4 4
+--R                 +-+  |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b
+--R            8b c\|2   |------------------------------------------------------
+--R                     4|                            5 7
+--R                     \|                       4096b c
+--R         *
+--R            4+-+4+-+3
+--R            \|b \|c
+--R         *
+--R            log
+--R                   3 3     2     2        2 2       3 3  +-+
+--R                 (A c  + 9A B b c  + 27A B b c + 27B b )\|x
+--R               + 
+--R                 -
+--R                          4 5
+--R                      512b c
+--R                   *
+--R                     +------------------------------------------------------+3
+--R                     |   4 4      3     3      2 2 2 2         3 3       4 4
+--R                     |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b
+--R                     |------------------------------------------------------
+--R                    4|                            5 7
+--R                    \|                       4096b c
+--R     + 
+--R                            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c - 3B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R                           \|2 \|c \|x  + \|b
+--R       (- 2A c - 6B b)atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R                           \|2 \|c \|x  - \|b
+--R       (- 2A c - 6B b)atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R                    +------------------------------------------------------+
+--R                    |   4 4      3     3      2 2 2 2         3 3       4 4
+--R               +-+  |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b  4+-+
+--R         16b c\|2   |------------------------------------------------------ \|b
+--R                   4|                            5 7
+--R                   \|                       4096b c
+--R      *
+--R         4+-+3
+--R         \|c
+--R      *
+--R                     +------------------------------------------------------+3
+--R                     |   4 4      3     3      2 2 2 2         3 3       4 4
+--R                4 5  |- A c  - 12A B b c  - 54A B b c  - 108A B b c - 81B b
+--R            512b c   |------------------------------------------------------
+--R                    4|                            5 7
+--R                    \|                       4096b c
+--R       atan(-----------------------------------------------------------------)
+--R                         3 3     2     2        2 2       3 3  +-+
+--R                       (A c  + 9A B b c  + 27A B b c + 27B b )\|x
+--R  /
+--R          +-+4+-+4+-+3
+--R     8b c\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1323
+
+--S 1324 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                         2 +-+4+-+2 +-+
+--R           (2A c + 6B b)x \|b \|b  \|c
+--R         + 
+--R                2           3                 2   4+-+2
+--R           ((A c  + 3B b c)x  + (3A b c + 9B b )x)\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                  2           3                  2   4+-+2
+--R           ((- A c  - 3B b c)x  + (- A b c - 3B b )x)\|b
+--R         + 
+--R                           2   +-+
+--R           (- 2A b c - 6B b )x\|b
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R            2           2               2  +-+4+-+2            2       2   2
+--R       ((A c  + 3B b c)x  + A b c + 3B b )\|b \|b   + (- 3A b c  - 9B b c)x
+--R     + 
+--R            2        3
+--R       - A b c - 3B b
+--R  /
+--R                     2 3      2     +-+4+-+2 +-+
+--R               (16b c x  + 16b c x)\|b \|b  \|c
+--R             + 
+--R                    3 4      2 2 2     3  4+-+2
+--R               (8b c x  + 16b c x  + 8b c)\|b
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R              2 3 3      3 2
+--R         - 16b c x  - 16b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1324
+
+)clear all
+
+--S 1325 of 3139
+t0:=x^(7/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               2      +-+
+--R           (B x  + A)\|x
+--R   (1)  --------------------
+--R         2 5         3    2
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1325
+
+--S 1326 of 3139
+r0:=-1/4*(b*B+3*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(7/4)*_
+   c^(5/4)*sqrt(2))+1/4*(b*B+3*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(7/4)*c^(5/4)*sqrt(2))-1/8*(b*B+3*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*c^(5/4)*sqrt(2))+_
+   1/8*(b*B+3*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(7/4)*c^(5/4)*sqrt(2))-1/2*(b*B-A*c)*sqrt(x)/(b*c*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R             2          2               2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       ((3A c  + B b c)x  + 3A b c + B b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 2          2               2
+--R         ((- 3A c  - B b c)x  - 3A b c - B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2           2                2      \|2 \|c \|x  + \|b
+--R       ((6A c  + 2B b c)x  + 6A b c + 2B b )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|b
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2           2                2      \|2 \|c \|x  - \|b
+--R       ((6A c  + 2B b c)x  + 6A b c + 2B b )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|b
+--R     + 
+--R                     +-+4+-+3 4+-+ +-+
+--R       (4A c - 4B b)\|2 \|b   \|c \|x
+--R  /
+--R          2 2     2   +-+4+-+3 4+-+
+--R     (8b c x  + 8b c)\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1326
+
+--S 1327 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 2     2
+--R         (2b c x  + 2b c)
+--R      *
+--R          +------------------------------------------------------+
+--R          |     4 4       3     3      2 2 2 2        3 3     4 4
+--R          |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R          |------------------------------------------------------
+--R         4|                            7 5
+--R         \|                       4096b c
+--R      *
+--R         log
+--R                           +-+
+--R              (3A c + B b)\|x
+--R            + 
+--R                    +------------------------------------------------------+
+--R                    |     4 4       3     3      2 2 2 2        3 3     4 4
+--R                2   |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R              8b c  |------------------------------------------------------
+--R                   4|                            7 5
+--R                   \|                       4096b c
+--R     + 
+--R                2 2     2
+--R         (- 2b c x  - 2b c)
+--R      *
+--R          +------------------------------------------------------+
+--R          |     4 4       3     3      2 2 2 2        3 3     4 4
+--R          |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R          |------------------------------------------------------
+--R         4|                            7 5
+--R         \|                       4096b c
+--R      *
+--R         log
+--R                           +-+
+--R              (3A c + B b)\|x
+--R            + 
+--R                      +------------------------------------------------------+
+--R                      |     4 4       3     3      2 2 2 2        3 3     4 4
+--R                  2   |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R              - 8b c  |------------------------------------------------------
+--R                     4|                            7 5
+--R                     \|                       4096b c
+--R     + 
+--R                2 2     2
+--R         (- 4b c x  - 4b c)
+--R      *
+--R          +------------------------------------------------------+
+--R          |     4 4       3     3      2 2 2 2        3 3     4 4
+--R          |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R          |------------------------------------------------------
+--R         4|                            7 5
+--R         \|                       4096b c
+--R      *
+--R                    +------------------------------------------------------+
+--R                    |     4 4       3     3      2 2 2 2        3 3     4 4
+--R                2   |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R              8b c  |------------------------------------------------------
+--R                   4|                            7 5
+--R                   \|                       4096b c
+--R         atan(-------------------------------------------------------------)
+--R                                                  +-+
+--R                                     (3A c + B b)\|x
+--R     + 
+--R                   +-+
+--R       (A c - B b)\|x
+--R  /
+--R         2 2     2
+--R     2b c x  + 2b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1327
+
+--S 1328 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3A c - B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   +------------------------------------------------------+
+--R                   |     4 4       3     3      2 2 2 2        3 3     4 4
+--R              +-+  |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b  4+-+3
+--R         8b c\|2   |------------------------------------------------------ \|b
+--R                  4|                            7 5
+--R                  \|                       4096b c
+--R      *
+--R         4+-+
+--R         \|c
+--R      *
+--R         log
+--R                           +-+
+--R              (3A c + B b)\|x
+--R            + 
+--R                    +------------------------------------------------------+
+--R                    |     4 4       3     3      2 2 2 2        3 3     4 4
+--R                2   |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R              8b c  |------------------------------------------------------
+--R                   4|                            7 5
+--R                   \|                       4096b c
+--R     + 
+--R       -
+--R                      +------------------------------------------------------+
+--R                      |     4 4       3     3      2 2 2 2        3 3     4 4
+--R                 +-+  |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R            8b c\|2   |------------------------------------------------------
+--R                     4|                            7 5
+--R                     \|                       4096b c
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R            log
+--R                              +-+
+--R                 (3A c + B b)\|x
+--R               + 
+--R                       +------------------------------------------------------+
+--R                       |     4 4       3     3      2 2 2 2        3 3     4 4
+--R                   2   |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R               - 8b c  |------------------------------------------------------
+--R                      4|                            7 5
+--R                      \|                       4096b c
+--R     + 
+--R                          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3A c + B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R                           \|2 \|c \|x  + \|b
+--R       (- 6A c - 2B b)atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R                           \|2 \|c \|x  - \|b
+--R       (- 6A c - 2B b)atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R       -
+--R                       +------------------------------------------------------+
+--R                       |     4 4       3     3      2 2 2 2        3 3     4 4
+--R                  +-+  |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R            16b c\|2   |------------------------------------------------------
+--R                      4|                            7 5
+--R                      \|                       4096b c
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R                       +------------------------------------------------------+
+--R                       |     4 4       3     3      2 2 2 2        3 3     4 4
+--R                   2   |- 81A c  - 108A B b c  - 54A B b c  - 12A B b c - B b
+--R                 8b c  |------------------------------------------------------
+--R                      4|                            7 5
+--R                      \|                       4096b c
+--R            atan(-------------------------------------------------------------)
+--R                                                     +-+
+--R                                        (3A c + B b)\|x
+--R  /
+--R          +-+4+-+3 4+-+
+--R     8b c\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1328
+
+--S 1329 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                           +-+4+-+2        2          3                2    +-+
+--R           ((6A c + 2B b)x\|b \|b   + (3A c  + B b c)x  + (3A b c + B b )x)\|c
+--R         + 
+--R                 2           2               2 4+-+2
+--R           ((9A c  + 3B b c)x  + 3A b c + B b )\|b
+--R         + 
+--R                   2          2               2  +-+
+--R           ((- 3A c  - B b c)x  - 3A b c - B b )\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R            2           2 +-+ +-+          3        2  3            2       2
+--R     (- 6A c  - 2B b c)x \|b \|c  + (- 3A c  - B b c )x  + (- 9A b c  - 3B b c)x
+--R  /
+--R                     2 3      2     +-+4+-+2 +-+
+--R               (16b c x  + 16b c x)\|b \|b  \|c
+--R             + 
+--R                    3 4      2 2 2     3  4+-+2
+--R               (8b c x  + 16b c x  + 8b c)\|b
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R              2 3 3      3 2
+--R         - 16b c x  - 16b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1329
+
+)clear all
+
+--S 1330 of 3139
+t0:=x^(5/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                2      +-+
+--R            (B x  + A)\|x
+--R   (1)  ---------------------
+--R         2 6         4    2 2
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1330
+
+--S 1331 of 3139
+r0:=-1/4*(b*B-5*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(9/4)*_
+   c^(3/4)*sqrt(2))+1/4*(b*B-5*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(9/4)*c^(3/4)*sqrt(2))+1/8*(b*B-5*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*c^(3/4)*sqrt(2))-_
+   1/8*(b*B-5*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(9/4)*c^(3/4)*sqrt(2))+1/2*(b*B-5*A*c)/(b^2*c*sqrt(x))+_
+   1/2*(-b*B+A*c)/(b*c*(b+c*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R               2          2               2  +-+
+--R         ((5A c  - B b c)x  + 5A b c - B b )\|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 2          2               2  +-+
+--R         ((- 5A c  + B b c)x  - 5A b c + B b )\|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                          +-+4+-+ +-+   4+-+
+--R                2           2                 2  +-+     \|2 \|c \|x  + \|b
+--R       ((- 10A c  + 2B b c)x  - 10A b c + 2B b )\|x atan(-------------------)
+--R                                                                 4+-+
+--R                                                                 \|b
+--R     + 
+--R                                                          +-+4+-+ +-+   4+-+
+--R                2           2                 2  +-+     \|2 \|c \|x  - \|b
+--R       ((- 10A c  + 2B b c)x  - 10A b c + 2B b )\|x atan(-------------------)
+--R                                                                 4+-+
+--R                                                                 \|b
+--R     + 
+--R                         2          +-+4+-+4+-+3
+--R       ((- 20A c + 4B b)x  - 16A b)\|2 \|b \|c
+--R  /
+--R        2   2     3  +-+4+-+4+-+3 +-+
+--R     (8b c x  + 8b )\|2 \|b \|c  \|x
+--R                                                    Type: Expression(Integer)
+--E 1331
+
+--S 1332 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2   2     3
+--R         (- 2b c x  - 2b )
+--R      *
+--R          +--------------------------------------------------------+
+--R          |      4 4       3     3       2 2 2 2        3 3     4 4
+--R          |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b   +-+
+--R          |-------------------------------------------------------- \|x
+--R         4|                             9 3
+--R         \|                        4096b c
+--R      *
+--R         log
+--R                   3 3      2     2        2 2     3 3  +-+
+--R              (125A c  - 75A B b c  + 15A B b c - B b )\|x
+--R            + 
+--R                     +--------------------------------------------------------+3
+--R                     |      4 4       3     3       2 2 2 2        3 3     4 4
+--R                7 2  |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b
+--R            512b c   |--------------------------------------------------------
+--R                    4|                             9 3
+--R                    \|                        4096b c
+--R     + 
+--R            2   2     3
+--R         (2b c x  + 2b )
+--R      *
+--R          +--------------------------------------------------------+
+--R          |      4 4       3     3       2 2 2 2        3 3     4 4
+--R          |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b   +-+
+--R          |-------------------------------------------------------- \|x
+--R         4|                             9 3
+--R         \|                        4096b c
+--R      *
+--R         log
+--R                   3 3      2     2        2 2     3 3  +-+
+--R              (125A c  - 75A B b c  + 15A B b c - B b )\|x
+--R            + 
+--R              -
+--R                       7 2
+--R                   512b c
+--R                *
+--R                    +--------------------------------------------------------+3
+--R                    |      4 4       3     3       2 2 2 2        3 3     4 4
+--R                    |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b
+--R                    |--------------------------------------------------------
+--R                   4|                             9 3
+--R                   \|                        4096b c
+--R     + 
+--R              2   2     3
+--R         (- 4b c x  - 4b )
+--R      *
+--R          +--------------------------------------------------------+
+--R          |      4 4       3     3       2 2 2 2        3 3     4 4
+--R          |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b   +-+
+--R          |-------------------------------------------------------- \|x
+--R         4|                             9 3
+--R         \|                        4096b c
+--R      *
+--R                     +--------------------------------------------------------+3
+--R                     |      4 4       3     3       2 2 2 2        3 3     4 4
+--R                7 2  |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b
+--R            512b c   |--------------------------------------------------------
+--R                    4|                             9 3
+--R                    \|                        4096b c
+--R       atan(-------------------------------------------------------------------)
+--R                            3 3      2     2        2 2     3 3  +-+
+--R                       (125A c  - 75A B b c  + 15A B b c - B b )\|x
+--R     + 
+--R                      2
+--R       (- 5A c + B b)x  - 4A b
+--R  /
+--R        2   2     3  +-+
+--R     (2b c x  + 2b )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1332
+
+--S 1333 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5A c + B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R                     +--------------------------------------------------------+
+--R                     |      4 4       3     3       2 2 2 2        3 3     4 4
+--R              2 +-+  |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b
+--R            8b \|2   |--------------------------------------------------------
+--R                    4|                             9 3
+--R                    \|                        4096b c
+--R         *
+--R            4+-+4+-+3
+--R            \|b \|c
+--R         *
+--R            log
+--R                      3 3      2     2        2 2     3 3  +-+
+--R                 (125A c  - 75A B b c  + 15A B b c - B b )\|x
+--R               + 
+--R                       7 2
+--R                   512b c
+--R                *
+--R                    +--------------------------------------------------------+3
+--R                    |      4 4       3     3       2 2 2 2        3 3     4 4
+--R                    |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b
+--R                    |--------------------------------------------------------
+--R                   4|                             9 3
+--R                   \|                        4096b c
+--R     + 
+--R                  +--------------------------------------------------------+
+--R                  |      4 4       3     3       2 2 2 2        3 3     4 4
+--R           2 +-+  |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b  4+-+
+--R         8b \|2   |-------------------------------------------------------- \|b
+--R                 4|                             9 3
+--R                 \|                        4096b c
+--R      *
+--R         4+-+3
+--R         \|c
+--R      *
+--R         log
+--R                   3 3      2     2        2 2     3 3  +-+
+--R              (125A c  - 75A B b c  + 15A B b c - B b )\|x
+--R            + 
+--R              -
+--R                       7 2
+--R                   512b c
+--R                *
+--R                    +--------------------------------------------------------+3
+--R                    |      4 4       3     3       2 2 2 2        3 3     4 4
+--R                    |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b
+--R                    |--------------------------------------------------------
+--R                   4|                             9 3
+--R                   \|                        4096b c
+--R     + 
+--R                          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5A c - B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                           +-+4+-+ +-+   4+-+
+--R                          \|2 \|c \|x  + \|b
+--R       (10A c - 2B b)atan(-------------------)
+--R                                  4+-+
+--R                                  \|b
+--R     + 
+--R                           +-+4+-+ +-+   4+-+
+--R                          \|2 \|c \|x  - \|b
+--R       (10A c - 2B b)atan(-------------------)
+--R                                  4+-+
+--R                                  \|b
+--R     + 
+--R       -
+--R                      +--------------------------------------------------------+
+--R                      |      4 4       3     3       2 2 2 2        3 3     4 4
+--R               2 +-+  |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b
+--R            16b \|2   |--------------------------------------------------------
+--R                     4|                             9 3
+--R                     \|                        4096b c
+--R         *
+--R            4+-+4+-+3
+--R            \|b \|c
+--R         *
+--R            atan
+--R                       7 2
+--R                   512b c
+--R                *
+--R                    +--------------------------------------------------------+3
+--R                    |      4 4       3     3       2 2 2 2        3 3     4 4
+--R                    |- 625A c  + 500A B b c  - 150A B b c  + 20A B b c - B b
+--R                    |--------------------------------------------------------
+--R                   4|                             9 3
+--R                   \|                        4096b c
+--R              /
+--R                      3 3      2     2        2 2     3 3  +-+
+--R                 (125A c  - 75A B b c  + 15A B b c - B b )\|x
+--R  /
+--R       2 +-+4+-+4+-+3
+--R     8b \|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1333
+
+--S 1334 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                            2 +-+4+-+2 +-+
+--R           (- 10A c + 2B b)x \|b \|b  \|c
+--R         + 
+--R                   2          3                    2   4+-+2
+--R           ((- 5A c  + B b c)x  + (- 15A b c + 3B b )x)\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                2          3                2   4+-+2                  2   +-+
+--R         (((5A c  - B b c)x  + (5A b c - B b )x)\|b   + (10A b c - 2B b )x\|b )
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R               2          2               2  +-+4+-+2           2       2   2
+--R       ((- 5A c  + B b c)x  - 5A b c + B b )\|b \|b   + (15A b c  - 3B b c)x
+--R     + 
+--R           2       3
+--R       5A b c - B b
+--R  /
+--R                2   3      3   +-+4+-+2 +-+      2 2 4      3   2     4 4+-+2
+--R           ((16b c x  + 16b x)\|b \|b  \|c  + (8b c x  + 16b c x  + 8b )\|b  )
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R              3 2 3      4
+--R         - 16b c x  - 16b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1334
+
+)clear all
+
+--S 1335 of 3139
+t0:=x^(3/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                2      +-+
+--R            (B x  + A)\|x
+--R   (1)  ---------------------
+--R         2 7         5    2 3
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1335
+
+--S 1336 of 3139
+r0:=1/6*(3*b*B-7*A*c)/(b^2*c*x^(3/2))+1/2*(-b*B+A*c)/(b*c*x^(3/2)*_
+   (b+c*x^2))-1/4*(3*b*B-7*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (b^(11/4)*c^(1/4)*sqrt(2))+1/4*(3*b*B-7*A*c)*atan(1+c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(11/4)*c^(1/4)*sqrt(2))-1/8*(3*b*B-7*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*_
+   c^(1/4)*sqrt(2))+1/8*(3*b*B-7*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*c^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  2           3                    2    +-+
+--R         ((- 21A c  + 9B b c)x  + (- 21A b c + 9B b )x)\|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                2           3                  2    +-+
+--R         ((21A c  - 9B b c)x  + (21A b c - 9B b )x)\|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  2            3                     2    +-+
+--R         ((- 42A c  + 18B b c)x  + (- 42A b c + 18B b )x)\|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                  2            3                     2    +-+
+--R         ((- 42A c  + 18B b c)x  + (- 42A b c + 18B b )x)\|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                          2          +-+4+-+3 4+-+
+--R       ((- 28A c + 12B b)x  - 16A b)\|2 \|b   \|c
+--R  /
+--R         2   3      3   +-+4+-+3 4+-+ +-+
+--R     (24b c x  + 24b x)\|2 \|b   \|c \|x
+--R                                                    Type: Expression(Integer)
+--E 1336
+
+--S 1337 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2   3     3
+--R         (- 6b c x  - 6b x)
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |       4 4        3     3        2 2 2 2         3 3       4 4
+--R          |- 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c - 81B b   +-+
+--R          |-------------------------------------------------------------- \|x
+--R         4|                                11
+--R         \|                           4096b  c
+--R      *
+--R         log
+--R                            +-+
+--R              (7A c - 3B b)\|x
+--R            + 
+--R                 +--------------------------------------------------------------+
+--R                 |       4 4        3     3        2 2 2 2         3 3       4 4
+--R              3  |- 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c - 81B b
+--R            8b   |--------------------------------------------------------------
+--R                4|                                11
+--R                \|                           4096b  c
+--R     + 
+--R            2   3     3
+--R         (6b c x  + 6b x)
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |       4 4        3     3        2 2 2 2         3 3       4 4
+--R          |- 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c - 81B b   +-+
+--R          |-------------------------------------------------------------- \|x
+--R         4|                                11
+--R         \|                           4096b  c
+--R      *
+--R         log
+--R                            +-+
+--R              (7A c - 3B b)\|x
+--R            + 
+--R              -
+--R                     3
+--R                   8b
+--R                *
+--R                   ROOT
+--R                                 4 4        3     3        2 2 2 2         3 3
+--R                          - 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c
+--R                        + 
+--R                               4 4
+--R                          - 81B b
+--R                     /
+--R                             11
+--R                        4096b  c
+--R                  ,
+--R                      4
+--R     + 
+--R             2   3      3
+--R         (12b c x  + 12b x)
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |       4 4        3     3        2 2 2 2         3 3       4 4
+--R          |- 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c - 81B b   +-+
+--R          |-------------------------------------------------------------- \|x
+--R         4|                                11
+--R         \|                           4096b  c
+--R      *
+--R         atan
+--R                 +--------------------------------------------------------------+
+--R                 |       4 4        3     3        2 2 2 2         3 3       4 4
+--R              3  |- 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c - 81B b
+--R            8b   |--------------------------------------------------------------
+--R                4|                                11
+--R                \|                           4096b  c
+--R            --------------------------------------------------------------------
+--R                                                    +-+
+--R                                      (7A c - 3B b)\|x
+--R     + 
+--R                       2
+--R       (- 7A c + 3B b)x  - 4A b
+--R  /
+--R        2   3     3   +-+
+--R     (6b c x  + 6b x)\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1337
+
+--S 1338 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +-+4+-+4+-+ +-+     +-+    +-+
+--R       (7A c - 3B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R              2 +-+
+--R            8b \|2
+--R         *
+--R             +--------------------------------------------------------------+
+--R             |       4 4        3     3        2 2 2 2         3 3       4 4
+--R             |- 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c - 81B b
+--R             |--------------------------------------------------------------
+--R            4|                                11
+--R            \|                           4096b  c
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R            log
+--R                               +-+
+--R                 (7A c - 3B b)\|x
+--R               + 
+--R                     3
+--R                   8b
+--R                *
+--R                   ROOT
+--R                                 4 4        3     3        2 2 2 2         3 3
+--R                          - 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c
+--R                        + 
+--R                               4 4
+--R                          - 81B b
+--R                     /
+--R                             11
+--R                        4096b  c
+--R                  ,
+--R                      4
+--R     + 
+--R           2 +-+
+--R         8b \|2
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |       4 4        3     3        2 2 2 2         3 3       4 4
+--R          |- 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c - 81B b  4+-+3
+--R          |-------------------------------------------------------------- \|b
+--R         4|                                11
+--R         \|                           4096b  c
+--R      *
+--R         4+-+
+--R         \|c
+--R      *
+--R         log
+--R                            +-+
+--R              (7A c - 3B b)\|x
+--R            + 
+--R              -
+--R                     3
+--R                   8b
+--R                *
+--R                   ROOT
+--R                                 4 4        3     3        2 2 2 2         3 3
+--R                          - 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c
+--R                        + 
+--R                               4 4
+--R                          - 81B b
+--R                     /
+--R                             11
+--R                        4096b  c
+--R                  ,
+--R                      4
+--R     + 
+--R                             +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 7A c + 3B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                           +-+4+-+ +-+   4+-+
+--R                          \|2 \|c \|x  + \|b
+--R       (14A c - 6B b)atan(-------------------)
+--R                                  4+-+
+--R                                  \|b
+--R     + 
+--R                           +-+4+-+ +-+   4+-+
+--R                          \|2 \|c \|x  - \|b
+--R       (14A c - 6B b)atan(-------------------)
+--R                                  4+-+
+--R                                  \|b
+--R     + 
+--R            2 +-+
+--R         16b \|2
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |       4 4        3     3        2 2 2 2         3 3       4 4
+--R          |- 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c - 81B b  4+-+3
+--R          |-------------------------------------------------------------- \|b
+--R         4|                                11
+--R         \|                           4096b  c
+--R      *
+--R         4+-+
+--R         \|c
+--R      *
+--R         atan
+--R                 +--------------------------------------------------------------+
+--R                 |       4 4        3     3        2 2 2 2         3 3       4 4
+--R              3  |- 2401A c  + 4116A B b c  - 2646A B b c  + 756A B b c - 81B b
+--R            8b   |--------------------------------------------------------------
+--R                4|                                11
+--R                \|                           4096b  c
+--R            --------------------------------------------------------------------
+--R                                                    +-+
+--R                                      (7A c - 3B b)\|x
+--R  /
+--R       2 +-+4+-+3 4+-+
+--R     8b \|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1338
+
+--S 1339 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                 +-+4+-+2          2           3
+--R               (- 14A c + 6B b)x\|b \|b   + (- 7A c  + 3B b c)x
+--R             + 
+--R                               2
+--R               (- 7A b c + 3B b )x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    2           2                2 4+-+2
+--R           ((- 21A c  + 9B b c)x  - 7A b c + 3B b )\|b
+--R         + 
+--R                 2           2                2  +-+
+--R           ((7A c  - 3B b c)x  + 7A b c - 3B b )\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R             2           2 +-+ +-+        3         2  3           2       2
+--R       (14A c  - 6B b c)x \|b \|c  + (7A c  - 3B b c )x  + (21A b c  - 9B b c)x
+--R  /
+--R                2   3      3   +-+4+-+2 +-+      2 2 4      3   2     4 4+-+2
+--R           ((16b c x  + 16b x)\|b \|b  \|c  + (8b c x  + 16b c x  + 8b )\|b  )
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R              3 2 3      4
+--R         - 16b c x  - 16b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1339
+
+)clear all
+
+--S 1340 of 3139
+t0:=(A+B*x^2)*sqrt(x)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                2      +-+
+--R            (B x  + A)\|x
+--R   (1)  ---------------------
+--R         2 8         6    2 4
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1340
+
+--S 1341 of 3139
+r0:=1/10*(5*b*B-9*A*c)/(b^2*c*x^(5/2))+1/2*(-b*B+A*c)/(b*c*x^(5/2)*_
+   (b+c*x^2))+1/4*c^(1/4)*(5*b*B-9*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(13/4)*sqrt(2))-1/4*c^(1/4)*(5*b*B-9*A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*sqrt(2))-1/8*c^(1/4)*(5*b*B-9*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*_
+   sqrt(2))+1/8*c^(1/4)*(5*b*B-9*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*sqrt(2))+1/2*(-5*b*B+9*A*c)/(b^3*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                  2            4                     2  2 4+-+ +-+
+--R         ((- 45A c  + 25B b c)x  + (- 45A b c + 25B b )x )\|c \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                2            4                   2  2 4+-+ +-+
+--R         ((45A c  - 25B b c)x  + (45A b c - 25B b )x )\|c \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                2            4                   2  2 4+-+ +-+
+--R         ((90A c  - 50B b c)x  + (90A b c - 50B b )x )\|c \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                2            4                   2  2 4+-+ +-+
+--R         ((90A c  - 50B b c)x  + (90A b c - 50B b )x )\|c \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R               2             4                    2  2        2  +-+4+-+
+--R       ((180A c  - 100B b c)x  + (144A b c - 80B b )x  - 16A b )\|2 \|b
+--R  /
+--R         3   4      4 2  +-+4+-+ +-+
+--R     (40b c x  + 40b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 1341
+
+--S 1342 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3   4      4 2
+--R         (10b c x  + 10b x )
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |       4 5         3     4         2 2 2 3          3 3 2       4 4
+--R          |- 6561A c  + 14580A B b c  - 12150A B b c  + 4500A B b c  - 625B b c
+--R          |--------------------------------------------------------------------
+--R         4|                                    13
+--R         \|                               4096b
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                   3 4        2     3         2 2 2       3 3   +-+
+--R              (729A c  - 1215A B b c  + 675A B b c  - 125B b c)\|x
+--R            + 
+--R                    10
+--R                512b
+--R             *
+--R                  ROOT
+--R                                4 5         3     4         2 2 2 3
+--R                         - 6561A c  + 14580A B b c  - 12150A B b c
+--R                       + 
+--R                                3 3 2       4 4
+--R                         4500A B b c  - 625B b c
+--R                    /
+--R                            13
+--R                       4096b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R               3   4      4 2
+--R         (- 10b c x  - 10b x )
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |       4 5         3     4         2 2 2 3          3 3 2       4 4
+--R          |- 6561A c  + 14580A B b c  - 12150A B b c  + 4500A B b c  - 625B b c
+--R          |--------------------------------------------------------------------
+--R         4|                                    13
+--R         \|                               4096b
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                   3 4        2     3         2 2 2       3 3   +-+
+--R              (729A c  - 1215A B b c  + 675A B b c  - 125B b c)\|x
+--R            + 
+--R              -
+--R                       10
+--R                   512b
+--R                *
+--R                     ROOT
+--R                                   4 5         3     4         2 2 2 3
+--R                            - 6561A c  + 14580A B b c  - 12150A B b c
+--R                          + 
+--R                                   3 3 2       4 4
+--R                            4500A B b c  - 625B b c
+--R                       /
+--R                               13
+--R                          4096b
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R             3   4      4 2
+--R         (20b c x  + 20b x )
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |       4 5         3     4         2 2 2 3          3 3 2       4 4
+--R          |- 6561A c  + 14580A B b c  - 12150A B b c  + 4500A B b c  - 625B b c
+--R          |--------------------------------------------------------------------
+--R         4|                                    13
+--R         \|                               4096b
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         atan
+--R                    10
+--R                512b
+--R             *
+--R                  ROOT
+--R                                4 5         3     4         2 2 2 3
+--R                         - 6561A c  + 14580A B b c  - 12150A B b c
+--R                       + 
+--R                                3 3 2       4 4
+--R                         4500A B b c  - 625B b c
+--R                    /
+--R                            13
+--R                       4096b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                   3 4        2     3         2 2 2       3 3   +-+
+--R              (729A c  - 1215A B b c  + 675A B b c  - 125B b c)\|x
+--R     + 
+--R             2            4                   2  2       2
+--R       (45A c  - 25B b c)x  + (36A b c - 20B b )x  - 4A b
+--R  /
+--R         3   4      4 2  +-+
+--R     (10b c x  + 10b x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1342
+
+--S 1343 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (9A c - 5B b)\|c log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           3 +-+
+--R         8b \|2
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |       4 5         3     4         2 2 2 3          3 3 2       4 4
+--R          |- 6561A c  + 14580A B b c  - 12150A B b c  + 4500A B b c  - 625B b c
+--R          |--------------------------------------------------------------------
+--R         4|                                    13
+--R         \|                               4096b
+--R      *
+--R         4+-+
+--R         \|b
+--R      *
+--R         log
+--R                   3 4        2     3         2 2 2       3 3   +-+
+--R              (729A c  - 1215A B b c  + 675A B b c  - 125B b c)\|x
+--R            + 
+--R                    10
+--R                512b
+--R             *
+--R                  ROOT
+--R                                4 5         3     4         2 2 2 3
+--R                         - 6561A c  + 14580A B b c  - 12150A B b c
+--R                       + 
+--R                                3 3 2       4 4
+--R                         4500A B b c  - 625B b c
+--R                    /
+--R                            13
+--R                       4096b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R       -
+--R              3 +-+
+--R            8b \|2
+--R         *
+--R            ROOT
+--R                          4 5         3     4         2 2 2 3          3 3 2
+--R                   - 6561A c  + 14580A B b c  - 12150A B b c  + 4500A B b c
+--R                 + 
+--R                         4 4
+--R                   - 625B b c
+--R              /
+--R                      13
+--R                 4096b
+--R           ,
+--R               4
+--R         *
+--R            4+-+
+--R            \|b
+--R         *
+--R            log
+--R                      3 4        2     3         2 2 2       3 3   +-+
+--R                 (729A c  - 1215A B b c  + 675A B b c  - 125B b c)\|x
+--R               + 
+--R                 -
+--R                          10
+--R                      512b
+--R                   *
+--R                        ROOT
+--R                                      4 5         3     4         2 2 2 3
+--R                               - 6561A c  + 14580A B b c  - 12150A B b c
+--R                             + 
+--R                                      3 3 2       4 4
+--R                               4500A B b c  - 625B b c
+--R                          /
+--R                                  13
+--R                             4096b
+--R                       ,
+--R                           4
+--R                     **
+--R                        3
+--R     + 
+--R                      4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 9A c + 5B b)\|c log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R                        4+-+     \|2 \|c \|x  + \|b
+--R       (- 18A c + 10B b)\|c atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R                        4+-+     \|2 \|c \|x  - \|b
+--R       (- 18A c + 10B b)\|c atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R            3 +-+
+--R         16b \|2
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |       4 5         3     4         2 2 2 3          3 3 2       4 4
+--R          |- 6561A c  + 14580A B b c  - 12150A B b c  + 4500A B b c  - 625B b c
+--R          |--------------------------------------------------------------------
+--R         4|                                    13
+--R         \|                               4096b
+--R      *
+--R         4+-+
+--R         \|b
+--R      *
+--R         atan
+--R                    10
+--R                512b
+--R             *
+--R                  ROOT
+--R                                4 5         3     4         2 2 2 3
+--R                         - 6561A c  + 14580A B b c  - 12150A B b c
+--R                       + 
+--R                                3 3 2       4 4
+--R                         4500A B b c  - 625B b c
+--R                    /
+--R                            13
+--R                       4096b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                   3 4        2     3         2 2 2       3 3   +-+
+--R              (729A c  - 1215A B b c  + 675A B b c  - 125B b c)\|x
+--R  /
+--R       3 +-+4+-+
+--R     8b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1343
+
+--S 1344 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     2           3                 2   4+-+2
+--R               ((9A c  - 5B b c)x  + (9A b c - 5B b )x)\|b
+--R             + 
+--R                               2   +-+
+--R               (18A b c - 10B b )x\|b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                   2           2                2  +-+4+-+2
+--R           ((- 9A c  + 5B b c)x  - 9A b c + 5B b )\|b \|b
+--R         + 
+--R                   2        2   2       2        3
+--R           (27A b c  - 15B b c)x  + 9A b c - 5B b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R               2            2 +-+4+-+2 +-+
+--R       (- 18A c  + 10B b c)x \|b \|b  \|c
+--R     + 
+--R               3         2  3             2        2    4+-+2
+--R       ((- 9A c  + 5B b c )x  + (- 27A b c  + 15B b c)x)\|b
+--R  /
+--R             4   3      5  4+-+2         3   3      4   +-+4+-+2 +-+
+--R         (16b c x  + 16b x)\|c   + (- 16b c x  - 16b x)\|b \|b  \|c
+--R       + 
+--R              3 2 4      4   2     5 4+-+2
+--R         (- 8b c x  - 16b c x  - 8b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1344
+
+)clear all
+
+--S 1345 of 3139
+t0:=(A+B*x^2)/((b*x^2+c*x^4)^2*sqrt(x))
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R          2 8         6    2 4  +-+
+--R        (c x  + 2b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1345
+
+--S 1346 of 3139
+r0:=1/14*(7*b*B-11*A*c)/(b^2*c*x^(7/2))+1/6*(-7*b*B+11*A*c)/(b^3*x^(3/2))+_
+   1/2*(-b*B+A*c)/(b*c*x^(7/2)*(b+c*x^2))+1/4*c^(3/4)*(7*b*B-11*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(15/4)*sqrt(2))-1/4*c^(3/4)*_
+   (7*b*B-11*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(15/4)*_
+   sqrt(2))+1/8*c^(3/4)*(7*b*B-11*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(15/4)*sqrt(2))-1/8*c^(3/4)*(7*b*B-_
+   11*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 2             5                     2  3 4+-+3 +-+
+--R         ((231A c  - 147B b c)x  + (231A b c - 147B b )x )\|c  \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   2             5                       2  3 4+-+3 +-+
+--R         ((- 231A c  + 147B b c)x  + (- 231A b c + 147B b )x )\|c  \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 2             5                     2  3 4+-+3 +-+
+--R         ((462A c  - 294B b c)x  + (462A b c - 294B b )x )\|c  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                 2             5                     2  3 4+-+3 +-+
+--R         ((462A c  - 294B b c)x  + (462A b c - 294B b )x )\|c  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R               2             4                     2  2        2  +-+4+-+3
+--R       ((308A c  - 196B b c)x  + (176A b c - 112B b )x  - 48A b )\|2 \|b
+--R  /
+--R          3   5       4 3  +-+4+-+3 +-+
+--R     (168b c x  + 168b x )\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 1346
+
+--S 1347 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3   5      4 3
+--R         (42b c x  + 42b x )
+--R      *
+--R         ROOT
+--R                        4 7         3     6         2 2 2 5           3 3 4
+--R                - 14641A c  + 37268A B b c  - 35574A B b c  + 15092A B b c
+--R              + 
+--R                       4 4 3
+--R                - 2401B b c
+--R           /
+--R                   15
+--R              4096b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                    2           +-+
+--R              (11A c  - 7B b c)\|x
+--R            + 
+--R                  4
+--R                8b
+--R             *
+--R                ROOT
+--R                               4 7         3     6         2 2 2 5
+--R                       - 14641A c  + 37268A B b c  - 35574A B b c
+--R                     + 
+--R                               3 3 4        4 4 3
+--R                       15092A B b c  - 2401B b c
+--R                  /
+--R                          15
+--R                     4096b
+--R               ,
+--R                   4
+--R     + 
+--R               3   5      4 3
+--R         (- 42b c x  - 42b x )
+--R      *
+--R         ROOT
+--R                        4 7         3     6         2 2 2 5           3 3 4
+--R                - 14641A c  + 37268A B b c  - 35574A B b c  + 15092A B b c
+--R              + 
+--R                       4 4 3
+--R                - 2401B b c
+--R           /
+--R                   15
+--R              4096b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                    2           +-+
+--R              (11A c  - 7B b c)\|x
+--R            + 
+--R              -
+--R                     4
+--R                   8b
+--R                *
+--R                   ROOT
+--R                                  4 7         3     6         2 2 2 5
+--R                          - 14641A c  + 37268A B b c  - 35574A B b c
+--R                        + 
+--R                                  3 3 4        4 4 3
+--R                          15092A B b c  - 2401B b c
+--R                     /
+--R                             15
+--R                        4096b
+--R                  ,
+--R                      4
+--R     + 
+--R               3   5      4 3
+--R         (- 84b c x  - 84b x )
+--R      *
+--R         ROOT
+--R                        4 7         3     6         2 2 2 5           3 3 4
+--R                - 14641A c  + 37268A B b c  - 35574A B b c  + 15092A B b c
+--R              + 
+--R                       4 4 3
+--R                - 2401B b c
+--R           /
+--R                   15
+--R              4096b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         atan
+--R                  4
+--R                8b
+--R             *
+--R                ROOT
+--R                               4 7         3     6         2 2 2 5
+--R                       - 14641A c  + 37268A B b c  - 35574A B b c
+--R                     + 
+--R                               3 3 4        4 4 3
+--R                       15092A B b c  - 2401B b c
+--R                  /
+--R                          15
+--R                     4096b
+--R               ,
+--R                   4
+--R           /
+--R                    2           +-+
+--R              (11A c  - 7B b c)\|x
+--R     + 
+--R             2            4                   2  2        2
+--R       (77A c  - 49B b c)x  + (44A b c - 28B b )x  - 12A b
+--R  /
+--R         3   5      4 3  +-+
+--R     (42b c x  + 42b x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1347
+
+--S 1348 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 11A c + 7B b)\|c  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           3 +-+
+--R         8b \|2
+--R      *
+--R         ROOT
+--R                        4 7         3     6         2 2 2 5           3 3 4
+--R                - 14641A c  + 37268A B b c  - 35574A B b c  + 15092A B b c
+--R              + 
+--R                       4 4 3
+--R                - 2401B b c
+--R           /
+--R                   15
+--R              4096b
+--R        ,
+--R            4
+--R      *
+--R         4+-+3
+--R         \|b
+--R      *
+--R         log
+--R                    2           +-+
+--R              (11A c  - 7B b c)\|x
+--R            + 
+--R                  4
+--R                8b
+--R             *
+--R                ROOT
+--R                               4 7         3     6         2 2 2 5
+--R                       - 14641A c  + 37268A B b c  - 35574A B b c
+--R                     + 
+--R                               3 3 4        4 4 3
+--R                       15092A B b c  - 2401B b c
+--R                  /
+--R                          15
+--R                     4096b
+--R               ,
+--R                   4
+--R     + 
+--R       -
+--R              3 +-+
+--R            8b \|2
+--R         *
+--R            ROOT
+--R                           4 7         3     6         2 2 2 5           3 3 4
+--R                   - 14641A c  + 37268A B b c  - 35574A B b c  + 15092A B b c
+--R                 + 
+--R                          4 4 3
+--R                   - 2401B b c
+--R              /
+--R                      15
+--R                 4096b
+--R           ,
+--R               4
+--R         *
+--R            4+-+3
+--R            \|b
+--R         *
+--R            log
+--R                       2           +-+
+--R                 (11A c  - 7B b c)\|x
+--R               + 
+--R                 -
+--R                        4
+--R                      8b
+--R                   *
+--R                      ROOT
+--R                                     4 7         3     6         2 2 2 5
+--R                             - 14641A c  + 37268A B b c  - 35574A B b c
+--R                           + 
+--R                                     3 3 4        4 4 3
+--R                             15092A B b c  - 2401B b c
+--R                        /
+--R                                15
+--R                           4096b
+--R                     ,
+--R                         4
+--R     + 
+--R                     4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (11A c - 7B b)\|c  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                        4+-+3     \|2 \|c \|x  + \|b
+--R       (- 22A c + 14B b)\|c  atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                        4+-+3     \|2 \|c \|x  - \|b
+--R       (- 22A c + 14B b)\|c  atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R       -
+--R               3 +-+
+--R            16b \|2
+--R         *
+--R            ROOT
+--R                           4 7         3     6         2 2 2 5           3 3 4
+--R                   - 14641A c  + 37268A B b c  - 35574A B b c  + 15092A B b c
+--R                 + 
+--R                          4 4 3
+--R                   - 2401B b c
+--R              /
+--R                      15
+--R                 4096b
+--R           ,
+--R               4
+--R         *
+--R            4+-+3
+--R            \|b
+--R         *
+--R            atan
+--R                     4
+--R                   8b
+--R                *
+--R                   ROOT
+--R                                  4 7         3     6         2 2 2 5
+--R                          - 14641A c  + 37268A B b c  - 35574A B b c
+--R                        + 
+--R                                  3 3 4        4 4 3
+--R                          15092A B b c  - 2401B b c
+--R                     /
+--R                             15
+--R                        4096b
+--R                  ,
+--R                      4
+--R              /
+--R                       2           +-+
+--R                 (11A c  - 7B b c)\|x
+--R  /
+--R       3 +-+4+-+3
+--R     8b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1348
+
+--S 1349 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 2            2 +-+ +-+         3         2  3
+--R           (22A c  - 14B b c)x \|b \|c  + (11A c  - 7B b c )x
+--R         + 
+--R                   2        2
+--R           (33A b c  - 21B b c)x
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                   2             +-+4+-+2           3         2  3
+--R           (- 22A c  + 14B b c)x\|b \|b   + (- 11A c  + 7B b c )x
+--R         + 
+--R                     2       2
+--R           (- 11A b c  + 7B b c)x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                3          2  2          2       2  4+-+2
+--R       ((- 33A c  + 21B b c )x  - 11A b c  + 7B b c)\|b
+--R     + 
+--R              3         2  2          2       2   +-+
+--R       ((11A c  - 7B b c )x  + 11A b c  - 7B b c)\|b
+--R  /
+--R             4   3      5  4+-+2         3   3      4   +-+4+-+2 +-+
+--R         (16b c x  + 16b x)\|c   + (- 16b c x  - 16b x)\|b \|b  \|c
+--R       + 
+--R              3 2 4      4   2     5 4+-+2
+--R         (- 8b c x  - 16b c x  - 8b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1349
+
+)clear all
+
+--S 1350 of 3139
+t0:=(A+B*x^2)/(x^(3/2)*(b*x^2+c*x^4)^2)
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R          2 9         7    2 5  +-+
+--R        (c x  + 2b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1350
+
+--S 1351 of 3139
+r0:=1/18*(9*b*B-13*A*c)/(b^2*c*x^(9/2))+1/10*(-9*b*B+13*A*c)/(b^3*x^(5/2))+_
+   1/2*(-b*B+A*c)/(b*c*x^(9/2)*(b+c*x^2))-1/4*c^(5/4)*(9*b*B-13*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(17/4)*sqrt(2))+1/4*c^(5/4)*_
+   (9*b*B-13*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(17/4)*_
+   sqrt(2))+1/8*c^(5/4)*(9*b*B-13*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*sqrt(2))-1/8*c^(5/4)*(9*b*B-13*A*c)*_
+   log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*_
+   sqrt(2))+1/2*c*(9*b*B-13*A*c)/(b^4*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                 3           2  6            2         2   4 4+-+ +-+
+--R         ((585A c  - 405B b c )x  + (585A b c  - 405B b c)x )\|c \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   3           2  6              2         2   4 4+-+ +-+
+--R         ((- 585A c  + 405B b c )x  + (- 585A b c  + 405B b c)x )\|c \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    3           2  6               2         2   4 4+-+ +-+
+--R         ((- 1170A c  + 810B b c )x  + (- 1170A b c  + 810B b c)x )\|c \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                    3           2  6               2         2   4 4+-+ +-+
+--R         ((- 1170A c  + 810B b c )x  + (- 1170A b c  + 810B b c)x )\|c \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                     3            2  6               2          2   4
+--R           (- 2340A c  + 1620B b c )x  + (- 1872A b c  + 1296B b c)x
+--R         + 
+--R                  2          3  2        3
+--R           (208A b c - 144B b )x  - 80A b
+--R      *
+--R          +-+4+-+
+--R         \|2 \|b
+--R  /
+--R          4   6       5 4  +-+4+-+ +-+
+--R     (360b c x  + 360b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 1351
+
+--S 1352 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4   6      5 4
+--R         (- 90b c x  - 90b x )
+--R      *
+--R         ROOT
+--R                        4 9         3     8         2 2 2 7           3 3 6
+--R                - 28561A c  + 79092A B b c  - 82134A B b c  + 37908A B b c
+--R              + 
+--R                       4 4 5
+--R                - 6561B b c
+--R           /
+--R                   17
+--R              4096b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                    3 7        2     6          2 2 5       3 3 4  +-+
+--R              (2197A c  - 4563A B b c  + 3159A B b c  - 729B b c )\|x
+--R            + 
+--R                    13
+--R                512b
+--R             *
+--R                  ROOT
+--R                                 4 9         3     8         2 2 2 7
+--R                         - 28561A c  + 79092A B b c  - 82134A B b c
+--R                       + 
+--R                                 3 3 6        4 4 5
+--R                         37908A B b c  - 6561B b c
+--R                    /
+--R                            17
+--R                       4096b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R             4   6      5 4
+--R         (90b c x  + 90b x )
+--R      *
+--R         ROOT
+--R                        4 9         3     8         2 2 2 7           3 3 6
+--R                - 28561A c  + 79092A B b c  - 82134A B b c  + 37908A B b c
+--R              + 
+--R                       4 4 5
+--R                - 6561B b c
+--R           /
+--R                   17
+--R              4096b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                    3 7        2     6          2 2 5       3 3 4  +-+
+--R              (2197A c  - 4563A B b c  + 3159A B b c  - 729B b c )\|x
+--R            + 
+--R              -
+--R                       13
+--R                   512b
+--R                *
+--R                     ROOT
+--R                                    4 9         3     8         2 2 2 7
+--R                            - 28561A c  + 79092A B b c  - 82134A B b c
+--R                          + 
+--R                                    3 3 6        4 4 5
+--R                            37908A B b c  - 6561B b c
+--R                       /
+--R                               17
+--R                          4096b
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R                4   6       5 4
+--R         (- 180b c x  - 180b x )
+--R      *
+--R         ROOT
+--R                        4 9         3     8         2 2 2 7           3 3 6
+--R                - 28561A c  + 79092A B b c  - 82134A B b c  + 37908A B b c
+--R              + 
+--R                       4 4 5
+--R                - 6561B b c
+--R           /
+--R                   17
+--R              4096b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         atan
+--R                    13
+--R                512b
+--R             *
+--R                  ROOT
+--R                                 4 9         3     8         2 2 2 7
+--R                         - 28561A c  + 79092A B b c  - 82134A B b c
+--R                       + 
+--R                                 3 3 6        4 4 5
+--R                         37908A B b c  - 6561B b c
+--R                    /
+--R                            17
+--R                       4096b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                    3 7        2     6          2 2 5       3 3 4  +-+
+--R              (2197A c  - 4563A B b c  + 3159A B b c  - 729B b c )\|x
+--R     + 
+--R                3           2  6              2         2   4
+--R       (- 585A c  + 405B b c )x  + (- 468A b c  + 324B b c)x
+--R     + 
+--R             2         3  2        3
+--R       (52A b c - 36B b )x  - 20A b
+--R  /
+--R         4   6      5 4  +-+
+--R     (90b c x  + 90b x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1352
+
+--S 1353 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               2          4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 13A c  + 9B b c)\|c log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R              4 +-+
+--R            8b \|2
+--R         *
+--R            ROOT
+--R                           4 9         3     8         2 2 2 7           3 3 6
+--R                   - 28561A c  + 79092A B b c  - 82134A B b c  + 37908A B b c
+--R                 + 
+--R                          4 4 5
+--R                   - 6561B b c
+--R              /
+--R                      17
+--R                 4096b
+--R           ,
+--R               4
+--R         *
+--R            4+-+
+--R            \|b
+--R         *
+--R            log
+--R                       3 7        2     6          2 2 5       3 3 4  +-+
+--R                 (2197A c  - 4563A B b c  + 3159A B b c  - 729B b c )\|x
+--R               + 
+--R                       13
+--R                   512b
+--R                *
+--R                     ROOT
+--R                                    4 9         3     8         2 2 2 7
+--R                            - 28561A c  + 79092A B b c  - 82134A B b c
+--R                          + 
+--R                                    3 3 6        4 4 5
+--R                            37908A B b c  - 6561B b c
+--R                       /
+--R                               17
+--R                          4096b
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R           4 +-+
+--R         8b \|2
+--R      *
+--R         ROOT
+--R                        4 9         3     8         2 2 2 7           3 3 6
+--R                - 28561A c  + 79092A B b c  - 82134A B b c  + 37908A B b c
+--R              + 
+--R                       4 4 5
+--R                - 6561B b c
+--R           /
+--R                   17
+--R              4096b
+--R        ,
+--R            4
+--R      *
+--R         4+-+
+--R         \|b
+--R      *
+--R         log
+--R                    3 7        2     6          2 2 5       3 3 4  +-+
+--R              (2197A c  - 4563A B b c  + 3159A B b c  - 729B b c )\|x
+--R            + 
+--R              -
+--R                       13
+--R                   512b
+--R                *
+--R                     ROOT
+--R                                    4 9         3     8         2 2 2 7
+--R                            - 28561A c  + 79092A B b c  - 82134A B b c
+--R                          + 
+--R                                    3 3 6        4 4 5
+--R                            37908A B b c  - 6561B b c
+--R                       /
+--R                               17
+--R                          4096b
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R             2          4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (13A c  - 9B b c)\|c log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R             2           4+-+     \|2 \|c \|x  + \|b
+--R       (26A c  - 18B b c)\|c atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R             2           4+-+     \|2 \|c \|x  - \|b
+--R       (26A c  - 18B b c)\|c atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R       -
+--R               4 +-+
+--R            16b \|2
+--R         *
+--R            ROOT
+--R                           4 9         3     8         2 2 2 7           3 3 6
+--R                   - 28561A c  + 79092A B b c  - 82134A B b c  + 37908A B b c
+--R                 + 
+--R                          4 4 5
+--R                   - 6561B b c
+--R              /
+--R                      17
+--R                 4096b
+--R           ,
+--R               4
+--R         *
+--R            4+-+
+--R            \|b
+--R         *
+--R            atan
+--R                       13
+--R                   512b
+--R                *
+--R                     ROOT
+--R                                    4 9         3     8         2 2 2 7
+--R                            - 28561A c  + 79092A B b c  - 82134A B b c
+--R                          + 
+--R                                    3 3 6        4 4 5
+--R                            37908A B b c  - 6561B b c
+--R                       /
+--R                               17
+--R                          4096b
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R              /
+--R                       3 7        2     6          2 2 5       3 3 4  +-+
+--R                 (2197A c  - 4563A B b c  + 3159A B b c  - 729B b c )\|x
+--R  /
+--R       4 +-+4+-+
+--R     8b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1353
+
+--S 1354 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                        3         2  3             2       2    4+-+2
+--R               ((- 13A c  + 9B b c )x  + (- 13A b c  + 9B b c)x)\|b
+--R             + 
+--R                         2        2    +-+
+--R               (- 26A b c  + 18B b c)x\|b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                  3         2  2          2       2   +-+4+-+2
+--R           ((13A c  - 9B b c )x  + 13A b c  - 9B b c)\|b \|b
+--R         + 
+--R                     3        2 2  2        2 2       3
+--R           (- 39A b c  + 27B b c )x  - 13A b c  + 9B b c
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R             3          2  2 +-+4+-+2 +-+
+--R       (26A c  - 18B b c )x \|b \|b  \|c
+--R     + 
+--R              4         3  3           3        2 2   4+-+2
+--R       ((13A c  - 9B b c )x  + (39A b c  - 27B b c )x)\|b
+--R  /
+--R             5   3      6  4+-+2         4   3      5   +-+4+-+2 +-+
+--R         (16b c x  + 16b x)\|c   + (- 16b c x  - 16b x)\|b \|b  \|c
+--R       + 
+--R              4 2 4      5   2     6 4+-+2
+--R         (- 8b c x  - 16b c x  - 8b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1354
+
+)clear all
+
+--S 1355 of 3139
+t0:=x^(23/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                  7      5  +-+
+--R              (B x  + A x )\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1355
+
+--S 1356 of 3139
+r0:=9/80*(13*b*B-5*A*c)*x^(5/2)/(b*c^3)-1/4*(b*B-A*c)*x^(13/2)/(b*c*(b+_
+   c*x^2)^2)-1/16*(13*b*B-5*A*c)*x^(9/2)/(b*c^2*(b+c*x^2))-9/32*b^(1/4)*_
+   (13*b*B-5*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(17/4)*_
+   sqrt(2))+9/32*b^(1/4)*(13*b*B-5*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(c^(17/4)*sqrt(2))-9/64*b^(1/4)*(13*b*B-5*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(17/4)*sqrt(2))+_
+   9/64*b^(1/4)*(13*b*B-5*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(c^(17/4)*sqrt(2))-9/16*(13*b*B-5*A*c)*sqrt(x)/c^4
+--R 
+--R
+--R   (2)
+--R                    3           2  4              2          2   2         2
+--R           (- 225A c  + 585B b c )x  + (- 450A b c  + 1170B b c)x  - 225A b c
+--R         + 
+--R                 3
+--R           585B b
+--R      *
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  3           2  4            2          2   2         2
+--R           (225A c  - 585B b c )x  + (450A b c  - 1170B b c)x  + 225A b c
+--R         + 
+--R                   3
+--R           - 585B b
+--R      *
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    3            2  4              2          2   2         2
+--R           (- 450A c  + 1170B b c )x  + (- 900A b c  + 2340B b c)x  - 450A b c
+--R         + 
+--R                  3
+--R           1170B b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|c \|x  + \|b
+--R         \|b atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R                    3            2  4              2          2   2         2
+--R           (- 450A c  + 1170B b c )x  + (- 900A b c  + 2340B b c)x  - 450A b c
+--R         + 
+--R                  3
+--R           1170B b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|c \|x  - \|b
+--R         \|b atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R                 3 6          3            2  4             2          2   2
+--R           128B c x  + (640A c  - 1664B b c )x  + (1620A b c  - 4212B b c)x
+--R         + 
+--R                 2           3
+--R           900A b c - 2340B b
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|c \|x
+--R  /
+--R          6 4         5 2       2 4  +-+4+-+
+--R     (320c x  + 640b c x  + 320b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1356
+
+--S 1357 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               6 4         5 2      2 4
+--R         (- 80c x  - 160b c x  - 80b c )
+--R      *
+--R         ROOT
+--R                          4   4            3   2 3             2 2 3 2
+--R                - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R              + 
+--R                            3 4              4 5
+--R                288290340A B b c - 187388721B b
+--R           /
+--R                       17
+--R              16777216c
+--R        ,
+--R            4
+--R      *
+--R         log
+--R                               +-+
+--R              (45A c - 117B b)\|x
+--R            + 
+--R                   4
+--R                64c
+--R             *
+--R                ROOT
+--R                                 4   4            3   2 3             2 2 3 2
+--R                       - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R                     + 
+--R                                   3 4              4 5
+--R                       288290340A B b c - 187388721B b
+--R                  /
+--R                              17
+--R                     16777216c
+--R               ,
+--R                   4
+--R     + 
+--R             6 4         5 2      2 4
+--R         (80c x  + 160b c x  + 80b c )
+--R      *
+--R         ROOT
+--R                          4   4            3   2 3             2 2 3 2
+--R                - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R              + 
+--R                            3 4              4 5
+--R                288290340A B b c - 187388721B b
+--R           /
+--R                       17
+--R              16777216c
+--R        ,
+--R            4
+--R      *
+--R         log
+--R                               +-+
+--R              (45A c - 117B b)\|x
+--R            + 
+--R              -
+--R                      4
+--R                   64c
+--R                *
+--R                   ROOT
+--R                                    4   4            3   2 3             2 2 3 2
+--R                          - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R                        + 
+--R                                      3 4              4 5
+--R                          288290340A B b c - 187388721B b
+--R                     /
+--R                                 17
+--R                        16777216c
+--R                  ,
+--R                      4
+--R     + 
+--R              6 4         5 2       2 4
+--R         (160c x  + 320b c x  + 160b c )
+--R      *
+--R         ROOT
+--R                          4   4            3   2 3             2 2 3 2
+--R                - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R              + 
+--R                            3 4              4 5
+--R                288290340A B b c - 187388721B b
+--R           /
+--R                       17
+--R              16777216c
+--R        ,
+--R            4
+--R      *
+--R         atan
+--R                   4
+--R                64c
+--R             *
+--R                ROOT
+--R                                 4   4            3   2 3             2 2 3 2
+--R                       - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R                     + 
+--R                                   3 4              4 5
+--R                       288290340A B b c - 187388721B b
+--R                  /
+--R                              17
+--R                     16777216c
+--R               ,
+--R                   4
+--R           /
+--R                               +-+
+--R              (45A c - 117B b)\|x
+--R     + 
+--R                3 6          3           2  4            2          2   2
+--R           32B c x  + (160A c  - 416B b c )x  + (405A b c  - 1053B b c)x
+--R         + 
+--R                 2          3
+--R           225A b c - 585B b
+--R      *
+--R          +-+
+--R         \|x
+--R  /
+--R        6 4         5 2      2 4
+--R     80c x  + 160b c x  + 80b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1357
+
+--S 1358 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45A c - 117B b)\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R               4 +-+
+--R            64c \|2
+--R         *
+--R            ROOT
+--R                             4   4            3   2 3             2 2 3 2
+--R                   - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R                 + 
+--R                               3 4              4 5
+--R                   288290340A B b c - 187388721B b
+--R              /
+--R                          17
+--R                 16777216c
+--R           ,
+--R               4
+--R         *
+--R            4+-+
+--R            \|c
+--R         *
+--R            log
+--R                                  +-+
+--R                 (45A c - 117B b)\|x
+--R               + 
+--R                      4
+--R                   64c
+--R                *
+--R                   ROOT
+--R                                    4   4            3   2 3             2 2 3 2
+--R                          - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R                        + 
+--R                                      3 4              4 5
+--R                          288290340A B b c - 187388721B b
+--R                     /
+--R                                 17
+--R                        16777216c
+--R                  ,
+--R                      4
+--R     + 
+--R            4 +-+
+--R         64c \|2
+--R      *
+--R         ROOT
+--R                          4   4            3   2 3             2 2 3 2
+--R                - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R              + 
+--R                            3 4              4 5
+--R                288290340A B b c - 187388721B b
+--R           /
+--R                       17
+--R              16777216c
+--R        ,
+--R            4
+--R      *
+--R         4+-+
+--R         \|c
+--R      *
+--R         log
+--R                               +-+
+--R              (45A c - 117B b)\|x
+--R            + 
+--R              -
+--R                      4
+--R                   64c
+--R                *
+--R                   ROOT
+--R                                    4   4            3   2 3             2 2 3 2
+--R                          - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R                        + 
+--R                                      3 4              4 5
+--R                          288290340A B b c - 187388721B b
+--R                     /
+--R                                 17
+--R                        16777216c
+--R                  ,
+--R                      4
+--R     + 
+--R                         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45A c + 117B b)\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R                       4+-+     \|2 \|c \|x  + \|b
+--R       (90A c - 234B b)\|b atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R                       4+-+     \|2 \|c \|x  - \|b
+--R       (90A c - 234B b)\|b atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R             4 +-+
+--R         128c \|2
+--R      *
+--R         ROOT
+--R                          4   4            3   2 3             2 2 3 2
+--R                - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R              + 
+--R                            3 4              4 5
+--R                288290340A B b c - 187388721B b
+--R           /
+--R                       17
+--R              16777216c
+--R        ,
+--R            4
+--R      *
+--R         4+-+
+--R         \|c
+--R      *
+--R         atan
+--R                   4
+--R                64c
+--R             *
+--R                ROOT
+--R                                 4   4            3   2 3             2 2 3 2
+--R                       - 4100625A b c  + 42646500A B b c  - 166321350A B b c
+--R                     + 
+--R                                   3 4              4 5
+--R                       288290340A B b c - 187388721B b
+--R                  /
+--R                              17
+--R                     16777216c
+--R               ,
+--R                   4
+--R           /
+--R                               +-+
+--R              (45A c - 117B b)\|x
+--R  /
+--R        4 +-+4+-+
+--R     64c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 1358
+
+--S 1359 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                        2             3                      2   4+-+2
+--R               ((- 45A c  + 117B b c)x  + (- 45A b c + 117B b )x)\|b
+--R             + 
+--R                                  2   +-+
+--R               (- 90A b c + 234B b )x\|b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                  2             2                   2  +-+4+-+2
+--R           ((45A c  - 117B b c)x  + 45A b c - 117B b )\|b \|b
+--R         + 
+--R                      2         2   2        2          3
+--R           (- 135A b c  + 351B b c)x  - 45A b c + 117B b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R             2             2 +-+4+-+2 +-+
+--R       (90A c  - 234B b c)x \|b \|b  \|c
+--R     + 
+--R              3           2  3            2         2    4+-+2
+--R       ((45A c  - 117B b c )x  + (135A b c  - 351B b c)x)\|b
+--R  /
+--R               5 3         4   +-+ +-+      6 4         5 2      2 4 4+-+2
+--R         ((128c x  + 128b c x)\|b \|c  + 64c x  + 128b c x  + 64b c )\|c
+--R       + 
+--R                6 3         5  4+-+2
+--R         (- 128c x  - 128b c x)\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1359
+
+)clear all
+
+--S 1360 of 3139
+t0:=x^(21/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                  6      4  +-+
+--R              (B x  + A x )\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1360
+
+--S 1361 of 3139
+r0:=7/48*(11*b*B-3*A*c)*x^(3/2)/(b*c^3)-1/4*(b*B-A*c)*x^(11/2)/(b*c*_
+   (b+c*x^2)^2)-1/16*(11*b*B-3*A*c)*x^(7/2)/(b*c^2*(b+c*x^2))+_
+   7/32*(11*b*B-3*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(1/4)*_
+   c^(15/4)*sqrt(2))-7/32*(11*b*B-3*A*c)*atan(1+c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(1/4)*c^(15/4)*sqrt(2))-7/64*(11*b*B-3*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*_
+   c^(15/4)*sqrt(2))+7/64*(11*b*B-3*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*c^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   3           2  4              2         2   2        2
+--R           (- 63A c  + 231B b c )x  + (- 126A b c  + 462B b c)x  - 63A b c
+--R         + 
+--R                 3
+--R           231B b
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                3           2  4            2         2   2        2          3
+--R         ((63A c  - 231B b c )x  + (126A b c  - 462B b c)x  + 63A b c - 231B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    3           2  4            2         2   2         2
+--R             (126A c  - 462B b c )x  + (252A b c  - 924B b c)x  + 126A b c
+--R           + 
+--R                     3
+--R             - 462B b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                    3           2  4            2         2   2         2
+--R             (126A c  - 462B b c )x  + (252A b c  - 924B b c)x  + 126A b c
+--R           + 
+--R                     3
+--R             - 462B b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                2 5            2             3                      2    +-+4+-+
+--R         (128B c x  + (- 132A c  + 484B b c)x  + (- 84A b c + 308B b )x)\|2 \|b
+--R      *
+--R         4+-+3 +-+
+--R         \|c  \|x
+--R  /
+--R          5 4         4 2       2 3  +-+4+-+4+-+3
+--R     (192c x  + 384b c x  + 192b c )\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1361
+
+--S 1362 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 4        4 2      2 3
+--R         (48c x  + 96b c x  + 48b c )
+--R      *
+--R         ROOT
+--R                         4 4           3     3            2 2 2 2
+--R                - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R              + 
+--R                           3 3             4 4
+--R                38348772A B b c - 35153041B b
+--R           /
+--R                         15
+--R              16777216b c
+--R        ,
+--R            4
+--R      *
+--R         log
+--R                    3 3          2     2            2 2           3 3  +-+
+--R              (9261A c  - 101871A B b c  + 373527A B b c - 456533B b )\|x
+--R            + 
+--R                         11
+--R                262144b c
+--R             *
+--R                  ROOT
+--R                                  4 4           3     3            2 2 2 2
+--R                         - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R                       + 
+--R                                    3 3             4 4
+--R                         38348772A B b c - 35153041B b
+--R                    /
+--R                                  15
+--R                       16777216b c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R               5 4        4 2      2 3
+--R         (- 48c x  - 96b c x  - 48b c )
+--R      *
+--R         ROOT
+--R                         4 4           3     3            2 2 2 2
+--R                - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R              + 
+--R                           3 3             4 4
+--R                38348772A B b c - 35153041B b
+--R           /
+--R                         15
+--R              16777216b c
+--R        ,
+--R            4
+--R      *
+--R         log
+--R                    3 3          2     2            2 2           3 3  +-+
+--R              (9261A c  - 101871A B b c  + 373527A B b c - 456533B b )\|x
+--R            + 
+--R              -
+--R                            11
+--R                   262144b c
+--R                *
+--R                     ROOT
+--R                                     4 4           3     3            2 2 2 2
+--R                            - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R                          + 
+--R                                       3 3             4 4
+--R                            38348772A B b c - 35153041B b
+--R                       /
+--R                                     15
+--R                          16777216b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R             5 4         4 2      2 3
+--R         (96c x  + 192b c x  + 96b c )
+--R      *
+--R         ROOT
+--R                         4 4           3     3            2 2 2 2
+--R                - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R              + 
+--R                           3 3             4 4
+--R                38348772A B b c - 35153041B b
+--R           /
+--R                         15
+--R              16777216b c
+--R        ,
+--R            4
+--R      *
+--R         atan
+--R                         11
+--R                262144b c
+--R             *
+--R                  ROOT
+--R                                  4 4           3     3            2 2 2 2
+--R                         - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R                       + 
+--R                                    3 3             4 4
+--R                         38348772A B b c - 35153041B b
+--R                    /
+--R                                  15
+--R                       16777216b c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                    3 3          2     2            2 2           3 3  +-+
+--R              (9261A c  - 101871A B b c  + 373527A B b c - 456533B b )\|x
+--R     + 
+--R             2 5           2             3                     2    +-+
+--R       (32B c x  + (- 33A c  + 121B b c)x  + (- 21A b c + 77B b )x)\|x
+--R  /
+--R        5 4        4 2      2 3
+--R     48c x  + 96b c x  + 48b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1362
+
+--S 1363 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21A c - 77B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            3 +-+
+--R         64c \|2
+--R      *
+--R         ROOT
+--R                         4 4           3     3            2 2 2 2
+--R                - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R              + 
+--R                           3 3             4 4
+--R                38348772A B b c - 35153041B b
+--R           /
+--R                         15
+--R              16777216b c
+--R        ,
+--R            4
+--R      *
+--R         4+-+4+-+3
+--R         \|b \|c
+--R      *
+--R         log
+--R                    3 3          2     2            2 2           3 3  +-+
+--R              (9261A c  - 101871A B b c  + 373527A B b c - 456533B b )\|x
+--R            + 
+--R                         11
+--R                262144b c
+--R             *
+--R                  ROOT
+--R                                  4 4           3     3            2 2 2 2
+--R                         - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R                       + 
+--R                                    3 3             4 4
+--R                         38348772A B b c - 35153041B b
+--R                    /
+--R                                  15
+--R                       16777216b c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R       -
+--R               3 +-+
+--R            64c \|2
+--R         *
+--R            ROOT
+--R                            4 4           3     3            2 2 2 2
+--R                   - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R                 + 
+--R                              3 3             4 4
+--R                   38348772A B b c - 35153041B b
+--R              /
+--R                            15
+--R                 16777216b c
+--R           ,
+--R               4
+--R         *
+--R            4+-+4+-+3
+--R            \|b \|c
+--R         *
+--R            log
+--R                       3 3          2     2            2 2           3 3  +-+
+--R                 (9261A c  - 101871A B b c  + 373527A B b c - 456533B b )\|x
+--R               + 
+--R                 -
+--R                               11
+--R                      262144b c
+--R                   *
+--R                        ROOT
+--R                                        4 4           3     3            2 2 2 2
+--R                               - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R                             + 
+--R                                          3 3             4 4
+--R                               38348772A B b c - 35153041B b
+--R                          /
+--R                                        15
+--R                             16777216b c
+--R                       ,
+--R                           4
+--R                     **
+--R                        3
+--R     + 
+--R                               +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21A c + 77B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R                              \|2 \|c \|x  + \|b
+--R       (- 42A c + 154B b)atan(-------------------)
+--R                                      4+-+
+--R                                      \|b
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R                              \|2 \|c \|x  - \|b
+--R       (- 42A c + 154B b)atan(-------------------)
+--R                                      4+-+
+--R                                      \|b
+--R     + 
+--R             3 +-+
+--R         128c \|2
+--R      *
+--R         ROOT
+--R                         4 4           3     3            2 2 2 2
+--R                - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R              + 
+--R                           3 3             4 4
+--R                38348772A B b c - 35153041B b
+--R           /
+--R                         15
+--R              16777216b c
+--R        ,
+--R            4
+--R      *
+--R         4+-+4+-+3
+--R         \|b \|c
+--R      *
+--R         atan
+--R                         11
+--R                262144b c
+--R             *
+--R                  ROOT
+--R                                  4 4           3     3            2 2 2 2
+--R                         - 194481A c  + 2852388A B b c  - 15688134A B b c
+--R                       + 
+--R                                    3 3             4 4
+--R                         38348772A B b c - 35153041B b
+--R                    /
+--R                                  15
+--R                       16777216b c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                    3 3          2     2            2 2           3 3  +-+
+--R              (9261A c  - 101871A B b c  + 373527A B b c - 456533B b )\|x
+--R  /
+--R        3 +-+4+-+4+-+3
+--R     64c \|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1363
+
+--S 1364 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                            2 +-+4+-+2 +-+
+--R           (42A c - 154B b)x \|b \|b  \|c
+--R         + 
+--R                  2            3                    2   4+-+2
+--R           ((21A c  - 77B b c)x  + (63A b c - 231B b )x)\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                    2            3                     2   4+-+2
+--R           ((- 21A c  + 77B b c)x  + (- 21A b c + 77B b )x)\|b
+--R         + 
+--R                              2   +-+
+--R           (- 42A b c + 154B b )x\|b
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R              2            2                  2  +-+4+-+2
+--R       ((21A c  - 77B b c)x  + 21A b c - 77B b )\|b \|b
+--R     + 
+--R                 2         2   2        2         3
+--R       (- 63A b c  + 231B b c)x  - 21A b c + 77B b
+--R  /
+--R                  4 3         3   +-+4+-+2 +-+
+--R             (128c x  + 128b c x)\|b \|b  \|c
+--R           + 
+--R                 5 4         4 2      2 3 4+-+2
+--R             (64c x  + 128b c x  + 64b c )\|b
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R                 5 3       2 4
+--R         - 128b c x  - 128b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1364
+
+)clear all
+
+--S 1365 of 3139
+t0:=x^(19/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                  5      3  +-+
+--R              (B x  + A x )\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1365
+
+--S 1366 of 3139
+r0:=-1/4*(b*B-A*c)*x^(9/2)/(b*c*(b+c*x^2)^2)-1/16*(9*b*B-A*c)*x^(5/2)/_
+   (b*c^2*(b+c*x^2))+5/32*(9*b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(3/4)*c^(13/4)*sqrt(2))-5/32*(9*b*B-A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(13/4)*sqrt(2))+5/64*(9*b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*_
+   c^(13/4)*sqrt(2))-5/64*(9*b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*c^(13/4)*sqrt(2))+5/16*(9*b*B-A*c)*_
+   sqrt(x)/(b*c^3)
+--R 
+--R
+--R   (2)
+--R               3          2  4           2        2   2       2         3
+--R         ((5A c  - 45B b c )x  + (10A b c  - 90B b c)x  + 5A b c - 45B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 3          2  4             2        2   2       2         3
+--R         ((- 5A c  + 45B b c )x  + (- 10A b c  + 90B b c)x  - 5A b c + 45B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                3          2  4           2         2   2        2         3
+--R         ((10A c  - 90B b c )x  + (20A b c  - 180B b c)x  + 10A b c - 90B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                3          2  4           2         2   2        2         3
+--R         ((10A c  - 90B b c )x  + (20A b c  - 180B b c)x  + 10A b c - 90B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R            2 4           2             2                   2  +-+4+-+3 4+-+ +-+
+--R     (128B c x  + (- 36A c  + 324B b c)x  - 20A b c + 180B b )\|2 \|b   \|c \|x
+--R  /
+--R         5 4         4 2      2 3  +-+4+-+3 4+-+
+--R     (64c x  + 128b c x  + 64b c )\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1366
+
+--S 1367 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 4        4 2      2 3
+--R         (16c x  + 32b c x  + 16b c )
+--R      *
+--R         ROOT
+--R                      4 4         3     3          2 2 2 2             3 3
+--R                - 625A c  + 22500A B b c  - 303750A B b c  + 1822500A B b c
+--R              + 
+--R                          4 4
+--R                - 4100625B b
+--R           /
+--R                       3 13
+--R              16777216b c
+--R        ,
+--R            4
+--R      *
+--R         log
+--R                             +-+
+--R              (5A c - 45B b)\|x
+--R            + 
+--R                     3
+--R                64b c
+--R             *
+--R                ROOT
+--R                             4 4         3     3          2 2 2 2
+--R                       - 625A c  + 22500A B b c  - 303750A B b c
+--R                     + 
+--R                                 3 3            4 4
+--R                       1822500A B b c - 4100625B b
+--R                  /
+--R                              3 13
+--R                     16777216b c
+--R               ,
+--R                   4
+--R     + 
+--R               5 4        4 2      2 3
+--R         (- 16c x  - 32b c x  - 16b c )
+--R      *
+--R         ROOT
+--R                      4 4         3     3          2 2 2 2             3 3
+--R                - 625A c  + 22500A B b c  - 303750A B b c  + 1822500A B b c
+--R              + 
+--R                          4 4
+--R                - 4100625B b
+--R           /
+--R                       3 13
+--R              16777216b c
+--R        ,
+--R            4
+--R      *
+--R         log
+--R                             +-+
+--R              (5A c - 45B b)\|x
+--R            + 
+--R              -
+--R                        3
+--R                   64b c
+--R                *
+--R                   ROOT
+--R                                4 4         3     3          2 2 2 2
+--R                          - 625A c  + 22500A B b c  - 303750A B b c
+--R                        + 
+--R                                    3 3            4 4
+--R                          1822500A B b c - 4100625B b
+--R                     /
+--R                                 3 13
+--R                        16777216b c
+--R                  ,
+--R                      4
+--R     + 
+--R               5 4        4 2      2 3
+--R         (- 32c x  - 64b c x  - 32b c )
+--R      *
+--R         ROOT
+--R                      4 4         3     3          2 2 2 2             3 3
+--R                - 625A c  + 22500A B b c  - 303750A B b c  + 1822500A B b c
+--R              + 
+--R                          4 4
+--R                - 4100625B b
+--R           /
+--R                       3 13
+--R              16777216b c
+--R        ,
+--R            4
+--R      *
+--R         atan
+--R                     3
+--R                64b c
+--R             *
+--R                ROOT
+--R                             4 4         3     3          2 2 2 2
+--R                       - 625A c  + 22500A B b c  - 303750A B b c
+--R                     + 
+--R                                 3 3            4 4
+--R                       1822500A B b c - 4100625B b
+--R                  /
+--R                              3 13
+--R                     16777216b c
+--R               ,
+--R                   4
+--R           /
+--R                             +-+
+--R              (5A c - 45B b)\|x
+--R     + 
+--R             2 4          2            2                 2  +-+
+--R       (32B c x  + (- 9A c  + 81B b c)x  - 5A b c + 45B b )\|x
+--R  /
+--R        5 4        4 2      2 3
+--R     16c x  + 32b c x  + 16b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1367
+
+--S 1368 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5A c + 45B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            3 +-+
+--R         64c \|2
+--R      *
+--R         ROOT
+--R                      4 4         3     3          2 2 2 2             3 3
+--R                - 625A c  + 22500A B b c  - 303750A B b c  + 1822500A B b c
+--R              + 
+--R                          4 4
+--R                - 4100625B b
+--R           /
+--R                       3 13
+--R              16777216b c
+--R        ,
+--R            4
+--R      *
+--R         4+-+3 4+-+
+--R         \|b   \|c
+--R      *
+--R         log
+--R                             +-+
+--R              (5A c - 45B b)\|x
+--R            + 
+--R                     3
+--R                64b c
+--R             *
+--R                ROOT
+--R                             4 4         3     3          2 2 2 2
+--R                       - 625A c  + 22500A B b c  - 303750A B b c
+--R                     + 
+--R                                 3 3            4 4
+--R                       1822500A B b c - 4100625B b
+--R                  /
+--R                              3 13
+--R                     16777216b c
+--R               ,
+--R                   4
+--R     + 
+--R       -
+--R               3 +-+
+--R            64c \|2
+--R         *
+--R            ROOT
+--R                         4 4         3     3          2 2 2 2             3 3
+--R                   - 625A c  + 22500A B b c  - 303750A B b c  + 1822500A B b c
+--R                 + 
+--R                             4 4
+--R                   - 4100625B b
+--R              /
+--R                          3 13
+--R                 16777216b c
+--R           ,
+--R               4
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R            log
+--R                                +-+
+--R                 (5A c - 45B b)\|x
+--R               + 
+--R                 -
+--R                           3
+--R                      64b c
+--R                   *
+--R                      ROOT
+--R                                   4 4         3     3          2 2 2 2
+--R                             - 625A c  + 22500A B b c  - 303750A B b c
+--R                           + 
+--R                                       3 3            4 4
+--R                             1822500A B b c - 4100625B b
+--R                        /
+--R                                    3 13
+--R                           16777216b c
+--R                     ,
+--R                         4
+--R     + 
+--R                            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5A c - 45B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                              +-+4+-+ +-+   4+-+
+--R                             \|2 \|c \|x  + \|b
+--R       (- 10A c + 90B b)atan(-------------------)
+--R                                     4+-+
+--R                                     \|b
+--R     + 
+--R                              +-+4+-+ +-+   4+-+
+--R                             \|2 \|c \|x  - \|b
+--R       (- 10A c + 90B b)atan(-------------------)
+--R                                     4+-+
+--R                                     \|b
+--R     + 
+--R       -
+--R                3 +-+
+--R            128c \|2
+--R         *
+--R            ROOT
+--R                         4 4         3     3          2 2 2 2             3 3
+--R                   - 625A c  + 22500A B b c  - 303750A B b c  + 1822500A B b c
+--R                 + 
+--R                             4 4
+--R                   - 4100625B b
+--R              /
+--R                          3 13
+--R                 16777216b c
+--R           ,
+--R               4
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R            atan
+--R                        3
+--R                   64b c
+--R                *
+--R                   ROOT
+--R                                4 4         3     3          2 2 2 2
+--R                          - 625A c  + 22500A B b c  - 303750A B b c
+--R                        + 
+--R                                    3 3            4 4
+--R                          1822500A B b c - 4100625B b
+--R                     /
+--R                                 3 13
+--R                        16777216b c
+--R                  ,
+--R                      4
+--R              /
+--R                                +-+
+--R                 (5A c - 45B b)\|x
+--R  /
+--R        3 +-+4+-+3 4+-+
+--R     64c \|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1368
+
+--S 1369 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                +-+4+-+2        2            3
+--R               (10A c - 90B b)x\|b \|b   + (5A c  - 45B b c)x
+--R             + 
+--R                              2
+--R               (5A b c - 45B b )x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                  2             2                 2 4+-+2
+--R           ((15A c  - 135B b c)x  + 5A b c - 45B b )\|b
+--R         + 
+--R                   2            2                 2  +-+
+--R           ((- 5A c  + 45B b c)x  - 5A b c + 45B b )\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R               2            2 +-+ +-+          3          2  3
+--R       (- 10A c  + 90B b c)x \|b \|c  + (- 5A c  + 45B b c )x
+--R     + 
+--R                 2         2
+--R       (- 15A b c  + 135B b c)x
+--R  /
+--R                  4 3         3   +-+4+-+2 +-+
+--R             (128c x  + 128b c x)\|b \|b  \|c
+--R           + 
+--R                 5 4         4 2      2 3 4+-+2
+--R             (64c x  + 128b c x  + 64b c )\|b
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R                 5 3       2 4
+--R         - 128b c x  - 128b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1369
+
+)clear all
+
+--S 1370 of 3139
+t0:=x^(17/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                  4      2  +-+
+--R              (B x  + A x )\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1370
+
+--S 1371 of 3139
+r0:=-1/4*(b*B-A*c)*x^(7/2)/(b*c*(b+c*x^2)^2)-1/16*(7*b*B+A*c)*x^(3/2)/_
+   (b*c^2*(b+c*x^2))-3/32*(7*b*B+A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(5/4)*c^(11/4)*sqrt(2))+3/32*(7*b*B+A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*c^(11/4)*sqrt(2))+3/64*(7*b*B+A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*_
+   c^(11/4)*sqrt(2))-3/64*(7*b*B+A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*c^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 3          2  4            2        2   2       2         3
+--R         ((- 3A c  - 21B b c )x  + (- 6A b c  - 42B b c)x  - 3A b c - 21B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               3          2  4          2        2   2       2         3
+--R         ((3A c  + 21B b c )x  + (6A b c  + 42B b c)x  + 3A b c + 21B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               3          2  4           2        2   2       2         3
+--R         ((6A c  + 42B b c )x  + (12A b c  + 84B b c)x  + 6A b c + 42B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R               3          2  4           2        2   2       2         3
+--R         ((6A c  + 42B b c )x  + (12A b c  + 84B b c)x  + 6A b c + 42B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R              2            3                    2    +-+4+-+4+-+3 +-+
+--R       ((12A c  - 44B b c)x  + (- 4A b c - 28B b )x)\|2 \|b \|c  \|x
+--R  /
+--R           4 4       2 3 2      3 2  +-+4+-+4+-+3
+--R     (64b c x  + 128b c x  + 64b c )\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1371
+
+--S 1372 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 4      2 3 2      3 2
+--R         (16b c x  + 32b c x  + 16b c )
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |     4 4        3     3         2 2 2 2            3 3           4 4
+--R          |- 81A c  - 2268A B b c  - 23814A B b c  - 111132A B b c - 194481B b
+--R          |--------------------------------------------------------------------
+--R         4|                                     5 11
+--R         \|                            16777216b c
+--R      *
+--R         log
+--R                  3 3       2     2          2 2         3 3  +-+
+--R              (27A c  + 567A B b c  + 3969A B b c + 9261B b )\|x
+--R            + 
+--R                       4 8
+--R                262144b c
+--R             *
+--R                  ROOT
+--R                              4 4        3     3         2 2 2 2            3 3
+--R                         - 81A c  - 2268A B b c  - 23814A B b c  - 111132A B b c
+--R                       + 
+--R                                  4 4
+--R                         - 194481B b
+--R                    /
+--R                                5 11
+--R                       16777216b c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R                 4 4      2 3 2      3 2
+--R         (- 16b c x  - 32b c x  - 16b c )
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |     4 4        3     3         2 2 2 2            3 3           4 4
+--R          |- 81A c  - 2268A B b c  - 23814A B b c  - 111132A B b c - 194481B b
+--R          |--------------------------------------------------------------------
+--R         4|                                     5 11
+--R         \|                            16777216b c
+--R      *
+--R         log
+--R                  3 3       2     2          2 2         3 3  +-+
+--R              (27A c  + 567A B b c  + 3969A B b c + 9261B b )\|x
+--R            + 
+--R              -
+--R                          4 8
+--R                   262144b c
+--R                *
+--R                     ROOT
+--R                                 4 4        3     3         2 2 2 2
+--R                            - 81A c  - 2268A B b c  - 23814A B b c
+--R                          + 
+--R                                       3 3           4 4
+--R                            - 111132A B b c - 194481B b
+--R                       /
+--R                                   5 11
+--R                          16777216b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R               4 4      2 3 2      3 2
+--R         (32b c x  + 64b c x  + 32b c )
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |     4 4        3     3         2 2 2 2            3 3           4 4
+--R          |- 81A c  - 2268A B b c  - 23814A B b c  - 111132A B b c - 194481B b
+--R          |--------------------------------------------------------------------
+--R         4|                                     5 11
+--R         \|                            16777216b c
+--R      *
+--R         atan
+--R                       4 8
+--R                262144b c
+--R             *
+--R                  ROOT
+--R                              4 4        3     3         2 2 2 2            3 3
+--R                         - 81A c  - 2268A B b c  - 23814A B b c  - 111132A B b c
+--R                       + 
+--R                                  4 4
+--R                         - 194481B b
+--R                    /
+--R                                5 11
+--R                       16777216b c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                  3 3       2     2          2 2         3 3  +-+
+--R              (27A c  + 567A B b c  + 3969A B b c + 9261B b )\|x
+--R     + 
+--R             2            3                  2    +-+
+--R       ((3A c  - 11B b c)x  + (- A b c - 7B b )x)\|x
+--R  /
+--R          4 4      2 3 2      3 2
+--R     16b c x  + 32b c x  + 16b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1372
+
+--S 1373 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3A c + 21B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              2 +-+
+--R         64b c \|2
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |     4 4        3     3         2 2 2 2            3 3           4 4
+--R          |- 81A c  - 2268A B b c  - 23814A B b c  - 111132A B b c - 194481B b
+--R          |--------------------------------------------------------------------
+--R         4|                                     5 11
+--R         \|                            16777216b c
+--R      *
+--R         4+-+4+-+3
+--R         \|b \|c
+--R      *
+--R         log
+--R                  3 3       2     2          2 2         3 3  +-+
+--R              (27A c  + 567A B b c  + 3969A B b c + 9261B b )\|x
+--R            + 
+--R                       4 8
+--R                262144b c
+--R             *
+--R                  ROOT
+--R                              4 4        3     3         2 2 2 2            3 3
+--R                         - 81A c  - 2268A B b c  - 23814A B b c  - 111132A B b c
+--R                       + 
+--R                                  4 4
+--R                         - 194481B b
+--R                    /
+--R                                5 11
+--R                       16777216b c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R       -
+--R                 2 +-+
+--R            64b c \|2
+--R         *
+--R            ROOT
+--R                        4 4        3     3         2 2 2 2            3 3
+--R                   - 81A c  - 2268A B b c  - 23814A B b c  - 111132A B b c
+--R                 + 
+--R                            4 4
+--R                   - 194481B b
+--R              /
+--R                          5 11
+--R                 16777216b c
+--R           ,
+--R               4
+--R         *
+--R            4+-+4+-+3
+--R            \|b \|c
+--R         *
+--R            log
+--R                     3 3       2     2          2 2         3 3  +-+
+--R                 (27A c  + 567A B b c  + 3969A B b c + 9261B b )\|x
+--R               + 
+--R                 -
+--R                             4 8
+--R                      262144b c
+--R                   *
+--R                        ROOT
+--R                                    4 4        3     3         2 2 2 2
+--R                               - 81A c  - 2268A B b c  - 23814A B b c
+--R                             + 
+--R                                          3 3           4 4
+--R                               - 111132A B b c - 194481B b
+--R                          /
+--R                                      5 11
+--R                             16777216b c
+--R                       ,
+--R                           4
+--R                     **
+--R                        3
+--R     + 
+--R                              +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3A c - 21B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  + \|b
+--R       (- 6A c - 42B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  - \|b
+--R       (- 6A c - 42B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R               2 +-+
+--R         128b c \|2
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |     4 4        3     3         2 2 2 2            3 3           4 4
+--R          |- 81A c  - 2268A B b c  - 23814A B b c  - 111132A B b c - 194481B b
+--R          |--------------------------------------------------------------------
+--R         4|                                     5 11
+--R         \|                            16777216b c
+--R      *
+--R         4+-+4+-+3
+--R         \|b \|c
+--R      *
+--R         atan
+--R                       4 8
+--R                262144b c
+--R             *
+--R                  ROOT
+--R                              4 4        3     3         2 2 2 2            3 3
+--R                         - 81A c  - 2268A B b c  - 23814A B b c  - 111132A B b c
+--R                       + 
+--R                                  4 4
+--R                         - 194481B b
+--R                    /
+--R                                5 11
+--R                       16777216b c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                  3 3       2     2          2 2         3 3  +-+
+--R              (27A c  + 567A B b c  + 3969A B b c + 9261B b )\|x
+--R  /
+--R          2 +-+4+-+4+-+3
+--R     64b c \|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1373
+
+--S 1374 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                          2 +-+4+-+2 +-+
+--R           (6A c + 42B b)x \|b \|b  \|c
+--R         + 
+--R                 2            3                  2   4+-+2
+--R           ((3A c  + 21B b c)x  + (9A b c + 63B b )x)\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                   2            3                    2   4+-+2
+--R           ((- 3A c  - 21B b c)x  + (- 3A b c - 21B b )x)\|b
+--R         + 
+--R                            2   +-+
+--R           (- 6A b c - 42B b )x\|b
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R             2            2                 2  +-+4+-+2
+--R       ((3A c  + 21B b c)x  + 3A b c + 21B b )\|b \|b
+--R     + 
+--R                2        2   2       2         3
+--R       (- 9A b c  - 63B b c)x  - 3A b c - 21B b
+--R  /
+--R                    3 3       2 2   +-+4+-+2 +-+
+--R             (128b c x  + 128b c x)\|b \|b  \|c
+--R           + 
+--R                   4 4       2 3 2      3 2 4+-+2
+--R             (64b c x  + 128b c x  + 64b c )\|b
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R               2 4 3       3 3
+--R         - 128b c x  - 128b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1374
+
+)clear all
+
+--S 1375 of 3139
+t0:=x^(15/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                   3        +-+
+--R               (B x  + A x)\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1375
+
+--S 1376 of 3139
+r0:=-1/4*(b*B-A*c)*x^(5/2)/(b*c*(b+c*x^2)^2)-1/32*(5*b*B+3*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(7/4)*c^(9/4)*sqrt(2))+_
+   1/32*(5*b*B+3*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(7/4)*_
+   c^(9/4)*sqrt(2))-1/64*(5*b*B+3*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*c^(9/4)*sqrt(2))+1/64*(5*b*B+3*A*c)*_
+   log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*_
+   c^(9/4)*sqrt(2))-1/16*(5*b*B+3*A*c)*sqrt(x)/(b*c^2*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R               3         2  4          2        2   2       2        3
+--R         ((3A c  + 5B b c )x  + (6A b c  + 10B b c)x  + 3A b c + 5B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 3         2  4            2        2   2       2        3
+--R         ((- 3A c  - 5B b c )x  + (- 6A b c  - 10B b c)x  - 3A b c - 5B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               3          2  4           2        2   2       2         3
+--R         ((6A c  + 10B b c )x  + (12A b c  + 20B b c)x  + 6A b c + 10B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R               3          2  4           2        2   2       2         3
+--R         ((6A c  + 10B b c )x  + (12A b c  + 20B b c)x  + 6A b c + 10B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R             2            2                  2  +-+4+-+3 4+-+ +-+
+--R       ((4A c  - 36B b c)x  - 12A b c - 20B b )\|2 \|b   \|c \|x
+--R  /
+--R           4 4       2 3 2      3 2  +-+4+-+3 4+-+
+--R     (64b c x  + 128b c x  + 64b c )\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1376
+
+--S 1377 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 4      2 3 2      3 2
+--R         (16b c x  + 32b c x  + 16b c )
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |     4 4       3     3        2 2 2 2          3 3        4 4
+--R          |- 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c - 625B b
+--R          |-------------------------------------------------------------
+--R         4|                                  7 9
+--R         \|                         16777216b c
+--R      *
+--R         log
+--R                            +-+
+--R              (3A c + 5B b)\|x
+--R            + 
+--R                   2 2
+--R                64b c
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |     4 4       3     3        2 2 2 2          3 3        4 4
+--R               |- 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c - 625B b
+--R               |-------------------------------------------------------------
+--R              4|                                  7 9
+--R              \|                         16777216b c
+--R     + 
+--R                 4 4      2 3 2      3 2
+--R         (- 16b c x  - 32b c x  - 16b c )
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |     4 4       3     3        2 2 2 2          3 3        4 4
+--R          |- 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c - 625B b
+--R          |-------------------------------------------------------------
+--R         4|                                  7 9
+--R         \|                         16777216b c
+--R      *
+--R         log
+--R                            +-+
+--R              (3A c + 5B b)\|x
+--R            + 
+--R              -
+--R                      2 2
+--R                   64b c
+--R                *
+--R                   ROOT
+--R                               4 4       3     3        2 2 2 2          3 3
+--R                          - 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c
+--R                        + 
+--R                                4 4
+--R                          - 625B b
+--R                     /
+--R                                 7 9
+--R                        16777216b c
+--R                  ,
+--R                      4
+--R     + 
+--R                 4 4      2 3 2      3 2
+--R         (- 32b c x  - 64b c x  - 32b c )
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |     4 4       3     3        2 2 2 2          3 3        4 4
+--R          |- 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c - 625B b
+--R          |-------------------------------------------------------------
+--R         4|                                  7 9
+--R         \|                         16777216b c
+--R      *
+--R         atan
+--R                   2 2
+--R                64b c
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |     4 4       3     3        2 2 2 2          3 3        4 4
+--R               |- 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c - 625B b
+--R               |-------------------------------------------------------------
+--R              4|                                  7 9
+--R              \|                         16777216b c
+--R           /
+--R                            +-+
+--R              (3A c + 5B b)\|x
+--R     + 
+--R            2           2                2  +-+
+--R       ((A c  - 9B b c)x  - 3A b c - 5B b )\|x
+--R  /
+--R          4 4      2 3 2      3 2
+--R     16b c x  + 32b c x  + 16b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1377
+
+--S 1378 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3A c - 5B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              2 +-+
+--R         64b c \|2
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |     4 4       3     3        2 2 2 2          3 3        4 4
+--R          |- 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c - 625B b  4+-+3
+--R          |------------------------------------------------------------- \|b
+--R         4|                                  7 9
+--R         \|                         16777216b c
+--R      *
+--R         4+-+
+--R         \|c
+--R      *
+--R         log
+--R                            +-+
+--R              (3A c + 5B b)\|x
+--R            + 
+--R                   2 2
+--R                64b c
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |     4 4       3     3        2 2 2 2          3 3        4 4
+--R               |- 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c - 625B b
+--R               |-------------------------------------------------------------
+--R              4|                                  7 9
+--R              \|                         16777216b c
+--R     + 
+--R       -
+--R                 2 +-+
+--R            64b c \|2
+--R         *
+--R             +-------------------------------------------------------------+
+--R             |     4 4       3     3        2 2 2 2          3 3        4 4
+--R             |- 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c - 625B b
+--R             |-------------------------------------------------------------
+--R            4|                                  7 9
+--R            \|                         16777216b c
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R            log
+--R                               +-+
+--R                 (3A c + 5B b)\|x
+--R               + 
+--R                 -
+--R                         2 2
+--R                      64b c
+--R                   *
+--R                      ROOT
+--R                                  4 4       3     3        2 2 2 2          3 3
+--R                             - 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c
+--R                           + 
+--R                                   4 4
+--R                             - 625B b
+--R                        /
+--R                                    7 9
+--R                           16777216b c
+--R                     ,
+--R                         4
+--R     + 
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3A c + 5B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  + \|b
+--R       (- 6A c - 10B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  - \|b
+--R       (- 6A c - 10B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R       -
+--R                  2 +-+
+--R            128b c \|2
+--R         *
+--R             +-------------------------------------------------------------+
+--R             |     4 4       3     3        2 2 2 2          3 3        4 4
+--R             |- 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c - 625B b
+--R             |-------------------------------------------------------------
+--R            4|                                  7 9
+--R            \|                         16777216b c
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R            atan
+--R                      2 2
+--R                   64b c
+--R                *
+--R                   ROOT
+--R                               4 4       3     3        2 2 2 2          3 3
+--R                          - 81A c  - 540A B b c  - 1350A B b c  - 1500A B b c
+--R                        + 
+--R                                4 4
+--R                          - 625B b
+--R                     /
+--R                                 7 9
+--R                        16777216b c
+--R                  ,
+--R                      4
+--R              /
+--R                               +-+
+--R                 (3A c + 5B b)\|x
+--R  /
+--R          2 +-+4+-+3 4+-+
+--R     64b c \|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1378
+
+--S 1379 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                              +-+4+-+2        2           3                 2
+--R             ((6A c + 10B b)x\|b \|b   + (3A c  + 5B b c)x  + (3A b c + 5B b )x)
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                 2            2                2 4+-+2
+--R           ((9A c  + 15B b c)x  + 3A b c + 5B b )\|b
+--R         + 
+--R                   2           2                2  +-+
+--R           ((- 3A c  - 5B b c)x  - 3A b c - 5B b )\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R              2            2 +-+ +-+          3         2  3
+--R       (- 6A c  - 10B b c)x \|b \|c  + (- 3A c  - 5B b c )x
+--R     + 
+--R                2        2
+--R       (- 9A b c  - 15B b c)x
+--R  /
+--R                    3 3       2 2   +-+4+-+2 +-+
+--R             (128b c x  + 128b c x)\|b \|b  \|c
+--R           + 
+--R                   4 4       2 3 2      3 2 4+-+2
+--R             (64b c x  + 128b c x  + 64b c )\|b
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R               2 4 3       3 3
+--R         - 128b c x  - 128b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1379
+
+)clear all
+
+--S 1380 of 3139
+t0:=x^(13/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    2      +-+
+--R                (B x  + A)\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 1380
+
+--S 1381 of 3139
+r0:=-1/4*(b*B-A*c)*x^(3/2)/(b*c*(b+c*x^2)^2)+1/16*(3*b*B+5*A*c)*x^(3/2)/_
+   (b^2*c*(b+c*x^2))-1/32*(3*b*B+5*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(9/4)*c^(7/4)*sqrt(2))+1/32*(3*b*B+5*A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(9/4)*c^(7/4)*sqrt(2))+1/64*(3*b*B+5*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*c^(7/4)*_
+   sqrt(2))-1/64*(3*b*B+5*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(9/4)*c^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 3         2  4             2       2   2       2        3
+--R         ((- 5A c  - 3B b c )x  + (- 10A b c  - 6B b c)x  - 5A b c - 3B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               3         2  4           2       2   2       2        3
+--R         ((5A c  + 3B b c )x  + (10A b c  + 6B b c)x  + 5A b c + 3B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                3         2  4           2        2   2        2        3
+--R         ((10A c  + 6B b c )x  + (20A b c  + 12B b c)x  + 10A b c + 6B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                3         2  4           2        2   2        2        3
+--R         ((10A c  + 6B b c )x  + (20A b c  + 12B b c)x  + 10A b c + 6B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R              2            3                  2    +-+4+-+4+-+3 +-+
+--R       ((20A c  + 12B b c)x  + (36A b c - 4B b )x)\|2 \|b \|c  \|x
+--R  /
+--R         2 3 4       3 2 2      4   +-+4+-+4+-+3
+--R     (64b c x  + 128b c x  + 64b c)\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1381
+
+--S 1382 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 3 4      3 2 2      4
+--R         (16b c x  + 32b c x  + 16b c)
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |      4 4        3     3        2 2 2 2         3 3       4 4
+--R          |- 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c - 81B b
+--R          |-------------------------------------------------------------
+--R         4|                                  9 7
+--R         \|                         16777216b c
+--R      *
+--R         log
+--R                   3 3       2     2         2 2       3 3  +-+
+--R              (125A c  + 225A B b c  + 135A B b c + 27B b )\|x
+--R            + 
+--R                       7 5
+--R                262144b c
+--R             *
+--R               +-------------------------------------------------------------+3
+--R               |      4 4        3     3        2 2 2 2         3 3       4 4
+--R               |- 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c - 81B b
+--R               |-------------------------------------------------------------
+--R              4|                                  9 7
+--R              \|                         16777216b c
+--R     + 
+--R               2 3 4      3 2 2      4
+--R         (- 16b c x  - 32b c x  - 16b c)
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |      4 4        3     3        2 2 2 2         3 3       4 4
+--R          |- 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c - 81B b
+--R          |-------------------------------------------------------------
+--R         4|                                  9 7
+--R         \|                         16777216b c
+--R      *
+--R         log
+--R                   3 3       2     2         2 2       3 3  +-+
+--R              (125A c  + 225A B b c  + 135A B b c + 27B b )\|x
+--R            + 
+--R              -
+--R                          7 5
+--R                   262144b c
+--R                *
+--R                     ROOT
+--R                                  4 4        3     3        2 2 2 2         3 3
+--R                            - 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c
+--R                          + 
+--R                                 4 4
+--R                            - 81B b
+--R                       /
+--R                                   9 7
+--R                          16777216b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R             2 3 4      3 2 2      4
+--R         (32b c x  + 64b c x  + 32b c)
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |      4 4        3     3        2 2 2 2         3 3       4 4
+--R          |- 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c - 81B b
+--R          |-------------------------------------------------------------
+--R         4|                                  9 7
+--R         \|                         16777216b c
+--R      *
+--R         atan
+--R                       7 5
+--R                262144b c
+--R             *
+--R               +-------------------------------------------------------------+3
+--R               |      4 4        3     3        2 2 2 2         3 3       4 4
+--R               |- 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c - 81B b
+--R               |-------------------------------------------------------------
+--R              4|                                  9 7
+--R              \|                         16777216b c
+--R           /
+--R                   3 3       2     2         2 2       3 3  +-+
+--R              (125A c  + 225A B b c  + 135A B b c + 27B b )\|x
+--R     + 
+--R             2           3                2    +-+
+--R       ((5A c  + 3B b c)x  + (9A b c - B b )x)\|x
+--R  /
+--R        2 3 4      3 2 2      4
+--R     16b c x  + 32b c x  + 16b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1382
+
+--S 1383 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5A c + 3B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            2  +-+
+--R         64b c\|2
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |      4 4        3     3        2 2 2 2         3 3       4 4
+--R          |- 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c - 81B b  4+-+
+--R          |------------------------------------------------------------- \|b
+--R         4|                                  9 7
+--R         \|                         16777216b c
+--R      *
+--R         4+-+3
+--R         \|c
+--R      *
+--R         log
+--R                   3 3       2     2         2 2       3 3  +-+
+--R              (125A c  + 225A B b c  + 135A B b c + 27B b )\|x
+--R            + 
+--R                       7 5
+--R                262144b c
+--R             *
+--R               +-------------------------------------------------------------+3
+--R               |      4 4        3     3        2 2 2 2         3 3       4 4
+--R               |- 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c - 81B b
+--R               |-------------------------------------------------------------
+--R              4|                                  9 7
+--R              \|                         16777216b c
+--R     + 
+--R       -
+--R               2  +-+
+--R            64b c\|2
+--R         *
+--R             +-------------------------------------------------------------+
+--R             |      4 4        3     3        2 2 2 2         3 3       4 4
+--R             |- 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c - 81B b  4+-+
+--R             |------------------------------------------------------------- \|b
+--R            4|                                  9 7
+--R            \|                         16777216b c
+--R         *
+--R            4+-+3
+--R            \|c
+--R         *
+--R            log
+--R                      3 3       2     2         2 2       3 3  +-+
+--R                 (125A c  + 225A B b c  + 135A B b c + 27B b )\|x
+--R               + 
+--R                 -
+--R                             7 5
+--R                      262144b c
+--R                   *
+--R                        ROOT
+--R                                     4 4        3     3        2 2 2 2
+--R                               - 625A c  - 1500A B b c  - 1350A B b c
+--R                             + 
+--R                                       3 3       4 4
+--R                               - 540A B b c - 81B b
+--R                          /
+--R                                      9 7
+--R                             16777216b c
+--R                       ,
+--R                           4
+--R                     **
+--R                        3
+--R     + 
+--R                             +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5A c - 3B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  + \|b
+--R       (- 10A c - 6B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  - \|b
+--R       (- 10A c - 6B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R             2  +-+
+--R         128b c\|2
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |      4 4        3     3        2 2 2 2         3 3       4 4
+--R          |- 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c - 81B b  4+-+
+--R          |------------------------------------------------------------- \|b
+--R         4|                                  9 7
+--R         \|                         16777216b c
+--R      *
+--R         4+-+3
+--R         \|c
+--R      *
+--R         atan
+--R                       7 5
+--R                262144b c
+--R             *
+--R               +-------------------------------------------------------------+3
+--R               |      4 4        3     3        2 2 2 2         3 3       4 4
+--R               |- 625A c  - 1500A B b c  - 1350A B b c  - 540A B b c - 81B b
+--R               |-------------------------------------------------------------
+--R              4|                                  9 7
+--R              \|                         16777216b c
+--R           /
+--R                   3 3       2     2         2 2       3 3  +-+
+--R              (125A c  + 225A B b c  + 135A B b c + 27B b )\|x
+--R  /
+--R        2  +-+4+-+4+-+3
+--R     64b c\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1383
+
+--S 1384 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                          2 +-+4+-+2 +-+
+--R           (10A c + 6B b)x \|b \|b  \|c
+--R         + 
+--R                 2           3                  2   4+-+2
+--R           ((5A c  + 3B b c)x  + (15A b c + 9B b )x)\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                   2           3                   2   4+-+2
+--R           ((- 5A c  - 3B b c)x  + (- 5A b c - 3B b )x)\|b
+--R         + 
+--R                            2   +-+
+--R           (- 10A b c - 6B b )x\|b
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R             2           2                2  +-+4+-+2             2       2   2
+--R       ((5A c  + 3B b c)x  + 5A b c + 3B b )\|b \|b   + (- 15A b c  - 9B b c)x
+--R     + 
+--R             2        3
+--R       - 5A b c - 3B b
+--R  /
+--R                  2 2 3       3     +-+4+-+2 +-+
+--R             (128b c x  + 128b c x)\|b \|b  \|c
+--R           + 
+--R                 2 3 4       3 2 2      4  4+-+2
+--R             (64b c x  + 128b c x  + 64b c)\|b
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R               3 3 3       4 2
+--R         - 128b c x  - 128b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1384
+
+)clear all
+
+--S 1385 of 3139
+t0:=x^(11/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    2      +-+
+--R                (B x  + A)\|x
+--R   (1)  ------------------------------
+--R         3 7       2 5     2   3    3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1385
+
+--S 1386 of 3139
+r0:=-3/32*(b*B+7*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*_
+   c^(5/4)*sqrt(2))+3/32*(b*B+7*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(11/4)*c^(5/4)*sqrt(2))-3/64*(b*B+7*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*c^(5/4)*sqrt(2))+_
+   3/64*(b*B+7*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(11/4)*c^(5/4)*sqrt(2))-1/4*(b*B-A*c)*sqrt(x)/(b*c*(b+_
+   c*x^2)^2)+1/16*(b*B+7*A*c)*sqrt(x)/(b^2*c*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R                3         2  4           2       2   2        2        3
+--R         ((21A c  + 3B b c )x  + (42A b c  + 6B b c)x  + 21A b c + 3B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  3         2  4             2       2   2        2        3
+--R         ((- 21A c  - 3B b c )x  + (- 42A b c  - 6B b c)x  - 21A b c - 3B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                3         2  4           2        2   2        2        3
+--R         ((42A c  + 6B b c )x  + (84A b c  + 12B b c)x  + 42A b c + 6B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                3         2  4           2        2   2        2        3
+--R         ((42A c  + 6B b c )x  + (84A b c  + 12B b c)x  + 42A b c + 6B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R              2           2                  2  +-+4+-+3 4+-+ +-+
+--R       ((28A c  + 4B b c)x  + 44A b c - 12B b )\|2 \|b   \|c \|x
+--R  /
+--R         2 3 4       3 2 2      4   +-+4+-+3 4+-+
+--R     (64b c x  + 128b c x  + 64b c)\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1386
+
+--S 1387 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 3 4      3 2 2      4
+--R         (16b c x  + 32b c x  + 16b c)
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |         4 4          3     3         2 2 2 2          3 3       4 4
+--R          |- 194481A c  - 111132A B b c  - 23814A B b c  - 2268A B b c - 81B b
+--R          |--------------------------------------------------------------------
+--R         4|                                     11 5
+--R         \|                            16777216b  c
+--R      *
+--R         log
+--R                             +-+
+--R              (21A c + 3B b)\|x
+--R            + 
+--R                   3
+--R                64b c
+--R             *
+--R                ROOT
+--R                                4 4          3     3         2 2 2 2
+--R                       - 194481A c  - 111132A B b c  - 23814A B b c
+--R                     + 
+--R                                3 3       4 4
+--R                       - 2268A B b c - 81B b
+--R                  /
+--R                              11 5
+--R                     16777216b  c
+--R               ,
+--R                   4
+--R     + 
+--R               2 3 4      3 2 2      4
+--R         (- 16b c x  - 32b c x  - 16b c)
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |         4 4          3     3         2 2 2 2          3 3       4 4
+--R          |- 194481A c  - 111132A B b c  - 23814A B b c  - 2268A B b c - 81B b
+--R          |--------------------------------------------------------------------
+--R         4|                                     11 5
+--R         \|                            16777216b  c
+--R      *
+--R         log
+--R                             +-+
+--R              (21A c + 3B b)\|x
+--R            + 
+--R              -
+--R                      3
+--R                   64b c
+--R                *
+--R                   ROOT
+--R                                   4 4          3     3         2 2 2 2
+--R                          - 194481A c  - 111132A B b c  - 23814A B b c
+--R                        + 
+--R                                   3 3       4 4
+--R                          - 2268A B b c - 81B b
+--R                     /
+--R                                 11 5
+--R                        16777216b  c
+--R                  ,
+--R                      4
+--R     + 
+--R               2 3 4      3 2 2      4
+--R         (- 32b c x  - 64b c x  - 32b c)
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |         4 4          3     3         2 2 2 2          3 3       4 4
+--R          |- 194481A c  - 111132A B b c  - 23814A B b c  - 2268A B b c - 81B b
+--R          |--------------------------------------------------------------------
+--R         4|                                     11 5
+--R         \|                            16777216b  c
+--R      *
+--R         atan
+--R                   3
+--R                64b c
+--R             *
+--R                ROOT
+--R                                4 4          3     3         2 2 2 2
+--R                       - 194481A c  - 111132A B b c  - 23814A B b c
+--R                     + 
+--R                                3 3       4 4
+--R                       - 2268A B b c - 81B b
+--R                  /
+--R                              11 5
+--R                     16777216b  c
+--R               ,
+--R                   4
+--R           /
+--R                             +-+
+--R              (21A c + 3B b)\|x
+--R     + 
+--R             2          2                 2  +-+
+--R       ((7A c  + B b c)x  + 11A b c - 3B b )\|x
+--R  /
+--R        2 3 4      3 2 2      4
+--R     16b c x  + 32b c x  + 16b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1387
+
+--S 1388 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21A c - 3B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            2  +-+
+--R         64b c\|2
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |         4 4          3     3         2 2 2 2          3 3       4 4
+--R          |- 194481A c  - 111132A B b c  - 23814A B b c  - 2268A B b c - 81B b
+--R          |--------------------------------------------------------------------
+--R         4|                                     11 5
+--R         \|                            16777216b  c
+--R      *
+--R         4+-+3 4+-+
+--R         \|b   \|c
+--R      *
+--R         log
+--R                             +-+
+--R              (21A c + 3B b)\|x
+--R            + 
+--R                   3
+--R                64b c
+--R             *
+--R                ROOT
+--R                                4 4          3     3         2 2 2 2
+--R                       - 194481A c  - 111132A B b c  - 23814A B b c
+--R                     + 
+--R                                3 3       4 4
+--R                       - 2268A B b c - 81B b
+--R                  /
+--R                              11 5
+--R                     16777216b  c
+--R               ,
+--R                   4
+--R     + 
+--R       -
+--R               2  +-+
+--R            64b c\|2
+--R         *
+--R            ROOT
+--R                            4 4          3     3         2 2 2 2          3 3
+--R                   - 194481A c  - 111132A B b c  - 23814A B b c  - 2268A B b c
+--R                 + 
+--R                        4 4
+--R                   - 81B b
+--R              /
+--R                          11 5
+--R                 16777216b  c
+--R           ,
+--R               4
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R            log
+--R                                +-+
+--R                 (21A c + 3B b)\|x
+--R               + 
+--R                 -
+--R                         3
+--R                      64b c
+--R                   *
+--R                      ROOT
+--R                                      4 4          3     3         2 2 2 2
+--R                             - 194481A c  - 111132A B b c  - 23814A B b c
+--R                           + 
+--R                                      3 3       4 4
+--R                             - 2268A B b c - 81B b
+--R                        /
+--R                                    11 5
+--R                           16777216b  c
+--R                     ,
+--R                         4
+--R     + 
+--R                            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21A c + 3B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  + \|b
+--R       (- 42A c - 6B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  - \|b
+--R       (- 42A c - 6B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R       -
+--R                2  +-+
+--R            128b c\|2
+--R         *
+--R            ROOT
+--R                            4 4          3     3         2 2 2 2          3 3
+--R                   - 194481A c  - 111132A B b c  - 23814A B b c  - 2268A B b c
+--R                 + 
+--R                        4 4
+--R                   - 81B b
+--R              /
+--R                          11 5
+--R                 16777216b  c
+--R           ,
+--R               4
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R            atan
+--R                      3
+--R                   64b c
+--R                *
+--R                   ROOT
+--R                                   4 4          3     3         2 2 2 2
+--R                          - 194481A c  - 111132A B b c  - 23814A B b c
+--R                        + 
+--R                                   3 3       4 4
+--R                          - 2268A B b c - 81B b
+--R                     /
+--R                                 11 5
+--R                        16777216b  c
+--R                  ,
+--R                      4
+--R              /
+--R                                +-+
+--R                 (21A c + 3B b)\|x
+--R  /
+--R        2  +-+4+-+3 4+-+
+--R     64b c\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1388
+
+--S 1389 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                 +-+4+-+2         2           3
+--R                 (42A c + 6B b)x\|b \|b   + (21A c  + 3B b c)x
+--R               + 
+--R                                2
+--R                 (21A b c + 3B b )x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                  2           2                 2 4+-+2
+--R           ((63A c  + 9B b c)x  + 21A b c + 3B b )\|b
+--R         + 
+--R                    2           2                 2  +-+
+--R           ((- 21A c  - 3B b c)x  - 21A b c - 3B b )\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R               2           2 +-+ +-+           3         2  3
+--R       (- 42A c  - 6B b c)x \|b \|c  + (- 21A c  - 3B b c )x
+--R     + 
+--R                 2       2
+--R       (- 63A b c  - 9B b c)x
+--R  /
+--R                  2 2 3       3     +-+4+-+2 +-+
+--R             (128b c x  + 128b c x)\|b \|b  \|c
+--R           + 
+--R                 2 3 4       3 2 2      4  4+-+2
+--R             (64b c x  + 128b c x  + 64b c)\|b
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R               3 3 3       4 2
+--R         - 128b c x  - 128b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1389
+
+)clear all
+
+--S 1390 of 3139
+t0:=x^(9/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     2      +-+
+--R                 (B x  + A)\|x
+--R   (1)  -------------------------------
+--R         3 8       2 6     2   4    3 2
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1390
+
+--S 1391 of 3139
+r0:=-5/32*(b*B-9*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*_
+   c^(3/4)*sqrt(2))+5/32*(b*B-9*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(13/4)*c^(3/4)*sqrt(2))+5/64*(b*B-9*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*c^(3/4)*sqrt(2))-_
+   5/64*(b*B-9*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(13/4)*c^(3/4)*sqrt(2))+5/16*(b*B-9*A*c)/(b^3*c*sqrt(x))+_
+   1/4*(-b*B+A*c)/(b*c*(b+c*x^2)^2*sqrt(x))+1/16*(-b*B+9*A*c)/_
+   (b^2*c*(b+c*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                3         2  4           2        2   2        2        3  +-+
+--R         ((45A c  - 5B b c )x  + (90A b c  - 10B b c)x  + 45A b c - 5B b )\|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  3         2  4             2        2   2        2        3
+--R         ((- 45A c  + 5B b c )x  + (- 90A b c  + 10B b c)x  - 45A b c + 5B b )
+--R      *
+--R          +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     3          2  4              2        2   2        2
+--R             (- 90A c  + 10B b c )x  + (- 180A b c  + 20B b c)x  - 90A b c
+--R           + 
+--R                  3
+--R             10B b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|c \|x  + \|b
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R                     3          2  4              2        2   2        2
+--R             (- 90A c  + 10B b c )x  + (- 180A b c  + 20B b c)x  - 90A b c
+--R           + 
+--R                  3
+--R             10B b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|c \|x  - \|b
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R               2            4                      2  2         2  +-+4+-+4+-+3
+--R     ((- 180A c  + 20B b c)x  + (- 324A b c + 36B b )x  - 128A b )\|2 \|b \|c
+--R  /
+--R         3 2 4       4   2      5  +-+4+-+4+-+3 +-+
+--R     (64b c x  + 128b c x  + 64b )\|2 \|b \|c  \|x
+--R                                                    Type: Expression(Integer)
+--E 1391
+
+--S 1392 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 2 4      4   2      5
+--R         (- 16b c x  - 32b c x  - 16b )
+--R      *
+--R         ROOT
+--R                          4 4           3     3          2 2 2 2           3 3
+--R                - 4100625A c  + 1822500A B b c  - 303750A B b c  + 22500A B b c
+--R              + 
+--R                      4 4
+--R                - 625B b
+--R           /
+--R                       13 3
+--R              16777216b  c
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                     3 3         2     2          2 2        3 3  +-+
+--R              (91125A c  - 30375A B b c  + 3375A B b c - 125B b )\|x
+--R            + 
+--R                       10 2
+--R                262144b  c
+--R             *
+--R                  ROOT
+--R                                   4 4           3     3          2 2 2 2
+--R                         - 4100625A c  + 1822500A B b c  - 303750A B b c
+--R                       + 
+--R                                 3 3        4 4
+--R                         22500A B b c - 625B b
+--R                    /
+--R                                13 3
+--R                       16777216b  c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R             3 2 4      4   2      5
+--R         (16b c x  + 32b c x  + 16b )
+--R      *
+--R         ROOT
+--R                          4 4           3     3          2 2 2 2           3 3
+--R                - 4100625A c  + 1822500A B b c  - 303750A B b c  + 22500A B b c
+--R              + 
+--R                      4 4
+--R                - 625B b
+--R           /
+--R                       13 3
+--R              16777216b  c
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                     3 3         2     2          2 2        3 3  +-+
+--R              (91125A c  - 30375A B b c  + 3375A B b c - 125B b )\|x
+--R            + 
+--R              -
+--R                          10 2
+--R                   262144b  c
+--R                *
+--R                     ROOT
+--R                                      4 4           3     3          2 2 2 2
+--R                            - 4100625A c  + 1822500A B b c  - 303750A B b c
+--R                          + 
+--R                                    3 3        4 4
+--R                            22500A B b c - 625B b
+--R                       /
+--R                                   13 3
+--R                          16777216b  c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R               3 2 4      4   2      5
+--R         (- 32b c x  - 64b c x  - 32b )
+--R      *
+--R         ROOT
+--R                          4 4           3     3          2 2 2 2           3 3
+--R                - 4100625A c  + 1822500A B b c  - 303750A B b c  + 22500A B b c
+--R              + 
+--R                      4 4
+--R                - 625B b
+--R           /
+--R                       13 3
+--R              16777216b  c
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         atan
+--R                       10 2
+--R                262144b  c
+--R             *
+--R                  ROOT
+--R                                   4 4           3     3          2 2 2 2
+--R                         - 4100625A c  + 1822500A B b c  - 303750A B b c
+--R                       + 
+--R                                 3 3        4 4
+--R                         22500A B b c - 625B b
+--R                    /
+--R                                13 3
+--R                       16777216b  c
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                     3 3         2     2          2 2        3 3  +-+
+--R              (91125A c  - 30375A B b c  + 3375A B b c - 125B b )\|x
+--R     + 
+--R               2           4                    2  2        2
+--R       (- 45A c  + 5B b c)x  + (- 81A b c + 9B b )x  - 32A b
+--R  /
+--R         3 2 4      4   2      5  +-+
+--R     (16b c x  + 32b c x  + 16b )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1392
+
+--S 1393 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45A c + 5B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R               3 +-+
+--R            64b \|2
+--R         *
+--R            ROOT
+--R                             4 4           3     3          2 2 2 2
+--R                   - 4100625A c  + 1822500A B b c  - 303750A B b c
+--R                 + 
+--R                           3 3        4 4
+--R                   22500A B b c - 625B b
+--R              /
+--R                          13 3
+--R                 16777216b  c
+--R           ,
+--R               4
+--R         *
+--R            4+-+4+-+3
+--R            \|b \|c
+--R         *
+--R            log
+--R                        3 3         2     2          2 2        3 3  +-+
+--R                 (91125A c  - 30375A B b c  + 3375A B b c - 125B b )\|x
+--R               + 
+--R                          10 2
+--R                   262144b  c
+--R                *
+--R                     ROOT
+--R                                      4 4           3     3          2 2 2 2
+--R                            - 4100625A c  + 1822500A B b c  - 303750A B b c
+--R                          + 
+--R                                    3 3        4 4
+--R                            22500A B b c - 625B b
+--R                       /
+--R                                   13 3
+--R                          16777216b  c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R            3 +-+
+--R         64b \|2
+--R      *
+--R         ROOT
+--R                          4 4           3     3          2 2 2 2           3 3
+--R                - 4100625A c  + 1822500A B b c  - 303750A B b c  + 22500A B b c
+--R              + 
+--R                      4 4
+--R                - 625B b
+--R           /
+--R                       13 3
+--R              16777216b  c
+--R        ,
+--R            4
+--R      *
+--R         4+-+4+-+3
+--R         \|b \|c
+--R      *
+--R         log
+--R                     3 3         2     2          2 2        3 3  +-+
+--R              (91125A c  - 30375A B b c  + 3375A B b c - 125B b )\|x
+--R            + 
+--R              -
+--R                          10 2
+--R                   262144b  c
+--R                *
+--R                     ROOT
+--R                                      4 4           3     3          2 2 2 2
+--R                            - 4100625A c  + 1822500A B b c  - 303750A B b c
+--R                          + 
+--R                                    3 3        4 4
+--R                            22500A B b c - 625B b
+--R                       /
+--R                                   13 3
+--R                          16777216b  c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R                            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45A c - 5B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R                           \|2 \|c \|x  + \|b
+--R       (90A c - 10B b)atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R                           \|2 \|c \|x  - \|b
+--R       (90A c - 10B b)atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R       -
+--R                3 +-+
+--R            128b \|2
+--R         *
+--R            ROOT
+--R                             4 4           3     3          2 2 2 2
+--R                   - 4100625A c  + 1822500A B b c  - 303750A B b c
+--R                 + 
+--R                           3 3        4 4
+--R                   22500A B b c - 625B b
+--R              /
+--R                          13 3
+--R                 16777216b  c
+--R           ,
+--R               4
+--R         *
+--R            4+-+4+-+3
+--R            \|b \|c
+--R         *
+--R            atan
+--R                          10 2
+--R                   262144b  c
+--R                *
+--R                     ROOT
+--R                                      4 4           3     3          2 2 2 2
+--R                            - 4100625A c  + 1822500A B b c  - 303750A B b c
+--R                          + 
+--R                                    3 3        4 4
+--R                            22500A B b c - 625B b
+--R                       /
+--R                                   13 3
+--R                          16777216b  c
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R              /
+--R                        3 3         2     2          2 2        3 3  +-+
+--R                 (91125A c  - 30375A B b c  + 3375A B b c - 125B b )\|x
+--R  /
+--R        3 +-+4+-+4+-+3
+--R     64b \|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 1393
+
+--S 1394 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                             2 +-+4+-+2 +-+
+--R           (- 90A c + 10B b)x \|b \|b  \|c
+--R         + 
+--R                    2           3                      2   4+-+2
+--R           ((- 45A c  + 5B b c)x  + (- 135A b c + 15B b )x)\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                  2           3                  2   4+-+2
+--R           ((45A c  - 5B b c)x  + (45A b c - 5B b )x)\|b
+--R         + 
+--R                           2   +-+
+--R           (90A b c - 10B b )x\|b
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                2           2                 2  +-+4+-+2
+--R       ((- 45A c  + 5B b c)x  - 45A b c + 5B b )\|b \|b
+--R     + 
+--R                2        2   2        2        3
+--R       (135A b c  - 15B b c)x  + 45A b c - 5B b
+--R  /
+--R                  3   3       4   +-+4+-+2 +-+
+--R             (128b c x  + 128b x)\|b \|b  \|c
+--R           + 
+--R                 3 2 4       4   2      5 4+-+2
+--R             (64b c x  + 128b c x  + 64b )\|b
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R               4 2 3       5
+--R         - 128b c x  - 128b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1394
+
+)clear all
+
+--S 1395 of 3139
+t0:=x^(7/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     2      +-+
+--R                 (B x  + A)\|x
+--R   (1)  -------------------------------
+--R         3 9       2 7     2   5    3 3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1395
+
+--S 1396 of 3139
+r0:=7/48*(3*b*B-11*A*c)/(b^3*c*x^(3/2))+1/4*(-b*B+A*c)/(b*c*x^(3/2)*_
+   (b+c*x^2)^2)+1/16*(-3*b*B+11*A*c)/(b^2*c*x^(3/2)*(b+c*x^2))-_
+   7/32*(3*b*B-11*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(15/4)*_
+   c^(1/4)*sqrt(2))+7/32*(3*b*B-11*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(15/4)*c^(1/4)*sqrt(2))-7/64*(3*b*B-11*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(15/4)*c^(1/4)*sqrt(2))+_
+   7/64*(3*b*B-11*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(15/4)*c^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                    3          2  5              2         2   3
+--R           (- 231A c  + 63B b c )x  + (- 462A b c  + 126B b c)x
+--R         + 
+--R                    2         3
+--R           (- 231A b c + 63B b )x
+--R      *
+--R          +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  3          2  5            2         2   3
+--R           (231A c  - 63B b c )x  + (462A b c  - 126B b c)x
+--R         + 
+--R                  2         3
+--R           (231A b c - 63B b )x
+--R      *
+--R          +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    3           2  5              2         2   3
+--R           (- 462A c  + 126B b c )x  + (- 924A b c  + 252B b c)x
+--R         + 
+--R                    2          3
+--R           (- 462A b c + 126B b )x
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|c \|x  + \|b
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R                    3           2  5              2         2   3
+--R           (- 462A c  + 126B b c )x  + (- 924A b c  + 252B b c)x
+--R         + 
+--R                    2          3
+--R           (- 462A b c + 126B b )x
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|c \|x  - \|b
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R               2            4                       2  2         2  +-+4+-+3 4+-+
+--R     ((- 308A c  + 84B b c)x  + (- 484A b c + 132B b )x  - 128A b )\|2 \|b   \|c
+--R  /
+--R          3 2 5       4   3       5   +-+4+-+3 4+-+ +-+
+--R     (192b c x  + 384b c x  + 192b x)\|2 \|b   \|c \|x
+--R                                                    Type: Expression(Integer)
+--E 1396
+
+--S 1397 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 2 5      4   3      5
+--R         (- 48b c x  - 96b c x  - 48b x)
+--R      *
+--R         ROOT
+--R                           4 4            3     3            2 2 2 2
+--R                - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R              + 
+--R                          3 3           4 4
+--R                2852388A B b c - 194481B b
+--R           /
+--R                       15
+--R              16777216b  c
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                              +-+
+--R              (77A c - 21B b)\|x
+--R            + 
+--R                   4
+--R                64b
+--R             *
+--R                ROOT
+--R                                  4 4            3     3            2 2 2 2
+--R                       - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R                     + 
+--R                                 3 3           4 4
+--R                       2852388A B b c - 194481B b
+--R                  /
+--R                              15
+--R                     16777216b  c
+--R               ,
+--R                   4
+--R     + 
+--R             3 2 5      4   3      5
+--R         (48b c x  + 96b c x  + 48b x)
+--R      *
+--R         ROOT
+--R                           4 4            3     3            2 2 2 2
+--R                - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R              + 
+--R                          3 3           4 4
+--R                2852388A B b c - 194481B b
+--R           /
+--R                       15
+--R              16777216b  c
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                              +-+
+--R              (77A c - 21B b)\|x
+--R            + 
+--R              -
+--R                      4
+--R                   64b
+--R                *
+--R                   ROOT
+--R                                     4 4            3     3            2 2 2 2
+--R                          - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R                        + 
+--R                                    3 3           4 4
+--R                          2852388A B b c - 194481B b
+--R                     /
+--R                                 15
+--R                        16777216b  c
+--R                  ,
+--R                      4
+--R     + 
+--R             3 2 5       4   3      5
+--R         (96b c x  + 192b c x  + 96b x)
+--R      *
+--R         ROOT
+--R                           4 4            3     3            2 2 2 2
+--R                - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R              + 
+--R                          3 3           4 4
+--R                2852388A B b c - 194481B b
+--R           /
+--R                       15
+--R              16777216b  c
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         atan
+--R                   4
+--R                64b
+--R             *
+--R                ROOT
+--R                                  4 4            3     3            2 2 2 2
+--R                       - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R                     + 
+--R                                 3 3           4 4
+--R                       2852388A B b c - 194481B b
+--R                  /
+--R                              15
+--R                     16777216b  c
+--R               ,
+--R                   4
+--R           /
+--R                              +-+
+--R              (77A c - 21B b)\|x
+--R     + 
+--R               2            4                      2  2        2
+--R       (- 77A c  + 21B b c)x  + (- 121A b c + 33B b )x  - 32A b
+--R  /
+--R         3 2 5      4   3      5   +-+
+--R     (48b c x  + 96b c x  + 48b x)\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1397
+
+--S 1398 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (77A c - 21B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R               3 +-+
+--R            64b \|2
+--R         *
+--R            ROOT
+--R                              4 4            3     3            2 2 2 2
+--R                   - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R                 + 
+--R                             3 3           4 4
+--R                   2852388A B b c - 194481B b
+--R              /
+--R                          15
+--R                 16777216b  c
+--R           ,
+--R               4
+--R         *
+--R            4+-+3 4+-+
+--R            \|b   \|c
+--R         *
+--R            log
+--R                                 +-+
+--R                 (77A c - 21B b)\|x
+--R               + 
+--R                      4
+--R                   64b
+--R                *
+--R                   ROOT
+--R                                     4 4            3     3            2 2 2 2
+--R                          - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R                        + 
+--R                                    3 3           4 4
+--R                          2852388A B b c - 194481B b
+--R                     /
+--R                                 15
+--R                        16777216b  c
+--R                  ,
+--R                      4
+--R     + 
+--R            3 +-+
+--R         64b \|2
+--R      *
+--R         ROOT
+--R                           4 4            3     3            2 2 2 2
+--R                - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R              + 
+--R                          3 3           4 4
+--R                2852388A B b c - 194481B b
+--R           /
+--R                       15
+--R              16777216b  c
+--R        ,
+--R            4
+--R      *
+--R         4+-+3 4+-+
+--R         \|b   \|c
+--R      *
+--R         log
+--R                              +-+
+--R              (77A c - 21B b)\|x
+--R            + 
+--R              -
+--R                      4
+--R                   64b
+--R                *
+--R                   ROOT
+--R                                     4 4            3     3            2 2 2 2
+--R                          - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R                        + 
+--R                                    3 3           4 4
+--R                          2852388A B b c - 194481B b
+--R                     /
+--R                                 15
+--R                        16777216b  c
+--R                  ,
+--R                      4
+--R     + 
+--R                               +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 77A c + 21B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  + \|b
+--R       (154A c - 42B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R                            \|2 \|c \|x  - \|b
+--R       (154A c - 42B b)atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R             3 +-+
+--R         128b \|2
+--R      *
+--R         ROOT
+--R                           4 4            3     3            2 2 2 2
+--R                - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R              + 
+--R                          3 3           4 4
+--R                2852388A B b c - 194481B b
+--R           /
+--R                       15
+--R              16777216b  c
+--R        ,
+--R            4
+--R      *
+--R         4+-+3 4+-+
+--R         \|b   \|c
+--R      *
+--R         atan
+--R                   4
+--R                64b
+--R             *
+--R                ROOT
+--R                                  4 4            3     3            2 2 2 2
+--R                       - 35153041A c  + 38348772A B b c  - 15688134A B b c
+--R                     + 
+--R                                 3 3           4 4
+--R                       2852388A B b c - 194481B b
+--R                  /
+--R                              15
+--R                     16777216b  c
+--R               ,
+--R                   4
+--R           /
+--R                              +-+
+--R              (77A c - 21B b)\|x
+--R  /
+--R        3 +-+4+-+3 4+-+
+--R     64b \|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 1398
+
+--S 1399 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                   +-+4+-+2           2            3
+--R               (- 154A c + 42B b)x\|b \|b   + (- 77A c  + 21B b c)x
+--R             + 
+--R                                 2
+--R               (- 77A b c + 21B b )x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                     2            2                  2 4+-+2
+--R           ((- 231A c  + 63B b c)x  - 77A b c + 21B b )\|b
+--R         + 
+--R                  2            2                  2  +-+
+--R           ((77A c  - 21B b c)x  + 77A b c - 21B b )\|b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R              2            2 +-+ +-+         3          2  3
+--R       (154A c  - 42B b c)x \|b \|c  + (77A c  - 21B b c )x
+--R     + 
+--R                2        2
+--R       (231A b c  - 63B b c)x
+--R  /
+--R                  3   3       4   +-+4+-+2 +-+
+--R             (128b c x  + 128b x)\|b \|b  \|c
+--R           + 
+--R                 3 2 4       4   2      5 4+-+2
+--R             (64b c x  + 128b c x  + 64b )\|b
+--R        *
+--R           4+-+2
+--R           \|c
+--R       + 
+--R               4 2 3       5
+--R         - 128b c x  - 128b c x
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1399
+
+)clear all
+
+--S 1400 of 3139
+t0:=x^(5/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     2      +-+
+--R                 (B x  + A)\|x
+--R   (1)  --------------------------------
+--R         3 10       2 8     2   6    3 4
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1400
+
+--S 1401 of 3139
+r0:=9/80*(5*b*B-13*A*c)/(b^3*c*x^(5/2))+1/4*(-b*B+A*c)/(b*c*x^(5/2)*_
+   (b+c*x^2)^2)+1/16*(-5*b*B+13*A*c)/(b^2*c*x^(5/2)*(b+c*x^2))+_
+   9/32*c^(1/4)*(5*b*B-13*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (b^(17/4)*sqrt(2))-9/32*c^(1/4)*(5*b*B-13*A*c)*atan(1+c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(17/4)*sqrt(2))-9/64*c^(1/4)*(5*b*B-13*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*_
+   sqrt(2))+9/64*c^(1/4)*(5*b*B-13*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*sqrt(2))-9/16*(5*b*B-13*A*c)/_
+   (b^4*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                    3           2  6               2         2   4
+--R           (- 585A c  + 225B b c )x  + (- 1170A b c  + 450B b c)x
+--R         + 
+--R                    2          3  2
+--R           (- 585A b c + 225B b )x
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  3           2  6             2         2   4
+--R           (585A c  - 225B b c )x  + (1170A b c  - 450B b c)x
+--R         + 
+--R                  2          3  2
+--R           (585A b c - 225B b )x
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   3           2  6             2         2   4
+--R           (1170A c  - 450B b c )x  + (2340A b c  - 900B b c)x
+--R         + 
+--R                   2          3  2
+--R           (1170A b c - 450B b )x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|c \|x  + \|b
+--R         \|c \|x atan(-------------------)
+--R                              4+-+
+--R                              \|b
+--R     + 
+--R                   3           2  6             2         2   4
+--R           (1170A c  - 450B b c )x  + (2340A b c  - 900B b c)x
+--R         + 
+--R                   2          3  2
+--R           (1170A b c - 450B b )x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|c \|x  - \|b
+--R         \|c \|x atan(-------------------)
+--R                              4+-+
+--R                              \|b
+--R     + 
+--R                   3           2  6             2          2   4
+--R           (2340A c  - 900B b c )x  + (4212A b c  - 1620B b c)x
+--R         + 
+--R                   2          3  2         3
+--R           (1664A b c - 640B b )x  - 128A b
+--R      *
+--R          +-+4+-+
+--R         \|2 \|b
+--R  /
+--R          4 2 6       5   4       6 2  +-+4+-+ +-+
+--R     (320b c x  + 640b c x  + 320b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 1401
+
+--S 1402 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             4 2 6       5   4      6 2
+--R         (80b c x  + 160b c x  + 80b x )
+--R      *
+--R         ROOT
+--R                            4 5             3     4             2 2 2 3
+--R                - 187388721A c  + 288290340A B b c  - 166321350A B b c
+--R              + 
+--R                           3 3 2           4 4
+--R                42646500A B b c  - 4100625B b c
+--R           /
+--R                       17
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                       3 4           2     3            2 2 2         3 3   +-+
+--R              (1601613A c  - 1848015A B b c  + 710775A B b c  - 91125B b c)\|x
+--R            + 
+--R                       13
+--R                262144b
+--R             *
+--R                  ROOT
+--R                                     4 5             3     4             2 2 2 3
+--R                         - 187388721A c  + 288290340A B b c  - 166321350A B b c
+--R                       + 
+--R                                    3 3 2           4 4
+--R                         42646500A B b c  - 4100625B b c
+--R                    /
+--R                                17
+--R                       16777216b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R               4 2 6       5   4      6 2
+--R         (- 80b c x  - 160b c x  - 80b x )
+--R      *
+--R         ROOT
+--R                            4 5             3     4             2 2 2 3
+--R                - 187388721A c  + 288290340A B b c  - 166321350A B b c
+--R              + 
+--R                           3 3 2           4 4
+--R                42646500A B b c  - 4100625B b c
+--R           /
+--R                       17
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                       3 4           2     3            2 2 2         3 3   +-+
+--R              (1601613A c  - 1848015A B b c  + 710775A B b c  - 91125B b c)\|x
+--R            + 
+--R              -
+--R                          13
+--R                   262144b
+--R                *
+--R                     ROOT
+--R                                        4 5             3     4
+--R                            - 187388721A c  + 288290340A B b c
+--R                          + 
+--R                                      2 2 2 3              3 3 2           4 4
+--R                          - 166321350A B b c  + 42646500A B b c  - 4100625B b c
+--R                       /
+--R                                   17
+--R                          16777216b
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R              4 2 6       5   4       6 2
+--R         (160b c x  + 320b c x  + 160b x )
+--R      *
+--R         ROOT
+--R                            4 5             3     4             2 2 2 3
+--R                - 187388721A c  + 288290340A B b c  - 166321350A B b c
+--R              + 
+--R                           3 3 2           4 4
+--R                42646500A B b c  - 4100625B b c
+--R           /
+--R                       17
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         atan
+--R                       13
+--R                262144b
+--R             *
+--R                  ROOT
+--R                                     4 5             3     4             2 2 2 3
+--R                         - 187388721A c  + 288290340A B b c  - 166321350A B b c
+--R                       + 
+--R                                    3 3 2           4 4
+--R                         42646500A B b c  - 4100625B b c
+--R                    /
+--R                                17
+--R                       16777216b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                       3 4           2     3            2 2 2         3 3   +-+
+--R              (1601613A c  - 1848015A B b c  + 710775A B b c  - 91125B b c)\|x
+--R     + 
+--R              3           2  6             2         2   4
+--R       (585A c  - 225B b c )x  + (1053A b c  - 405B b c)x
+--R     + 
+--R              2          3  2        3
+--R       (416A b c - 160B b )x  - 32A b
+--R  /
+--R         4 2 6       5   4      6 2  +-+
+--R     (80b c x  + 160b c x  + 80b x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1402
+
+--S 1403 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (117A c - 45B b)\|c log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            4 +-+
+--R         64b \|2
+--R      *
+--R         ROOT
+--R                            4 5             3     4             2 2 2 3
+--R                - 187388721A c  + 288290340A B b c  - 166321350A B b c
+--R              + 
+--R                           3 3 2           4 4
+--R                42646500A B b c  - 4100625B b c
+--R           /
+--R                       17
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R         4+-+
+--R         \|b
+--R      *
+--R         log
+--R                       3 4           2     3            2 2 2         3 3   +-+
+--R              (1601613A c  - 1848015A B b c  + 710775A B b c  - 91125B b c)\|x
+--R            + 
+--R                       13
+--R                262144b
+--R             *
+--R                  ROOT
+--R                                     4 5             3     4             2 2 2 3
+--R                         - 187388721A c  + 288290340A B b c  - 166321350A B b c
+--R                       + 
+--R                                    3 3 2           4 4
+--R                         42646500A B b c  - 4100625B b c
+--R                    /
+--R                                17
+--R                       16777216b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R       -
+--R               4 +-+
+--R            64b \|2
+--R         *
+--R            ROOT
+--R                               4 5             3     4             2 2 2 3
+--R                   - 187388721A c  + 288290340A B b c  - 166321350A B b c
+--R                 + 
+--R                              3 3 2           4 4
+--R                   42646500A B b c  - 4100625B b c
+--R              /
+--R                          17
+--R                 16777216b
+--R           ,
+--R               4
+--R         *
+--R            4+-+
+--R            \|b
+--R         *
+--R            log
+--R                            3 4           2     3            2 2 2         3 3
+--R                   (1601613A c  - 1848015A B b c  + 710775A B b c  - 91125B b c)
+--R                *
+--R                    +-+
+--R                   \|x
+--R               + 
+--R                 -
+--R                             13
+--R                      262144b
+--R                   *
+--R                        ROOT
+--R                                           4 5             3     4
+--R                               - 187388721A c  + 288290340A B b c
+--R                             + 
+--R                                           2 2 2 3              3 3 2
+--R                               - 166321350A B b c  + 42646500A B b c
+--R                             + 
+--R                                         4 4
+--R                               - 4100625B b c
+--R                          /
+--R                                      17
+--R                             16777216b
+--R                       ,
+--R                           4
+--R                     **
+--R                        3
+--R     + 
+--R                         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 117A c + 45B b)\|c log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                         4+-+     \|2 \|c \|x  + \|b
+--R       (- 234A c + 90B b)\|c atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                         4+-+     \|2 \|c \|x  - \|b
+--R       (- 234A c + 90B b)\|c atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R             4 +-+
+--R         128b \|2
+--R      *
+--R         ROOT
+--R                            4 5             3     4             2 2 2 3
+--R                - 187388721A c  + 288290340A B b c  - 166321350A B b c
+--R              + 
+--R                           3 3 2           4 4
+--R                42646500A B b c  - 4100625B b c
+--R           /
+--R                       17
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R         4+-+
+--R         \|b
+--R      *
+--R         atan
+--R                       13
+--R                262144b
+--R             *
+--R                  ROOT
+--R                                     4 5             3     4             2 2 2 3
+--R                         - 187388721A c  + 288290340A B b c  - 166321350A B b c
+--R                       + 
+--R                                    3 3 2           4 4
+--R                         42646500A B b c  - 4100625B b c
+--R                    /
+--R                                17
+--R                       16777216b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                       3 4           2     3            2 2 2         3 3   +-+
+--R              (1601613A c  - 1848015A B b c  + 710775A B b c  - 91125B b c)\|x
+--R  /
+--R        4 +-+4+-+
+--R     64b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1403
+
+--S 1404 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       2            3                    2   4+-+2
+--R               ((117A c  - 45B b c)x  + (117A b c - 45B b )x)\|b
+--R             + 
+--R                                2   +-+
+--R               (234A b c - 90B b )x\|b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                     2            2                   2  +-+4+-+2
+--R           ((- 117A c  + 45B b c)x  - 117A b c + 45B b )\|b \|b
+--R         + 
+--R                    2         2   2         2         3
+--R           (351A b c  - 135B b c)x  + 117A b c - 45B b
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                2            2 +-+4+-+2 +-+
+--R       (- 234A c  + 90B b c)x \|b \|b  \|c
+--R     + 
+--R                 3          2  3              2         2    4+-+2
+--R       ((- 117A c  + 45B b c )x  + (- 351A b c  + 135B b c)x)\|b
+--R  /
+--R              5   3       6  4+-+2          4   3       5   +-+4+-+2 +-+
+--R         (128b c x  + 128b x)\|c   + (- 128b c x  - 128b x)\|b \|b  \|c
+--R       + 
+--R               4 2 4       5   2      6 4+-+2
+--R         (- 64b c x  - 128b c x  - 64b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1404
+
+)clear all
+
+--S 1405 of 3139
+t0:=x^(3/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     2      +-+
+--R                 (B x  + A)\|x
+--R   (1)  --------------------------------
+--R         3 11       2 9     2   7    3 5
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1405
+
+--S 1406 of 3139
+r0:=11/112*(7*b*B-15*A*c)/(b^3*c*x^(7/2))-11/48*(7*b*B-15*A*c)/_
+   (b^4*x^(3/2))+1/4*(-b*B+A*c)/(b*c*x^(7/2)*(b+c*x^2)^2)+_
+   1/16*(-7*b*B+15*A*c)/(b^2*c*x^(7/2)*(b+c*x^2))+11/32*c^(3/4)*_
+   (7*b*B-15*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(19/4)*_
+   sqrt(2))-11/32*c^(3/4)*(7*b*B-15*A*c)*atan(1+c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(19/4)*sqrt(2))+11/64*c^(3/4)*(7*b*B-15*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(19/4)*_
+   sqrt(2))-11/64*c^(3/4)*(7*b*B-15*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(19/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   3            2  7             2          2   5
+--R           (3465A c  - 1617B b c )x  + (6930A b c  - 3234B b c)x
+--R         + 
+--R                   2           3  3
+--R           (3465A b c - 1617B b )x
+--R      *
+--R         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     3            2  7               2          2   5
+--R           (- 3465A c  + 1617B b c )x  + (- 6930A b c  + 3234B b c)x
+--R         + 
+--R                     2           3  3
+--R           (- 3465A b c + 1617B b )x
+--R      *
+--R         4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   3            2  7              2          2   5
+--R           (6930A c  - 3234B b c )x  + (13860A b c  - 6468B b c)x
+--R         + 
+--R                   2           3  3
+--R           (6930A b c - 3234B b )x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|c \|x  + \|b
+--R         \|c  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|b
+--R     + 
+--R                   3            2  7              2          2   5
+--R           (6930A c  - 3234B b c )x  + (13860A b c  - 6468B b c)x
+--R         + 
+--R                   2           3  3
+--R           (6930A b c - 3234B b )x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|c \|x  - \|b
+--R         \|c  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|b
+--R     + 
+--R                   3            2  6             2          2   4
+--R           (4620A c  - 2156B b c )x  + (7260A b c  - 3388B b c)x
+--R         + 
+--R                   2          3  2         3
+--R           (1920A b c - 896B b )x  - 384A b
+--R      *
+--R          +-+4+-+3
+--R         \|2 \|b
+--R  /
+--R           4 2 7        5   5        6 3  +-+4+-+3 +-+
+--R     (1344b c x  + 2688b c x  + 1344b x )\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 1406
+
+--S 1407 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              4 2 7       5   5       6 3
+--R         (336b c x  + 672b c x  + 336b x )
+--R      *
+--R         ROOT
+--R                            4 7              3     6             2 2 2 5
+--R                - 741200625A c  + 1383574500A B b c  - 968502150A B b c
+--R              + 
+--R                            3 3 4            4 4 3
+--R                301311780A B b c  - 35153041B b c
+--R           /
+--R                       19
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                     2            +-+
+--R              (165A c  - 77B b c)\|x
+--R            + 
+--R                   5
+--R                64b
+--R             *
+--R                ROOT
+--R                                   4 7              3     6             2 2 2 5
+--R                       - 741200625A c  + 1383574500A B b c  - 968502150A B b c
+--R                     + 
+--R                                   3 3 4            4 4 3
+--R                       301311780A B b c  - 35153041B b c
+--R                  /
+--R                              19
+--R                     16777216b
+--R               ,
+--R                   4
+--R     + 
+--R                4 2 7       5   5       6 3
+--R         (- 336b c x  - 672b c x  - 336b x )
+--R      *
+--R         ROOT
+--R                            4 7              3     6             2 2 2 5
+--R                - 741200625A c  + 1383574500A B b c  - 968502150A B b c
+--R              + 
+--R                            3 3 4            4 4 3
+--R                301311780A B b c  - 35153041B b c
+--R           /
+--R                       19
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                     2            +-+
+--R              (165A c  - 77B b c)\|x
+--R            + 
+--R              -
+--R                      5
+--R                   64b
+--R                *
+--R                   ROOT
+--R                                      4 7              3     6
+--R                          - 741200625A c  + 1383574500A B b c
+--R                        + 
+--R                                    2 2 2 5               3 3 4            4 4 3
+--R                        - 968502150A B b c  + 301311780A B b c  - 35153041B b c
+--R                     /
+--R                                 19
+--R                        16777216b
+--R                  ,
+--R                      4
+--R     + 
+--R                4 2 7        5   5       6 3
+--R         (- 672b c x  - 1344b c x  - 672b x )
+--R      *
+--R         ROOT
+--R                            4 7              3     6             2 2 2 5
+--R                - 741200625A c  + 1383574500A B b c  - 968502150A B b c
+--R              + 
+--R                            3 3 4            4 4 3
+--R                301311780A B b c  - 35153041B b c
+--R           /
+--R                       19
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         atan
+--R                   5
+--R                64b
+--R             *
+--R                ROOT
+--R                                   4 7              3     6             2 2 2 5
+--R                       - 741200625A c  + 1383574500A B b c  - 968502150A B b c
+--R                     + 
+--R                                   3 3 4            4 4 3
+--R                       301311780A B b c  - 35153041B b c
+--R                  /
+--R                              19
+--R                     16777216b
+--R               ,
+--R                   4
+--R           /
+--R                     2            +-+
+--R              (165A c  - 77B b c)\|x
+--R     + 
+--R               3           2  6             2         2   4
+--R       (1155A c  - 539B b c )x  + (1815A b c  - 847B b c)x
+--R     + 
+--R              2          3  2        3
+--R       (480A b c - 224B b )x  - 96A b
+--R  /
+--R          4 2 7       5   5       6 3  +-+
+--R     (336b c x  + 672b c x  + 336b x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1407
+
+--S 1408 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 165A c + 77B b)\|c  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            4 +-+
+--R         64b \|2
+--R      *
+--R         ROOT
+--R                            4 7              3     6             2 2 2 5
+--R                - 741200625A c  + 1383574500A B b c  - 968502150A B b c
+--R              + 
+--R                            3 3 4            4 4 3
+--R                301311780A B b c  - 35153041B b c
+--R           /
+--R                       19
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R         4+-+3
+--R         \|b
+--R      *
+--R         log
+--R                     2            +-+
+--R              (165A c  - 77B b c)\|x
+--R            + 
+--R                   5
+--R                64b
+--R             *
+--R                ROOT
+--R                                   4 7              3     6             2 2 2 5
+--R                       - 741200625A c  + 1383574500A B b c  - 968502150A B b c
+--R                     + 
+--R                                   3 3 4            4 4 3
+--R                       301311780A B b c  - 35153041B b c
+--R                  /
+--R                              19
+--R                     16777216b
+--R               ,
+--R                   4
+--R     + 
+--R       -
+--R               4 +-+
+--R            64b \|2
+--R         *
+--R            ROOT
+--R                               4 7              3     6             2 2 2 5
+--R                   - 741200625A c  + 1383574500A B b c  - 968502150A B b c
+--R                 + 
+--R                               3 3 4            4 4 3
+--R                   301311780A B b c  - 35153041B b c
+--R              /
+--R                          19
+--R                 16777216b
+--R           ,
+--R               4
+--R         *
+--R            4+-+3
+--R            \|b
+--R         *
+--R            log
+--R                        2            +-+
+--R                 (165A c  - 77B b c)\|x
+--R               + 
+--R                 -
+--R                         5
+--R                      64b
+--R                   *
+--R                      ROOT
+--R                                         4 7              3     6
+--R                             - 741200625A c  + 1383574500A B b c
+--R                           + 
+--R                                         2 2 2 5               3 3 4
+--R                             - 968502150A B b c  + 301311780A B b c
+--R                           + 
+--R                                        4 4 3
+--R                             - 35153041B b c
+--R                        /
+--R                                    19
+--R                           16777216b
+--R                     ,
+--R                         4
+--R     + 
+--R                       4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (165A c - 77B b)\|c  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R                          4+-+3     \|2 \|c \|x  + \|b
+--R       (- 330A c + 154B b)\|c  atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R                          4+-+3     \|2 \|c \|x  - \|b
+--R       (- 330A c + 154B b)\|c  atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R       -
+--R                4 +-+
+--R            128b \|2
+--R         *
+--R            ROOT
+--R                               4 7              3     6             2 2 2 5
+--R                   - 741200625A c  + 1383574500A B b c  - 968502150A B b c
+--R                 + 
+--R                               3 3 4            4 4 3
+--R                   301311780A B b c  - 35153041B b c
+--R              /
+--R                          19
+--R                 16777216b
+--R           ,
+--R               4
+--R         *
+--R            4+-+3
+--R            \|b
+--R         *
+--R            atan
+--R                      5
+--R                   64b
+--R                *
+--R                   ROOT
+--R                                      4 7              3     6
+--R                          - 741200625A c  + 1383574500A B b c
+--R                        + 
+--R                                    2 2 2 5               3 3 4            4 4 3
+--R                        - 968502150A B b c  + 301311780A B b c  - 35153041B b c
+--R                     /
+--R                                 19
+--R                        16777216b
+--R                  ,
+--R                      4
+--R              /
+--R                        2            +-+
+--R                 (165A c  - 77B b c)\|x
+--R  /
+--R        4 +-+4+-+3
+--R     64b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1408
+
+--S 1409 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  2             2 +-+ +-+          3          2  3
+--R           (330A c  - 154B b c)x \|b \|c  + (165A c  - 77B b c )x
+--R         + 
+--R                    2         2
+--R           (495A b c  - 231B b c)x
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                    2              +-+4+-+2            3          2  3
+--R           (- 330A c  + 154B b c)x\|b \|b   + (- 165A c  + 77B b c )x
+--R         + 
+--R                      2        2
+--R           (- 165A b c  + 77B b c)x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                 3           2  2           2        2  4+-+2
+--R       ((- 495A c  + 231B b c )x  - 165A b c  + 77B b c)\|b
+--R     + 
+--R               3          2  2           2        2   +-+
+--R       ((165A c  - 77B b c )x  + 165A b c  - 77B b c)\|b
+--R  /
+--R              5   3       6  4+-+2          4   3       5   +-+4+-+2 +-+
+--R         (128b c x  + 128b x)\|c   + (- 128b c x  - 128b x)\|b \|b  \|c
+--R       + 
+--R               4 2 4       5   2      6 4+-+2
+--R         (- 64b c x  - 128b c x  - 64b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1409
+
+)clear all
+
+--S 1410 of 3139
+t0:=(A+B*x^2)*sqrt(x)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      2      +-+
+--R                  (B x  + A)\|x
+--R   (1)  ---------------------------------
+--R         3 12       2 10     2   8    3 6
+--R        c x   + 3b c x   + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1410
+
+--S 1411 of 3139
+r0:=13/144*(9*b*B-17*A*c)/(b^3*c*x^(9/2))-13/80*(9*b*B-17*A*c)/(b^4*_
+   x^(5/2))+1/4*(-b*B+A*c)/(b*c*x^(9/2)*(b+c*x^2)^2)+1/16*(-9*b*B+_
+   17*A*c)/(b^2*c*x^(9/2)*(b+c*x^2))-13/32*c^(5/4)*(9*b*B-17*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(21/4)*sqrt(2))+_
+   13/32*c^(5/4)*(9*b*B-17*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (b^(21/4)*sqrt(2))+13/64*c^(5/4)*(9*b*B-17*A*c)*log(sqrt(b)+x*sqrt(c)-_
+   b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(21/4)*sqrt(2))-13/64*c^(5/4)*_
+   (9*b*B-17*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(21/4)*sqrt(2))+13/16*c*(9*b*B-17*A*c)/(b^5*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                   4            3  8              3           2 2  6
+--R           (9945A c  - 5265B b c )x  + (19890A b c  - 10530B b c )x
+--R         + 
+--R                   2 2          3   4
+--R           (9945A b c  - 5265B b c)x
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     4            3  8                3           2 2  6
+--R           (- 9945A c  + 5265B b c )x  + (- 19890A b c  + 10530B b c )x
+--R         + 
+--R                     2 2          3   4
+--R           (- 9945A b c  + 5265B b c)x
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                      4             3  8                3           2 2  6
+--R           (- 19890A c  + 10530B b c )x  + (- 39780A b c  + 21060B b c )x
+--R         + 
+--R                      2 2           3   4
+--R           (- 19890A b c  + 10530B b c)x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|c \|x  + \|b
+--R         \|c \|x atan(-------------------)
+--R                              4+-+
+--R                              \|b
+--R     + 
+--R                      4             3  8                3           2 2  6
+--R           (- 19890A c  + 10530B b c )x  + (- 39780A b c  + 21060B b c )x
+--R         + 
+--R                      2 2           3   4
+--R           (- 19890A b c  + 10530B b c)x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|c \|x  - \|b
+--R         \|c \|x atan(-------------------)
+--R                              4+-+
+--R                              \|b
+--R     + 
+--R                      4             3  8                3           2 2  6
+--R           (- 39780A c  + 21060B b c )x  + (- 71604A b c  + 37908B b c )x
+--R         + 
+--R                      2 2           3   4           3           4  2         4
+--R           (- 28288A b c  + 14976B b c)x  + (2176A b c - 1152B b )x  - 640A b
+--R      *
+--R          +-+4+-+
+--R         \|2 \|b
+--R  /
+--R           5 2 8        6   6        7 4  +-+4+-+ +-+
+--R     (2880b c x  + 5760b c x  + 2880b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 1411
+
+--S 1412 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                5 2 8        6   6       7 4
+--R         (- 720b c x  - 1440b c x  - 720b x )
+--R      *
+--R         ROOT
+--R                             4 9              3     8              2 2 2 7
+--R                - 2385443281A c  + 5051526948A B b c  - 4011506694A B b c
+--R              + 
+--R                             3 3 6             4 4 5
+--R                1415825892A B b c  - 187388721B b c
+--R           /
+--R                       21
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                           3 7            2     6             2 2 5
+--R                  10793861A c  - 17143191A B b c  + 9075807A B b c
+--R                + 
+--R                            3 3 4
+--R                  - 1601613B b c
+--R             *
+--R                 +-+
+--R                \|x
+--R            + 
+--R                       16
+--R                262144b
+--R             *
+--R                  ROOT
+--R                                      4 9              3     8
+--R                         - 2385443281A c  + 5051526948A B b c
+--R                       + 
+--R                                      2 2 2 7                3 3 6
+--R                         - 4011506694A B b c  + 1415825892A B b c
+--R                       + 
+--R                                     4 4 5
+--R                         - 187388721B b c
+--R                    /
+--R                                21
+--R                       16777216b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R     + 
+--R              5 2 8        6   6       7 4
+--R         (720b c x  + 1440b c x  + 720b x )
+--R      *
+--R         ROOT
+--R                             4 9              3     8              2 2 2 7
+--R                - 2385443281A c  + 5051526948A B b c  - 4011506694A B b c
+--R              + 
+--R                             3 3 6             4 4 5
+--R                1415825892A B b c  - 187388721B b c
+--R           /
+--R                       21
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                           3 7            2     6             2 2 5
+--R                  10793861A c  - 17143191A B b c  + 9075807A B b c
+--R                + 
+--R                            3 3 4
+--R                  - 1601613B b c
+--R             *
+--R                 +-+
+--R                \|x
+--R            + 
+--R              -
+--R                          16
+--R                   262144b
+--R                *
+--R                     ROOT
+--R                                         4 9              3     8
+--R                            - 2385443281A c  + 5051526948A B b c
+--R                          + 
+--R                                         2 2 2 7                3 3 6
+--R                            - 4011506694A B b c  + 1415825892A B b c
+--R                          + 
+--R                                        4 4 5
+--R                            - 187388721B b c
+--R                       /
+--R                                   21
+--R                          16777216b
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R                 5 2 8        6   6        7 4
+--R         (- 1440b c x  - 2880b c x  - 1440b x )
+--R      *
+--R         ROOT
+--R                             4 9              3     8              2 2 2 7
+--R                - 2385443281A c  + 5051526948A B b c  - 4011506694A B b c
+--R              + 
+--R                             3 3 6             4 4 5
+--R                1415825892A B b c  - 187388721B b c
+--R           /
+--R                       21
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         atan
+--R                       16
+--R                262144b
+--R             *
+--R                  ROOT
+--R                                      4 9              3     8
+--R                         - 2385443281A c  + 5051526948A B b c
+--R                       + 
+--R                                      2 2 2 7                3 3 6
+--R                         - 4011506694A B b c  + 1415825892A B b c
+--R                       + 
+--R                                     4 4 5
+--R                         - 187388721B b c
+--R                    /
+--R                                21
+--R                       16777216b
+--R                 ,
+--R                     4
+--R               **
+--R                  3
+--R           /
+--R                           3 7            2     6             2 2 5
+--R                  10793861A c  - 17143191A B b c  + 9075807A B b c
+--R                + 
+--R                            3 3 4
+--R                  - 1601613B b c
+--R             *
+--R                 +-+
+--R                \|x
+--R     + 
+--R                 4            3  8                3          2 2  6
+--R       (- 9945A c  + 5265B b c )x  + (- 17901A b c  + 9477B b c )x
+--R     + 
+--R                 2 2          3   4          3          4  2         4
+--R       (- 7072A b c  + 3744B b c)x  + (544A b c - 288B b )x  - 160A b
+--R  /
+--R          5 2 8        6   6       7 4  +-+
+--R     (720b c x  + 1440b c x  + 720b x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1412
+
+--S 1413 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2            4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 221A c  + 117B b c)\|c log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R               5 +-+
+--R            64b \|2
+--R         *
+--R            ROOT
+--R                                4 9              3     8              2 2 2 7
+--R                   - 2385443281A c  + 5051526948A B b c  - 4011506694A B b c
+--R                 + 
+--R                                3 3 6             4 4 5
+--R                   1415825892A B b c  - 187388721B b c
+--R              /
+--R                          21
+--R                 16777216b
+--R           ,
+--R               4
+--R         *
+--R            4+-+
+--R            \|b
+--R         *
+--R            log
+--R                              3 7            2     6             2 2 5
+--R                     10793861A c  - 17143191A B b c  + 9075807A B b c
+--R                   + 
+--R                               3 3 4
+--R                     - 1601613B b c
+--R                *
+--R                    +-+
+--R                   \|x
+--R               + 
+--R                          16
+--R                   262144b
+--R                *
+--R                     ROOT
+--R                                         4 9              3     8
+--R                            - 2385443281A c  + 5051526948A B b c
+--R                          + 
+--R                                         2 2 2 7                3 3 6
+--R                            - 4011506694A B b c  + 1415825892A B b c
+--R                          + 
+--R                                        4 4 5
+--R                            - 187388721B b c
+--R                       /
+--R                                   21
+--R                          16777216b
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R            5 +-+
+--R         64b \|2
+--R      *
+--R         ROOT
+--R                             4 9              3     8              2 2 2 7
+--R                - 2385443281A c  + 5051526948A B b c  - 4011506694A B b c
+--R              + 
+--R                             3 3 6             4 4 5
+--R                1415825892A B b c  - 187388721B b c
+--R           /
+--R                       21
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R         4+-+
+--R         \|b
+--R      *
+--R         log
+--R                           3 7            2     6             2 2 5
+--R                  10793861A c  - 17143191A B b c  + 9075807A B b c
+--R                + 
+--R                            3 3 4
+--R                  - 1601613B b c
+--R             *
+--R                 +-+
+--R                \|x
+--R            + 
+--R              -
+--R                          16
+--R                   262144b
+--R                *
+--R                     ROOT
+--R                                         4 9              3     8
+--R                            - 2385443281A c  + 5051526948A B b c
+--R                          + 
+--R                                         2 2 2 7                3 3 6
+--R                            - 4011506694A B b c  + 1415825892A B b c
+--R                          + 
+--R                                        4 4 5
+--R                            - 187388721B b c
+--R                       /
+--R                                   21
+--R                          16777216b
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R     + 
+--R              2            4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (221A c  - 117B b c)\|c log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R              2            4+-+     \|2 \|c \|x  + \|b
+--R       (442A c  - 234B b c)\|c atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R              2            4+-+     \|2 \|c \|x  - \|b
+--R       (442A c  - 234B b c)\|c atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R       -
+--R                5 +-+
+--R            128b \|2
+--R         *
+--R            ROOT
+--R                                4 9              3     8              2 2 2 7
+--R                   - 2385443281A c  + 5051526948A B b c  - 4011506694A B b c
+--R                 + 
+--R                                3 3 6             4 4 5
+--R                   1415825892A B b c  - 187388721B b c
+--R              /
+--R                          21
+--R                 16777216b
+--R           ,
+--R               4
+--R         *
+--R            4+-+
+--R            \|b
+--R         *
+--R            atan
+--R                          16
+--R                   262144b
+--R                *
+--R                     ROOT
+--R                                         4 9              3     8
+--R                            - 2385443281A c  + 5051526948A B b c
+--R                          + 
+--R                                         2 2 2 7                3 3 6
+--R                            - 4011506694A B b c  + 1415825892A B b c
+--R                          + 
+--R                                        4 4 5
+--R                            - 187388721B b c
+--R                       /
+--R                                   21
+--R                          16777216b
+--R                    ,
+--R                        4
+--R                  **
+--R                     3
+--R              /
+--R                              3 7            2     6             2 2 5
+--R                     10793861A c  - 17143191A B b c  + 9075807A B b c
+--R                   + 
+--R                               3 3 4
+--R                     - 1601613B b c
+--R                *
+--R                    +-+
+--R                   \|x
+--R  /
+--R        5 +-+4+-+
+--R     64b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1413
+
+--S 1414 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                         3           2  3              2         2    4+-+2
+--R               ((- 221A c  + 117B b c )x  + (- 221A b c  + 117B b c)x)\|b
+--R             + 
+--R                          2         2    +-+
+--R               (- 442A b c  + 234B b c)x\|b
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                   3           2  2           2         2   +-+4+-+2
+--R           ((221A c  - 117B b c )x  + 221A b c  - 117B b c)\|b \|b
+--R         + 
+--R                      3         2 2  2         2 2         3
+--R           (- 663A b c  + 351B b c )x  - 221A b c  + 117B b c
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R              3           2  2 +-+4+-+2 +-+
+--R       (442A c  - 234B b c )x \|b \|b  \|c
+--R     + 
+--R               4           3  3            3         2 2   4+-+2
+--R       ((221A c  - 117B b c )x  + (663A b c  - 351B b c )x)\|b
+--R  /
+--R              6   3       7  4+-+2          5   3       6   +-+4+-+2 +-+
+--R         (128b c x  + 128b x)\|c   + (- 128b c x  - 128b x)\|b \|b  \|c
+--R       + 
+--R               5 2 4       6   2      7 4+-+2
+--R         (- 64b c x  - 128b c x  - 64b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1414
+
+)clear all
+
+--S 1415 of 3139
+t0:=(A+B*x^2)/((b*x^2+c*x^4)^3*sqrt(x))
+--R 
+--R
+--R                           2
+--R                        B x  + A
+--R   (1)  ---------------------------------------
+--R          3 12       2 10     2   8    3 6  +-+
+--R        (c x   + 3b c x   + 3b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 1415
+
+--S 1416 of 3139
+r0:=15/176*(11*b*B-19*A*c)/(b^3*c*x^(11/2))-15/112*(11*b*B-19*A*c)/_
+   (b^4*x^(7/2))+5/16*c*(11*b*B-19*A*c)/(b^5*x^(3/2))+1/4*(-b*B+A*c)/_
+   (b*c*x^(11/2)*(b+c*x^2)^2)+1/16*(-11*b*B+19*A*c)/(b^2*c*x^(11/2)*_
+   (b+c*x^2))-15/32*c^(7/4)*(11*b*B-19*A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(23/4)*sqrt(2))+15/32*c^(7/4)*(11*b*B-19*A*c)*_
+   atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(23/4)*sqrt(2))-_
+   15/64*c^(7/4)*(11*b*B-19*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(23/4)*sqrt(2))+15/64*c^(7/4)*(11*b*B-19*A*c)*_
+   log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(23/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                      4             3  9                3           2 2  7
+--R           (- 21945A c  + 12705B b c )x  + (- 43890A b c  + 25410B b c )x
+--R         + 
+--R                      2 2           3   5
+--R           (- 21945A b c  + 12705B b c)x
+--R      *
+--R         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    4             3  9              3           2 2  7
+--R           (21945A c  - 12705B b c )x  + (43890A b c  - 25410B b c )x
+--R         + 
+--R                    2 2           3   5
+--R           (21945A b c  - 12705B b c)x
+--R      *
+--R         4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                      4             3  9                3           2 2  7
+--R           (- 43890A c  + 25410B b c )x  + (- 87780A b c  + 50820B b c )x
+--R         + 
+--R                      2 2           3   5
+--R           (- 43890A b c  + 25410B b c)x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|c \|x  + \|b
+--R         \|c  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|b
+--R     + 
+--R                      4             3  9                3           2 2  7
+--R           (- 43890A c  + 25410B b c )x  + (- 87780A b c  + 50820B b c )x
+--R         + 
+--R                      2 2           3   5
+--R           (- 43890A b c  + 25410B b c)x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|c \|x  - \|b
+--R         \|c  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|b
+--R     + 
+--R                      4             3  8                3           2 2  6
+--R           (- 29260A c  + 16940B b c )x  + (- 45980A b c  + 26620B b c )x
+--R         + 
+--R                      2 2          3   4           3           4  2         4
+--R           (- 12160A b c  + 7040B b c)x  + (2432A b c - 1408B b )x  - 896A b
+--R      *
+--R          +-+4+-+3
+--R         \|2 \|b
+--R  /
+--R           5 2 9        6   7        7 5  +-+4+-+3 +-+
+--R     (4928b c x  + 9856b c x  + 4928b x )\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 1416
+
+--S 1417 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 5 2 9        6   7        7 5
+--R         (- 1232b c x  - 2464b c x  - 1232b x )
+--R      *
+--R         ROOT
+--R                             4 11               3     10               2 2 2 9
+--R                - 6597500625A c   + 15278422500A B b c   - 13268103750A B b c
+--R              + 
+--R                             3 3 8             4 4 7
+--R                5121022500A B b c  - 741200625B b c
+--R           /
+--R                       23
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                     3           2  +-+
+--R              (285A c  - 165B b c )\|x
+--R            + 
+--R                   6
+--R                64b
+--R             *
+--R                ROOT
+--R                                    4 11               3     10
+--R                       - 6597500625A c   + 15278422500A B b c
+--R                     + 
+--R                                     2 2 2 9                3 3 8
+--R                       - 13268103750A B b c  + 5121022500A B b c
+--R                     + 
+--R                                   4 4 7
+--R                       - 741200625B b c
+--R                  /
+--R                              23
+--R                     16777216b
+--R               ,
+--R                   4
+--R     + 
+--R               5 2 9        6   7        7 5
+--R         (1232b c x  + 2464b c x  + 1232b x )
+--R      *
+--R         ROOT
+--R                             4 11               3     10               2 2 2 9
+--R                - 6597500625A c   + 15278422500A B b c   - 13268103750A B b c
+--R              + 
+--R                             3 3 8             4 4 7
+--R                5121022500A B b c  - 741200625B b c
+--R           /
+--R                       23
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         log
+--R                     3           2  +-+
+--R              (285A c  - 165B b c )\|x
+--R            + 
+--R              -
+--R                      6
+--R                   64b
+--R                *
+--R                   ROOT
+--R                                       4 11               3     10
+--R                          - 6597500625A c   + 15278422500A B b c
+--R                        + 
+--R                                        2 2 2 9                3 3 8
+--R                          - 13268103750A B b c  + 5121022500A B b c
+--R                        + 
+--R                                      4 4 7
+--R                          - 741200625B b c
+--R                     /
+--R                                 23
+--R                        16777216b
+--R                  ,
+--R                      4
+--R     + 
+--R               5 2 9        6   7        7 5
+--R         (2464b c x  + 4928b c x  + 2464b x )
+--R      *
+--R         ROOT
+--R                             4 11               3     10               2 2 2 9
+--R                - 6597500625A c   + 15278422500A B b c   - 13268103750A B b c
+--R              + 
+--R                             3 3 8             4 4 7
+--R                5121022500A B b c  - 741200625B b c
+--R           /
+--R                       23
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R          +-+
+--R         \|x
+--R      *
+--R         atan
+--R                   6
+--R                64b
+--R             *
+--R                ROOT
+--R                                    4 11               3     10
+--R                       - 6597500625A c   + 15278422500A B b c
+--R                     + 
+--R                                     2 2 2 9                3 3 8
+--R                       - 13268103750A B b c  + 5121022500A B b c
+--R                     + 
+--R                                   4 4 7
+--R                       - 741200625B b c
+--R                  /
+--R                              23
+--R                     16777216b
+--R               ,
+--R                   4
+--R           /
+--R                     3           2  +-+
+--R              (285A c  - 165B b c )\|x
+--R     + 
+--R                 4            3  8                3          2 2  6
+--R       (- 7315A c  + 4235B b c )x  + (- 11495A b c  + 6655B b c )x
+--R     + 
+--R                 2 2          3   4          3          4  2         4
+--R       (- 3040A b c  + 1760B b c)x  + (608A b c - 352B b )x  - 224A b
+--R  /
+--R           5 2 9        6   7        7 5  +-+
+--R     (1232b c x  + 2464b c x  + 1232b x )\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1417
+
+--S 1418 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2            4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (285A c  - 165B b c)\|c  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       -
+--R               5 +-+
+--R            64b \|2
+--R         *
+--R            ROOT
+--R                                4 11               3     10
+--R                   - 6597500625A c   + 15278422500A B b c
+--R                 + 
+--R                                 2 2 2 9                3 3 8             4 4 7
+--R                   - 13268103750A B b c  + 5121022500A B b c  - 741200625B b c
+--R              /
+--R                          23
+--R                 16777216b
+--R           ,
+--R               4
+--R         *
+--R            4+-+3
+--R            \|b
+--R         *
+--R            log
+--R                        3           2  +-+
+--R                 (285A c  - 165B b c )\|x
+--R               + 
+--R                      6
+--R                   64b
+--R                *
+--R                   ROOT
+--R                                       4 11               3     10
+--R                          - 6597500625A c   + 15278422500A B b c
+--R                        + 
+--R                                        2 2 2 9                3 3 8
+--R                          - 13268103750A B b c  + 5121022500A B b c
+--R                        + 
+--R                                      4 4 7
+--R                          - 741200625B b c
+--R                     /
+--R                                 23
+--R                        16777216b
+--R                  ,
+--R                      4
+--R     + 
+--R            5 +-+
+--R         64b \|2
+--R      *
+--R         ROOT
+--R                             4 11               3     10               2 2 2 9
+--R                - 6597500625A c   + 15278422500A B b c   - 13268103750A B b c
+--R              + 
+--R                             3 3 8             4 4 7
+--R                5121022500A B b c  - 741200625B b c
+--R           /
+--R                       23
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R         4+-+3
+--R         \|b
+--R      *
+--R         log
+--R                     3           2  +-+
+--R              (285A c  - 165B b c )\|x
+--R            + 
+--R              -
+--R                      6
+--R                   64b
+--R                *
+--R                   ROOT
+--R                                       4 11               3     10
+--R                          - 6597500625A c   + 15278422500A B b c
+--R                        + 
+--R                                        2 2 2 9                3 3 8
+--R                          - 13268103750A B b c  + 5121022500A B b c
+--R                        + 
+--R                                      4 4 7
+--R                          - 741200625B b c
+--R                     /
+--R                                 23
+--R                        16777216b
+--R                  ,
+--R                      4
+--R     + 
+--R                2            4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 285A c  + 165B b c)\|c  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                      +-+4+-+ +-+   4+-+
+--R              2            4+-+3     \|2 \|c \|x  + \|b
+--R       (570A c  - 330B b c)\|c  atan(-------------------)
+--R                                             4+-+
+--R                                             \|b
+--R     + 
+--R                                      +-+4+-+ +-+   4+-+
+--R              2            4+-+3     \|2 \|c \|x  - \|b
+--R       (570A c  - 330B b c)\|c  atan(-------------------)
+--R                                             4+-+
+--R                                             \|b
+--R     + 
+--R             5 +-+
+--R         128b \|2
+--R      *
+--R         ROOT
+--R                             4 11               3     10               2 2 2 9
+--R                - 6597500625A c   + 15278422500A B b c   - 13268103750A B b c
+--R              + 
+--R                             3 3 8             4 4 7
+--R                5121022500A B b c  - 741200625B b c
+--R           /
+--R                       23
+--R              16777216b
+--R        ,
+--R            4
+--R      *
+--R         4+-+3
+--R         \|b
+--R      *
+--R         atan
+--R                   6
+--R                64b
+--R             *
+--R                ROOT
+--R                                    4 11               3     10
+--R                       - 6597500625A c   + 15278422500A B b c
+--R                     + 
+--R                                     2 2 2 9                3 3 8
+--R                       - 13268103750A B b c  + 5121022500A B b c
+--R                     + 
+--R                                   4 4 7
+--R                       - 741200625B b c
+--R                  /
+--R                              23
+--R                     16777216b
+--R               ,
+--R                   4
+--R           /
+--R                     3           2  +-+
+--R              (285A c  - 165B b c )\|x
+--R  /
+--R        5 +-+4+-+3
+--R     64b \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 1418
+
+--S 1419 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    3           2  2 +-+ +-+            4           3  3
+--R           (- 570A c  + 330B b c )x \|b \|c  + (- 285A c  + 165B b c )x
+--R         + 
+--R                      3         2 2
+--R           (- 855A b c  + 495B b c )x
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                  3           2   +-+4+-+2          4           3  3
+--R           (570A c  - 330B b c )x\|b \|b   + (285A c  - 165B b c )x
+--R         + 
+--R                    3         2 2
+--R           (285A b c  - 165B b c )x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R               4           3  2           3         2 2 4+-+2
+--R       ((855A c  - 495B b c )x  + 285A b c  - 165B b c )\|b
+--R     + 
+--R                 4           3  2           3         2 2  +-+
+--R       ((- 285A c  + 165B b c )x  - 285A b c  + 165B b c )\|b
+--R  /
+--R              6   3       7  4+-+2          5   3       6   +-+4+-+2 +-+
+--R         (128b c x  + 128b x)\|c   + (- 128b c x  - 128b x)\|b \|b  \|c
+--R       + 
+--R               5 2 4       6   2      7 4+-+2
+--R         (- 64b c x  - 128b c x  - 64b )\|b
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 1419
+
+)clear all
+
+--S 1420 of 3139
+t0:=x^(9/2)*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                          +-----------+
+--R            6      4  +-+ |   4      2
+--R   (1)  (B x  + A x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1420
+
+--S 1421 of 3139
+--r0:=2/19*B*x^(7/2)*(b*x^2+c*x^4)^(3/2)/c+4/1463*b^(17/4)*(13*b*B-19*A*c)*_
+---  x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(17/4)*sqrt(b*x^2+c*x^4))+12/7315*b^2*(13*b*B-19*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^3-4/3135*b*(13*b*B-19*A*c)*x^(7/2)*sqrt(b*x^2+_
+---  c*x^4)/c^2-2/285*(13*b*B-19*A*c)*x^(11/2)*sqrt(b*x^2+c*x^4)/c-_
+---  4/1463*b^3*(13*b*B-19*A*c)*sqrt(b*x^2+c*x^4)/(c^4*sqrt(x))
+--E 1421
+
+--S 1422 of 3139
+--a0:=integrate(t0,x)
+--E 1422
+
+--S 1423 of 3139
+--m0:=a0-r0
+--E 1423
+
+--S 1424 of 3139
+--d0:=D(m0,x)
+--E 1424
+
+)clear all
+
+--S 1425 of 3139
+t0:=x^(7/2)*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                          +-----------+
+--R            5      3  +-+ |   4      2
+--R   (1)  (B x  + A x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1425
+
+--S 1426 of 3139
+--r0:=2/17*B*x^(5/2)*(b*x^2+c*x^4)^(3/2)/c+28/3315*b^(15/4)*(11*b*B-17*A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(15/4)*sqrt(b*x^2+c*x^4))-28/3315*b^(15/4)*(11*b*B-17*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(15/4)*sqrt(b*x^2+c*x^4))-4/1989*b*(11*b*B-17*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-2/221*(11*b*B-17*A*c)*x^(9/2)*sqrt(b*x^2+c*x^4)/_
+---  c+28/9945*b^2*(11*b*B-17*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^3
+--E 1426
+
+--S 1427 of 3139
+--a0:=integrate(t0,x)
+--E 1427
+
+--S 1428 of 3139
+--m0:=a0-r0
+--E 1428
+
+--S 1429 of 3139
+--d0:=D(m0,x)
+--E 1429
+
+)clear all
+
+--S 1430 of 3139
+t0:=x^(5/2)*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                          +-----------+
+--R            4      2  +-+ |   4      2
+--R   (1)  (B x  + A x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1430
+
+--S 1431 of 3139
+--r0:=2/15*B*x^(3/2)*(b*x^2+c*x^4)^(3/2)/c+4/231*b^(13/4)*(3*b*B-5*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(13/4)*sqrt(b*x^2+c*x^4))-4/385*b*(3*b*B-5*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-2/55*(3*b*B-5*A*c)*x^(7/2)*sqrt(b*x^2+c*x^4)/c+_
+---  4/231*b^2*(3*b*B-5*A*c)*sqrt(b*x^2+c*x^4)/(c^3*sqrt(x))
+--E 1431
+
+--S 1432 of 3139
+--a0:=integrate(t0,x)
+--E 1432
+
+--S 1433 of 3139
+--m0:=a0-r0
+--E 1433
+
+--S 1434 of 3139
+--d0:=D(m0,x)
+--E 1434
+
+)clear all
+
+--S 1435 of 3139
+t0:=x^(3/2)*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                         +-----------+
+--R            3        +-+ |   4      2
+--R   (1)  (B x  + A x)\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1435
+
+--S 1436 of 3139
+--r0:=2/13*B*(b*x^2+c*x^4)^(3/2)*sqrt(x)/c+4/195*b^(11/4)*(7*b*B-13*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))-4/195*b^(11/4)*(7*b*B-13*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))-2/117*(7*b*B-13*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c-4/585*b*(7*b*B-13*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^2
+--E 1436
+
+--S 1437 of 3139
+--a0:=integrate(t0,x)
+--E 1437
+
+--S 1438 of 3139
+--m0:=a0-r0
+--E 1438
+
+--S 1439 of 3139
+--d0:=D(m0,x)
+--E 1439
+
+)clear all
+
+--S 1440 of 3139
+t0:=(A+B*x^2)*sqrt(x)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                       +-----------+
+--R            2      +-+ |   4      2
+--R   (1)  (B x  + A)\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1440
+
+--S 1441 of 3139
+--r0:=2/11*B*(b*x^2+c*x^4)^(3/2)/(c*sqrt(x))+4/231*b^(9/4)*(5*b*B-11*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(9/4)*sqrt(b*x^2+c*x^4))-2/77*(5*b*B-11*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c-4/231*b*(5*b*B-11*A*c)*sqrt(b*x^2+c*x^4)/(c^2*sqrt(x))
+--E 1441
+
+--S 1442 of 3139
+--a0:=integrate(t0,x)
+--E 1442
+
+--S 1443 of 3139
+--m0:=a0-r0
+--E 1443
+
+--S 1444 of 3139
+--d0:=D(m0,x)
+--E 1444
+
+)clear all
+
+--S 1445 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/sqrt(x)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                   +-+
+--R                  \|x
+--R                                                    Type: Expression(Integer)
+--E 1445
+
+--S 1446 of 3139
+--r0:=2/9*B*(b*x^2+c*x^4)^(3/2)/(c*x^(3/2))+4/15*b^(7/4)*(b*B-3*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(7/4)*sqrt(b*x^2+c*x^4))-4/15*b^(7/4)*(b*B-3*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(7/4)*sqrt(b*x^2+c*x^4))-2/15*(b*B-3*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/c
+--E 1446
+
+--S 1447 of 3139
+--a0:=integrate(t0,x)
+--E 1447
+
+--S 1448 of 3139
+--m0:=a0-r0
+--E 1448
+
+--S 1449 of 3139
+--d0:=D(m0,x)
+--E 1449
+
+)clear all
+
+--S 1450 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(3/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    +-+
+--R                  x\|x
+--R                                                    Type: Expression(Integer)
+--E 1450
+
+--S 1451 of 3139
+--r0:=2/7*B*(b*x^2+c*x^4)^(3/2)/(c*x^(5/2))+4/21*b^(5/4)*(b*B-7*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(5/4)*sqrt(b*x^2+c*x^4))-2/21*(b*B-7*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (c*sqrt(x))
+--E 1451
+
+--S 1452 of 3139
+--a0:=integrate(t0,x)
+--E 1452
+
+--S 1453 of 3139
+--m0:=a0-r0
+--E 1453
+
+--S 1454 of 3139
+--d0:=D(m0,x)
+--E 1454
+
+)clear all
+
+--S 1455 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(5/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  2 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 1455
+
+--S 1456 of 3139
+--r0:=-2*A*(b*x^2+c*x^4)^(3/2)/(b*x^(7/2))+4/5*b^(3/4)*(b*B+5*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(3/4)*sqrt(b*x^2+c*x^4))-4/5*b^(3/4)*(b*B+5*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(3/4)*sqrt(b*x^2+c*x^4))+2/5*(b*B+5*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/b
+--E 1456
+
+--S 1457 of 3139
+--a0:=integrate(t0,x)
+--E 1457
+
+--S 1458 of 3139
+--m0:=a0-r0
+--E 1458
+
+--S 1459 of 3139
+--d0:=D(m0,x)
+--E 1459
+
+)clear all
+
+--S 1460 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(7/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  3 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 1460
+
+--S 1461 of 3139
+--r0:=-2/3*A*(b*x^2+c*x^4)^(3/2)/(b*x^(9/2))+4/3*b^(1/4)*(b*B+A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(1/4)*sqrt(b*x^2+c*x^4))+2/3*(b*B+A*c)*sqrt(b*x^2+c*x^4)/(b*sqrt(x))
+--E 1461
+
+--S 1462 of 3139
+--a0:=integrate(t0,x)
+--E 1462
+
+--S 1463 of 3139
+--m0:=a0-r0
+--E 1463
+
+--S 1464 of 3139
+--d0:=D(m0,x)
+--E 1464
+
+)clear all
+
+--S 1465 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(9/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  4 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 1465
+
+--S 1466 of 3139
+--r0:=-2/5*A*(b*x^2+c*x^4)^(3/2)/(b*x^(11/2))-4/5*(-c)^(1/4)*(5*b*B+A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*sqrt(b*x^2+c*x^4))+4/5*(-c)^(1/4)*(5*b*B+A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*sqrt(b*x^2+c*x^4))-2/5*(5*b*B+A*c)*sqrt(b*x^2+c*x^4)/(b*x^(3/2))
+--E 1466
+
+--S 1467 of 3139
+--a0:=integrate(t0,x)
+--E 1467
+
+--S 1468 of 3139
+--m0:=a0-r0
+--E 1468
+
+--S 1469 of 3139
+--d0:=D(m0,x)
+--E 1469
+
+)clear all
+
+--S 1470 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(11/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  5 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 1470
+
+--S 1471 of 3139
+--r0:=-2/7*A*(b*x^2+c*x^4)^(3/2)/(b*x^(13/2))-4/21*(-c)^(3/4)*(7*b*B-A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(3/4)*sqrt(b*x^2+c*x^4))-2/21*(7*b*B-A*c)*sqrt(b*x^2+c*x^4)/(b*x^(5/2))
+--E 1471
+
+--S 1472 of 3139
+--a0:=integrate(t0,x)
+--E 1472
+
+--S 1473 of 3139
+--m0:=a0-r0
+--E 1473
+
+--S 1474 of 3139
+--d0:=D(m0,x)
+--E 1474
+
+)clear all
+
+--S 1475 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(13/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  6 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 1475
+
+--S 1476 of 3139
+--r0:=-2/9*A*(b*x^2+c*x^4)^(3/2)/(b*x^(15/2))+4/15*(-c)^(5/4)*(3*b*B-A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(5/4)*sqrt(b*x^2+c*x^4))-4/15*(-c)^(5/4)*(3*b*B-A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(5/4)*sqrt(b*x^2+c*x^4))-2/15*(3*b*B-A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b*x^(7/2))-4/15*c*(3*b*B-A*c)*sqrt(b*x^2+c*x^4)/(b^2*x^(3/2))
+--E 1476
+
+--S 1477 of 3139
+--a0:=integrate(t0,x)
+--E 1477
+
+--S 1478 of 3139
+--m0:=a0-r0
+--E 1478
+
+--S 1479 of 3139
+--d0:=D(m0,x)
+--E 1479
+
+)clear all
+
+--S 1480 of 3139
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(15/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  7 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 1480
+
+--S 1481 of 3139
+--r0:=-2/11*A*(b*x^2+c*x^4)^(3/2)/(b*x^(17/2))-4/231*(-c)^(7/4)*_
+---  (11*b*B-5*A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/(b^(7/4)*sqrt(b*x^2+c*x^4))-2/77*(11*b*B-5*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b*x^(9/2))-4/231*c*(11*b*B-5*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^2*x^(5/2))
+--E 1481
+
+--S 1482 of 3139
+--a0:=integrate(t0,x)
+--E 1482
+
+--S 1483 of 3139
+--m0:=a0-r0
+--E 1483
+
+--S 1484 of 3139
+--d0:=D(m0,x)
+--E 1484
+
+)clear all
+
+--S 1485 of 3139
+t0:=x^(7/2)*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                              +-----------+
+--R              9               7        5  +-+ |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1485
+
+--S 1486 of 3139
+--r0:=-2/105*(3*b*B-5*A*c)*x^(9/2)*(b*x^2+c*x^4)^(3/2)/c+2/25*B*x^(5/2)*_
+---  (b*x^2+c*x^4)^(5/2)/c+88/16575*b^(23/4)*(3*b*B-5*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(19/4)*sqrt(b*x^2+c*x^4))-88/16575*b^(23/4)*(3*b*B-5*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(19/4)*sqrt(b*x^2+c*x^4))+88/69615*b^3*(3*b*B-5*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c^3-8/7735*b^2*(3*b*B-5*A*c)*x^(9/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-4/595*b*(3*b*B-5*A*c)*x^(13/2)*_
+---  sqrt(b*x^2+c*x^4)/c-88/49725*b^4*(3*b*B-5*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/c^4
+--E 1486
+
+--S 1487 of 3139
+--a0:=integrate(t0,x)
+--E 1487
+
+--S 1488 of 3139
+--m0:=a0-r0
+--E 1488
+
+--S 1489 of 3139
+--d0:=D(m0,x)
+--E 1489
+
+)clear all
+
+--S 1490 of 3139
+t0:=x^(5/2)*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                              +-----------+
+--R              8               6        4  +-+ |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1490
+
+--S 1491 of 3139
+--r0:=-2/437*(13*b*B-23*A*c)*x^(7/2)*(b*x^2+c*x^4)^(3/2)/c+2/23*B*x^(3/2)*_
+---  (b*x^2+c*x^4)^(5/2)/c+24/33649*b^(21/4)*(13*b*B-23*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(17/4)*sqrt(b*x^2+c*x^4))+72/168245*b^3*(13*b*B-23*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^3-8/24035*b^2*(13*b*B-23*A*c)*x^(7/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-4/2185*b*(13*b*B-23*A*c)*x^(11/2)*_
+---  sqrt(b*x^2+c*x^4)/c-24/33649*b^4*(13*b*B-23*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (c^4*sqrt(x))
+--E 1491
+
+--S 1492 of 3139
+--a0:=integrate(t0,x)
+--E 1492
+
+--S 1493 of 3139
+--m0:=a0-r0
+--E 1493
+
+--S 1494 of 3139
+--d0:=D(m0,x)
+--E 1494
+
+)clear all
+
+--S 1495 of 3139
+t0:=x^(3/2)*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                              +-----------+
+--R              7               5        3  +-+ |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1495
+
+--S 1496 of 3139
+--r0:=-2/357*(11*b*B-21*A*c)*x^(5/2)*(b*x^2+c*x^4)^(3/2)/c+_
+---  2/21*B*(b*x^2+c*x^4)^(5/2)*sqrt(x)/c+8/3315*b^(19/4)*(11*b*B-21*A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(15/4)*sqrt(b*x^2+c*x^4))-8/3315*b^(19/4)*(11*b*B-21*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(15/4)*sqrt(b*x^2+c*x^4))-8/13923*b^2*(11*b*B-21*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-4/1547*b*(11*b*B-21*A*c)*x^(9/2)*_
+---  sqrt(b*x^2+c*x^4)/c+8/9945*b^3*(11*b*B-21*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/c^3
+--E 1496
+
+--S 1497 of 3139
+--a0:=integrate(t0,x)
+--E 1497
+
+--S 1498 of 3139
+--m0:=a0-r0
+--E 1498
+
+--S 1499 of 3139
+--d0:=D(m0,x)
+--E 1499
+
+)clear all
+
+--S 1500 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)*sqrt(x)
+--R 
+--R
+--R                                              +-----------+
+--R              6               4        2  +-+ |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1500
+
+--S 1501 of 3139
+--r0:=-2/285*(9*b*B-19*A*c)*x^(3/2)*(b*x^2+c*x^4)^(3/2)/c+2/19*B*_
+---  (b*x^2+c*x^4)^(5/2)/(c*sqrt(x))+8/4389*b^(17/4)*(9*b*B-19*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(13/4)*sqrt(b*x^2+c*x^4))-8/7315*b^2*(9*b*B-19*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-4/1045*b*(9*b*B-19*A*c)*x^(7/2)*_
+---  sqrt(b*x^2+c*x^4)/c+8/4389*b^3*(9*b*B-19*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (c^3*sqrt(x))
+--E 1501
+
+--S 1502 of 3139
+--a0:=integrate(t0,x)
+--E 1502
+
+--S 1503 of 3139
+--m0:=a0-r0
+--E 1503
+
+--S 1504 of 3139
+--d0:=D(m0,x)
+--E 1504
+
+)clear all
+
+--S 1505 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/sqrt(x)
+--R 
+--R
+--R                                          +-----------+
+--R              6               4        2  |   4      2
+--R        (B c x  + (A c + B b)x  + A b x )\|c x  + b x
+--R   (1)  -----------------------------------------------
+--R                               +-+
+--R                              \|x
+--R                                                    Type: Expression(Integer)
+--E 1505
+
+--S 1506 of 3139
+--r0:=2/17*B*(b*x^2+c*x^4)^(5/2)/(c*x^(3/2))-2/221*(7*b*B-17*A*c)*_
+---  (b*x^2+c*x^4)^(3/2)*sqrt(x)/c+8/1105*b^(15/4)*(7*b*B-17*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))-8/1105*b^(15/4)*(7*b*B-17*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))-4/663*b*(7*b*B-17*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c-8/3315*b^2*(7*b*B-17*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/c^2
+--E 1506
+
+--S 1507 of 3139
+--a0:=integrate(t0,x)
+--E 1507
+
+--S 1508 of 3139
+--m0:=a0-r0
+--E 1508
+
+--S 1509 of 3139
+--d0:=D(m0,x)
+--E 1509
+
+)clear all
+
+--S 1510 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(3/2)
+--R 
+--R
+--R                                         +-----------+
+--R              5               3          |   4      2
+--R        (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  ----------------------------------------------
+--R                              +-+
+--R                             \|x
+--R                                                    Type: Expression(Integer)
+--E 1510
+
+--S 1511 of 3139
+--r0:=2/15*B*(b*x^2+c*x^4)^(5/2)/(c*x^(5/2))-2/33*(b*B-3*A*c)*_
+---  (b*x^2+c*x^4)^(3/2)/(c*sqrt(x))+8/231*b^(13/4)*(b*B-3*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(9/4)*sqrt(b*x^2+c*x^4))-4/77*b*(b*B-3*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c-8/231*b^2*(b*B-3*A*c)*sqrt(b*x^2+c*x^4)/(c^2*sqrt(x))
+--E 1511
+
+--S 1512 of 3139
+--a0:=integrate(t0,x)
+--E 1512
+
+--S 1513 of 3139
+--m0:=a0-r0
+--E 1513
+
+--S 1514 of 3139
+--d0:=D(m0,x)
+--E 1514
+
+)clear all
+
+--S 1515 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(5/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                             +-+
+--R                            \|x
+--R                                                    Type: Expression(Integer)
+--E 1515
+
+--S 1516 of 3139
+--r0:=-2/117*(3*b*B-13*A*c)*(b*x^2+c*x^4)^(3/2)/(c*x^(3/2))+_
+---  2/13*B*(b*x^2+c*x^4)^(5/2)/(c*x^(7/2))+8/195*b^(11/4)*(3*b*B-13*A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(7/4)*sqrt(b*x^2+c*x^4))-8/195*b^(11/4)*(3*b*B-13*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(7/4)*sqrt(b*x^2+c*x^4))-4/195*b*(3*b*B-13*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/c
+--E 1516
+
+--S 1517 of 3139
+--a0:=integrate(t0,x)
+--E 1517
+
+--S 1518 of 3139
+--m0:=a0-r0
+--E 1518
+
+--S 1519 of 3139
+--d0:=D(m0,x)
+--E 1519
+
+)clear all
+
+--S 1520 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(7/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              +-+
+--R                            x\|x
+--R                                                    Type: Expression(Integer)
+--E 1520
+
+--S 1521 of 3139
+--r0:=-2/77*(b*B-11*A*c)*(b*x^2+c*x^4)^(3/2)/(c*x^(5/2))+_
+---  2/11*B*(b*x^2+c*x^4)^(5/2)/(c*x^(9/2))+8/77*b^(9/4)*(b*B-11*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(5/4)*sqrt(b*x^2+c*x^4))-4/77*b*(b*B-11*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(c*sqrt(x))
+--E 1521
+
+--S 1522 of 3139
+--a0:=integrate(t0,x)
+--E 1522
+
+--S 1523 of 3139
+--m0:=a0-r0
+--E 1523
+
+--S 1524 of 3139
+--d0:=D(m0,x)
+--E 1524
+
+)clear all
+
+--S 1525 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(9/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                            2 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 1525
+
+--S 1526 of 3139
+--r0:=2/9*(b*B+9*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^(3/2))-_
+---  2*A*(b*x^2+c*x^4)^(5/2)/(b*x^(11/2))+8/15*b^(7/4)*(b*B+9*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(3/4)*sqrt(b*x^2+c*x^4))-8/15*b^(7/4)*(b*B+9*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(3/4)*sqrt(b*x^2+c*x^4))+4/15*(b*B+9*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)
+--E 1526
+
+--S 1527 of 3139
+--a0:=integrate(t0,x)
+--E 1527
+
+--S 1528 of 3139
+--m0:=a0-r0
+--E 1528
+
+--S 1529 of 3139
+--d0:=D(m0,x)
+--E 1529
+
+)clear all
+
+--S 1530 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(11/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                            3 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 1530
+
+--S 1531 of 3139
+--r0:=2/21*(3*b*B+7*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^(5/2))-_
+---  2/3*A*(b*x^2+c*x^4)^(5/2)/(b*x^(13/2))+8/21*b^(5/4)*(3*b*B+7*A*c)*_
+---  x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(1/4)*sqrt(b*x^2+c*x^4))+4/21*(3*b*B+7*A*c)*sqrt(b*x^2+c*x^4)/_
+---  sqrt(x)
+--E 1531
+
+--S 1532 of 3139
+--a0:=integrate(t0,x)
+--E 1532
+
+--S 1533 of 3139
+--m0:=a0-r0
+--E 1533
+
+--S 1534 of 3139
+--d0:=D(m0,x)
+--E 1534
+
+)clear all
+
+--S 1535 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(13/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                            4 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 1535
+
+--S 1536 of 3139
+--r0:=-2*(b*B+A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^(7/2))-2/5*A*_
+---  (b*x^2+c*x^4)^(5/2)/(b*x^(15/2))-24/5*b^(3/4)*(-c)^(1/4)*(b*B+A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  sqrt(b*x^2+c*x^4)+24/5*b^(3/4)*(-c)^(1/4)*(b*B+A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  sqrt(b*x^2+c*x^4)+12/5*c*(b*B+A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/b
+--E 1536
+
+--S 1537 of 3139
+--a0:=integrate(t0,x)
+--E 1537
+
+--S 1538 of 3139
+--m0:=a0-r0
+--E 1538
+
+--S 1539 of 3139
+--d0:=D(m0,x)
+--E 1539
+
+)clear all
+
+--S 1540 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(15/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                            5 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 1540
+
+--S 1541 of 3139
+--r0:=-2/21*(7*b*B+3*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^(9/2))-_
+---  2/7*A*(b*x^2+c*x^4)^(5/2)/(b*x^(17/2))-8/21*b^(1/4)*(-c)^(3/4)*_
+---  (7*b*B+3*A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/sqrt(b*x^2+c*x^4)+4/21*c*(7*b*B+3*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b*sqrt(x))
+--E 1541
+
+--S 1542 of 3139
+--a0:=integrate(t0,x)
+--E 1542
+
+--S 1543 of 3139
+--m0:=a0-r0
+--E 1543
+
+--S 1544 of 3139
+--d0:=D(m0,x)
+--E 1544
+
+)clear all
+
+--S 1545 of 3139
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(17/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                            6 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 1545
+
+--S 1546 of 3139
+--r0:=-2/45*(9*b*B+A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^(11/2))-_
+---  2/9*A*(b*x^2+c*x^4)^(5/2)/(b*x^(19/2))+8/15*(-c)^(5/4)*(9*b*B+A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*sqrt(b*x^2+c*x^4))-8/15*(-c)^(5/4)*(9*b*B+A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*sqrt(b*x^2+c*x^4))-4/15*c*(9*b*B+A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b*x^(3/2))
+--E 1546
+
+--S 1547 of 3139
+--a0:=integrate(t0,x)
+--E 1547
+
+--S 1548 of 3139
+--m0:=a0-r0
+--E 1548
+
+--S 1549 of 3139
+--d0:=D(m0,x)
+--E 1549
+
+)clear all
+
+--S 1550 of 3139
+t0:=x^(15/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            9      7  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1550
+
+--S 1551 of 3139
+--r0:=154/3315*b^(15/4)*(15*b*B-17*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(19/4)*sqrt(b*x^2+_
+---  c*x^4))-154/3315*b^(15/4)*(15*b*B-17*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(19/4)*sqrt(b*x^2+c*x^4))+22/1989*b*(15*b*B-17*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c^3-2/221*(15*b*B-17*A*c)*x^(9/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2+2/17*B*x^(13/2)*sqrt(b*x^2+c*x^4)/c-_
+---  154/9945*b^2*(15*b*B-17*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^4
+--E 1551
+
+--S 1552 of 3139
+--a0:=integrate(t0,x)
+--E 1552
+
+--S 1553 of 3139
+--m0:=a0-r0
+--E 1553
+
+--S 1554 of 3139
+--d0:=D(m0,x)
+--E 1554
+
+)clear all
+
+--S 1555 of 3139
+t0:=x^(13/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            8      6  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1555
+
+--S 1556 of 3139
+--r0:=2/77*b^(13/4)*(13*b*B-15*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(17/4)*_
+---  sqrt(b*x^2+c*x^4))+6/385*b*(13*b*B-15*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^3-2/165*(13*b*B-15*A*c)*x^(7/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2+2/15*B*x^(11/2)*sqrt(b*x^2+c*x^4)/c-_
+---  2/77*b^2*(13*b*B-15*A*c)*sqrt(b*x^2+c*x^4)/(c^4*sqrt(x))
+--E 1556
+
+--S 1557 of 3139
+--a0:=integrate(t0,x)
+--E 1557
+
+--S 1558 of 3139
+--m0:=a0-r0
+--E 1558
+
+--S 1559 of 3139
+--d0:=D(m0,x)
+--E 1559
+
+)clear all
+
+--S 1560 of 3139
+t0:=x^(11/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            7      5  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1560
+
+--S 1561 of 3139
+--r0:=14/195*b^(11/4)*(11*b*B-13*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(15/4)*_
+---  sqrt(b*x^2+c*x^4))-14/195*b^(11/4)*(11*b*B-13*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(15/4)*sqrt(b*x^2+c*x^4))-2/117*(11*b*B-13*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2+2/13*B*x^(9/2)*sqrt(b*x^2+c*x^4)/c+_
+---  14/585*b*(11*b*B-13*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^3
+--E 1561
+
+--S 1562 of 3139
+--a0:=integrate(t0,x)
+--E 1562
+
+--S 1563 of 3139
+--m0:=a0-r0
+--E 1563
+
+--S 1564 of 3139
+--d0:=D(m0,x)
+--E 1564
+
+)clear all
+
+--S 1565 of 3139
+t0:=x^(9/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            6      4  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1565
+
+--S 1566 of 3139
+--r0:=10/231*b^(9/4)*(9*b*B-11*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(13/4)*_
+---  sqrt(b*x^2+c*x^4))-2/77*(9*b*B-11*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2+2/11*B*x^(7/2)*sqrt(b*x^2+c*x^4)/c+10/231*b*_
+---  (9*b*B-11*A*c)*sqrt(b*x^2+c*x^4)/(c^3*sqrt(x))
+--E 1566
+
+--S 1567 of 3139
+--a0:=integrate(t0,x)
+--E 1567
+
+--S 1568 of 3139
+--m0:=a0-r0
+--E 1568
+
+--S 1569 of 3139
+--d0:=D(m0,x)
+--E 1569
+
+)clear all
+
+--S 1570 of 3139
+t0:=x^(7/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            5      3  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1570
+
+--S 1571 of 3139
+--r0:=2/15*b^(7/4)*(7*b*B-9*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(11/4)*_
+---  sqrt(b*x^2+c*x^4))-2/15*b^(7/4)*(7*b*B-9*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))+2/9*B*x^(5/2)*sqrt(b*x^2+c*x^4)/c-_
+---  2/45*(7*b*B-9*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^2
+--E 1571
+
+--S 1572 of 3139
+--a0:=integrate(t0,x)
+--E 1572
+
+--S 1573 of 3139
+--m0:=a0-r0
+--E 1573
+
+--S 1574 of 3139
+--d0:=D(m0,x)
+--E 1574
+
+)clear all
+
+--S 1575 of 3139
+t0:=x^(5/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            4      2  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1575
+
+--S 1576 of 3139
+--r0:=2/21*b^(5/4)*(5*b*B-7*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(9/4)*sqrt(b*x^2+c*x^4))+_
+---  2/7*B*x^(3/2)*sqrt(b*x^2+c*x^4)/c-2/21*(5*b*B-7*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(c^2*sqrt(x))
+--E 1576
+
+--S 1577 of 3139
+--a0:=integrate(t0,x)
+--E 1577
+
+--S 1578 of 3139
+--m0:=a0-r0
+--E 1578
+
+--S 1579 of 3139
+--d0:=D(m0,x)
+--E 1579
+
+)clear all
+
+--S 1580 of 3139
+t0:=x^(3/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            3        +-+
+--R        (B x  + A x)\|x
+--R   (1)  ----------------
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1580
+
+--S 1581 of 3139
+--r0:=2/5*b^(3/4)*(3*b*B-5*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(7/4)*sqrt(b*x^2+c*x^4))-_
+---  2/5*b^(3/4)*(3*b*B-5*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(7/4)*_
+---  sqrt(b*x^2+c*x^4))+2/5*B*sqrt(x)*sqrt(b*x^2+c*x^4)/c
+--E 1581
+
+--S 1582 of 3139
+--a0:=integrate(t0,x)
+--E 1582
+
+--S 1583 of 3139
+--m0:=a0-r0
+--E 1583
+
+--S 1584 of 3139
+--d0:=D(m0,x)
+--E 1584
+
+)clear all
+
+--S 1585 of 3139
+t0:=(A+B*x^2)*sqrt(x)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            2      +-+
+--R        (B x  + A)\|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1585
+
+--S 1586 of 3139
+--r0:=2/3*b^(1/4)*(b*B-3*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(5/4)*_
+---  sqrt(b*x^2+c*x^4))+2/3*B*sqrt(b*x^2+c*x^4)/(c*sqrt(x))
+--E 1586
+
+--S 1587 of 3139
+--a0:=integrate(t0,x)
+--E 1587
+
+--S 1588 of 3139
+--m0:=a0-r0
+--E 1588
+
+--S 1589 of 3139
+--d0:=D(m0,x)
+--E 1589
+
+)clear all
+
+--S 1590 of 3139
+t0:=(A+B*x^2)/(sqrt(x)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  ------------------
+--R             +-----------+
+--R         +-+ |   4      2
+--R        \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1590
+
+--S 1591 of 3139
+--r0:=2*(b*B+A*c)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/(b^(1/4)*(-c)^(3/4)*sqrt(b*x^2+c*x^4))-_
+---  2*(b*B+A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/(b^(1/4)*(-c)^(3/4)*sqrt(b*x^2+c*x^4))-_
+---  2*A*sqrt(b*x^2+c*x^4)/(b*x^(3/2))
+--E 1591
+
+--S 1592 of 3139
+--a0:=integrate(t0,x)
+--E 1592
+
+--S 1593 of 3139
+--m0:=a0-r0
+--E 1593
+
+--S 1594 of 3139
+--d0:=D(m0,x)
+--E 1594
+
+)clear all
+
+--S 1595 of 3139
+t0:=(A+B*x^2)/(x^(3/2)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  -------------------
+--R              +-----------+
+--R          +-+ |   4      2
+--R        x\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1595
+
+--S 1596 of 3139
+--r0:=2/3*(3*b*B-A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/(b^(3/4)*(-c)^(1/4)*sqrt(b*x^2+c*x^4))-_
+---  2/3*A*sqrt(b*x^2+c*x^4)/(b*x^(5/2))
+--E 1596
+
+--S 1597 of 3139
+--a0:=integrate(t0,x)
+--E 1597
+
+--S 1598 of 3139
+--m0:=a0-r0
+--E 1598
+
+--S 1599 of 3139
+--d0:=D(m0,x)
+--E 1599
+
+)clear all
+
+--S 1600 of 3139
+t0:=(A+B*x^2)/(x^(5/2)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  --------------------
+--R               +-----------+
+--R         2 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1600
+
+--S 1601 of 3139
+--r0:=-2/5*(-c)^(1/4)*(5*b*B-3*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(5/4)*sqrt(b*x^2+c*x^4))+_
+---  2/5*(-c)^(1/4)*(5*b*B-3*A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/_
+---  b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(5/4)*sqrt(b*x^2+c*x^4))-_
+---  2/5*A*sqrt(b*x^2+c*x^4)/(b*x^(7/2))-2/5*(5*b*B-3*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^2*x^(3/2))
+--E 1601
+
+--S 1602 of 3139
+--a0:=integrate(t0,x)
+--E 1602
+
+--S 1603 of 3139
+--m0:=a0-r0
+--E 1603
+
+--S 1604 of 3139
+--d0:=D(m0,x)
+--E 1604
+
+)clear all
+
+--S 1605 of 3139
+t0:=(A+B*x^2)/(x^(7/2)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  --------------------
+--R               +-----------+
+--R         3 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1605
+
+--S 1606 of 3139
+--r0:=2/21*(-c)^(3/4)*(7*b*B-5*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(7/4)*sqrt(b*x^2+c*x^4))-_
+---  2/7*A*sqrt(b*x^2+c*x^4)/(b*x^(9/2))-2/21*(7*b*B-5*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^2*x^(5/2))
+--E 1606
+
+--S 1607 of 3139
+--a0:=integrate(t0,x)
+--E 1607
+
+--S 1608 of 3139
+--m0:=a0-r0
+--E 1608
+
+--S 1609 of 3139
+--d0:=D(m0,x)
+--E 1609
+
+)clear all
+
+--S 1610 of 3139
+t0:=(A+B*x^2)/(x^(9/2)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  --------------------
+--R               +-----------+
+--R         4 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1610
+
+--S 1611 of 3139
+--r0:=-2/15*(-c)^(5/4)*(9*b*B-7*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(9/4)*sqrt(b*x^2+c*x^4))+_
+---  2/15*(-c)^(5/4)*(9*b*B-7*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(9/4)*sqrt(b*x^2+c*x^4))-_
+---  2/9*A*sqrt(b*x^2+c*x^4)/(b*x^(11/2))-2/45*(9*b*B-7*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^2*x^(7/2))+2/15*c*(9*b*B-7*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^3*x^(3/2))
+--E 1611
+
+--S 1612 of 3139
+--a0:=integrate(t0,x)
+--E 1612
+
+--S 1613 of 3139
+--m0:=a0-r0
+--E 1613
+
+--S 1614 of 3139
+--d0:=D(m0,x)
+--E 1614
+
+)clear all
+
+--S 1615 of 3139
+t0:=(A+B*x^2)/(x^(11/2)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  --------------------
+--R               +-----------+
+--R         5 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1615
+
+--S 1616 of 3139
+--r0:=10/231*(-c)^(7/4)*(11*b*B-9*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(11/4)*sqrt(b*x^2+c*x^4))-_
+---  2/11*A*sqrt(b*x^2+c*x^4)/(b*x^(13/2))-2/77*(11*b*B-9*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^2*x^(9/2))+10/231*c*(11*b*B-9*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^3*x^(5/2))
+--E 1616
+
+--S 1617 of 3139
+--a0:=integrate(t0,x)
+--E 1617
+
+--S 1618 of 3139
+--m0:=a0-r0
+--E 1618
+
+--S 1619 of 3139
+--d0:=D(m0,x)
+--E 1619
+
+)clear all
+
+--S 1620 of 3139
+t0:=x^(17/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                8      6  +-+
+--R            (B x  + A x )\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1620
+
+--S 1621 of 3139
+--r0:=-(b*B-A*c)*x^(15/2)/(b*c*sqrt(b*x^2+c*x^4))-15/77*b^(9/4)*_
+---  (13*b*B-11*A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/((-c)^(17/4)*sqrt(b*x^2+c*x^4))-9/77*(13*b*B-11*A*c)*_
+---  x^(3/2)*sqrt(b*x^2+c*x^4)/c^3+1/11*(13*b*B-11*A*c)*x^(7/2)*_
+---  sqrt(b*x^2+c*x^4)/(b*c^2)+15/77*b*(13*b*B-11*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(c^4*sqrt(x))
+--E 1621
+
+--S 1622 of 3139
+--a0:=integrate(t0,x)
+--E 1622
+
+--S 1623 of 3139
+--m0:=a0-r0
+--E 1623
+
+--S 1624 of 3139
+--d0:=D(m0,x)
+--E 1624
+
+)clear all
+
+--S 1625 of 3139
+t0:=x^(15/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                7      5  +-+
+--R            (B x  + A x )\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1625
+
+--S 1626 of 3139
+--r0:=-(b*B-A*c)*x^(13/2)/(b*c*sqrt(b*x^2+c*x^4))-7/15*b^(7/4)*_
+---  (11*b*B-9*A*c)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/((-c)^(15/4)*sqrt(b*x^2+c*x^4))+7/15*b^(7/4)*_
+---  (11*b*B-9*A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/((-c)^(15/4)*sqrt(b*x^2+c*x^4))+_
+---  1/9*(11*b*B-9*A*c)*x^(5/2)*sqrt(b*x^2+c*x^4)/(b*c^2)-_
+---  7/45*(11*b*B-9*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^3
+--E 1626
+
+--S 1627 of 3139
+--a0:=integrate(t0,x)
+--E 1627
+
+--S 1628 of 3139
+--m0:=a0-r0
+--E 1628
+
+--S 1629 of 3139
+--d0:=D(m0,x)
+--E 1629
+
+)clear all
+
+--S 1630 of 3139
+t0:=x^(13/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                6      4  +-+
+--R            (B x  + A x )\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1630
+
+--S 1631 of 3139
+--r0:=-(b*B-A*c)*x^(11/2)/(b*c*sqrt(b*x^2+c*x^4))-5/21*b^(5/4)*(9*b*B-7*A*c)*_
+---  x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(13/4)*sqrt(b*x^2+c*x^4))+1/7*(9*b*B-7*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/(b*c^2)-5/21*(9*b*B-7*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (c^3*sqrt(x))
+--E 1631
+
+--S 1632 of 3139
+--a0:=integrate(t0,x)
+--E 1632
+
+--S 1633 of 3139
+--m0:=a0-r0
+--E 1633
+
+--S 1634 of 3139
+--d0:=D(m0,x)
+--E 1634
+
+)clear all
+
+--S 1635 of 3139
+t0:=x^(11/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                5      3  +-+
+--R            (B x  + A x )\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1635
+
+--S 1636 of 3139
+--r0:=-(b*B-A*c)*x^(9/2)/(b*c*sqrt(b*x^2+c*x^4))-3/5*b^(3/4)*(7*b*B-5*A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))+3/5*b^(3/4)*(7*b*B-5*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))+1/5*(7*b*B-5*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/(b*c^2)
+--E 1636
+
+--S 1637 of 3139
+--a0:=integrate(t0,x)
+--E 1637
+
+--S 1638 of 3139
+--m0:=a0-r0
+--E 1638
+
+--S 1639 of 3139
+--d0:=D(m0,x)
+--E 1639
+
+)clear all
+
+--S 1640 of 3139
+t0:=x^(9/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                4      2  +-+
+--R            (B x  + A x )\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1640
+
+--S 1641 of 3139
+--r0:=-(b*B-A*c)*x^(7/2)/(b*c*sqrt(b*x^2+c*x^4))-1/3*b^(1/4)*(5*b*B-3*A*c)*_
+---  x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(9/4)*sqrt(b*x^2+c*x^4))+1/3*(5*b*B-3*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b*c^2*sqrt(x))
+--E 1641
+
+--S 1642 of 3139
+--a0:=integrate(t0,x)
+--E 1642
+
+--S 1643 of 3139
+--m0:=a0-r0
+--E 1643
+
+--S 1644 of 3139
+--d0:=D(m0,x)
+--E 1644
+
+)clear all
+
+--S 1645 of 3139
+t0:=x^(7/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                3        +-+
+--R            (B x  + A x)\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1645
+
+--S 1646 of 3139
+--r0:=-(b*B-A*c)*x^(5/2)/(b*c*sqrt(b*x^2+c*x^4))-(3*b*B-A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*(-c)^(7/4)*sqrt(b*x^2+c*x^4))+(3*b*B-A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*(-c)^(7/4)*sqrt(b*x^2+c*x^4))
+--E 1646
+
+--S 1647 of 3139
+--a0:=integrate(t0,x)
+--E 1647
+
+--S 1648 of 3139
+--m0:=a0-r0
+--E 1648
+
+--S 1649 of 3139
+--d0:=D(m0,x)
+--E 1649
+
+)clear all
+
+--S 1650 of 3139
+t0:=x^(5/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                 2      +-+
+--R             (B x  + A)\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1650
+
+--S 1651 of 3139
+--r0:=-(b*B-A*c)*x^(3/2)/(b*c*sqrt(b*x^2+c*x^4))-(b*B+A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(3/4)*(-c)^(5/4)*sqrt(b*x^2+c*x^4))
+--E 1651
+
+--S 1652 of 3139
+--a0:=integrate(t0,x)
+--E 1652
+
+--S 1653 of 3139
+--m0:=a0-r0
+--E 1653
+
+--S 1654 of 3139
+--d0:=D(m0,x)
+--E 1654
+
+)clear all
+
+--S 1655 of 3139
+t0:=x^(3/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  2      +-+
+--R              (B x  + A)\|x
+--R   (1)  --------------------------
+--R                     +-----------+
+--R            3        |   4      2
+--R        (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1655
+
+--S 1656 of 3139
+--r0:=(b*B-3*A*c)*x^(5/2)/(b^2*sqrt(b*x^2+c*x^4))-2*A*sqrt(x)/(b*_
+---  sqrt(b*x^2+c*x^4))-(b*B-3*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(5/4)*(-c)^(3/4)*_
+---  sqrt(b*x^2+c*x^4))+(b*B-3*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(5/4)*(-c)^(3/4)*_
+---  sqrt(b*x^2+c*x^4))
+--E 1656
+
+--S 1657 of 3139
+--a0:=integrate(t0,x)
+--E 1657
+
+--S 1658 of 3139
+--m0:=a0-r0
+--E 1658
+
+--S 1659 of 3139
+--d0:=D(m0,x)
+--E 1659
+
+)clear all
+
+--S 1660 of 3139
+t0:=(A+B*x^2)*sqrt(x)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                   2      +-+
+--R               (B x  + A)\|x
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            4      2  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1660
+
+--S 1661 of 3139
+--r0:=1/3*(3*b*B-5*A*c)*x^(3/2)/(b^2*sqrt(b*x^2+c*x^4))-2/3*A/(b*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4))+1/3*(3*b*B-5*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(7/4)*(-c)^(1/4)*_
+---  sqrt(b*x^2+c*x^4))
+--E 1661
+
+--S 1662 of 3139
+--a0:=integrate(t0,x)
+--E 1662
+
+--S 1663 of 3139
+--m0:=a0-r0
+--E 1663
+
+--S 1664 of 3139
+--d0:=D(m0,x)
+--E 1664
+
+)clear all
+
+--S 1665 of 3139
+t0:=(A+B*x^2)/((b*x^2+c*x^4)^(3/2)*sqrt(x))
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            4      2  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1665
+
+--S 1666 of 3139
+--r0:=-2/5*A/(b*x^(3/2)*sqrt(b*x^2+c*x^4))+1/5*(5*b*B-7*A*c)*_
+---  sqrt(x)/(b^2*sqrt(b*x^2+c*x^4))-3/5*(-c)^(1/4)*(5*b*B-7*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(9/4)*sqrt(b*x^2+c*x^4))+3/5*(-c)^(1/4)*(5*b*B-7*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(9/4)*sqrt(b*x^2+c*x^4))-3/5*(5*b*B-7*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b^3*x^(3/2))
+--E 1666
+
+--S 1667 of 3139
+--a0:=integrate(t0,x)
+--E 1667
+
+--S 1668 of 3139
+--m0:=a0-r0
+--E 1668
+
+--S 1669 of 3139
+--d0:=D(m0,x)
+--E 1669
+
+)clear all
+
+--S 1670 of 3139
+t0:=(A+B*x^2)/(x^(3/2)*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            5      3  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1670
+
+--S 1671 of 3139
+--r0:=-2/7*A/(b*x^(5/2)*sqrt(b*x^2+c*x^4))+1/7*(7*b*B-9*A*c)/(b^2*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4))+5/21*(-c)^(3/4)*(7*b*B-9*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(11/4)*sqrt(b*x^2+c*x^4))-5/21*(7*b*B-9*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b^3*x^(5/2))
+--E 1671
+
+--S 1672 of 3139
+--a0:=integrate(t0,x)
+--E 1672
+
+--S 1673 of 3139
+--m0:=a0-r0
+--E 1673
+
+--S 1674 of 3139
+--d0:=D(m0,x)
+--E 1674
+
+)clear all
+
+--S 1675 of 3139
+t0:=(A+B*x^2)/(x^(5/2)*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            6      4  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1675
+
+--S 1676 of 3139
+--r0:=-2/9*A/(b*x^(7/2)*sqrt(b*x^2+c*x^4))+1/9*(9*b*B-11*A*c)/(b^2*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4))-7/15*(-c)^(5/4)*(9*b*B-11*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(13/4)*sqrt(b*x^2+c*x^4))+7/15*(-c)^(5/4)*(9*b*B-11*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(13/4)*sqrt(b*x^2+c*x^4))-7/45*(9*b*B-11*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b^3*x^(7/2))+7/15*c*(9*b*B-11*A*c)*sqrt(b*x^2+c*x^4)/(b^4*x^(3/2))
+--E 1676
+
+--S 1677 of 3139
+--a0:=integrate(t0,x)
+--E 1677
+
+--S 1678 of 3139
+--m0:=a0-r0
+--E 1678
+
+--S 1679 of 3139
+--d0:=D(m0,x)
+--E 1679
+
+)clear all
+
+--S 1680 of 3139
+t0:=(A+B*x^2)/(x^(7/2)*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            7      5  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1680
+
+--S 1681 of 3139
+--r0:=-2/11*A/(b*x^(9/2)*sqrt(b*x^2+c*x^4))+1/11*(11*b*B-13*A*c)/_
+---  (b^2*x^(5/2)*sqrt(b*x^2+c*x^4))+15/77*(-c)^(7/4)*(11*b*B-13*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(15/4)*sqrt(b*x^2+c*x^4))-9/77*(11*b*B-13*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b^3*x^(9/2))+15/77*c*(11*b*B-13*A*c)*sqrt(b*x^2+c*x^4)/(b^4*x^(5/2))
+--E 1681
+
+--S 1682 of 3139
+--a0:=integrate(t0,x)
+--E 1682
+
+--S 1683 of 3139
+--m0:=a0-r0
+--E 1683
+
+--S 1684 of 3139
+--d0:=D(m0,x)
+--E 1684
+
+)clear all
+
+--S 1685 of 3139
+t0:=x^3*(d+e*x^2)*(a+c*x^4)^5
+--R 
+--R
+--R   (1)
+--R      5   25    5   23       4   21       4   19      2 3   17      2 3   15
+--R     c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R   + 
+--R        3 2   13      3 2   11     4     9     4     7    5   5    5   3
+--R     10a c e x   + 10a c d x   + 5a c e x  + 5a c d x  + a e x  + a d x
+--R                                                    Type: Polynomial(Integer)
+--E 1685
+
+--S 1686 of 3139
+r0:=1/4*a^5*d*x^4+1/6*a^5*e*x^6+5/8*a^4*c*d*x^8+1/2*a^4*c*e*x^10+_
+   5/6*a^3*c^2*d*x^12+5/7*a^3*c^2*e*x^14+5/8*a^2*c^3*d*x^16+_
+   5/9*a^2*c^3*e*x^18+1/4*a*c^4*d*x^20+5/22*a*c^4*e*x^22+1/24*c^5*d*x^24+_
+   1/26*c^5*e*x^26
+--R 
+--R
+--R   (2)
+--R      1  5   26    1  5   24    5    4   22   1    4   20   5  2 3   18
+--R     -- c e x   + -- c d x   + -- a c e x   + - a c d x   + - a c e x
+--R     26           24           22             4             9
+--R   + 
+--R     5  2 3   16   5  3 2   14   5  3 2   12   1  4     10   5  4     8
+--R     - a c d x   + - a c e x   + - a c d x   + - a c e x   + - a c d x
+--R     8             7             6             2             8
+--R   + 
+--R     1  5   6   1  5   4
+--R     - a e x  + - a d x
+--R     6          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1686
+
+--S 1687 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  5   26    1  5   24    5    4   22   1    4   20   5  2 3   18
+--R     -- c e x   + -- c d x   + -- a c e x   + - a c d x   + - a c e x
+--R     26           24           22             4             9
+--R   + 
+--R     5  2 3   16   5  3 2   14   5  3 2   12   1  4     10   5  4     8
+--R     - a c d x   + - a c e x   + - a c d x   + - a c e x   + - a c d x
+--R     8             7             6             2             8
+--R   + 
+--R     1  5   6   1  5   4
+--R     - a e x  + - a d x
+--R     6          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1687
+
+--S 1688 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1688
+
+--S 1689 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1689
+
+)clear all
+
+--S 1690 of 3139
+t0:=x^2*(d+e*x^2)*(a+c*x^4)^5
+--R 
+--R
+--R   (1)
+--R      5   24    5   22       4   20       4   18      2 3   16      2 3   14
+--R     c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R   + 
+--R        3 2   12      3 2   10     4     8     4     6    5   4    5   2
+--R     10a c e x   + 10a c d x   + 5a c e x  + 5a c d x  + a e x  + a d x
+--R                                                    Type: Polynomial(Integer)
+--E 1690
+
+--S 1691 of 3139
+r0:=1/3*a^5*d*x^3+1/5*a^5*e*x^5+5/7*a^4*c*d*x^7+5/9*a^4*c*e*x^9+_
+   10/11*a^3*c^2*d*x^11+10/13*a^3*c^2*e*x^13+2/3*a^2*c^3*d*x^15+_
+   10/17*a^2*c^3*e*x^17+5/19*a*c^4*d*x^19+5/21*a*c^4*e*x^21+_
+   1/23*c^5*d*x^23+1/25*c^5*e*x^25
+--R 
+--R
+--R   (2)
+--R      1  5   25    1  5   23    5    4   21    5    4   19   10  2 3   17
+--R     -- c e x   + -- c d x   + -- a c e x   + -- a c d x   + -- a c e x
+--R     25           23           21             19             17
+--R   + 
+--R     2  2 3   15   10  3 2   13   10  3 2   11   5  4     9   5  4     7
+--R     - a c d x   + -- a c e x   + -- a c d x   + - a c e x  + - a c d x
+--R     3             13             11             9            7
+--R   + 
+--R     1  5   5   1  5   3
+--R     - a e x  + - a d x
+--R     5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1691
+
+--S 1692 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  5   25    1  5   23    5    4   21    5    4   19   10  2 3   17
+--R     -- c e x   + -- c d x   + -- a c e x   + -- a c d x   + -- a c e x
+--R     25           23           21             19             17
+--R   + 
+--R     2  2 3   15   10  3 2   13   10  3 2   11   5  4     9   5  4     7
+--R     - a c d x   + -- a c e x   + -- a c d x   + - a c e x  + - a c d x
+--R     3             13             11             9            7
+--R   + 
+--R     1  5   5   1  5   3
+--R     - a e x  + - a d x
+--R     5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1692
+
+--S 1693 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1693
+
+--S 1694 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1694
+
+)clear all
+
+--S 1695 of 3139
+t0:=x*(d+e*x^2)*(a+c*x^4)^5
+--R 
+--R
+--R   (1)
+--R      5   23    5   21       4   19       4   17      2 3   15      2 3   13
+--R     c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R   + 
+--R        3 2   11      3 2   9     4     7     4     5    5   3    5
+--R     10a c e x   + 10a c d x  + 5a c e x  + 5a c d x  + a e x  + a d x
+--R                                                    Type: Polynomial(Integer)
+--E 1695
+
+--S 1696 of 3139
+r0:=1/2*a^5*d*x^2+5/6*a^4*c*d*x^6+a^3*c^2*d*x^10+5/7*a^2*c^3*d*x^14+_
+   5/18*a*c^4*d*x^18+1/22*c^5*d*x^22+1/24*e*(a+c*x^4)^6/c
+--R 
+--R
+--R   (2)
+--R        1  6   24    1  6   22   1    5   20    5    5   18   5  2 4   16
+--R       -- c e x   + -- c d x   + - a c e x   + -- a c d x   + - a c e x
+--R       24           22           4             18             8
+--R     + 
+--R       5  2 4   14   5  3 3   12    3 3   10   5  4 2   8   5  4 2   6
+--R       - a c d x   + - a c e x   + a c d x   + - a c e x  + - a c d x
+--R       7             6                         8            6
+--R     + 
+--R       1  5     4   1  5     2    1  6
+--R       - a c e x  + - a c d x  + -- a e
+--R       4            2            24
+--R  /
+--R     c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1696
+
+--S 1697 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  5   24    1  5   22   1    4   20    5    4   18   5  2 3   16
+--R     -- c e x   + -- c d x   + - a c e x   + -- a c d x   + - a c e x
+--R     24           22           4             18             8
+--R   + 
+--R     5  2 3   14   5  3 2   12    3 2   10   5  4     8   5  4     6   1  5   4
+--R     - a c d x   + - a c e x   + a c d x   + - a c e x  + - a c d x  + - a e x
+--R     7             6                         8            6            4
+--R   + 
+--R     1  5   2
+--R     - a d x
+--R     2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1697
+
+--S 1698 of 3139
+m0:=a0-r0
+--R 
+--R
+--R           1  6
+--R          -- a e
+--R          24
+--R   (4)  - ------
+--R             c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1698
+
+--S 1699 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1699
+
+)clear all
+
+--S 1700 of 3139
+t0:=(d+e*x^2)*(a+c*x^4)^5
+--R 
+--R
+--R   (1)
+--R      5   22    5   20       4   18       4   16      2 3   14      2 3   12
+--R     c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R   + 
+--R        3 2   10      3 2   8     4     6     4     4    5   2    5
+--R     10a c e x   + 10a c d x  + 5a c e x  + 5a c d x  + a e x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 1700
+
+--S 1701 of 3139
+r0:=a^5*d*x+1/3*a^5*e*x^3+a^4*c*d*x^5+5/7*a^4*c*e*x^7+10/9*a^3*c^2*d*x^9+_
+   10/11*a^3*c^2*e*x^11+10/13*a^2*c^3*d*x^13+2/3*a^2*c^3*e*x^15+_
+   5/17*a*c^4*d*x^17+5/19*a*c^4*e*x^19+1/21*c^5*d*x^21+1/23*c^5*e*x^23
+--R 
+--R
+--R   (2)
+--R      1  5   23    1  5   21    5    4   19    5    4   17   2  2 3   15
+--R     -- c e x   + -- c d x   + -- a c e x   + -- a c d x   + - a c e x
+--R     23           21           19             17             3
+--R   + 
+--R     10  2 3   13   10  3 2   11   10  3 2   9   5  4     7    4     5
+--R     -- a c d x   + -- a c e x   + -- a c d x  + - a c e x  + a c d x
+--R     13             11              9            7
+--R   + 
+--R     1  5   3    5
+--R     - a e x  + a d x
+--R     3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1701
+
+--S 1702 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  5   23    1  5   21    5    4   19    5    4   17   2  2 3   15
+--R     -- c e x   + -- c d x   + -- a c e x   + -- a c d x   + - a c e x
+--R     23           21           19             17             3
+--R   + 
+--R     10  2 3   13   10  3 2   11   10  3 2   9   5  4     7    4     5
+--R     -- a c d x   + -- a c e x   + -- a c d x  + - a c e x  + a c d x
+--R     13             11              9            7
+--R   + 
+--R     1  5   3    5
+--R     - a e x  + a d x
+--R     3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1702
+
+--S 1703 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1703
+
+--S 1704 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1704
+
+)clear all
+
+--S 1705 of 3139
+t0:=(d+e*x^2)*(a+c*x^4)^5/x
+--R 
+--R
+--R   (1)
+--R        5   22    5   20       4   18       4   16      2 3   14      2 3   12
+--R       c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R     + 
+--R          3 2   10      3 2   8     4     6     4     4    5   2    5
+--R       10a c e x   + 10a c d x  + 5a c e x  + 5a c d x  + a e x  + a d
+--R  /
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1705
+
+--S 1706 of 3139
+r0:=1/2*a^5*e*x^2+5/4*a^4*c*d*x^4+5/6*a^4*c*e*x^6+5/4*a^3*c^2*d*x^8+_
+   a^3*c^2*e*x^10+5/6*a^2*c^3*d*x^12+5/7*a^2*c^3*e*x^14+_
+   5/16*a*c^4*d*x^16+5/18*a*c^4*e*x^18+1/20*c^5*d*x^20+_
+   1/22*c^5*e*x^22+a^5*d*log(x)
+--R 
+--R
+--R   (2)
+--R             5                5   22        5   20           4   18
+--R       55440a d log(x) + 2520c e x   + 2772c d x   + 15400a c e x
+--R     + 
+--R               4   16         2 3   14         2 3   12         3 2   10
+--R       17325a c d x   + 39600a c e x   + 46200a c d x   + 55440a c e x
+--R     + 
+--R             3 2   8         4     6         4     4         5   2
+--R       69300a c d x  + 46200a c e x  + 69300a c d x  + 27720a e x
+--R  /
+--R     55440
+--R                                                    Type: Expression(Integer)
+--E 1706
+
+--S 1707 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5                5   22        5   20           4   18
+--R       55440a d log(x) + 2520c e x   + 2772c d x   + 15400a c e x
+--R     + 
+--R               4   16         2 3   14         2 3   12         3 2   10
+--R       17325a c d x   + 39600a c e x   + 46200a c d x   + 55440a c e x
+--R     + 
+--R             3 2   8         4     6         4     4         5   2
+--R       69300a c d x  + 46200a c e x  + 69300a c d x  + 27720a e x
+--R  /
+--R     55440
+--R                                         Type: Union(Expression(Integer),...)
+--E 1707
+
+--S 1708 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1708
+
+--S 1709 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1709
+
+)clear all
+
+--S 1710 of 3139
+t0:=(d+e*x^2)*(a+c*x^4)^5/x^2
+--R 
+--R
+--R   (1)
+--R        5   22    5   20       4   18       4   16      2 3   14      2 3   12
+--R       c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R     + 
+--R          3 2   10      3 2   8     4     6     4     4    5   2    5
+--R       10a c e x   + 10a c d x  + 5a c e x  + 5a c d x  + a e x  + a d
+--R  /
+--R      2
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1710
+
+--S 1711 of 3139
+r0:=-a^5*d/x+a^5*e*x+5/3*a^4*c*d*x^3+a^4*c*e*x^5+10/7*a^3*c^2*d*x^7+_
+   10/9*a^3*c^2*e*x^9+10/11*a^2*c^3*d*x^11+10/13*a^2*c^3*e*x^13+_
+   1/3*a*c^4*d*x^15+5/17*a*c^4*e*x^17+1/19*c^5*d*x^19+1/21*c^5*e*x^21
+--R 
+--R
+--R   (2)
+--R              5   22          5   20            4   18            4   16
+--R       138567c e x   + 153153c d x   + 855855a c e x   + 969969a c d x
+--R     + 
+--R               2 3   14           2 3   12           3 2   10           3 2   8
+--R       2238390a c e x   + 2645370a c d x   + 3233230a c e x   + 4157010a c d x
+--R     + 
+--R               4     6           4     4           5   2           5
+--R       2909907a c e x  + 4849845a c d x  + 2909907a e x  - 2909907a d
+--R  /
+--R     2909907x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1711
+
+--S 1712 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              5   22          5   20            4   18            4   16
+--R       138567c e x   + 153153c d x   + 855855a c e x   + 969969a c d x
+--R     + 
+--R               2 3   14           2 3   12           3 2   10           3 2   8
+--R       2238390a c e x   + 2645370a c d x   + 3233230a c e x   + 4157010a c d x
+--R     + 
+--R               4     6           4     4           5   2           5
+--R       2909907a c e x  + 4849845a c d x  + 2909907a e x  - 2909907a d
+--R  /
+--R     2909907x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1712
+
+--S 1713 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1713
+
+--S 1714 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1714
+
+)clear all
+
+--S 1715 of 3139
+t0:=(d+e*x^2)*(a+c*x^4)^5/x^3
+--R 
+--R
+--R   (1)
+--R        5   22    5   20       4   18       4   16      2 3   14      2 3   12
+--R       c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R     + 
+--R          3 2   10      3 2   8     4     6     4     4    5   2    5
+--R       10a c e x   + 10a c d x  + 5a c e x  + 5a c d x  + a e x  + a d
+--R  /
+--R      3
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1715
+
+--S 1716 of 3139
+r0:=-1/2*a^5*d/x^2+5/2*a^4*c*d*x^2+5/4*a^4*c*e*x^4+5/3*a^3*c^2*d*x^6+_
+   5/4*a^3*c^2*e*x^8+a^2*c^3*d*x^10+5/6*a^2*c^3*e*x^12+5/14*a*c^4*d*x^14+_
+   5/16*a*c^4*e*x^16+1/18*c^5*d*x^18+1/20*c^5*e*x^20+a^5*e*log(x)
+--R 
+--R
+--R   (2)
+--R            5   2             5   22       5   20          4   18
+--R       5040a e x log(x) + 252c e x   + 280c d x   + 1575a c e x
+--R     + 
+--R              4   16        2 3   14        2 3   12        3 2   10
+--R       1800a c d x   + 4200a c e x   + 5040a c d x   + 6300a c e x
+--R     + 
+--R            3 2   8        4     6         4     4        5
+--R       8400a c d x  + 6300a c e x  + 12600a c d x  - 2520a d
+--R  /
+--R          2
+--R     5040x
+--R                                                    Type: Expression(Integer)
+--E 1716
+
+--S 1717 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            5   2             5   22       5   20          4   18
+--R       5040a e x log(x) + 252c e x   + 280c d x   + 1575a c e x
+--R     + 
+--R              4   16        2 3   14        2 3   12        3 2   10
+--R       1800a c d x   + 4200a c e x   + 5040a c d x   + 6300a c e x
+--R     + 
+--R            3 2   8        4     6         4     4        5
+--R       8400a c d x  + 6300a c e x  + 12600a c d x  - 2520a d
+--R  /
+--R          2
+--R     5040x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1717
+
+--S 1718 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1718
+
+--S 1719 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1719
+
+)clear all
+
+--S 1720 of 3139
+t0:=(1+x^2)/(1+x^4)
+--R 
+--R
+--R         2
+--R        x  + 1
+--R   (1)  ------
+--R         4
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1720
+
+--S 1721 of 3139
+r0:=-atan(1-x*sqrt(2))/sqrt(2)+atan(1+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R               +-+               +-+
+--R        atan(x\|2  + 1) + atan(x\|2  - 1)
+--R   (2)  ---------------------------------
+--R                        +-+
+--R                       \|2
+--R                                                    Type: Expression(Integer)
+--E 1721
+
+--S 1722 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+          3
+--R             x\|2          x  + x
+--R        atan(-----) + atan(------)
+--R               2             +-+
+--R                            \|2
+--R   (3)  --------------------------
+--R                    +-+
+--R                   \|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1722
+
+--S 1723 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                                                     +-+          3
+--R                 +-+               +-+             x\|2          x  + x
+--R        - atan(x\|2  + 1) - atan(x\|2  - 1) + atan(-----) + atan(------)
+--R                                                     2             +-+
+--R                                                                  \|2
+--R   (4)  ----------------------------------------------------------------
+--R                                       +-+
+--R                                      \|2
+--R                                                    Type: Expression(Integer)
+--E 1723
+
+--S 1724 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1724
+
+)clear all
+
+--S 1725 of 3139
+t0:=(1-x^2)/(1+x^4)
+--R 
+--R
+--R           2
+--R        - x  + 1
+--R   (1)  --------
+--R          4
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1725
+
+--S 1726 of 3139
+r0:=-1/2*log(1+x^2-x*sqrt(2))/sqrt(2)+1/2*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R              +-+    2                +-+    2
+--R        log(x\|2  + x  + 1) - log(- x\|2  + x  + 1)
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           2\|2
+--R                                                    Type: Expression(Integer)
+--E 1726
+
+--S 1727 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4     2      +-+     3
+--R            (x  + 4x  + 1)\|2  + 4x  + 4x
+--R        log(-----------------------------)
+--R                         4
+--R                        x  + 1
+--R   (3)  ----------------------------------
+--R                         +-+
+--R                       2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1727
+
+--S 1728 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     4     2      +-+     3
+--R               +-+    2            (x  + 4x  + 1)\|2  + 4x  + 4x
+--R       - log(x\|2  + x  + 1) + log(-----------------------------)
+--R                                                4
+--R                                               x  + 1
+--R     + 
+--R               +-+    2
+--R       log(- x\|2  + x  + 1)
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 1728
+
+--S 1729 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1729
+
+)clear all
+
+--S 1730 of 3139
+t0:=(1+x^2)/(1-x^4)
+--R 
+--R
+--R             1
+--R   (1)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1730
+
+--S 1731 of 3139
+r0:=atanh(x)
+--R 
+--R
+--R   (2)  atanh(x)
+--R                                                    Type: Expression(Integer)
+--E 1731
+
+--S 1732 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(x + 1) - log(x - 1)
+--R   (3)  -----------------------
+--R                   2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1732
+
+--S 1733 of 3139
+m0:=a0-r0
+--R 
+--R
+--R        log(x + 1) - log(x - 1) - 2atanh(x)
+--R   (4)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 1733
+
+--S 1734 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1734
+
+)clear all
+
+--S 1735 of 3139
+t0:=(1-x^2)/(1-x^4)
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         2
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1735
+
+--S 1736 of 3139
+r0:=atan(x)
+--R 
+--R
+--R        %pi
+--R   (2)  ---
+--R         3
+--R                                                    Type: Expression(Integer)
+--E 1736
+
+--S 1737 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R        %pi
+--R   (3)  ---
+--R         3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1737
+
+--S 1738 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1738
+
+--S 1739 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1739
+
+)clear all
+
+--S 1740 of 3139
+t0:=(2+3*x^2)/(4+9*x^4)
+--R 
+--R
+--R          2
+--R        3x  + 2
+--R   (1)  -------
+--R          4
+--R        9x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1740
+
+--S 1741 of 3139
+r0:=-1/2*atan(1-x*sqrt(3))/sqrt(3)+1/2*atan(1+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R               +-+               +-+
+--R        atan(x\|3  + 1) + atan(x\|3  - 1)
+--R   (2)  ---------------------------------
+--R                        +-+
+--R                      2\|3
+--R                                                    Type: Expression(Integer)
+--E 1741
+
+--S 1742 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+           3
+--R             x\|3          9x  + 6x
+--R        atan(-----) + atan(--------)
+--R               2               +-+
+--R                             4\|3
+--R   (3)  ----------------------------
+--R                      +-+
+--R                    2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1742
+
+--S 1743 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                                                     +-+           3
+--R                 +-+               +-+             x\|3          9x  + 6x
+--R        - atan(x\|3  + 1) - atan(x\|3  - 1) + atan(-----) + atan(--------)
+--R                                                     2               +-+
+--R                                                                   4\|3
+--R   (4)  ------------------------------------------------------------------
+--R                                         +-+
+--R                                       2\|3
+--R                                                    Type: Expression(Integer)
+--E 1743
+
+--S 1744 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1744
+
+)clear all
+
+--S 1745 of 3139
+t0:=(2-3*x^2)/(4+9*x^4)
+--R 
+--R
+--R            2
+--R        - 3x  + 2
+--R   (1)  ---------
+--R           4
+--R         9x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1745
+
+--S 1746 of 3139
+r0:=-1/4*log(2+3*x^2-2*x*sqrt(3))/sqrt(3)+1/4*log(2+3*x^2+2*x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R               +-+     2                 +-+     2
+--R        log(2x\|3  + 3x  + 2) - log(- 2x\|3  + 3x  + 2)
+--R   (2)  -----------------------------------------------
+--R                               +-+
+--R                             4\|3
+--R                                                    Type: Expression(Integer)
+--E 1746
+
+--S 1747 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4      2      +-+      3
+--R            (9x  + 24x  + 4)\|3  + 36x  + 24x
+--R        log(---------------------------------)
+--R                           4
+--R                         9x  + 4
+--R   (3)  --------------------------------------
+--R                           +-+
+--R                         4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1747
+
+--S 1748 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                        4      2      +-+      3
+--R                +-+     2            (9x  + 24x  + 4)\|3  + 36x  + 24x
+--R       - log(2x\|3  + 3x  + 2) + log(---------------------------------)
+--R                                                    4
+--R                                                  9x  + 4
+--R     + 
+--R                +-+     2
+--R       log(- 2x\|3  + 3x  + 2)
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1748
+
+--S 1749 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1749
+
+)clear all
+
+--S 1750 of 3139
+t0:=(2+3*x^2)/(4-9*x^4)
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R            2
+--R          3x  - 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1750
+
+--S 1751 of 3139
+r0:=atanh(x*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R                +-+
+--R              x\|3
+--R        atanh(-----)
+--R                +-+
+--R               \|2
+--R   (2)  ------------
+--R             +-+
+--R            \|6
+--R                                                    Type: Expression(Integer)
+--E 1751
+
+--S 1752 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2      +-+
+--R            (3x  + 2)\|6  + 12x
+--R        log(-------------------)
+--R                    2
+--R                  3x  - 2
+--R   (3)  ------------------------
+--R                    +-+
+--R                  2\|6
+--R                                         Type: Union(Expression(Integer),...)
+--E 1752
+
+--S 1753 of 3139
+m0:=a0-r0
+--R 
+--R
+--R               2      +-+                   +-+
+--R            (3x  + 2)\|6  + 12x           x\|3
+--R        log(-------------------) - 2atanh(-----)
+--R                    2                       +-+
+--R                  3x  - 2                  \|2
+--R   (4)  ----------------------------------------
+--R                            +-+
+--R                          2\|6
+--R                                                    Type: Expression(Integer)
+--E 1753
+
+--S 1754 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R            +-+ +-+     2      +-+      2      +-+ +-+
+--R        (2x\|2 \|3  - 3x  - 2)\|6  + (3x  + 2)\|2 \|3  - 12x
+--R   (5)  ----------------------------------------------------
+--R                        4      +-+      3
+--R                     (9x  - 4)\|6  + 36x  - 24x
+--R                                                    Type: Expression(Integer)
+--E 1754
+
+)clear all
+
+--S 1755 of 3139
+t0:=(2-3*x^2)/(4-9*x^4)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R          2
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1755
+
+--S 1756 of 3139
+r0:=atan(x*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R               +-+
+--R             x\|3
+--R        atan(-----)
+--R               +-+
+--R              \|2
+--R   (2)  -----------
+--R             +-+
+--R            \|6
+--R                                                    Type: Expression(Integer)
+--E 1756
+
+--S 1757 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+
+--R             x\|6
+--R        atan(-----)
+--R               2
+--R   (3)  -----------
+--R             +-+
+--R            \|6
+--R                                         Type: Union(Expression(Integer),...)
+--E 1757
+
+--S 1758 of 3139
+m0:=a0-r0
+--R 
+--R
+--R               +-+           +-+
+--R             x\|6          x\|3
+--R        atan(-----) - atan(-----)
+--R               2             +-+
+--R                            \|2
+--R   (4)  -------------------------
+--R                    +-+
+--R                   \|6
+--R                                                    Type: Expression(Integer)
+--E 1758
+
+--S 1759 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R           +-+ +-+ +-+
+--R        - \|2 \|3 \|6  + 6
+--R   (5)  ------------------
+--R                2
+--R             18x  + 12
+--R                                                    Type: Expression(Integer)
+--E 1759
+
+)clear all
+
+--S 1760 of 3139
+t0:=(c+d*x^2)/(a+b*x^4)
+--R 
+--R
+--R           2
+--R        d x  + c
+--R   (1)  --------
+--R           4
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1760
+
+--S 1761 of 3139
+r0:=-1/4*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-d*sqrt(a)+_
+   c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))+1/4*log(a^(1/4)*b^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(b))*(-d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))-_
+   1/2*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(d*sqrt(a)+c*sqrt(b))/(a^(3/4)*_
+   b^(3/4)*sqrt(2))+1/2*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(d*sqrt(a)+_
+   c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R          +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (c\|b  - d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R            +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- c\|b  + d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|b  + \|a
+--R       (2c\|b  + 2d\|a )atan(----------------)
+--R                                   4+-+
+--R                                   \|a
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|b  - \|a
+--R       (2c\|b  + 2d\|a )atan(----------------)
+--R                                   4+-+
+--R                                   \|a
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 1761
+
+--S 1762 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +--------------------------------------+
+--R          |     +-------------------------+
+--R          |     |   2 4         2 2    2 4
+--R          |     |- a d  + 2a b c d  - b c
+--R          |4a b |-------------------------  - c d
+--R          |     |             3 3
+--R          |    \|          64a b
+--R          |--------------------------------------
+--R         \|                 2a b
+--R      *
+--R         log
+--R                         +-------------------------+
+--R                         |   2 4         2 2    2 4
+--R                    3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                (16a b d |-------------------------  + 2a b c d  - 2a b c )
+--R                         |             3 3
+--R                        \|          64a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |     +-------------------------+
+--R                 |     |   2 4         2 2    2 4
+--R                 |     |- a d  + 2a b c d  - b c
+--R                 |4a b |-------------------------  - c d
+--R                 |     |             3 3
+--R                 |    \|          64a b
+--R                 |--------------------------------------
+--R                \|                 2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R             +----------------------------------------+
+--R             |       +-------------------------+
+--R             |       |   2 4         2 2    2 4
+--R             |       |- a d  + 2a b c d  - b c
+--R             |- 4a b |-------------------------  - c d
+--R             |       |             3 3
+--R             |      \|          64a b
+--R             |----------------------------------------
+--R            \|                  2a b
+--R         *
+--R            log
+--R                            +-------------------------+
+--R                            |   2 4         2 2    2 4
+--R                       3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                   (16a b d |-------------------------  - 2a b c d  + 2a b c )
+--R                            |             3 3
+--R                           \|          64a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |       +-------------------------+
+--R                    |       |   2 4         2 2    2 4
+--R                    |       |- a d  + 2a b c d  - b c
+--R                    |- 4a b |-------------------------  - c d
+--R                    |       |             3 3
+--R                    |      \|          64a b
+--R                    |----------------------------------------
+--R                   \|                  2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R          +----------------------------------------+
+--R          |       +-------------------------+
+--R          |       |   2 4         2 2    2 4
+--R          |       |- a d  + 2a b c d  - b c
+--R          |- 4a b |-------------------------  - c d
+--R          |       |             3 3
+--R          |      \|          64a b
+--R          |----------------------------------------
+--R         \|                  2a b
+--R      *
+--R         log
+--R                           +-------------------------+
+--R                           |   2 4         2 2    2 4
+--R                      3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                (- 16a b d |-------------------------  + 2a b c d  - 2a b c )
+--R                           |             3 3
+--R                          \|          64a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |       +-------------------------+
+--R                 |       |   2 4         2 2    2 4
+--R                 |       |- a d  + 2a b c d  - b c
+--R                 |- 4a b |-------------------------  - c d
+--R                 |       |             3 3
+--R                 |      \|          64a b
+--R                 |----------------------------------------
+--R                \|                  2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R             +--------------------------------------+
+--R             |     +-------------------------+
+--R             |     |   2 4         2 2    2 4
+--R             |     |- a d  + 2a b c d  - b c
+--R             |4a b |-------------------------  - c d
+--R             |     |             3 3
+--R             |    \|          64a b
+--R             |--------------------------------------
+--R            \|                 2a b
+--R         *
+--R            log
+--R                              +-------------------------+
+--R                              |   2 4         2 2    2 4
+--R                         3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                   (- 16a b d |-------------------------  - 2a b c d  + 2a b c )
+--R                              |             3 3
+--R                             \|          64a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |     +-------------------------+
+--R                    |     |   2 4         2 2    2 4
+--R                    |     |- a d  + 2a b c d  - b c
+--R                    |4a b |-------------------------  - c d
+--R                    |     |             3 3
+--R                    |    \|          64a b
+--R                    |--------------------------------------
+--R                   \|                 2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1762
+
+--S 1763 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +--------------------------------------+
+--R                          |     +-------------------------+
+--R                          |     |   2 4         2 2    2 4
+--R                          |     |- a d  + 2a b c d  - b c
+--R                          |4a b |-------------------------  - c d
+--R                          |     |             3 3
+--R           +-+4+-+3 4+-+3 |    \|          64a b
+--R         2\|2 \|a   \|b   |--------------------------------------
+--R                         \|                 2a b
+--R      *
+--R         log
+--R                         +-------------------------+
+--R                         |   2 4         2 2    2 4
+--R                    3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                (16a b d |-------------------------  + 2a b c d  - 2a b c )
+--R                         |             3 3
+--R                        \|          64a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |     +-------------------------+
+--R                 |     |   2 4         2 2    2 4
+--R                 |     |- a d  + 2a b c d  - b c
+--R                 |4a b |-------------------------  - c d
+--R                 |     |             3 3
+--R                 |    \|          64a b
+--R                 |--------------------------------------
+--R                \|                 2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R                             +----------------------------------------+
+--R                             |       +-------------------------+
+--R                             |       |   2 4         2 2    2 4
+--R                             |       |- a d  + 2a b c d  - b c
+--R                             |- 4a b |-------------------------  - c d
+--R                             |       |             3 3
+--R              +-+4+-+3 4+-+3 |      \|          64a b
+--R            2\|2 \|a   \|b   |----------------------------------------
+--R                            \|                  2a b
+--R         *
+--R            log
+--R                            +-------------------------+
+--R                            |   2 4         2 2    2 4
+--R                       3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                   (16a b d |-------------------------  - 2a b c d  + 2a b c )
+--R                            |             3 3
+--R                           \|          64a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |       +-------------------------+
+--R                    |       |   2 4         2 2    2 4
+--R                    |       |- a d  + 2a b c d  - b c
+--R                    |- 4a b |-------------------------  - c d
+--R                    |       |             3 3
+--R                    |      \|          64a b
+--R                    |----------------------------------------
+--R                   \|                  2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R                          +----------------------------------------+
+--R                          |       +-------------------------+
+--R                          |       |   2 4         2 2    2 4
+--R                          |       |- a d  + 2a b c d  - b c
+--R                          |- 4a b |-------------------------  - c d
+--R                          |       |             3 3
+--R           +-+4+-+3 4+-+3 |      \|          64a b
+--R         2\|2 \|a   \|b   |----------------------------------------
+--R                         \|                  2a b
+--R      *
+--R         log
+--R                           +-------------------------+
+--R                           |   2 4         2 2    2 4
+--R                      3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                (- 16a b d |-------------------------  + 2a b c d  - 2a b c )
+--R                           |             3 3
+--R                          \|          64a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |       +-------------------------+
+--R                 |       |   2 4         2 2    2 4
+--R                 |       |- a d  + 2a b c d  - b c
+--R                 |- 4a b |-------------------------  - c d
+--R                 |       |             3 3
+--R                 |      \|          64a b
+--R                 |----------------------------------------
+--R                \|                  2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R                             +--------------------------------------+
+--R                             |     +-------------------------+
+--R                             |     |   2 4         2 2    2 4
+--R                             |     |- a d  + 2a b c d  - b c
+--R                             |4a b |-------------------------  - c d
+--R                             |     |             3 3
+--R              +-+4+-+3 4+-+3 |    \|          64a b
+--R            2\|2 \|a   \|b   |--------------------------------------
+--R                            \|                 2a b
+--R         *
+--R            log
+--R                              +-------------------------+
+--R                              |   2 4         2 2    2 4
+--R                         3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                   (- 16a b d |-------------------------  - 2a b c d  + 2a b c )
+--R                              |             3 3
+--R                             \|          64a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |     +-------------------------+
+--R                    |     |   2 4         2 2    2 4
+--R                    |     |- a d  + 2a b c d  - b c
+--R                    |4a b |-------------------------  - c d
+--R                    |     |             3 3
+--R                    |    \|          64a b
+--R                    |--------------------------------------
+--R                   \|                 2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R            +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- c\|b  + d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R          +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (c\|b  - d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|b  + \|a
+--R       (- 2c\|b  - 2d\|a )atan(----------------)
+--R                                     4+-+
+--R                                     \|a
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|b  - \|a
+--R       (- 2c\|b  - 2d\|a )atan(----------------)
+--R                                     4+-+
+--R                                     \|a
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 1763
+
+--S 1764 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4       2  +-+4+-+2        6         4        2  +-+
+--R           ((4d x  + 4c x )\|a \|a   - b c x  - 2a d x  + a c x )\|b
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2b d x  + 2b c x  + 2a d x  + 2a c)\|a
+--R         + 
+--R                   6         4        2  +-+
+--R           (- b d x  - 2b c x  + a d x )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                   4         2       4+-+2
+--R             (b c x  - 2a d x  - a c)\|a
+--R           + 
+--R                     6        4        2        +-+
+--R             (- b d x  - b c x  - a d x  - a c)\|a
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R             4         2        +-+4+-+2    2   6           4           2    2
+--R       (b d x  - 2b c x  - a d)\|a \|a   + b c x  - 3a b d x  - 3a b c x  + a d
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4b x  + 4a x )\|a \|a  \|b  + (2b x  + 4a b x  + 2a )\|a  )\|b
+--R     + 
+--R             2 6     2   2
+--R       - 4a b x  - 4a b x
+--R                                                    Type: Expression(Integer)
+--E 1764
+
+)clear all
+
+--S 1765 of 3139
+t0:=(c-d*x^2)/(a+b*x^4)
+--R 
+--R
+--R             2
+--R        - d x  + c
+--R   (1)  ----------
+--R            4
+--R         b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1765
+
+--S 1766 of 3139
+r0:=-1/2*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(-d*sqrt(a)+c*sqrt(b))/(a^(3/4)*_
+   b^(3/4)*sqrt(2))+1/2*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(-d*sqrt(a)+_
+   c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))-1/4*log(-a^(1/4)*b^(1/4)*x*_
+   sqrt(2)+sqrt(a)+x^2*sqrt(b))*(d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4)*_
+   sqrt(2))+1/4*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*_
+   (d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R          +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (c\|b  + d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R            +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- c\|b  - d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|b  + \|a
+--R       (2c\|b  - 2d\|a )atan(----------------)
+--R                                   4+-+
+--R                                   \|a
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|b  - \|a
+--R       (2c\|b  - 2d\|a )atan(----------------)
+--R                                   4+-+
+--R                                   \|a
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 1766
+
+--S 1767 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +--------------------------------------+
+--R             |     +-------------------------+
+--R             |     |   2 4         2 2    2 4
+--R             |     |- a d  + 2a b c d  - b c
+--R             |4a b |-------------------------  + c d
+--R             |     |             3 3
+--R             |    \|          64a b
+--R             |--------------------------------------
+--R            \|                 2a b
+--R         *
+--R            log
+--R                            +-------------------------+
+--R                            |   2 4         2 2    2 4
+--R                       3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                   (16a b d |-------------------------  - 2a b c d  + 2a b c )
+--R                            |             3 3
+--R                           \|          64a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |     +-------------------------+
+--R                    |     |   2 4         2 2    2 4
+--R                    |     |- a d  + 2a b c d  - b c
+--R                    |4a b |-------------------------  + c d
+--R                    |     |             3 3
+--R                    |    \|          64a b
+--R                    |--------------------------------------
+--R                   \|                 2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R          +----------------------------------------+
+--R          |       +-------------------------+
+--R          |       |   2 4         2 2    2 4
+--R          |       |- a d  + 2a b c d  - b c
+--R          |- 4a b |-------------------------  + c d
+--R          |       |             3 3
+--R          |      \|          64a b
+--R          |----------------------------------------
+--R         \|                  2a b
+--R      *
+--R         log
+--R                         +-------------------------+
+--R                         |   2 4         2 2    2 4
+--R                    3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                (16a b d |-------------------------  + 2a b c d  - 2a b c )
+--R                         |             3 3
+--R                        \|          64a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |       +-------------------------+
+--R                 |       |   2 4         2 2    2 4
+--R                 |       |- a d  + 2a b c d  - b c
+--R                 |- 4a b |-------------------------  + c d
+--R                 |       |             3 3
+--R                 |      \|          64a b
+--R                 |----------------------------------------
+--R                \|                  2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R             +----------------------------------------+
+--R             |       +-------------------------+
+--R             |       |   2 4         2 2    2 4
+--R             |       |- a d  + 2a b c d  - b c
+--R             |- 4a b |-------------------------  + c d
+--R             |       |             3 3
+--R             |      \|          64a b
+--R             |----------------------------------------
+--R            \|                  2a b
+--R         *
+--R            log
+--R                              +-------------------------+
+--R                              |   2 4         2 2    2 4
+--R                         3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                   (- 16a b d |-------------------------  - 2a b c d  + 2a b c )
+--R                              |             3 3
+--R                             \|          64a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |       +-------------------------+
+--R                    |       |   2 4         2 2    2 4
+--R                    |       |- a d  + 2a b c d  - b c
+--R                    |- 4a b |-------------------------  + c d
+--R                    |       |             3 3
+--R                    |      \|          64a b
+--R                    |----------------------------------------
+--R                   \|                  2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R          +--------------------------------------+
+--R          |     +-------------------------+
+--R          |     |   2 4         2 2    2 4
+--R          |     |- a d  + 2a b c d  - b c
+--R          |4a b |-------------------------  + c d
+--R          |     |             3 3
+--R          |    \|          64a b
+--R          |--------------------------------------
+--R         \|                 2a b
+--R      *
+--R         log
+--R                           +-------------------------+
+--R                           |   2 4         2 2    2 4
+--R                      3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                (- 16a b d |-------------------------  + 2a b c d  - 2a b c )
+--R                           |             3 3
+--R                          \|          64a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |     +-------------------------+
+--R                 |     |   2 4         2 2    2 4
+--R                 |     |- a d  + 2a b c d  - b c
+--R                 |4a b |-------------------------  + c d
+--R                 |     |             3 3
+--R                 |    \|          64a b
+--R                 |--------------------------------------
+--R                \|                 2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1767
+
+--S 1768 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                             +--------------------------------------+
+--R                             |     +-------------------------+
+--R                             |     |   2 4         2 2    2 4
+--R                             |     |- a d  + 2a b c d  - b c
+--R                             |4a b |-------------------------  + c d
+--R                             |     |             3 3
+--R              +-+4+-+3 4+-+3 |    \|          64a b
+--R            2\|2 \|a   \|b   |--------------------------------------
+--R                            \|                 2a b
+--R         *
+--R            log
+--R                            +-------------------------+
+--R                            |   2 4         2 2    2 4
+--R                       3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                   (16a b d |-------------------------  - 2a b c d  + 2a b c )
+--R                            |             3 3
+--R                           \|          64a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |     +-------------------------+
+--R                    |     |   2 4         2 2    2 4
+--R                    |     |- a d  + 2a b c d  - b c
+--R                    |4a b |-------------------------  + c d
+--R                    |     |             3 3
+--R                    |    \|          64a b
+--R                    |--------------------------------------
+--R                   \|                 2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R                          +----------------------------------------+
+--R                          |       +-------------------------+
+--R                          |       |   2 4         2 2    2 4
+--R                          |       |- a d  + 2a b c d  - b c
+--R                          |- 4a b |-------------------------  + c d
+--R                          |       |             3 3
+--R           +-+4+-+3 4+-+3 |      \|          64a b
+--R         2\|2 \|a   \|b   |----------------------------------------
+--R                         \|                  2a b
+--R      *
+--R         log
+--R                         +-------------------------+
+--R                         |   2 4         2 2    2 4
+--R                    3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                (16a b d |-------------------------  + 2a b c d  - 2a b c )
+--R                         |             3 3
+--R                        \|          64a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |       +-------------------------+
+--R                 |       |   2 4         2 2    2 4
+--R                 |       |- a d  + 2a b c d  - b c
+--R                 |- 4a b |-------------------------  + c d
+--R                 |       |             3 3
+--R                 |      \|          64a b
+--R                 |----------------------------------------
+--R                \|                  2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R                             +----------------------------------------+
+--R                             |       +-------------------------+
+--R                             |       |   2 4         2 2    2 4
+--R                             |       |- a d  + 2a b c d  - b c
+--R                             |- 4a b |-------------------------  + c d
+--R                             |       |             3 3
+--R              +-+4+-+3 4+-+3 |      \|          64a b
+--R            2\|2 \|a   \|b   |----------------------------------------
+--R                            \|                  2a b
+--R         *
+--R            log
+--R                              +-------------------------+
+--R                              |   2 4         2 2    2 4
+--R                         3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                   (- 16a b d |-------------------------  - 2a b c d  + 2a b c )
+--R                              |             3 3
+--R                             \|          64a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |       +-------------------------+
+--R                    |       |   2 4         2 2    2 4
+--R                    |       |- a d  + 2a b c d  - b c
+--R                    |- 4a b |-------------------------  + c d
+--R                    |       |             3 3
+--R                    |      \|          64a b
+--R                    |----------------------------------------
+--R                   \|                  2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R                          +--------------------------------------+
+--R                          |     +-------------------------+
+--R                          |     |   2 4         2 2    2 4
+--R                          |     |- a d  + 2a b c d  - b c
+--R                          |4a b |-------------------------  + c d
+--R                          |     |             3 3
+--R           +-+4+-+3 4+-+3 |    \|          64a b
+--R         2\|2 \|a   \|b   |--------------------------------------
+--R                         \|                 2a b
+--R      *
+--R         log
+--R                           +-------------------------+
+--R                           |   2 4         2 2    2 4
+--R                      3 2  |- a d  + 2a b c d  - b c       2     2       2 3
+--R                (- 16a b d |-------------------------  + 2a b c d  - 2a b c )
+--R                           |             3 3
+--R                          \|          64a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |     +-------------------------+
+--R                 |     |   2 4         2 2    2 4
+--R                 |     |- a d  + 2a b c d  - b c
+--R                 |4a b |-------------------------  + c d
+--R                 |     |             3 3
+--R                 |    \|          64a b
+--R                 |--------------------------------------
+--R                \|                 2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R            +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- c\|b  - d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R          +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (c\|b  + d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|b  + \|a
+--R       (- 2c\|b  + 2d\|a )atan(----------------)
+--R                                     4+-+
+--R                                     \|a
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|b  - \|a
+--R       (- 2c\|b  + 2d\|a )atan(----------------)
+--R                                     4+-+
+--R                                     \|a
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 1768
+
+--S 1769 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                   4       2  +-+4+-+2        6         4        2  +-+
+--R           ((- 4d x  + 4c x )\|a \|a   - b c x  + 2a d x  + a c x )\|b
+--R         + 
+--R                    6         4         2        4+-+2
+--R           (- 2b d x  + 2b c x  - 2a d x  + 2a c)\|a
+--R         + 
+--R                 6         4        2  +-+
+--R           (b d x  - 2b c x  - a d x )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                4         2       4+-+2         6        4        2        +-+
+--R         ((b c x  + 2a d x  - a c)\|a   + (b d x  - b c x  + a d x  - a c)\|a )
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R             4         2        +-+4+-+2    2   6           4           2    2
+--R     (- b d x  - 2b c x  + a d)\|a \|a   + b c x  + 3a b d x  - 3a b c x  - a d
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4b x  + 4a x )\|a \|a  \|b  + (2b x  + 4a b x  + 2a )\|a  )\|b
+--R     + 
+--R             2 6     2   2
+--R       - 4a b x  - 4a b x
+--R                                                    Type: Expression(Integer)
+--E 1769
+
+)clear all
+
+--S 1770 of 3139
+t0:=(c+d*x^2)/(a-b*x^4)
+--R 
+--R
+--R             2
+--R        - d x  - c
+--R   (1)  ----------
+--R            4
+--R         b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1770
+
+--S 1771 of 3139
+r0:=1/2*atan(b^(1/4)*x/a^(1/4))*(-d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4))+_
+   1/2*atanh(b^(1/4)*x/a^(1/4))*(d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4))
+--R 
+--R
+--R                              4+-+                         4+-+
+--R           +-+     +-+       x\|b        +-+     +-+      x\|b
+--R        (c\|b  + d\|a )atanh(-----) + (c\|b  - d\|a )atan(-----)
+--R                              4+-+                         4+-+
+--R                              \|a                          \|a
+--R   (2)  --------------------------------------------------------
+--R                                4+-+3 4+-+3
+--R                               2\|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 1771
+
+--S 1772 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +------------------------------------+
+--R          |     +-----------------------+
+--R          |     | 2 4         2 2    2 4
+--R          |     |a d  + 2a b c d  + b c
+--R          |4a b |-----------------------  + c d
+--R          |     |            3 3
+--R          |    \|         64a b
+--R          |------------------------------------
+--R         \|                2a b
+--R      *
+--R         log
+--R                         +-----------------------+
+--R                         | 2 4         2 2    2 4
+--R                    3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                (16a b d |-----------------------  - 2a b c d  - 2a b c )
+--R                         |            3 3
+--R                        \|         64a b
+--R             *
+--R                 +------------------------------------+
+--R                 |     +-----------------------+
+--R                 |     | 2 4         2 2    2 4
+--R                 |     |a d  + 2a b c d  + b c
+--R                 |4a b |-----------------------  + c d
+--R                 |     |            3 3
+--R                 |    \|         64a b
+--R                 |------------------------------------
+--R                \|                2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R             +--------------------------------------+
+--R             |       +-----------------------+
+--R             |       | 2 4         2 2    2 4
+--R             |       |a d  + 2a b c d  + b c
+--R             |- 4a b |-----------------------  + c d
+--R             |       |            3 3
+--R             |      \|         64a b
+--R             |--------------------------------------
+--R            \|                 2a b
+--R         *
+--R            log
+--R                            +-----------------------+
+--R                            | 2 4         2 2    2 4
+--R                       3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                   (16a b d |-----------------------  + 2a b c d  + 2a b c )
+--R                            |            3 3
+--R                           \|         64a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |       +-----------------------+
+--R                    |       | 2 4         2 2    2 4
+--R                    |       |a d  + 2a b c d  + b c
+--R                    |- 4a b |-----------------------  + c d
+--R                    |       |            3 3
+--R                    |      \|         64a b
+--R                    |--------------------------------------
+--R                   \|                 2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R          +--------------------------------------+
+--R          |       +-----------------------+
+--R          |       | 2 4         2 2    2 4
+--R          |       |a d  + 2a b c d  + b c
+--R          |- 4a b |-----------------------  + c d
+--R          |       |            3 3
+--R          |      \|         64a b
+--R          |--------------------------------------
+--R         \|                 2a b
+--R      *
+--R         log
+--R                           +-----------------------+
+--R                           | 2 4         2 2    2 4
+--R                      3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                (- 16a b d |-----------------------  - 2a b c d  - 2a b c )
+--R                           |            3 3
+--R                          \|         64a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |       +-----------------------+
+--R                 |       | 2 4         2 2    2 4
+--R                 |       |a d  + 2a b c d  + b c
+--R                 |- 4a b |-----------------------  + c d
+--R                 |       |            3 3
+--R                 |      \|         64a b
+--R                 |--------------------------------------
+--R                \|                 2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R             +------------------------------------+
+--R             |     +-----------------------+
+--R             |     | 2 4         2 2    2 4
+--R             |     |a d  + 2a b c d  + b c
+--R             |4a b |-----------------------  + c d
+--R             |     |            3 3
+--R             |    \|         64a b
+--R             |------------------------------------
+--R            \|                2a b
+--R         *
+--R            log
+--R                              +-----------------------+
+--R                              | 2 4         2 2    2 4
+--R                         3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                   (- 16a b d |-----------------------  + 2a b c d  + 2a b c )
+--R                              |            3 3
+--R                             \|         64a b
+--R                *
+--R                    +------------------------------------+
+--R                    |     +-----------------------+
+--R                    |     | 2 4         2 2    2 4
+--R                    |     |a d  + 2a b c d  + b c
+--R                    |4a b |-----------------------  + c d
+--R                    |     |            3 3
+--R                    |    \|         64a b
+--R                    |------------------------------------
+--R                   \|                2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1772
+
+--S 1773 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +------------------------------------+
+--R                     |     +-----------------------+
+--R                     |     | 2 4         2 2    2 4
+--R                     |     |a d  + 2a b c d  + b c
+--R                     |4a b |-----------------------  + c d
+--R                     |     |            3 3
+--R         4+-+3 4+-+3 |    \|         64a b
+--R         \|a   \|b   |------------------------------------
+--R                    \|                2a b
+--R      *
+--R         log
+--R                         +-----------------------+
+--R                         | 2 4         2 2    2 4
+--R                    3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                (16a b d |-----------------------  - 2a b c d  - 2a b c )
+--R                         |            3 3
+--R                        \|         64a b
+--R             *
+--R                 +------------------------------------+
+--R                 |     +-----------------------+
+--R                 |     | 2 4         2 2    2 4
+--R                 |     |a d  + 2a b c d  + b c
+--R                 |4a b |-----------------------  + c d
+--R                 |     |            3 3
+--R                 |    \|         64a b
+--R                 |------------------------------------
+--R                \|                2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R                        +--------------------------------------+
+--R                        |       +-----------------------+
+--R                        |       | 2 4         2 2    2 4
+--R                        |       |a d  + 2a b c d  + b c
+--R                        |- 4a b |-----------------------  + c d
+--R                        |       |            3 3
+--R            4+-+3 4+-+3 |      \|         64a b
+--R            \|a   \|b   |--------------------------------------
+--R                       \|                 2a b
+--R         *
+--R            log
+--R                            +-----------------------+
+--R                            | 2 4         2 2    2 4
+--R                       3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                   (16a b d |-----------------------  + 2a b c d  + 2a b c )
+--R                            |            3 3
+--R                           \|         64a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |       +-----------------------+
+--R                    |       | 2 4         2 2    2 4
+--R                    |       |a d  + 2a b c d  + b c
+--R                    |- 4a b |-----------------------  + c d
+--R                    |       |            3 3
+--R                    |      \|         64a b
+--R                    |--------------------------------------
+--R                   \|                 2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R                     +--------------------------------------+
+--R                     |       +-----------------------+
+--R                     |       | 2 4         2 2    2 4
+--R                     |       |a d  + 2a b c d  + b c
+--R                     |- 4a b |-----------------------  + c d
+--R                     |       |            3 3
+--R         4+-+3 4+-+3 |      \|         64a b
+--R         \|a   \|b   |--------------------------------------
+--R                    \|                 2a b
+--R      *
+--R         log
+--R                           +-----------------------+
+--R                           | 2 4         2 2    2 4
+--R                      3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                (- 16a b d |-----------------------  - 2a b c d  - 2a b c )
+--R                           |            3 3
+--R                          \|         64a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |       +-----------------------+
+--R                 |       | 2 4         2 2    2 4
+--R                 |       |a d  + 2a b c d  + b c
+--R                 |- 4a b |-----------------------  + c d
+--R                 |       |            3 3
+--R                 |      \|         64a b
+--R                 |--------------------------------------
+--R                \|                 2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R                        +------------------------------------+
+--R                        |     +-----------------------+
+--R                        |     | 2 4         2 2    2 4
+--R                        |     |a d  + 2a b c d  + b c
+--R                        |4a b |-----------------------  + c d
+--R                        |     |            3 3
+--R            4+-+3 4+-+3 |    \|         64a b
+--R            \|a   \|b   |------------------------------------
+--R                       \|                2a b
+--R         *
+--R            log
+--R                              +-----------------------+
+--R                              | 2 4         2 2    2 4
+--R                         3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                   (- 16a b d |-----------------------  + 2a b c d  + 2a b c )
+--R                              |            3 3
+--R                             \|         64a b
+--R                *
+--R                    +------------------------------------+
+--R                    |     +-----------------------+
+--R                    |     | 2 4         2 2    2 4
+--R                    |     |a d  + 2a b c d  + b c
+--R                    |4a b |-----------------------  + c d
+--R                    |     |            3 3
+--R                    |    \|         64a b
+--R                    |------------------------------------
+--R                   \|                2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R                               4+-+                           4+-+
+--R            +-+     +-+       x\|b          +-+     +-+      x\|b
+--R       (- c\|b  - d\|a )atanh(-----) + (- c\|b  + d\|a )atan(-----)
+--R                               4+-+                           4+-+
+--R                               \|a                            \|a
+--R  /
+--R      4+-+3 4+-+3
+--R     2\|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 1773
+
+--S 1774 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R               2     4+-+2      2 +-+ 4+-+2     4+-+2 +-+
+--R        ((- d x  - c)\|a   + d x \|a )\|b   + c \|a  \|b
+--R   (5)  -------------------------------------------------
+--R                           4     4+-+2 4+-+2
+--R                       (b x  - a)\|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 1774
+
+)clear all
+
+--S 1775 of 3139
+t0:=(c-d*x^2)/(a-b*x^4)
+--R 
+--R
+--R           2
+--R        d x  - c
+--R   (1)  --------
+--R           4
+--R        b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1775
+
+--S 1776 of 3139
+r0:=1/2*atanh(b^(1/4)*x/a^(1/4))*(-d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4))+_
+   1/2*atan(b^(1/4)*x/a^(1/4))*(d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4))
+--R 
+--R
+--R                              4+-+                         4+-+
+--R           +-+     +-+       x\|b        +-+     +-+      x\|b
+--R        (c\|b  - d\|a )atanh(-----) + (c\|b  + d\|a )atan(-----)
+--R                              4+-+                         4+-+
+--R                              \|a                          \|a
+--R   (2)  --------------------------------------------------------
+--R                                4+-+3 4+-+3
+--R                               2\|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 1776
+
+--S 1777 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +------------------------------------+
+--R             |     +-----------------------+
+--R             |     | 2 4         2 2    2 4
+--R             |     |a d  + 2a b c d  + b c
+--R             |4a b |-----------------------  - c d
+--R             |     |            3 3
+--R             |    \|         64a b
+--R             |------------------------------------
+--R            \|                2a b
+--R         *
+--R            log
+--R                            +-----------------------+
+--R                            | 2 4         2 2    2 4
+--R                       3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                   (16a b d |-----------------------  + 2a b c d  + 2a b c )
+--R                            |            3 3
+--R                           \|         64a b
+--R                *
+--R                    +------------------------------------+
+--R                    |     +-----------------------+
+--R                    |     | 2 4         2 2    2 4
+--R                    |     |a d  + 2a b c d  + b c
+--R                    |4a b |-----------------------  - c d
+--R                    |     |            3 3
+--R                    |    \|         64a b
+--R                    |------------------------------------
+--R                   \|                2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R          +--------------------------------------+
+--R          |       +-----------------------+
+--R          |       | 2 4         2 2    2 4
+--R          |       |a d  + 2a b c d  + b c
+--R          |- 4a b |-----------------------  - c d
+--R          |       |            3 3
+--R          |      \|         64a b
+--R          |--------------------------------------
+--R         \|                 2a b
+--R      *
+--R         log
+--R                         +-----------------------+
+--R                         | 2 4         2 2    2 4
+--R                    3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                (16a b d |-----------------------  - 2a b c d  - 2a b c )
+--R                         |            3 3
+--R                        \|         64a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |       +-----------------------+
+--R                 |       | 2 4         2 2    2 4
+--R                 |       |a d  + 2a b c d  + b c
+--R                 |- 4a b |-----------------------  - c d
+--R                 |       |            3 3
+--R                 |      \|         64a b
+--R                 |--------------------------------------
+--R                \|                 2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R             +--------------------------------------+
+--R             |       +-----------------------+
+--R             |       | 2 4         2 2    2 4
+--R             |       |a d  + 2a b c d  + b c
+--R             |- 4a b |-----------------------  - c d
+--R             |       |            3 3
+--R             |      \|         64a b
+--R             |--------------------------------------
+--R            \|                 2a b
+--R         *
+--R            log
+--R                              +-----------------------+
+--R                              | 2 4         2 2    2 4
+--R                         3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                   (- 16a b d |-----------------------  + 2a b c d  + 2a b c )
+--R                              |            3 3
+--R                             \|         64a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |       +-----------------------+
+--R                    |       | 2 4         2 2    2 4
+--R                    |       |a d  + 2a b c d  + b c
+--R                    |- 4a b |-----------------------  - c d
+--R                    |       |            3 3
+--R                    |      \|         64a b
+--R                    |--------------------------------------
+--R                   \|                 2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R          +------------------------------------+
+--R          |     +-----------------------+
+--R          |     | 2 4         2 2    2 4
+--R          |     |a d  + 2a b c d  + b c
+--R          |4a b |-----------------------  - c d
+--R          |     |            3 3
+--R          |    \|         64a b
+--R          |------------------------------------
+--R         \|                2a b
+--R      *
+--R         log
+--R                           +-----------------------+
+--R                           | 2 4         2 2    2 4
+--R                      3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                (- 16a b d |-----------------------  - 2a b c d  - 2a b c )
+--R                           |            3 3
+--R                          \|         64a b
+--R             *
+--R                 +------------------------------------+
+--R                 |     +-----------------------+
+--R                 |     | 2 4         2 2    2 4
+--R                 |     |a d  + 2a b c d  + b c
+--R                 |4a b |-----------------------  - c d
+--R                 |     |            3 3
+--R                 |    \|         64a b
+--R                 |------------------------------------
+--R                \|                2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1777
+
+--S 1778 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        +------------------------------------+
+--R                        |     +-----------------------+
+--R                        |     | 2 4         2 2    2 4
+--R                        |     |a d  + 2a b c d  + b c
+--R                        |4a b |-----------------------  - c d
+--R                        |     |            3 3
+--R            4+-+3 4+-+3 |    \|         64a b
+--R            \|a   \|b   |------------------------------------
+--R                       \|                2a b
+--R         *
+--R            log
+--R                            +-----------------------+
+--R                            | 2 4         2 2    2 4
+--R                       3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                   (16a b d |-----------------------  + 2a b c d  + 2a b c )
+--R                            |            3 3
+--R                           \|         64a b
+--R                *
+--R                    +------------------------------------+
+--R                    |     +-----------------------+
+--R                    |     | 2 4         2 2    2 4
+--R                    |     |a d  + 2a b c d  + b c
+--R                    |4a b |-----------------------  - c d
+--R                    |     |            3 3
+--R                    |    \|         64a b
+--R                    |------------------------------------
+--R                   \|                2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R                     +--------------------------------------+
+--R                     |       +-----------------------+
+--R                     |       | 2 4         2 2    2 4
+--R                     |       |a d  + 2a b c d  + b c
+--R                     |- 4a b |-----------------------  - c d
+--R                     |       |            3 3
+--R         4+-+3 4+-+3 |      \|         64a b
+--R         \|a   \|b   |--------------------------------------
+--R                    \|                 2a b
+--R      *
+--R         log
+--R                         +-----------------------+
+--R                         | 2 4         2 2    2 4
+--R                    3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                (16a b d |-----------------------  - 2a b c d  - 2a b c )
+--R                         |            3 3
+--R                        \|         64a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |       +-----------------------+
+--R                 |       | 2 4         2 2    2 4
+--R                 |       |a d  + 2a b c d  + b c
+--R                 |- 4a b |-----------------------  - c d
+--R                 |       |            3 3
+--R                 |      \|         64a b
+--R                 |--------------------------------------
+--R                \|                 2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R       -
+--R                        +--------------------------------------+
+--R                        |       +-----------------------+
+--R                        |       | 2 4         2 2    2 4
+--R                        |       |a d  + 2a b c d  + b c
+--R                        |- 4a b |-----------------------  - c d
+--R                        |       |            3 3
+--R            4+-+3 4+-+3 |      \|         64a b
+--R            \|a   \|b   |--------------------------------------
+--R                       \|                 2a b
+--R         *
+--R            log
+--R                              +-----------------------+
+--R                              | 2 4         2 2    2 4
+--R                         3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                   (- 16a b d |-----------------------  + 2a b c d  + 2a b c )
+--R                              |            3 3
+--R                             \|         64a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |       +-----------------------+
+--R                    |       | 2 4         2 2    2 4
+--R                    |       |a d  + 2a b c d  + b c
+--R                    |- 4a b |-----------------------  - c d
+--R                    |       |            3 3
+--R                    |      \|         64a b
+--R                    |--------------------------------------
+--R                   \|                 2a b
+--R               + 
+--R                   2 4    2 4
+--R                 (a d  - b c )x
+--R     + 
+--R                     +------------------------------------+
+--R                     |     +-----------------------+
+--R                     |     | 2 4         2 2    2 4
+--R                     |     |a d  + 2a b c d  + b c
+--R                     |4a b |-----------------------  - c d
+--R                     |     |            3 3
+--R         4+-+3 4+-+3 |    \|         64a b
+--R         \|a   \|b   |------------------------------------
+--R                    \|                2a b
+--R      *
+--R         log
+--R                           +-----------------------+
+--R                           | 2 4         2 2    2 4
+--R                      3 2  |a d  + 2a b c d  + b c       2     2       2 3
+--R                (- 16a b d |-----------------------  - 2a b c d  - 2a b c )
+--R                           |            3 3
+--R                          \|         64a b
+--R             *
+--R                 +------------------------------------+
+--R                 |     +-----------------------+
+--R                 |     | 2 4         2 2    2 4
+--R                 |     |a d  + 2a b c d  + b c
+--R                 |4a b |-----------------------  - c d
+--R                 |     |            3 3
+--R                 |    \|         64a b
+--R                 |------------------------------------
+--R                \|                2a b
+--R            + 
+--R                2 4    2 4
+--R              (a d  - b c )x
+--R     + 
+--R                               4+-+                           4+-+
+--R            +-+     +-+       x\|b          +-+     +-+      x\|b
+--R       (- c\|b  + d\|a )atanh(-----) + (- c\|b  - d\|a )atan(-----)
+--R                               4+-+                           4+-+
+--R                               \|a                            \|a
+--R  /
+--R      4+-+3 4+-+3
+--R     2\|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 1778
+
+--S 1779 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R             2     4+-+2      2 +-+ 4+-+2     4+-+2 +-+
+--R        ((d x  - c)\|a   - d x \|a )\|b   + c \|a  \|b
+--R   (5)  -----------------------------------------------
+--R                          4     4+-+2 4+-+2
+--R                      (b x  - a)\|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 1779
+
+)clear all
+
+--S 1780 of 3139
+t0:=(5+2*x^2)/(-1+x^4)
+--R 
+--R
+--R          2
+--R        2x  + 5
+--R   (1)  -------
+--R          4
+--R         x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1780
+
+--S 1781 of 3139
+r0:=-3/2*atan(x)-7/2*atanh(x)
+--R 
+--R
+--R        - 7atanh(x) - %pi
+--R   (2)  -----------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 1781
+
+--S 1782 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 7log(x + 1) + 7log(x - 1) - 2%pi
+--R   (3)  ----------------------------------
+--R                         4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1782
+
+--S 1783 of 3139
+m0:=a0-r0
+--R 
+--R
+--R        - 7log(x + 1) + 7log(x - 1) + 14atanh(x)
+--R   (4)  ----------------------------------------
+--R                            4
+--R                                                    Type: Expression(Integer)
+--E 1783
+
+--S 1784 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1784
+
+)clear all
+
+--S 1785 of 3139
+t0:=x^m*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R          22             20               18                16
+--R       e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x
+--R     + 
+--R                     14                 12                 10                 8
+--R       (210e + 120d)x   + (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x
+--R     + 
+--R                    6               4             2
+--R       (45e + 120d)x  + (10e + 45d)x  + (e + 10d)x  + d
+--R  *
+--R      m
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 1785
+
+--S 1786 of 3139
+r0:=d*x^(1+m)/(1+m)+(10*d+e)*x^(3+m)/(3+m)+5*(9*d+2*e)*x^(5+m)/(5+m)+_
+   15*(8*d+3*e)*x^(7+m)/(7+m)+30*(7*d+4*e)*x^(9+m)/(9+m)+42*(6*d+5*e)*_
+   x^(11+m)/(11+m)+42*(5*d+6*e)*x^(13+m)/(13+m)+30*(4*d+7*e)*x^(15+m)/_
+   (15+m)+15*(3*d+8*e)*x^(17+m)/(17+m)+5*(2*d+9*e)*x^(19+m)/(19+m)+_
+   (d+10*e)*x^(21+m)/(21+m)+e*x^(23+m)/(23+m)
+--R 
+--R
+--R   (2)
+--R              11         10          9            8             7              6
+--R           e m   + 121e m   + 6435e m  + 197835e m  + 3889578e m  + 51069018e m
+--R         + 
+--R                       5                4                 3                 2
+--R           453714470e m  + 2702025590e m  + 10431670821e m  + 24372200061e m
+--R         + 
+--R           29985521895e m + 13749310575e
+--R      *
+--R          m + 23
+--R         x
+--R     + 
+--R                     11                  10                    9
+--R           (10e + d)m   + (1230e + 123d)m   + (66350e + 6635d)m
+--R         + 
+--R                                8                          7
+--R           (2065050e + 206505d)m  + (41031780e + 4103178d)m
+--R         + 
+--R                                    6                              5
+--R           (543625740e + 54362574d)m  + (4866878300e + 486687830d)m
+--R         + 
+--R                                        4                                  3
+--R           (29170139700e + 2917013970d)m  + (113209660210e + 11320966021d)m
+--R         + 
+--R                                          2
+--R           (265603425030e + 26560342503d)m  + (327789307350e + 32778930735d)m
+--R         + 
+--R           150587687250e + 15058768725d
+--R      *
+--R          m + 21
+--R         x
+--R     + 
+--R                       11                   10                      9
+--R           (45e + 10d)m   + (5625e + 1250d)m   + (307935e + 68430d)m
+--R         + 
+--R                                 8                            7
+--R           (9712035e + 2158230d)m  + (195261570e + 43391460d)m
+--R         + 
+--R                                      6                                5
+--R           (2613849210e + 580855380d)m  + (23610449790e + 5246766620d)m
+--R         + 
+--R                                          4                                   3
+--R           (142587081990e + 31686018220d)m  + (556867114785e + 123748247730d)m
+--R         + 
+--R                                            2
+--R           (1313053121565e + 291789582570d)m
+--R         + 
+--R           (1626566238675e + 361459164150d)m + 748975602375e + 166439022750d
+--R      *
+--R          m + 19
+--R         x
+--R     + 
+--R                        11                    10                       9
+--R           (120e + 45d)m   + (15240e + 5715d)m   + (847080e + 317655d)m
+--R         + 
+--R                                   8                             7
+--R           (27100440e + 10162665d)m  + (552066480e + 207024930d)m
+--R         + 
+--R                                       6                                 5
+--R           (7478387280e + 2804395230d)m  + (68263642320e + 25598865870d)m
+--R         + 
+--R                                           4
+--R           (416013088560e + 156004908210d)m
+--R         + 
+--R                                            3
+--R           (1637168621400e + 613938233025d)m
+--R         + 
+--R                                             2
+--R           (3884208909480e + 1456578341055d)m
+--R         + 
+--R           (4833983334600e + 1812743750475d)m + 2232241011000e + 837090379125d
+--R      *
+--R          m + 17
+--R         x
+--R     + 
+--R                         11                     10                        9
+--R           (210e + 120d)m   + (27090e + 15480d)m   + (1529430e + 873960d)m
+--R         + 
+--R                                   8                              7
+--R           (49684950e + 28391400d)m  + (1027080180e + 586902960d)m
+--R         + 
+--R                                        6                                  5
+--R           (14104952820e + 8059973040d)m  + (130369103340e + 74496630480d)m
+--R         + 
+--R                                           4
+--R           (803329713900e + 459045550800d)m
+--R         + 
+--R                                             3
+--R           (3191488763610e + 1823707864920d)m
+--R         + 
+--R                                             2
+--R           (7630800624090e + 4360457499480d)m
+--R         + 
+--R           (9552676531230e + 5458672303560d)m + 4427278005150e + 2529873145800d
+--R      *
+--R          m + 15
+--R         x
+--R     + 
+--R                         11                     10                         9
+--R           (252e + 210d)m   + (33012e + 27510d)m   + (1893780e + 1578150d)m
+--R         + 
+--R                                   8                               7
+--R           (62532540e + 52110450d)m  + (1313902296e + 1094918580d)m
+--R         + 
+--R                                         6                                   5
+--R           (18332656776e + 15277213980d)m  + (172007536680e + 143339613900d)m
+--R         + 
+--R                                            4
+--R           (1074541539960e + 895451283300d)m
+--R         + 
+--R                                             3
+--R           (4320681347052e + 3600567789210d)m
+--R         + 
+--R                                              2
+--R           (10434900982212e + 8695750818510d)m
+--R         + 
+--R         (13163910302340e + 10969925251950d)m + 6130077237900e + 5108397698250d
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                         11                     10                         9
+--R           (210e + 252d)m   + (27930e + 33516d)m   + (1628550e + 1954260d)m
+--R         + 
+--R                                   8                               7
+--R           (54712350e + 65654820d)m  + (1170518580e + 1404622296d)m
+--R         + 
+--R                                         6                                   5
+--R           (16635451140e + 19962541368d)m  + (158953433100e + 190744119720d)m
+--R         + 
+--R                                             4
+--R           (1010378499900e + 1212454199880d)m
+--R         + 
+--R                                             3
+--R           (4127270973210e + 4952725167852d)m
+--R         + 
+--R                                               2
+--R           (10103151372930e + 12123781647516d)m
+--R         + 
+--R         (12880020790350e + 15456024948420d)m + 6037197279750e + 7244636735700d
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                         11                     10                        9
+--R           (120e + 210d)m   + (16200e + 28350d)m   + (960360e + 1680630d)m
+--R         + 
+--R                                   8                              7
+--R           (32857560e + 57500730d)m  + (717055920e + 1254847860d)m
+--R         + 
+--R                                         6                                   5
+--R           (10410014160e + 18217524780d)m  + (101706098640e + 177985672620d)m
+--R         + 
+--R                                            4
+--R           (661140120240e + 1156995210420d)m
+--R         + 
+--R                                             3
+--R           (2759130044760e + 4828477578330d)m
+--R         + 
+--R                                              2
+--R           (6883905070440e + 12046833873270d)m
+--R         + 
+--R         (8910389161800e + 15593181033150d)m + 4216455243000e + 7378796675250d
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                        11                    10                       9
+--R           (45e + 120d)m   + (6165e + 16440d)m   + (371655e + 991080d)m
+--R         + 
+--R                                   8                             7
+--R           (12961215e + 34563240d)m  + (289061730e + 770831280d)m
+--R         + 
+--R                                        6                                  5
+--R           (4300386930e + 11467698480d)m  + (43170876270e + 115122336720d)m
+--R         + 
+--R                                           4
+--R           (288989494110e + 770638650960d)m
+--R         + 
+--R                                             3
+--R           (1243095213825e + 3314920570200d)m
+--R         + 
+--R                                             2
+--R           (3191861805705e + 8511631481880d)m
+--R         + 
+--R         (4231542908475e + 11284114422600d)m + 2032933777875e + 5421156741000d
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R                       11                   10                      9
+--R           (10e + 45d)m   + (1390e + 6255d)m   + (85230e + 383535d)m
+--R         + 
+--R                                  8                            7
+--R           (3032250e + 13645125d)m  + (69236580e + 311564610d)m
+--R         + 
+--R                                       6                                 5
+--R           (1059110220e + 4765995990d)m  + (10987467740e + 49443604830d)m
+--R         + 
+--R                                          4                                    3
+--R           (76437245300e + 343967603850d)m  + (343596367410e + 1546183653345d)m
+--R         + 
+--R                                            2
+--R           (925024452390e + 4162610035755d)m
+--R         + 
+--R           (1280338971030e + 5761525369635d)m + 632468286450e + 2846107289025d
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R                     11                  10                    9
+--R           (e + 10d)m   + (141e + 1410d)m   + (8795e + 87950d)m
+--R         + 
+--R                                8                          7
+--R           (319455e + 3194550d)m  + (7481418e + 74814180d)m
+--R         + 
+--R                                      6                                5
+--R           (118085058e + 1180850580d)m  + (1274046710e + 12740467100d)m
+--R         + 
+--R                                        4                                  3
+--R           (9315318270e + 93153182700d)m  + (44632304581e + 446323045810d)m
+--R         + 
+--R                                            2
+--R           (130403715201e + 1304037152010d)m
+--R         + 
+--R           (199334977695e + 1993349776950d)m + 105411381075e + 1054113810750d
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R              11         10          9            8             7
+--R           d m   + 143d m   + 9075d m  + 336765d m  + 8103018d m
+--R         + 
+--R                       6                5                 4                 3
+--R           132426294d m  + 1495875590d m  + 11641582810d m  + 60936676581d m
+--R         + 
+--R                          2
+--R           203363952363d m  + 387182170935d m + 316234143225d
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R        12       11        10          9           8             7
+--R       m   + 144m   + 9218m   + 345840m  + 8439783m  + 140529312m
+--R     + 
+--R                  6               5               4                3
+--R       1628301884m  + 13137458400m  + 72578259391m  + 264300628944m
+--R     + 
+--R                    2
+--R       590546123298m  + 703416314160m + 316234143225
+--R                                                    Type: Expression(Integer)
+--E 1786
+
+--S 1787 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                11         10          9            8             7
+--R             e m   + 121e m   + 6435e m  + 197835e m  + 3889578e m
+--R           + 
+--R                        6               5                4                 3
+--R             51069018e m  + 453714470e m  + 2702025590e m  + 10431670821e m
+--R           + 
+--R                           2
+--R             24372200061e m  + 29985521895e m + 13749310575e
+--R        *
+--R            23
+--R           x
+--R       + 
+--R                       11                  10                    9
+--R             (10e + d)m   + (1230e + 123d)m   + (66350e + 6635d)m
+--R           + 
+--R                                  8                          7
+--R             (2065050e + 206505d)m  + (41031780e + 4103178d)m
+--R           + 
+--R                                      6                              5
+--R             (543625740e + 54362574d)m  + (4866878300e + 486687830d)m
+--R           + 
+--R                                          4                                  3
+--R             (29170139700e + 2917013970d)m  + (113209660210e + 11320966021d)m
+--R           + 
+--R                                            2
+--R             (265603425030e + 26560342503d)m  + (327789307350e + 32778930735d)m
+--R           + 
+--R             150587687250e + 15058768725d
+--R        *
+--R            21
+--R           x
+--R       + 
+--R                         11                   10                      9
+--R             (45e + 10d)m   + (5625e + 1250d)m   + (307935e + 68430d)m
+--R           + 
+--R                                   8                            7
+--R             (9712035e + 2158230d)m  + (195261570e + 43391460d)m
+--R           + 
+--R                                        6                                5
+--R             (2613849210e + 580855380d)m  + (23610449790e + 5246766620d)m
+--R           + 
+--R                                            4
+--R             (142587081990e + 31686018220d)m
+--R           + 
+--R                                             3
+--R             (556867114785e + 123748247730d)m
+--R           + 
+--R                                              2
+--R             (1313053121565e + 291789582570d)m
+--R           + 
+--R             (1626566238675e + 361459164150d)m + 748975602375e + 166439022750d
+--R        *
+--R            19
+--R           x
+--R       + 
+--R                          11                    10                       9
+--R             (120e + 45d)m   + (15240e + 5715d)m   + (847080e + 317655d)m
+--R           + 
+--R                                     8                             7
+--R             (27100440e + 10162665d)m  + (552066480e + 207024930d)m
+--R           + 
+--R                                         6                                 5
+--R             (7478387280e + 2804395230d)m  + (68263642320e + 25598865870d)m
+--R           + 
+--R                                             4
+--R             (416013088560e + 156004908210d)m
+--R           + 
+--R                                              3
+--R             (1637168621400e + 613938233025d)m
+--R           + 
+--R                                               2
+--R             (3884208909480e + 1456578341055d)m
+--R           + 
+--R           (4833983334600e + 1812743750475d)m + 2232241011000e + 837090379125d
+--R        *
+--R            17
+--R           x
+--R       + 
+--R                           11                     10                        9
+--R             (210e + 120d)m   + (27090e + 15480d)m   + (1529430e + 873960d)m
+--R           + 
+--R                                     8                              7
+--R             (49684950e + 28391400d)m  + (1027080180e + 586902960d)m
+--R           + 
+--R                                          6                                  5
+--R             (14104952820e + 8059973040d)m  + (130369103340e + 74496630480d)m
+--R           + 
+--R                                             4
+--R             (803329713900e + 459045550800d)m
+--R           + 
+--R                                               3
+--R             (3191488763610e + 1823707864920d)m
+--R           + 
+--R                                               2
+--R             (7630800624090e + 4360457499480d)m
+--R           + 
+--R           (9552676531230e + 5458672303560d)m + 4427278005150e + 2529873145800d
+--R        *
+--R            15
+--R           x
+--R       + 
+--R                           11                     10                         9
+--R             (252e + 210d)m   + (33012e + 27510d)m   + (1893780e + 1578150d)m
+--R           + 
+--R                                     8                               7
+--R             (62532540e + 52110450d)m  + (1313902296e + 1094918580d)m
+--R           + 
+--R                                           6                                   5
+--R             (18332656776e + 15277213980d)m  + (172007536680e + 143339613900d)m
+--R           + 
+--R                                              4
+--R             (1074541539960e + 895451283300d)m
+--R           + 
+--R                                               3
+--R             (4320681347052e + 3600567789210d)m
+--R           + 
+--R                                                2
+--R             (10434900982212e + 8695750818510d)m
+--R           + 
+--R             (13163910302340e + 10969925251950d)m + 6130077237900e
+--R           + 
+--R             5108397698250d
+--R        *
+--R            13
+--R           x
+--R       + 
+--R                           11                     10                         9
+--R             (210e + 252d)m   + (27930e + 33516d)m   + (1628550e + 1954260d)m
+--R           + 
+--R                                     8                               7
+--R             (54712350e + 65654820d)m  + (1170518580e + 1404622296d)m
+--R           + 
+--R                                           6                                   5
+--R             (16635451140e + 19962541368d)m  + (158953433100e + 190744119720d)m
+--R           + 
+--R                                               4
+--R             (1010378499900e + 1212454199880d)m
+--R           + 
+--R                                               3
+--R             (4127270973210e + 4952725167852d)m
+--R           + 
+--R                                                 2
+--R             (10103151372930e + 12123781647516d)m
+--R           + 
+--R             (12880020790350e + 15456024948420d)m + 6037197279750e
+--R           + 
+--R             7244636735700d
+--R        *
+--R            11
+--R           x
+--R       + 
+--R                           11                     10                        9
+--R             (120e + 210d)m   + (16200e + 28350d)m   + (960360e + 1680630d)m
+--R           + 
+--R                                     8                              7
+--R             (32857560e + 57500730d)m  + (717055920e + 1254847860d)m
+--R           + 
+--R                                           6                                   5
+--R             (10410014160e + 18217524780d)m  + (101706098640e + 177985672620d)m
+--R           + 
+--R                                              4
+--R             (661140120240e + 1156995210420d)m
+--R           + 
+--R                                               3
+--R             (2759130044760e + 4828477578330d)m
+--R           + 
+--R                                                2
+--R             (6883905070440e + 12046833873270d)m
+--R           + 
+--R           (8910389161800e + 15593181033150d)m + 4216455243000e + 7378796675250d
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                          11                    10                       9
+--R             (45e + 120d)m   + (6165e + 16440d)m   + (371655e + 991080d)m
+--R           + 
+--R                                     8                             7
+--R             (12961215e + 34563240d)m  + (289061730e + 770831280d)m
+--R           + 
+--R                                          6                                  5
+--R             (4300386930e + 11467698480d)m  + (43170876270e + 115122336720d)m
+--R           + 
+--R                                             4
+--R             (288989494110e + 770638650960d)m
+--R           + 
+--R                                               3
+--R             (1243095213825e + 3314920570200d)m
+--R           + 
+--R                                               2
+--R             (3191861805705e + 8511631481880d)m
+--R           + 
+--R           (4231542908475e + 11284114422600d)m + 2032933777875e + 5421156741000d
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                         11                   10                      9
+--R             (10e + 45d)m   + (1390e + 6255d)m   + (85230e + 383535d)m
+--R           + 
+--R                                    8                            7
+--R             (3032250e + 13645125d)m  + (69236580e + 311564610d)m
+--R           + 
+--R                                         6                                 5
+--R             (1059110220e + 4765995990d)m  + (10987467740e + 49443604830d)m
+--R           + 
+--R                                            4
+--R             (76437245300e + 343967603850d)m
+--R           + 
+--R                                              3
+--R             (343596367410e + 1546183653345d)m
+--R           + 
+--R                                              2
+--R             (925024452390e + 4162610035755d)m
+--R           + 
+--R           (1280338971030e + 5761525369635d)m + 632468286450e + 2846107289025d
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                       11                  10                    9
+--R             (e + 10d)m   + (141e + 1410d)m   + (8795e + 87950d)m
+--R           + 
+--R                                  8                          7
+--R             (319455e + 3194550d)m  + (7481418e + 74814180d)m
+--R           + 
+--R                                        6                                5
+--R             (118085058e + 1180850580d)m  + (1274046710e + 12740467100d)m
+--R           + 
+--R                                          4                                  3
+--R             (9315318270e + 93153182700d)m  + (44632304581e + 446323045810d)m
+--R           + 
+--R                                              2
+--R             (130403715201e + 1304037152010d)m
+--R           + 
+--R             (199334977695e + 1993349776950d)m + 105411381075e + 1054113810750d
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                11         10          9            8             7
+--R             d m   + 143d m   + 9075d m  + 336765d m  + 8103018d m
+--R           + 
+--R                         6                5                 4                 3
+--R             132426294d m  + 1495875590d m  + 11641582810d m  + 60936676581d m
+--R           + 
+--R                            2
+--R             203363952363d m  + 387182170935d m + 316234143225d
+--R        *
+--R           x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R        12       11        10          9           8             7
+--R       m   + 144m   + 9218m   + 345840m  + 8439783m  + 140529312m
+--R     + 
+--R                  6               5               4                3
+--R       1628301884m  + 13137458400m  + 72578259391m  + 264300628944m
+--R     + 
+--R                    2
+--R       590546123298m  + 703416314160m + 316234143225
+--R                                         Type: Union(Expression(Integer),...)
+--E 1787
+
+--S 1788 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  11         10          9            8             7
+--R               e m   + 121e m   + 6435e m  + 197835e m  + 3889578e m
+--R             + 
+--R                          6               5                4                 3
+--R               51069018e m  + 453714470e m  + 2702025590e m  + 10431670821e m
+--R             + 
+--R                             2
+--R               24372200061e m  + 29985521895e m + 13749310575e
+--R          *
+--R              23
+--R             x
+--R         + 
+--R                         11                  10                    9
+--R               (10e + d)m   + (1230e + 123d)m   + (66350e + 6635d)m
+--R             + 
+--R                                    8                          7
+--R               (2065050e + 206505d)m  + (41031780e + 4103178d)m
+--R             + 
+--R                                        6                              5
+--R               (543625740e + 54362574d)m  + (4866878300e + 486687830d)m
+--R             + 
+--R                                            4                                  3
+--R               (29170139700e + 2917013970d)m  + (113209660210e + 11320966021d)m
+--R             + 
+--R                                              2
+--R               (265603425030e + 26560342503d)m
+--R             + 
+--R               (327789307350e + 32778930735d)m + 150587687250e + 15058768725d
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                           11                   10                      9
+--R               (45e + 10d)m   + (5625e + 1250d)m   + (307935e + 68430d)m
+--R             + 
+--R                                     8                            7
+--R               (9712035e + 2158230d)m  + (195261570e + 43391460d)m
+--R             + 
+--R                                          6                                5
+--R               (2613849210e + 580855380d)m  + (23610449790e + 5246766620d)m
+--R             + 
+--R                                              4
+--R               (142587081990e + 31686018220d)m
+--R             + 
+--R                                               3
+--R               (556867114785e + 123748247730d)m
+--R             + 
+--R                                                2
+--R               (1313053121565e + 291789582570d)m
+--R             + 
+--R             (1626566238675e + 361459164150d)m + 748975602375e + 166439022750d
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                            11                    10                       9
+--R               (120e + 45d)m   + (15240e + 5715d)m   + (847080e + 317655d)m
+--R             + 
+--R                                       8                             7
+--R               (27100440e + 10162665d)m  + (552066480e + 207024930d)m
+--R             + 
+--R                                           6                                 5
+--R               (7478387280e + 2804395230d)m  + (68263642320e + 25598865870d)m
+--R             + 
+--R                                               4
+--R               (416013088560e + 156004908210d)m
+--R             + 
+--R                                                3
+--R               (1637168621400e + 613938233025d)m
+--R             + 
+--R                                                 2
+--R               (3884208909480e + 1456578341055d)m
+--R             + 
+--R             (4833983334600e + 1812743750475d)m + 2232241011000e + 837090379125d
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                             11                     10                        9
+--R               (210e + 120d)m   + (27090e + 15480d)m   + (1529430e + 873960d)m
+--R             + 
+--R                                       8                              7
+--R               (49684950e + 28391400d)m  + (1027080180e + 586902960d)m
+--R             + 
+--R                                            6                                  5
+--R               (14104952820e + 8059973040d)m  + (130369103340e + 74496630480d)m
+--R             + 
+--R                                               4
+--R               (803329713900e + 459045550800d)m
+--R             + 
+--R                                                 3
+--R               (3191488763610e + 1823707864920d)m
+--R             + 
+--R                                                 2
+--R               (7630800624090e + 4360457499480d)m
+--R             + 
+--R               (9552676531230e + 5458672303560d)m + 4427278005150e
+--R             + 
+--R               2529873145800d
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                             11                     10                         9
+--R               (252e + 210d)m   + (33012e + 27510d)m   + (1893780e + 1578150d)m
+--R             + 
+--R                                       8                               7
+--R               (62532540e + 52110450d)m  + (1313902296e + 1094918580d)m
+--R             + 
+--R                                             6
+--R               (18332656776e + 15277213980d)m
+--R             + 
+--R                                               5
+--R               (172007536680e + 143339613900d)m
+--R             + 
+--R                                                4
+--R               (1074541539960e + 895451283300d)m
+--R             + 
+--R                                                 3
+--R               (4320681347052e + 3600567789210d)m
+--R             + 
+--R                                                  2
+--R               (10434900982212e + 8695750818510d)m
+--R             + 
+--R               (13163910302340e + 10969925251950d)m + 6130077237900e
+--R             + 
+--R               5108397698250d
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                             11                     10                         9
+--R               (210e + 252d)m   + (27930e + 33516d)m   + (1628550e + 1954260d)m
+--R             + 
+--R                                       8                               7
+--R               (54712350e + 65654820d)m  + (1170518580e + 1404622296d)m
+--R             + 
+--R                                             6
+--R               (16635451140e + 19962541368d)m
+--R             + 
+--R                                               5
+--R               (158953433100e + 190744119720d)m
+--R             + 
+--R                                                 4
+--R               (1010378499900e + 1212454199880d)m
+--R             + 
+--R                                                 3
+--R               (4127270973210e + 4952725167852d)m
+--R             + 
+--R                                                   2
+--R               (10103151372930e + 12123781647516d)m
+--R             + 
+--R               (12880020790350e + 15456024948420d)m + 6037197279750e
+--R             + 
+--R               7244636735700d
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                             11                     10                        9
+--R               (120e + 210d)m   + (16200e + 28350d)m   + (960360e + 1680630d)m
+--R             + 
+--R                                       8                              7
+--R               (32857560e + 57500730d)m  + (717055920e + 1254847860d)m
+--R             + 
+--R                                             6
+--R               (10410014160e + 18217524780d)m
+--R             + 
+--R                                               5
+--R               (101706098640e + 177985672620d)m
+--R             + 
+--R                                                4
+--R               (661140120240e + 1156995210420d)m
+--R             + 
+--R                                                 3
+--R               (2759130044760e + 4828477578330d)m
+--R             + 
+--R                                                  2
+--R               (6883905070440e + 12046833873270d)m
+--R             + 
+--R               (8910389161800e + 15593181033150d)m + 4216455243000e
+--R             + 
+--R               7378796675250d
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                            11                    10                       9
+--R               (45e + 120d)m   + (6165e + 16440d)m   + (371655e + 991080d)m
+--R             + 
+--R                                       8                             7
+--R               (12961215e + 34563240d)m  + (289061730e + 770831280d)m
+--R             + 
+--R                                            6                                  5
+--R               (4300386930e + 11467698480d)m  + (43170876270e + 115122336720d)m
+--R             + 
+--R                                               4
+--R               (288989494110e + 770638650960d)m
+--R             + 
+--R                                                 3
+--R               (1243095213825e + 3314920570200d)m
+--R             + 
+--R                                                 2
+--R               (3191861805705e + 8511631481880d)m
+--R             + 
+--R               (4231542908475e + 11284114422600d)m + 2032933777875e
+--R             + 
+--R               5421156741000d
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                           11                   10                      9
+--R               (10e + 45d)m   + (1390e + 6255d)m   + (85230e + 383535d)m
+--R             + 
+--R                                      8                            7
+--R               (3032250e + 13645125d)m  + (69236580e + 311564610d)m
+--R             + 
+--R                                           6                                 5
+--R               (1059110220e + 4765995990d)m  + (10987467740e + 49443604830d)m
+--R             + 
+--R                                              4
+--R               (76437245300e + 343967603850d)m
+--R             + 
+--R                                                3
+--R               (343596367410e + 1546183653345d)m
+--R             + 
+--R                                                2
+--R               (925024452390e + 4162610035755d)m
+--R             + 
+--R             (1280338971030e + 5761525369635d)m + 632468286450e + 2846107289025d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                         11                  10                    9
+--R               (e + 10d)m   + (141e + 1410d)m   + (8795e + 87950d)m
+--R             + 
+--R                                    8                          7
+--R               (319455e + 3194550d)m  + (7481418e + 74814180d)m
+--R             + 
+--R                                          6                                5
+--R               (118085058e + 1180850580d)m  + (1274046710e + 12740467100d)m
+--R             + 
+--R                                            4                                  3
+--R               (9315318270e + 93153182700d)m  + (44632304581e + 446323045810d)m
+--R             + 
+--R                                                2
+--R               (130403715201e + 1304037152010d)m
+--R             + 
+--R             (199334977695e + 1993349776950d)m + 105411381075e + 1054113810750d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  11         10          9            8             7
+--R               d m   + 143d m   + 9075d m  + 336765d m  + 8103018d m
+--R             + 
+--R                           6                5                 4
+--R               132426294d m  + 1495875590d m  + 11641582810d m
+--R             + 
+--R                             3                  2
+--R               60936676581d m  + 203363952363d m  + 387182170935d m
+--R             + 
+--R               316234143225d
+--R          *
+--R             x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R                11         10          9            8             7
+--R           - e m   - 121e m   - 6435e m  - 197835e m  - 3889578e m
+--R         + 
+--R                        6               5                4                 3
+--R           - 51069018e m  - 453714470e m  - 2702025590e m  - 10431670821e m
+--R         + 
+--R                           2
+--R           - 24372200061e m  - 29985521895e m - 13749310575e
+--R      *
+--R          m + 23
+--R         x
+--R     + 
+--R                       11                    10                      9
+--R           (- 10e - d)m   + (- 1230e - 123d)m   + (- 66350e - 6635d)m
+--R         + 
+--R                                  8                            7
+--R           (- 2065050e - 206505d)m  + (- 41031780e - 4103178d)m
+--R         + 
+--R                                      6                                5
+--R           (- 543625740e - 54362574d)m  + (- 4866878300e - 486687830d)m
+--R         + 
+--R                                          4                                    3
+--R           (- 29170139700e - 2917013970d)m  + (- 113209660210e - 11320966021d)m
+--R         + 
+--R                                            2
+--R           (- 265603425030e - 26560342503d)m
+--R         + 
+--R           (- 327789307350e - 32778930735d)m - 150587687250e - 15058768725d
+--R      *
+--R          m + 21
+--R         x
+--R     + 
+--R                         11                     10                        9
+--R           (- 45e - 10d)m   + (- 5625e - 1250d)m   + (- 307935e - 68430d)m
+--R         + 
+--R                                   8                              7
+--R           (- 9712035e - 2158230d)m  + (- 195261570e - 43391460d)m
+--R         + 
+--R                                        6                                  5
+--R           (- 2613849210e - 580855380d)m  + (- 23610449790e - 5246766620d)m
+--R         + 
+--R                                            4
+--R           (- 142587081990e - 31686018220d)m
+--R         + 
+--R                                             3
+--R           (- 556867114785e - 123748247730d)m
+--R         + 
+--R                                              2
+--R           (- 1313053121565e - 291789582570d)m
+--R         + 
+--R           (- 1626566238675e - 361459164150d)m - 748975602375e - 166439022750d
+--R      *
+--R          m + 19
+--R         x
+--R     + 
+--R                          11                      10                         9
+--R           (- 120e - 45d)m   + (- 15240e - 5715d)m   + (- 847080e - 317655d)m
+--R         + 
+--R                                     8                               7
+--R           (- 27100440e - 10162665d)m  + (- 552066480e - 207024930d)m
+--R         + 
+--R                                         6                                   5
+--R           (- 7478387280e - 2804395230d)m  + (- 68263642320e - 25598865870d)m
+--R         + 
+--R                                             4
+--R           (- 416013088560e - 156004908210d)m
+--R         + 
+--R                                              3
+--R           (- 1637168621400e - 613938233025d)m
+--R         + 
+--R                                               2
+--R           (- 3884208909480e - 1456578341055d)m
+--R         + 
+--R         (- 4833983334600e - 1812743750475d)m - 2232241011000e - 837090379125d
+--R      *
+--R          m + 17
+--R         x
+--R     + 
+--R                           11                       10
+--R           (- 210e - 120d)m   + (- 27090e - 15480d)m
+--R         + 
+--R                                  9                             8
+--R           (- 1529430e - 873960d)m  + (- 49684950e - 28391400d)m
+--R         + 
+--R                                        7                                  6
+--R           (- 1027080180e - 586902960d)m  + (- 14104952820e - 8059973040d)m
+--R         + 
+--R                                            5
+--R           (- 130369103340e - 74496630480d)m
+--R         + 
+--R                                             4
+--R           (- 803329713900e - 459045550800d)m
+--R         + 
+--R                                               3
+--R           (- 3191488763610e - 1823707864920d)m
+--R         + 
+--R                                               2
+--R           (- 7630800624090e - 4360457499480d)m
+--R         + 
+--R         (- 9552676531230e - 5458672303560d)m - 4427278005150e - 2529873145800d
+--R      *
+--R          m + 15
+--R         x
+--R     + 
+--R                           11                       10
+--R           (- 252e - 210d)m   + (- 33012e - 27510d)m
+--R         + 
+--R                                   9                             8
+--R           (- 1893780e - 1578150d)m  + (- 62532540e - 52110450d)m
+--R         + 
+--R                                         7                                   6
+--R           (- 1313902296e - 1094918580d)m  + (- 18332656776e - 15277213980d)m
+--R         + 
+--R                                             5
+--R           (- 172007536680e - 143339613900d)m
+--R         + 
+--R                                              4
+--R           (- 1074541539960e - 895451283300d)m
+--R         + 
+--R                                               3
+--R           (- 4320681347052e - 3600567789210d)m
+--R         + 
+--R                                                2
+--R           (- 10434900982212e - 8695750818510d)m
+--R         + 
+--R           (- 13163910302340e - 10969925251950d)m - 6130077237900e
+--R         + 
+--R           - 5108397698250d
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                           11                       10
+--R           (- 210e - 252d)m   + (- 27930e - 33516d)m
+--R         + 
+--R                                   9                             8
+--R           (- 1628550e - 1954260d)m  + (- 54712350e - 65654820d)m
+--R         + 
+--R                                         7                                   6
+--R           (- 1170518580e - 1404622296d)m  + (- 16635451140e - 19962541368d)m
+--R         + 
+--R                                             5
+--R           (- 158953433100e - 190744119720d)m
+--R         + 
+--R                                               4
+--R           (- 1010378499900e - 1212454199880d)m
+--R         + 
+--R                                               3
+--R           (- 4127270973210e - 4952725167852d)m
+--R         + 
+--R                                                 2
+--R           (- 10103151372930e - 12123781647516d)m
+--R         + 
+--R           (- 12880020790350e - 15456024948420d)m - 6037197279750e
+--R         + 
+--R           - 7244636735700d
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                           11                       10
+--R           (- 120e - 210d)m   + (- 16200e - 28350d)m
+--R         + 
+--R                                  9                             8
+--R           (- 960360e - 1680630d)m  + (- 32857560e - 57500730d)m
+--R         + 
+--R                                        7                                   6
+--R           (- 717055920e - 1254847860d)m  + (- 10410014160e - 18217524780d)m
+--R         + 
+--R                                             5
+--R           (- 101706098640e - 177985672620d)m
+--R         + 
+--R                                              4
+--R           (- 661140120240e - 1156995210420d)m
+--R         + 
+--R                                               3
+--R           (- 2759130044760e - 4828477578330d)m
+--R         + 
+--R                                                2
+--R           (- 6883905070440e - 12046833873270d)m
+--R         + 
+--R         (- 8910389161800e - 15593181033150d)m - 4216455243000e - 7378796675250d
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                          11                      10                         9
+--R           (- 45e - 120d)m   + (- 6165e - 16440d)m   + (- 371655e - 991080d)m
+--R         + 
+--R                                     8                               7
+--R           (- 12961215e - 34563240d)m  + (- 289061730e - 770831280d)m
+--R         + 
+--R                                          6                                    5
+--R           (- 4300386930e - 11467698480d)m  + (- 43170876270e - 115122336720d)m
+--R         + 
+--R                                             4
+--R           (- 288989494110e - 770638650960d)m
+--R         + 
+--R                                               3
+--R           (- 1243095213825e - 3314920570200d)m
+--R         + 
+--R                                               2
+--R           (- 3191861805705e - 8511631481880d)m
+--R         + 
+--R         (- 4231542908475e - 11284114422600d)m - 2032933777875e - 5421156741000d
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R                         11                     10                        9
+--R           (- 10e - 45d)m   + (- 1390e - 6255d)m   + (- 85230e - 383535d)m
+--R         + 
+--R                                    8                              7
+--R           (- 3032250e - 13645125d)m  + (- 69236580e - 311564610d)m
+--R         + 
+--R                                         6                                   5
+--R           (- 1059110220e - 4765995990d)m  + (- 10987467740e - 49443604830d)m
+--R         + 
+--R                                            4
+--R           (- 76437245300e - 343967603850d)m
+--R         + 
+--R                                              3
+--R           (- 343596367410e - 1546183653345d)m
+--R         + 
+--R                                              2
+--R           (- 925024452390e - 4162610035755d)m
+--R         + 
+--R         (- 1280338971030e - 5761525369635d)m - 632468286450e - 2846107289025d
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R                       11                    10                      9
+--R           (- e - 10d)m   + (- 141e - 1410d)m   + (- 8795e - 87950d)m
+--R         + 
+--R                                  8                            7
+--R           (- 319455e - 3194550d)m  + (- 7481418e - 74814180d)m
+--R         + 
+--R                                        6                                  5
+--R           (- 118085058e - 1180850580d)m  + (- 1274046710e - 12740467100d)m
+--R         + 
+--R                                          4                                    3
+--R           (- 9315318270e - 93153182700d)m  + (- 44632304581e - 446323045810d)m
+--R         + 
+--R                                              2
+--R           (- 130403715201e - 1304037152010d)m
+--R         + 
+--R           (- 199334977695e - 1993349776950d)m - 105411381075e - 1054113810750d
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R                11         10          9            8             7
+--R           - d m   - 143d m   - 9075d m  - 336765d m  - 8103018d m
+--R         + 
+--R                         6                5                 4                 3
+--R           - 132426294d m  - 1495875590d m  - 11641582810d m  - 60936676581d m
+--R         + 
+--R                            2
+--R           - 203363952363d m  - 387182170935d m - 316234143225d
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R        12       11        10          9           8             7
+--R       m   + 144m   + 9218m   + 345840m  + 8439783m  + 140529312m
+--R     + 
+--R                  6               5               4                3
+--R       1628301884m  + 13137458400m  + 72578259391m  + 264300628944m
+--R     + 
+--R                    2
+--R       590546123298m  + 703416314160m + 316234143225
+--R                                                    Type: Expression(Integer)
+--E 1788
+
+--S 1789 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            22             20               18                16
+--R         e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x
+--R       + 
+--R                       14                 12                 10
+--R         (210e + 120d)x   + (252e + 210d)x   + (210e + 252d)x
+--R       + 
+--R                       8                6               4             2
+--R         (120e + 210d)x  + (45e + 120d)x  + (10e + 45d)x  + (e + 10d)x  + d
+--R    *
+--R         m log(x)
+--R       %e
+--R   + 
+--R          m + 22               m + 20                 m + 18
+--R     - e x       + (- 10e - d)x       + (- 45e - 10d)x
+--R   + 
+--R                    m + 16                   m + 14                   m + 12
+--R     (- 120e - 45d)x       + (- 210e - 120d)x       + (- 252e - 210d)x
+--R   + 
+--R                     m + 10                   m + 8                  m + 6
+--R     (- 210e - 252d)x       + (- 120e - 210d)x      + (- 45e - 120d)x
+--R   + 
+--R                   m + 4               m + 2      m
+--R     (- 10e - 45d)x      + (- e - 10d)x      - d x
+--R                                                    Type: Expression(Integer)
+--E 1789
+
+)clear all
+
+--S 1790 of 3139
+t0:=x^5*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        27             25               23                21                 19
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   17                 15                 13                11
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x   + (45e + 120d)x
+--R   + 
+--R                 9             7      5
+--R     (10e + 45d)x  + (e + 10d)x  + d x
+--R                                                    Type: Polynomial(Integer)
+--E 1790
+
+--S 1791 of 3139
+r0:=1/22*(d-e)*(1+x^2)^11-1/24*(2*d-3*e)*(1+x^2)^12+1/26*(d-3*e)*(1+x^2)^13+_
+   1/28*e*(1+x^2)^14
+--R 
+--R
+--R   (2)
+--R      1    28     5      1    26    15      5    24    60     45    22
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (-- e + -- d)x
+--R     28          13     26           8     12          11     22
+--R   + 
+--R      21         20          35    18    105     63    16    60          14
+--R     (-- e + 6d)x   + (14e + -- d)x   + (--- e + -- d)x   + (-- e + 15d)x
+--R       2                      3           8       4           7
+--R   + 
+--R      15          12        9    10    1     5    8   1    6     1        1
+--R     (-- e + 10d)x   + (e + - d)x   + (- e + - d)x  + - d x  - ---- e + ---- d
+--R       4                    2          8     4        6        8008     1716
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1791
+
+--S 1792 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    28     5      1    26    15      5    24    60     45    22
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (-- e + -- d)x
+--R     28          13     26           8     12          11     22
+--R   + 
+--R      21         20          35    18    105     63    16    60          14
+--R     (-- e + 6d)x   + (14e + -- d)x   + (--- e + -- d)x   + (-- e + 15d)x
+--R       2                      3           8       4           7
+--R   + 
+--R      15          12        9    10    1     5    8   1    6
+--R     (-- e + 10d)x   + (e + - d)x   + (- e + - d)x  + - d x
+--R       4                    2          8     4        6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1792
+
+--S 1793 of 3139
+m0:=a0-r0
+--R 
+--R
+--R          1        1
+--R   (4)  ---- e - ---- d
+--R        8008     1716
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1793
+
+--S 1794 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1794
+
+)clear all
+
+--S 1795 of 3139
+t0:=x^4*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        26             24               22                20                 18
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   16                 14                 12                10
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x   + (45e + 120d)x
+--R   + 
+--R                 8             6      4
+--R     (10e + 45d)x  + (e + 10d)x  + d x
+--R                                                    Type: Polynomial(Integer)
+--E 1795
+
+--S 1796 of 3139
+r0:=1/5*d*x^5+1/7*(10*d+e)*x^7+5/9*(9*d+2*e)*x^9+15/11*(8*d+3*e)*x^11+_
+   30/13*(7*d+4*e)*x^13+14/5*(6*d+5*e)*x^15+42/17*(5*d+6*e)*x^17+_
+   30/19*(4*d+7*e)*x^19+5/7*(3*d+8*e)*x^21+5/23*(2*d+9*e)*x^23+_
+   1/25*(d+10*e)*x^25+1/27*e*x^27
+--R 
+--R
+--R   (2)
+--R      1    27    2      1    25    45     10    23    40     15    21
+--R     -- e x   + (- e + -- d)x   + (-- e + -- d)x   + (-- e + -- d)x
+--R     27          5     25          23     23           7      7
+--R   + 
+--R      210     120    19    252     210    17          84    15
+--R     (--- e + --- d)x   + (--- e + --- d)x   + (14e + -- d)x
+--R       19      19           17      17                 5
+--R   + 
+--R      120     210    13    45     120    11    10         9    1     10    7
+--R     (--- e + --- d)x   + (-- e + --- d)x   + (-- e + 5d)x  + (- e + -- d)x
+--R       13      13          11      11           9              7      7
+--R   + 
+--R     1    5
+--R     - d x
+--R     5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1796
+
+--S 1797 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    27    2      1    25    45     10    23    40     15    21
+--R     -- e x   + (- e + -- d)x   + (-- e + -- d)x   + (-- e + -- d)x
+--R     27          5     25          23     23           7      7
+--R   + 
+--R      210     120    19    252     210    17          84    15
+--R     (--- e + --- d)x   + (--- e + --- d)x   + (14e + -- d)x
+--R       19      19           17      17                 5
+--R   + 
+--R      120     210    13    45     120    11    10         9    1     10    7
+--R     (--- e + --- d)x   + (-- e + --- d)x   + (-- e + 5d)x  + (- e + -- d)x
+--R       13      13          11      11           9              7      7
+--R   + 
+--R     1    5
+--R     - d x
+--R     5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1797
+
+--S 1798 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1798
+
+--S 1799 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1799
+
+)clear all
+
+--S 1800 of 3139
+t0:=x^3*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        25             23               21                19                 17
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   15                 13                 11                9
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x   + (45e + 120d)x
+--R   + 
+--R                 7             5      3
+--R     (10e + 45d)x  + (e + 10d)x  + d x
+--R                                                    Type: Polynomial(Integer)
+--E 1800
+
+--S 1801 of 3139
+r0:=-1/22*(d-e)*(1+x^2)^11+1/24*(d-2*e)*(1+x^2)^12+1/26*e*(1+x^2)^13
+--R 
+--R
+--R   (2)
+--R      1    26     5      1    24    45      5    22         9    20
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (6e + - d)x
+--R     26          12     24          22     11               4
+--R   + 
+--R      35     20    18    63     105    16               14          35    12
+--R     (-- e + -- d)x   + (-- e + --- d)x   + (15e + 18d)x   + (10e + -- d)x
+--R       3      3           4      8                                   2
+--R   + 
+--R      9          10    5     45    8    1     5    6   1    4     1       1
+--R     (- e + 12d)x   + (- e + -- d)x  + (- e + - d)x  + - d x  + ---- e - --- d
+--R      2                4      8         6     3        4        1716     264
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1801
+
+--S 1802 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    26     5      1    24    45      5    22         9    20
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (6e + - d)x
+--R     26          12     24          22     11               4
+--R   + 
+--R      35     20    18    63     105    16               14          35    12
+--R     (-- e + -- d)x   + (-- e + --- d)x   + (15e + 18d)x   + (10e + -- d)x
+--R       3      3           4      8                                   2
+--R   + 
+--R      9          10    5     45    8    1     5    6   1    4
+--R     (- e + 12d)x   + (- e + -- d)x  + (- e + - d)x  + - d x
+--R      2                4      8         6     3        4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1802
+
+--S 1803 of 3139
+m0:=a0-r0
+--R 
+--R
+--R            1       1
+--R   (4)  - ---- e + --- d
+--R          1716     264
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1803
+
+--S 1804 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1804
+
+)clear all
+
+--S 1805 of 3139
+t0:=x^2*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        24             22               20                18                 16
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   14                 12                 10                8
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x   + (45e + 120d)x
+--R   + 
+--R                 6             4      2
+--R     (10e + 45d)x  + (e + 10d)x  + d x
+--R                                                    Type: Polynomial(Integer)
+--E 1805
+
+--S 1806 of 3139
+r0:=1/3*d*x^3+1/5*(10*d+e)*x^5+5/7*(9*d+2*e)*x^7+5/3*(8*d+3*e)*x^9+_
+   30/11*(7*d+4*e)*x^11+42/13*(6*d+5*e)*x^13+14/5*(5*d+6*e)*x^15+_
+   30/17*(4*d+7*e)*x^17+15/19*(3*d+8*e)*x^19+5/21*(2*d+9*e)*x^21+_
+   1/23*(d+10*e)*x^23+1/25*e*x^25
+--R 
+--R
+--R   (2)
+--R      1    25    10      1    23    15     10    21    120     45    19
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (--- e + -- d)x
+--R     25          23     23           7     21           19     19
+--R   + 
+--R      210     120    17    84          15    210     252    13
+--R     (--- e + --- d)x   + (-- e + 14d)x   + (--- e + --- d)x
+--R       17      17           5                 13      13
+--R   + 
+--R    120     210    11         40    9    10     45    7    1         5   1    3
+--R   (--- e + --- d)x   + (5e + -- d)x  + (-- e + -- d)x  + (- e + 2d)x  + - d x
+--R     11      11                3          7      7         5             3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1806
+
+--S 1807 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    25    10      1    23    15     10    21    120     45    19
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (--- e + -- d)x
+--R     25          23     23           7     21           19     19
+--R   + 
+--R      210     120    17    84          15    210     252    13
+--R     (--- e + --- d)x   + (-- e + 14d)x   + (--- e + --- d)x
+--R       17      17           5                 13      13
+--R   + 
+--R    120     210    11         40    9    10     45    7    1         5   1    3
+--R   (--- e + --- d)x   + (5e + -- d)x  + (-- e + -- d)x  + (- e + 2d)x  + - d x
+--R     11      11                3          7      7         5             3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1807
+
+--S 1808 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1808
+
+--S 1809 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1809
+
+)clear all
+
+--S 1810 of 3139
+t0:=x*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        23             21               19                17                 15
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   13                 11                 9                7
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x  + (45e + 120d)x
+--R   + 
+--R                 5             3
+--R     (10e + 45d)x  + (e + 10d)x  + d x
+--R                                                    Type: Polynomial(Integer)
+--E 1810
+
+--S 1811 of 3139
+r0:=1/22*(d-e)*(1+x^2)^11+1/24*e*(1+x^2)^12
+--R 
+--R
+--R   (2)
+--R      1    24     5      1    22    9     1    20    20     5    18
+--R     -- e x   + (-- e + -- d)x   + (- e + - d)x   + (-- e + - d)x
+--R     24          11     22          4     2           3     2
+--R   + 
+--R      105     15    16               14    35          12               10
+--R     (--- e + -- d)x   + (18e + 15d)x   + (-- e + 21d)x   + (12e + 21d)x
+--R       8       2                            2
+--R   + 
+--R      45          8    5     15    6    1     5    4   1    2    1       1
+--R     (-- e + 15d)x  + (- e + -- d)x  + (- e + - d)x  + - d x  - --- e + -- d
+--R       8               3      2         4     2        2        264     22
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1811
+
+--S 1812 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    24     5      1    22    9     1    20    20     5    18
+--R     -- e x   + (-- e + -- d)x   + (- e + - d)x   + (-- e + - d)x
+--R     24          11     22          4     2           3     2
+--R   + 
+--R      105     15    16               14    35          12               10
+--R     (--- e + -- d)x   + (18e + 15d)x   + (-- e + 21d)x   + (12e + 21d)x
+--R       8       2                            2
+--R   + 
+--R      45          8    5     15    6    1     5    4   1    2
+--R     (-- e + 15d)x  + (- e + -- d)x  + (- e + - d)x  + - d x
+--R       8               3      2         4     2        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1812
+
+--S 1813 of 3139
+m0:=a0-r0
+--R 
+--R
+--R         1       1
+--R   (4)  --- e - -- d
+--R        264     22
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1813
+
+--S 1814 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1814
+
+)clear all
+
+--S 1815 of 3139
+t0:=(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        22             20               18                16                 14
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   12                 10                 8                6
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x  + (45e + 120d)x
+--R   + 
+--R                 4             2
+--R     (10e + 45d)x  + (e + 10d)x  + d
+--R                                                    Type: Polynomial(Integer)
+--E 1815
+
+--S 1816 of 3139
+r0:=d*x+1/3*(10*d+e)*x^3+(9*d+2*e)*x^5+15/7*(8*d+3*e)*x^7+10/3*(7*d+4*e)*_
+   x^9+42/11*(6*d+5*e)*x^11+42/13*(5*d+6*e)*x^13+2*(4*d+7*e)*x^15+_
+   15/17*(3*d+8*e)*x^17+5/19*(2*d+9*e)*x^19+1/21*(d+10*e)*x^21+1/23*e*x^23
+--R 
+--R
+--R   (2)
+--R      1    23    10      1    21    45     10    19    120     45    17
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (--- e + -- d)x
+--R     23          21     21          19     19           17     17
+--R   + 
+--R                15    252     210    13    210     252    11    40     70    9
+--R     (14e + 8d)x   + (--- e + --- d)x   + (--- e + --- d)x   + (-- e + -- d)x
+--R                       13      13           11      11           3      3
+--R   + 
+--R      45     120    7             5    1     10    3
+--R     (-- e + --- d)x  + (2e + 9d)x  + (- e + -- d)x  + d x
+--R       7      7                        3      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1816
+
+--S 1817 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    23    10      1    21    45     10    19    120     45    17
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (--- e + -- d)x
+--R     23          21     21          19     19           17     17
+--R   + 
+--R                15    252     210    13    210     252    11    40     70    9
+--R     (14e + 8d)x   + (--- e + --- d)x   + (--- e + --- d)x   + (-- e + -- d)x
+--R                       13      13           11      11           3      3
+--R   + 
+--R      45     120    7             5    1     10    3
+--R     (-- e + --- d)x  + (2e + 9d)x  + (- e + -- d)x  + d x
+--R       7      7                        3      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1817
+
+--S 1818 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1818
+
+--S 1819 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1819
+
+)clear all
+
+--S 1820 of 3139
+t0:=(d+e*x^2)*(1+2*x^2+x^4)^5/x
+--R 
+--R
+--R   (1)
+--R          22             20               18                16
+--R       e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x
+--R     + 
+--R                     14                 12                 10                 8
+--R       (210e + 120d)x   + (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x
+--R     + 
+--R                    6               4             2
+--R       (45e + 120d)x  + (10e + 45d)x  + (e + 10d)x  + d
+--R  /
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1820
+
+--S 1821 of 3139
+r0:=5*d*x^2+45/4*d*x^4+20*d*x^6+105/4*d*x^8+126/5*d*x^10+35/2*d*x^12+_
+   60/7*d*x^14+45/16*d*x^16+5/9*d*x^18+1/20*d*x^20+1/22*e*(1+x^2)^11+d*log(x)
+--R 
+--R
+--R   (2)
+--R                              22                    20                      18
+--R       55440d log(x) + 2520e x   + (27720e + 2772d)x   + (138600e + 30800d)x
+--R     + 
+--R                           16                       14                        12
+--R       (415800e + 155925d)x   + (831600e + 475200d)x   + (1164240e + 970200d)x
+--R     + 
+--R                             10                        8
+--R       (1164240e + 1397088d)x   + (831600e + 1455300d)x
+--R     + 
+--R                            6                       4                      2
+--R       (415800e + 1108800d)x  + (138600e + 623700d)x  + (27720e + 277200d)x
+--R     + 
+--R       2520e
+--R  /
+--R     55440
+--R                                                    Type: Expression(Integer)
+--E 1821
+
+--S 1822 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                              22                    20                      18
+--R       55440d log(x) + 2520e x   + (27720e + 2772d)x   + (138600e + 30800d)x
+--R     + 
+--R                           16                       14                        12
+--R       (415800e + 155925d)x   + (831600e + 475200d)x   + (1164240e + 970200d)x
+--R     + 
+--R                             10                        8
+--R       (1164240e + 1397088d)x   + (831600e + 1455300d)x
+--R     + 
+--R                            6                       4                      2
+--R       (415800e + 1108800d)x  + (138600e + 623700d)x  + (27720e + 277200d)x
+--R  /
+--R     55440
+--R                                         Type: Union(Expression(Integer),...)
+--E 1822
+
+--S 1823 of 3139
+m0:=a0-r0
+--R 
+--R
+--R           e
+--R   (4)  - --
+--R          22
+--R                                                    Type: Expression(Integer)
+--E 1823
+
+--S 1824 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1824
+
+)clear all
+
+--S 1825 of 3139
+t0:=(d+e*x^2)*(1+2*x^2+x^4)^5/x^2
+--R 
+--R
+--R   (1)
+--R          22             20               18                16
+--R       e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x
+--R     + 
+--R                     14                 12                 10                 8
+--R       (210e + 120d)x   + (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x
+--R     + 
+--R                    6               4             2
+--R       (45e + 120d)x  + (10e + 45d)x  + (e + 10d)x  + d
+--R  /
+--R      2
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1825
+
+--S 1826 of 3139
+r0:=-d/x+(10*d+e)*x+5/3*(9*d+2*e)*x^3+3*(8*d+3*e)*x^5+30/7*(7*d+4*e)*x^7+_
+   14/3*(6*d+5*e)*x^9+42/11*(5*d+6*e)*x^11+30/13*(4*d+7*e)*x^13+(3*d+8*e)*_
+   x^15+5/17*(2*d+9*e)*x^17+1/19*(d+10*e)*x^19+1/21*e*x^21
+--R 
+--R
+--R   (2)
+--R               22                      20                        18
+--R       46189e x   + (510510e + 51051d)x   + (2567565e + 570570d)x
+--R     + 
+--R                             16                          14
+--R       (7759752e + 2909907d)x   + (15668730e + 8953560d)x
+--R     + 
+--R                               12                           10
+--R       (22221108e + 18517590d)x   + (22632610e + 27159132d)x
+--R     + 
+--R                               8                          6
+--R       (16628040e + 29099070d)x  + (8729721e + 23279256d)x
+--R     + 
+--R                              4                        2
+--R       (3233230e + 14549535d)x  + (969969e + 9699690d)x  - 969969d
+--R  /
+--R     969969x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1826
+
+--S 1827 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               22                      20                        18
+--R       46189e x   + (510510e + 51051d)x   + (2567565e + 570570d)x
+--R     + 
+--R                             16                          14
+--R       (7759752e + 2909907d)x   + (15668730e + 8953560d)x
+--R     + 
+--R                               12                           10
+--R       (22221108e + 18517590d)x   + (22632610e + 27159132d)x
+--R     + 
+--R                               8                          6
+--R       (16628040e + 29099070d)x  + (8729721e + 23279256d)x
+--R     + 
+--R                              4                        2
+--R       (3233230e + 14549535d)x  + (969969e + 9699690d)x  - 969969d
+--R  /
+--R     969969x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1827
+
+--S 1828 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1828
+
+--S 1829 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1829
+
+)clear all
+
+--S 1830 of 3139
+t0:=(d+e*x^2)*(1+2*x^2+x^4)^5/x^3
+--R 
+--R
+--R   (1)
+--R          22             20               18                16
+--R       e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x
+--R     + 
+--R                     14                 12                 10                 8
+--R       (210e + 120d)x   + (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x
+--R     + 
+--R                    6               4             2
+--R       (45e + 120d)x  + (10e + 45d)x  + (e + 10d)x  + d
+--R  /
+--R      3
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1830
+
+--S 1831 of 3139
+r0:=-1/2*d/x^2+5/2*(9*d+2*e)*x^2+15/4*(8*d+3*e)*x^4+5*(7*d+4*e)*x^6+_
+   21/4*(6*d+5*e)*x^8+21/5*(5*d+6*e)*x^10+5/2*(4*d+7*e)*x^12+_
+   15/14*(3*d+8*e)*x^14+5/16*(2*d+9*e)*x^16+1/18*(d+10*e)*x^18+_
+   1/20*e*x^20+(10*d+e)*log(x)
+--R 
+--R
+--R   (2)
+--R                        2               22                  20
+--R       (5040e + 50400d)x log(x) + 252e x   + (2800e + 280d)x
+--R     + 
+--R                        18                     16                     14
+--R       (14175e + 3150d)x   + (43200e + 16200d)x   + (88200e + 50400d)x
+--R     + 
+--R                           12                       10                       8
+--R       (127008e + 105840d)x   + (132300e + 158760d)x   + (100800e + 176400d)x
+--R     + 
+--R                          6                      4
+--R       (56700e + 151200d)x  + (25200e + 113400d)x  - 2520d
+--R  /
+--R          2
+--R     5040x
+--R                                                    Type: Expression(Integer)
+--E 1831
+
+--S 1832 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        2               22                  20
+--R       (5040e + 50400d)x log(x) + 252e x   + (2800e + 280d)x
+--R     + 
+--R                        18                     16                     14
+--R       (14175e + 3150d)x   + (43200e + 16200d)x   + (88200e + 50400d)x
+--R     + 
+--R                           12                       10                       8
+--R       (127008e + 105840d)x   + (132300e + 158760d)x   + (100800e + 176400d)x
+--R     + 
+--R                          6                      4
+--R       (56700e + 151200d)x  + (25200e + 113400d)x  - 2520d
+--R  /
+--R          2
+--R     5040x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1832
+
+--S 1833 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1833
+
+--S 1834 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1834
+
+)clear all
+
+--S 1835 of 3139
+t0:=x^m*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        22      20      18       16       14       12       10       8       6
+--R       x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R     + 
+--R          4      2
+--R       55x  + 11x  + 1
+--R  *
+--R      m
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 1835
+
+--S 1836 of 3139
+r0:=x^(1+m)/(1+m)+11*x^(3+m)/(3+m)+55*x^(5+m)/(5+m)+165*x^(7+m)/(7+m)+_
+   330*x^(9+m)/(9+m)+462*x^(11+m)/(11+m)+462*x^(13+m)/(13+m)+_
+   330*x^(15+m)/(15+m)+165*x^(17+m)/(17+m)+55*x^(19+m)/(19+m)+_
+   11*x^(21+m)/(21+m)+x^(23+m)/(23+m)
+--R 
+--R
+--R   (2)
+--R            11       10        9          8           7            6
+--R           m   + 121m   + 6435m  + 197835m  + 3889578m  + 51069018m
+--R         + 
+--R                     5              4               3               2
+--R           453714470m  + 2702025590m  + 10431670821m  + 24372200061m
+--R         + 
+--R           29985521895m + 13749310575
+--R      *
+--R          m + 23
+--R         x
+--R     + 
+--R              11        10         9           8            7             6
+--R           11m   + 1353m   + 72985m  + 2271555m  + 45134958m  + 597988314m
+--R         + 
+--R                      5               4                3                2
+--R           5353566130m  + 32087153670m  + 124530626231m  + 292163767533m
+--R         + 
+--R           360568238085m + 165646455975
+--R      *
+--R          m + 21
+--R         x
+--R     + 
+--R              11        10          9            8             7              6
+--R           55m   + 6875m   + 376365m  + 11870265m  + 238653030m  + 3194704590m
+--R         + 
+--R                       5                4                3                 2
+--R           28857216410m  + 174273100210m  + 680615362515m  + 1604842704135m
+--R         + 
+--R           1988025402825m + 915414625125
+--R      *
+--R          m + 19
+--R         x
+--R     + 
+--R               11         10           9            8             7
+--R           165m   + 20955m   + 1164735m  + 37263105m  + 759091410m
+--R         + 
+--R                       6               5                4                 3
+--R           10282782510m  + 93862508190m  + 572017996770m  + 2251106854425m
+--R         + 
+--R                         2
+--R           5340787250535m  + 6646727085075m + 3069331390125
+--R      *
+--R          m + 17
+--R         x
+--R     + 
+--R               11         10           9            8              7
+--R           330m   + 42570m   + 2403390m  + 78076350m  + 1613983140m
+--R         + 
+--R                       6                5                 4                 3
+--R           22164925860m  + 204865733820m  + 1262375264700m  + 5015196628530m
+--R         + 
+--R                          2
+--R           11991258123570m  + 15011348834790m + 6957151150950
+--R      *
+--R          m + 15
+--R         x
+--R     + 
+--R               11         10           9             8              7
+--R           462m   + 60522m   + 3471930m  + 114642990m  + 2408820876m
+--R         + 
+--R                       6                5                 4                 3
+--R           33609870756m  + 315347150580m  + 1969992823260m  + 7921249136262m
+--R         + 
+--R                          2
+--R           19130651800722m  + 24133835554290m + 11238474936150
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R               11         10           9             8              7
+--R           462m   + 61446m   + 3582810m  + 120367170m  + 2575140876m
+--R         + 
+--R                       6                5                 4                 3
+--R           36597992508m  + 349697552820m  + 2222832699780m  + 9079996141062m
+--R         + 
+--R                          2
+--R           22226933020446m  + 28336045738770m + 13281834015450
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R               11         10           9            8              7
+--R           330m   + 44550m   + 2640990m  + 90358290m  + 1971903780m
+--R         + 
+--R                       6                5                 4                 3
+--R           28627538940m  + 279691771260m  + 1818135330660m  + 7587607623090m
+--R         + 
+--R                          2
+--R           18930738943710m  + 24503570194950m + 11595251918250
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R               11         10           9            8              7
+--R           165m   + 22605m   + 1362735m  + 47524455m  + 1059893010m
+--R         + 
+--R                       6                5                 4                 3
+--R           15768085410m  + 158293212990m  + 1059628145070m  + 4558015784025m
+--R         + 
+--R                          2
+--R           11703493287585m  + 15515657331075m + 7454090518875
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R              11        10          9            8             7              6
+--R           55m   + 7645m   + 468765m  + 16677375m  + 380801190m  + 5825106210m
+--R         + 
+--R                       5                4                 3                 2
+--R           60431072570m  + 420404849150m  + 1889780020755m  + 5087634488145m
+--R         + 
+--R           7041864340665m + 3478575575475
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R              11        10         9           8            7              6
+--R           11m   + 1551m   + 96745m  + 3514005m  + 82295598m  + 1298935638m
+--R         + 
+--R                       5                4                3                 2
+--R           14014513810m  + 102468500970m  + 490955350391m  + 1434440867211m
+--R         + 
+--R           2192684754645m + 1159525191825
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R            11       10        9          8           7             6
+--R           m   + 143m   + 9075m  + 336765m  + 8103018m  + 132426294m
+--R         + 
+--R                      5               4               3                2
+--R           1495875590m  + 11641582810m  + 60936676581m  + 203363952363m
+--R         + 
+--R           387182170935m + 316234143225
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R        12       11        10          9           8             7
+--R       m   + 144m   + 9218m   + 345840m  + 8439783m  + 140529312m
+--R     + 
+--R                  6               5               4                3
+--R       1628301884m  + 13137458400m  + 72578259391m  + 264300628944m
+--R     + 
+--R                    2
+--R       590546123298m  + 703416314160m + 316234143225
+--R                                                    Type: Expression(Integer)
+--E 1836
+
+--S 1837 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              11       10        9          8           7            6
+--R             m   + 121m   + 6435m  + 197835m  + 3889578m  + 51069018m
+--R           + 
+--R                       5              4               3               2
+--R             453714470m  + 2702025590m  + 10431670821m  + 24372200061m
+--R           + 
+--R             29985521895m + 13749310575
+--R        *
+--R            23
+--R           x
+--R       + 
+--R                11        10         9           8            7             6
+--R             11m   + 1353m   + 72985m  + 2271555m  + 45134958m  + 597988314m
+--R           + 
+--R                        5               4                3                2
+--R             5353566130m  + 32087153670m  + 124530626231m  + 292163767533m
+--R           + 
+--R             360568238085m + 165646455975
+--R        *
+--R            21
+--R           x
+--R       + 
+--R                11        10          9            8             7
+--R             55m   + 6875m   + 376365m  + 11870265m  + 238653030m
+--R           + 
+--R                        6               5                4                3
+--R             3194704590m  + 28857216410m  + 174273100210m  + 680615362515m
+--R           + 
+--R                           2
+--R             1604842704135m  + 1988025402825m + 915414625125
+--R        *
+--R            19
+--R           x
+--R       + 
+--R                 11         10           9            8             7
+--R             165m   + 20955m   + 1164735m  + 37263105m  + 759091410m
+--R           + 
+--R                         6               5                4                 3
+--R             10282782510m  + 93862508190m  + 572017996770m  + 2251106854425m
+--R           + 
+--R                           2
+--R             5340787250535m  + 6646727085075m + 3069331390125
+--R        *
+--R            17
+--R           x
+--R       + 
+--R                 11         10           9            8              7
+--R             330m   + 42570m   + 2403390m  + 78076350m  + 1613983140m
+--R           + 
+--R                         6                5                 4                 3
+--R             22164925860m  + 204865733820m  + 1262375264700m  + 5015196628530m
+--R           + 
+--R                            2
+--R             11991258123570m  + 15011348834790m + 6957151150950
+--R        *
+--R            15
+--R           x
+--R       + 
+--R                 11         10           9             8              7
+--R             462m   + 60522m   + 3471930m  + 114642990m  + 2408820876m
+--R           + 
+--R                         6                5                 4                 3
+--R             33609870756m  + 315347150580m  + 1969992823260m  + 7921249136262m
+--R           + 
+--R                            2
+--R             19130651800722m  + 24133835554290m + 11238474936150
+--R        *
+--R            13
+--R           x
+--R       + 
+--R                 11         10           9             8              7
+--R             462m   + 61446m   + 3582810m  + 120367170m  + 2575140876m
+--R           + 
+--R                         6                5                 4                 3
+--R             36597992508m  + 349697552820m  + 2222832699780m  + 9079996141062m
+--R           + 
+--R                            2
+--R             22226933020446m  + 28336045738770m + 13281834015450
+--R        *
+--R            11
+--R           x
+--R       + 
+--R                 11         10           9            8              7
+--R             330m   + 44550m   + 2640990m  + 90358290m  + 1971903780m
+--R           + 
+--R                         6                5                 4                 3
+--R             28627538940m  + 279691771260m  + 1818135330660m  + 7587607623090m
+--R           + 
+--R                            2
+--R             18930738943710m  + 24503570194950m + 11595251918250
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                 11         10           9            8              7
+--R             165m   + 22605m   + 1362735m  + 47524455m  + 1059893010m
+--R           + 
+--R                         6                5                 4                 3
+--R             15768085410m  + 158293212990m  + 1059628145070m  + 4558015784025m
+--R           + 
+--R                            2
+--R             11703493287585m  + 15515657331075m + 7454090518875
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                11        10          9            8             7
+--R             55m   + 7645m   + 468765m  + 16677375m  + 380801190m
+--R           + 
+--R                        6               5                4                 3
+--R             5825106210m  + 60431072570m  + 420404849150m  + 1889780020755m
+--R           + 
+--R                           2
+--R             5087634488145m  + 7041864340665m + 3478575575475
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                11        10         9           8            7              6
+--R             11m   + 1551m   + 96745m  + 3514005m  + 82295598m  + 1298935638m
+--R           + 
+--R                         5                4                3                 2
+--R             14014513810m  + 102468500970m  + 490955350391m  + 1434440867211m
+--R           + 
+--R             2192684754645m + 1159525191825
+--R        *
+--R            3
+--R           x
+--R       + 
+--R              11       10        9          8           7             6
+--R             m   + 143m   + 9075m  + 336765m  + 8103018m  + 132426294m
+--R           + 
+--R                        5               4               3                2
+--R             1495875590m  + 11641582810m  + 60936676581m  + 203363952363m
+--R           + 
+--R             387182170935m + 316234143225
+--R        *
+--R           x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R        12       11        10          9           8             7
+--R       m   + 144m   + 9218m   + 345840m  + 8439783m  + 140529312m
+--R     + 
+--R                  6               5               4                3
+--R       1628301884m  + 13137458400m  + 72578259391m  + 264300628944m
+--R     + 
+--R                    2
+--R       590546123298m  + 703416314160m + 316234143225
+--R                                         Type: Union(Expression(Integer),...)
+--E 1837
+
+--S 1838 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                11       10        9          8           7            6
+--R               m   + 121m   + 6435m  + 197835m  + 3889578m  + 51069018m
+--R             + 
+--R                         5              4               3               2
+--R               453714470m  + 2702025590m  + 10431670821m  + 24372200061m
+--R             + 
+--R               29985521895m + 13749310575
+--R          *
+--R              23
+--R             x
+--R         + 
+--R                  11        10         9           8            7             6
+--R               11m   + 1353m   + 72985m  + 2271555m  + 45134958m  + 597988314m
+--R             + 
+--R                          5               4                3                2
+--R               5353566130m  + 32087153670m  + 124530626231m  + 292163767533m
+--R             + 
+--R               360568238085m + 165646455975
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                  11        10          9            8             7
+--R               55m   + 6875m   + 376365m  + 11870265m  + 238653030m
+--R             + 
+--R                          6               5                4                3
+--R               3194704590m  + 28857216410m  + 174273100210m  + 680615362515m
+--R             + 
+--R                             2
+--R               1604842704135m  + 1988025402825m + 915414625125
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                   11         10           9            8             7
+--R               165m   + 20955m   + 1164735m  + 37263105m  + 759091410m
+--R             + 
+--R                           6               5                4                 3
+--R               10282782510m  + 93862508190m  + 572017996770m  + 2251106854425m
+--R             + 
+--R                             2
+--R               5340787250535m  + 6646727085075m + 3069331390125
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                   11         10           9            8              7
+--R               330m   + 42570m   + 2403390m  + 78076350m  + 1613983140m
+--R             + 
+--R                           6                5                 4
+--R               22164925860m  + 204865733820m  + 1262375264700m
+--R             + 
+--R                             3                  2
+--R               5015196628530m  + 11991258123570m  + 15011348834790m
+--R             + 
+--R               6957151150950
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                   11         10           9             8              7
+--R               462m   + 60522m   + 3471930m  + 114642990m  + 2408820876m
+--R             + 
+--R                           6                5                 4
+--R               33609870756m  + 315347150580m  + 1969992823260m
+--R             + 
+--R                             3                  2
+--R               7921249136262m  + 19130651800722m  + 24133835554290m
+--R             + 
+--R               11238474936150
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                   11         10           9             8              7
+--R               462m   + 61446m   + 3582810m  + 120367170m  + 2575140876m
+--R             + 
+--R                           6                5                 4
+--R               36597992508m  + 349697552820m  + 2222832699780m
+--R             + 
+--R                             3                  2
+--R               9079996141062m  + 22226933020446m  + 28336045738770m
+--R             + 
+--R               13281834015450
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                   11         10           9            8              7
+--R               330m   + 44550m   + 2640990m  + 90358290m  + 1971903780m
+--R             + 
+--R                           6                5                 4
+--R               28627538940m  + 279691771260m  + 1818135330660m
+--R             + 
+--R                             3                  2
+--R               7587607623090m  + 18930738943710m  + 24503570194950m
+--R             + 
+--R               11595251918250
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                   11         10           9            8              7
+--R               165m   + 22605m   + 1362735m  + 47524455m  + 1059893010m
+--R             + 
+--R                           6                5                 4
+--R               15768085410m  + 158293212990m  + 1059628145070m
+--R             + 
+--R                             3                  2
+--R               4558015784025m  + 11703493287585m  + 15515657331075m
+--R             + 
+--R               7454090518875
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                  11        10          9            8             7
+--R               55m   + 7645m   + 468765m  + 16677375m  + 380801190m
+--R             + 
+--R                          6               5                4                 3
+--R               5825106210m  + 60431072570m  + 420404849150m  + 1889780020755m
+--R             + 
+--R                             2
+--R               5087634488145m  + 7041864340665m + 3478575575475
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                  11        10         9           8            7              6
+--R               11m   + 1551m   + 96745m  + 3514005m  + 82295598m  + 1298935638m
+--R             + 
+--R                           5                4                3                 2
+--R               14014513810m  + 102468500970m  + 490955350391m  + 1434440867211m
+--R             + 
+--R               2192684754645m + 1159525191825
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                11       10        9          8           7             6
+--R               m   + 143m   + 9075m  + 336765m  + 8103018m  + 132426294m
+--R             + 
+--R                          5               4               3                2
+--R               1495875590m  + 11641582810m  + 60936676581m  + 203363952363m
+--R             + 
+--R               387182170935m + 316234143225
+--R          *
+--R             x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R              11       10        9          8           7            6
+--R           - m   - 121m   - 6435m  - 197835m  - 3889578m  - 51069018m
+--R         + 
+--R                       5              4               3               2
+--R           - 453714470m  - 2702025590m  - 10431670821m  - 24372200061m
+--R         + 
+--R           - 29985521895m - 13749310575
+--R      *
+--R          m + 23
+--R         x
+--R     + 
+--R                11        10         9           8            7             6
+--R           - 11m   - 1353m   - 72985m  - 2271555m  - 45134958m  - 597988314m
+--R         + 
+--R                        5               4                3                2
+--R           - 5353566130m  - 32087153670m  - 124530626231m  - 292163767533m
+--R         + 
+--R           - 360568238085m - 165646455975
+--R      *
+--R          m + 21
+--R         x
+--R     + 
+--R                11        10          9            8             7
+--R           - 55m   - 6875m   - 376365m  - 11870265m  - 238653030m
+--R         + 
+--R                        6               5                4                3
+--R           - 3194704590m  - 28857216410m  - 174273100210m  - 680615362515m
+--R         + 
+--R                           2
+--R           - 1604842704135m  - 1988025402825m - 915414625125
+--R      *
+--R          m + 19
+--R         x
+--R     + 
+--R                 11         10           9            8             7
+--R           - 165m   - 20955m   - 1164735m  - 37263105m  - 759091410m
+--R         + 
+--R                         6               5                4                 3
+--R           - 10282782510m  - 93862508190m  - 572017996770m  - 2251106854425m
+--R         + 
+--R                           2
+--R           - 5340787250535m  - 6646727085075m - 3069331390125
+--R      *
+--R          m + 17
+--R         x
+--R     + 
+--R                 11         10           9            8              7
+--R           - 330m   - 42570m   - 2403390m  - 78076350m  - 1613983140m
+--R         + 
+--R                         6                5                 4                 3
+--R           - 22164925860m  - 204865733820m  - 1262375264700m  - 5015196628530m
+--R         + 
+--R                            2
+--R           - 11991258123570m  - 15011348834790m - 6957151150950
+--R      *
+--R          m + 15
+--R         x
+--R     + 
+--R                 11         10           9             8              7
+--R           - 462m   - 60522m   - 3471930m  - 114642990m  - 2408820876m
+--R         + 
+--R                         6                5                 4                 3
+--R           - 33609870756m  - 315347150580m  - 1969992823260m  - 7921249136262m
+--R         + 
+--R                            2
+--R           - 19130651800722m  - 24133835554290m - 11238474936150
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                 11         10           9             8              7
+--R           - 462m   - 61446m   - 3582810m  - 120367170m  - 2575140876m
+--R         + 
+--R                         6                5                 4                 3
+--R           - 36597992508m  - 349697552820m  - 2222832699780m  - 9079996141062m
+--R         + 
+--R                            2
+--R           - 22226933020446m  - 28336045738770m - 13281834015450
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                 11         10           9            8              7
+--R           - 330m   - 44550m   - 2640990m  - 90358290m  - 1971903780m
+--R         + 
+--R                         6                5                 4                 3
+--R           - 28627538940m  - 279691771260m  - 1818135330660m  - 7587607623090m
+--R         + 
+--R                            2
+--R           - 18930738943710m  - 24503570194950m - 11595251918250
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                 11         10           9            8              7
+--R           - 165m   - 22605m   - 1362735m  - 47524455m  - 1059893010m
+--R         + 
+--R                         6                5                 4                 3
+--R           - 15768085410m  - 158293212990m  - 1059628145070m  - 4558015784025m
+--R         + 
+--R                            2
+--R           - 11703493287585m  - 15515657331075m - 7454090518875
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R                11        10          9            8             7
+--R           - 55m   - 7645m   - 468765m  - 16677375m  - 380801190m
+--R         + 
+--R                        6               5                4                 3
+--R           - 5825106210m  - 60431072570m  - 420404849150m  - 1889780020755m
+--R         + 
+--R                           2
+--R           - 5087634488145m  - 7041864340665m - 3478575575475
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R                11        10         9           8            7              6
+--R           - 11m   - 1551m   - 96745m  - 3514005m  - 82295598m  - 1298935638m
+--R         + 
+--R                         5                4                3                 2
+--R           - 14014513810m  - 102468500970m  - 490955350391m  - 1434440867211m
+--R         + 
+--R           - 2192684754645m - 1159525191825
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R              11       10        9          8           7             6
+--R           - m   - 143m   - 9075m  - 336765m  - 8103018m  - 132426294m
+--R         + 
+--R                        5               4               3                2
+--R           - 1495875590m  - 11641582810m  - 60936676581m  - 203363952363m
+--R         + 
+--R           - 387182170935m - 316234143225
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R        12       11        10          9           8             7
+--R       m   + 144m   + 9218m   + 345840m  + 8439783m  + 140529312m
+--R     + 
+--R                  6               5               4                3
+--R       1628301884m  + 13137458400m  + 72578259391m  + 264300628944m
+--R     + 
+--R                    2
+--R       590546123298m  + 703416314160m + 316234143225
+--R                                                    Type: Expression(Integer)
+--E 1838
+
+--S 1839 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R          22      20      18       16       14       12       10       8       6
+--R         x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R       + 
+--R            4      2
+--R         55x  + 11x  + 1
+--R    *
+--R         m log(x)
+--R       %e
+--R   + 
+--R        m + 22      m + 20      m + 18       m + 16       m + 14       m + 12
+--R     - x       - 11x       - 55x       - 165x       - 330x       - 462x
+--R   + 
+--R           m + 10       m + 8       m + 6      m + 4      m + 2    m
+--R     - 462x       - 330x      - 165x      - 55x      - 11x      - x
+--R                                                    Type: Expression(Integer)
+--E 1839
+
+)clear all
+
+--S 1840 of 3139
+t0:=x^5*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      27      25      23       21       19       17       15       13       11
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x   + 165x
+--R   + 
+--R        9      7    5
+--R     55x  + 11x  + x
+--R                                                    Type: Polynomial(Integer)
+--E 1840
+
+--S 1841 of 3139
+r0:=1/24*(1+x^2)^12-1/13*(1+x^2)^13+1/28*(1+x^2)^14
+--R 
+--R
+--R   (2)
+--R      1  28   11  26   55  24   15  22   33  20   77  18   231  16   165  14
+--R     -- x   + -- x   + -- x   + -- x   + -- x   + -- x   + --- x   + --- x
+--R     28       26       24        2        2        3        8         7
+--R   + 
+--R     55  12   11  10   11  8   1  6     1
+--R     -- x   + -- x   + -- x  + - x  + ----
+--R      4        2        8      6      2184
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1841
+
+--S 1842 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  28   11  26   55  24   15  22   33  20   77  18   231  16   165  14
+--R     -- x   + -- x   + -- x   + -- x   + -- x   + -- x   + --- x   + --- x
+--R     28       26       24        2        2        3        8         7
+--R   + 
+--R     55  12   11  10   11  8   1  6
+--R     -- x   + -- x   + -- x  + - x
+--R      4        2        8      6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1842
+
+--S 1843 of 3139
+m0:=a0-r0
+--R 
+--R
+--R            1
+--R   (4)  - ----
+--R          2184
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1843
+
+--S 1844 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1844
+
+)clear all
+
+--S 1845 of 3139
+t0:=x^4*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      26      24      22       20       18       16       14       12       10
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x   + 165x
+--R   + 
+--R        8      6    4
+--R     55x  + 11x  + x
+--R                                                    Type: Polynomial(Integer)
+--E 1845
+
+--S 1846 of 3139
+r0:=1/5*x^5+11/7*x^7+55/9*x^9+15*x^11+330/13*x^13+154/5*x^15+462/17*x^17+_
+   330/19*x^19+55/7*x^21+55/23*x^23+11/25*x^25+1/27*x^27
+--R 
+--R
+--R   (2)
+--R      1  27   11  25   55  23   55  21   330  19   462  17   154  15   330  13
+--R     -- x   + -- x   + -- x   + -- x   + --- x   + --- x   + --- x   + --- x
+--R     27       25       23        7        19        17        5         13
+--R   + 
+--R        11   55  9   11  7   1  5
+--R     15x   + -- x  + -- x  + - x
+--R              9       7      5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1846
+
+--S 1847 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  27   11  25   55  23   55  21   330  19   462  17   154  15   330  13
+--R     -- x   + -- x   + -- x   + -- x   + --- x   + --- x   + --- x   + --- x
+--R     27       25       23        7        19        17        5         13
+--R   + 
+--R        11   55  9   11  7   1  5
+--R     15x   + -- x  + -- x  + - x
+--R              9       7      5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1847
+
+--S 1848 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1848
+
+--S 1849 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1849
+
+)clear all
+
+--S 1850 of 3139
+t0:=x^3*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      25      23      21       19       17       15       13       11       9
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x   + 165x
+--R   + 
+--R        7      5    3
+--R     55x  + 11x  + x
+--R                                                    Type: Polynomial(Integer)
+--E 1850
+
+--S 1851 of 3139
+r0:=-1/24*(1+x^2)^12+1/26*(1+x^2)^13
+--R 
+--R
+--R   (2)
+--R      1  26   11  24   5  22   33  20   55  18   231  16      14   55  12
+--R     -- x   + -- x   + - x   + -- x   + -- x   + --- x   + 33x   + -- x
+--R     26       24       2        4        3        8                 2
+--R   + 
+--R     33  10   55  8   11  6   1  4    1
+--R     -- x   + -- x  + -- x  + - x  - ---
+--R      2        8       6      4      312
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1851
+
+--S 1852 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  26   11  24   5  22   33  20   55  18   231  16      14   55  12
+--R     -- x   + -- x   + - x   + -- x   + -- x   + --- x   + 33x   + -- x
+--R     26       24       2        4        3        8                 2
+--R   + 
+--R     33  10   55  8   11  6   1  4
+--R     -- x   + -- x  + -- x  + - x
+--R      2        8       6      4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1852
+
+--S 1853 of 3139
+m0:=a0-r0
+--R 
+--R
+--R         1
+--R   (4)  ---
+--R        312
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1853
+
+--S 1854 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1854
+
+)clear all
+
+--S 1855 of 3139
+t0:=x^2*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      24      22      20       18       16       14       12       10       8
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x   + 165x
+--R   + 
+--R        6      4    2
+--R     55x  + 11x  + x
+--R                                                    Type: Polynomial(Integer)
+--E 1855
+
+--S 1856 of 3139
+r0:=1/3*x^3+11/5*x^5+55/7*x^7+55/3*x^9+30*x^11+462/13*x^13+154/5*x^15+_
+   330/17*x^17+165/19*x^19+55/21*x^21+11/23*x^23+1/25*x^25
+--R 
+--R
+--R   (2)
+--R      1  25   11  23   55  21   165  19   330  17   154  15   462  13      11
+--R     -- x   + -- x   + -- x   + --- x   + --- x   + --- x   + --- x   + 30x
+--R     25       23       21        19        17        5         13
+--R   + 
+--R     55  9   55  7   11  5   1  3
+--R     -- x  + -- x  + -- x  + - x
+--R      3       7       5      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1856
+
+--S 1857 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  25   11  23   55  21   165  19   330  17   154  15   462  13      11
+--R     -- x   + -- x   + -- x   + --- x   + --- x   + --- x   + --- x   + 30x
+--R     25       23       21        19        17        5         13
+--R   + 
+--R     55  9   55  7   11  5   1  3
+--R     -- x  + -- x  + -- x  + - x
+--R      3       7       5      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1857
+
+--S 1858 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1858
+
+--S 1859 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1859
+
+)clear all
+
+--S 1860 of 3139
+t0:=x*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      23      21      19       17       15       13       11       9       7
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R   + 
+--R        5      3
+--R     55x  + 11x  + x
+--R                                                    Type: Polynomial(Integer)
+--E 1860
+
+--S 1861 of 3139
+r0:=1/24*(1+x^2)^12
+--R 
+--R
+--R   (2)
+--R      1  24   1  22   11  20   55  18   165  16      14   77  12      10
+--R     -- x   + - x   + -- x   + -- x   + --- x   + 33x   + -- x   + 33x
+--R     24       2        4        6        8                 2
+--R   + 
+--R     165  8   55  6   11  4   1  2    1
+--R     --- x  + -- x  + -- x  + - x  + --
+--R      8        6       4      2      24
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1861
+
+--S 1862 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  24   1  22   11  20   55  18   165  16      14   77  12      10
+--R     -- x   + - x   + -- x   + -- x   + --- x   + 33x   + -- x   + 33x
+--R     24       2        4        6        8                 2
+--R   + 
+--R     165  8   55  6   11  4   1  2
+--R     --- x  + -- x  + -- x  + - x
+--R      8        6       4      2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1862
+
+--S 1863 of 3139
+m0:=a0-r0
+--R 
+--R
+--R           1
+--R   (4)  - --
+--R          24
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1863
+
+--S 1864 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1864
+
+)clear all
+
+--S 1865 of 3139
+t0:=(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      22      20      18       16       14       12       10       8       6
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R   + 
+--R        4      2
+--R     55x  + 11x  + 1
+--R                                                    Type: Polynomial(Integer)
+--E 1865
+
+--S 1866 of 3139
+r0:=x+11/3*x^3+11*x^5+165/7*x^7+110/3*x^9+42*x^11+462/13*x^13+22*x^15+_
+   165/17*x^17+55/19*x^19+11/21*x^21+1/23*x^23
+--R 
+--R
+--R   (2)
+--R      1  23   11  21   55  19   165  17      15   462  13      11   110  9
+--R     -- x   + -- x   + -- x   + --- x   + 22x   + --- x   + 42x   + --- x
+--R     23       21       19        17                13                3
+--R   + 
+--R     165  7      5   11  3
+--R     --- x  + 11x  + -- x  + x
+--R      7               3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1866
+
+--S 1867 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  23   11  21   55  19   165  17      15   462  13      11   110  9
+--R     -- x   + -- x   + -- x   + --- x   + 22x   + --- x   + 42x   + --- x
+--R     23       21       19        17                13                3
+--R   + 
+--R     165  7      5   11  3
+--R     --- x  + 11x  + -- x  + x
+--R      7               3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1867
+
+--S 1868 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1868
+
+--S 1869 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1869
+
+)clear all
+
+--S 1870 of 3139
+t0:=(1+x^2)*(1+2*x^2+x^4)^5/x
+--R 
+--R
+--R   (1)
+--R        22      20      18       16       14       12       10       8       6
+--R       x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R     + 
+--R          4      2
+--R       55x  + 11x  + 1
+--R  /
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1870
+
+--S 1871 of 3139
+r0:=11/2*x^2+55/4*x^4+55/2*x^6+165/4*x^8+231/5*x^10+77/2*x^12+165/7*x^14+_
+   165/16*x^16+55/18*x^18+11/20*x^20+1/22*x^22+log(x)
+--R 
+--R
+--R   (2)
+--R                          22         20          18          16           14
+--R       55440log(x) + 2520x   + 30492x   + 169400x   + 571725x   + 1306800x
+--R     + 
+--R               12           10           8           6          4          2
+--R       2134440x   + 2561328x   + 2286900x  + 1524600x  + 762300x  + 304920x
+--R  /
+--R     55440
+--R                                                    Type: Expression(Integer)
+--E 1871
+
+--S 1872 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          22         20          18          16           14
+--R       55440log(x) + 2520x   + 30492x   + 169400x   + 571725x   + 1306800x
+--R     + 
+--R               12           10           8           6          4          2
+--R       2134440x   + 2561328x   + 2286900x  + 1524600x  + 762300x  + 304920x
+--R  /
+--R     55440
+--R                                         Type: Union(Expression(Integer),...)
+--E 1872
+
+--S 1873 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1873
+
+--S 1874 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1874
+
+)clear all
+
+--S 1875 of 3139
+t0:=(1+x^2)*(1+2*x^2+x^4)^5/x^2
+--R 
+--R
+--R   (1)
+--R        22      20      18       16       14       12       10       8       6
+--R       x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R     + 
+--R          4      2
+--R       55x  + 11x  + 1
+--R  /
+--R      2
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1875
+
+--S 1876 of 3139
+r0:=(-1)/x+11*x+55/3*x^3+33*x^5+330/7*x^7+154/3*x^9+42*x^11+330/13*x^13+_
+   11*x^15+55/17*x^17+11/19*x^19+1/21*x^21
+--R 
+--R
+--R   (2)
+--R            22         20          18          16           14           12
+--R       4199x   + 51051x   + 285285x   + 969969x   + 2238390x   + 3703518x
+--R     + 
+--R               10           8           6           4          2
+--R       4526522x   + 4157010x  + 2909907x  + 1616615x  + 969969x  - 88179
+--R  /
+--R     88179x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1876
+
+--S 1877 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            22         20          18          16           14           12
+--R       4199x   + 51051x   + 285285x   + 969969x   + 2238390x   + 3703518x
+--R     + 
+--R               10           8           6           4          2
+--R       4526522x   + 4157010x  + 2909907x  + 1616615x  + 969969x  - 88179
+--R  /
+--R     88179x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1877
+
+--S 1878 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1878
+
+--S 1879 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1879
+
+)clear all
+
+--S 1880 of 3139
+t0:=(1+x^2)*(1+2*x^2+x^4)^5/x^3
+--R 
+--R
+--R   (1)
+--R        22      20      18       16       14       12       10       8       6
+--R       x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R     + 
+--R          4      2
+--R       55x  + 11x  + 1
+--R  /
+--R      3
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1880
+
+--S 1881 of 3139
+r0:=(-1/2)/x^2+55/2*x^2+165/4*x^4+55*x^6+231/4*x^8+231/5*x^10+55/2*x^12+_
+   165/14*x^14+55/16*x^16+11/18*x^18+1/20*x^20+11*log(x)
+--R 
+--R
+--R   (2)
+--R             2             22        20         18         16          14
+--R       55440x log(x) + 252x   + 3080x   + 17325x   + 59400x   + 138600x
+--R     + 
+--R              12          10          8          6          4
+--R       232848x   + 291060x   + 277200x  + 207900x  + 138600x  - 2520
+--R  /
+--R          2
+--R     5040x
+--R                                                    Type: Expression(Integer)
+--E 1881
+
+--S 1882 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2             22        20         18         16          14
+--R       55440x log(x) + 252x   + 3080x   + 17325x   + 59400x   + 138600x
+--R     + 
+--R              12          10          8          6          4
+--R       232848x   + 291060x   + 277200x  + 207900x  + 138600x  - 2520
+--R  /
+--R          2
+--R     5040x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1882
+
+--S 1883 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1883
+
+--S 1884 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1884
+
+)clear all
+
+--S 1885 of 3139
+t0:=(3+2*x^2)/(1-2*x^2+x^4)
+--R 
+--R
+--R             2
+--R           2x  + 3
+--R   (1)  ------------
+--R         4     2
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1885
+
+--S 1886 of 3139
+r0:=5/2*x/(1-x^2)+1/2*atanh(x)
+--R 
+--R
+--R          2
+--R        (x  - 1)atanh(x) - 5x
+--R   (2)  ---------------------
+--R                 2
+--R               2x  - 2
+--R                                                    Type: Expression(Integer)
+--E 1886
+
+--S 1887 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2                      2
+--R        (x  - 1)log(x + 1) + (- x  + 1)log(x - 1) - 10x
+--R   (3)  -----------------------------------------------
+--R                              2
+--R                            4x  - 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1887
+
+--S 1888 of 3139
+m0:=a0-r0
+--R 
+--R
+--R        log(x + 1) - log(x - 1) - 2atanh(x)
+--R   (4)  -----------------------------------
+--R                         4
+--R                                                    Type: Expression(Integer)
+--E 1888
+
+--S 1889 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1889
+
+)clear all
+
+--S 1890 of 3139
+t0:=x*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R            3         2 4         2    2 p
+--R   (1)  (b x  + a x)(b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1890
+
+--S 1891 of 3139
+r0:=1/4*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b*(1+p))
+--R 
+--R
+--R          2 4         2    2 p + 1
+--R        (b x  + 2a b x  + a )
+--R   (2)  --------------------------
+--R                 4b p + 4b
+--R                                                    Type: Expression(Integer)
+--E 1891
+
+--S 1892 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                      2 4         2    2
+--R          2 4         2    2   p log(b x  + 2a b x  + a )
+--R        (b x  + 2a b x  + a )%e
+--R   (3)  -------------------------------------------------
+--R                            4b p + 4b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1892
+
+--S 1893 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     2 4         2    2
+--R         2 4         2    2   p log(b x  + 2a b x  + a )
+--R       (b x  + 2a b x  + a )%e
+--R     + 
+--R           2 4         2    2 p + 1
+--R       - (b x  + 2a b x  + a )
+--R  /
+--R     4b p + 4b
+--R                                                    Type: Expression(Integer)
+--E 1893
+
+--S 1894 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                          2 4         2    2
+--R         3         p log(b x  + 2a b x  + a )
+--R     (b x  + a x)%e
+--R   + 
+--R           3         2 4         2    2 p
+--R     (- b x  - a x)(b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1894
+
+)clear all
+
+--S 1895 of 3139
+t0:=x^3*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R            5      3   2 4         2    2 p
+--R   (1)  (b x  + a x )(b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1895
+
+--S 1896 of 3139
+r0:=-1/4*a*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^2*(1+p)*(3+2*p))+_
+   1/2*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b*(3+2*p))
+--R 
+--R
+--R                     2       2 4         2    2 p + 1
+--R        ((2b p + 2b)x  - a)(b x  + 2a b x  + a )
+--R   (2)  ---------------------------------------------
+--R                       2 2      2       2
+--R                     8b p  + 20b p + 12b
+--R                                                    Type: Expression(Integer)
+--E 1896
+
+--S 1897 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3      3  6        2        2  4     2     2    3
+--R       ((2b p + 2b )x  + (4a b p + 3a b )x  + 2a b p x  - a )
+--R    *
+--R                2 4         2    2
+--R         p log(b x  + 2a b x  + a )
+--R       %e
+--R  /
+--R       2 2      2       2
+--R     8b p  + 20b p + 12b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1897
+
+--S 1898 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3      3  6        2        2  4     2     2    3
+--R         ((2b p + 2b )x  + (4a b p + 3a b )x  + 2a b p x  - a )
+--R      *
+--R                  2 4         2    2
+--R           p log(b x  + 2a b x  + a )
+--R         %e
+--R     + 
+--R                      2       2 4         2    2 p + 1
+--R       ((- 2b p - 2b)x  + a)(b x  + 2a b x  + a )
+--R  /
+--R       2 2      2       2
+--R     8b p  + 20b p + 12b
+--R                                                    Type: Expression(Integer)
+--E 1898
+
+--S 1899 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                    2 4         2    2
+--R           2      2  5                   3   p log(b x  + 2a b x  + a )
+--R       ((2b p + 3b )x  + (2a b p + 3a b)x )%e
+--R     + 
+--R             2 4         2    2 p + 1
+--R       - x (b x  + 2a b x  + a )
+--R     + 
+--R             2      2  5                    3    2    2 4         2    2 p
+--R       ((- 2b p - 2b )x  + (- 2a b p - a b)x  + a x)(b x  + 2a b x  + a )
+--R  /
+--R     2b p + 3b
+--R                                                    Type: Expression(Integer)
+--E 1899
+
+)clear all
+
+--S 1900 of 3139
+t0:=x^5*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R            7      5   2 4         2    2 p
+--R   (1)  (b x  + a x )(b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1900
+
+--S 1901 of 3139
+r0:=1/4*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^3*(1+p)*(2+p)*(3+2*p))-_
+   1/2*a*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^2*(2+p)*(3+2*p))+_
+   1/4*x^4*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b*(2+p))
+--R 
+--R
+--R   (2)
+--R       2 2     2      2  4                     2    2   2 4         2    2 p + 1
+--R   ((2b p  + 5b p + 3b )x  + (- 2a b p - 2a b)x  + a )(b x  + 2a b x  + a )
+--R   -----------------------------------------------------------------------------
+--R                             3 3      3 2      3       3
+--R                           8b p  + 36b p  + 52b p + 24b
+--R                                                    Type: Expression(Integer)
+--E 1901
+
+--S 1902 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4 2     4      4  8        3 2       3        3  6
+--R         (2b p  + 5b p + 3b )x  + (4a b p  + 8a b p + 4a b )x
+--R       + 
+--R            2 2 2    2 2   4     3     2    4
+--R         (2a b p  + a b p)x  - 2a b p x  + a
+--R    *
+--R                2 4         2    2
+--R         p log(b x  + 2a b x  + a )
+--R       %e
+--R  /
+--R       3 3      3 2      3       3
+--R     8b p  + 36b p  + 52b p + 24b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1902
+
+--S 1903 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              4 2     4      4  8        3 2       3        3  6
+--R           (2b p  + 5b p + 3b )x  + (4a b p  + 8a b p + 4a b )x
+--R         + 
+--R              2 2 2    2 2   4     3     2    4
+--R           (2a b p  + a b p)x  - 2a b p x  + a
+--R      *
+--R                  2 4         2    2
+--R           p log(b x  + 2a b x  + a )
+--R         %e
+--R     + 
+--R               2 2     2      2  4                   2    2
+--R         ((- 2b p  - 5b p - 3b )x  + (2a b p + 2a b)x  - a )
+--R      *
+--R           2 4         2    2 p + 1
+--R         (b x  + 2a b x  + a )
+--R  /
+--R       3 3      3 2      3       3
+--R     8b p  + 36b p  + 52b p + 24b
+--R                                                    Type: Expression(Integer)
+--E 1903
+
+--S 1904 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R             3 2     3      3  7        2 2       2        2  5
+--R         ((2b p  + 7b p + 6b )x  + (2a b p  + 7a b p + 6a b )x )
+--R      *
+--R                  2 4         2    2
+--R           p log(b x  + 2a b x  + a )
+--R         %e
+--R     + 
+--R                      3         2 4         2    2 p + 1
+--R       ((- 2b p - 3b)x  + a x)(b x  + 2a b x  + a )
+--R     + 
+--R                3 2     3      3  7          2 2       2       2  5
+--R           (- 2b p  - 5b p - 3b )x  + (- 2a b p  - 3a b p - a b )x
+--R         + 
+--R              2       2   3    3
+--R           (2a b p + a b)x  - a x
+--R      *
+--R           2 4         2    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R       2 2     2      2
+--R     2b p  + 7b p + 6b
+--R                                                    Type: Expression(Integer)
+--E 1904
+
+)clear all
+
+--S 1905 of 3139
+t0:=(d-e*x^2)/(c*d^2/e^2+b*x^2+c*x^4)
+--R 
+--R
+--R                3 2      2
+--R             - e x  + d e
+--R   (1)  ----------------------
+--R           2 4      2 2      2
+--R        c e x  + b e x  + c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1905
+
+--S 1906 of 3139
+r0:=-1/2*e^(3/2)*log(d+e*x^2-x*sqrt(e)*sqrt(2*c*d-b*e)/sqrt(c))/(sqrt(c)*_
+   sqrt(2*c*d-b*e))+1/2*e^(3/2)*log(d+e*x^2+x*sqrt(e)*sqrt(2*c*d-b*e)/_
+   sqrt(c))/(sqrt(c)*sqrt(2*c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                  +------------+ +-+       2      +-+
+--R         +-+    x\|- b e + 2c d \|e  + (e x  + d)\|c
+--R       e\|e log(-------------------------------------)
+--R                                  +-+
+--R                                 \|c
+--R     + 
+--R                      +------------+ +-+       2      +-+
+--R           +-+    - x\|- b e + 2c d \|e  + (e x  + d)\|c
+--R       - e\|e log(---------------------------------------)
+--R                                     +-+
+--R                                    \|c
+--R  /
+--R       +------------+ +-+
+--R     2\|- b e + 2c d \|c
+--R                                                    Type: Expression(Integer)
+--E 1906
+
+--S 1907 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           +--------------+
+--R           |        e
+--R         e |- ------------
+--R           |            2
+--R          \|  b c e - 2c d
+--R      *
+--R         log
+--R                            2     2     3                   2 2
+--R                  ((- 2b c e  + 4c d e)x  + (- 2b c d e + 4c d )x)
+--R               *
+--R                   +--------------+
+--R                   |        e
+--R                   |- ------------
+--R                   |            2
+--R                  \|  b c e - 2c d
+--R              + 
+--R                   2 4         2           2      2
+--R                c e x  + (- b e  + 4c d e)x  + c d
+--R           /
+--R                 2 4      2 2      2
+--R              c e x  + b e x  + c d
+--R    /
+--R       2
+--R     ,
+--R                                       +------------+
+--R                                       |      e
+--R                         (b e - 2c d)x |------------
+--R      +------------+                   |          2
+--R      |      e                        \|b c e - 2c d
+--R    e |------------ atan(----------------------------)]
+--R      |          2                    2
+--R     \|b c e - 2c d                e x  + d
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1907
+
+--S 1908 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    +------------+ +-+       2      +-+
+--R           +-+    x\|- b e + 2c d \|e  + (e x  + d)\|c
+--R       - e\|e log(-------------------------------------)
+--R                                    +-+
+--R                                   \|c
+--R     + 
+--R                          +--------------+
+--R           +------------+ |        e       +-+
+--R         e\|- b e + 2c d  |- ------------ \|c
+--R                          |            2
+--R                         \|  b c e - 2c d
+--R      *
+--R         log
+--R                            2     2     3                   2 2
+--R                  ((- 2b c e  + 4c d e)x  + (- 2b c d e + 4c d )x)
+--R               *
+--R                   +--------------+
+--R                   |        e
+--R                   |- ------------
+--R                   |            2
+--R                  \|  b c e - 2c d
+--R              + 
+--R                   2 4         2           2      2
+--R                c e x  + (- b e  + 4c d e)x  + c d
+--R           /
+--R                 2 4      2 2      2
+--R              c e x  + b e x  + c d
+--R     + 
+--R                    +------------+ +-+       2      +-+
+--R         +-+    - x\|- b e + 2c d \|e  + (e x  + d)\|c
+--R       e\|e log(---------------------------------------)
+--R                                   +-+
+--R                                  \|c
+--R  /
+--R       +------------+ +-+
+--R     2\|- b e + 2c d \|c
+--R                                                    Type: Expression(Integer)
+--E 1908
+
+--S 1909 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1909
+
+--S 1910 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    +------------+ +-+       2      +-+
+--R           +-+    x\|- b e + 2c d \|e  + (e x  + d)\|c
+--R       - e\|e log(-------------------------------------)
+--R                                    +-+
+--R                                   \|c
+--R     + 
+--R                    +------------+ +-+       2      +-+
+--R         +-+    - x\|- b e + 2c d \|e  + (e x  + d)\|c
+--R       e\|e log(---------------------------------------)
+--R                                   +-+
+--R                                  \|c
+--R     + 
+--R                                                              +------------+
+--R                                                              |      e
+--R                                                (b e - 2c d)x |------------
+--R                         +------------+                       |          2
+--R          +------------+ |      e       +-+                  \|b c e - 2c d
+--R       2e\|- b e + 2c d  |------------ \|c atan(----------------------------)
+--R                         |          2                        2
+--R                        \|b c e - 2c d                    e x  + d
+--R  /
+--R       +------------+ +-+
+--R     2\|- b e + 2c d \|c
+--R                                                    Type: Expression(Integer)
+--E 1910
+
+--S 1911 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1911
+
+)clear all
+
+--S 1912 of 3139
+t0:=(d+e*x^2)/(c*d^2/e^2+b*x^2+c*x^4)
+--R 
+--R
+--R               3 2      2
+--R              e x  + d e
+--R   (1)  ----------------------
+--R           2 4      2 2      2
+--R        c e x  + b e x  + c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1912
+
+--S 1913 of 3139
+r0:=-e^(3/2)*atan((-2*x*sqrt(c)*sqrt(e)+sqrt(2*c*d-b*e))/sqrt(2*c*d+b*e))/_
+   (sqrt(c)*sqrt(2*c*d+b*e))+e^(3/2)*atan((2*x*sqrt(c)*sqrt(e)+_
+   sqrt(2*c*d-b*e))/sqrt(2*c*d+b*e))/(sqrt(c)*sqrt(2*c*d+b*e))
+--R 
+--R
+--R   (2)
+--R                    +-+ +-+    +------------+
+--R         +-+     2x\|c \|e  + \|- b e + 2c d
+--R       e\|e atan(----------------------------)
+--R                          +----------+
+--R                         \|b e + 2c d
+--R     + 
+--R                    +-+ +-+    +------------+
+--R         +-+     2x\|c \|e  - \|- b e + 2c d
+--R       e\|e atan(----------------------------)
+--R                          +----------+
+--R                         \|b e + 2c d
+--R  /
+--R      +-+ +----------+
+--R     \|c \|b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1913
+
+--S 1914 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           +--------------+
+--R           |        e
+--R         e |- ------------
+--R           |            2
+--R          \|  b c e + 2c d
+--R      *
+--R         log
+--R                                                               +--------------+
+--R                        2     2     3                   2 2    |        e
+--R                ((2b c e  + 4c d e)x  + (- 2b c d e - 4c d )x) |- ------------
+--R                                                               |            2
+--R                                                              \|  b c e + 2c d
+--R              + 
+--R                   2 4         2           2      2
+--R                c e x  + (- b e  - 4c d e)x  + c d
+--R           /
+--R                 2 4      2 2      2
+--R              c e x  + b e x  + c d
+--R    /
+--R       2
+--R     ,
+--R                                         +------------+
+--R                                         |      e
+--R                           (b e + 2c d)x |------------
+--R        +------------+                   |          2
+--R        |      e                        \|b c e + 2c d
+--R    - e |------------ atan(----------------------------)]
+--R        |          2                    2
+--R       \|b c e + 2c d                e x  - d
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1914
+
+--S 1915 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           +--------------+
+--R           |        e       +-+ +----------+
+--R         e |- ------------ \|c \|b e + 2c d
+--R           |            2
+--R          \|  b c e + 2c d
+--R      *
+--R         log
+--R                                                               +--------------+
+--R                        2     2     3                   2 2    |        e
+--R                ((2b c e  + 4c d e)x  + (- 2b c d e - 4c d )x) |- ------------
+--R                                                               |            2
+--R                                                              \|  b c e + 2c d
+--R              + 
+--R                   2 4         2           2      2
+--R                c e x  + (- b e  - 4c d e)x  + c d
+--R           /
+--R                 2 4      2 2      2
+--R              c e x  + b e x  + c d
+--R     + 
+--R                       +-+ +-+    +------------+
+--R            +-+     2x\|c \|e  + \|- b e + 2c d
+--R       - 2e\|e atan(----------------------------)
+--R                             +----------+
+--R                            \|b e + 2c d
+--R     + 
+--R                       +-+ +-+    +------------+
+--R            +-+     2x\|c \|e  - \|- b e + 2c d
+--R       - 2e\|e atan(----------------------------)
+--R                             +----------+
+--R                            \|b e + 2c d
+--R  /
+--R       +-+ +----------+
+--R     2\|c \|b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1915
+
+--S 1916 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1916
+
+--S 1917 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                             +------------+
+--R                                                             |      e
+--R                                               (b e + 2c d)x |------------
+--R           +------------+                                    |          2
+--R           |      e       +-+ +----------+                  \|b c e + 2c d
+--R       - e |------------ \|c \|b e + 2c d atan(----------------------------)
+--R           |          2                                     2
+--R          \|b c e + 2c d                                 e x  - d
+--R     + 
+--R                      +-+ +-+    +------------+
+--R           +-+     2x\|c \|e  + \|- b e + 2c d
+--R       - e\|e atan(----------------------------)
+--R                            +----------+
+--R                           \|b e + 2c d
+--R     + 
+--R                      +-+ +-+    +------------+
+--R           +-+     2x\|c \|e  - \|- b e + 2c d
+--R       - e\|e atan(----------------------------)
+--R                            +----------+
+--R                           \|b e + 2c d
+--R  /
+--R      +-+ +----------+
+--R     \|c \|b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1917
+
+--S 1918 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1918
+
+)clear all
+
+--S 1919 of 3139
+t0:=(d+e*x^2)/(b*x^2+c*(d^2/e^2+x^4))
+--R 
+--R
+--R               3 2      2
+--R              e x  + d e
+--R   (1)  ----------------------
+--R           2 4      2 2      2
+--R        c e x  + b e x  + c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1919
+
+--S 1920 of 3139
+r0:=-e^(3/2)*atan((-2*x*sqrt(c)*sqrt(e)+sqrt(2*c*d-b*e))/sqrt(2*c*d+b*e))/_
+   (sqrt(c)*sqrt(2*c*d+b*e))+e^(3/2)*atan((2*x*sqrt(c)*sqrt(e)+_
+   sqrt(2*c*d-b*e))/sqrt(2*c*d+b*e))/(sqrt(c)*sqrt(2*c*d+b*e))
+--R 
+--R
+--R   (2)
+--R                    +-+ +-+    +------------+
+--R         +-+     2x\|c \|e  + \|- b e + 2c d
+--R       e\|e atan(----------------------------)
+--R                          +----------+
+--R                         \|b e + 2c d
+--R     + 
+--R                    +-+ +-+    +------------+
+--R         +-+     2x\|c \|e  - \|- b e + 2c d
+--R       e\|e atan(----------------------------)
+--R                          +----------+
+--R                         \|b e + 2c d
+--R  /
+--R      +-+ +----------+
+--R     \|c \|b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1920
+
+--S 1921 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           +--------------+
+--R           |        e
+--R         e |- ------------
+--R           |            2
+--R          \|  b c e + 2c d
+--R      *
+--R         log
+--R                                                               +--------------+
+--R                        2     2     3                   2 2    |        e
+--R                ((2b c e  + 4c d e)x  + (- 2b c d e - 4c d )x) |- ------------
+--R                                                               |            2
+--R                                                              \|  b c e + 2c d
+--R              + 
+--R                   2 4         2           2      2
+--R                c e x  + (- b e  - 4c d e)x  + c d
+--R           /
+--R                 2 4      2 2      2
+--R              c e x  + b e x  + c d
+--R    /
+--R       2
+--R     ,
+--R                                         +------------+
+--R                                         |      e
+--R                           (b e + 2c d)x |------------
+--R        +------------+                   |          2
+--R        |      e                        \|b c e + 2c d
+--R    - e |------------ atan(----------------------------)]
+--R        |          2                    2
+--R       \|b c e + 2c d                e x  - d
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1921
+
+--S 1922 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           +--------------+
+--R           |        e       +-+ +----------+
+--R         e |- ------------ \|c \|b e + 2c d
+--R           |            2
+--R          \|  b c e + 2c d
+--R      *
+--R         log
+--R                                                               +--------------+
+--R                        2     2     3                   2 2    |        e
+--R                ((2b c e  + 4c d e)x  + (- 2b c d e - 4c d )x) |- ------------
+--R                                                               |            2
+--R                                                              \|  b c e + 2c d
+--R              + 
+--R                   2 4         2           2      2
+--R                c e x  + (- b e  - 4c d e)x  + c d
+--R           /
+--R                 2 4      2 2      2
+--R              c e x  + b e x  + c d
+--R     + 
+--R                       +-+ +-+    +------------+
+--R            +-+     2x\|c \|e  + \|- b e + 2c d
+--R       - 2e\|e atan(----------------------------)
+--R                             +----------+
+--R                            \|b e + 2c d
+--R     + 
+--R                       +-+ +-+    +------------+
+--R            +-+     2x\|c \|e  - \|- b e + 2c d
+--R       - 2e\|e atan(----------------------------)
+--R                             +----------+
+--R                            \|b e + 2c d
+--R  /
+--R       +-+ +----------+
+--R     2\|c \|b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1922
+
+--S 1923 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1923
+
+--S 1924 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                             +------------+
+--R                                                             |      e
+--R                                               (b e + 2c d)x |------------
+--R           +------------+                                    |          2
+--R           |      e       +-+ +----------+                  \|b c e + 2c d
+--R       - e |------------ \|c \|b e + 2c d atan(----------------------------)
+--R           |          2                                     2
+--R          \|b c e + 2c d                                 e x  - d
+--R     + 
+--R                      +-+ +-+    +------------+
+--R           +-+     2x\|c \|e  + \|- b e + 2c d
+--R       - e\|e atan(----------------------------)
+--R                            +----------+
+--R                           \|b e + 2c d
+--R     + 
+--R                      +-+ +-+    +------------+
+--R           +-+     2x\|c \|e  - \|- b e + 2c d
+--R       - e\|e atan(----------------------------)
+--R                            +----------+
+--R                           \|b e + 2c d
+--R  /
+--R      +-+ +----------+
+--R     \|c \|b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1924
+
+--S 1925 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1925
+
+)clear all
+
+--S 1926 of 3139
+t0:=(a-b*x^2)/(a^2+(-1+2*a*b)*x^2+b^2*x^4)
+--R 
+--R
+--R                    2
+--R               - b x  + a
+--R   (1)  ------------------------
+--R         2 4              2    2
+--R        b x  + (2a b - 1)x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1926
+
+--S 1927 of 3139
+r0:=-atanh(-2*b*x+sqrt(1-4*a*b))+atanh(2*b*x+sqrt(1-4*a*b))
+--R 
+--R
+--R               +----------+                  +----------+
+--R   (2)  atanh(\|- 4a b + 1  + 2b x) - atanh(\|- 4a b + 1  - 2b x)
+--R                                                    Type: Expression(Integer)
+--E 1927
+
+--S 1928 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2                   2
+--R        log(b x  + x + a) - log(b x  - x + a)
+--R   (3)  -------------------------------------
+--R                          2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1928
+
+--S 1929 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 +----------+                   +----------+
+--R       - 2atanh(\|- 4a b + 1  + 2b x) + 2atanh(\|- 4a b + 1  - 2b x)
+--R     + 
+--R              2                   2
+--R       log(b x  + x + a) - log(b x  - x + a)
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 1929
+
+--S 1930 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1930
+
+)clear all
+
+--S 1931 of 3139
+t0:=(a+b*x^2)/(a^2+(-1+2*a*b)*x^2+b^2*x^4)
+--R 
+--R
+--R                   2
+--R                b x  + a
+--R   (1)  ------------------------
+--R         2 4              2    2
+--R        b x  + (2a b - 1)x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1931
+
+--S 1932 of 3139
+r0:=atanh((1-2*b*x)/sqrt(1-4*a*b))/sqrt(1-4*a*b)-atanh((1+2*b*x)/_
+   sqrt(1-4*a*b))/sqrt(1-4*a*b)
+--R 
+--R
+--R                   2b x + 1               2b x - 1
+--R        - atanh(-------------) - atanh(-------------)
+--R                 +----------+           +----------+
+--R                \|- 4a b + 1           \|- 4a b + 1
+--R   (2)  ---------------------------------------------
+--R                         +----------+
+--R                        \|- 4a b + 1
+--R                                                    Type: Expression(Integer)
+--E 1932
+
+--S 1933 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 4                2    2  +----------+        2       3
+--R              (b x  + (- 6a b + 1)x  + a )\|- 4a b + 1  + (8a b  - 2b)x
+--R            + 
+--R                   2
+--R              (- 8a b + 2a)x
+--R         /
+--R             2 4              2    2
+--R            b x  + (2a b - 1)x  + a
+--R    /
+--R         +----------+
+--R       2\|- 4a b + 1
+--R     ,
+--R             +--------+          2 3
+--R         b x\|4a b - 1          b x  + (3a b - 1)x
+--R    atan(--------------) + atan(------------------)
+--R            4a b - 1                 +--------+
+--R                                   a\|4a b - 1
+--R    -----------------------------------------------]
+--R                       +--------+
+--R                      \|4a b - 1
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1933
+
+--S 1934 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                2 4                2    2  +----------+        2       3
+--R              (b x  + (- 6a b + 1)x  + a )\|- 4a b + 1  + (8a b  - 2b)x
+--R            + 
+--R                   2
+--R              (- 8a b + 2a)x
+--R         /
+--R             2 4              2    2
+--R            b x  + (2a b - 1)x  + a
+--R     + 
+--R                 2b x + 1                2b x - 1
+--R       2atanh(-------------) + 2atanh(-------------)
+--R               +----------+            +----------+
+--R              \|- 4a b + 1            \|- 4a b + 1
+--R  /
+--R       +----------+
+--R     2\|- 4a b + 1
+--R                                                    Type: Expression(Integer)
+--E 1934
+
+--S 1935 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1935
+
+--S 1936 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        +--------+         2b x + 1       +--------+         2b x - 1
+--R       \|4a b - 1 atanh(-------------) + \|4a b - 1 atanh(-------------)
+--R                         +----------+                      +----------+
+--R                        \|- 4a b + 1                      \|- 4a b + 1
+--R     + 
+--R                           +--------+                       2 3
+--R      +----------+     b x\|4a b - 1      +----------+     b x  + (3a b - 1)x
+--R     \|- 4a b + 1 atan(--------------) + \|- 4a b + 1 atan(------------------)
+--R                          4a b - 1                              +--------+
+--R                                                              a\|4a b - 1
+--R  /
+--R      +----------+ +--------+
+--R     \|- 4a b + 1 \|4a b - 1
+--R                                                    Type: Expression(Integer)
+--E 1936
+
+--S 1937 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1937
+
+)clear all
+
+--S 1938 of 3139
+t0:=(1-x^2)/(1+b*x^2+x^4)
+--R 
+--R
+--R              2
+--R           - x  + 1
+--R   (1)  -------------
+--R         4      2
+--R        x  + b x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1938
+
+--S 1939 of 3139
+r0:=-1/2*log(1+x^2-x*sqrt(2-b))/sqrt(2-b)+1/2*log(1+x^2+x*sqrt(2-b))/sqrt(2-b)
+--R 
+--R
+--R              +-------+    2                +-------+    2
+--R        log(x\|- b + 2  + x  + 1) - log(- x\|- b + 2  + x  + 1)
+--R   (2)  -------------------------------------------------------
+--R                                +-------+
+--R                              2\|- b + 2
+--R                                                    Type: Expression(Integer)
+--E 1939
+
+--S 1940 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          4             2      +-------+              3
+--R        (x  + (- b + 4)x  + 1)\|- b + 2  + (- 2b + 4)x  + (- 2b + 4)x
+--R    log(-------------------------------------------------------------)
+--R                                 4      2
+--R                                x  + b x  + 1
+--R   [------------------------------------------------------------------,
+--R                                  +-------+
+--R                                2\|- b + 2
+--R             +-----+          3
+--R           x\|b - 2          x  + (b - 1)x
+--R    - atan(---------) + atan(-------------)
+--R             b - 2               +-----+
+--R                                \|b - 2
+--R    ---------------------------------------]
+--R                     +-----+
+--R                    \|b - 2
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1940
+
+--S 1941 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               +-------+    2
+--R       - log(x\|- b + 2  + x  + 1)
+--R     + 
+--R             4             2      +-------+              3
+--R           (x  + (- b + 4)x  + 1)\|- b + 2  + (- 2b + 4)x  + (- 2b + 4)x
+--R       log(-------------------------------------------------------------)
+--R                                    4      2
+--R                                   x  + b x  + 1
+--R     + 
+--R               +-------+    2
+--R       log(- x\|- b + 2  + x  + 1)
+--R  /
+--R       +-------+
+--R     2\|- b + 2
+--R                                                    Type: Expression(Integer)
+--E 1941
+
+--S 1942 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1942
+
+--S 1943 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +-----+      +-------+    2         +-----+        +-------+    2
+--R       - \|b - 2 log(x\|- b + 2  + x  + 1) + \|b - 2 log(- x\|- b + 2  + x  + 1)
+--R     + 
+--R                           +-----+                     3
+--R           +-------+     x\|b - 2       +-------+     x  + (b - 1)x
+--R       - 2\|- b + 2 atan(---------) + 2\|- b + 2 atan(-------------)
+--R                           b - 2                          +-----+
+--R                                                         \|b - 2
+--R  /
+--R       +-------+ +-----+
+--R     2\|- b + 2 \|b - 2
+--R                                                    Type: Expression(Integer)
+--E 1943
+
+--S 1944 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1944
+
+)clear all
+
+--S 1945 of 3139
+t0:=(1-x^2)/(1+5*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1945
+
+--S 1946 of 3139
+r0:=-atan(x*sqrt(2/(5+sqrt(21))))/sqrt(3)+atan(x*sqrt(1/2*(5+sqrt(21))))/_
+   sqrt(3)
+--R 
+--R
+--R               +---------+           +-----------+
+--R               | +--+                |   +--+
+--R             x\|\|21  + 5          x\|- \|21  + 5
+--R        atan(-------------) - atan(---------------)
+--R                   +-+                    +-+
+--R                  \|2                    \|2
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                            \|3
+--R                                                    Type: Expression(Integer)
+--E 1946
+
+--S 1947 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-+          3
+--R               x\|3          x  + 4x
+--R        - atan(-----) + atan(-------)
+--R                 3              +-+
+--R                               \|3
+--R   (3)  -----------------------------
+--R                      +-+
+--R                     \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1947
+
+--S 1948 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +---------+           +-----------+
+--R            | +--+                |   +--+                +-+          3
+--R          x\|\|21  + 5          x\|- \|21  + 5          x\|3          x  + 4x
+--R   - atan(-------------) + atan(---------------) - atan(-----) + atan(-------)
+--R                +-+                    +-+                3              +-+
+--R               \|2                    \|2                               \|3
+--R   ---------------------------------------------------------------------------
+--R                                        +-+
+--R                                       \|3
+--R                                                    Type: Expression(Integer)
+--E 1948
+
+--S 1949 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                               +---------+
+--R         2 +-+ +-+ +--+        2      +-+ +-+  | +--+
+--R       (x \|2 \|3 \|21  + (- 5x  - 2)\|2 \|3 )\|\|21  + 5
+--R     + 
+--R                                             +-----------+
+--R         2 +-+ +-+ +--+      2      +-+ +-+  |   +--+           2
+--R       (x \|2 \|3 \|21  + (5x  + 2)\|2 \|3 )\|- \|21  + 5  - 12x  + 12
+--R  /
+--R        4      2
+--R     12x  + 60x  + 12
+--R                                                    Type: Expression(Integer)
+--E 1949
+
+)clear all
+
+--S 1950 of 3139
+t0:=(1-x^2)/(1+4*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1950
+
+--S 1951 of 3139
+r0:=atan(x/sqrt(2-sqrt(3)))/sqrt(2)-atan(x/sqrt(2+sqrt(3)))/sqrt(2)
+--R 
+--R
+--R                          +--------+                      +----------+
+--R                +-+       | +-+                 +-+       |   +-+
+--R        atan((x\|3  - 2x)\|\|3  + 2 ) + atan((x\|3  + 2x)\|- \|3  + 2 )
+--R   (2)  ---------------------------------------------------------------
+--R                                       +-+
+--R                                      \|2
+--R                                                    Type: Expression(Integer)
+--E 1951
+
+--S 1952 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-+          3
+--R               x\|2          x  + 3x
+--R        - atan(-----) + atan(-------)
+--R                 2              +-+
+--R                               \|2
+--R   (3)  -----------------------------
+--R                      +-+
+--R                     \|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1952
+
+--S 1953 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           +--------+                      +----------+
+--R                 +-+       | +-+                 +-+       |   +-+
+--R       - atan((x\|3  - 2x)\|\|3  + 2 ) - atan((x\|3  + 2x)\|- \|3  + 2 )
+--R     + 
+--R                +-+          3
+--R              x\|2          x  + 3x
+--R       - atan(-----) + atan(-------)
+--R                2              +-+
+--R                              \|2
+--R  /
+--R      +-+
+--R     \|2
+--R                                                    Type: Expression(Integer)
+--E 1953
+
+--S 1954 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                   +--------+
+--R           +-+ +-+     2      +-+  | +-+
+--R       (- \|2 \|3  + (x  + 2)\|2 )\|\|3  + 2
+--R     + 
+--R                                     +----------+
+--R           +-+ +-+       2      +-+  |   +-+          2
+--R       (- \|2 \|3  + (- x  - 2)\|2 )\|- \|3  + 2  - 2x  + 2
+--R  /
+--R       4     2
+--R     2x  + 8x  + 2
+--R                                                    Type: Expression(Integer)
+--E 1954
+
+)clear all
+
+--S 1955 of 3139
+t0:=(1-x^2)/(1+3*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1955
+
+--S 1956 of 3139
+r0:=-atan(x*sqrt(2/(3+sqrt(5))))+atan(x*sqrt(1/2*(3+sqrt(5))))
+--R 
+--R
+--R               +--------+           +----------+
+--R               | +-+                |   +-+
+--R             x\|\|5  + 3          x\|- \|5  + 3
+--R   (2)  atan(------------) - atan(--------------)
+--R                  +-+                   +-+
+--R                 \|2                   \|2
+--R                                                    Type: Expression(Integer)
+--E 1956
+
+--S 1957 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3
+--R   (3)  atan(x  + 2x) - atan(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 1957
+
+--S 1958 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                 +--------+           +----------+
+--R                 | +-+                |   +-+
+--R               x\|\|5  + 3          x\|- \|5  + 3           3
+--R   (4)  - atan(------------) + atan(--------------) + atan(x  + 2x) - atan(x)
+--R                    +-+                   +-+
+--R                   \|2                   \|2
+--R                                                    Type: Expression(Integer)
+--E 1958
+
+--S 1959 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                      +--------+
+--R         2 +-+ +-+        2      +-+  | +-+
+--R       (x \|2 \|5  + (- 3x  - 2)\|2 )\|\|5  + 3
+--R     + 
+--R                                    +----------+
+--R         2 +-+ +-+      2      +-+  |   +-+          2
+--R       (x \|2 \|5  + (3x  + 2)\|2 )\|- \|5  + 3  - 4x  + 4
+--R  /
+--R       4      2
+--R     4x  + 12x  + 4
+--R                                                    Type: Expression(Integer)
+--E 1959
+
+)clear all
+
+--S 1960 of 3139
+t0:=(1-x^2)/(1+2*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1960
+
+--S 1961 of 3139
+r0:=x/(1+x^2)
+--R 
+--R
+--R           x
+--R   (2)  ------
+--R         2
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1961
+
+--S 1962 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x
+--R   (3)  ------
+--R         2
+--R        x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 1962
+
+--S 1963 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1963
+
+--S 1964 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1964
+
+)clear all
+
+--S 1965 of 3139
+t0:=(1-x^2)/(1+x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1965
+
+--S 1966 of 3139
+r0:=-1/2*log(1-x+x^2)+1/2*log(1+x+x^2)
+--R 
+--R
+--R             2                 2
+--R        log(x  + x + 1) - log(x  - x + 1)
+--R   (2)  ---------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 1966
+
+--S 1967 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2                 2
+--R        log(x  + x + 1) - log(x  - x + 1)
+--R   (3)  ---------------------------------
+--R                        2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1967
+
+--S 1968 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1968
+
+--S 1969 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1969
+
+)clear all
+
+--S 1970 of 3139
+t0:=(1-x^2)/(1+x^4)
+--R 
+--R
+--R           2
+--R        - x  + 1
+--R   (1)  --------
+--R          4
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1970
+
+--S 1971 of 3139
+r0:=-1/2*log(1+x^2-x*sqrt(2))/sqrt(2)+1/2*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R              +-+    2                +-+    2
+--R        log(x\|2  + x  + 1) - log(- x\|2  + x  + 1)
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           2\|2
+--R                                                    Type: Expression(Integer)
+--E 1971
+
+--S 1972 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4     2      +-+     3
+--R            (x  + 4x  + 1)\|2  + 4x  + 4x
+--R        log(-----------------------------)
+--R                         4
+--R                        x  + 1
+--R   (3)  ----------------------------------
+--R                         +-+
+--R                       2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1972
+
+--S 1973 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     4     2      +-+     3
+--R               +-+    2            (x  + 4x  + 1)\|2  + 4x  + 4x
+--R       - log(x\|2  + x  + 1) + log(-----------------------------)
+--R                                                4
+--R                                               x  + 1
+--R     + 
+--R               +-+    2
+--R       log(- x\|2  + x  + 1)
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 1973
+
+--S 1974 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1974
+
+)clear all
+
+--S 1975 of 3139
+t0:=(1-x^2)/(1-x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  -----------
+--R         4    2
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1975
+
+--S 1976 of 3139
+r0:=-1/2*log(1+x^2-x*sqrt(3))/sqrt(3)+1/2*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R              +-+    2                +-+    2
+--R        log(x\|3  + x  + 1) - log(- x\|3  + x  + 1)
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           2\|3
+--R                                                    Type: Expression(Integer)
+--E 1976
+
+--S 1977 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4     2      +-+     3
+--R            (x  + 5x  + 1)\|3  + 6x  + 6x
+--R        log(-----------------------------)
+--R                      4    2
+--R                     x  - x  + 1
+--R   (3)  ----------------------------------
+--R                         +-+
+--R                       2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1977
+
+--S 1978 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     4     2      +-+     3
+--R               +-+    2            (x  + 5x  + 1)\|3  + 6x  + 6x
+--R       - log(x\|3  + x  + 1) + log(-----------------------------)
+--R                                             4    2
+--R                                            x  - x  + 1
+--R     + 
+--R               +-+    2
+--R       log(- x\|3  + x  + 1)
+--R  /
+--R       +-+
+--R     2\|3
+--R                                                    Type: Expression(Integer)
+--E 1978
+
+--S 1979 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1979
+
+)clear all
+
+--S 1980 of 3139
+t0:=(1-x^2)/(1-2*x^2+x^4)
+--R 
+--R
+--R             1
+--R   (1)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1980
+
+--S 1981 of 3139
+r0:=atanh(x)
+--R 
+--R
+--R   (2)  atanh(x)
+--R                                                    Type: Expression(Integer)
+--E 1981
+
+--S 1982 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(x + 1) - log(x - 1)
+--R   (3)  -----------------------
+--R                   2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1982
+
+--S 1983 of 3139
+m0:=a0-r0
+--R 
+--R
+--R        log(x + 1) - log(x - 1) - 2atanh(x)
+--R   (4)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 1983
+
+--S 1984 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1984
+
+)clear all
+
+--S 1985 of 3139
+t0:=(1-x^2)/(1-3*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1985
+
+--S 1986 of 3139
+r0:=-atanh((1-2*x)/sqrt(5))/sqrt(5)+atanh((1+2*x)/sqrt(5))/sqrt(5)
+--R 
+--R
+--R                       +-+                   +-+
+--R              (2x + 1)\|5           (2x - 1)\|5
+--R        atanh(------------) + atanh(------------)
+--R                    5                     5
+--R   (2)  -----------------------------------------
+--R                            +-+
+--R                           \|5
+--R                                                    Type: Expression(Integer)
+--E 1986
+
+--S 1987 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4     2      +-+      3
+--R            (x  + 7x  + 1)\|5  + 10x  + 10x
+--R        log(-------------------------------)
+--R                       4     2
+--R                      x  - 3x  + 1
+--R   (3)  ------------------------------------
+--R                          +-+
+--R                        2\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1987
+
+--S 1988 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4     2      +-+      3                          +-+
+--R           (x  + 7x  + 1)\|5  + 10x  + 10x           (2x + 1)\|5
+--R       log(-------------------------------) - 2atanh(------------)
+--R                      4     2                              5
+--R                     x  - 3x  + 1
+--R     + 
+--R                         +-+
+--R                (2x - 1)\|5
+--R       - 2atanh(------------)
+--R                      5
+--R  /
+--R       +-+
+--R     2\|5
+--R                                                    Type: Expression(Integer)
+--E 1988
+
+--S 1989 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1989
+
+)clear all
+
+--S 1990 of 3139
+t0:=(1-x^2)/(1-4*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1990
+
+--S 1991 of 3139
+r0:=atanh((1+x*sqrt(2))/sqrt(3))/sqrt(6)-atanh((-2*x+sqrt(2))/sqrt(6))/sqrt(6)
+--R 
+--R
+--R                  +-+       +-+             +-+      +-+
+--R                (\|2  - 2x)\|6           (x\|2  + 1)\|3
+--R        - atanh(---------------) + atanh(---------------)
+--R                       6                        3
+--R   (2)  -------------------------------------------------
+--R                                +-+
+--R                               \|6
+--R                                                    Type: Expression(Integer)
+--E 1991
+
+--S 1992 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4     2      +-+      3
+--R            (x  + 8x  + 1)\|6  + 12x  + 12x
+--R        log(-------------------------------)
+--R                       4     2
+--R                      x  - 4x  + 1
+--R   (3)  ------------------------------------
+--R                          +-+
+--R                        2\|6
+--R                                         Type: Union(Expression(Integer),...)
+--E 1992
+
+--S 1993 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4     2      +-+      3                   +-+       +-+
+--R           (x  + 8x  + 1)\|6  + 12x  + 12x           (\|2  - 2x)\|6
+--R       log(-------------------------------) + 2atanh(---------------)
+--R                      4     2                               6
+--R                     x  - 4x  + 1
+--R     + 
+--R                   +-+      +-+
+--R                (x\|2  + 1)\|3
+--R       - 2atanh(---------------)
+--R                       3
+--R  /
+--R       +-+
+--R     2\|6
+--R                                                    Type: Expression(Integer)
+--E 1993
+
+--S 1994 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R               5       +-+     4     2  +-+     5     3      +-+    6     4
+--R           ((2x  - 2x)\|2  - 4x  - 4x )\|3  + (x  + 8x  + x)\|2  - x  - 7x
+--R         + 
+--R             2
+--R           7x  + 1
+--R      *
+--R          +-+
+--R         \|6
+--R     + 
+--R          6     4     2      +-+     5      3       +-+       4      2  +-+
+--R       ((x  + 7x  - 7x  - 1)\|2  - 2x  - 16x  - 2x)\|3  + (12x  + 12x )\|2
+--R     + 
+--R            5
+--R       - 12x  + 12x
+--R  /
+--R        8     6      4     2      +-+      7      5      3
+--R     (2x  + 8x  - 60x  + 8x  + 2)\|6  + 24x  - 72x  - 72x  + 24x
+--R                                                    Type: Expression(Integer)
+--E 1994
+
+)clear all
+
+--S 1995 of 3139
+t0:=(1-x^2)/(1-5*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1995
+
+--S 1996 of 3139
+r0:=-atanh((-2*x+sqrt(3))/sqrt(7))/sqrt(7)+atanh((2*x+sqrt(3))/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                +-+       +-+            +-+       +-+
+--R              (\|3  + 2x)\|7           (\|3  - 2x)\|7
+--R        atanh(---------------) - atanh(---------------)
+--R                     7                        7
+--R   (2)  -----------------------------------------------
+--R                               +-+
+--R                              \|7
+--R                                                    Type: Expression(Integer)
+--E 1996
+
+--S 1997 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4     2      +-+      3
+--R            (x  + 9x  + 1)\|7  + 14x  + 14x
+--R        log(-------------------------------)
+--R                       4     2
+--R                      x  - 5x  + 1
+--R   (3)  ------------------------------------
+--R                          +-+
+--R                        2\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 1997
+
+--S 1998 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4     2      +-+      3                   +-+       +-+
+--R           (x  + 9x  + 1)\|7  + 14x  + 14x           (\|3  + 2x)\|7
+--R       log(-------------------------------) - 2atanh(---------------)
+--R                      4     2                               7
+--R                     x  - 5x  + 1
+--R     + 
+--R                +-+       +-+
+--R              (\|3  - 2x)\|7
+--R       2atanh(---------------)
+--R                     7
+--R  /
+--R       +-+
+--R     2\|7
+--R                                                    Type: Expression(Integer)
+--E 1998
+
+--S 1999 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1999
+
+)clear all
+
+--S 2000 of 3139
+t0:=(1-2*x^2)/(1-5*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2000
+
+--S 2001 of 3139
+r0:=-1/6*log(1-2*x)-1/6*log(1-x)+1/6*log(1+x)+1/6*log(1+2*x)
+--R 
+--R
+--R        log(2x + 1) + log(x + 1) - log(- x + 1) - log(- 2x + 1)
+--R   (2)  -------------------------------------------------------
+--R                                   6
+--R                                                    Type: Expression(Integer)
+--E 2001
+
+--S 2002 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                   2
+--R        log(2x  + 3x + 1) - log(2x  - 3x + 1)
+--R   (3)  -------------------------------------
+--R                          6
+--R                                         Type: Union(Expression(Integer),...)
+--E 2002
+
+--S 2003 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2                   2
+--R       log(2x  + 3x + 1) - log(2x  - 3x + 1) - log(2x + 1) - log(x + 1)
+--R     + 
+--R       log(- x + 1) + log(- 2x + 1)
+--R  /
+--R     6
+--R                                                    Type: Expression(Integer)
+--E 2003
+
+--S 2004 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2004
+
+)clear all
+
+--S 2005 of 3139
+t0:=(1+x^2)/(1+b*x^2+x^4)
+--R 
+--R
+--R             2
+--R            x  + 1
+--R   (1)  -------------
+--R         4      2
+--R        x  + b x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2005
+
+--S 2006 of 3139
+r0:=-atan((-2*x+sqrt(2-b))/sqrt(2+b))/sqrt(2+b)+_
+   atan((2*x+sqrt(2-b))/sqrt(2+b))/sqrt(2+b)
+--R 
+--R
+--R              +-------+               +-------+
+--R             \|- b + 2  + 2x         \|- b + 2  - 2x
+--R        atan(---------------) - atan(---------------)
+--R                  +-----+                 +-----+
+--R                 \|b + 2                 \|b + 2
+--R   (2)  ---------------------------------------------
+--R                            +-----+
+--R                           \|b + 2
+--R                                                    Type: Expression(Integer)
+--E 2006
+
+--S 2007 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          4             2      +-------+            3
+--R        (x  + (- b - 4)x  + 1)\|- b - 2  + (2b + 4)x  + (- 2b - 4)x
+--R    log(-----------------------------------------------------------)
+--R                                4      2
+--R                               x  + b x  + 1
+--R   [----------------------------------------------------------------,
+--R                                 +-------+
+--R                               2\|- b - 2
+--R           +-----+          3
+--R         x\|b + 2          x  + (b + 1)x
+--R    atan(---------) + atan(-------------)
+--R           b + 2               +-----+
+--R                              \|b + 2
+--R    -------------------------------------]
+--R                    +-----+
+--R                   \|b + 2
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2007
+
+--S 2008 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     4             2      +-------+            3
+--R        +-----+    (x  + (- b - 4)x  + 1)\|- b - 2  + (2b + 4)x  + (- 2b - 4)x
+--R       \|b + 2 log(-----------------------------------------------------------)
+--R                                           4      2
+--R                                          x  + b x  + 1
+--R     + 
+--R                          +-------+                          +-------+
+--R           +-------+     \|- b + 2  + 2x      +-------+     \|- b + 2  - 2x
+--R       - 2\|- b - 2 atan(---------------) + 2\|- b - 2 atan(---------------)
+--R                              +-----+                            +-----+
+--R                             \|b + 2                            \|b + 2
+--R  /
+--R       +-------+ +-----+
+--R     2\|- b - 2 \|b + 2
+--R                                                    Type: Expression(Integer)
+--E 2008
+
+--S 2009 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2009
+
+--S 2010 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              +-----+          +-------+               +-------+
+--R            x\|b + 2          \|- b + 2  + 2x         \|- b + 2  - 2x
+--R       atan(---------) - atan(---------------) + atan(---------------)
+--R              b + 2                +-----+                 +-----+
+--R                                  \|b + 2                 \|b + 2
+--R     + 
+--R             3
+--R            x  + (b + 1)x
+--R       atan(-------------)
+--R                +-----+
+--R               \|b + 2
+--R  /
+--R      +-----+
+--R     \|b + 2
+--R                                                    Type: Expression(Integer)
+--E 2010
+
+--S 2011 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2011
+
+)clear all
+
+--S 2012 of 3139
+t0:=(1+x^2)/(1+5*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2012
+
+--S 2013 of 3139
+r0:=atan(x*sqrt(2/(5+sqrt(21))))/sqrt(7)+atan(x*sqrt(1/2*(5+sqrt(21))))/sqrt(7)
+--R 
+--R
+--R               +---------+           +-----------+
+--R               | +--+                |   +--+
+--R             x\|\|21  + 5          x\|- \|21  + 5
+--R        atan(-------------) + atan(---------------)
+--R                   +-+                    +-+
+--R                  \|2                    \|2
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                            \|7
+--R                                                    Type: Expression(Integer)
+--E 2013
+
+--S 2014 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+          3
+--R             x\|7          x  + 6x
+--R        atan(-----) + atan(-------)
+--R               7              +-+
+--R                             \|7
+--R   (3)  ---------------------------
+--R                     +-+
+--R                    \|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 2014
+
+--S 2015 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +---------+           +-----------+
+--R            | +--+                |   +--+                +-+          3
+--R          x\|\|21  + 5          x\|- \|21  + 5          x\|7          x  + 6x
+--R   - atan(-------------) - atan(---------------) + atan(-----) + atan(-------)
+--R                +-+                    +-+                7              +-+
+--R               \|2                    \|2                               \|7
+--R   ---------------------------------------------------------------------------
+--R                                        +-+
+--R                                       \|7
+--R                                                    Type: Expression(Integer)
+--E 2015
+
+--S 2016 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                               +---------+
+--R         2 +-+ +-+ +--+        2      +-+ +-+  | +--+
+--R       (x \|2 \|7 \|21  + (- 5x  - 2)\|2 \|7 )\|\|21  + 5
+--R     + 
+--R                                                 +-----------+
+--R           2 +-+ +-+ +--+        2      +-+ +-+  |   +--+           2
+--R       (- x \|2 \|7 \|21  + (- 5x  - 2)\|2 \|7 )\|- \|21  + 5  + 28x  + 28
+--R  /
+--R        4       2
+--R     28x  + 140x  + 28
+--R                                                    Type: Expression(Integer)
+--E 2016
+
+)clear all
+
+--S 2017 of 3139
+t0:=(1+x^2)/(1+4*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2017
+
+--S 2018 of 3139
+r0:=atan(x/sqrt(2-sqrt(3)))/sqrt(6)+atan(x/sqrt(2+sqrt(3)))/sqrt(6)
+--R 
+--R
+--R                            +--------+                      +----------+
+--R                  +-+       | +-+                 +-+       |   +-+
+--R        - atan((x\|3  - 2x)\|\|3  + 2 ) + atan((x\|3  + 2x)\|- \|3  + 2 )
+--R   (2)  -----------------------------------------------------------------
+--R                                        +-+
+--R                                       \|6
+--R                                                    Type: Expression(Integer)
+--E 2018
+
+--S 2019 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+          3
+--R             x\|6          x  + 5x
+--R        atan(-----) + atan(-------)
+--R               6              +-+
+--R                             \|6
+--R   (3)  ---------------------------
+--R                     +-+
+--R                    \|6
+--R                                         Type: Union(Expression(Integer),...)
+--E 2019
+
+--S 2020 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +--------+                      +----------+
+--R               +-+       | +-+                 +-+       |   +-+
+--R       atan((x\|3  - 2x)\|\|3  + 2 ) - atan((x\|3  + 2x)\|- \|3  + 2 )
+--R     + 
+--R              +-+          3
+--R            x\|6          x  + 5x
+--R       atan(-----) + atan(-------)
+--R              6              +-+
+--R                            \|6
+--R  /
+--R      +-+
+--R     \|6
+--R                                                    Type: Expression(Integer)
+--E 2020
+
+--S 2021 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       +--------+                         +----------+
+--R     +-+    2      +-+ | +-+            +-+    2      +-+ |   +-+          2
+--R   (\|3  - x  - 2)\|6 \|\|3  + 2  + (- \|3  - x  - 2)\|6 \|- \|3  + 2  + 6x  + 6
+--R   -----------------------------------------------------------------------------
+--R                                     4      2
+--R                                   6x  + 24x  + 6
+--R                                                    Type: Expression(Integer)
+--E 2021
+
+)clear all
+
+--S 2022 of 3139
+t0:=(1+x^2)/(1+3*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2022
+
+--S 2023 of 3139
+r0:=atan(x*sqrt(2/(3+sqrt(5))))/sqrt(5)+atan(x*sqrt(1/2*(3+sqrt(5))))/sqrt(5)
+--R 
+--R
+--R               +--------+           +----------+
+--R               | +-+                |   +-+
+--R             x\|\|5  + 3          x\|- \|5  + 3
+--R        atan(------------) + atan(--------------)
+--R                  +-+                   +-+
+--R                 \|2                   \|2
+--R   (2)  -----------------------------------------
+--R                            +-+
+--R                           \|5
+--R                                                    Type: Expression(Integer)
+--E 2023
+
+--S 2024 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+          3
+--R             x\|5          x  + 4x
+--R        atan(-----) + atan(-------)
+--R               5              +-+
+--R                             \|5
+--R   (3)  ---------------------------
+--R                     +-+
+--R                    \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 2024
+
+--S 2025 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +--------+           +----------+
+--R            | +-+                |   +-+                +-+          3
+--R          x\|\|5  + 3          x\|- \|5  + 3          x\|5          x  + 4x
+--R   - atan(------------) - atan(--------------) + atan(-----) + atan(-------)
+--R               +-+                   +-+                5              +-+
+--R              \|2                   \|2                               \|5
+--R   -------------------------------------------------------------------------
+--R                                       +-+
+--R                                      \|5
+--R                                                    Type: Expression(Integer)
+--E 2025
+
+--S 2026 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                       +--------+
+--R             2      +-+ +-+     2 +-+  | +-+
+--R       ((- 3x  - 2)\|2 \|5  + 5x \|2 )\|\|5  + 3
+--R     + 
+--R                                       +----------+
+--R             2      +-+ +-+     2 +-+  |   +-+           2
+--R       ((- 3x  - 2)\|2 \|5  - 5x \|2 )\|- \|5  + 3  + 20x  + 20
+--R  /
+--R        4      2
+--R     20x  + 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 2026
+
+)clear all
+
+--S 2027 of 3139
+t0:=(1+x^2)/(1+2*x^2+x^4)
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         2
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2027
+
+--S 2028 of 3139
+r0:=atan(x)
+--R 
+--R
+--R        %pi
+--R   (2)  ---
+--R         3
+--R                                                    Type: Expression(Integer)
+--E 2028
+
+--S 2029 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R        %pi
+--R   (3)  ---
+--R         3
+--R                                         Type: Union(Expression(Integer),...)
+--E 2029
+
+--S 2030 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2030
+
+--S 2031 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2031
+
+)clear all
+
+--S 2032 of 3139
+t0:=(1+x^2)/(1+x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2032
+
+--S 2033 of 3139
+r0:=-atan((1-2*x)/sqrt(3))/sqrt(3)+atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                      +-+                  +-+
+--R             (2x + 1)\|3          (2x - 1)\|3
+--R        atan(------------) + atan(------------)
+--R                   3                    3
+--R   (2)  ---------------------------------------
+--R                           +-+
+--R                          \|3
+--R                                                    Type: Expression(Integer)
+--E 2033
+
+--S 2034 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+          3
+--R             x\|3          x  + 2x
+--R        atan(-----) + atan(-------)
+--R               3              +-+
+--R                             \|3
+--R   (3)  ---------------------------
+--R                     +-+
+--R                    \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 2034
+
+--S 2035 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +-+                  +-+           +-+          3
+--R          (2x + 1)\|3          (2x - 1)\|3          x\|3          x  + 2x
+--R   - atan(------------) - atan(------------) + atan(-----) + atan(-------)
+--R                3                    3                3              +-+
+--R                                                                    \|3
+--R   -----------------------------------------------------------------------
+--R                                      +-+
+--R                                     \|3
+--R                                                    Type: Expression(Integer)
+--E 2035
+
+--S 2036 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2036
+
+)clear all
+
+--S 2037 of 3139
+t0:=(1+x^2)/(1+x^4)
+--R 
+--R
+--R         2
+--R        x  + 1
+--R   (1)  ------
+--R         4
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2037
+
+--S 2038 of 3139
+r0:=-atan(1-x*sqrt(2))/sqrt(2)+atan(1+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R               +-+               +-+
+--R        atan(x\|2  + 1) + atan(x\|2  - 1)
+--R   (2)  ---------------------------------
+--R                        +-+
+--R                       \|2
+--R                                                    Type: Expression(Integer)
+--E 2038
+
+--S 2039 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+          3
+--R             x\|2          x  + x
+--R        atan(-----) + atan(------)
+--R               2             +-+
+--R                            \|2
+--R   (3)  --------------------------
+--R                    +-+
+--R                   \|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2039
+
+--S 2040 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                                                     +-+          3
+--R                 +-+               +-+             x\|2          x  + x
+--R        - atan(x\|2  + 1) - atan(x\|2  - 1) + atan(-----) + atan(------)
+--R                                                     2             +-+
+--R                                                                  \|2
+--R   (4)  ----------------------------------------------------------------
+--R                                       +-+
+--R                                      \|2
+--R                                                    Type: Expression(Integer)
+--E 2040
+
+--S 2041 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2041
+
+)clear all
+
+--S 2042 of 3139
+t0:=(1+x^2)/(1-x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  -----------
+--R         4    2
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2042
+
+--S 2043 of 3139
+r0:=-atan(-2*x+sqrt(3))+atan(2*x+sqrt(3))
+--R 
+--R
+--R              +-+               +-+
+--R   (2)  atan(\|3  + 2x) - atan(\|3  - 2x)
+--R                                                    Type: Expression(Integer)
+--E 2043
+
+--S 2044 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3
+--R   (3)  atan(x ) + atan(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 2044
+
+--S 2045 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                +-+               +-+               3
+--R   (4)  - atan(\|3  + 2x) + atan(\|3  - 2x) + atan(x ) + atan(x)
+--R                                                    Type: Expression(Integer)
+--E 2045
+
+--S 2046 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2046
+
+)clear all
+
+--S 2047 of 3139
+t0:=(1+x^2)/(1-2*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2047
+
+--S 2048 of 3139
+r0:=x/(1-x^2)
+--R 
+--R
+--R             x
+--R   (2)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2048
+
+--S 2049 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             x
+--R   (3)  - ------
+--R           2
+--R          x  - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 2049
+
+--S 2050 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2050
+
+--S 2051 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2051
+
+)clear all
+
+--S 2052 of 3139
+t0:=(1+x^2)/(1-3*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2052
+
+--S 2053 of 3139
+r0:=atanh(-2*x+sqrt(5))-atanh(2*x+sqrt(5))
+--R 
+--R
+--R                 +-+                +-+
+--R   (2)  - atanh(\|5  + 2x) + atanh(\|5  - 2x)
+--R                                                    Type: Expression(Integer)
+--E 2053
+
+--S 2054 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2                 2
+--R        - log(x  + x - 1) + log(x  - x - 1)
+--R   (3)  -----------------------------------
+--R                         2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2054
+
+--S 2055 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          2                 2                    +-+                 +-+
+--R   - log(x  + x - 1) + log(x  - x - 1) + 2atanh(\|5  + 2x) - 2atanh(\|5  - 2x)
+--R   ---------------------------------------------------------------------------
+--R                                        2
+--R                                                    Type: Expression(Integer)
+--E 2055
+
+--S 2056 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2056
+
+)clear all
+
+--S 2057 of 3139
+t0:=(1+x^2)/(1-4*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2057
+
+--S 2058 of 3139
+r0a:=atanh(-x*sqrt(2)+sqrt(3))/sqrt(2)-atanh(x*sqrt(2)+sqrt(3))/sqrt(2)
+--R 
+--R
+--R                 +-+     +-+           +-+     +-+
+--R        - atanh(\|3  + x\|2 ) + atanh(\|3  - x\|2 )
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                            \|2
+--R                                                    Type: Expression(Integer)
+--E 2058
+
+--S 2059 of 3139
+r0b:=atanh((-2*x+sqrt(6))/sqrt(2))/sqrt(2)-atanh((2*x+sqrt(6))/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                 +-+ +-+      +-+           +-+ +-+      +-+
+--R                \|2 \|6  + 2x\|2           \|2 \|6  - 2x\|2
+--R        - atanh(-----------------) + atanh(-----------------)
+--R                        2                          2
+--R   (3)  -----------------------------------------------------
+--R                                  +-+
+--R                                 \|2
+--R                                                    Type: Expression(Integer)
+--E 2059
+
+--S 2060 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4      +-+     3
+--R            (x  + 1)\|2  - 4x  + 4x
+--R        log(-----------------------)
+--R                   4     2
+--R                  x  - 4x  + 1
+--R   (4)  ----------------------------
+--R                      +-+
+--R                    2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2060
+
+--S 2061 of 3139
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R         4      +-+     3
+--R       (x  + 1)\|2  - 4x  + 4x            +-+     +-+            +-+     +-+
+--R   log(-----------------------) + 2atanh(\|3  + x\|2 ) - 2atanh(\|3  - x\|2 )
+--R              4     2
+--R             x  - 4x  + 1
+--R   --------------------------------------------------------------------------
+--R                                        +-+
+--R                                      2\|2
+--R                                                    Type: Expression(Integer)
+--E 2061
+
+--S 2062 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 2062
+
+--S 2063 of 3139
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R             4      +-+     3                 +-+ +-+      +-+
+--R           (x  + 1)\|2  - 4x  + 4x           \|2 \|6  + 2x\|2
+--R       log(-----------------------) + 2atanh(-----------------)
+--R                  4     2                            2
+--R                 x  - 4x  + 1
+--R     + 
+--R                 +-+ +-+      +-+
+--R                \|2 \|6  - 2x\|2
+--R       - 2atanh(-----------------)
+--R                        2
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 2063
+
+--S 2064 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 2064
+
+)clear all
+
+--S 2065 of 3139
+t0:=(1+x^2)/(1-5*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2065
+
+--S 2066 of 3139
+r0:=atanh((-2*x+sqrt(7))/sqrt(3))/sqrt(3)-atanh((2*x+sqrt(7))/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                 +-+ +-+      +-+           +-+ +-+      +-+
+--R                \|3 \|7  + 2x\|3           \|3 \|7  - 2x\|3
+--R        - atanh(-----------------) + atanh(-----------------)
+--R                        3                          3
+--R   (2)  -----------------------------------------------------
+--R                                  +-+
+--R                                 \|3
+--R                                                    Type: Expression(Integer)
+--E 2066
+
+--S 2067 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4    2      +-+     3
+--R            (x  + x  + 1)\|3  - 6x  + 6x
+--R        log(----------------------------)
+--R                     4     2
+--R                    x  - 5x  + 1
+--R   (3)  ---------------------------------
+--R                        +-+
+--R                      2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 2067
+
+--S 2068 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4    2      +-+     3                 +-+ +-+      +-+
+--R           (x  + x  + 1)\|3  - 6x  + 6x           \|3 \|7  + 2x\|3
+--R       log(----------------------------) + 2atanh(-----------------)
+--R                    4     2                               3
+--R                   x  - 5x  + 1
+--R     + 
+--R                 +-+ +-+      +-+
+--R                \|3 \|7  - 2x\|3
+--R       - 2atanh(-----------------)
+--R                        3
+--R  /
+--R       +-+
+--R     2\|3
+--R                                                    Type: Expression(Integer)
+--E 2068
+
+--S 2069 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2069
+
+)clear all
+
+--S 2070 of 3139
+t0:=(1+2*x^2)/(1+5*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2070
+
+--S 2071 of 3139
+r0:=1/3*atan(x)+1/3*atan(2*x)
+--R 
+--R
+--R        3atan(2x) + %pi
+--R   (2)  ---------------
+--R               9
+--R                                                    Type: Expression(Integer)
+--E 2071
+
+--S 2072 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3
+--R             4x  + 7x         2x
+--R        atan(--------) + atan(--)
+--R                 3             3
+--R   (3)  -------------------------
+--R                    3
+--R                                         Type: Union(Expression(Integer),...)
+--E 2072
+
+--S 2073 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                3
+--R              4x  + 7x                      2x
+--R        3atan(--------) - 3atan(2x) + 3atan(--) - %pi
+--R                  3                          3
+--R   (4)  ---------------------------------------------
+--R                              9
+--R                                                    Type: Expression(Integer)
+--E 2073
+
+--S 2074 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R           1
+--R   (5)  -------
+--R          2
+--R        3x  + 3
+--R                                                    Type: Expression(Integer)
+--E 2074
+
+)clear all
+
+--S 2075 of 3139
+t0:=x^m*(A+B*x^2)*(a+b*x^2+c*x^4)^4
+--R 
+--R
+--R   (1)
+--R          4 18       4         3  16                  3       2 2  14
+--R       B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R     + 
+--R              3        2            2       3   12
+--R       (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R     + 
+--R                       2  2        3          2        4  10
+--R       ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R     + 
+--R            2 2           2        2         4         3  8
+--R       (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R     + 
+--R              2        3           3       2 2  6
+--R       ((12A a b + 4B a )c + 4A a b  + 6B a b )x
+--R     + 
+--R            3        2 2       3   4        3       4  2      4
+--R       (4A a c + 6A a b  + 4B a b)x  + (4A a b + B a )x  + A a
+--R  *
+--R      m
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 2075
+
+--S 2076 of 3139
+r0:=a^4*A*x^(1+m)/(1+m)+a^3*(4*A*b+a*B)*x^(3+m)/(3+m)+2*a^2*(3*A*b^2+_
+   2*a*b*B+2*a*A*c)*x^(5+m)/(5+m)+2*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*_
+   x^(7+m)/(7+m)+(4*a*b*B*(b^2+3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*_
+   x^(9+m)/(9+m)+(b^4*B+4*A*b^3*c+12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*_
+   x^(11+m)/(11+m)+2*c*(2*b^3*B+3*A*b^2*c+6*a*b*B*c+2*a*A*c^2)*_
+   x^(13+m)/(13+m)+2*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^(15+m)/(15+m)+_
+   c^3*(4*b*B+A*c)*x^(17+m)/(17+m)+B*c^4*x^(19+m)/(19+m)
+--R 
+--R
+--R   (2)
+--R              4 9        4 8          4 7           4 6            4 5
+--R           B c m  + 81B c m  + 2796B c m  + 53676B c m  + 626934B c m
+--R         + 
+--R                     4 4              4 3              4 2              4
+--R           4574934B c m  + 20570444B c m  + 53809164B c m  + 71697105B c m
+--R         + 
+--R                      4
+--R           34459425B c
+--R      *
+--R          m + 19
+--R         x
+--R     + 
+--R               4         3  9         4           3  8
+--R           (A c  + 4B b c )m  + (83A c  + 332B b c )m
+--R         + 
+--R                   4             3  7            4              3  6
+--R           (2924A c  + 11696B b c )m  + (57092A c  + 228368B b c )m
+--R         + 
+--R                     4               3  5              4                3  4
+--R           (676214A c  + 2704856B b c )m  + (4991042A c  + 19964168B b c )m
+--R         + 
+--R                       4                3  3
+--R           (22646476A c  + 90585904B b c )m
+--R         + 
+--R                       4                 3  2
+--R           (59657508A c  + 238630032B b c )m
+--R         + 
+--R                       4                 3                4                 3
+--R           (79893585A c  + 319574340B b c )m + 38513475A c  + 154053900B b c
+--R      *
+--R          m + 17
+--R         x
+--R     + 
+--R                          3       2 2  9                      3         2 2  8
+--R           ((4A b + 4B a)c  + 6B b c )m  + ((340A b + 340B a)c  + 510B b c )m
+--R         + 
+--R                                  3           2 2  7
+--R           ((12240A b + 12240B a)c  + 18360B b c )m
+--R         + 
+--R                                    3            2 2  6
+--R           ((243600A b + 243600B a)c  + 365400B b c )m
+--R         + 
+--R                                      3             2 2  5
+--R           ((2933112A b + 2933112B a)c  + 4399668B b c )m
+--R         + 
+--R                                        3              2 2  4
+--R           ((21950040A b + 21950040B a)c  + 32925060B b c )m
+--R         + 
+--R                                          3               2 2  3
+--R           ((100726160A b + 100726160B a)c  + 151089240B b c )m
+--R         + 
+--R                                          3               2 2  2
+--R           ((267698000A b + 267698000B a)c  + 401547000B b c )m
+--R         + 
+--R                                          3               2 2
+--R           ((360814884A b + 360814884B a)c  + 541222326B b c )m
+--R         + 
+--R                                         3               2 2
+--R           (174594420A b + 174594420B a)c  + 261891630B b c
+--R      *
+--R          m + 15
+--R         x
+--R     + 
+--R                  3        2            2       3   9
+--R           (4A a c  + (6A b  + 12B a b)c  + 4B b c)m
+--R         + 
+--R                    3          2              2         3   8
+--R           (348A a c  + (522A b  + 1044B a b)c  + 348B b c)m
+--R         + 
+--R                      3            2               2           3   7
+--R           (12816A a c  + (19224A b  + 38448B a b)c  + 12816B b c)m
+--R         + 
+--R                       3             2                2            3   6
+--R           (260592A a c  + (390888A b  + 781776B a b)c  + 260592B b c)m
+--R         + 
+--R                        3              2                 2             3   5
+--R           (3199416A a c  + (4799124A b  + 9598248B a b)c  + 3199416B b c)m
+--R         + 
+--R                         3               2                  2              3   4
+--R           (24354312A a c  + (36531468A b  + 73062936B a b)c  + 24354312B b c)m
+--R         + 
+--R                             3                2                   2
+--R               113370704A a c  + (170056056A b  + 340112112B a b)c
+--R             + 
+--R                           3
+--R               113370704B b c
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                             3                2                   2
+--R               304771248A a c  + (457156872A b  + 914313744B a b)c
+--R             + 
+--R                           3
+--R               304771248B b c
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                             3                2                    2
+--R               414258660A a c  + (621387990A b  + 1242775980B a b)c
+--R             + 
+--R                           3
+--R               414258660B b c
+--R          *
+--R             m
+--R         + 
+--R                       3                2                   2               3
+--R         201455100A a c  + (302182650A b  + 604365300B a b)c  + 201455100B b c
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                           2  2        3          2        4  9
+--R           ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )m
+--R         + 
+--R                               2  2          3            2          4  8
+--R           ((1068A a b + 534B a )c  + (356A b  + 1068B a b )c + 89B b )m
+--R         + 
+--R                                       2  2            3             2
+--R                 (40272A a b + 20136B a )c  + (13424A b  + 40272B a b )c
+--R               + 
+--R                        4
+--R                 3356B b
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                                       2  2             3              2
+--R               (838608A a b + 419304B a )c  + (279536A b  + 838608B a b )c
+--R             + 
+--R                       4
+--R               69884B b
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                                          2  2              3                2
+--R               (10536648A a b + 5268324B a )c  + (3512216A b  + 10536648B a b )c
+--R             + 
+--R                        4
+--R               878054B b
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                                           2  2
+--R               (81937032A a b + 40968516B a )c
+--R             + 
+--R                           3                2               4
+--R               (27312344A b  + 81937032B a b )c + 6828086B b
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                                             2  2
+--R               (388622928A a b + 194311464B a )c
+--R             + 
+--R                            3                 2                4
+--R               (129540976A b  + 388622928B a b )c + 32385244B b
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                                              2  2
+--R               (1060918992A a b + 530459496B a )c
+--R             + 
+--R                            3                  2                4
+--R               (353639664A b  + 1060918992B a b )c + 88409916B b
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                                              2  2
+--R               (1458745740A a b + 729372870B a )c
+--R             + 
+--R                            3                  2                 4
+--R               (486248580A b  + 1458745740B a b )c + 121562145B b
+--R          *
+--R             m
+--R         + 
+--R                                         2  2
+--R           (714249900A a b + 357124950B a )c
+--R         + 
+--R                        3                 2                4
+--R           (238083300A b  + 714249900B a b )c + 59520825B b
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                2 2           2        2         4         3  9
+--R           (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )m
+--R         + 
+--R                  2 2             2          2           4           3  8
+--R           (546A a c  + (1092A a b  + 1092B a b)c + 91A b  + 364B a b )m
+--R         + 
+--R                         2 2              2           2             4
+--R                 21096A a c  + (42192A a b  + 42192B a b)c + 3516A b
+--R               + 
+--R                           3
+--R                 14064B a b
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                        2 2               2            2              4
+--R               450936A a c  + (901872A a b  + 901872B a b)c + 75156A b
+--R             + 
+--R                          3
+--R               300624B a b
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                         2 2                 2              2               4
+--R               5822244A a c  + (11644488A a b  + 11644488B a b)c + 970374A b
+--R             + 
+--R                           3
+--R               3881496B a b
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                          2 2                 2              2                4
+--R               46519884A a c  + (93039768A a b  + 93039768B a b)c + 7753314A b
+--R             + 
+--R                            3
+--R               31013256B a b
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                           2 2                  2               2
+--R               226286184A a c  + (452572368A a b  + 452572368B a b)c
+--R             + 
+--R                          4                 3
+--R               37714364A b  + 150857456B a b
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                           2 2                   2                2
+--R               631309944A a c  + (1262619888A a b  + 1262619888B a b)c
+--R             + 
+--R                           4                 3
+--R               105218324A b  + 420873296B a b
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                           2 2                   2                2
+--R               882637830A a c  + (1765275660A a b  + 1765275660B a b)c
+--R             + 
+--R                           4                 3
+--R               147106305A b  + 588425220B a b
+--R          *
+--R             m
+--R         + 
+--R                       2 2                  2               2                 4
+--R           436486050A a c  + (872972100A a b  + 872972100B a b)c + 72747675A b
+--R         + 
+--R                         3
+--R           290990700B a b
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                  2        3           3       2 2  9
+--R           ((12A a b + 4B a )c + 4A a b  + 6B a b )m
+--R         + 
+--R                    2          3             3         2 2  8
+--R           ((1116A a b + 372B a )c + 372A a b  + 558B a b )m
+--R         + 
+--R                     2            3               3           2 2  7
+--R           ((44208A a b + 14736B a )c + 14736A a b  + 22104B a b )m
+--R         + 
+--R                      2             3                3            2 2  6
+--R           ((972144A a b + 324048B a )c + 324048A a b  + 486072B a b )m
+--R         + 
+--R                        2              3                 3             2 2  5
+--R           ((12956328A a b + 4318776B a )c + 4318776A a b  + 6478164B a b )m
+--R         + 
+--R                              2               3                  3
+--R                 (107145864A a b + 35715288B a )c + 35715288A a b
+--R               + 
+--R                            2 2
+--R                 53572932B a b
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                            2                3                   3
+--R               (539909232A a b + 179969744B a )c + 179969744A a b
+--R             + 
+--R                           2 2
+--R               269954616B a b
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                             2                3                   3
+--R               (1556406576A a b + 518802192B a )c + 518802192A a b
+--R             + 
+--R                           2 2
+--R               778203288B a b
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                             2                3                   3
+--R               (2234008620A a b + 744669540B a )c + 744669540A a b
+--R             + 
+--R                            2 2
+--R               1117004310B a b
+--R          *
+--R             m
+--R         + 
+--R                       2                3                   3               2 2
+--R         (1122392700A a b + 374130900B a )c + 374130900A a b  + 561196350B a b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R                3        2 2       3   9          3          2 2         3   8
+--R           (4A a c + 6A a b  + 4B a b)m  + (380A a c + 570A a b  + 380B a b)m
+--R         + 
+--R                    3            2 2           3   7
+--R           (15440A a c + 23160A a b  + 15440B a b)m
+--R         + 
+--R                     3             2 2            3   6
+--R           (350000A a c + 525000A a b  + 350000B a b)m
+--R         + 
+--R                      3              2 2             3   5
+--R           (4837112A a c + 7255668A a b  + 4837112B a b)m
+--R         + 
+--R                       3               2 2              3   4
+--R           (41761160A a c + 62641740A a b  + 41761160B a b)m
+--R         + 
+--R                        3                2 2               3   3
+--R           (221170960A a c + 331756440A a b  + 221170960B a b)m
+--R         + 
+--R                        3                 2 2               3   2
+--R           (672735600A a c + 1009103400A a b  + 672735600B a b)m
+--R         + 
+--R                         3                 2 2                3
+--R           (1012606884A a c + 1518910326A a b  + 1012606884B a b)m
+--R         + 
+--R                       3                2 2               3
+--R           523783260A a c + 785674890A a b  + 523783260B a b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R                3       4  9          3         4  8            3           4  7
+--R           (4A a b + B a )m  + (388A a b + 97B a )m  + (16176A a b + 4044B a )m
+--R         + 
+--R                     3            4  6              3              4  5
+--R           (378672A a b + 94668B a )m  + (5451096A a b + 1362774B a )m
+--R         + 
+--R                       3               4  4                3               4  3
+--R           (49593432A a b + 12398358B a )m  + (281196464A a b + 70299116B a )m
+--R         + 
+--R                        3                4  2
+--R           (935001008A a b + 233750252B a )m
+--R         + 
+--R                         3                4                 3                4
+--R           (1571281860A a b + 392820465B a )m + 872972100A a b + 218243025B a
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R              4 9        4 8          4 7            4 6             4 5
+--R           A a m  + 99A a m  + 4236A a m  + 102564A a m  + 1544214A a m
+--R         + 
+--R                      4 4              4 3               4 2               4
+--R           14942466A a m  + 92551724A a m  + 352095876A a m  + 741975345A a m
+--R         + 
+--R                       4
+--R           654729075A a
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R        10       9        8          7           6            5             4
+--R       m   + 100m  + 4335m  + 106800m  + 1646778m  + 16486680m  + 107494190m
+--R     + 
+--R                 3              2
+--R       444647600m  + 1094071221m  + 1396704420m + 654729075
+--R                                                    Type: Expression(Integer)
+--E 2076
+
+--S 2077 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4 9        4 8          4 7           4 6            4 5
+--R             B c m  + 81B c m  + 2796B c m  + 53676B c m  + 626934B c m
+--R           + 
+--R                       4 4              4 3              4 2              4
+--R             4574934B c m  + 20570444B c m  + 53809164B c m  + 71697105B c m
+--R           + 
+--R                        4
+--R             34459425B c
+--R        *
+--R            19
+--R           x
+--R       + 
+--R                 4         3  9         4           3  8
+--R             (A c  + 4B b c )m  + (83A c  + 332B b c )m
+--R           + 
+--R                     4             3  7            4              3  6
+--R             (2924A c  + 11696B b c )m  + (57092A c  + 228368B b c )m
+--R           + 
+--R                       4               3  5              4                3  4
+--R             (676214A c  + 2704856B b c )m  + (4991042A c  + 19964168B b c )m
+--R           + 
+--R                         4                3  3
+--R             (22646476A c  + 90585904B b c )m
+--R           + 
+--R                         4                 3  2
+--R             (59657508A c  + 238630032B b c )m
+--R           + 
+--R                         4                 3                4                 3
+--R             (79893585A c  + 319574340B b c )m + 38513475A c  + 154053900B b c
+--R        *
+--R            17
+--R           x
+--R       + 
+--R                            3       2 2  9                      3         2 2  8
+--R             ((4A b + 4B a)c  + 6B b c )m  + ((340A b + 340B a)c  + 510B b c )m
+--R           + 
+--R                                    3           2 2  7
+--R             ((12240A b + 12240B a)c  + 18360B b c )m
+--R           + 
+--R                                      3            2 2  6
+--R             ((243600A b + 243600B a)c  + 365400B b c )m
+--R           + 
+--R                                        3             2 2  5
+--R             ((2933112A b + 2933112B a)c  + 4399668B b c )m
+--R           + 
+--R                                          3              2 2  4
+--R             ((21950040A b + 21950040B a)c  + 32925060B b c )m
+--R           + 
+--R                                            3               2 2  3
+--R             ((100726160A b + 100726160B a)c  + 151089240B b c )m
+--R           + 
+--R                                            3               2 2  2
+--R             ((267698000A b + 267698000B a)c  + 401547000B b c )m
+--R           + 
+--R                                            3               2 2
+--R             ((360814884A b + 360814884B a)c  + 541222326B b c )m
+--R           + 
+--R                                           3               2 2
+--R             (174594420A b + 174594420B a)c  + 261891630B b c
+--R        *
+--R            15
+--R           x
+--R       + 
+--R                    3        2            2       3   9
+--R             (4A a c  + (6A b  + 12B a b)c  + 4B b c)m
+--R           + 
+--R                      3          2              2         3   8
+--R             (348A a c  + (522A b  + 1044B a b)c  + 348B b c)m
+--R           + 
+--R                        3            2               2           3   7
+--R             (12816A a c  + (19224A b  + 38448B a b)c  + 12816B b c)m
+--R           + 
+--R                         3             2                2            3   6
+--R             (260592A a c  + (390888A b  + 781776B a b)c  + 260592B b c)m
+--R           + 
+--R                          3              2                 2             3   5
+--R             (3199416A a c  + (4799124A b  + 9598248B a b)c  + 3199416B b c)m
+--R           + 
+--R                                3               2                  2
+--R                   24354312A a c  + (36531468A b  + 73062936B a b)c
+--R                 + 
+--R                              3
+--R                   24354312B b c
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                               3                2                   2
+--R                 113370704A a c  + (170056056A b  + 340112112B a b)c
+--R               + 
+--R                             3
+--R                 113370704B b c
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                               3                2                   2
+--R                 304771248A a c  + (457156872A b  + 914313744B a b)c
+--R               + 
+--R                             3
+--R                 304771248B b c
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                               3                2                    2
+--R                 414258660A a c  + (621387990A b  + 1242775980B a b)c
+--R               + 
+--R                             3
+--R                 414258660B b c
+--R            *
+--R               m
+--R           + 
+--R                         3                2                   2               3
+--R           201455100A a c  + (302182650A b  + 604365300B a b)c  + 201455100B b c
+--R        *
+--R            13
+--R           x
+--R       + 
+--R                             2  2        3          2        4  9
+--R             ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )m
+--R           + 
+--R                                 2  2          3            2          4  8
+--R             ((1068A a b + 534B a )c  + (356A b  + 1068B a b )c + 89B b )m
+--R           + 
+--R                                       2  2            3             2
+--R                 (40272A a b + 20136B a )c  + (13424A b  + 40272B a b )c
+--R               + 
+--R                        4
+--R                 3356B b
+--R            *
+--R                7
+--R               m
+--R           + 
+--R                                         2  2             3              2
+--R                 (838608A a b + 419304B a )c  + (279536A b  + 838608B a b )c
+--R               + 
+--R                         4
+--R                 69884B b
+--R            *
+--R                6
+--R               m
+--R           + 
+--R                                            2  2
+--R                 (10536648A a b + 5268324B a )c
+--R               + 
+--R                            3                2              4
+--R                 (3512216A b  + 10536648B a b )c + 878054B b
+--R            *
+--R                5
+--R               m
+--R           + 
+--R                                             2  2
+--R                 (81937032A a b + 40968516B a )c
+--R               + 
+--R                             3                2               4
+--R                 (27312344A b  + 81937032B a b )c + 6828086B b
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                                               2  2
+--R                 (388622928A a b + 194311464B a )c
+--R               + 
+--R                              3                 2                4
+--R                 (129540976A b  + 388622928B a b )c + 32385244B b
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                                                2  2
+--R                 (1060918992A a b + 530459496B a )c
+--R               + 
+--R                              3                  2                4
+--R                 (353639664A b  + 1060918992B a b )c + 88409916B b
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                                                2  2
+--R                 (1458745740A a b + 729372870B a )c
+--R               + 
+--R                              3                  2                 4
+--R                 (486248580A b  + 1458745740B a b )c + 121562145B b
+--R            *
+--R               m
+--R           + 
+--R                                           2  2
+--R             (714249900A a b + 357124950B a )c
+--R           + 
+--R                          3                 2                4
+--R             (238083300A b  + 714249900B a b )c + 59520825B b
+--R        *
+--R            11
+--R           x
+--R       + 
+--R                  2 2           2        2         4         3  9
+--R             (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )m
+--R           + 
+--R                    2 2             2          2           4           3  8
+--R             (546A a c  + (1092A a b  + 1092B a b)c + 91A b  + 364B a b )m
+--R           + 
+--R                         2 2              2           2             4
+--R                 21096A a c  + (42192A a b  + 42192B a b)c + 3516A b
+--R               + 
+--R                           3
+--R                 14064B a b
+--R            *
+--R                7
+--R               m
+--R           + 
+--R                          2 2               2            2              4
+--R                 450936A a c  + (901872A a b  + 901872B a b)c + 75156A b
+--R               + 
+--R                            3
+--R                 300624B a b
+--R            *
+--R                6
+--R               m
+--R           + 
+--R                           2 2                 2              2               4
+--R                 5822244A a c  + (11644488A a b  + 11644488B a b)c + 970374A b
+--R               + 
+--R                             3
+--R                 3881496B a b
+--R            *
+--R                5
+--R               m
+--R           + 
+--R                            2 2                 2              2
+--R                 46519884A a c  + (93039768A a b  + 93039768B a b)c
+--R               + 
+--R                           4                3
+--R                 7753314A b  + 31013256B a b
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                             2 2                  2               2
+--R                 226286184A a c  + (452572368A a b  + 452572368B a b)c
+--R               + 
+--R                            4                 3
+--R                 37714364A b  + 150857456B a b
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                             2 2                   2                2
+--R                 631309944A a c  + (1262619888A a b  + 1262619888B a b)c
+--R               + 
+--R                             4                 3
+--R                 105218324A b  + 420873296B a b
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                             2 2                   2                2
+--R                 882637830A a c  + (1765275660A a b  + 1765275660B a b)c
+--R               + 
+--R                             4                 3
+--R                 147106305A b  + 588425220B a b
+--R            *
+--R               m
+--R           + 
+--R                         2 2                  2               2
+--R             436486050A a c  + (872972100A a b  + 872972100B a b)c
+--R           + 
+--R                        4                 3
+--R             72747675A b  + 290990700B a b
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                    2        3           3       2 2  9
+--R             ((12A a b + 4B a )c + 4A a b  + 6B a b )m
+--R           + 
+--R                      2          3             3         2 2  8
+--R             ((1116A a b + 372B a )c + 372A a b  + 558B a b )m
+--R           + 
+--R                       2            3               3           2 2  7
+--R             ((44208A a b + 14736B a )c + 14736A a b  + 22104B a b )m
+--R           + 
+--R                        2             3                3            2 2  6
+--R             ((972144A a b + 324048B a )c + 324048A a b  + 486072B a b )m
+--R           + 
+--R                          2              3                 3             2 2  5
+--R             ((12956328A a b + 4318776B a )c + 4318776A a b  + 6478164B a b )m
+--R           + 
+--R                              2               3                  3
+--R                 (107145864A a b + 35715288B a )c + 35715288A a b
+--R               + 
+--R                            2 2
+--R                 53572932B a b
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                              2                3                   3
+--R                 (539909232A a b + 179969744B a )c + 179969744A a b
+--R               + 
+--R                             2 2
+--R                 269954616B a b
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                               2                3                   3
+--R                 (1556406576A a b + 518802192B a )c + 518802192A a b
+--R               + 
+--R                             2 2
+--R                 778203288B a b
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                               2                3                   3
+--R                 (2234008620A a b + 744669540B a )c + 744669540A a b
+--R               + 
+--R                              2 2
+--R                 1117004310B a b
+--R            *
+--R               m
+--R           + 
+--R                           2                3                   3
+--R             (1122392700A a b + 374130900B a )c + 374130900A a b
+--R           + 
+--R                         2 2
+--R             561196350B a b
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                  3        2 2       3   9          3          2 2         3   8
+--R             (4A a c + 6A a b  + 4B a b)m  + (380A a c + 570A a b  + 380B a b)m
+--R           + 
+--R                      3            2 2           3   7
+--R             (15440A a c + 23160A a b  + 15440B a b)m
+--R           + 
+--R                       3             2 2            3   6
+--R             (350000A a c + 525000A a b  + 350000B a b)m
+--R           + 
+--R                        3              2 2             3   5
+--R             (4837112A a c + 7255668A a b  + 4837112B a b)m
+--R           + 
+--R                         3               2 2              3   4
+--R             (41761160A a c + 62641740A a b  + 41761160B a b)m
+--R           + 
+--R                          3                2 2               3   3
+--R             (221170960A a c + 331756440A a b  + 221170960B a b)m
+--R           + 
+--R                          3                 2 2               3   2
+--R             (672735600A a c + 1009103400A a b  + 672735600B a b)m
+--R           + 
+--R                           3                 2 2                3
+--R             (1012606884A a c + 1518910326A a b  + 1012606884B a b)m
+--R           + 
+--R                         3                2 2               3
+--R             523783260A a c + 785674890A a b  + 523783260B a b
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                  3       4  9          3         4  8
+--R             (4A a b + B a )m  + (388A a b + 97B a )m
+--R           + 
+--R                      3           4  7             3            4  6
+--R             (16176A a b + 4044B a )m  + (378672A a b + 94668B a )m
+--R           + 
+--R                        3              4  5               3               4  4
+--R             (5451096A a b + 1362774B a )m  + (49593432A a b + 12398358B a )m
+--R           + 
+--R                          3               4  3
+--R             (281196464A a b + 70299116B a )m
+--R           + 
+--R                          3                4  2
+--R             (935001008A a b + 233750252B a )m
+--R           + 
+--R                         3                4                 3                4
+--R           (1571281860A a b + 392820465B a )m + 872972100A a b + 218243025B a
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                4 9        4 8          4 7            4 6             4 5
+--R             A a m  + 99A a m  + 4236A a m  + 102564A a m  + 1544214A a m
+--R           + 
+--R                        4 4              4 3               4 2               4
+--R             14942466A a m  + 92551724A a m  + 352095876A a m  + 741975345A a m
+--R           + 
+--R                         4
+--R             654729075A a
+--R        *
+--R           x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R        10       9        8          7           6            5             4
+--R       m   + 100m  + 4335m  + 106800m  + 1646778m  + 16486680m  + 107494190m
+--R     + 
+--R                 3              2
+--R       444647600m  + 1094071221m  + 1396704420m + 654729075
+--R                                         Type: Union(Expression(Integer),...)
+--E 2077
+
+--S 2078 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  4 9        4 8          4 7           4 6            4 5
+--R               B c m  + 81B c m  + 2796B c m  + 53676B c m  + 626934B c m
+--R             + 
+--R                         4 4              4 3              4 2              4
+--R               4574934B c m  + 20570444B c m  + 53809164B c m  + 71697105B c m
+--R             + 
+--R                          4
+--R               34459425B c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                   4         3  9         4           3  8
+--R               (A c  + 4B b c )m  + (83A c  + 332B b c )m
+--R             + 
+--R                       4             3  7            4              3  6
+--R               (2924A c  + 11696B b c )m  + (57092A c  + 228368B b c )m
+--R             + 
+--R                         4               3  5              4                3  4
+--R               (676214A c  + 2704856B b c )m  + (4991042A c  + 19964168B b c )m
+--R             + 
+--R                           4                3  3
+--R               (22646476A c  + 90585904B b c )m
+--R             + 
+--R                           4                 3  2
+--R               (59657508A c  + 238630032B b c )m
+--R             + 
+--R                         4                 3                4                 3
+--R             (79893585A c  + 319574340B b c )m + 38513475A c  + 154053900B b c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                              3       2 2  9
+--R               ((4A b + 4B a)c  + 6B b c )m
+--R             + 
+--R                                  3         2 2  8
+--R               ((340A b + 340B a)c  + 510B b c )m
+--R             + 
+--R                                      3           2 2  7
+--R               ((12240A b + 12240B a)c  + 18360B b c )m
+--R             + 
+--R                                        3            2 2  6
+--R               ((243600A b + 243600B a)c  + 365400B b c )m
+--R             + 
+--R                                          3             2 2  5
+--R               ((2933112A b + 2933112B a)c  + 4399668B b c )m
+--R             + 
+--R                                            3              2 2  4
+--R               ((21950040A b + 21950040B a)c  + 32925060B b c )m
+--R             + 
+--R                                              3               2 2  3
+--R               ((100726160A b + 100726160B a)c  + 151089240B b c )m
+--R             + 
+--R                                              3               2 2  2
+--R               ((267698000A b + 267698000B a)c  + 401547000B b c )m
+--R             + 
+--R                                              3               2 2
+--R               ((360814884A b + 360814884B a)c  + 541222326B b c )m
+--R             + 
+--R                                             3               2 2
+--R               (174594420A b + 174594420B a)c  + 261891630B b c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                      3        2            2       3   9
+--R               (4A a c  + (6A b  + 12B a b)c  + 4B b c)m
+--R             + 
+--R                        3          2              2         3   8
+--R               (348A a c  + (522A b  + 1044B a b)c  + 348B b c)m
+--R             + 
+--R                          3            2               2           3   7
+--R               (12816A a c  + (19224A b  + 38448B a b)c  + 12816B b c)m
+--R             + 
+--R                           3             2                2            3   6
+--R               (260592A a c  + (390888A b  + 781776B a b)c  + 260592B b c)m
+--R             + 
+--R                            3              2                 2             3   5
+--R               (3199416A a c  + (4799124A b  + 9598248B a b)c  + 3199416B b c)m
+--R             + 
+--R                                3               2                  2
+--R                   24354312A a c  + (36531468A b  + 73062936B a b)c
+--R                 + 
+--R                              3
+--R                   24354312B b c
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                                 3                2                   2
+--R                   113370704A a c  + (170056056A b  + 340112112B a b)c
+--R                 + 
+--R                               3
+--R                   113370704B b c
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                                 3                2                   2
+--R                   304771248A a c  + (457156872A b  + 914313744B a b)c
+--R                 + 
+--R                               3
+--R                   304771248B b c
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                                 3                2                    2
+--R                   414258660A a c  + (621387990A b  + 1242775980B a b)c
+--R                 + 
+--R                               3
+--R                   414258660B b c
+--R              *
+--R                 m
+--R             + 
+--R                             3                2                   2
+--R               201455100A a c  + (302182650A b  + 604365300B a b)c
+--R             + 
+--R                           3
+--R               201455100B b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                               2  2        3          2        4  9
+--R               ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )m
+--R             + 
+--R                                   2  2          3            2          4  8
+--R               ((1068A a b + 534B a )c  + (356A b  + 1068B a b )c + 89B b )m
+--R             + 
+--R                                         2  2            3             2
+--R                   (40272A a b + 20136B a )c  + (13424A b  + 40272B a b )c
+--R                 + 
+--R                          4
+--R                   3356B b
+--R              *
+--R                  7
+--R                 m
+--R             + 
+--R                                           2  2             3              2
+--R                   (838608A a b + 419304B a )c  + (279536A b  + 838608B a b )c
+--R                 + 
+--R                           4
+--R                   69884B b
+--R              *
+--R                  6
+--R                 m
+--R             + 
+--R                                              2  2
+--R                   (10536648A a b + 5268324B a )c
+--R                 + 
+--R                              3                2              4
+--R                   (3512216A b  + 10536648B a b )c + 878054B b
+--R              *
+--R                  5
+--R                 m
+--R             + 
+--R                                               2  2
+--R                   (81937032A a b + 40968516B a )c
+--R                 + 
+--R                               3                2               4
+--R                   (27312344A b  + 81937032B a b )c + 6828086B b
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                                                 2  2
+--R                   (388622928A a b + 194311464B a )c
+--R                 + 
+--R                                3                 2                4
+--R                   (129540976A b  + 388622928B a b )c + 32385244B b
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                                                  2  2
+--R                   (1060918992A a b + 530459496B a )c
+--R                 + 
+--R                                3                  2                4
+--R                   (353639664A b  + 1060918992B a b )c + 88409916B b
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                                                  2  2
+--R                   (1458745740A a b + 729372870B a )c
+--R                 + 
+--R                                3                  2                 4
+--R                   (486248580A b  + 1458745740B a b )c + 121562145B b
+--R              *
+--R                 m
+--R             + 
+--R                                             2  2
+--R               (714249900A a b + 357124950B a )c
+--R             + 
+--R                            3                 2                4
+--R               (238083300A b  + 714249900B a b )c + 59520825B b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                    2 2           2        2         4         3  9
+--R               (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )m
+--R             + 
+--R                      2 2             2          2           4           3  8
+--R               (546A a c  + (1092A a b  + 1092B a b)c + 91A b  + 364B a b )m
+--R             + 
+--R                           2 2              2           2             4
+--R                   21096A a c  + (42192A a b  + 42192B a b)c + 3516A b
+--R                 + 
+--R                             3
+--R                   14064B a b
+--R              *
+--R                  7
+--R                 m
+--R             + 
+--R                            2 2               2            2              4
+--R                   450936A a c  + (901872A a b  + 901872B a b)c + 75156A b
+--R                 + 
+--R                              3
+--R                   300624B a b
+--R              *
+--R                  6
+--R                 m
+--R             + 
+--R                             2 2                 2              2
+--R                   5822244A a c  + (11644488A a b  + 11644488B a b)c
+--R                 + 
+--R                            4               3
+--R                   970374A b  + 3881496B a b
+--R              *
+--R                  5
+--R                 m
+--R             + 
+--R                              2 2                 2              2
+--R                   46519884A a c  + (93039768A a b  + 93039768B a b)c
+--R                 + 
+--R                             4                3
+--R                   7753314A b  + 31013256B a b
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                               2 2                  2               2
+--R                   226286184A a c  + (452572368A a b  + 452572368B a b)c
+--R                 + 
+--R                              4                 3
+--R                   37714364A b  + 150857456B a b
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                               2 2                   2                2
+--R                   631309944A a c  + (1262619888A a b  + 1262619888B a b)c
+--R                 + 
+--R                               4                 3
+--R                   105218324A b  + 420873296B a b
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                               2 2                   2                2
+--R                   882637830A a c  + (1765275660A a b  + 1765275660B a b)c
+--R                 + 
+--R                               4                 3
+--R                   147106305A b  + 588425220B a b
+--R              *
+--R                 m
+--R             + 
+--R                           2 2                  2               2
+--R               436486050A a c  + (872972100A a b  + 872972100B a b)c
+--R             + 
+--R                          4                 3
+--R               72747675A b  + 290990700B a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                      2        3           3       2 2  9
+--R               ((12A a b + 4B a )c + 4A a b  + 6B a b )m
+--R             + 
+--R                        2          3             3         2 2  8
+--R               ((1116A a b + 372B a )c + 372A a b  + 558B a b )m
+--R             + 
+--R                         2            3               3           2 2  7
+--R               ((44208A a b + 14736B a )c + 14736A a b  + 22104B a b )m
+--R             + 
+--R                          2             3                3            2 2  6
+--R               ((972144A a b + 324048B a )c + 324048A a b  + 486072B a b )m
+--R             + 
+--R                                 2              3                 3
+--R                     (12956328A a b + 4318776B a )c + 4318776A a b
+--R                   + 
+--R                               2 2
+--R                     6478164B a b
+--R              *
+--R                  5
+--R                 m
+--R             + 
+--R                                2               3                  3
+--R                   (107145864A a b + 35715288B a )c + 35715288A a b
+--R                 + 
+--R                              2 2
+--R                   53572932B a b
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                                2                3                   3
+--R                   (539909232A a b + 179969744B a )c + 179969744A a b
+--R                 + 
+--R                               2 2
+--R                   269954616B a b
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                                 2                3                   3
+--R                   (1556406576A a b + 518802192B a )c + 518802192A a b
+--R                 + 
+--R                               2 2
+--R                   778203288B a b
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                                 2                3                   3
+--R                   (2234008620A a b + 744669540B a )c + 744669540A a b
+--R                 + 
+--R                                2 2
+--R                   1117004310B a b
+--R              *
+--R                 m
+--R             + 
+--R                             2                3                   3
+--R               (1122392700A a b + 374130900B a )c + 374130900A a b
+--R             + 
+--R                           2 2
+--R               561196350B a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                    3        2 2       3   9
+--R               (4A a c + 6A a b  + 4B a b)m
+--R             + 
+--R                      3          2 2         3   8
+--R               (380A a c + 570A a b  + 380B a b)m
+--R             + 
+--R                        3            2 2           3   7
+--R               (15440A a c + 23160A a b  + 15440B a b)m
+--R             + 
+--R                         3             2 2            3   6
+--R               (350000A a c + 525000A a b  + 350000B a b)m
+--R             + 
+--R                          3              2 2             3   5
+--R               (4837112A a c + 7255668A a b  + 4837112B a b)m
+--R             + 
+--R                           3               2 2              3   4
+--R               (41761160A a c + 62641740A a b  + 41761160B a b)m
+--R             + 
+--R                            3                2 2               3   3
+--R               (221170960A a c + 331756440A a b  + 221170960B a b)m
+--R             + 
+--R                            3                 2 2               3   2
+--R               (672735600A a c + 1009103400A a b  + 672735600B a b)m
+--R             + 
+--R                             3                 2 2                3
+--R               (1012606884A a c + 1518910326A a b  + 1012606884B a b)m
+--R             + 
+--R                           3                2 2               3
+--R               523783260A a c + 785674890A a b  + 523783260B a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    3       4  9          3         4  8
+--R               (4A a b + B a )m  + (388A a b + 97B a )m
+--R             + 
+--R                        3           4  7             3            4  6
+--R               (16176A a b + 4044B a )m  + (378672A a b + 94668B a )m
+--R             + 
+--R                          3              4  5               3               4  4
+--R               (5451096A a b + 1362774B a )m  + (49593432A a b + 12398358B a )m
+--R             + 
+--R                            3               4  3
+--R               (281196464A a b + 70299116B a )m
+--R             + 
+--R                            3                4  2
+--R               (935001008A a b + 233750252B a )m
+--R             + 
+--R                           3                4                 3                4
+--R             (1571281860A a b + 392820465B a )m + 872972100A a b + 218243025B a
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  4 9        4 8          4 7            4 6             4 5
+--R               A a m  + 99A a m  + 4236A a m  + 102564A a m  + 1544214A a m
+--R             + 
+--R                          4 4              4 3               4 2
+--R               14942466A a m  + 92551724A a m  + 352095876A a m
+--R             + 
+--R                           4                4
+--R               741975345A a m + 654729075A a
+--R          *
+--R             x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R                4 9        4 8          4 7           4 6            4 5
+--R           - B c m  - 81B c m  - 2796B c m  - 53676B c m  - 626934B c m
+--R         + 
+--R                       4 4              4 3              4 2              4
+--R           - 4574934B c m  - 20570444B c m  - 53809164B c m  - 71697105B c m
+--R         + 
+--R                        4
+--R           - 34459425B c
+--R      *
+--R          m + 19
+--R         x
+--R     + 
+--R                 4         3  9           4           3  8
+--R           (- A c  - 4B b c )m  + (- 83A c  - 332B b c )m
+--R         + 
+--R                     4             3  7              4              3  6
+--R           (- 2924A c  - 11696B b c )m  + (- 57092A c  - 228368B b c )m
+--R         + 
+--R                       4               3  5                4                3  4
+--R           (- 676214A c  - 2704856B b c )m  + (- 4991042A c  - 19964168B b c )m
+--R         + 
+--R                         4                3  3
+--R           (- 22646476A c  - 90585904B b c )m
+--R         + 
+--R                         4                 3  2
+--R           (- 59657508A c  - 238630032B b c )m
+--R         + 
+--R                         4                 3                4                 3
+--R           (- 79893585A c  - 319574340B b c )m - 38513475A c  - 154053900B b c
+--R      *
+--R          m + 17
+--R         x
+--R     + 
+--R                            3       2 2  9
+--R           ((- 4A b - 4B a)c  - 6B b c )m
+--R         + 
+--R                                3         2 2  8
+--R           ((- 340A b - 340B a)c  - 510B b c )m
+--R         + 
+--R                                    3           2 2  7
+--R           ((- 12240A b - 12240B a)c  - 18360B b c )m
+--R         + 
+--R                                      3            2 2  6
+--R           ((- 243600A b - 243600B a)c  - 365400B b c )m
+--R         + 
+--R                                        3             2 2  5
+--R           ((- 2933112A b - 2933112B a)c  - 4399668B b c )m
+--R         + 
+--R                                          3              2 2  4
+--R           ((- 21950040A b - 21950040B a)c  - 32925060B b c )m
+--R         + 
+--R                                            3               2 2  3
+--R           ((- 100726160A b - 100726160B a)c  - 151089240B b c )m
+--R         + 
+--R                                            3               2 2  2
+--R           ((- 267698000A b - 267698000B a)c  - 401547000B b c )m
+--R         + 
+--R                                            3               2 2
+--R           ((- 360814884A b - 360814884B a)c  - 541222326B b c )m
+--R         + 
+--R                                           3               2 2
+--R           (- 174594420A b - 174594420B a)c  - 261891630B b c
+--R      *
+--R          m + 15
+--R         x
+--R     + 
+--R                    3          2            2       3   9
+--R           (- 4A a c  + (- 6A b  - 12B a b)c  - 4B b c)m
+--R         + 
+--R                      3            2              2         3   8
+--R           (- 348A a c  + (- 522A b  - 1044B a b)c  - 348B b c)m
+--R         + 
+--R                        3              2               2           3   7
+--R           (- 12816A a c  + (- 19224A b  - 38448B a b)c  - 12816B b c)m
+--R         + 
+--R                         3               2                2            3   6
+--R           (- 260592A a c  + (- 390888A b  - 781776B a b)c  - 260592B b c)m
+--R         + 
+--R                          3                2                 2             3   5
+--R           (- 3199416A a c  + (- 4799124A b  - 9598248B a b)c  - 3199416B b c)m
+--R         + 
+--R                              3                 2                  2
+--R               - 24354312A a c  + (- 36531468A b  - 73062936B a b)c
+--R             + 
+--R                            3
+--R               - 24354312B b c
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                               3                  2                   2
+--R               - 113370704A a c  + (- 170056056A b  - 340112112B a b)c
+--R             + 
+--R                             3
+--R               - 113370704B b c
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                               3                  2                   2
+--R               - 304771248A a c  + (- 457156872A b  - 914313744B a b)c
+--R             + 
+--R                             3
+--R               - 304771248B b c
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                               3                  2                    2
+--R               - 414258660A a c  + (- 621387990A b  - 1242775980B a b)c
+--R             + 
+--R                             3
+--R               - 414258660B b c
+--R          *
+--R             m
+--R         + 
+--R                           3                  2                   2
+--R           - 201455100A a c  + (- 302182650A b  - 604365300B a b)c
+--R         + 
+--R                         3
+--R           - 201455100B b c
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                             2  2          3          2        4  9
+--R           ((- 12A a b - 6B a )c  + (- 4A b  - 12B a b )c - B b )m
+--R         + 
+--R                                 2  2            3            2          4  8
+--R           ((- 1068A a b - 534B a )c  + (- 356A b  - 1068B a b )c - 89B b )m
+--R         + 
+--R                                       2  2              3             2
+--R               (- 40272A a b - 20136B a )c  + (- 13424A b  - 40272B a b )c
+--R             + 
+--R                        4
+--R               - 3356B b
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                                         2  2               3              2
+--R               (- 838608A a b - 419304B a )c  + (- 279536A b  - 838608B a b )c
+--R             + 
+--R                         4
+--R               - 69884B b
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                                            2  2
+--R               (- 10536648A a b - 5268324B a )c
+--R             + 
+--R                            3                2              4
+--R               (- 3512216A b  - 10536648B a b )c - 878054B b
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                                             2  2
+--R               (- 81937032A a b - 40968516B a )c
+--R             + 
+--R                             3                2               4
+--R               (- 27312344A b  - 81937032B a b )c - 6828086B b
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                                               2  2
+--R               (- 388622928A a b - 194311464B a )c
+--R             + 
+--R                              3                 2                4
+--R               (- 129540976A b  - 388622928B a b )c - 32385244B b
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                                                2  2
+--R               (- 1060918992A a b - 530459496B a )c
+--R             + 
+--R                              3                  2                4
+--R               (- 353639664A b  - 1060918992B a b )c - 88409916B b
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                                                2  2
+--R               (- 1458745740A a b - 729372870B a )c
+--R             + 
+--R                              3                  2                 4
+--R               (- 486248580A b  - 1458745740B a b )c - 121562145B b
+--R          *
+--R             m
+--R         + 
+--R                                           2  2
+--R           (- 714249900A a b - 357124950B a )c
+--R         + 
+--R                          3                 2                4
+--R           (- 238083300A b  - 714249900B a b )c - 59520825B b
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                  2 2             2        2         4         3  9
+--R           (- 6A a c  + (- 12A a b  - 12B a b)c - A b  - 4B a b )m
+--R         + 
+--R                    2 2               2          2           4           3  8
+--R           (- 546A a c  + (- 1092A a b  - 1092B a b)c - 91A b  - 364B a b )m
+--R         + 
+--R                         2 2                2           2             4
+--R               - 21096A a c  + (- 42192A a b  - 42192B a b)c - 3516A b
+--R             + 
+--R                           3
+--R               - 14064B a b
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                          2 2                 2            2              4
+--R               - 450936A a c  + (- 901872A a b  - 901872B a b)c - 75156A b
+--R             + 
+--R                            3
+--R               - 300624B a b
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                           2 2                   2              2
+--R               - 5822244A a c  + (- 11644488A a b  - 11644488B a b)c
+--R             + 
+--R                          4               3
+--R               - 970374A b  - 3881496B a b
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                            2 2                   2              2
+--R               - 46519884A a c  + (- 93039768A a b  - 93039768B a b)c
+--R             + 
+--R                           4                3
+--R               - 7753314A b  - 31013256B a b
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                             2 2                    2               2
+--R               - 226286184A a c  + (- 452572368A a b  - 452572368B a b)c
+--R             + 
+--R                            4                 3
+--R               - 37714364A b  - 150857456B a b
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                             2 2                     2                2
+--R               - 631309944A a c  + (- 1262619888A a b  - 1262619888B a b)c
+--R             + 
+--R                             4                 3
+--R               - 105218324A b  - 420873296B a b
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                             2 2                     2                2
+--R               - 882637830A a c  + (- 1765275660A a b  - 1765275660B a b)c
+--R             + 
+--R                             4                 3
+--R               - 147106305A b  - 588425220B a b
+--R          *
+--R             m
+--R         + 
+--R                         2 2                    2               2
+--R           - 436486050A a c  + (- 872972100A a b  - 872972100B a b)c
+--R         + 
+--R                        4                 3
+--R           - 72747675A b  - 290990700B a b
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                    2        3           3       2 2  9
+--R           ((- 12A a b - 4B a )c - 4A a b  - 6B a b )m
+--R         + 
+--R                      2          3             3         2 2  8
+--R           ((- 1116A a b - 372B a )c - 372A a b  - 558B a b )m
+--R         + 
+--R                       2            3               3           2 2  7
+--R           ((- 44208A a b - 14736B a )c - 14736A a b  - 22104B a b )m
+--R         + 
+--R                        2             3                3            2 2  6
+--R           ((- 972144A a b - 324048B a )c - 324048A a b  - 486072B a b )m
+--R         + 
+--R                          2              3                 3             2 2  5
+--R           ((- 12956328A a b - 4318776B a )c - 4318776A a b  - 6478164B a b )m
+--R         + 
+--R                              2               3                  3
+--R               (- 107145864A a b - 35715288B a )c - 35715288A a b
+--R             + 
+--R                            2 2
+--R               - 53572932B a b
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                              2                3                   3
+--R               (- 539909232A a b - 179969744B a )c - 179969744A a b
+--R             + 
+--R                             2 2
+--R               - 269954616B a b
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                               2                3                   3
+--R               (- 1556406576A a b - 518802192B a )c - 518802192A a b
+--R             + 
+--R                             2 2
+--R               - 778203288B a b
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                               2                3                   3
+--R               (- 2234008620A a b - 744669540B a )c - 744669540A a b
+--R             + 
+--R                              2 2
+--R               - 1117004310B a b
+--R          *
+--R             m
+--R         + 
+--R                           2                3                   3
+--R           (- 1122392700A a b - 374130900B a )c - 374130900A a b
+--R         + 
+--R                         2 2
+--R           - 561196350B a b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R                  3        2 2       3   9
+--R           (- 4A a c - 6A a b  - 4B a b)m
+--R         + 
+--R                    3          2 2         3   8
+--R           (- 380A a c - 570A a b  - 380B a b)m
+--R         + 
+--R                      3            2 2           3   7
+--R           (- 15440A a c - 23160A a b  - 15440B a b)m
+--R         + 
+--R                       3             2 2            3   6
+--R           (- 350000A a c - 525000A a b  - 350000B a b)m
+--R         + 
+--R                        3              2 2             3   5
+--R           (- 4837112A a c - 7255668A a b  - 4837112B a b)m
+--R         + 
+--R                         3               2 2              3   4
+--R           (- 41761160A a c - 62641740A a b  - 41761160B a b)m
+--R         + 
+--R                          3                2 2               3   3
+--R           (- 221170960A a c - 331756440A a b  - 221170960B a b)m
+--R         + 
+--R                          3                 2 2               3   2
+--R           (- 672735600A a c - 1009103400A a b  - 672735600B a b)m
+--R         + 
+--R                           3                 2 2                3
+--R           (- 1012606884A a c - 1518910326A a b  - 1012606884B a b)m
+--R         + 
+--R                         3                2 2               3
+--R           - 523783260A a c - 785674890A a b  - 523783260B a b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R                  3       4  9            3         4  8
+--R           (- 4A a b - B a )m  + (- 388A a b - 97B a )m
+--R         + 
+--R                      3           4  7               3            4  6
+--R           (- 16176A a b - 4044B a )m  + (- 378672A a b - 94668B a )m
+--R         + 
+--R                        3              4  5                 3               4  4
+--R           (- 5451096A a b - 1362774B a )m  + (- 49593432A a b - 12398358B a )m
+--R         + 
+--R                          3               4  3
+--R           (- 281196464A a b - 70299116B a )m
+--R         + 
+--R                          3                4  2
+--R           (- 935001008A a b - 233750252B a )m
+--R         + 
+--R                         3                4                 3                4
+--R         (- 1571281860A a b - 392820465B a )m - 872972100A a b - 218243025B a
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R                4 9        4 8          4 7            4 6             4 5
+--R           - A a m  - 99A a m  - 4236A a m  - 102564A a m  - 1544214A a m
+--R         + 
+--R                        4 4              4 3               4 2               4
+--R           - 14942466A a m  - 92551724A a m  - 352095876A a m  - 741975345A a m
+--R         + 
+--R                         4
+--R           - 654729075A a
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R        10       9        8          7           6            5             4
+--R       m   + 100m  + 4335m  + 106800m  + 1646778m  + 16486680m  + 107494190m
+--R     + 
+--R                 3              2
+--R       444647600m  + 1094071221m  + 1396704420m + 654729075
+--R                                                    Type: Expression(Integer)
+--E 2078
+
+--S 2079 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            4 18       4         3  16                  3       2 2  14
+--R         B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R       + 
+--R                3        2            2       3   12
+--R         (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R       + 
+--R                         2  2        3          2        4  10
+--R         ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R       + 
+--R              2 2           2        2         4         3  8
+--R         (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R       + 
+--R                2        3           3       2 2  6
+--R         ((12A a b + 4B a )c + 4A a b  + 6B a b )x
+--R       + 
+--R              3        2 2       3   4        3       4  2      4
+--R         (4A a c + 6A a b  + 4B a b)x  + (4A a b + B a )x  + A a
+--R    *
+--R         m log(x)
+--R       %e
+--R   + 
+--R          4 m + 18         4         3  m + 16
+--R     - B c x       + (- A c  - 4B b c )x
+--R   + 
+--R                      3       2 2  m + 14
+--R     ((- 4A b - 4B a)c  - 6B b c )x
+--R   + 
+--R              3          2            2       3   m + 12
+--R     (- 4A a c  + (- 6A b  - 12B a b)c  - 4B b c)x
+--R   + 
+--R                       2  2          3          2        4  m + 10
+--R     ((- 12A a b - 6B a )c  + (- 4A b  - 12B a b )c - B b )x
+--R   + 
+--R            2 2             2        2         4         3  m + 8
+--R     (- 6A a c  + (- 12A a b  - 12B a b)c - A b  - 4B a b )x
+--R   + 
+--R              2        3           3       2 2  m + 6
+--R     ((- 12A a b - 4B a )c - 4A a b  - 6B a b )x
+--R   + 
+--R            3        2 2       3   m + 4          3       4  m + 2      4 m
+--R     (- 4A a c - 6A a b  - 4B a b)x      + (- 4A a b - B a )x      - A a x
+--R                                                    Type: Expression(Integer)
+--E 2079
+
+)clear all
+
+--S 2080 of 3139
+t0:=x^3*(A+B*x^2)*(a+b*x^2+c*x^4)^4
+--R 
+--R
+--R   (1)
+--R        4 21       4         3  19                  3       2 2  17
+--R     B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R   + 
+--R            3        2            2       3   15
+--R     (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R   + 
+--R                     2  2        3          2        4  13
+--R     ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R   + 
+--R          2 2           2        2         4         3  11
+--R     (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R   + 
+--R            2        3           3       2 2  9        3        2 2       3   7
+--R     ((12A a b + 4B a )c + 4A a b  + 6B a b )x  + (4A a c + 6A a b  + 4B a b)x
+--R   + 
+--R          3       4  5      4 3
+--R     (4A a b + B a )x  + A a x
+--R                                                    Type: Polynomial(Integer)
+--E 2080
+
+--S 2081 of 3139
+r0:=1/4*a^4*A*x^4+1/6*a^3*(4*A*b+a*B)*x^6+1/4*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*_
+   x^8+1/5*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^10+1/12*(4*a*b*B*(b^2+_
+   3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^12+1/14*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^14+1/8*c*(2*b^3*B+3*A*b^2*c+_
+   6*a*b*B*c+2*a*A*c^2)*x^16+1/9*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^18+_
+   1/20*c^3*(4*b*B+A*c)*x^20+1/22*B*c^4*x^22
+--R 
+--R
+--R   (2)
+--R      1    4 22     1    4   1      3  20     2       2      3   1    2 2  18
+--R     -- B c x   + (-- A c  + - B b c )x   + ((- A b + - B a)c  + - B b c )x
+--R     22            20        5                9       9          3
+--R   + 
+--R      1      3    3    2   3        2   1    3   16
+--R     (- A a c  + (- A b  + - B a b)c  + - B b c)x
+--R      4           8        4            4
+--R   + 
+--R       6         3    2  2    2    3   6      2      1    4  14
+--R     ((- A a b + - B a )c  + (- A b  + - B a b )c + -- B b )x
+--R       7         7            7        7            14
+--R   + 
+--R      1    2 2         2      2       1    4   1      3  12
+--R     (- A a c  + (A a b  + B a b)c + -- A b  + - B a b )x
+--R      2                              12        3
+--R   + 
+--R       6    2    2    3     2      3   3    2 2  10
+--R     ((- A a b + - B a )c + - A a b  + - B a b )x
+--R       5         5          5          5
+--R   + 
+--R      1    3    3    2 2   1    3   8    2    3    1    4  6   1    4 4
+--R     (- A a c + - A a b  + - B a b)x  + (- A a b + - B a )x  + - A a x
+--R      2         4          2             3         6           4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2081
+
+--S 2082 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    4 22     1    4   1      3  20     2       2      3   1    2 2  18
+--R     -- B c x   + (-- A c  + - B b c )x   + ((- A b + - B a)c  + - B b c )x
+--R     22            20        5                9       9          3
+--R   + 
+--R      1      3    3    2   3        2   1    3   16
+--R     (- A a c  + (- A b  + - B a b)c  + - B b c)x
+--R      4           8        4            4
+--R   + 
+--R       6         3    2  2    2    3   6      2      1    4  14
+--R     ((- A a b + - B a )c  + (- A b  + - B a b )c + -- B b )x
+--R       7         7            7        7            14
+--R   + 
+--R      1    2 2         2      2       1    4   1      3  12
+--R     (- A a c  + (A a b  + B a b)c + -- A b  + - B a b )x
+--R      2                              12        3
+--R   + 
+--R       6    2    2    3     2      3   3    2 2  10
+--R     ((- A a b + - B a )c + - A a b  + - B a b )x
+--R       5         5          5          5
+--R   + 
+--R      1    3    3    2 2   1    3   8    2    3    1    4  6   1    4 4
+--R     (- A a c + - A a b  + - B a b)x  + (- A a b + - B a )x  + - A a x
+--R      2         4          2             3         6           4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2082
+
+--S 2083 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2083
+
+--S 2084 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2084
+
+)clear all
+
+--S 2085 of 3139
+t0:=x^2*(A+B*x^2)*(a+b*x^2+c*x^4)^4
+--R 
+--R
+--R   (1)
+--R        4 20       4         3  18                  3       2 2  16
+--R     B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R   + 
+--R            3        2            2       3   14
+--R     (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R   + 
+--R                     2  2        3          2        4  12
+--R     ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R   + 
+--R          2 2           2        2         4         3  10
+--R     (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R   + 
+--R            2        3           3       2 2  8        3        2 2       3   6
+--R     ((12A a b + 4B a )c + 4A a b  + 6B a b )x  + (4A a c + 6A a b  + 4B a b)x
+--R   + 
+--R          3       4  4      4 2
+--R     (4A a b + B a )x  + A a x
+--R                                                    Type: Polynomial(Integer)
+--E 2085
+
+--S 2086 of 3139
+r0:=1/3*a^4*A*x^3+1/5*a^3*(4*A*b+a*B)*x^5+2/7*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*_
+   x^7+2/9*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^9+1/11*(4*a*b*B*(b^2+_
+   3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^11+1/13*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^13+2/15*c*(2*b^3*B+_
+   3*A*b^2*c+6*a*b*B*c+2*a*A*c^2)*x^15+2/17*c^2*(3*b^2*B+2*A*b*c+_
+   2*a*B*c)*x^17+1/19*c^3*(4*b*B+A*c)*x^19+1/21*B*c^4*x^21
+--R 
+--R
+--R   (2)
+--R      1    4 21     1    4    4      3  19
+--R     -- B c x   + (-- A c  + -- B b c )x
+--R     21            19        19
+--R   + 
+--R        4        4      3    6    2 2  17
+--R     ((-- A b + -- B a)c  + -- B b c )x
+--R       17       17          17
+--R   + 
+--R       4      3    2    2   4        2    4    3   15
+--R     (-- A a c  + (- A b  + - B a b)c  + -- B b c)x
+--R      15           5        5            15
+--R   + 
+--R       12          6    2  2     4    3   12      2      1    4  13
+--R     ((-- A a b + -- B a )c  + (-- A b  + -- B a b )c + -- B b )x
+--R       13         13            13        13            13
+--R   + 
+--R       6    2 2    12      2   12    2       1    4    4      3  11
+--R     (-- A a c  + (-- A a b  + -- B a b)c + -- A b  + -- B a b )x
+--R      11           11          11           11        11
+--R   + 
+--R       4    2    4    3     4      3   2    2 2  9
+--R     ((- A a b + - B a )c + - A a b  + - B a b )x
+--R       3         9          9          3
+--R   + 
+--R      4    3    6    2 2   4    3   7    4    3    1    4  5   1    4 3
+--R     (- A a c + - A a b  + - B a b)x  + (- A a b + - B a )x  + - A a x
+--R      7         7          7             5         5           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2086
+
+--S 2087 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    4 21     1    4    4      3  19
+--R     -- B c x   + (-- A c  + -- B b c )x
+--R     21            19        19
+--R   + 
+--R        4        4      3    6    2 2  17
+--R     ((-- A b + -- B a)c  + -- B b c )x
+--R       17       17          17
+--R   + 
+--R       4      3    2    2   4        2    4    3   15
+--R     (-- A a c  + (- A b  + - B a b)c  + -- B b c)x
+--R      15           5        5            15
+--R   + 
+--R       12          6    2  2     4    3   12      2      1    4  13
+--R     ((-- A a b + -- B a )c  + (-- A b  + -- B a b )c + -- B b )x
+--R       13         13            13        13            13
+--R   + 
+--R       6    2 2    12      2   12    2       1    4    4      3  11
+--R     (-- A a c  + (-- A a b  + -- B a b)c + -- A b  + -- B a b )x
+--R      11           11          11           11        11
+--R   + 
+--R       4    2    4    3     4      3   2    2 2  9
+--R     ((- A a b + - B a )c + - A a b  + - B a b )x
+--R       3         9          9          3
+--R   + 
+--R      4    3    6    2 2   4    3   7    4    3    1    4  5   1    4 3
+--R     (- A a c + - A a b  + - B a b)x  + (- A a b + - B a )x  + - A a x
+--R      7         7          7             5         5           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2087
+
+--S 2088 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2088
+
+--S 2089 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2089
+
+)clear all
+
+--S 2090 of 3139
+t0:=x*(A+B*x^2)*(a+b*x^2+c*x^4)^4
+--R 
+--R
+--R   (1)
+--R        4 19       4         3  17                  3       2 2  15
+--R     B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R   + 
+--R            3        2            2       3   13
+--R     (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R   + 
+--R                     2  2        3          2        4  11
+--R     ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R   + 
+--R          2 2           2        2         4         3  9
+--R     (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R   + 
+--R            2        3           3       2 2  7        3        2 2       3   5
+--R     ((12A a b + 4B a )c + 4A a b  + 6B a b )x  + (4A a c + 6A a b  + 4B a b)x
+--R   + 
+--R          3       4  3      4
+--R     (4A a b + B a )x  + A a x
+--R                                                    Type: Polynomial(Integer)
+--E 2090
+
+--S 2091 of 3139
+r0:=1/2*a^4*A*x^2+1/4*a^3*(4*A*b+a*B)*x^4+1/3*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*_
+   x^6+1/4*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^8+1/10*(4*a*b*B*_
+   (b^2+3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^10+1/12*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^12+1/7*c*(2*b^3*B+3*A*b^2*c+_
+   6*a*b*B*c+2*a*A*c^2)*x^14+1/8*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^16+_
+   1/18*c^3*(4*b*B+A*c)*x^18+1/20*B*c^4*x^20
+--R 
+--R
+--R   (2)
+--R      1    4 20     1    4   2      3  18     1       1      3   3    2 2  16
+--R     -- B c x   + (-- A c  + - B b c )x   + ((- A b + - B a)c  + - B b c )x
+--R     20            18        9                4       4          8
+--R   + 
+--R      2      3    3    2   6        2   2    3   14
+--R     (- A a c  + (- A b  + - B a b)c  + - B b c)x
+--R      7           7        7            7
+--R   + 
+--R               1    2  2    1    3        2      1    4  12
+--R     ((A a b + - B a )c  + (- A b  + B a b )c + -- B b )x
+--R               2            3                   12
+--R   + 
+--R      3    2 2    6      2   6    2       1    4   2      3  10
+--R     (- A a c  + (- A a b  + - B a b)c + -- A b  + - B a b )x
+--R      5           5          5           10        5
+--R   + 
+--R       3    2    1    3     1      3   3    2 2  8
+--R     ((- A a b + - B a )c + - A a b  + - B a b )x
+--R       2         2          2          4
+--R   + 
+--R      2    3       2 2   2    3   6       3    1    4  4   1    4 2
+--R     (- A a c + A a b  + - B a b)x  + (A a b + - B a )x  + - A a x
+--R      3                  3                     4           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2091
+
+--S 2092 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    4 20     1    4   2      3  18     1       1      3   3    2 2  16
+--R     -- B c x   + (-- A c  + - B b c )x   + ((- A b + - B a)c  + - B b c )x
+--R     20            18        9                4       4          8
+--R   + 
+--R      2      3    3    2   6        2   2    3   14
+--R     (- A a c  + (- A b  + - B a b)c  + - B b c)x
+--R      7           7        7            7
+--R   + 
+--R               1    2  2    1    3        2      1    4  12
+--R     ((A a b + - B a )c  + (- A b  + B a b )c + -- B b )x
+--R               2            3                   12
+--R   + 
+--R      3    2 2    6      2   6    2       1    4   2      3  10
+--R     (- A a c  + (- A a b  + - B a b)c + -- A b  + - B a b )x
+--R      5           5          5           10        5
+--R   + 
+--R       3    2    1    3     1      3   3    2 2  8
+--R     ((- A a b + - B a )c + - A a b  + - B a b )x
+--R       2         2          2          4
+--R   + 
+--R      2    3       2 2   2    3   6       3    1    4  4   1    4 2
+--R     (- A a c + A a b  + - B a b)x  + (A a b + - B a )x  + - A a x
+--R      3                  3                     4           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2092
+
+--S 2093 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2093
+
+--S 2094 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2094
+
+)clear all
+
+--S 2095 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^4
+--R 
+--R
+--R   (1)
+--R        4 18       4         3  16                  3       2 2  14
+--R     B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R   + 
+--R            3        2            2       3   12
+--R     (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R   + 
+--R                     2  2        3          2        4  10
+--R     ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R   + 
+--R          2 2           2        2         4         3  8
+--R     (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R   + 
+--R            2        3           3       2 2  6        3        2 2       3   4
+--R     ((12A a b + 4B a )c + 4A a b  + 6B a b )x  + (4A a c + 6A a b  + 4B a b)x
+--R   + 
+--R          3       4  2      4
+--R     (4A a b + B a )x  + A a
+--R                                                    Type: Polynomial(Integer)
+--E 2095
+
+--S 2096 of 3139
+r0:=a^4*A*x+1/3*a^3*(4*A*b+a*B)*x^3+2/5*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*x^5+_
+   2/7*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^7+1/9*(4*a*b*B*(b^2+_
+   3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^9+1/11*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^11+2/13*c*(2*b^3*B+3*A*b^2*c+_
+   6*a*b*B*c+2*a*A*c^2)*x^13+2/15*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^15+_
+   1/17*c^3*(4*b*B+A*c)*x^17+1/19*B*c^4*x^19
+--R 
+--R
+--R   (2)
+--R      1    4 19     1    4    4      3  17      4        4      3   2    2 2  15
+--R     -- B c x   + (-- A c  + -- B b c )x   + ((-- A b + -- B a)c  + - B b c )x
+--R     19            17        17                15       15          5
+--R   + 
+--R       4      3     6    2   12        2    4    3   13
+--R     (-- A a c  + (-- A b  + -- B a b)c  + -- B b c)x
+--R      13           13        13            13
+--R   + 
+--R       12          6    2  2     4    3   12      2      1    4  11
+--R     ((-- A a b + -- B a )c  + (-- A b  + -- B a b )c + -- B b )x
+--R       11         11            11        11            11
+--R   + 
+--R      2    2 2    4      2   4    2      1    4   4      3  9
+--R     (- A a c  + (- A a b  + - B a b)c + - A b  + - B a b )x
+--R      3           3          3           9        9
+--R   + 
+--R       12    2    4    3     4      3   6    2 2  7
+--R     ((-- A a b + - B a )c + - A a b  + - B a b )x
+--R        7         7          7          7
+--R   + 
+--R      4    3    6    2 2   4    3   5    4    3    1    4  3      4
+--R     (- A a c + - A a b  + - B a b)x  + (- A a b + - B a )x  + A a x
+--R      5         5          5             3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2096
+
+--S 2097 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    4 19     1    4    4      3  17      4        4      3   2    2 2  15
+--R     -- B c x   + (-- A c  + -- B b c )x   + ((-- A b + -- B a)c  + - B b c )x
+--R     19            17        17                15       15          5
+--R   + 
+--R       4      3     6    2   12        2    4    3   13
+--R     (-- A a c  + (-- A b  + -- B a b)c  + -- B b c)x
+--R      13           13        13            13
+--R   + 
+--R       12          6    2  2     4    3   12      2      1    4  11
+--R     ((-- A a b + -- B a )c  + (-- A b  + -- B a b )c + -- B b )x
+--R       11         11            11        11            11
+--R   + 
+--R      2    2 2    4      2   4    2      1    4   4      3  9
+--R     (- A a c  + (- A a b  + - B a b)c + - A b  + - B a b )x
+--R      3           3          3           9        9
+--R   + 
+--R       12    2    4    3     4      3   6    2 2  7
+--R     ((-- A a b + - B a )c + - A a b  + - B a b )x
+--R        7         7          7          7
+--R   + 
+--R      4    3    6    2 2   4    3   5    4    3    1    4  3      4
+--R     (- A a c + - A a b  + - B a b)x  + (- A a b + - B a )x  + A a x
+--R      5         5          5             3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2097
+
+--S 2098 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2098
+
+--S 2099 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2099
+
+)clear all
+
+--S 2100 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^4/x
+--R 
+--R
+--R   (1)
+--R          4 18       4         3  16                  3       2 2  14
+--R       B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R     + 
+--R              3        2            2       3   12
+--R       (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R     + 
+--R                       2  2        3          2        4  10
+--R       ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R     + 
+--R            2 2           2        2         4         3  8
+--R       (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R     + 
+--R              2        3           3       2 2  6
+--R       ((12A a b + 4B a )c + 4A a b  + 6B a b )x
+--R     + 
+--R            3        2 2       3   4        3       4  2      4
+--R       (4A a c + 6A a b  + 4B a b)x  + (4A a b + B a )x  + A a
+--R  /
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2100
+
+--S 2101 of 3139
+r0:=1/2*a^3*(4*A*b+a*B)*x^2+1/2*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*x^4+_
+   1/3*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^6+1/8*(4*a*b*B*(b^2+_
+   3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^8+1/10*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^10+1/6*c*(2*b^3*B+3*A*b^2*c+_
+   6*a*b*B*c+2*a*A*c^2)*x^12+1/7*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^14+_
+   1/16*c^3*(4*b*B+A*c)*x^16+1/18*B*c^4*x^18+a^4*A*log(x)
+--R 
+--R
+--R   (2)
+--R              4               4 18          4            3  16
+--R       5040A a log(x) + 280B c x   + (315A c  + 1260B b c )x
+--R     + 
+--R                            3          2 2  14
+--R       ((1440A b + 1440B a)c  + 2160B b c )x
+--R     + 
+--R                 3           2              2          3   12
+--R       (1680A a c  + (2520A b  + 5040B a b)c  + 1680B b c)x
+--R     + 
+--R                            2  2           3            2           4  10
+--R       ((6048A a b + 3024B a )c  + (2016A b  + 6048B a b )c + 504B b )x
+--R     + 
+--R               2 2             2          2            4            3  8
+--R       (3780A a c  + (7560A a b  + 7560B a b)c + 630A b  + 2520B a b )x
+--R     + 
+--R                 2           3              3          2 2  6
+--R       ((10080A a b + 3360B a )c + 3360A a b  + 5040B a b )x
+--R     + 
+--R               3           2 2          3   4            3           4  2
+--R       (5040A a c + 7560A a b  + 5040B a b)x  + (10080A a b + 2520B a )x
+--R  /
+--R     5040
+--R                                                    Type: Expression(Integer)
+--E 2101
+
+--S 2102 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              4               4 18          4            3  16
+--R       5040A a log(x) + 280B c x   + (315A c  + 1260B b c )x
+--R     + 
+--R                            3          2 2  14
+--R       ((1440A b + 1440B a)c  + 2160B b c )x
+--R     + 
+--R                 3           2              2          3   12
+--R       (1680A a c  + (2520A b  + 5040B a b)c  + 1680B b c)x
+--R     + 
+--R                            2  2           3            2           4  10
+--R       ((6048A a b + 3024B a )c  + (2016A b  + 6048B a b )c + 504B b )x
+--R     + 
+--R               2 2             2          2            4            3  8
+--R       (3780A a c  + (7560A a b  + 7560B a b)c + 630A b  + 2520B a b )x
+--R     + 
+--R                 2           3              3          2 2  6
+--R       ((10080A a b + 3360B a )c + 3360A a b  + 5040B a b )x
+--R     + 
+--R               3           2 2          3   4            3           4  2
+--R       (5040A a c + 7560A a b  + 5040B a b)x  + (10080A a b + 2520B a )x
+--R  /
+--R     5040
+--R                                         Type: Union(Expression(Integer),...)
+--E 2102
+
+--S 2103 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2103
+
+--S 2104 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2104
+
+)clear all
+
+--S 2105 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^4/x^2
+--R 
+--R
+--R   (1)
+--R          4 18       4         3  16                  3       2 2  14
+--R       B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R     + 
+--R              3        2            2       3   12
+--R       (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R     + 
+--R                       2  2        3          2        4  10
+--R       ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R     + 
+--R            2 2           2        2         4         3  8
+--R       (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R     + 
+--R              2        3           3       2 2  6
+--R       ((12A a b + 4B a )c + 4A a b  + 6B a b )x
+--R     + 
+--R            3        2 2       3   4        3       4  2      4
+--R       (4A a c + 6A a b  + 4B a b)x  + (4A a b + B a )x  + A a
+--R  /
+--R      2
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2105
+
+--S 2106 of 3139
+r0:=-a^4*A/x+a^3*(4*A*b+a*B)*x+2/3*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*x^3+_
+   2/5*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^5+1/7*(4*a*b*B*(b^2+_
+   3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^7+1/9*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^9+2/11*c*(2*b^3*B+3*A*b^2*c+_
+   6*a*b*B*c+2*a*A*c^2)*x^11+2/13*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^13+_
+   1/15*c^3*(4*b*B+A*c)*x^15+1/17*B*c^4*x^17
+--R 
+--R
+--R   (2)
+--R               4 18            4              3  16
+--R       45045B c x   + (51051A c  + 204204B b c )x
+--R     + 
+--R                                3            2 2  14
+--R       ((235620A b + 235620B a)c  + 353430B b c )x
+--R     + 
+--R                   3             2                2            3   12
+--R       (278460A a c  + (417690A b  + 835380B a b)c  + 278460B b c)x
+--R     + 
+--R                                    2  2             3               2
+--R           (1021020A a b + 510510B a )c  + (340340A b  + 1021020B a b )c
+--R         + 
+--R                   4
+--R           85085B b
+--R      *
+--R          10
+--R         x
+--R     + 
+--R                    2 2                2             2               4
+--R           656370A a c  + (1312740A a b  + 1312740B a b)c + 109395A b
+--R         + 
+--R                      3
+--R           437580B a b
+--R      *
+--R          8
+--R         x
+--R     + 
+--R                   2             3                3            2 2  6
+--R       ((1837836A a b + 612612B a )c + 612612A a b  + 918918B a b )x
+--R     + 
+--R                  3              2 2             3   4
+--R       (1021020A a c + 1531530A a b  + 1021020B a b)x
+--R     + 
+--R                  3             4  2            4
+--R       (3063060A a b + 765765B a )x  - 765765A a
+--R  /
+--R     765765x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2106
+
+--S 2107 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 18            4              3  16
+--R       45045B c x   + (51051A c  + 204204B b c )x
+--R     + 
+--R                                3            2 2  14
+--R       ((235620A b + 235620B a)c  + 353430B b c )x
+--R     + 
+--R                   3             2                2            3   12
+--R       (278460A a c  + (417690A b  + 835380B a b)c  + 278460B b c)x
+--R     + 
+--R                                    2  2             3               2
+--R           (1021020A a b + 510510B a )c  + (340340A b  + 1021020B a b )c
+--R         + 
+--R                   4
+--R           85085B b
+--R      *
+--R          10
+--R         x
+--R     + 
+--R                    2 2                2             2               4
+--R           656370A a c  + (1312740A a b  + 1312740B a b)c + 109395A b
+--R         + 
+--R                      3
+--R           437580B a b
+--R      *
+--R          8
+--R         x
+--R     + 
+--R                   2             3                3            2 2  6
+--R       ((1837836A a b + 612612B a )c + 612612A a b  + 918918B a b )x
+--R     + 
+--R                  3              2 2             3   4
+--R       (1021020A a c + 1531530A a b  + 1021020B a b)x
+--R     + 
+--R                  3             4  2            4
+--R       (3063060A a b + 765765B a )x  - 765765A a
+--R  /
+--R     765765x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2107
+
+--S 2108 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2108
+
+--S 2109 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2109
+
+)clear all
+
+--S 2110 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^4/x^3
+--R 
+--R
+--R   (1)
+--R          4 18       4         3  16                  3       2 2  14
+--R       B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R     + 
+--R              3        2            2       3   12
+--R       (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R     + 
+--R                       2  2        3          2        4  10
+--R       ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R     + 
+--R            2 2           2        2         4         3  8
+--R       (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R     + 
+--R              2        3           3       2 2  6
+--R       ((12A a b + 4B a )c + 4A a b  + 6B a b )x
+--R     + 
+--R            3        2 2       3   4        3       4  2      4
+--R       (4A a c + 6A a b  + 4B a b)x  + (4A a b + B a )x  + A a
+--R  /
+--R      3
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2110
+
+--S 2111 of 3139
+r0:=-1/2*a^4*A/x^2+a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*x^2+1/2*a*(a*B*(3*b^2+_
+   2*a*c)+2*A*(b^3+3*a*b*c))*x^4+1/6*(4*a*b*B*(b^2+3*a*c)+A*(b^4+12*a*b^2*c+_
+   6*a^2*c^2))*x^6+1/8*(b^4*B+4*A*b^3*c+12*a*b^2*B*c+12*a*A*b*c^2+_
+   6*a^2*B*c^2)*x^8+1/5*c*(2*b^3*B+3*A*b^2*c+6*a*b*B*c+2*a*A*c^2)*x^10+_
+   1/6*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^12+1/14*c^3*(4*b*B+A*c)*x^14+_
+   1/16*B*c^4*x^16+a^3*(4*A*b+a*B)*log(x)
+--R 
+--R
+--R   (2)
+--R               3           4  2               4 18          4           3  16
+--R       (6720A a b + 1680B a )x log(x) + 105B c x   + (120A c  + 480B b c )x
+--R     + 
+--R                          3         2 2  14
+--R       ((560A b + 560B a)c  + 840B b c )x
+--R     + 
+--R                3           2              2         3   12
+--R       (672A a c  + (1008A b  + 2016B a b)c  + 672B b c)x
+--R     + 
+--R                            2  2          3            2           4  10
+--R       ((2520A a b + 1260B a )c  + (840A b  + 2520B a b )c + 210B b )x
+--R     + 
+--R               2 2             2          2            4            3  8
+--R       (1680A a c  + (3360A a b  + 3360B a b)c + 280A b  + 1120B a b )x
+--R     + 
+--R                2           3              3          2 2  6
+--R       ((5040A a b + 1680B a )c + 1680A a b  + 2520B a b )x
+--R     + 
+--R               3           2 2          3   4         4
+--R       (3360A a c + 5040A a b  + 3360B a b)x  - 840A a
+--R  /
+--R          2
+--R     1680x
+--R                                                    Type: Expression(Integer)
+--E 2111
+
+--S 2112 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3           4  2               4 18          4           3  16
+--R       (6720A a b + 1680B a )x log(x) + 105B c x   + (120A c  + 480B b c )x
+--R     + 
+--R                          3         2 2  14
+--R       ((560A b + 560B a)c  + 840B b c )x
+--R     + 
+--R                3           2              2         3   12
+--R       (672A a c  + (1008A b  + 2016B a b)c  + 672B b c)x
+--R     + 
+--R                            2  2          3            2           4  10
+--R       ((2520A a b + 1260B a )c  + (840A b  + 2520B a b )c + 210B b )x
+--R     + 
+--R               2 2             2          2            4            3  8
+--R       (1680A a c  + (3360A a b  + 3360B a b)c + 280A b  + 1120B a b )x
+--R     + 
+--R                2           3              3          2 2  6
+--R       ((5040A a b + 1680B a )c + 1680A a b  + 2520B a b )x
+--R     + 
+--R               3           2 2          3   4         4
+--R       (3360A a c + 5040A a b  + 3360B a b)x  - 840A a
+--R  /
+--R          2
+--R     1680x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2112
+
+--S 2113 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2113
+
+--S 2114 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2114
+
+)clear all
+
+--S 2115 of 3139
+t0:=x^5*(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R             7      5
+--R          B x  + A x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2115
+
+--S 2116 of 3139
+r0:=-1/2*(b*B-A*c)*x^2/c^2+1/4*B*x^4/c+1/4*(b^2*B-A*b*c-a*B*c)*_
+   log(a+b*x^2+c*x^4)/c^3+1/2*(b^3*B-A*b^2*c-3*a*b*B*c+2*a*A*c^2)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                                           2
+--R              2          2                  3          2c x  + b
+--R       (4A a c  + (- 2A b  - 6B a b)c + 2B b )atanh(--------------)
+--R                                                     +-----------+
+--R                                                     |          2
+--R                                                    \|- 4a c + b
+--R     + 
+--R                                2        4      2           2 4
+--R           ((- A b - B a)c + B b )log(c x  + b x  + a) + B c x
+--R         + 
+--R                2           2
+--R           (2A c  - 2B b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2116
+
+--S 2117 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2         2                 3
+--R           (2A a c  + (- A b  - 3B a b)c + B b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                  2        4      2           2 4
+--R             ((- A b - B a)c + B b )log(c x  + b x  + a) + B c x
+--R           + 
+--R                  2           2
+--R             (2A c  - 2B b c)x
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R           +-----------+
+--R         3 |          2
+--R       4c \|- 4a c + b
+--R     ,
+--R
+--R                                                                 +---------+
+--R                                                          2      |        2
+--R                  2        2                  3      (2c x  + b)\|4a c - b
+--R         (- 4A a c  + (2A b  + 6B a b)c - 2B b )atan(-----------------------)
+--R                                                                    2
+--R                                                            4a c - b
+--R       + 
+--R                                  2        4      2           2 4
+--R             ((- A b - B a)c + B b )log(c x  + b x  + a) + B c x
+--R           + 
+--R                  2           2
+--R             (2A c  - 2B b c)x
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R           +---------+
+--R         3 |        2
+--R       4c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2117
+
+--S 2118 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                2         2                 3
+--R         (2A a c  + (- A b  - 3B a b)c + B b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                                           2
+--R                2        2                  3          2c x  + b
+--R       (- 4A a c  + (2A b  + 6B a b)c - 2B b )atanh(--------------)
+--R                                                     +-----------+
+--R                                                     |          2
+--R                                                    \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2118
+
+--S 2119 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2119
+
+--S 2120 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                             +---------+             2
+--R                2       2                 3  |        2          2c x  + b
+--R       (- 2A a c  + (A b  + 3B a b)c - B b )\|4a c - b  atanh(--------------)
+--R                                                               +-----------+
+--R                                                               |          2
+--R                                                              \|- 4a c + b
+--R     + 
+--R                                               +-----------+
+--R                  2       2                 3  |          2
+--R         (- 2A a c  + (A b  + 3B a b)c - B b )\|- 4a c + b
+--R      *
+--R                          +---------+
+--R                   2      |        2
+--R              (2c x  + b)\|4a c - b
+--R         atan(-----------------------)
+--R                             2
+--R                     4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       3 |          2  |        2
+--R     2c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2120
+
+--S 2121 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2121
+
+)clear all
+
+--S 2122 of 3139
+t0:=x^3*(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R             5      3
+--R          B x  + A x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2122
+
+--S 2123 of 3139
+r0:=1/2*B*x^2/c-1/4*(b*B-A*c)*log(a+b*x^2+c*x^4)/c^2-1/2*(b^2*B-A*b*c-_
+   2*a*B*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                            2
+--R                             2          2c x  + b
+--R       ((2A b + 4B a)c - 2B b )atanh(--------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R     + 
+--R                                                   +-----------+
+--R                          4      2              2  |          2
+--R       ((A c - B b)log(c x  + b x  + a) + 2B c x )\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2123
+
+--S 2124 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               2
+--R           ((A b + 2B a)c - B b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                                     +-----------+
+--R                            4      2              2  |          2
+--R         ((A c - B b)log(c x  + b x  + a) + 2B c x )\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         2 |          2
+--R       4c \|- 4a c + b
+--R     ,
+--R
+--R                                                    +---------+
+--R                                             2      |        2
+--R                                 2      (2c x  + b)\|4a c - b
+--R         ((- 2A b - 4B a)c + 2B b )atan(-----------------------)
+--R                                                       2
+--R                                               4a c - b
+--R       + 
+--R                                                     +---------+
+--R                            4      2              2  |        2
+--R         ((A c - B b)log(c x  + b x  + a) + 2B c x )\|4a c - b
+--R    /
+--R           +---------+
+--R         2 |        2
+--R       4c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2124
+
+--S 2125 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             2
+--R         ((A b + 2B a)c - B b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                              2
+--R                               2          2c x  + b
+--R       ((- 2A b - 4B a)c + 2B b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2125
+
+--S 2126 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2126
+
+--S 2127 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                +---------+             2
+--R                             2  |        2          2c x  + b
+--R       ((- A b - 2B a)c + B b )\|4a c - b  atanh(--------------)
+--R                                                  +-----------+
+--R                                                  |          2
+--R                                                 \|- 4a c + b
+--R     + 
+--R                                                              +---------+
+--R                                +-----------+          2      |        2
+--R                             2  |          2      (2c x  + b)\|4a c - b
+--R       ((- A b - 2B a)c + B b )\|- 4a c + b  atan(-----------------------)
+--R                                                                 2
+--R                                                         4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     2c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2127
+
+--S 2128 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2128
+
+)clear all
+
+--S 2129 of 3139
+t0:=x*(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R              3
+--R           B x  + A x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2129
+
+--S 2130 of 3139
+r0:=1/4*B*log(a+b*x^2+c*x^4)/c+1/2*(b*B-2*A*c)*atanh((b+2*c*x^2)/sqrt(b^2-_
+   4*a*c))/(c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                               2                                 +-----------+
+--R                           2c x  + b               4      2      |          2
+--R   (- 4A c + 2B b)atanh(--------------) + B log(c x  + b x  + a)\|- 4a c + b
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                    +-----------+
+--R                                    |          2
+--R                                 4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2130
+
+--S 2131 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           (2A c - B b)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                +-----------+
+--R                  4      2      |          2
+--R         B log(c x  + b x  + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       4c\|- 4a c + b
+--R     ,
+--R
+--R                                       +---------+
+--R                                2      |        2
+--R                           (2c x  + b)\|4a c - b
+--R         (4A c - 2B b)atan(-----------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                                +---------+
+--R                  4      2      |        2
+--R         B log(c x  + b x  + a)\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       4c\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2131
+
+--S 2132 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (2A c - B b)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                 2
+--R                             2c x  + b
+--R       (4A c - 2B b)atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2132
+
+--S 2133 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2133
+
+--S 2134 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    +---------+             2
+--R                    |        2          2c x  + b
+--R       (2A c - B b)\|4a c - b  atanh(--------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                    +-----------+          2      |        2
+--R                    |          2      (2c x  + b)\|4a c - b
+--R       (2A c - B b)\|- 4a c + b  atan(-----------------------)
+--R                                                     2
+--R                                             4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     2c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2134
+
+--S 2135 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2135
+
+)clear all
+
+--S 2136 of 3139
+t0:=(A+B*x^2)/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2136
+
+--S 2137 of 3139
+r0:=A*log(x)/a-1/4*A*log(a+b*x^2+c*x^4)/a+1/2*(A*b-2*a*B)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                 2
+--R                             2c x  + b
+--R       (2A b - 4B a)atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R     + 
+--R                                              +-----------+
+--R                   4      2                   |          2
+--R       (- A log(c x  + b x  + a) + 4A log(x))\|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     4a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2137
+
+--S 2138 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           (A b - 2B a)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                                +-----------+
+--R                     4      2                   |          2
+--R         (- A log(c x  + b x  + a) + 4A log(x))\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       4a\|- 4a c + b
+--R     ,
+--R
+--R                                         +---------+
+--R                                  2      |        2
+--R                             (2c x  + b)\|4a c - b
+--R         (- 2A b + 4B a)atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R       + 
+--R                                                +---------+
+--R                     4      2                   |        2
+--R         (- A log(c x  + b x  + a) + 4A log(x))\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       4a\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2138
+
+--S 2139 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (A b - 2B a)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                   2
+--R                               2c x  + b
+--R       (- 2A b + 4B a)atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     4a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2139
+
+--S 2140 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2140
+
+--S 2141 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      +---------+             2
+--R                      |        2          2c x  + b
+--R       (- A b + 2B a)\|4a c - b  atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                                                    +---------+
+--R                      +-----------+          2      |        2
+--R                      |          2      (2c x  + b)\|4a c - b
+--R       (- A b + 2B a)\|- 4a c + b  atan(-----------------------)
+--R                                                       2
+--R                                               4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     2a\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2141
+
+--S 2142 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2142
+
+)clear all
+
+--S 2143 of 3139
+t0:=(A+B*x^2)/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2143
+
+--S 2144 of 3139
+r0:=-1/2*A/(a*x^2)-(A*b-a*B)*log(x)/a^2+1/4*(A*b-a*B)*log(a+b*x^2+c*x^4)/a^2-_
+   1/2*(A*b^2-a*b*B-2*a*A*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^2*_
+   sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                               2
+--R                     2           2         2c x  + b
+--R       (4A a c - 2A b  + 2B a b)x atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                      2       4      2                        2
+--R         ((A b - B a)x log(c x  + b x  + a) + (- 4A b + 4B a)x log(x) - 2A a)
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       2 2 |          2
+--R     4a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2144
+
+--S 2145 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        2          2
+--R           (2A a c - A b  + B a b)x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                        2       4      2                        2
+--R           ((A b - B a)x log(c x  + b x  + a) + (- 4A b + 4B a)x log(x) - 2A a)
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             +-----------+
+--R         2 2 |          2
+--R       4a x \|- 4a c + b
+--R     ,
+--R
+--R                                                       +---------+
+--R                                                2      |        2
+--R                         2           2     (2c x  + b)\|4a c - b
+--R         (- 4A a c + 2A b  - 2B a b)x atan(-----------------------)
+--R                                                          2
+--R                                                  4a c - b
+--R       + 
+--R                        2       4      2                        2
+--R           ((A b - B a)x log(c x  + b x  + a) + (- 4A b + 4B a)x log(x) - 2A a)
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R             +---------+
+--R         2 2 |        2
+--R       4a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2145
+
+--S 2146 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2
+--R         (2A a c - A b  + B a b)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                               2
+--R                       2                   2c x  + b
+--R       (- 4A a c + 2A b  - 2B a b)atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2146
+
+--S 2147 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2147
+
+--S 2148 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                 +---------+             2
+--R                      2          |        2          2c x  + b
+--R       (- 2A a c + A b  - B a b)\|4a c - b  atanh(--------------)
+--R                                                   +-----------+
+--R                                                   |          2
+--R                                                  \|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R                                 +-----------+          2      |        2
+--R                      2          |          2      (2c x  + b)\|4a c - b
+--R       (- 2A a c + A b  - B a b)\|- 4a c + b  atan(-----------------------)
+--R                                                                  2
+--R                                                          4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     2a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2148
+
+--S 2149 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2149
+
+)clear all
+
+--S 2150 of 3139
+t0:=x^4*(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R             6      4
+--R          B x  + A x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2150
+
+--S 2151 of 3139
+r0:=-(b*B-A*c)*x/c^2+1/3*B*x^3/c+atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*(b^2*B-A*b*c-a*B*c+(-b^3*B+A*b^2*c+3*a*b*B*c-_
+   2*a*A*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^2*B-A*b*c-a*B*c+_
+   (b^3*B-A*b^2*c-3*a*b*B*c+2*a*A*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                      +-----------+
+--R                                   2  |          2          2
+--R           ((- 3A b - 3B a)c + 3B b )\|- 4a c + b   - 6A a c
+--R         + 
+--R                2                  3
+--R           (3A b  + 9B a b)c - 3B b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                      +-----------+
+--R                                   2  |          2          2
+--R           ((- 3A b - 3B a)c + 3B b )\|- 4a c + b   + 6A a c
+--R         + 
+--R                  2                  3
+--R           (- 3A b  - 9B a b)c + 3B b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                         +--------------------+
+--R                                       +-----------+     |   +-----------+
+--R               3                   +-+ |          2  +-+ |   |          2
+--R         (B c x  + (3A c - 3B b)x)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     3c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2151
+
+--S 2152 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2
+--R         3c
+--R      *
+--R         ROOT
+--R                        6     2 5
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                            4 2 6      4   2     3   2      2 2 3  5
+--R                         - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                       + 
+--R                             4 4      3     3      2 2 2 2       3 3     4 4  4
+--R                         (- A b  - 12A B a b  - 24A B a b  - 8A B a b - B a )c
+--R                       + 
+--R                            3   5      2 2   4        3 2 3     4 3 2  3
+--R                         (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                       + 
+--R                              2 2 6        3   5      4 2 4  2
+--R                         (- 6A B b  - 20A B a b  - 11B a b )c
+--R                       + 
+--R                              3 7     4   6      4 8
+--R                         (4A B b  + 6B a b )c - B b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                     2            2  3     2 3           2     2 2   2
+--R                (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R              + 
+--R                         4     2   3      2 5
+--R                (- 2A B b  - 5B a b )c + B b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                                     2  7          3          2  6       4 5
+--R                    ((16A a b + 32B a )c  + (- 4A b  - 24B a b )c  + 4B b c )
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4   2     3   2      2 2 3  5
+--R                           - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                         + 
+--R                                    4 4      3     3      2 2 2 2       3 3
+--R                                 - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                               + 
+--R                                    4 4
+--R                                 - B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                              3   5      2 2   4        3 2 3     4 3 2  3
+--R                           (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                         + 
+--R                                2 2 6        3   5      4 2 4  2
+--R                           (- 6A B b  - 20A B a b  - 11B a b )c
+--R                         + 
+--R                                3 7     4   6      4 8
+--R                           (4A B b  + 6B a b )c - B b
+--R                      /
+--R                              11      2 10
+--R                         64a c   - 16b c
+--R                + 
+--R                      3 2 5      3   2      2   2        2 3  4
+--R                  - 4A a c  + (5A a b  + 20A B a b + 4A B a )c
+--R                + 
+--R                      3 4      2     3        2 2 2     3 3   3
+--R                  (- A b  - 17A B a b  - 29A B a b  - 4B a b)c
+--R                + 
+--R                     2   5        2   4      3 2 3  2          2 6     3   5
+--R                  (3A B b  + 19A B a b  + 13B a b )c  + (- 3A B b  - 7B a b )c
+--R                + 
+--R                   3 7
+--R                  B b
+--R             *
+--R                ROOT
+--R                               6     2 5
+--R                         (16a c  - 4b c )
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4   2     3   2      2 2 3  5
+--R                                - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                              + 
+--R                                       4 4      3     3      2 2 2 2       3 3
+--R                                    - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                  + 
+--R                                       4 4
+--R                                    - B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                   3   5      2 2   4        3 2 3     4 3 2  3
+--R                                (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                              + 
+--R                                     2 2 6        3   5      4 2 4  2
+--R                                (- 6A B b  - 20A B a b  - 11B a b )c
+--R                              + 
+--R                                     3 7     4   6      4 8
+--R                                (4A B b  + 6B a b )c - B b
+--R                           /
+--R                                   11      2 10
+--R                              64a c   - 16b c
+--R                     + 
+--R                            2            2  3     2 3           2     2 2   2
+--R                       (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                     + 
+--R                                4     2   3      2 5
+--R                       (- 2A B b  - 5B a b )c + B b
+--R                  /
+--R                         6     2 5
+--R                     8a c  - 2b c
+--R            + 
+--R                    4 2 4        4   2      3   2   3
+--R                  2A a c  + (- 2A a b  - 10A B a b)c
+--R                + 
+--R                     3     3      2 2 2 2       3 3      4 4  2
+--R                  (6A B a b  + 12A B a b  - 6A B a b - 2B a )c
+--R                + 
+--R                       2 2   4       3 2 3     4 3 2         3   5     4 2 4
+--R                  (- 6A B a b  - 2A B a b  + 6B a b )c + 2A B a b  - 2B a b
+--R             *
+--R                x
+--R     + 
+--R       -
+--R              2
+--R            3c
+--R         *
+--R            ROOT
+--R                             6     2 5
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                     ROOT
+--R                               4 2 6      4   2     3   2      2 2 3  5
+--R                            - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                          + 
+--R                                     4 4      3     3      2 2 2 2       3 3
+--R                                  - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                + 
+--R                                     4 4
+--R                                  - B a
+--R                           *
+--R                               4
+--R                              c
+--R                          + 
+--R                               3   5      2 2   4        3 2 3     4 3 2  3
+--R                            (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                          + 
+--R                                 2 2 6        3   5      4 2 4  2
+--R                            (- 6A B b  - 20A B a b  - 11B a b )c
+--R                          + 
+--R                                 3 7     4   6      4 8
+--R                            (4A B b  + 6B a b )c - B b
+--R                       /
+--R                               11      2 10
+--R                          64a c   - 16b c
+--R                 + 
+--R                        2            2  3     2 3           2     2 2   2
+--R                   (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                 + 
+--R                            4     2   3      2 5
+--R                   (- 2A B b  - 5B a b )c + B b
+--R              /
+--R                     6     2 5
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                                        2  7          3          2  6       4 5
+--R                       ((16A a b + 32B a )c  + (- 4A b  - 24B a b )c  + 4B b c )
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4   2     3   2      2 2 3  5
+--R                              - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                            + 
+--R                                     4 4      3     3      2 2 2 2       3 3
+--R                                  - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                + 
+--R                                     4 4
+--R                                  - B a
+--R                             *
+--R                                 4
+--R                                c
+--R                            + 
+--R                                 3   5      2 2   4        3 2 3     4 3 2  3
+--R                              (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                            + 
+--R                                   2 2 6        3   5      4 2 4  2
+--R                              (- 6A B b  - 20A B a b  - 11B a b )c
+--R                            + 
+--R                                   3 7     4   6      4 8
+--R                              (4A B b  + 6B a b )c - B b
+--R                         /
+--R                                 11      2 10
+--R                            64a c   - 16b c
+--R                   + 
+--R                       3 2 5        3   2      2   2        2 3  4
+--R                     4A a c  + (- 5A a b  - 20A B a b - 4A B a )c
+--R                   + 
+--R                       3 4      2     3        2 2 2     3 3   3
+--R                     (A b  + 17A B a b  + 29A B a b  + 4B a b)c
+--R                   + 
+--R                          2   5        2   4      3 2 3  2
+--R                     (- 3A B b  - 19A B a b  - 13B a b )c
+--R                   + 
+--R                          2 6     3   5      3 7
+--R                     (3A B b  + 7B a b )c - B b
+--R                *
+--R                   ROOT
+--R                                    6     2 5
+--R                            (- 16a c  + 4b c )
+--R                         *
+--R                            ROOT
+--R                                      4 2 6      4   2     3   2      2 2 3  5
+--R                                   - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                                 + 
+--R                                          4 4      3     3      2 2 2 2
+--R                                       - A b  - 12A B a b  - 24A B a b
+--R                                     + 
+--R                                             3 3     4 4
+--R                                       - 8A B a b - B a
+--R                                  *
+--R                                      4
+--R                                     c
+--R                                 + 
+--R                                           3   5      2 2   4        3 2 3
+--R                                         4A B b  + 24A B a b  + 28A B a b
+--R                                       + 
+--R                                           4 3 2
+--R                                         6B a b
+--R                                  *
+--R                                      3
+--R                                     c
+--R                                 + 
+--R                                        2 2 6        3   5      4 2 4  2
+--R                                   (- 6A B b  - 20A B a b  - 11B a b )c
+--R                                 + 
+--R                                        3 7     4   6      4 8
+--R                                   (4A B b  + 6B a b )c - B b
+--R                              /
+--R                                      11      2 10
+--R                                 64a c   - 16b c
+--R                        + 
+--R                               2            2  3     2 3           2     2 2   2
+--R                          (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                        + 
+--R                                   4     2   3      2 5
+--R                          (- 2A B b  - 5B a b )c + B b
+--R                     /
+--R                            6     2 5
+--R                        8a c  - 2b c
+--R               + 
+--R                       4 2 4        4   2      3   2   3
+--R                     2A a c  + (- 2A a b  - 10A B a b)c
+--R                   + 
+--R                        3     3      2 2 2 2       3 3      4 4  2
+--R                     (6A B a b  + 12A B a b  - 6A B a b - 2B a )c
+--R                   + 
+--R                          2 2   4       3 2 3     4 3 2         3   5     4 2 4
+--R                     (- 6A B a b  - 2A B a b  + 6B a b )c + 2A B a b  - 2B a b
+--R                *
+--R                   x
+--R     + 
+--R           2
+--R         3c
+--R      *
+--R         ROOT
+--R                          6     2 5
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                            4 2 6      4   2     3   2      2 2 3  5
+--R                         - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                       + 
+--R                             4 4      3     3      2 2 2 2       3 3     4 4  4
+--R                         (- A b  - 12A B a b  - 24A B a b  - 8A B a b - B a )c
+--R                       + 
+--R                            3   5      2 2   4        3 2 3     4 3 2  3
+--R                         (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                       + 
+--R                              2 2 6        3   5      4 2 4  2
+--R                         (- 6A B b  - 20A B a b  - 11B a b )c
+--R                       + 
+--R                              3 7     4   6      4 8
+--R                         (4A B b  + 6B a b )c - B b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                     2            2  3     2 3           2     2 2   2
+--R                (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R              + 
+--R                         4     2   3      2 5
+--R                (- 2A B b  - 5B a b )c + B b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                                       2  7        3          2  6       4 5
+--R                    ((- 16A a b - 32B a )c  + (4A b  + 24B a b )c  - 4B b c )
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4   2     3   2      2 2 3  5
+--R                           - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                         + 
+--R                                    4 4      3     3      2 2 2 2       3 3
+--R                                 - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                               + 
+--R                                    4 4
+--R                                 - B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                              3   5      2 2   4        3 2 3     4 3 2  3
+--R                           (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                         + 
+--R                                2 2 6        3   5      4 2 4  2
+--R                           (- 6A B b  - 20A B a b  - 11B a b )c
+--R                         + 
+--R                                3 7     4   6      4 8
+--R                           (4A B b  + 6B a b )c - B b
+--R                      /
+--R                              11      2 10
+--R                         64a c   - 16b c
+--R                + 
+--R                      3 2 5      3   2      2   2        2 3  4
+--R                  - 4A a c  + (5A a b  + 20A B a b + 4A B a )c
+--R                + 
+--R                      3 4      2     3        2 2 2     3 3   3
+--R                  (- A b  - 17A B a b  - 29A B a b  - 4B a b)c
+--R                + 
+--R                     2   5        2   4      3 2 3  2          2 6     3   5
+--R                  (3A B b  + 19A B a b  + 13B a b )c  + (- 3A B b  - 7B a b )c
+--R                + 
+--R                   3 7
+--R                  B b
+--R             *
+--R                ROOT
+--R                                 6     2 5
+--R                         (- 16a c  + 4b c )
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4   2     3   2      2 2 3  5
+--R                                - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                              + 
+--R                                       4 4      3     3      2 2 2 2       3 3
+--R                                    - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                  + 
+--R                                       4 4
+--R                                    - B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                   3   5      2 2   4        3 2 3     4 3 2  3
+--R                                (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                              + 
+--R                                     2 2 6        3   5      4 2 4  2
+--R                                (- 6A B b  - 20A B a b  - 11B a b )c
+--R                              + 
+--R                                     3 7     4   6      4 8
+--R                                (4A B b  + 6B a b )c - B b
+--R                           /
+--R                                   11      2 10
+--R                              64a c   - 16b c
+--R                     + 
+--R                            2            2  3     2 3           2     2 2   2
+--R                       (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                     + 
+--R                                4     2   3      2 5
+--R                       (- 2A B b  - 5B a b )c + B b
+--R                  /
+--R                         6     2 5
+--R                     8a c  - 2b c
+--R            + 
+--R                    4 2 4        4   2      3   2   3
+--R                  2A a c  + (- 2A a b  - 10A B a b)c
+--R                + 
+--R                     3     3      2 2 2 2       3 3      4 4  2
+--R                  (6A B a b  + 12A B a b  - 6A B a b - 2B a )c
+--R                + 
+--R                       2 2   4       3 2 3     4 3 2         3   5     4 2 4
+--R                  (- 6A B a b  - 2A B a b  + 6B a b )c + 2A B a b  - 2B a b
+--R             *
+--R                x
+--R     + 
+--R       -
+--R              2
+--R            3c
+--R         *
+--R            ROOT
+--R                           6     2 5
+--R                     (16a c  - 4b c )
+--R                  *
+--R                     ROOT
+--R                               4 2 6      4   2     3   2      2 2 3  5
+--R                            - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                          + 
+--R                                     4 4      3     3      2 2 2 2       3 3
+--R                                  - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                + 
+--R                                     4 4
+--R                                  - B a
+--R                           *
+--R                               4
+--R                              c
+--R                          + 
+--R                               3   5      2 2   4        3 2 3     4 3 2  3
+--R                            (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                          + 
+--R                                 2 2 6        3   5      4 2 4  2
+--R                            (- 6A B b  - 20A B a b  - 11B a b )c
+--R                          + 
+--R                                 3 7     4   6      4 8
+--R                            (4A B b  + 6B a b )c - B b
+--R                       /
+--R                               11      2 10
+--R                          64a c   - 16b c
+--R                 + 
+--R                        2            2  3     2 3           2     2 2   2
+--R                   (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                 + 
+--R                            4     2   3      2 5
+--R                   (- 2A B b  - 5B a b )c + B b
+--R              /
+--R                     6     2 5
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                                          2  7        3          2  6       4 5
+--R                       ((- 16A a b - 32B a )c  + (4A b  + 24B a b )c  - 4B b c )
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4   2     3   2      2 2 3  5
+--R                              - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                            + 
+--R                                     4 4      3     3      2 2 2 2       3 3
+--R                                  - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                + 
+--R                                     4 4
+--R                                  - B a
+--R                             *
+--R                                 4
+--R                                c
+--R                            + 
+--R                                 3   5      2 2   4        3 2 3     4 3 2  3
+--R                              (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                            + 
+--R                                   2 2 6        3   5      4 2 4  2
+--R                              (- 6A B b  - 20A B a b  - 11B a b )c
+--R                            + 
+--R                                   3 7     4   6      4 8
+--R                              (4A B b  + 6B a b )c - B b
+--R                         /
+--R                                 11      2 10
+--R                            64a c   - 16b c
+--R                   + 
+--R                       3 2 5        3   2      2   2        2 3  4
+--R                     4A a c  + (- 5A a b  - 20A B a b - 4A B a )c
+--R                   + 
+--R                       3 4      2     3        2 2 2     3 3   3
+--R                     (A b  + 17A B a b  + 29A B a b  + 4B a b)c
+--R                   + 
+--R                          2   5        2   4      3 2 3  2
+--R                     (- 3A B b  - 19A B a b  - 13B a b )c
+--R                   + 
+--R                          2 6     3   5      3 7
+--R                     (3A B b  + 7B a b )c - B b
+--R                *
+--R                   ROOT
+--R                                  6     2 5
+--R                            (16a c  - 4b c )
+--R                         *
+--R                            ROOT
+--R                                      4 2 6      4   2     3   2      2 2 3  5
+--R                                   - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                                 + 
+--R                                          4 4      3     3      2 2 2 2
+--R                                       - A b  - 12A B a b  - 24A B a b
+--R                                     + 
+--R                                             3 3     4 4
+--R                                       - 8A B a b - B a
+--R                                  *
+--R                                      4
+--R                                     c
+--R                                 + 
+--R                                           3   5      2 2   4        3 2 3
+--R                                         4A B b  + 24A B a b  + 28A B a b
+--R                                       + 
+--R                                           4 3 2
+--R                                         6B a b
+--R                                  *
+--R                                      3
+--R                                     c
+--R                                 + 
+--R                                        2 2 6        3   5      4 2 4  2
+--R                                   (- 6A B b  - 20A B a b  - 11B a b )c
+--R                                 + 
+--R                                        3 7     4   6      4 8
+--R                                   (4A B b  + 6B a b )c - B b
+--R                              /
+--R                                      11      2 10
+--R                                 64a c   - 16b c
+--R                        + 
+--R                               2            2  3     2 3           2     2 2   2
+--R                          (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                        + 
+--R                                   4     2   3      2 5
+--R                          (- 2A B b  - 5B a b )c + B b
+--R                     /
+--R                            6     2 5
+--R                        8a c  - 2b c
+--R               + 
+--R                       4 2 4        4   2      3   2   3
+--R                     2A a c  + (- 2A a b  - 10A B a b)c
+--R                   + 
+--R                        3     3      2 2 2 2       3 3      4 4  2
+--R                     (6A B a b  + 12A B a b  - 6A B a b - 2B a )c
+--R                   + 
+--R                          2 2   4       3 2 3     4 3 2         3   5     4 2 4
+--R                     (- 6A B a b  - 2A B a b  + 6B a b )c + 2A B a b  - 2B a b
+--R                *
+--R                   x
+--R     + 
+--R             3
+--R       2B c x  + (6A c - 6B b)x
+--R  /
+--R       2
+--R     6c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2152
+
+--S 2153 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  +--------------------+ +------------------+
+--R                +-----------+     |   +-----------+      | +-----------+
+--R          2 +-+ |          2  +-+ |   |          2       | |          2
+--R         c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6     2 5
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                            4 2 6      4   2     3   2      2 2 3  5
+--R                         - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                       + 
+--R                             4 4      3     3      2 2 2 2       3 3     4 4  4
+--R                         (- A b  - 12A B a b  - 24A B a b  - 8A B a b - B a )c
+--R                       + 
+--R                            3   5      2 2   4        3 2 3     4 3 2  3
+--R                         (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                       + 
+--R                              2 2 6        3   5      4 2 4  2
+--R                         (- 6A B b  - 20A B a b  - 11B a b )c
+--R                       + 
+--R                              3 7     4   6      4 8
+--R                         (4A B b  + 6B a b )c - B b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                     2            2  3     2 3           2     2 2   2
+--R                (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R              + 
+--R                         4     2   3      2 5
+--R                (- 2A B b  - 5B a b )c + B b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                                     2  7          3          2  6       4 5
+--R                    ((16A a b + 32B a )c  + (- 4A b  - 24B a b )c  + 4B b c )
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4   2     3   2      2 2 3  5
+--R                           - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                         + 
+--R                                    4 4      3     3      2 2 2 2       3 3
+--R                                 - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                               + 
+--R                                    4 4
+--R                                 - B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                              3   5      2 2   4        3 2 3     4 3 2  3
+--R                           (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                         + 
+--R                                2 2 6        3   5      4 2 4  2
+--R                           (- 6A B b  - 20A B a b  - 11B a b )c
+--R                         + 
+--R                                3 7     4   6      4 8
+--R                           (4A B b  + 6B a b )c - B b
+--R                      /
+--R                              11      2 10
+--R                         64a c   - 16b c
+--R                + 
+--R                      3 2 5      3   2      2   2        2 3  4
+--R                  - 4A a c  + (5A a b  + 20A B a b + 4A B a )c
+--R                + 
+--R                      3 4      2     3        2 2 2     3 3   3
+--R                  (- A b  - 17A B a b  - 29A B a b  - 4B a b)c
+--R                + 
+--R                     2   5        2   4      3 2 3  2          2 6     3   5
+--R                  (3A B b  + 19A B a b  + 13B a b )c  + (- 3A B b  - 7B a b )c
+--R                + 
+--R                   3 7
+--R                  B b
+--R             *
+--R                ROOT
+--R                               6     2 5
+--R                         (16a c  - 4b c )
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4   2     3   2      2 2 3  5
+--R                                - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                              + 
+--R                                       4 4      3     3      2 2 2 2       3 3
+--R                                    - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                  + 
+--R                                       4 4
+--R                                    - B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                   3   5      2 2   4        3 2 3     4 3 2  3
+--R                                (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                              + 
+--R                                     2 2 6        3   5      4 2 4  2
+--R                                (- 6A B b  - 20A B a b  - 11B a b )c
+--R                              + 
+--R                                     3 7     4   6      4 8
+--R                                (4A B b  + 6B a b )c - B b
+--R                           /
+--R                                   11      2 10
+--R                              64a c   - 16b c
+--R                     + 
+--R                            2            2  3     2 3           2     2 2   2
+--R                       (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                     + 
+--R                                4     2   3      2 5
+--R                       (- 2A B b  - 5B a b )c + B b
+--R                  /
+--R                         6     2 5
+--R                     8a c  - 2b c
+--R            + 
+--R                    4 2 4        4   2      3   2   3
+--R                  2A a c  + (- 2A a b  - 10A B a b)c
+--R                + 
+--R                     3     3      2 2 2 2       3 3      4 4  2
+--R                  (6A B a b  + 12A B a b  - 6A B a b - 2B a )c
+--R                + 
+--R                       2 2   4       3 2 3     4 3 2         3   5     4 2 4
+--R                  (- 6A B a b  - 2A B a b  + 6B a b )c + 2A B a b  - 2B a b
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                   +-----------+
+--R             2 +-+ |          2  +-+
+--R            c \|2 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                             6     2 5
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                     ROOT
+--R                               4 2 6      4   2     3   2      2 2 3  5
+--R                            - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                          + 
+--R                                     4 4      3     3      2 2 2 2       3 3
+--R                                  - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                + 
+--R                                     4 4
+--R                                  - B a
+--R                           *
+--R                               4
+--R                              c
+--R                          + 
+--R                               3   5      2 2   4        3 2 3     4 3 2  3
+--R                            (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                          + 
+--R                                 2 2 6        3   5      4 2 4  2
+--R                            (- 6A B b  - 20A B a b  - 11B a b )c
+--R                          + 
+--R                                 3 7     4   6      4 8
+--R                            (4A B b  + 6B a b )c - B b
+--R                       /
+--R                               11      2 10
+--R                          64a c   - 16b c
+--R                 + 
+--R                        2            2  3     2 3           2     2 2   2
+--R                   (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                 + 
+--R                            4     2   3      2 5
+--R                   (- 2A B b  - 5B a b )c + B b
+--R              /
+--R                     6     2 5
+--R                 8a c  - 2b c
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                        2  7          3          2  6       4 5
+--R                       ((16A a b + 32B a )c  + (- 4A b  - 24B a b )c  + 4B b c )
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4   2     3   2      2 2 3  5
+--R                              - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                            + 
+--R                                     4 4      3     3      2 2 2 2       3 3
+--R                                  - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                + 
+--R                                     4 4
+--R                                  - B a
+--R                             *
+--R                                 4
+--R                                c
+--R                            + 
+--R                                 3   5      2 2   4        3 2 3     4 3 2  3
+--R                              (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                            + 
+--R                                   2 2 6        3   5      4 2 4  2
+--R                              (- 6A B b  - 20A B a b  - 11B a b )c
+--R                            + 
+--R                                   3 7     4   6      4 8
+--R                              (4A B b  + 6B a b )c - B b
+--R                         /
+--R                                 11      2 10
+--R                            64a c   - 16b c
+--R                   + 
+--R                       3 2 5        3   2      2   2        2 3  4
+--R                     4A a c  + (- 5A a b  - 20A B a b - 4A B a )c
+--R                   + 
+--R                       3 4      2     3        2 2 2     3 3   3
+--R                     (A b  + 17A B a b  + 29A B a b  + 4B a b)c
+--R                   + 
+--R                          2   5        2   4      3 2 3  2
+--R                     (- 3A B b  - 19A B a b  - 13B a b )c
+--R                   + 
+--R                          2 6     3   5      3 7
+--R                     (3A B b  + 7B a b )c - B b
+--R                *
+--R                   ROOT
+--R                                    6     2 5
+--R                            (- 16a c  + 4b c )
+--R                         *
+--R                            ROOT
+--R                                      4 2 6      4   2     3   2      2 2 3  5
+--R                                   - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                                 + 
+--R                                          4 4      3     3      2 2 2 2
+--R                                       - A b  - 12A B a b  - 24A B a b
+--R                                     + 
+--R                                             3 3     4 4
+--R                                       - 8A B a b - B a
+--R                                  *
+--R                                      4
+--R                                     c
+--R                                 + 
+--R                                           3   5      2 2   4        3 2 3
+--R                                         4A B b  + 24A B a b  + 28A B a b
+--R                                       + 
+--R                                           4 3 2
+--R                                         6B a b
+--R                                  *
+--R                                      3
+--R                                     c
+--R                                 + 
+--R                                        2 2 6        3   5      4 2 4  2
+--R                                   (- 6A B b  - 20A B a b  - 11B a b )c
+--R                                 + 
+--R                                        3 7     4   6      4 8
+--R                                   (4A B b  + 6B a b )c - B b
+--R                              /
+--R                                      11      2 10
+--R                                 64a c   - 16b c
+--R                        + 
+--R                               2            2  3     2 3           2     2 2   2
+--R                          (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                        + 
+--R                                   4     2   3      2 5
+--R                          (- 2A B b  - 5B a b )c + B b
+--R                     /
+--R                            6     2 5
+--R                        8a c  - 2b c
+--R               + 
+--R                       4 2 4        4   2      3   2   3
+--R                     2A a c  + (- 2A a b  - 10A B a b)c
+--R                   + 
+--R                        3     3      2 2 2 2       3 3      4 4  2
+--R                     (6A B a b  + 12A B a b  - 6A B a b - 2B a )c
+--R                   + 
+--R                          2 2   4       3 2 3     4 3 2         3   5     4 2 4
+--R                     (- 6A B a b  - 2A B a b  + 6B a b )c + 2A B a b  - 2B a b
+--R                *
+--R                   x
+--R     + 
+--R                +-----------+
+--R          2 +-+ |          2  +-+
+--R         c \|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          6     2 5
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                            4 2 6      4   2     3   2      2 2 3  5
+--R                         - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                       + 
+--R                             4 4      3     3      2 2 2 2       3 3     4 4  4
+--R                         (- A b  - 12A B a b  - 24A B a b  - 8A B a b - B a )c
+--R                       + 
+--R                            3   5      2 2   4        3 2 3     4 3 2  3
+--R                         (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                       + 
+--R                              2 2 6        3   5      4 2 4  2
+--R                         (- 6A B b  - 20A B a b  - 11B a b )c
+--R                       + 
+--R                              3 7     4   6      4 8
+--R                         (4A B b  + 6B a b )c - B b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                     2            2  3     2 3           2     2 2   2
+--R                (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R              + 
+--R                         4     2   3      2 5
+--R                (- 2A B b  - 5B a b )c + B b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                       2  7        3          2  6       4 5
+--R                    ((- 16A a b - 32B a )c  + (4A b  + 24B a b )c  - 4B b c )
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4   2     3   2      2 2 3  5
+--R                           - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                         + 
+--R                                    4 4      3     3      2 2 2 2       3 3
+--R                                 - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                               + 
+--R                                    4 4
+--R                                 - B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                              3   5      2 2   4        3 2 3     4 3 2  3
+--R                           (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                         + 
+--R                                2 2 6        3   5      4 2 4  2
+--R                           (- 6A B b  - 20A B a b  - 11B a b )c
+--R                         + 
+--R                                3 7     4   6      4 8
+--R                           (4A B b  + 6B a b )c - B b
+--R                      /
+--R                              11      2 10
+--R                         64a c   - 16b c
+--R                + 
+--R                      3 2 5      3   2      2   2        2 3  4
+--R                  - 4A a c  + (5A a b  + 20A B a b + 4A B a )c
+--R                + 
+--R                      3 4      2     3        2 2 2     3 3   3
+--R                  (- A b  - 17A B a b  - 29A B a b  - 4B a b)c
+--R                + 
+--R                     2   5        2   4      3 2 3  2          2 6     3   5
+--R                  (3A B b  + 19A B a b  + 13B a b )c  + (- 3A B b  - 7B a b )c
+--R                + 
+--R                   3 7
+--R                  B b
+--R             *
+--R                ROOT
+--R                                 6     2 5
+--R                         (- 16a c  + 4b c )
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4   2     3   2      2 2 3  5
+--R                                - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                              + 
+--R                                       4 4      3     3      2 2 2 2       3 3
+--R                                    - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                  + 
+--R                                       4 4
+--R                                    - B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                   3   5      2 2   4        3 2 3     4 3 2  3
+--R                                (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                              + 
+--R                                     2 2 6        3   5      4 2 4  2
+--R                                (- 6A B b  - 20A B a b  - 11B a b )c
+--R                              + 
+--R                                     3 7     4   6      4 8
+--R                                (4A B b  + 6B a b )c - B b
+--R                           /
+--R                                   11      2 10
+--R                              64a c   - 16b c
+--R                     + 
+--R                            2            2  3     2 3           2     2 2   2
+--R                       (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                     + 
+--R                                4     2   3      2 5
+--R                       (- 2A B b  - 5B a b )c + B b
+--R                  /
+--R                         6     2 5
+--R                     8a c  - 2b c
+--R            + 
+--R                    4 2 4        4   2      3   2   3
+--R                  2A a c  + (- 2A a b  - 10A B a b)c
+--R                + 
+--R                     3     3      2 2 2 2       3 3      4 4  2
+--R                  (6A B a b  + 12A B a b  - 6A B a b - 2B a )c
+--R                + 
+--R                       2 2   4       3 2 3     4 3 2         3   5     4 2 4
+--R                  (- 6A B a b  - 2A B a b  + 6B a b )c + 2A B a b  - 2B a b
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                     +--------------------+ +------------------+
+--R                   +-----------+     |   +-----------+      | +-----------+
+--R             2 +-+ |          2  +-+ |   |          2       | |          2
+--R            c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                           6     2 5
+--R                     (16a c  - 4b c )
+--R                  *
+--R                     ROOT
+--R                               4 2 6      4   2     3   2      2 2 3  5
+--R                            - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                          + 
+--R                                     4 4      3     3      2 2 2 2       3 3
+--R                                  - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                + 
+--R                                     4 4
+--R                                  - B a
+--R                           *
+--R                               4
+--R                              c
+--R                          + 
+--R                               3   5      2 2   4        3 2 3     4 3 2  3
+--R                            (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                          + 
+--R                                 2 2 6        3   5      4 2 4  2
+--R                            (- 6A B b  - 20A B a b  - 11B a b )c
+--R                          + 
+--R                                 3 7     4   6      4 8
+--R                            (4A B b  + 6B a b )c - B b
+--R                       /
+--R                               11      2 10
+--R                          64a c   - 16b c
+--R                 + 
+--R                        2            2  3     2 3           2     2 2   2
+--R                   (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                 + 
+--R                            4     2   3      2 5
+--R                   (- 2A B b  - 5B a b )c + B b
+--R              /
+--R                     6     2 5
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                                          2  7        3          2  6       4 5
+--R                       ((- 16A a b - 32B a )c  + (4A b  + 24B a b )c  - 4B b c )
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4   2     3   2      2 2 3  5
+--R                              - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                            + 
+--R                                     4 4      3     3      2 2 2 2       3 3
+--R                                  - A b  - 12A B a b  - 24A B a b  - 8A B a b
+--R                                + 
+--R                                     4 4
+--R                                  - B a
+--R                             *
+--R                                 4
+--R                                c
+--R                            + 
+--R                                 3   5      2 2   4        3 2 3     4 3 2  3
+--R                              (4A B b  + 24A B a b  + 28A B a b  + 6B a b )c
+--R                            + 
+--R                                   2 2 6        3   5      4 2 4  2
+--R                              (- 6A B b  - 20A B a b  - 11B a b )c
+--R                            + 
+--R                                   3 7     4   6      4 8
+--R                              (4A B b  + 6B a b )c - B b
+--R                         /
+--R                                 11      2 10
+--R                            64a c   - 16b c
+--R                   + 
+--R                       3 2 5        3   2      2   2        2 3  4
+--R                     4A a c  + (- 5A a b  - 20A B a b - 4A B a )c
+--R                   + 
+--R                       3 4      2     3        2 2 2     3 3   3
+--R                     (A b  + 17A B a b  + 29A B a b  + 4B a b)c
+--R                   + 
+--R                          2   5        2   4      3 2 3  2
+--R                     (- 3A B b  - 19A B a b  - 13B a b )c
+--R                   + 
+--R                          2 6     3   5      3 7
+--R                     (3A B b  + 7B a b )c - B b
+--R                *
+--R                   ROOT
+--R                                  6     2 5
+--R                            (16a c  - 4b c )
+--R                         *
+--R                            ROOT
+--R                                      4 2 6      4   2     3   2      2 2 3  5
+--R                                   - A a c  + (2A a b  + 8A B a b + 2A B a )c
+--R                                 + 
+--R                                          4 4      3     3      2 2 2 2
+--R                                       - A b  - 12A B a b  - 24A B a b
+--R                                     + 
+--R                                             3 3     4 4
+--R                                       - 8A B a b - B a
+--R                                  *
+--R                                      4
+--R                                     c
+--R                                 + 
+--R                                           3   5      2 2   4        3 2 3
+--R                                         4A B b  + 24A B a b  + 28A B a b
+--R                                       + 
+--R                                           4 3 2
+--R                                         6B a b
+--R                                  *
+--R                                      3
+--R                                     c
+--R                                 + 
+--R                                        2 2 6        3   5      4 2 4  2
+--R                                   (- 6A B b  - 20A B a b  - 11B a b )c
+--R                                 + 
+--R                                        3 7     4   6      4 8
+--R                                   (4A B b  + 6B a b )c - B b
+--R                              /
+--R                                      11      2 10
+--R                                 64a c   - 16b c
+--R                        + 
+--R                               2            2  3     2 3           2     2 2   2
+--R                          (- 3A a b - 4A B a )c  + (A b  + 8A B a b  + 5B a b)c
+--R                        + 
+--R                                   4     2   3      2 5
+--R                          (- 2A B b  - 5B a b )c + B b
+--R                     /
+--R                            6     2 5
+--R                        8a c  - 2b c
+--R               + 
+--R                       4 2 4        4   2      3   2   3
+--R                     2A a c  + (- 2A a b  - 10A B a b)c
+--R                   + 
+--R                        3     3      2 2 2 2       3 3      4 4  2
+--R                     (6A B a b  + 12A B a b  - 6A B a b - 2B a )c
+--R                   + 
+--R                          2 2   4       3 2 3     4 3 2         3   5     4 2 4
+--R                     (- 6A B a b  - 2A B a b  + 6B a b )c + 2A B a b  - 2B a b
+--R                *
+--R                   x
+--R     + 
+--R                                    +-----------+
+--R                                 2  |          2          2
+--R           ((2A b + 2B a)c - 2B b )\|- 4a c + b   + 4A a c
+--R         + 
+--R                  2                  3
+--R           (- 2A b  - 6B a b)c + 2B b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                    +-----------+
+--R                                 2  |          2          2        2
+--R           ((2A b + 2B a)c - 2B b )\|- 4a c + b   - 4A a c  + (2A b  + 6B a b)c
+--R         + 
+--R                 3
+--R           - 2B b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2153
+
+--S 2154 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2154
+
+)clear all
+
+--S 2155 of 3139
+t0:=x^2*(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R             4      2
+--R          B x  + A x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2155
+
+--S 2156 of 3139
+r0:=B*x/c-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b*B-A*c+_
+   (-b^2*B+A*b*c+2*a*B*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (b*B-A*c+(b^2*B-A*b*c-2*a*B*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      +-----------+
+--R                      |          2                         2
+--R         ((A c - B b)\|- 4a c + b   + (- A b - 2B a)c + B b )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                      +-----------+
+--R                      |          2                       2
+--R         ((A c - B b)\|- 4a c + b   + (A b + 2B a)c - B b )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R       B x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2156
+
+--S 2157 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         c
+--R      *
+--R         ROOT
+--R                        4     2 3
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                            4 4      3        2 2   3
+--R                         - A c  + (4A B b + 2A B a)c
+--R                       + 
+--R                              2 2 2       3       4 2  2        3 3     4   2
+--R                         (- 6A B b  - 4A B a b - B a )c  + (4A B b  + 2B a b )c
+--R                       + 
+--R                            4 4
+--R                         - B b
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                  2            2            2     2         2 3
+--R                (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                            5          2            4       3 3
+--R                    (32A a c  + (- 8A b  - 16B a b)c  + 4B b c )
+--R                 *
+--R                    ROOT
+--R                              4 4      3        2 2   3
+--R                           - A c  + (4A B b + 2A B a)c
+--R                         + 
+--R                                2 2 2       3       4 2  2
+--R                           (- 6A B b  - 4A B a b - B a )c
+--R                         + 
+--R                                3 3     4   2      4 4
+--R                           (4A B b  + 2B a b )c - B b
+--R                      /
+--R                              7      2 6
+--R                         64a c  - 16b c
+--R                + 
+--R                      2     3     2   2       2        3 2  2
+--R                  - 4A B a c  + (A B b  + 8A B a b + 4B a )c
+--R                + 
+--R                         2 3     3   2      3 4
+--R                  (- 2A B b  - 5B a b )c + B b
+--R             *
+--R                ROOT
+--R                               4     2 3
+--R                         (16a c  - 4b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4      3        2 2   3
+--R                                - A c  + (4A B b + 2A B a)c
+--R                              + 
+--R                                     2 2 2       3       4 2  2
+--R                                (- 6A B b  - 4A B a b - B a )c
+--R                              + 
+--R                                     3 3     4   2      4 4
+--R                                (4A B b  + 2B a b )c - B b
+--R                           /
+--R                                   7      2 6
+--R                              64a c  - 16b c
+--R                     + 
+--R                         2            2            2     2         2 3
+--R                       (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R                  /
+--R                         4     2 3
+--R                     8a c  - 2b c
+--R            + 
+--R                    4 3     3     2      2 2 2       3        4 2         3 3
+--R                  2A c  - 6A B b c  + (6A B b  - 2A B a b - 2B a )c - 2A B b
+--R                + 
+--R                    4   2
+--R                  2B a b
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                             4     2 3
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                     ROOT
+--R                               4 4      3        2 2   3
+--R                            - A c  + (4A B b + 2A B a)c
+--R                          + 
+--R                                 2 2 2       3       4 2  2
+--R                            (- 6A B b  - 4A B a b - B a )c
+--R                          + 
+--R                                 3 3     4   2      4 4
+--R                            (4A B b  + 2B a b )c - B b
+--R                       /
+--R                               7      2 6
+--R                          64a c  - 16b c
+--R                 + 
+--R                     2            2            2     2         2 3
+--R                   (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R              /
+--R                     4     2 3
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                               5          2            4       3 3
+--R                       (32A a c  + (- 8A b  - 16B a b)c  + 4B b c )
+--R                    *
+--R                       ROOT
+--R                                 4 4      3        2 2   3
+--R                              - A c  + (4A B b + 2A B a)c
+--R                            + 
+--R                                   2 2 2       3       4 2  2
+--R                              (- 6A B b  - 4A B a b - B a )c
+--R                            + 
+--R                                   3 3     4   2      4 4
+--R                              (4A B b  + 2B a b )c - B b
+--R                         /
+--R                                 7      2 6
+--R                            64a c  - 16b c
+--R                   + 
+--R                       2     3       2   2       2        3 2  2
+--R                     4A B a c  + (- A B b  - 8A B a b - 4B a )c
+--R                   + 
+--R                          2 3     3   2      3 4
+--R                     (2A B b  + 5B a b )c - B b
+--R                *
+--R                   ROOT
+--R                                    4     2 3
+--R                            (- 16a c  + 4b c )
+--R                         *
+--R                            ROOT
+--R                                      4 4      3        2 2   3
+--R                                   - A c  + (4A B b + 2A B a)c
+--R                                 + 
+--R                                        2 2 2       3       4 2  2
+--R                                   (- 6A B b  - 4A B a b - B a )c
+--R                                 + 
+--R                                        3 3     4   2      4 4
+--R                                   (4A B b  + 2B a b )c - B b
+--R                              /
+--R                                      7      2 6
+--R                                 64a c  - 16b c
+--R                        + 
+--R                            2            2            2     2         2 3
+--R                          (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R                     /
+--R                            4     2 3
+--R                        8a c  - 2b c
+--R               + 
+--R                       4 3     3     2      2 2 2       3        4 2         3 3
+--R                     2A c  - 6A B b c  + (6A B b  - 2A B a b - 2B a )c - 2A B b
+--R                   + 
+--R                       4   2
+--R                     2B a b
+--R                *
+--R                   x
+--R     + 
+--R         c
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                            4 4      3        2 2   3
+--R                         - A c  + (4A B b + 2A B a)c
+--R                       + 
+--R                              2 2 2       3       4 2  2        3 3     4   2
+--R                         (- 6A B b  - 4A B a b - B a )c  + (4A B b  + 2B a b )c
+--R                       + 
+--R                            4 4
+--R                         - B b
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                  2            2            2     2         2 3
+--R                (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                              5        2            4       3 3
+--R                    (- 32A a c  + (8A b  + 16B a b)c  - 4B b c )
+--R                 *
+--R                    ROOT
+--R                              4 4      3        2 2   3
+--R                           - A c  + (4A B b + 2A B a)c
+--R                         + 
+--R                                2 2 2       3       4 2  2
+--R                           (- 6A B b  - 4A B a b - B a )c
+--R                         + 
+--R                                3 3     4   2      4 4
+--R                           (4A B b  + 2B a b )c - B b
+--R                      /
+--R                              7      2 6
+--R                         64a c  - 16b c
+--R                + 
+--R                      2     3     2   2       2        3 2  2
+--R                  - 4A B a c  + (A B b  + 8A B a b + 4B a )c
+--R                + 
+--R                         2 3     3   2      3 4
+--R                  (- 2A B b  - 5B a b )c + B b
+--R             *
+--R                ROOT
+--R                                 4     2 3
+--R                         (- 16a c  + 4b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4      3        2 2   3
+--R                                - A c  + (4A B b + 2A B a)c
+--R                              + 
+--R                                     2 2 2       3       4 2  2
+--R                                (- 6A B b  - 4A B a b - B a )c
+--R                              + 
+--R                                     3 3     4   2      4 4
+--R                                (4A B b  + 2B a b )c - B b
+--R                           /
+--R                                   7      2 6
+--R                              64a c  - 16b c
+--R                     + 
+--R                         2            2            2     2         2 3
+--R                       (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R                  /
+--R                         4     2 3
+--R                     8a c  - 2b c
+--R            + 
+--R                    4 3     3     2      2 2 2       3        4 2         3 3
+--R                  2A c  - 6A B b c  + (6A B b  - 2A B a b - 2B a )c - 2A B b
+--R                + 
+--R                    4   2
+--R                  2B a b
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                           4     2 3
+--R                     (16a c  - 4b c )
+--R                  *
+--R                     ROOT
+--R                               4 4      3        2 2   3
+--R                            - A c  + (4A B b + 2A B a)c
+--R                          + 
+--R                                 2 2 2       3       4 2  2
+--R                            (- 6A B b  - 4A B a b - B a )c
+--R                          + 
+--R                                 3 3     4   2      4 4
+--R                            (4A B b  + 2B a b )c - B b
+--R                       /
+--R                               7      2 6
+--R                          64a c  - 16b c
+--R                 + 
+--R                     2            2            2     2         2 3
+--R                   (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R              /
+--R                     4     2 3
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                                 5        2            4       3 3
+--R                       (- 32A a c  + (8A b  + 16B a b)c  - 4B b c )
+--R                    *
+--R                       ROOT
+--R                                 4 4      3        2 2   3
+--R                              - A c  + (4A B b + 2A B a)c
+--R                            + 
+--R                                   2 2 2       3       4 2  2
+--R                              (- 6A B b  - 4A B a b - B a )c
+--R                            + 
+--R                                   3 3     4   2      4 4
+--R                              (4A B b  + 2B a b )c - B b
+--R                         /
+--R                                 7      2 6
+--R                            64a c  - 16b c
+--R                   + 
+--R                       2     3       2   2       2        3 2  2
+--R                     4A B a c  + (- A B b  - 8A B a b - 4B a )c
+--R                   + 
+--R                          2 3     3   2      3 4
+--R                     (2A B b  + 5B a b )c - B b
+--R                *
+--R                   ROOT
+--R                                  4     2 3
+--R                            (16a c  - 4b c )
+--R                         *
+--R                            ROOT
+--R                                      4 4      3        2 2   3
+--R                                   - A c  + (4A B b + 2A B a)c
+--R                                 + 
+--R                                        2 2 2       3       4 2  2
+--R                                   (- 6A B b  - 4A B a b - B a )c
+--R                                 + 
+--R                                        3 3     4   2      4 4
+--R                                   (4A B b  + 2B a b )c - B b
+--R                              /
+--R                                      7      2 6
+--R                                 64a c  - 16b c
+--R                        + 
+--R                            2            2            2     2         2 3
+--R                          (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R                     /
+--R                            4     2 3
+--R                        8a c  - 2b c
+--R               + 
+--R                       4 3     3     2      2 2 2       3        4 2         3 3
+--R                     2A c  - 6A B b c  + (6A B b  - 2A B a b - 2B a )c - 2A B b
+--R                   + 
+--R                       4   2
+--R                     2B a b
+--R                *
+--R                   x
+--R     + 
+--R       2B x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2157
+
+--S 2158 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4     2 3
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                            4 4      3        2 2   3
+--R                         - A c  + (4A B b + 2A B a)c
+--R                       + 
+--R                              2 2 2       3       4 2  2        3 3     4   2
+--R                         (- 6A B b  - 4A B a b - B a )c  + (4A B b  + 2B a b )c
+--R                       + 
+--R                            4 4
+--R                         - B b
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                  2            2            2     2         2 3
+--R                (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                            5          2            4       3 3
+--R                    (32A a c  + (- 8A b  - 16B a b)c  + 4B b c )
+--R                 *
+--R                    ROOT
+--R                              4 4      3        2 2   3
+--R                           - A c  + (4A B b + 2A B a)c
+--R                         + 
+--R                                2 2 2       3       4 2  2
+--R                           (- 6A B b  - 4A B a b - B a )c
+--R                         + 
+--R                                3 3     4   2      4 4
+--R                           (4A B b  + 2B a b )c - B b
+--R                      /
+--R                              7      2 6
+--R                         64a c  - 16b c
+--R                + 
+--R                      2     3     2   2       2        3 2  2
+--R                  - 4A B a c  + (A B b  + 8A B a b + 4B a )c
+--R                + 
+--R                         2 3     3   2      3 4
+--R                  (- 2A B b  - 5B a b )c + B b
+--R             *
+--R                ROOT
+--R                               4     2 3
+--R                         (16a c  - 4b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4      3        2 2   3
+--R                                - A c  + (4A B b + 2A B a)c
+--R                              + 
+--R                                     2 2 2       3       4 2  2
+--R                                (- 6A B b  - 4A B a b - B a )c
+--R                              + 
+--R                                     3 3     4   2      4 4
+--R                                (4A B b  + 2B a b )c - B b
+--R                           /
+--R                                   7      2 6
+--R                              64a c  - 16b c
+--R                     + 
+--R                         2            2            2     2         2 3
+--R                       (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R                  /
+--R                         4     2 3
+--R                     8a c  - 2b c
+--R            + 
+--R                    4 3     3     2      2 2 2       3        4 2         3 3
+--R                  2A c  - 6A B b c  + (6A B b  - 2A B a b - 2B a )c - 2A B b
+--R                + 
+--R                    4   2
+--R                  2B a b
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            c\|2 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                             4     2 3
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                     ROOT
+--R                               4 4      3        2 2   3
+--R                            - A c  + (4A B b + 2A B a)c
+--R                          + 
+--R                                 2 2 2       3       4 2  2
+--R                            (- 6A B b  - 4A B a b - B a )c
+--R                          + 
+--R                                 3 3     4   2      4 4
+--R                            (4A B b  + 2B a b )c - B b
+--R                       /
+--R                               7      2 6
+--R                          64a c  - 16b c
+--R                 + 
+--R                     2            2            2     2         2 3
+--R                   (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R              /
+--R                     4     2 3
+--R                 8a c  - 2b c
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                               5          2            4       3 3
+--R                       (32A a c  + (- 8A b  - 16B a b)c  + 4B b c )
+--R                    *
+--R                       ROOT
+--R                                 4 4      3        2 2   3
+--R                              - A c  + (4A B b + 2A B a)c
+--R                            + 
+--R                                   2 2 2       3       4 2  2
+--R                              (- 6A B b  - 4A B a b - B a )c
+--R                            + 
+--R                                   3 3     4   2      4 4
+--R                              (4A B b  + 2B a b )c - B b
+--R                         /
+--R                                 7      2 6
+--R                            64a c  - 16b c
+--R                   + 
+--R                       2     3       2   2       2        3 2  2
+--R                     4A B a c  + (- A B b  - 8A B a b - 4B a )c
+--R                   + 
+--R                          2 3     3   2      3 4
+--R                     (2A B b  + 5B a b )c - B b
+--R                *
+--R                   ROOT
+--R                                    4     2 3
+--R                            (- 16a c  + 4b c )
+--R                         *
+--R                            ROOT
+--R                                      4 4      3        2 2   3
+--R                                   - A c  + (4A B b + 2A B a)c
+--R                                 + 
+--R                                        2 2 2       3       4 2  2
+--R                                   (- 6A B b  - 4A B a b - B a )c
+--R                                 + 
+--R                                        3 3     4   2      4 4
+--R                                   (4A B b  + 2B a b )c - B b
+--R                              /
+--R                                      7      2 6
+--R                                 64a c  - 16b c
+--R                        + 
+--R                            2            2            2     2         2 3
+--R                          (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R                     /
+--R                            4     2 3
+--R                        8a c  - 2b c
+--R               + 
+--R                       4 3     3     2      2 2 2       3        4 2         3 3
+--R                     2A c  - 6A B b c  + (6A B b  - 2A B a b - 2B a )c - 2A B b
+--R                   + 
+--R                       4   2
+--R                     2B a b
+--R                *
+--R                   x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2  +-+
+--R         c\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                            4 4      3        2 2   3
+--R                         - A c  + (4A B b + 2A B a)c
+--R                       + 
+--R                              2 2 2       3       4 2  2        3 3     4   2
+--R                         (- 6A B b  - 4A B a b - B a )c  + (4A B b  + 2B a b )c
+--R                       + 
+--R                            4 4
+--R                         - B b
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                  2            2            2     2         2 3
+--R                (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              5        2            4       3 3
+--R                    (- 32A a c  + (8A b  + 16B a b)c  - 4B b c )
+--R                 *
+--R                    ROOT
+--R                              4 4      3        2 2   3
+--R                           - A c  + (4A B b + 2A B a)c
+--R                         + 
+--R                                2 2 2       3       4 2  2
+--R                           (- 6A B b  - 4A B a b - B a )c
+--R                         + 
+--R                                3 3     4   2      4 4
+--R                           (4A B b  + 2B a b )c - B b
+--R                      /
+--R                              7      2 6
+--R                         64a c  - 16b c
+--R                + 
+--R                      2     3     2   2       2        3 2  2
+--R                  - 4A B a c  + (A B b  + 8A B a b + 4B a )c
+--R                + 
+--R                         2 3     3   2      3 4
+--R                  (- 2A B b  - 5B a b )c + B b
+--R             *
+--R                ROOT
+--R                                 4     2 3
+--R                         (- 16a c  + 4b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4      3        2 2   3
+--R                                - A c  + (4A B b + 2A B a)c
+--R                              + 
+--R                                     2 2 2       3       4 2  2
+--R                                (- 6A B b  - 4A B a b - B a )c
+--R                              + 
+--R                                     3 3     4   2      4 4
+--R                                (4A B b  + 2B a b )c - B b
+--R                           /
+--R                                   7      2 6
+--R                              64a c  - 16b c
+--R                     + 
+--R                         2            2            2     2         2 3
+--R                       (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R                  /
+--R                         4     2 3
+--R                     8a c  - 2b c
+--R            + 
+--R                    4 3     3     2      2 2 2       3        4 2         3 3
+--R                  2A c  - 6A B b c  + (6A B b  - 2A B a b - 2B a )c - 2A B b
+--R                + 
+--R                    4   2
+--R                  2B a b
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                    +--------------------+ +------------------+
+--R                  +-----------+     |   +-----------+      | +-----------+
+--R              +-+ |          2  +-+ |   |          2       | |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                           4     2 3
+--R                     (16a c  - 4b c )
+--R                  *
+--R                     ROOT
+--R                               4 4      3        2 2   3
+--R                            - A c  + (4A B b + 2A B a)c
+--R                          + 
+--R                                 2 2 2       3       4 2  2
+--R                            (- 6A B b  - 4A B a b - B a )c
+--R                          + 
+--R                                 3 3     4   2      4 4
+--R                            (4A B b  + 2B a b )c - B b
+--R                       /
+--R                               7      2 6
+--R                          64a c  - 16b c
+--R                 + 
+--R                     2            2            2     2         2 3
+--R                   (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R              /
+--R                     4     2 3
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                                 5        2            4       3 3
+--R                       (- 32A a c  + (8A b  + 16B a b)c  - 4B b c )
+--R                    *
+--R                       ROOT
+--R                                 4 4      3        2 2   3
+--R                              - A c  + (4A B b + 2A B a)c
+--R                            + 
+--R                                   2 2 2       3       4 2  2
+--R                              (- 6A B b  - 4A B a b - B a )c
+--R                            + 
+--R                                   3 3     4   2      4 4
+--R                              (4A B b  + 2B a b )c - B b
+--R                         /
+--R                                 7      2 6
+--R                            64a c  - 16b c
+--R                   + 
+--R                       2     3       2   2       2        3 2  2
+--R                     4A B a c  + (- A B b  - 8A B a b - 4B a )c
+--R                   + 
+--R                          2 3     3   2      3 4
+--R                     (2A B b  + 5B a b )c - B b
+--R                *
+--R                   ROOT
+--R                                  4     2 3
+--R                            (16a c  - 4b c )
+--R                         *
+--R                            ROOT
+--R                                      4 4      3        2 2   3
+--R                                   - A c  + (4A B b + 2A B a)c
+--R                                 + 
+--R                                        2 2 2       3       4 2  2
+--R                                   (- 6A B b  - 4A B a b - B a )c
+--R                                 + 
+--R                                        3 3     4   2      4 4
+--R                                   (4A B b  + 2B a b )c - B b
+--R                              /
+--R                                      7      2 6
+--R                                 64a c  - 16b c
+--R                        + 
+--R                            2            2            2     2         2 3
+--R                          (A b + 4A B a)c  + (- 2A B b  - 3B a b)c + B b
+--R                     /
+--R                            4     2 3
+--R                        8a c  - 2b c
+--R               + 
+--R                       4 3     3     2      2 2 2       3        4 2         3 3
+--R                     2A c  - 6A B b c  + (6A B b  - 2A B a b - 2B a )c - 2A B b
+--R                   + 
+--R                       4   2
+--R                     2B a b
+--R                *
+--R                   x
+--R     + 
+--R                          +-----------+
+--R                          |          2                         2
+--R         ((- 2A c + 2B b)\|- 4a c + b   + (2A b + 4B a)c - 2B b )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                          |          2                           2
+--R         ((- 2A c + 2B b)\|- 4a c + b   + (- 2A b - 4B a)c + 2B b )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2158
+
+--S 2159 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2159
+
+)clear all
+
+--S 2160 of 3139
+t0:=(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2160
+
+--S 2161 of 3139
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(B+(-b*B+2*A*c)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(B+(b*B-2*A*c)/sqrt(b^2-_
+   4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2                | |          2
+--R         (B\|- 4a c + b   + 2A c - B b)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2                |   |          2
+--R         (B\|- 4a c + b   - 2A c + B b)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2161
+
+--S 2162 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R                                  +------------------------+
+--R                                  |   4 2     2 2       4 2
+--R                    2 2       2   |- A c  + 2A B a c - B a       2
+--R                (16a c  - 4a b c) |------------------------  + (A b - 4A B a)c
+--R                                  |       3 3      2 2 2
+--R                                 \|    64a c  - 16a b c
+--R              + 
+--R                 2
+--R                B a b
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                           2         3  2            3       2 2
+--R                    ((16A a b - 32B a )c  + (- 4A a b  + 8B a b )c)
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                    3   2       3 2       2 2        2   2
+--R                  4A a c  + (- A b  - 4A B a )c + A B a b
+--R             *
+--R                ROOT
+--R                                         +------------------------+
+--R                                         |   4 2     2 2       4 2
+--R                           2 2       2   |- A c  + 2A B a c - B a
+--R                       (16a c  - 4a b c) |------------------------
+--R                                         |       3 3      2 2 2
+--R                                        \|    64a c  - 16a b c
+--R                     + 
+--R                         2                2
+--R                       (A b - 4A B a)c + B a b
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 4 2     3            3        4 2
+--R              (2A c  - 2A B b c + 2A B a b - 2B a )x
+--R     + 
+--R       -
+--R            ROOT
+--R                                       +------------------------+
+--R                                       |   4 2     2 2       4 2
+--R                         2 2       2   |- A c  + 2A B a c - B a
+--R                   (- 16a c  + 4a b c) |------------------------
+--R                                       |       3 3      2 2 2
+--R                                      \|    64a c  - 16a b c
+--R                 + 
+--R                     2                2
+--R                   (A b - 4A B a)c + B a b
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                              2         3  2            3       2 2
+--R                       ((16A a b - 32B a )c  + (- 4A a b  + 8B a b )c)
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                         3   2     3 2       2 2        2   2
+--R                     - 4A a c  + (A b  + 4A B a )c - A B a b
+--R                *
+--R                   ROOT
+--R                                              +------------------------+
+--R                                              |   4 2     2 2       4 2
+--R                                2 2       2   |- A c  + 2A B a c - B a
+--R                          (- 16a c  + 4a b c) |------------------------
+--R                                              |       3 3      2 2 2
+--R                                             \|    64a c  - 16a b c
+--R                        + 
+--R                            2                2
+--R                          (A b - 4A B a)c + B a b
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    4 2     3            3        4 2
+--R                 (2A c  - 2A B b c + 2A B a b - 2B a )x
+--R     + 
+--R         ROOT
+--R                                    +------------------------+
+--R                                    |   4 2     2 2       4 2
+--R                      2 2       2   |- A c  + 2A B a c - B a       2
+--R                (- 16a c  + 4a b c) |------------------------  + (A b - 4A B a)c
+--R                                    |       3 3      2 2 2
+--R                                   \|    64a c  - 16a b c
+--R              + 
+--R                 2
+--R                B a b
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                             2         3  2          3       2 2
+--R                    ((- 16A a b + 32B a )c  + (4A a b  - 8B a b )c)
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                    3   2       3 2       2 2        2   2
+--R                  4A a c  + (- A b  - 4A B a )c + A B a b
+--R             *
+--R                ROOT
+--R                                           +------------------------+
+--R                                           |   4 2     2 2       4 2
+--R                             2 2       2   |- A c  + 2A B a c - B a
+--R                       (- 16a c  + 4a b c) |------------------------
+--R                                           |       3 3      2 2 2
+--R                                          \|    64a c  - 16a b c
+--R                     + 
+--R                         2                2
+--R                       (A b - 4A B a)c + B a b
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 4 2     3            3        4 2
+--R              (2A c  - 2A B b c + 2A B a b - 2B a )x
+--R     + 
+--R       -
+--R            ROOT
+--R                                     +------------------------+
+--R                                     |   4 2     2 2       4 2
+--R                       2 2       2   |- A c  + 2A B a c - B a
+--R                   (16a c  - 4a b c) |------------------------
+--R                                     |       3 3      2 2 2
+--R                                    \|    64a c  - 16a b c
+--R                 + 
+--R                     2                2
+--R                   (A b - 4A B a)c + B a b
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                                2         3  2          3       2 2
+--R                       ((- 16A a b + 32B a )c  + (4A a b  - 8B a b )c)
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                         3   2     3 2       2 2        2   2
+--R                     - 4A a c  + (A b  + 4A B a )c - A B a b
+--R                *
+--R                   ROOT
+--R                                            +------------------------+
+--R                                            |   4 2     2 2       4 2
+--R                              2 2       2   |- A c  + 2A B a c - B a
+--R                          (16a c  - 4a b c) |------------------------
+--R                                            |       3 3      2 2 2
+--R                                           \|    64a c  - 16a b c
+--R                        + 
+--R                            2                2
+--R                          (A b - 4A B a)c + B a b
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    4 2     3            3        4 2
+--R                 (2A c  - 2A B b c + 2A B a b - 2B a )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2162
+
+--S 2163 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                  +------------------------+
+--R                                  |   4 2     2 2       4 2
+--R                    2 2       2   |- A c  + 2A B a c - B a       2
+--R                (16a c  - 4a b c) |------------------------  + (A b - 4A B a)c
+--R                                  |       3 3      2 2 2
+--R                                 \|    64a c  - 16a b c
+--R              + 
+--R                 2
+--R                B a b
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                           2         3  2            3       2 2
+--R                    ((16A a b - 32B a )c  + (- 4A a b  + 8B a b )c)
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                    3   2       3 2       2 2        2   2
+--R                  4A a c  + (- A b  - 4A B a )c + A B a b
+--R             *
+--R                ROOT
+--R                                         +------------------------+
+--R                                         |   4 2     2 2       4 2
+--R                           2 2       2   |- A c  + 2A B a c - B a
+--R                       (16a c  - 4a b c) |------------------------
+--R                                         |       3 3      2 2 2
+--R                                        \|    64a c  - 16a b c
+--R                     + 
+--R                         2                2
+--R                       (A b - 4A B a)c + B a b
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 4 2     3            3        4 2
+--R              (2A c  - 2A B b c + 2A B a b - 2B a )x
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2  +-+
+--R            \|2 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                                       +------------------------+
+--R                                       |   4 2     2 2       4 2
+--R                         2 2       2   |- A c  + 2A B a c - B a
+--R                   (- 16a c  + 4a b c) |------------------------
+--R                                       |       3 3      2 2 2
+--R                                      \|    64a c  - 16a b c
+--R                 + 
+--R                     2                2
+--R                   (A b - 4A B a)c + B a b
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                              2         3  2            3       2 2
+--R                       ((16A a b - 32B a )c  + (- 4A a b  + 8B a b )c)
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                         3   2     3 2       2 2        2   2
+--R                     - 4A a c  + (A b  + 4A B a )c - A B a b
+--R                *
+--R                   ROOT
+--R                                              +------------------------+
+--R                                              |   4 2     2 2       4 2
+--R                                2 2       2   |- A c  + 2A B a c - B a
+--R                          (- 16a c  + 4a b c) |------------------------
+--R                                              |       3 3      2 2 2
+--R                                             \|    64a c  - 16a b c
+--R                        + 
+--R                            2                2
+--R                          (A b - 4A B a)c + B a b
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    4 2     3            3        4 2
+--R                 (2A c  - 2A B b c + 2A B a b - 2B a )x
+--R     + 
+--R              +-----------+
+--R          +-+ |          2  +-+
+--R         \|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                                    +------------------------+
+--R                                    |   4 2     2 2       4 2
+--R                      2 2       2   |- A c  + 2A B a c - B a       2
+--R                (- 16a c  + 4a b c) |------------------------  + (A b - 4A B a)c
+--R                                    |       3 3      2 2 2
+--R                                   \|    64a c  - 16a b c
+--R              + 
+--R                 2
+--R                B a b
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                             2         3  2          3       2 2
+--R                    ((- 16A a b + 32B a )c  + (4A a b  - 8B a b )c)
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                    3   2       3 2       2 2        2   2
+--R                  4A a c  + (- A b  - 4A B a )c + A B a b
+--R             *
+--R                ROOT
+--R                                           +------------------------+
+--R                                           |   4 2     2 2       4 2
+--R                             2 2       2   |- A c  + 2A B a c - B a
+--R                       (- 16a c  + 4a b c) |------------------------
+--R                                           |       3 3      2 2 2
+--R                                          \|    64a c  - 16a b c
+--R                     + 
+--R                         2                2
+--R                       (A b - 4A B a)c + B a b
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 4 2     3            3        4 2
+--R              (2A c  - 2A B b c + 2A B a b - 2B a )x
+--R     + 
+--R       -
+--R                                   +--------------------+ +------------------+
+--R                 +-----------+     |   +-----------+      | +-----------+
+--R             +-+ |          2  +-+ |   |          2       | |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                     +------------------------+
+--R                                     |   4 2     2 2       4 2
+--R                       2 2       2   |- A c  + 2A B a c - B a
+--R                   (16a c  - 4a b c) |------------------------
+--R                                     |       3 3      2 2 2
+--R                                    \|    64a c  - 16a b c
+--R                 + 
+--R                     2                2
+--R                   (A b - 4A B a)c + B a b
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                                2         3  2          3       2 2
+--R                       ((- 16A a b + 32B a )c  + (4A a b  - 8B a b )c)
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                         3   2     3 2       2 2        2   2
+--R                     - 4A a c  + (A b  + 4A B a )c - A B a b
+--R                *
+--R                   ROOT
+--R                                            +------------------------+
+--R                                            |   4 2     2 2       4 2
+--R                              2 2       2   |- A c  + 2A B a c - B a
+--R                          (16a c  - 4a b c) |------------------------
+--R                                            |       3 3      2 2 2
+--R                                           \|    64a c  - 16a b c
+--R                        + 
+--R                            2                2
+--R                          (A b - 4A B a)c + B a b
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    4 2     3            3        4 2
+--R                 (2A c  - 2A B b c + 2A B a b - 2B a )x
+--R     + 
+--R                                            +------------------+
+--R               +-----------+                | +-----------+
+--R               |          2                 | |          2
+--R         (- 2B\|- 4a c + b   - 4A c + 2B b)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R               +-----------+                |   +-----------+
+--R               |          2                 |   |          2
+--R         (- 2B\|- 4a c + b   + 4A c - 2B b)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2163
+
+--S 2164 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2164
+
+)clear all
+
+--S 2165 of 3139
+t0:=(A+B*x^2)/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2165
+
+--S 2166 of 3139
+r0:=-A/(a*x)-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (A+(A*b-2*a*B)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(A+(-A*b+_
+   2*a*B)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                     +------------------+
+--R                +-----------+                        | +-----------+
+--R                |          2                     +-+ | |          2
+--R         (- A x\|- 4a c + b   + (- A b + 2B a)x)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                   +--------------------+
+--R                +-----------+                      |   +-----------+
+--R                |          2                   +-+ |   |          2
+--R         (- A x\|- 4a c + b   + (A b - 2B a)x)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R           +-+ |          2  |   |          2       | |          2
+--R       - A\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R         +-+ |          2  |   |          2       | |          2
+--R     a x\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2166
+
+--S 2167 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                         4      3 2
+--R                     (16a c - 4a b )
+--R                  *
+--R                     ROOT
+--R                               4 2 2      4   2     3   2      2 2 3      4 4
+--R                            - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                          + 
+--R                              3     3     2 2 2 2       3 3     4 4
+--R                            4A B a b  - 6A B a b  + 4A B a b - B a
+--R                       /
+--R                             7       6 2
+--R                          64a c - 16a b
+--R                 + 
+--R                        2            2      2 3           2    2 2
+--R                   (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R              /
+--R                   4      3 2
+--R                 8a c - 2a b
+--R         *
+--R            log
+--R                             5 2           4 2        5          3 4       4 3
+--R                       (32A a c  + (- 24A a b  + 16B a b)c + 4A a b  - 4B a b )
+--R                    *
+--R                       ROOT
+--R                                 4 2 2      4   2     3   2      2 2 3      4 4
+--R                              - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                            + 
+--R                                3     3     2 2 2 2       3 3     4 4
+--R                              4A B a b  - 6A B a b  + 4A B a b - B a
+--R                         /
+--R                               7       6 2
+--R                            64a c - 16a b
+--R                   + 
+--R                        3 2      2   3  2
+--R                     (4A a b - 4A B a )c
+--R                   + 
+--R                          3   3      2   2 2        2 3      3 4      3 5
+--R                     (- 5A a b  + 13A B a b  - 12A B a b + 4B a )c + A b
+--R                   + 
+--R                         2     4       2 2 3    3 3 2
+--R                     - 3A B a b  + 3A B a b  - B a b
+--R                *
+--R                   ROOT
+--R                                4      3 2
+--R                            (16a c - 4a b )
+--R                         *
+--R                            ROOT
+--R                                      4 2 2      4   2     3   2      2 2 3
+--R                                   - A a c  + (2A a b  - 4A B a b + 2A B a )c
+--R                                 + 
+--R                                      4 4     3     3     2 2 2 2       3 3
+--R                                   - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                                 + 
+--R                                      4 4
+--R                                   - B a
+--R                              /
+--R                                    7       6 2
+--R                                 64a c - 16a b
+--R                        + 
+--R                               2            2      2 3           2    2 2
+--R                          (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R                     /
+--R                          4      3 2
+--R                        8a c - 2a b
+--R               + 
+--R                       4   3        4 2     3       2
+--R                     2A a c  + (- 2A b  + 2A B a b)c
+--R                   + 
+--R                        3   3     2 2   2       3 2      4 3
+--R                     (2A B b  - 6A B a b  + 6A B a b - 2B a )c
+--R                *
+--R                   x
+--R     + 
+--R         a x
+--R      *
+--R         ROOT
+--R                        4      3 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                            4 2 2      4   2     3   2      2 2 3      4 4
+--R                         - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                       + 
+--R                           3     3     2 2 2 2       3 3     4 4
+--R                         4A B a b  - 6A B a b  + 4A B a b - B a
+--R                    /
+--R                          7       6 2
+--R                       64a c - 16a b
+--R              + 
+--R                     2            2      2 3           2    2 2
+--R                (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                          5 2           4 2        5          3 4       4 3
+--R                    (32A a c  + (- 24A a b  + 16B a b)c + 4A a b  - 4B a b )
+--R                 *
+--R                    ROOT
+--R                              4 2 2      4   2     3   2      2 2 3      4 4
+--R                           - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                         + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                           4A B a b  - 6A B a b  + 4A B a b - B a
+--R                      /
+--R                            7       6 2
+--R                         64a c - 16a b
+--R                + 
+--R                       3 2      2   3  2
+--R                  (- 4A a b + 4A B a )c
+--R                + 
+--R                     3   3      2   2 2        2 3      3 4      3 5     2     4
+--R                  (5A a b  - 13A B a b  + 12A B a b - 4B a )c - A b  + 3A B a b
+--R                + 
+--R                        2 2 3    3 3 2
+--R                  - 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                               4      3 2
+--R                         (- 16a c + 4a b )
+--R                      *
+--R                         ROOT
+--R                                   4 2 2      4   2     3   2      2 2 3
+--R                                - A a c  + (2A a b  - 4A B a b + 2A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  + 4A B a b  - 6A B a b  + 4A B a b - B a
+--R                           /
+--R                                 7       6 2
+--R                              64a c - 16a b
+--R                     + 
+--R                            2            2      2 3           2    2 2
+--R                       (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R                  /
+--R                       4      3 2
+--R                     8a c - 2a b
+--R            + 
+--R                    4   3        4 2     3       2
+--R                  2A a c  + (- 2A b  + 2A B a b)c
+--R                + 
+--R                     3   3     2 2   2       3 2      4 3
+--R                  (2A B b  - 6A B a b  + 6A B a b - 2B a )c
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                           4      3 2
+--R                     (- 16a c + 4a b )
+--R                  *
+--R                     ROOT
+--R                               4 2 2      4   2     3   2      2 2 3      4 4
+--R                            - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                          + 
+--R                              3     3     2 2 2 2       3 3     4 4
+--R                            4A B a b  - 6A B a b  + 4A B a b - B a
+--R                       /
+--R                             7       6 2
+--R                          64a c - 16a b
+--R                 + 
+--R                        2            2      2 3           2    2 2
+--R                   (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R              /
+--R                   4      3 2
+--R                 8a c - 2a b
+--R         *
+--R            log
+--R                               5 2         4 2        5          3 4       4 3
+--R                       (- 32A a c  + (24A a b  - 16B a b)c - 4A a b  + 4B a b )
+--R                    *
+--R                       ROOT
+--R                                 4 2 2      4   2     3   2      2 2 3      4 4
+--R                              - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                            + 
+--R                                3     3     2 2 2 2       3 3     4 4
+--R                              4A B a b  - 6A B a b  + 4A B a b - B a
+--R                         /
+--R                               7       6 2
+--R                            64a c - 16a b
+--R                   + 
+--R                        3 2      2   3  2
+--R                     (4A a b - 4A B a )c
+--R                   + 
+--R                          3   3      2   2 2        2 3      3 4      3 5
+--R                     (- 5A a b  + 13A B a b  - 12A B a b + 4B a )c + A b
+--R                   + 
+--R                         2     4       2 2 3    3 3 2
+--R                     - 3A B a b  + 3A B a b  - B a b
+--R                *
+--R                   ROOT
+--R                                  4      3 2
+--R                            (- 16a c + 4a b )
+--R                         *
+--R                            ROOT
+--R                                      4 2 2      4   2     3   2      2 2 3
+--R                                   - A a c  + (2A a b  - 4A B a b + 2A B a )c
+--R                                 + 
+--R                                      4 4     3     3     2 2 2 2       3 3
+--R                                   - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                                 + 
+--R                                      4 4
+--R                                   - B a
+--R                              /
+--R                                    7       6 2
+--R                                 64a c - 16a b
+--R                        + 
+--R                               2            2      2 3           2    2 2
+--R                          (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R                     /
+--R                          4      3 2
+--R                        8a c - 2a b
+--R               + 
+--R                       4   3        4 2     3       2
+--R                     2A a c  + (- 2A b  + 2A B a b)c
+--R                   + 
+--R                        3   3     2 2   2       3 2      4 3
+--R                     (2A B b  - 6A B a b  + 6A B a b - 2B a )c
+--R                *
+--R                   x
+--R     + 
+--R         a x
+--R      *
+--R         ROOT
+--R                      4      3 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                            4 2 2      4   2     3   2      2 2 3      4 4
+--R                         - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                       + 
+--R                           3     3     2 2 2 2       3 3     4 4
+--R                         4A B a b  - 6A B a b  + 4A B a b - B a
+--R                    /
+--R                          7       6 2
+--R                       64a c - 16a b
+--R              + 
+--R                     2            2      2 3           2    2 2
+--R                (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                            5 2         4 2        5          3 4       4 3
+--R                    (- 32A a c  + (24A a b  - 16B a b)c - 4A a b  + 4B a b )
+--R                 *
+--R                    ROOT
+--R                              4 2 2      4   2     3   2      2 2 3      4 4
+--R                           - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                         + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                           4A B a b  - 6A B a b  + 4A B a b - B a
+--R                      /
+--R                            7       6 2
+--R                         64a c - 16a b
+--R                + 
+--R                       3 2      2   3  2
+--R                  (- 4A a b + 4A B a )c
+--R                + 
+--R                     3   3      2   2 2        2 3      3 4      3 5     2     4
+--R                  (5A a b  - 13A B a b  + 12A B a b - 4B a )c - A b  + 3A B a b
+--R                + 
+--R                        2 2 3    3 3 2
+--R                  - 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                             4      3 2
+--R                         (16a c - 4a b )
+--R                      *
+--R                         ROOT
+--R                                   4 2 2      4   2     3   2      2 2 3
+--R                                - A a c  + (2A a b  - 4A B a b + 2A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  + 4A B a b  - 6A B a b  + 4A B a b - B a
+--R                           /
+--R                                 7       6 2
+--R                              64a c - 16a b
+--R                     + 
+--R                            2            2      2 3           2    2 2
+--R                       (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R                  /
+--R                       4      3 2
+--R                     8a c - 2a b
+--R            + 
+--R                    4   3        4 2     3       2
+--R                  2A a c  + (- 2A b  + 2A B a b)c
+--R                + 
+--R                     3   3     2 2   2       3 2      4 3
+--R                  (2A B b  - 6A B a b  + 6A B a b - 2B a )c
+--R             *
+--R                x
+--R     + 
+--R       - 2A
+--R  /
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2167
+
+--S 2168 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R              +-+ |          2  |   |          2       | |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                         4      3 2
+--R                     (16a c - 4a b )
+--R                  *
+--R                     ROOT
+--R                               4 2 2      4   2     3   2      2 2 3      4 4
+--R                            - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                          + 
+--R                              3     3     2 2 2 2       3 3     4 4
+--R                            4A B a b  - 6A B a b  + 4A B a b - B a
+--R                       /
+--R                             7       6 2
+--R                          64a c - 16a b
+--R                 + 
+--R                        2            2      2 3           2    2 2
+--R                   (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R              /
+--R                   4      3 2
+--R                 8a c - 2a b
+--R         *
+--R            log
+--R                             5 2           4 2        5          3 4       4 3
+--R                       (32A a c  + (- 24A a b  + 16B a b)c + 4A a b  - 4B a b )
+--R                    *
+--R                       ROOT
+--R                                 4 2 2      4   2     3   2      2 2 3      4 4
+--R                              - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                            + 
+--R                                3     3     2 2 2 2       3 3     4 4
+--R                              4A B a b  - 6A B a b  + 4A B a b - B a
+--R                         /
+--R                               7       6 2
+--R                            64a c - 16a b
+--R                   + 
+--R                        3 2      2   3  2
+--R                     (4A a b - 4A B a )c
+--R                   + 
+--R                          3   3      2   2 2        2 3      3 4      3 5
+--R                     (- 5A a b  + 13A B a b  - 12A B a b + 4B a )c + A b
+--R                   + 
+--R                         2     4       2 2 3    3 3 2
+--R                     - 3A B a b  + 3A B a b  - B a b
+--R                *
+--R                   ROOT
+--R                                4      3 2
+--R                            (16a c - 4a b )
+--R                         *
+--R                            ROOT
+--R                                      4 2 2      4   2     3   2      2 2 3
+--R                                   - A a c  + (2A a b  - 4A B a b + 2A B a )c
+--R                                 + 
+--R                                      4 4     3     3     2 2 2 2       3 3
+--R                                   - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                                 + 
+--R                                      4 4
+--R                                   - B a
+--R                              /
+--R                                    7       6 2
+--R                                 64a c - 16a b
+--R                        + 
+--R                               2            2      2 3           2    2 2
+--R                          (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R                     /
+--R                          4      3 2
+--R                        8a c - 2a b
+--R               + 
+--R                       4   3        4 2     3       2
+--R                     2A a c  + (- 2A b  + 2A B a b)c
+--R                   + 
+--R                        3   3     2 2   2       3 2      4 3
+--R                     (2A B b  - 6A B a b  + 6A B a b - 2B a )c
+--R                *
+--R                   x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2
+--R         a\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                        4      3 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                            4 2 2      4   2     3   2      2 2 3      4 4
+--R                         - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                       + 
+--R                           3     3     2 2 2 2       3 3     4 4
+--R                         4A B a b  - 6A B a b  + 4A B a b - B a
+--R                    /
+--R                          7       6 2
+--R                       64a c - 16a b
+--R              + 
+--R                     2            2      2 3           2    2 2
+--R                (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          5 2           4 2        5          3 4       4 3
+--R                    (32A a c  + (- 24A a b  + 16B a b)c + 4A a b  - 4B a b )
+--R                 *
+--R                    ROOT
+--R                              4 2 2      4   2     3   2      2 2 3      4 4
+--R                           - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                         + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                           4A B a b  - 6A B a b  + 4A B a b - B a
+--R                      /
+--R                            7       6 2
+--R                         64a c - 16a b
+--R                + 
+--R                       3 2      2   3  2
+--R                  (- 4A a b + 4A B a )c
+--R                + 
+--R                     3   3      2   2 2        2 3      3 4      3 5     2     4
+--R                  (5A a b  - 13A B a b  + 12A B a b - 4B a )c - A b  + 3A B a b
+--R                + 
+--R                        2 2 3    3 3 2
+--R                  - 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                               4      3 2
+--R                         (- 16a c + 4a b )
+--R                      *
+--R                         ROOT
+--R                                   4 2 2      4   2     3   2      2 2 3
+--R                                - A a c  + (2A a b  - 4A B a b + 2A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  + 4A B a b  - 6A B a b  + 4A B a b - B a
+--R                           /
+--R                                 7       6 2
+--R                              64a c - 16a b
+--R                     + 
+--R                            2            2      2 3           2    2 2
+--R                       (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R                  /
+--R                       4      3 2
+--R                     8a c - 2a b
+--R            + 
+--R                    4   3        4 2     3       2
+--R                  2A a c  + (- 2A b  + 2A B a b)c
+--R                + 
+--R                     3   3     2 2   2       3 2      4 3
+--R                  (2A B b  - 6A B a b  + 6A B a b - 2B a )c
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2
+--R            a\|2 \|- 4a c + b
+--R         *
+--R            ROOT
+--R                           4      3 2
+--R                     (- 16a c + 4a b )
+--R                  *
+--R                     ROOT
+--R                               4 2 2      4   2     3   2      2 2 3      4 4
+--R                            - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                          + 
+--R                              3     3     2 2 2 2       3 3     4 4
+--R                            4A B a b  - 6A B a b  + 4A B a b - B a
+--R                       /
+--R                             7       6 2
+--R                          64a c - 16a b
+--R                 + 
+--R                        2            2      2 3           2    2 2
+--R                   (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R              /
+--R                   4      3 2
+--R                 8a c - 2a b
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                               5 2         4 2        5          3 4       4 3
+--R                       (- 32A a c  + (24A a b  - 16B a b)c - 4A a b  + 4B a b )
+--R                    *
+--R                       ROOT
+--R                                 4 2 2      4   2     3   2      2 2 3      4 4
+--R                              - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                            + 
+--R                                3     3     2 2 2 2       3 3     4 4
+--R                              4A B a b  - 6A B a b  + 4A B a b - B a
+--R                         /
+--R                               7       6 2
+--R                            64a c - 16a b
+--R                   + 
+--R                        3 2      2   3  2
+--R                     (4A a b - 4A B a )c
+--R                   + 
+--R                          3   3      2   2 2        2 3      3 4      3 5
+--R                     (- 5A a b  + 13A B a b  - 12A B a b + 4B a )c + A b
+--R                   + 
+--R                         2     4       2 2 3    3 3 2
+--R                     - 3A B a b  + 3A B a b  - B a b
+--R                *
+--R                   ROOT
+--R                                  4      3 2
+--R                            (- 16a c + 4a b )
+--R                         *
+--R                            ROOT
+--R                                      4 2 2      4   2     3   2      2 2 3
+--R                                   - A a c  + (2A a b  - 4A B a b + 2A B a )c
+--R                                 + 
+--R                                      4 4     3     3     2 2 2 2       3 3
+--R                                   - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                                 + 
+--R                                      4 4
+--R                                   - B a
+--R                              /
+--R                                    7       6 2
+--R                                 64a c - 16a b
+--R                        + 
+--R                               2            2      2 3           2    2 2
+--R                          (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R                     /
+--R                          4      3 2
+--R                        8a c - 2a b
+--R               + 
+--R                       4   3        4 2     3       2
+--R                     2A a c  + (- 2A b  + 2A B a b)c
+--R                   + 
+--R                        3   3     2 2   2       3 2      4 3
+--R                     (2A B b  - 6A B a b  + 6A B a b - 2B a )c
+--R                *
+--R                   x
+--R     + 
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R           +-+ |          2  |   |          2       | |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                      4      3 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                            4 2 2      4   2     3   2      2 2 3      4 4
+--R                         - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                       + 
+--R                           3     3     2 2 2 2       3 3     4 4
+--R                         4A B a b  - 6A B a b  + 4A B a b - B a
+--R                    /
+--R                          7       6 2
+--R                       64a c - 16a b
+--R              + 
+--R                     2            2      2 3           2    2 2
+--R                (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                            5 2         4 2        5          3 4       4 3
+--R                    (- 32A a c  + (24A a b  - 16B a b)c - 4A a b  + 4B a b )
+--R                 *
+--R                    ROOT
+--R                              4 2 2      4   2     3   2      2 2 3      4 4
+--R                           - A a c  + (2A a b  - 4A B a b + 2A B a )c - A b
+--R                         + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                           4A B a b  - 6A B a b  + 4A B a b - B a
+--R                      /
+--R                            7       6 2
+--R                         64a c - 16a b
+--R                + 
+--R                       3 2      2   3  2
+--R                  (- 4A a b + 4A B a )c
+--R                + 
+--R                     3   3      2   2 2        2 3      3 4      3 5     2     4
+--R                  (5A a b  - 13A B a b  + 12A B a b - 4B a )c - A b  + 3A B a b
+--R                + 
+--R                        2 2 3    3 3 2
+--R                  - 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                             4      3 2
+--R                         (16a c - 4a b )
+--R                      *
+--R                         ROOT
+--R                                   4 2 2      4   2     3   2      2 2 3
+--R                                - A a c  + (2A a b  - 4A B a b + 2A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  + 4A B a b  - 6A B a b  + 4A B a b - B a
+--R                           /
+--R                                 7       6 2
+--R                              64a c - 16a b
+--R                     + 
+--R                            2            2      2 3           2    2 2
+--R                       (- 3A a b + 4A B a )c + A b  - 2A B a b  + B a b
+--R                  /
+--R                       4      3 2
+--R                     8a c - 2a b
+--R            + 
+--R                    4   3        4 2     3       2
+--R                  2A a c  + (- 2A b  + 2A B a b)c
+--R                + 
+--R                     3   3     2 2   2       3 2      4 3
+--R                  (2A B b  - 6A B a b  + 6A B a b - 2B a )c
+--R             *
+--R                x
+--R     + 
+--R                                              +------------------+
+--R             +-----------+                    | +-----------+
+--R             |          2                 +-+ | |          2
+--R         (2A\|- 4a c + b   + 2A b - 4B a)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                              +--------------------+
+--R             +-----------+                    |   +-----------+
+--R             |          2                 +-+ |   |          2
+--R         (2A\|- 4a c + b   - 2A b + 4B a)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R     2a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2168
+
+--S 2169 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2169
+
+)clear all
+
+--S 2170 of 3139
+t0:=(A+B*x^2)/(x^4*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  ------------------
+--R           8      6      4
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2170
+
+--S 2171 of 3139
+r0:=-1/3*A/(a*x^3)+(A*b-a*B)/(a^2*x)+atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(A*b-a*B+(-a*b*B+A*(b^2-2*a*c))/sqrt(b^2-_
+   4*a*c))/(a^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(A*b-a*B+(-A*b^2+a*b*B+2*a*A*c)/_
+   sqrt(b^2-4*a*c))/(a^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R                        3 |          2                    2           3  +-+
+--R         ((3A b - 3B a)x \|- 4a c + b   + (- 6A a c + 3A b  - 3B a b)x )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                        3 |          2                  2           3  +-+
+--R         ((3A b - 3B a)x \|- 4a c + b   + (6A a c - 3A b  + 3B a b)x )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                   +--------------------+
+--R                                     +-----------+ |   +-----------+
+--R                        2        +-+ |          2  |   |          2
+--R         ((3A b - 3B a)x  - A a)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R       2 3 +-+ |          2  |   |          2       | |          2
+--R     3a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2171
+
+--S 2172 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R              2 3
+--R            3a x
+--R         *
+--R            ROOT
+--R                         6      5 2
+--R                     (16a c - 4a b )
+--R                  *
+--R                     ROOT
+--R                               4 4 4      4 3 2     3   4      2 2 5  3
+--R                            - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                          + 
+--R                                     4 2 4      3   3 3      2 2 4 2       3 5
+--R                                - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                              + 
+--R                                   4 6
+--R                                - B a
+--R                           *
+--R                               2
+--R                              c
+--R                          + 
+--R                                  4   6      3   2 5      2 2 3 4        3 4 3
+--R                                6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                              + 
+--R                                  4 5 2
+--R                                2B a b
+--R                           *
+--R                              c
+--R                          + 
+--R                               4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                            - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                       /
+--R                             11       10 2
+--R                          64a  c - 16a  b
+--R                 + 
+--R                      2 2          3  2        2   3         2 2     2 3
+--R                   (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c
+--R                 + 
+--R                    2 5           4    2 2 3
+--R                   A b  - 2A B a b  + B a b
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R            log
+--R                               7         8  2           6 3        7 2
+--R                         (48A a b - 32B a )c  + (- 28A a b  + 24B a b )c
+--R                       + 
+--R                             5 5       6 4
+--R                         4A a b  - 4B a b
+--R                    *
+--R                       ROOT
+--R                                 4 4 4      4 3 2     3   4      2 2 5  3
+--R                              - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                            + 
+--R                                       4 2 4      3   3 3      2 2 4 2
+--R                                  - 11A a b  + 28A B a b  - 24A B a b
+--R                                + 
+--R                                      3 5     4 6
+--R                                  8A B a b - B a
+--R                             *
+--R                                 2
+--R                                c
+--R                            + 
+--R                                    4   6      3   2 5      2 2 3 4        3 4 3
+--R                                  6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                                + 
+--R                                    4 5 2
+--R                                  2B a b
+--R                             *
+--R                                c
+--R                            + 
+--R                               4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                            - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                         /
+--R                               11       10 2
+--R                            64a  c - 16a  b
+--R                   + 
+--R                       3 4 4         3 3 2      2   4        2 5  3
+--R                     4A a c  + (- 17A a b  + 20A B a b - 4A B a )c
+--R                   + 
+--R                         3 2 4      2   3 3        2 4 2     3 5   2
+--R                     (20A a b  - 41A B a b  + 25A B a b  - 4B a b)c
+--R                   + 
+--R                          3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                     (- 8A a b  + 21A B a b  - 18A B a b  + 5B a b )c + A b
+--R                   + 
+--R                         2     7       2 2 6    3 3 5
+--R                     - 3A B a b  + 3A B a b  - B a b
+--R                *
+--R                   ROOT
+--R                                6      5 2
+--R                            (16a c - 4a b )
+--R                         *
+--R                            ROOT
+--R                                      4 4 4      4 3 2     3   4      2 2 5  3
+--R                                   - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                                 + 
+--R                                            4 2 4      3   3 3      2 2 4 2
+--R                                       - 11A a b  + 28A B a b  - 24A B a b
+--R                                     + 
+--R                                           3 5     4 6
+--R                                       8A B a b - B a
+--R                                  *
+--R                                      2
+--R                                     c
+--R                                 + 
+--R                                         4   6      3   2 5      2 2 3 4
+--R                                       6A a b  - 20A B a b  + 24A B a b
+--R                                     + 
+--R                                              3 4 3     4 5 2
+--R                                       - 12A B a b  + 2B a b
+--R                                  *
+--R                                     c
+--R                                 + 
+--R                                      4 8     3     7     2 2 2 6       3 3 5
+--R                                   - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                                 + 
+--R                                      4 4 4
+--R                                   - B a b
+--R                              /
+--R                                    11       10 2
+--R                                 64a  c - 16a  b
+--R                        + 
+--R                             2 2          3  2
+--R                          (5A a b - 4A B a )c
+--R                        + 
+--R                               2   3         2 2     2 3       2 5           4
+--R                          (- 5A a b  + 8A B a b  - 3B a b)c + A b  - 2A B a b
+--R                        + 
+--R                           2 2 3
+--R                          B a b
+--R                     /
+--R                          6      5 2
+--R                        8a c - 2a b
+--R               + 
+--R                       4 2 5        4   2     3   2   4
+--R                     2A a c  + (- 6A a b  + 6A B a b)c
+--R                   + 
+--R                        4 4     3     3      2 2 2 2        3 3      4 4  3
+--R                     (2A b  + 2A B a b  - 12A B a b  + 10A B a b - 2B a )c
+--R                   + 
+--R                          3   5     2 2   4       3 2 3     4 3 2  2
+--R                     (- 2A B b  + 6A B a b  - 6A B a b  + 2B a b )c
+--R                *
+--R                   x
+--R     + 
+--R           2 3
+--R         3a x
+--R      *
+--R         ROOT
+--R                        6      5 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                            4 4 4      4 3 2     3   4      2 2 5  3
+--R                         - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                       + 
+--R                                  4 2 4      3   3 3      2 2 4 2       3 5
+--R                             - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                           + 
+--R                                4 6
+--R                             - B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                               4   6      3   2 5      2 2 3 4        3 4 3
+--R                             6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                           + 
+--R                               4 5 2
+--R                             2B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                         - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                   2 2          3  2        2   3         2 2     2 3       2 5
+--R                (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c + A b
+--R              + 
+--R                          4    2 2 3
+--R                - 2A B a b  + B a b
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                            7         8  2           6 3        7 2         5 5
+--R                      (48A a b - 32B a )c  + (- 28A a b  + 24B a b )c + 4A a b
+--R                    + 
+--R                            6 4
+--R                      - 4B a b
+--R                 *
+--R                    ROOT
+--R                              4 4 4      4 3 2     3   4      2 2 5  3
+--R                           - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                         + 
+--R                                    4 2 4      3   3 3      2 2 4 2       3 5
+--R                               - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                             + 
+--R                                  4 6
+--R                               - B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                 4   6      3   2 5      2 2 3 4        3 4 3
+--R                               6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                             + 
+--R                                 4 5 2
+--R                               2B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                              4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                           - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                      /
+--R                            11       10 2
+--R                         64a  c - 16a  b
+--R                + 
+--R                      3 4 4       3 3 2      2   4        2 5  3
+--R                  - 4A a c  + (17A a b  - 20A B a b + 4A B a )c
+--R                + 
+--R                        3 2 4      2   3 3        2 4 2     3 5   2
+--R                  (- 20A a b  + 41A B a b  - 25A B a b  + 4B a b)c
+--R                + 
+--R                     3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (8A a b  - 21A B a b  + 18A B a b  - 5B a b )c - A b
+--R                + 
+--R                    2     7       2 2 6    3 3 5
+--R                  3A B a b  - 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                               6      5 2
+--R                         (- 16a c + 4a b )
+--R                      *
+--R                         ROOT
+--R                                   4 4 4      4 3 2     3   4      2 2 5  3
+--R                                - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                              + 
+--R                                         4 2 4      3   3 3      2 2 4 2
+--R                                    - 11A a b  + 28A B a b  - 24A B a b
+--R                                  + 
+--R                                        3 5     4 6
+--R                                    8A B a b - B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                      4   6      3   2 5      2 2 3 4
+--R                                    6A a b  - 20A B a b  + 24A B a b
+--R                                  + 
+--R                                           3 4 3     4 5 2
+--R                                    - 12A B a b  + 2B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                   4 8     3     7     2 2 2 6       3 3 5
+--R                                - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                 11       10 2
+--R                              64a  c - 16a  b
+--R                     + 
+--R                          2 2          3  2        2   3         2 2     2 3
+--R                       (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c
+--R                     + 
+--R                        2 5           4    2 2 3
+--R                       A b  - 2A B a b  + B a b
+--R                  /
+--R                       6      5 2
+--R                     8a c - 2a b
+--R            + 
+--R                    4 2 5        4   2     3   2   4
+--R                  2A a c  + (- 6A a b  + 6A B a b)c
+--R                + 
+--R                     4 4     3     3      2 2 2 2        3 3      4 4  3
+--R                  (2A b  + 2A B a b  - 12A B a b  + 10A B a b - 2B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2  2
+--R                  (- 2A B b  + 6A B a b  - 6A B a b  + 2B a b )c
+--R             *
+--R                x
+--R     + 
+--R       -
+--R              2 3
+--R            3a x
+--R         *
+--R            ROOT
+--R                           6      5 2
+--R                     (- 16a c + 4a b )
+--R                  *
+--R                     ROOT
+--R                               4 4 4      4 3 2     3   4      2 2 5  3
+--R                            - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                          + 
+--R                                     4 2 4      3   3 3      2 2 4 2       3 5
+--R                                - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                              + 
+--R                                   4 6
+--R                                - B a
+--R                           *
+--R                               2
+--R                              c
+--R                          + 
+--R                                  4   6      3   2 5      2 2 3 4        3 4 3
+--R                                6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                              + 
+--R                                  4 5 2
+--R                                2B a b
+--R                           *
+--R                              c
+--R                          + 
+--R                               4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                            - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                       /
+--R                             11       10 2
+--R                          64a  c - 16a  b
+--R                 + 
+--R                      2 2          3  2        2   3         2 2     2 3
+--R                   (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c
+--R                 + 
+--R                    2 5           4    2 2 3
+--R                   A b  - 2A B a b  + B a b
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R            log
+--R                                 7         8  2         6 3        7 2
+--R                         (- 48A a b + 32B a )c  + (28A a b  - 24B a b )c
+--R                       + 
+--R                               5 5       6 4
+--R                         - 4A a b  + 4B a b
+--R                    *
+--R                       ROOT
+--R                                 4 4 4      4 3 2     3   4      2 2 5  3
+--R                              - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                            + 
+--R                                       4 2 4      3   3 3      2 2 4 2
+--R                                  - 11A a b  + 28A B a b  - 24A B a b
+--R                                + 
+--R                                      3 5     4 6
+--R                                  8A B a b - B a
+--R                             *
+--R                                 2
+--R                                c
+--R                            + 
+--R                                    4   6      3   2 5      2 2 3 4        3 4 3
+--R                                  6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                                + 
+--R                                    4 5 2
+--R                                  2B a b
+--R                             *
+--R                                c
+--R                            + 
+--R                               4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                            - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                         /
+--R                               11       10 2
+--R                            64a  c - 16a  b
+--R                   + 
+--R                       3 4 4         3 3 2      2   4        2 5  3
+--R                     4A a c  + (- 17A a b  + 20A B a b - 4A B a )c
+--R                   + 
+--R                         3 2 4      2   3 3        2 4 2     3 5   2
+--R                     (20A a b  - 41A B a b  + 25A B a b  - 4B a b)c
+--R                   + 
+--R                          3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                     (- 8A a b  + 21A B a b  - 18A B a b  + 5B a b )c + A b
+--R                   + 
+--R                         2     7       2 2 6    3 3 5
+--R                     - 3A B a b  + 3A B a b  - B a b
+--R                *
+--R                   ROOT
+--R                                  6      5 2
+--R                            (- 16a c + 4a b )
+--R                         *
+--R                            ROOT
+--R                                      4 4 4      4 3 2     3   4      2 2 5  3
+--R                                   - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                                 + 
+--R                                            4 2 4      3   3 3      2 2 4 2
+--R                                       - 11A a b  + 28A B a b  - 24A B a b
+--R                                     + 
+--R                                           3 5     4 6
+--R                                       8A B a b - B a
+--R                                  *
+--R                                      2
+--R                                     c
+--R                                 + 
+--R                                         4   6      3   2 5      2 2 3 4
+--R                                       6A a b  - 20A B a b  + 24A B a b
+--R                                     + 
+--R                                              3 4 3     4 5 2
+--R                                       - 12A B a b  + 2B a b
+--R                                  *
+--R                                     c
+--R                                 + 
+--R                                      4 8     3     7     2 2 2 6       3 3 5
+--R                                   - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                                 + 
+--R                                      4 4 4
+--R                                   - B a b
+--R                              /
+--R                                    11       10 2
+--R                                 64a  c - 16a  b
+--R                        + 
+--R                             2 2          3  2
+--R                          (5A a b - 4A B a )c
+--R                        + 
+--R                               2   3         2 2     2 3       2 5           4
+--R                          (- 5A a b  + 8A B a b  - 3B a b)c + A b  - 2A B a b
+--R                        + 
+--R                           2 2 3
+--R                          B a b
+--R                     /
+--R                          6      5 2
+--R                        8a c - 2a b
+--R               + 
+--R                       4 2 5        4   2     3   2   4
+--R                     2A a c  + (- 6A a b  + 6A B a b)c
+--R                   + 
+--R                        4 4     3     3      2 2 2 2        3 3      4 4  3
+--R                     (2A b  + 2A B a b  - 12A B a b  + 10A B a b - 2B a )c
+--R                   + 
+--R                          3   5     2 2   4       3 2 3     4 3 2  2
+--R                     (- 2A B b  + 6A B a b  - 6A B a b  + 2B a b )c
+--R                *
+--R                   x
+--R     + 
+--R           2 3
+--R         3a x
+--R      *
+--R         ROOT
+--R                      6      5 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                            4 4 4      4 3 2     3   4      2 2 5  3
+--R                         - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                       + 
+--R                                  4 2 4      3   3 3      2 2 4 2       3 5
+--R                             - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                           + 
+--R                                4 6
+--R                             - B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                               4   6      3   2 5      2 2 3 4        3 4 3
+--R                             6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                           + 
+--R                               4 5 2
+--R                             2B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                         - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                   2 2          3  2        2   3         2 2     2 3       2 5
+--R                (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c + A b
+--R              + 
+--R                          4    2 2 3
+--R                - 2A B a b  + B a b
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                              7         8  2         6 3        7 2         5 5
+--R                      (- 48A a b + 32B a )c  + (28A a b  - 24B a b )c - 4A a b
+--R                    + 
+--R                          6 4
+--R                      4B a b
+--R                 *
+--R                    ROOT
+--R                              4 4 4      4 3 2     3   4      2 2 5  3
+--R                           - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                         + 
+--R                                    4 2 4      3   3 3      2 2 4 2       3 5
+--R                               - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                             + 
+--R                                  4 6
+--R                               - B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                 4   6      3   2 5      2 2 3 4        3 4 3
+--R                               6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                             + 
+--R                                 4 5 2
+--R                               2B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                              4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                           - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                      /
+--R                            11       10 2
+--R                         64a  c - 16a  b
+--R                + 
+--R                      3 4 4       3 3 2      2   4        2 5  3
+--R                  - 4A a c  + (17A a b  - 20A B a b + 4A B a )c
+--R                + 
+--R                        3 2 4      2   3 3        2 4 2     3 5   2
+--R                  (- 20A a b  + 41A B a b  - 25A B a b  + 4B a b)c
+--R                + 
+--R                     3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (8A a b  - 21A B a b  + 18A B a b  - 5B a b )c - A b
+--R                + 
+--R                    2     7       2 2 6    3 3 5
+--R                  3A B a b  - 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                             6      5 2
+--R                         (16a c - 4a b )
+--R                      *
+--R                         ROOT
+--R                                   4 4 4      4 3 2     3   4      2 2 5  3
+--R                                - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                              + 
+--R                                         4 2 4      3   3 3      2 2 4 2
+--R                                    - 11A a b  + 28A B a b  - 24A B a b
+--R                                  + 
+--R                                        3 5     4 6
+--R                                    8A B a b - B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                      4   6      3   2 5      2 2 3 4
+--R                                    6A a b  - 20A B a b  + 24A B a b
+--R                                  + 
+--R                                           3 4 3     4 5 2
+--R                                    - 12A B a b  + 2B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                   4 8     3     7     2 2 2 6       3 3 5
+--R                                - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                 11       10 2
+--R                              64a  c - 16a  b
+--R                     + 
+--R                          2 2          3  2        2   3         2 2     2 3
+--R                       (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c
+--R                     + 
+--R                        2 5           4    2 2 3
+--R                       A b  - 2A B a b  + B a b
+--R                  /
+--R                       6      5 2
+--R                     8a c - 2a b
+--R            + 
+--R                    4 2 5        4   2     3   2   4
+--R                  2A a c  + (- 6A a b  + 6A B a b)c
+--R                + 
+--R                     4 4     3     3      2 2 2 2        3 3      4 4  3
+--R                  (2A b  + 2A B a b  - 12A B a b  + 10A B a b - 2B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2  2
+--R                  (- 2A B b  + 6A B a b  - 6A B a b  + 2B a b )c
+--R             *
+--R                x
+--R     + 
+--R                     2
+--R       (6A b - 6B a)x  - 2A a
+--R  /
+--R       2 3
+--R     6a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2172
+
+--S 2173 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                 +--------------------+
+--R                   +-----------+ |   +-----------+
+--R             2 +-+ |          2  |   |          2
+--R            a \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                         6      5 2
+--R                     (16a c - 4a b )
+--R                  *
+--R                     ROOT
+--R                               4 4 4      4 3 2     3   4      2 2 5  3
+--R                            - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                          + 
+--R                                     4 2 4      3   3 3      2 2 4 2       3 5
+--R                                - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                              + 
+--R                                   4 6
+--R                                - B a
+--R                           *
+--R                               2
+--R                              c
+--R                          + 
+--R                                  4   6      3   2 5      2 2 3 4        3 4 3
+--R                                6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                              + 
+--R                                  4 5 2
+--R                                2B a b
+--R                           *
+--R                              c
+--R                          + 
+--R                               4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                            - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                       /
+--R                             11       10 2
+--R                          64a  c - 16a  b
+--R                 + 
+--R                      2 2          3  2        2   3         2 2     2 3
+--R                   (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c
+--R                 + 
+--R                    2 5           4    2 2 3
+--R                   A b  - 2A B a b  + B a b
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                               7         8  2           6 3        7 2
+--R                         (48A a b - 32B a )c  + (- 28A a b  + 24B a b )c
+--R                       + 
+--R                             5 5       6 4
+--R                         4A a b  - 4B a b
+--R                    *
+--R                       ROOT
+--R                                 4 4 4      4 3 2     3   4      2 2 5  3
+--R                              - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                            + 
+--R                                       4 2 4      3   3 3      2 2 4 2
+--R                                  - 11A a b  + 28A B a b  - 24A B a b
+--R                                + 
+--R                                      3 5     4 6
+--R                                  8A B a b - B a
+--R                             *
+--R                                 2
+--R                                c
+--R                            + 
+--R                                    4   6      3   2 5      2 2 3 4        3 4 3
+--R                                  6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                                + 
+--R                                    4 5 2
+--R                                  2B a b
+--R                             *
+--R                                c
+--R                            + 
+--R                               4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                            - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                         /
+--R                               11       10 2
+--R                            64a  c - 16a  b
+--R                   + 
+--R                       3 4 4         3 3 2      2   4        2 5  3
+--R                     4A a c  + (- 17A a b  + 20A B a b - 4A B a )c
+--R                   + 
+--R                         3 2 4      2   3 3        2 4 2     3 5   2
+--R                     (20A a b  - 41A B a b  + 25A B a b  - 4B a b)c
+--R                   + 
+--R                          3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                     (- 8A a b  + 21A B a b  - 18A B a b  + 5B a b )c + A b
+--R                   + 
+--R                         2     7       2 2 6    3 3 5
+--R                     - 3A B a b  + 3A B a b  - B a b
+--R                *
+--R                   ROOT
+--R                                6      5 2
+--R                            (16a c - 4a b )
+--R                         *
+--R                            ROOT
+--R                                      4 4 4      4 3 2     3   4      2 2 5  3
+--R                                   - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                                 + 
+--R                                            4 2 4      3   3 3      2 2 4 2
+--R                                       - 11A a b  + 28A B a b  - 24A B a b
+--R                                     + 
+--R                                           3 5     4 6
+--R                                       8A B a b - B a
+--R                                  *
+--R                                      2
+--R                                     c
+--R                                 + 
+--R                                         4   6      3   2 5      2 2 3 4
+--R                                       6A a b  - 20A B a b  + 24A B a b
+--R                                     + 
+--R                                              3 4 3     4 5 2
+--R                                       - 12A B a b  + 2B a b
+--R                                  *
+--R                                     c
+--R                                 + 
+--R                                      4 8     3     7     2 2 2 6       3 3 5
+--R                                   - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                                 + 
+--R                                      4 4 4
+--R                                   - B a b
+--R                              /
+--R                                    11       10 2
+--R                                 64a  c - 16a  b
+--R                        + 
+--R                             2 2          3  2
+--R                          (5A a b - 4A B a )c
+--R                        + 
+--R                               2   3         2 2     2 3       2 5           4
+--R                          (- 5A a b  + 8A B a b  - 3B a b)c + A b  - 2A B a b
+--R                        + 
+--R                           2 2 3
+--R                          B a b
+--R                     /
+--R                          6      5 2
+--R                        8a c - 2a b
+--R               + 
+--R                       4 2 5        4   2     3   2   4
+--R                     2A a c  + (- 6A a b  + 6A B a b)c
+--R                   + 
+--R                        4 4     3     3      2 2 2 2        3 3      4 4  3
+--R                     (2A b  + 2A B a b  - 12A B a b  + 10A B a b - 2B a )c
+--R                   + 
+--R                          3   5     2 2   4       3 2 3     4 3 2  2
+--R                     (- 2A B b  + 6A B a b  - 6A B a b  + 2B a b )c
+--R                *
+--R                   x
+--R     + 
+--R                              +--------------------+
+--R                +-----------+ |   +-----------+
+--R          2 +-+ |          2  |   |          2
+--R         a \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6      5 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                            4 4 4      4 3 2     3   4      2 2 5  3
+--R                         - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                       + 
+--R                                  4 2 4      3   3 3      2 2 4 2       3 5
+--R                             - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                           + 
+--R                                4 6
+--R                             - B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                               4   6      3   2 5      2 2 3 4        3 4 3
+--R                             6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                           + 
+--R                               4 5 2
+--R                             2B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                         - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                   2 2          3  2        2   3         2 2     2 3       2 5
+--R                (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c + A b
+--R              + 
+--R                          4    2 2 3
+--R                - 2A B a b  + B a b
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            7         8  2           6 3        7 2         5 5
+--R                      (48A a b - 32B a )c  + (- 28A a b  + 24B a b )c + 4A a b
+--R                    + 
+--R                            6 4
+--R                      - 4B a b
+--R                 *
+--R                    ROOT
+--R                              4 4 4      4 3 2     3   4      2 2 5  3
+--R                           - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                         + 
+--R                                    4 2 4      3   3 3      2 2 4 2       3 5
+--R                               - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                             + 
+--R                                  4 6
+--R                               - B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                 4   6      3   2 5      2 2 3 4        3 4 3
+--R                               6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                             + 
+--R                                 4 5 2
+--R                               2B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                              4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                           - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                      /
+--R                            11       10 2
+--R                         64a  c - 16a  b
+--R                + 
+--R                      3 4 4       3 3 2      2   4        2 5  3
+--R                  - 4A a c  + (17A a b  - 20A B a b + 4A B a )c
+--R                + 
+--R                        3 2 4      2   3 3        2 4 2     3 5   2
+--R                  (- 20A a b  + 41A B a b  - 25A B a b  + 4B a b)c
+--R                + 
+--R                     3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (8A a b  - 21A B a b  + 18A B a b  - 5B a b )c - A b
+--R                + 
+--R                    2     7       2 2 6    3 3 5
+--R                  3A B a b  - 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                               6      5 2
+--R                         (- 16a c + 4a b )
+--R                      *
+--R                         ROOT
+--R                                   4 4 4      4 3 2     3   4      2 2 5  3
+--R                                - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                              + 
+--R                                         4 2 4      3   3 3      2 2 4 2
+--R                                    - 11A a b  + 28A B a b  - 24A B a b
+--R                                  + 
+--R                                        3 5     4 6
+--R                                    8A B a b - B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                      4   6      3   2 5      2 2 3 4
+--R                                    6A a b  - 20A B a b  + 24A B a b
+--R                                  + 
+--R                                           3 4 3     4 5 2
+--R                                    - 12A B a b  + 2B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                   4 8     3     7     2 2 2 6       3 3 5
+--R                                - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                 11       10 2
+--R                              64a  c - 16a  b
+--R                     + 
+--R                          2 2          3  2        2   3         2 2     2 3
+--R                       (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c
+--R                     + 
+--R                        2 5           4    2 2 3
+--R                       A b  - 2A B a b  + B a b
+--R                  /
+--R                       6      5 2
+--R                     8a c - 2a b
+--R            + 
+--R                    4 2 5        4   2     3   2   4
+--R                  2A a c  + (- 6A a b  + 6A B a b)c
+--R                + 
+--R                     4 4     3     3      2 2 2 2        3 3      4 4  3
+--R                  (2A b  + 2A B a b  - 12A B a b  + 10A B a b - 2B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2  2
+--R                  (- 2A B b  + 6A B a b  - 6A B a b  + 2B a b )c
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                 +--------------------+
+--R                   +-----------+ |   +-----------+
+--R             2 +-+ |          2  |   |          2
+--R            a \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                           6      5 2
+--R                     (- 16a c + 4a b )
+--R                  *
+--R                     ROOT
+--R                               4 4 4      4 3 2     3   4      2 2 5  3
+--R                            - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                          + 
+--R                                     4 2 4      3   3 3      2 2 4 2       3 5
+--R                                - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                              + 
+--R                                   4 6
+--R                                - B a
+--R                           *
+--R                               2
+--R                              c
+--R                          + 
+--R                                  4   6      3   2 5      2 2 3 4        3 4 3
+--R                                6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                              + 
+--R                                  4 5 2
+--R                                2B a b
+--R                           *
+--R                              c
+--R                          + 
+--R                               4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                            - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                       /
+--R                             11       10 2
+--R                          64a  c - 16a  b
+--R                 + 
+--R                      2 2          3  2        2   3         2 2     2 3
+--R                   (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c
+--R                 + 
+--R                    2 5           4    2 2 3
+--R                   A b  - 2A B a b  + B a b
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                 7         8  2         6 3        7 2
+--R                         (- 48A a b + 32B a )c  + (28A a b  - 24B a b )c
+--R                       + 
+--R                               5 5       6 4
+--R                         - 4A a b  + 4B a b
+--R                    *
+--R                       ROOT
+--R                                 4 4 4      4 3 2     3   4      2 2 5  3
+--R                              - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                            + 
+--R                                       4 2 4      3   3 3      2 2 4 2
+--R                                  - 11A a b  + 28A B a b  - 24A B a b
+--R                                + 
+--R                                      3 5     4 6
+--R                                  8A B a b - B a
+--R                             *
+--R                                 2
+--R                                c
+--R                            + 
+--R                                    4   6      3   2 5      2 2 3 4        3 4 3
+--R                                  6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                                + 
+--R                                    4 5 2
+--R                                  2B a b
+--R                             *
+--R                                c
+--R                            + 
+--R                               4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                            - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                         /
+--R                               11       10 2
+--R                            64a  c - 16a  b
+--R                   + 
+--R                       3 4 4         3 3 2      2   4        2 5  3
+--R                     4A a c  + (- 17A a b  + 20A B a b - 4A B a )c
+--R                   + 
+--R                         3 2 4      2   3 3        2 4 2     3 5   2
+--R                     (20A a b  - 41A B a b  + 25A B a b  - 4B a b)c
+--R                   + 
+--R                          3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                     (- 8A a b  + 21A B a b  - 18A B a b  + 5B a b )c + A b
+--R                   + 
+--R                         2     7       2 2 6    3 3 5
+--R                     - 3A B a b  + 3A B a b  - B a b
+--R                *
+--R                   ROOT
+--R                                  6      5 2
+--R                            (- 16a c + 4a b )
+--R                         *
+--R                            ROOT
+--R                                      4 4 4      4 3 2     3   4      2 2 5  3
+--R                                   - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                                 + 
+--R                                            4 2 4      3   3 3      2 2 4 2
+--R                                       - 11A a b  + 28A B a b  - 24A B a b
+--R                                     + 
+--R                                           3 5     4 6
+--R                                       8A B a b - B a
+--R                                  *
+--R                                      2
+--R                                     c
+--R                                 + 
+--R                                         4   6      3   2 5      2 2 3 4
+--R                                       6A a b  - 20A B a b  + 24A B a b
+--R                                     + 
+--R                                              3 4 3     4 5 2
+--R                                       - 12A B a b  + 2B a b
+--R                                  *
+--R                                     c
+--R                                 + 
+--R                                      4 8     3     7     2 2 2 6       3 3 5
+--R                                   - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                                 + 
+--R                                      4 4 4
+--R                                   - B a b
+--R                              /
+--R                                    11       10 2
+--R                                 64a  c - 16a  b
+--R                        + 
+--R                             2 2          3  2
+--R                          (5A a b - 4A B a )c
+--R                        + 
+--R                               2   3         2 2     2 3       2 5           4
+--R                          (- 5A a b  + 8A B a b  - 3B a b)c + A b  - 2A B a b
+--R                        + 
+--R                           2 2 3
+--R                          B a b
+--R                     /
+--R                          6      5 2
+--R                        8a c - 2a b
+--R               + 
+--R                       4 2 5        4   2     3   2   4
+--R                     2A a c  + (- 6A a b  + 6A B a b)c
+--R                   + 
+--R                        4 4     3     3      2 2 2 2        3 3      4 4  3
+--R                     (2A b  + 2A B a b  - 12A B a b  + 10A B a b - 2B a )c
+--R                   + 
+--R                          3   5     2 2   4       3 2 3     4 3 2  2
+--R                     (- 2A B b  + 6A B a b  - 6A B a b  + 2B a b )c
+--R                *
+--R                   x
+--R     + 
+--R                              +--------------------+
+--R                +-----------+ |   +-----------+
+--R          2 +-+ |          2  |   |          2
+--R         a \|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                      6      5 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                            4 4 4      4 3 2     3   4      2 2 5  3
+--R                         - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                       + 
+--R                                  4 2 4      3   3 3      2 2 4 2       3 5
+--R                             - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                           + 
+--R                                4 6
+--R                             - B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                               4   6      3   2 5      2 2 3 4        3 4 3
+--R                             6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                           + 
+--R                               4 5 2
+--R                             2B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                         - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                   2 2          3  2        2   3         2 2     2 3       2 5
+--R                (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c + A b
+--R              + 
+--R                          4    2 2 3
+--R                - 2A B a b  + B a b
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              7         8  2         6 3        7 2         5 5
+--R                      (- 48A a b + 32B a )c  + (28A a b  - 24B a b )c - 4A a b
+--R                    + 
+--R                          6 4
+--R                      4B a b
+--R                 *
+--R                    ROOT
+--R                              4 4 4      4 3 2     3   4      2 2 5  3
+--R                           - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                         + 
+--R                                    4 2 4      3   3 3      2 2 4 2       3 5
+--R                               - 11A a b  + 28A B a b  - 24A B a b  + 8A B a b
+--R                             + 
+--R                                  4 6
+--R                               - B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                 4   6      3   2 5      2 2 3 4        3 4 3
+--R                               6A a b  - 20A B a b  + 24A B a b  - 12A B a b
+--R                             + 
+--R                                 4 5 2
+--R                               2B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                              4 8     3     7     2 2 2 6       3 3 5    4 4 4
+--R                           - A b  + 4A B a b  - 6A B a b  + 4A B a b  - B a b
+--R                      /
+--R                            11       10 2
+--R                         64a  c - 16a  b
+--R                + 
+--R                      3 4 4       3 3 2      2   4        2 5  3
+--R                  - 4A a c  + (17A a b  - 20A B a b + 4A B a )c
+--R                + 
+--R                        3 2 4      2   3 3        2 4 2     3 5   2
+--R                  (- 20A a b  + 41A B a b  - 25A B a b  + 4B a b)c
+--R                + 
+--R                     3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (8A a b  - 21A B a b  + 18A B a b  - 5B a b )c - A b
+--R                + 
+--R                    2     7       2 2 6    3 3 5
+--R                  3A B a b  - 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                             6      5 2
+--R                         (16a c - 4a b )
+--R                      *
+--R                         ROOT
+--R                                   4 4 4      4 3 2     3   4      2 2 5  3
+--R                                - A a c  + (6A a b  - 8A B a b + 2A B a )c
+--R                              + 
+--R                                         4 2 4      3   3 3      2 2 4 2
+--R                                    - 11A a b  + 28A B a b  - 24A B a b
+--R                                  + 
+--R                                        3 5     4 6
+--R                                    8A B a b - B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                      4   6      3   2 5      2 2 3 4
+--R                                    6A a b  - 20A B a b  + 24A B a b
+--R                                  + 
+--R                                           3 4 3     4 5 2
+--R                                    - 12A B a b  + 2B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                   4 8     3     7     2 2 2 6       3 3 5
+--R                                - A b  + 4A B a b  - 6A B a b  + 4A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                 11       10 2
+--R                              64a  c - 16a  b
+--R                     + 
+--R                          2 2          3  2        2   3         2 2     2 3
+--R                       (5A a b - 4A B a )c  + (- 5A a b  + 8A B a b  - 3B a b)c
+--R                     + 
+--R                        2 5           4    2 2 3
+--R                       A b  - 2A B a b  + B a b
+--R                  /
+--R                       6      5 2
+--R                     8a c - 2a b
+--R            + 
+--R                    4 2 5        4   2     3   2   4
+--R                  2A a c  + (- 6A a b  + 6A B a b)c
+--R                + 
+--R                     4 4     3     3      2 2 2 2        3 3      4 4  3
+--R                  (2A b  + 2A B a b  - 12A B a b  + 10A B a b - 2B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2  2
+--R                  (- 2A B b  + 6A B a b  - 6A B a b  + 2B a b )c
+--R             *
+--R                x
+--R     + 
+--R                          +-----------+
+--R                          |          2                 2           +-+
+--R         ((- 2A b + 2B a)\|- 4a c + b   + 4A a c - 2A b  + 2B a b)\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                          |          2                 2           +-+
+--R         ((- 2A b + 2B a)\|- 4a c + b   - 4A a c + 2A b  - 2B a b)\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R       2 +-+ |          2  |   |          2       | |          2
+--R     2a \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2173
+
+--S 2174 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2174
+
+)clear all
+
+--S 2175 of 3139
+t0:=x^7*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            9      7
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2175
+
+--S 2176 of 3139
+r0:=1/2*(2*b^2*B-A*b*c-6*a*B*c)*x^2/(c^2*(b^2-4*a*c))-1/2*(b*B-2*A*c)*_
+   x^4/(c*(b^2-4*a*c))-1/2*x^6*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))-1/2*(2*b^4*B-A*b^3*c-12*a*b^2*B*c+6*a*A*b*c^2+_
+   12*a^2*B*c^2)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^3*(b^2-_
+   4*a*c)^(3/2))-1/4*(2*b*B-A*c)*log(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R                            2  3          3          2  2       4   4
+--R           ((12A a b + 24B a )c  + (- 2A b  - 24B a b )c  + 4B b c)x
+--R         + 
+--R                    2        2   2          4          3         5  2
+--R           ((12A a b  + 24B a b)c  + (- 2A b  - 24B a b )c + 4B b )x
+--R         + 
+--R                 2         3  2            3        2 2           4
+--R           (12A a b + 24B a )c  + (- 2A a b  - 24B a b )c + 4B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                      3         2           2       3   4
+--R               (4A a c  + (- A b  - 8B a b)c  + 2B b c)x
+--R             + 
+--R                        2         3         2         4  2       2 2
+--R               (4A a b c  + (- A b  - 8B a b )c + 2B b )x  + 4A a c
+--R             + 
+--R                       2       2            3
+--R               (- A a b  - 8B a b)c + 2B a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                  3       2 2  6            3        2            2       3   4
+--R           (8B a c  - 2B b c )x  + (- 4A a c  + (2A b  + 14B a b)c  - 4B b c)x
+--R         + 
+--R                           2  2         2   2
+--R           ((2A a b + 12B a )c  - 4B a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              5     2 4  4           4     3 3  2      2 4       2 3
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2176
+
+--S 2177 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             2  3         3          2  2       4   4
+--R             ((6A a b + 12B a )c  + (- A b  - 12B a b )c  + 2B b c)x
+--R           + 
+--R                     2        2   2         4          3         5  2
+--R             ((6A a b  + 12B a b)c  + (- A b  - 12B a b )c + 2B b )x
+--R           + 
+--R                  2         3  2           3        2 2           4
+--R             (6A a b + 12B a )c  + (- A a b  - 12B a b )c + 2B a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                        3         2           2       3   4
+--R                 (4A a c  + (- A b  - 8B a b)c  + 2B b c)x
+--R               + 
+--R                          2         3         2         4  2       2 2
+--R                 (4A a b c  + (- A b  - 8B a b )c + 2B b )x  + 4A a c
+--R               + 
+--R                         2       2            3
+--R                 (- A a b  - 8B a b)c + 2B a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                    3       2 2  6            2       3   4
+--R             (8B a c  - 2B b c )x  + (8B a b c  - 2B b c)x
+--R           + 
+--R                             2  2          3          2         4  2       2 2
+--R             ((6A a b + 12B a )c  + (- 2A b  - 10B a b )c + 2B b )x  + 4A a c
+--R           + 
+--R                      2       2            3
+--R             (- 2A a b  - 6B a b)c + 2B a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                5     2 4  4           4     3 3  2      2 4       2 3
+--R         ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                                2  3        3          2  2       4   4
+--R             ((- 12A a b - 24B a )c  + (2A b  + 24B a b )c  - 4B b c)x
+--R           + 
+--R                        2        2   2        4          3         5  2
+--R             ((- 12A a b  - 24B a b)c  + (2A b  + 24B a b )c - 4B b )x
+--R           + 
+--R                     2         3  2          3        2 2           4
+--R             (- 12A a b - 24B a )c  + (2A a b  + 24B a b )c - 4B a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                        3         2           2       3   4
+--R                 (4A a c  + (- A b  - 8B a b)c  + 2B b c)x
+--R               + 
+--R                          2         3         2         4  2       2 2
+--R                 (4A a b c  + (- A b  - 8B a b )c + 2B b )x  + 4A a c
+--R               + 
+--R                         2       2            3
+--R                 (- A a b  - 8B a b)c + 2B a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                    3       2 2  6            2       3   4
+--R             (8B a c  - 2B b c )x  + (8B a b c  - 2B b c)x
+--R           + 
+--R                             2  2          3          2         4  2       2 2
+--R             ((6A a b + 12B a )c  + (- 2A b  - 10B a b )c + 2B b )x  + 4A a c
+--R           + 
+--R                      2       2            3
+--R             (- 2A a b  - 6B a b)c + 2B a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                5     2 4  4           4     3 3  2      2 4       2 3
+--R         ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2177
+
+--S 2178 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         2  2         3          2         4
+--R         ((6A a b + 12B a )c  + (- A b  - 12B a b )c + 2B b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                            2  2        3          2         4
+--R         ((- 12A a b - 24B a )c  + (2A b  + 24B a b )c - 4B b )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                               +-----------+
+--R              2          2                  3  |          2
+--R       (4A a c  + (- 2A b  - 6B a b)c + 2B b )\|- 4a c + b
+--R  /
+--R                      +-----------+
+--R           4     2 3  |          2
+--R     (16a c  - 4b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2178
+
+--S 2179 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2179
+
+--S 2180 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                              +---------+
+--R                           2  2       3          2         4  |        2
+--R         ((- 6A a b - 12B a )c  + (A b  + 12B a b )c - 2B b )\|4a c - b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                              +-----------+
+--R                           2  2       3          2         4  |          2
+--R         ((- 6A a b - 12B a )c  + (A b  + 12B a b )c - 2B b )\|- 4a c + b
+--R      *
+--R                          +---------+
+--R                   2      |        2
+--R              (2c x  + b)\|4a c - b
+--R         atan(-----------------------)
+--R                             2
+--R                     4a c - b
+--R     + 
+--R                                             +-----------+ +---------+
+--R              2         2                 3  |          2  |        2
+--R       (2A a c  + (- A b  - 3B a b)c + B b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                     +-----------+ +---------+
+--R          4     2 3  |          2  |        2
+--R     (8a c  - 2b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2180
+
+--S 2181 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2181
+
+)clear all
+
+--S 2182 of 3139
+t0:=x^5*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            7      5
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2182
+
+--S 2183 of 3139
+r0:=1/2*(2*A-b*B/c)*x^2/(b^2-4*a*c)-1/2*x^4*(A*b-2*a*B-(b*B-2*A*c)*x^2)/_
+   ((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*(b^3*B-6*a*b*B*c+4*a*A*c^2)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*(b^2-4*a*c)^(3/2))+_
+   1/4*B*log(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                    3            2       3   4
+--R           (- 8A a c  + 12B a b c  - 2B b c)x
+--R         + 
+--R                      2          2        4  2       2 2        2            3
+--R           (- 8A a b c  + 12B a b c - 2B b )x  - 8A a c  + 12B a b c - 2B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2      2   4                  3  2       2         2
+--R             ((4B a c  - B b c)x  + (4B a b c - B b )x  + 4B a c - B a b )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                            2       2   4            2             2
+--R           ((- 2A b - 4B a)c  + 2B b c)x  + (- 4A a c  + 2B a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              4     2 3  4           3     3 2  2      2 3       2 2
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2183
+
+--S 2184 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    3           2      3   4            2         2       4  2
+--R             (4A a c  - 6B a b c  + B b c)x  + (4A a b c  - 6B a b c + B b )x
+--R           + 
+--R                 2 2       2           3
+--R             4A a c  - 6B a b c + B a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                       2      2   4                  3  2       2         2
+--R               ((4B a c  - B b c)x  + (4B a b c - B b )x  + 4B a c - B a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                      2        2                  3  2                 2
+--R             (- 4A a c  + (2A b  + 6B a b)c - 2B b )x  + (2A a b + 4B a )c
+--R           + 
+--R                     2
+--R             - 2B a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                4     2 3  4           3     3 2  2      2 3       2 2
+--R         ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    3            2       3   4
+--R             (8A a c  - 12B a b c  + 2B b c)x
+--R           + 
+--R                      2          2        4  2       2 2        2            3
+--R             (8A a b c  - 12B a b c + 2B b )x  + 8A a c  - 12B a b c + 2B a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2      2   4                  3  2       2         2
+--R               ((4B a c  - B b c)x  + (4B a b c - B b )x  + 4B a c - B a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                      2        2                  3  2                 2
+--R             (- 4A a c  + (2A b  + 6B a b)c - 2B b )x  + (2A a b + 4B a )c
+--R           + 
+--R                     2
+--R             - 2B a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                4     2 3  4           3     3 2  2      2 3       2 2
+--R         ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2184
+
+--S 2185 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                2                 3
+--R         (4A a c  - 6B a b c + B b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                                 2
+--R              2                   3          2c x  + b
+--R       (8A a c  - 12B a b c + 2B b )atanh(--------------)
+--R                                           +-----------+
+--R                                           |          2
+--R                                          \|- 4a c + b
+--R     + 
+--R                                +-----------+
+--R                             2  |          2
+--R       ((2A b + 4B a)c - 2B b )\|- 4a c + b
+--R  /
+--R                      +-----------+
+--R           3     2 2  |          2
+--R     (16a c  - 4b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2185
+
+--S 2186 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2186
+
+--S 2187 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                   +---------+             2
+--R              2                 3  |        2          2c x  + b
+--R       (4A a c  - 6B a b c + B b )\|4a c - b  atanh(--------------)
+--R                                                     +-----------+
+--R                                                     |          2
+--R                                                    \|- 4a c + b
+--R     + 
+--R                                                                 +---------+
+--R                                   +-----------+          2      |        2
+--R              2                 3  |          2      (2c x  + b)\|4a c - b
+--R       (4A a c  - 6B a b c + B b )\|- 4a c + b  atan(-----------------------)
+--R                                                                    2
+--R                                                            4a c - b
+--R     + 
+--R                              +-----------+ +---------+
+--R                           2  |          2  |        2
+--R       ((A b + 2B a)c - B b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                     +-----------+ +---------+
+--R          3     2 2  |          2  |        2
+--R     (8a c  - 2b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2187
+
+--S 2188 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2188
+
+)clear all
+
+--S 2189 of 3139
+t0:=x^3*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            5      3
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2189
+
+--S 2190 of 3139
+r0:=1/2*(2*a+b*x^2)*(A+B*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-_
+   (A*b-2*a*B)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                          4        2           2                2
+--R         ((2A b - 4B a)c x  + (2A b  - 4B a b)x  + 2A a b - 4B a )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                            +-----------+
+--R               4                  2         |          2
+--R       (- B b x  + (- A b - 2B a)x  - 2A a)\|- 4a c + b
+--R  /
+--R                                                          +-----------+
+--R           2     2   4               3  2     2        2  |          2
+--R     ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2190
+
+--S 2191 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         2 4       2             2                2
+--R           ((A b - 2B a)c x  + (A b  - 2B a b)c x  + (A a b - 2B a )c)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                                       +-----------+
+--R                                2  2                   |          2
+--R         (((- A b - 2B a)c + B b )x  - 2A a c + B a b)\|- 4a c + b
+--R    /
+--R                                                                 +-----------+
+--R             3     2 2  4          2     3   2     2 2       2   |          2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|- 4a c + b
+--R     ,
+--R
+--R                            2 4          2             2                   2
+--R           ((- 2A b + 4B a)c x  + (- 2A b  + 4B a b)c x  + (- 2A a b + 4B a )c)
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                                                       +---------+
+--R                                2  2                   |        2
+--R         (((- A b - 2B a)c + B b )x  - 2A a c + B a b)\|4a c - b
+--R    /
+--R                                                                 +---------+
+--R             3     2 2  4          2     3   2     2 2       2   |        2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2191
+
+--S 2192 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (A b - 2B a)c
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                     2              +-----------+
+--R                                 2c x  + b          |          2
+--R       (- 2A b + 4B a)c atanh(--------------) + B b\|- 4a c + b
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R          2     2   |          2
+--R     (8a c  - 2b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2192
+
+--S 2193 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2193
+
+--S 2194 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        +---------+             2
+--R                        |        2          2c x  + b
+--R       (- 2A b + 4B a)c\|4a c - b  atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R     + 
+--R                                                      +---------+
+--R                        +-----------+          2      |        2
+--R                        |          2      (2c x  + b)\|4a c - b
+--R       (- 2A b + 4B a)c\|- 4a c + b  atan(-----------------------)
+--R                                                         2
+--R                                                 4a c - b
+--R     + 
+--R           +-----------+ +---------+
+--R           |          2  |        2
+--R       B b\|- 4a c + b  \|4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R          2     2   |          2  |        2
+--R     (8a c  - 2b c)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2194
+
+--S 2195 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2195
+
+)clear all
+
+--S 2196 of 3139
+t0:=x*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             3
+--R                          B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2196
+
+--S 2197 of 3139
+r0:=1/2*(-A*b+2*a*B+(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-_
+   (b*B-2*A*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                 2           4                   2  2
+--R         ((- 4A c  + 2B b c)x  + (- 4A b c + 2B b )x  - 4A a c + 2B a b)
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                     +-----------+
+--R                     2               |          2
+--R       ((2A c - B b)x  + A b - 2B a)\|- 4a c + b
+--R  /
+--R                                                          +-----------+
+--R           2     2   4               3  2     2        2  |          2
+--R     ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2197
+
+--S 2198 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2          4                2  2
+--R           ((2A c  - B b c)x  + (2A b c - B b )x  + 2A a c - B a b)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                       +-----------+
+--R                       2               |          2
+--R         ((2A c - B b)x  + A b - 2B a)\|- 4a c + b
+--R    /
+--R                                                            +-----------+
+--R             2     2   4               3  2     2        2  |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R     ,
+--R
+--R                 2           4                 2  2
+--R           ((4A c  - 2B b c)x  + (4A b c - 2B b )x  + 4A a c - 2B a b)
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                                       +---------+
+--R                       2               |        2
+--R         ((2A c - B b)x  + A b - 2B a)\|4a c - b
+--R    /
+--R                                                            +---------+
+--R             2     2   4               3  2     2        2  |        2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2198
+
+--S 2199 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (2A c - B b)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                 2
+--R                             2c x  + b
+--R       (4A c - 2B b)atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R                  +-----------+
+--R               2  |          2
+--R     (8a c - 2b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2199
+
+--S 2200 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2200
+
+--S 2201 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    +---------+             2
+--R                    |        2          2c x  + b
+--R       (2A c - B b)\|4a c - b  atanh(--------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                    +-----------+          2      |        2
+--R                    |          2      (2c x  + b)\|4a c - b
+--R       (2A c - B b)\|- 4a c + b  atan(-----------------------)
+--R                                                     2
+--R                                             4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2201
+
+--S 2202 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2202
+
+)clear all
+
+--S 2203 of 3139
+t0:=(A+B*x^2)/(x*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                              2
+--R                           B x  + A
+--R   (1)  ----------------------------------------------
+--R         2 9         7            2  5         3    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2203
+
+--S 2204 of 3139
+r0:=1/2*(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/2*(4*a^2*B*c+A*(b^3-6*a*b*c))*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^(3/2))+A*log(x)/a^2-_
+   1/4*A*log(a+b*x^2+c*x^4)/a^2
+--R 
+--R
+--R   (2)
+--R                           2  2       3   4            2       2          4  2
+--R           ((12A a b - 8B a )c  - 2A b c)x  + ((12A a b  - 8B a b)c - 2A b )x
+--R         + 
+--R                 2        3           3
+--R           (12A a b - 8B a )c - 2A a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                       2      2   4                    3  2       2         2
+--R             ((- 4A a c  + A b c)x  + (- 4A a b c + A b )x  - 4A a c + A a b )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                      2       2   4                    3  2        2          2
+--R             ((16A a c  - 4A b c)x  + (16A a b c - 4A b )x  + 16A a c - 4A a b )
+--R          *
+--R             log(x)
+--R         + 
+--R                           2    2       2          2       2
+--R           (- 2A a b + 4B a )c x  + 4A a c - 2A a b  + 2B a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                 +-----------+
+--R          3 2     2 2   4       3        2 3  2      4      3 2  |          2
+--R     ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2204
+
+--S 2205 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            2  2      3   4           2       2         4  2
+--R             ((6A a b - 4B a )c  - A b c)x  + ((6A a b  - 4B a b)c - A b )x
+--R           + 
+--R                  2        3          3
+--R             (6A a b - 4B a )c - A a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                         2      2   4                    3  2       2         2
+--R               ((- 4A a c  + A b c)x  + (- 4A a b c + A b )x  - 4A a c + A a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                           2       2   4                    3  2        2
+--R                   (16A a c  - 4A b c)x  + (16A a b c - 4A b )x  + 16A a c
+--R                 + 
+--R                           2
+--R                   - 4A a b
+--R            *
+--R               log(x)
+--R           + 
+--R                             2    2       2          2       2
+--R             (- 2A a b + 4B a )c x  + 4A a c - 2A a b  + 2B a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                                   +-----------+
+--R            3 2     2 2   4       3        2 3  2      4      3 2  |          2
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|- 4a c + b
+--R     ,
+--R
+--R                               2  2       3   4
+--R             ((- 12A a b + 8B a )c  + 2A b c)x
+--R           + 
+--R                      2       2          4  2           2        3           3
+--R           ((- 12A a b  + 8B a b)c + 2A b )x  + (- 12A a b + 8B a )c + 2A a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                         2      2   4                    3  2       2         2
+--R               ((- 4A a c  + A b c)x  + (- 4A a b c + A b )x  - 4A a c + A a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                           2       2   4                    3  2        2
+--R                   (16A a c  - 4A b c)x  + (16A a b c - 4A b )x  + 16A a c
+--R                 + 
+--R                           2
+--R                   - 4A a b
+--R            *
+--R               log(x)
+--R           + 
+--R                             2    2       2          2       2
+--R             (- 2A a b + 4B a )c x  + 4A a c - 2A a b  + 2B a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                   +---------+
+--R            3 2     2 2   4       3        2 3  2      4      3 2  |        2
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2205
+
+--S 2206 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        2        3
+--R         ((6A a b - 4B a )c - A b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                                  2
+--R                         2         3          2c x  + b
+--R       ((- 12A a b + 8B a )c + 2A b )atanh(--------------)
+--R                                            +-----------+
+--R                                            |          2
+--R                                           \|- 4a c + b
+--R  /
+--R                     +-----------+
+--R         3      2 2  |          2
+--R     (16a c - 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2206
+
+--S 2207 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2207
+
+--S 2208 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                    +---------+             2
+--R                        2        3  |        2          2c x  + b
+--R       ((- 6A a b + 4B a )c + A b )\|4a c - b  atanh(--------------)
+--R                                                      +-----------+
+--R                                                      |          2
+--R                                                     \|- 4a c + b
+--R     + 
+--R                                                                  +---------+
+--R                                    +-----------+          2      |        2
+--R                        2        3  |          2      (2c x  + b)\|4a c - b
+--R       ((- 6A a b + 4B a )c + A b )\|- 4a c + b  atan(-----------------------)
+--R                                                                     2
+--R                                                             4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R        3      2 2  |          2  |        2
+--R     (8a c - 2a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2208
+
+--S 2209 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2209
+
+)clear all
+
+--S 2210 of 3139
+t0:=(A+B*x^2)/(x^3*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                               2
+--R                            B x  + A
+--R   (1)  ------------------------------------------------
+--R         2 11         9            2  7         5    2 3
+--R        c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2210
+
+--S 2211 of 3139
+r0:=1/2*(-2*A*b^2+a*b*B+6*a*A*c)/(a^2*(b^2-4*a*c)*x^2)+1/2*(-a*b*B+_
+   A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*x^2*(a+b*x^2+c*x^4))+_
+   1/2*(a*b*B*(b^2-6*a*c)-2*A*(b^4-6*a*b^2*c+6*a^2*c^2))*atanh((b+_
+   2*c*x^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(3/2))-(2*A*b-a*B)*_
+   log(x)/a^3+1/4*(2*A*b-a*B)*log(a+b*x^2+c*x^4)/a^3
+--R 
+--R
+--R   (2)
+--R                 2 3             2        2   2        4         3    6
+--R           (24A a c  + (- 24A a b  + 12B a b)c  + (4A b  - 2B a b )c)x
+--R         + 
+--R                 2   2             3        2 2         5         4  4
+--R           (24A a b c  + (- 24A a b  + 12B a b )c + 4A b  - 2B a b )x
+--R         + 
+--R                 3 2           2 2        3            4       2 3  2
+--R           (24A a c  + (- 24A a b  + 12B a b)c + 4A a b  - 2B a b )x
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                              2  2          3        2    6
+--R               ((8A a b - 4B a )c  + (- 2A b  + B a b )c)x
+--R             + 
+--R                       2       2          4        3  4
+--R               ((8A a b  - 4B a b)c - 2A b  + B a b )x
+--R             + 
+--R                     2        3           3      2 2  2
+--R               ((8A a b - 4B a )c - 2A a b  + B a b )x
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                                  2  2        3         2    6
+--R               ((- 32A a b + 16B a )c  + (8A b  - 4B a b )c)x
+--R             + 
+--R                          2        2          4         3  4
+--R               ((- 32A a b  + 16B a b)c + 8A b  - 4B a b )x
+--R             + 
+--R                        2         3           3       2 2  2
+--R               ((- 32A a b + 16B a )c + 8A a b  - 4B a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R                   2 2          2       2     4
+--R           (- 12A a c  + (4A a b  - 2B a b)c)x
+--R         + 
+--R                    2        3           3       2 2  2       3        2 2
+--R           ((- 14A a b + 4B a )c + 4A a b  - 2B a b )x  - 8A a c + 2A a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            4 2     3 2   6       4        3 3  4       5      4 2  2
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + (16a c - 4a b )x )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2211
+
+--S 2212 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2 3             2       2   2        4        3    6
+--R             (12A a c  + (- 12A a b  + 6B a b)c  + (2A b  - B a b )c)x
+--R           + 
+--R                   2   2             3       2 2         5        4  4
+--R             (12A a b c  + (- 12A a b  + 6B a b )c + 2A b  - B a b )x
+--R           + 
+--R                   3 2           2 2       3            4      2 3  2
+--R             (12A a c  + (- 12A a b  + 6B a b)c + 2A a b  - B a b )x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                2  2          3        2    6
+--R                 ((8A a b - 4B a )c  + (- 2A b  + B a b )c)x
+--R               + 
+--R                         2       2          4        3  4
+--R                 ((8A a b  - 4B a b)c - 2A b  + B a b )x
+--R               + 
+--R                       2        3           3      2 2  2
+--R                 ((8A a b - 4B a )c - 2A a b  + B a b )x
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                                    2  2        3         2    6
+--R                 ((- 32A a b + 16B a )c  + (8A b  - 4B a b )c)x
+--R               + 
+--R                            2        2          4         3  4
+--R                 ((- 32A a b  + 16B a b)c + 8A b  - 4B a b )x
+--R               + 
+--R                          2         3           3       2 2  2
+--R                 ((- 32A a b + 16B a )c + 8A a b  - 4B a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                     2 2          2       2     4
+--R             (- 12A a c  + (4A a b  - 2B a b)c)x
+--R           + 
+--R                      2        3           3       2 2  2       3        2 2
+--R             ((- 14A a b + 4B a )c + 4A a b  - 2B a b )x  - 8A a c + 2A a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R              4 2     3 2   6       4        3 3  4       5      4 2  2
+--R         ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + (16a c - 4a b )x )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                     2 3           2        2   2          4         3    6
+--R             (- 24A a c  + (24A a b  - 12B a b)c  + (- 4A b  + 2B a b )c)x
+--R           + 
+--R                     2   2           3        2 2         5         4  4
+--R             (- 24A a b c  + (24A a b  - 12B a b )c - 4A b  + 2B a b )x
+--R           + 
+--R                     3 2         2 2        3            4       2 3  2
+--R             (- 24A a c  + (24A a b  - 12B a b)c - 4A a b  + 2B a b )x
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                                2  2          3        2    6
+--R                 ((8A a b - 4B a )c  + (- 2A b  + B a b )c)x
+--R               + 
+--R                         2       2          4        3  4
+--R                 ((8A a b  - 4B a b)c - 2A b  + B a b )x
+--R               + 
+--R                       2        3           3      2 2  2
+--R                 ((8A a b - 4B a )c - 2A a b  + B a b )x
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                                    2  2        3         2    6
+--R                 ((- 32A a b + 16B a )c  + (8A b  - 4B a b )c)x
+--R               + 
+--R                            2        2          4         3  4
+--R                 ((- 32A a b  + 16B a b)c + 8A b  - 4B a b )x
+--R               + 
+--R                          2         3           3       2 2  2
+--R                 ((- 32A a b + 16B a )c + 8A a b  - 4B a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                     2 2          2       2     4
+--R             (- 12A a c  + (4A a b  - 2B a b)c)x
+--R           + 
+--R                      2        3           3       2 2  2       3        2 2
+--R             ((- 14A a b + 4B a )c + 4A a b  - 2B a b )x  - 8A a c + 2A a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R              4 2     3 2   6       4        3 3  4       5      4 2  2
+--R         ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + (16a c - 4a b )x )
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2212
+
+--S 2213 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               2 2             2       2          4        3
+--R         (12A a c  + (- 12A a b  + 6B a b)c + 2A b  - B a b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                                                        2
+--R             2 2           2        2          4         3          2c x  + b
+--R     (- 24A a c  + (24A a b  - 12B a b)c - 4A b  + 2B a b )atanh(--------------)
+--R                                                                  +-----------+
+--R                                                                  |          2
+--R                                                                 \|- 4a c + b
+--R  /
+--R                     +-----------+
+--R         4      3 2  |          2
+--R     (16a c - 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2213
+
+--S 2214 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2214
+
+--S 2215 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                              +---------+
+--R                 2 2           2       2          4        3  |        2
+--R         (- 12A a c  + (12A a b  - 6B a b)c - 2A b  + B a b )\|4a c - b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                              +-----------+
+--R                 2 2           2       2          4        3  |          2
+--R         (- 12A a c  + (12A a b  - 6B a b)c - 2A b  + B a b )\|- 4a c + b
+--R      *
+--R                          +---------+
+--R                   2      |        2
+--R              (2c x  + b)\|4a c - b
+--R         atan(-----------------------)
+--R                             2
+--R                     4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R        4      3 2  |          2  |        2
+--R     (8a c - 2a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2215
+
+--S 2216 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2216
+
+)clear all
+
+--S 2217 of 3139
+t0:=x^6*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            8      6
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2217
+
+--S 2218 of 3139
+r0:=1/2*(3*b^2*B-A*b*c-10*a*B*c)*x/(c^2*(b^2-4*a*c))-1/2*(b*B-2*A*c)*x^3/_
+   (c*(b^2-4*a*c))-1/2*x^5*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))-1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (3*b^3*B-A*b^2*c-13*a*b*B*c+6*a*A*c^2+(-3*b^4*B+A*b^3*c+19*a*b^2*B*c-_
+   8*a*A*b*c^2-20*a^2*B*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*(b^2-4*a*c)*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-1/2*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*(3*b^3*B-A*b^2*c-13*a*b*B*c+6*a*A*c^2+_
+   (3*b^4*B-A*b^3*c-19*a*b^2*B*c+8*a*A*b*c^2+20*a^2*B*c^2)/_
+   sqrt(b^2-4*a*c))/(c^(5/2)*(b^2-4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      3         2            2       3   4
+--R               (6A a c  + (- A b  - 13B a b)c  + 3B b c)x
+--R             + 
+--R                        2         3          2         4  2       2 2
+--R               (6A a b c  + (- A b  - 13B a b )c + 3B b )x  + 6A a c
+--R             + 
+--R                       2        2            3
+--R               (- A a b  - 13B a b)c + 3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                             2  3       3          2  2       4   4
+--R           ((- 8A a b - 20B a )c  + (A b  + 19B a b )c  - 3B b c)x
+--R         + 
+--R                     2        2   2       4          3         5  2
+--R           ((- 8A a b  - 20B a b)c  + (A b  + 19B a b )c - 3B b )x
+--R         + 
+--R                  2         3  2         3        2 2           4
+--R           (- 8A a b - 20B a )c  + (A a b  + 19B a b )c - 3B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                      3         2            2       3   4
+--R               (6A a c  + (- A b  - 13B a b)c  + 3B b c)x
+--R             + 
+--R                        2         3          2         4  2       2 2
+--R               (6A a b c  + (- A b  - 13B a b )c + 3B b )x  + 6A a c
+--R             + 
+--R                       2        2            3
+--R               (- A a b  - 13B a b)c + 3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                           2  3         3          2  2       4   4
+--R           ((8A a b + 20B a )c  + (- A b  - 19B a b )c  + 3B b c)x
+--R         + 
+--R                   2        2   2         4          3         5  2
+--R           ((8A a b  + 20B a b)c  + (- A b  - 19B a b )c + 3B b )x
+--R         + 
+--R                2         3  2           3        2 2           4
+--R           (8A a b + 20B a )c  + (- A a b  - 19B a b )c + 3B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                  2       2   5            2       2                   3  3
+--R           (8B a c  - 2B b c)x  + (- 2A a c  + (A b  + 11B a b)c - 3B b )x
+--R         + 
+--R                          2           2
+--R           ((A a b + 10B a )c - 3B a b )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R             4     2 3  4          3     3 2  2     2 3       2 2  +-+
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x  + 8a c  - 2a b c )\|2
+--R    *
+--R                          +--------------------+ +------------------+
+--R        +-----------+     |   +-----------+      | +-----------+
+--R        |          2  +-+ |   |          2       | |          2
+--R       \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2218
+
+--S 2219 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4    2 3  4          3    3 2  2     2 3      2 2
+--R         ((4a c  - b c )x  + (4a b c  - b c )x  + 4a c  - a b c )
+--R      *
+--R         ROOT
+--R                        3 8       2 2 7         4 6      6 5
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                  ROOT
+--R                              4 2 6       4   2       3   2        2 2 3  5
+--R                         - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                       + 
+--R                                4 4       3     3        2 2 2 2          3 3
+--R                             - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                           + 
+--R                                   4 4
+--R                             - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                             3   5       2 2   4          3 2 3        4 3 2  3
+--R                         (12A B b  + 792A B a b  + 4788A B a b  + 2550B a b )c
+--R                       + 
+--R                               2 2 6          3   5        4 2 4  2
+--R                         (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                       + 
+--R                                3 7       4   6        4 8
+--R                         (108A B b  + 918B a b )c - 81B b
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                    2 2            3  4
+--R                (60A a b + 240A B a )c
+--R              + 
+--R                      2   3           2 2       2 3   3
+--R                (- 15A a b  - 300A B a b  - 420B a b)c
+--R              + 
+--R                  2 5            4       2 2 3  2            6       2   5
+--R                (A b  + 80A B a b  + 385B a b )c  + (- 6A B b  - 105B a b )c
+--R              + 
+--R                  2 7
+--R                9B b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              4 10              3 2           4   9
+--R                      12288A a c   + (- 10240A a b  - 16384B a b)c
+--R                    + 
+--R                              2 4           3 3  8
+--R                      (3072A a b  + 15360B a b )c
+--R                    + 
+--R                                 6          2 5  7         8           7  6
+--R                      (- 384A a b  - 5376B a b )c  + (16A b  + 832B a b )c
+--R                    + 
+--R                             9 5
+--R                      - 48B b c
+--R                 *
+--R                    ROOT
+--R                                4 2 6       4   2       3   2        2 2 3  5
+--R                           - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                         + 
+--R                                  4 4       3     3        2 2 2 2          3 3
+--R                               - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                             + 
+--R                                     4 4
+--R                               - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5       2 2   4          3 2 3
+--R                                 12A B b  + 792A B a b  + 4788A B a b
+--R                               + 
+--R                                      4 3 2
+--R                                 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5        4 2 4  2
+--R                           (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                         + 
+--R                                  3 7       4   6        4 8
+--R                           (108A B b  + 918B a b )c - 81B b
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                         3 3         2   4  6
+--R                  (- 144A a b - 1440A B a )c
+--R                + 
+--R                      3 2 3        2   3 2          2 4         3 5  5
+--R                  (88A a b  + 2016A B a b  + 7440A B a b + 4000B a )c
+--R                + 
+--R                        3   5       2   2 4          2 3 3         3 4 2  4
+--R                  (- 17A a b  - 882A B a b  - 7608A B a b  - 11360B a b )c
+--R                + 
+--R                    3 7       2     6          2 2 5        3 3 4  3
+--R                  (A b  + 153A B a b  + 2841A B a b  + 8818B a b )c
+--R                + 
+--R                       2   8         2   7        3 2 6  2
+--R                  (- 9A B b  - 459A B a b  - 2961B a b )c
+--R                + 
+--R                        2 9       3   8        3 10
+--R                  (27A B b  + 459B a b )c - 27B b
+--R             *
+--R                ROOT
+--R                               3 8       2 2 7         4 6      6 5
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                         ROOT
+--R                                     4 2 6
+--R                                - 81A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3  5
+--R                                (18A a b  + 792A B a b + 450A B a )c
+--R                              + 
+--R                                       4 4       3     3        2 2 2 2
+--R                                    - A b  - 196A B a b  - 2904A B a b
+--R                                  + 
+--R                                             3 3        4 4
+--R                                    - 2200A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                       3   5       2 2   4          3 2 3
+--R                                    12A B b  + 792A B a b  + 4788A B a b
+--R                                  + 
+--R                                         4 3 2
+--R                                    2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5        4 2 4  2
+--R                                (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                              + 
+--R                                       3 7       4   6        4 8
+--R                                (108A B b  + 918B a b )c - 81B b
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                           2 2            3  4
+--R                       (60A a b + 240A B a )c
+--R                     + 
+--R                             2   3           2 2       2 3   3
+--R                       (- 15A a b  - 300A B a b  - 420B a b)c
+--R                     + 
+--R                         2 5            4       2 2 3  2
+--R                       (A b  + 80A B a b  + 385B a b )c
+--R                     + 
+--R                                6       2   5       2 7
+--R                       (- 6A B b  - 105B a b )c + 9B b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                      4 3 5         4 2 2        3   3   4
+--R                  324A a c  + (- 81A a b  - 2268A B a b)c
+--R                + 
+--R                        4   4       3   2 3        2 2 3 2          3 4
+--R                      5A a b  + 647A B a b  + 5016A B a b  - 2500A B a b
+--R                    + 
+--R                             4 5
+--R                      - 2500B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3     5        2 2 2 4          3 3 3        4 4 2  2
+--R                  (- 45A B a b  - 1674A B a b  - 2727A B a b  + 5625B a b )c
+--R                + 
+--R                       2 2   6          3 2 5        4 3 4           3   7
+--R                  (135A B a b  + 1323A B a b  - 1971B a b )c - 135A B a b
+--R                + 
+--R                      4 2 6
+--R                  189B a b
+--R             *
+--R                x
+--R     + 
+--R                 4    2 3  4            3    3 2  2     2 3      2 2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c )x  - 4a c  + a b c )
+--R      *
+--R         ROOT
+--R                          3 8       2 2 7         4 6      6 5
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                  ROOT
+--R                              4 2 6       4   2       3   2        2 2 3  5
+--R                         - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                       + 
+--R                                4 4       3     3        2 2 2 2          3 3
+--R                             - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                           + 
+--R                                   4 4
+--R                             - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                             3   5       2 2   4          3 2 3        4 3 2  3
+--R                         (12A B b  + 792A B a b  + 4788A B a b  + 2550B a b )c
+--R                       + 
+--R                               2 2 6          3   5        4 2 4  2
+--R                         (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                       + 
+--R                                3 7       4   6        4 8
+--R                         (108A B b  + 918B a b )c - 81B b
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                    2 2            3  4
+--R                (60A a b + 240A B a )c
+--R              + 
+--R                      2   3           2 2       2 3   3
+--R                (- 15A a b  - 300A B a b  - 420B a b)c
+--R              + 
+--R                  2 5            4       2 2 3  2            6       2   5
+--R                (A b  + 80A B a b  + 385B a b )c  + (- 6A B b  - 105B a b )c
+--R              + 
+--R                  2 7
+--R                9B b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              4 10              3 2           4   9
+--R                      12288A a c   + (- 10240A a b  - 16384B a b)c
+--R                    + 
+--R                              2 4           3 3  8
+--R                      (3072A a b  + 15360B a b )c
+--R                    + 
+--R                                 6          2 5  7         8           7  6
+--R                      (- 384A a b  - 5376B a b )c  + (16A b  + 832B a b )c
+--R                    + 
+--R                             9 5
+--R                      - 48B b c
+--R                 *
+--R                    ROOT
+--R                                4 2 6       4   2       3   2        2 2 3  5
+--R                           - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                         + 
+--R                                  4 4       3     3        2 2 2 2          3 3
+--R                               - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                             + 
+--R                                     4 4
+--R                               - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5       2 2   4          3 2 3
+--R                                 12A B b  + 792A B a b  + 4788A B a b
+--R                               + 
+--R                                      4 3 2
+--R                                 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5        4 2 4  2
+--R                           (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                         + 
+--R                                  3 7       4   6        4 8
+--R                           (108A B b  + 918B a b )c - 81B b
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                       3 3         2   4  6
+--R                  (144A a b + 1440A B a )c
+--R                + 
+--R                        3 2 3        2   3 2          2 4         3 5  5
+--R                  (- 88A a b  - 2016A B a b  - 7440A B a b - 4000B a )c
+--R                + 
+--R                      3   5       2   2 4          2 3 3         3 4 2  4
+--R                  (17A a b  + 882A B a b  + 7608A B a b  + 11360B a b )c
+--R                + 
+--R                      3 7       2     6          2 2 5        3 3 4  3
+--R                  (- A b  - 153A B a b  - 2841A B a b  - 8818B a b )c
+--R                + 
+--R                     2   8         2   7        3 2 6  2
+--R                  (9A B b  + 459A B a b  + 2961B a b )c
+--R                + 
+--R                          2 9       3   8        3 10
+--R                  (- 27A B b  - 459B a b )c + 27B b
+--R             *
+--R                ROOT
+--R                                 3 8       2 2 7         4 6      6 5
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                     4 2 6
+--R                                - 81A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3  5
+--R                                (18A a b  + 792A B a b + 450A B a )c
+--R                              + 
+--R                                       4 4       3     3        2 2 2 2
+--R                                    - A b  - 196A B a b  - 2904A B a b
+--R                                  + 
+--R                                             3 3        4 4
+--R                                    - 2200A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                       3   5       2 2   4          3 2 3
+--R                                    12A B b  + 792A B a b  + 4788A B a b
+--R                                  + 
+--R                                         4 3 2
+--R                                    2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5        4 2 4  2
+--R                                (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                              + 
+--R                                       3 7       4   6        4 8
+--R                                (108A B b  + 918B a b )c - 81B b
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                           2 2            3  4
+--R                       (60A a b + 240A B a )c
+--R                     + 
+--R                             2   3           2 2       2 3   3
+--R                       (- 15A a b  - 300A B a b  - 420B a b)c
+--R                     + 
+--R                         2 5            4       2 2 3  2
+--R                       (A b  + 80A B a b  + 385B a b )c
+--R                     + 
+--R                                6       2   5       2 7
+--R                       (- 6A B b  - 105B a b )c + 9B b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                      4 3 5         4 2 2        3   3   4
+--R                  324A a c  + (- 81A a b  - 2268A B a b)c
+--R                + 
+--R                        4   4       3   2 3        2 2 3 2          3 4
+--R                      5A a b  + 647A B a b  + 5016A B a b  - 2500A B a b
+--R                    + 
+--R                             4 5
+--R                      - 2500B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3     5        2 2 2 4          3 3 3        4 4 2  2
+--R                  (- 45A B a b  - 1674A B a b  - 2727A B a b  + 5625B a b )c
+--R                + 
+--R                       2 2   6          3 2 5        4 3 4           3   7
+--R                  (135A B a b  + 1323A B a b  - 1971B a b )c - 135A B a b
+--R                + 
+--R                      4 2 6
+--R                  189B a b
+--R             *
+--R                x
+--R     + 
+--R               4    2 3  4          3    3 2  2     2 3      2 2
+--R         ((4a c  - b c )x  + (4a b c  - b c )x  + 4a c  - a b c )
+--R      *
+--R         ROOT
+--R                          3 8       2 2 7         4 6      6 5
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                  ROOT
+--R                              4 2 6       4   2       3   2        2 2 3  5
+--R                         - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                       + 
+--R                                4 4       3     3        2 2 2 2          3 3
+--R                             - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                           + 
+--R                                   4 4
+--R                             - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                             3   5       2 2   4          3 2 3        4 3 2  3
+--R                         (12A B b  + 792A B a b  + 4788A B a b  + 2550B a b )c
+--R                       + 
+--R                               2 2 6          3   5        4 2 4  2
+--R                         (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                       + 
+--R                                3 7       4   6        4 8
+--R                         (108A B b  + 918B a b )c - 81B b
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                    2 2            3  4
+--R                (60A a b + 240A B a )c
+--R              + 
+--R                      2   3           2 2       2 3   3
+--R                (- 15A a b  - 300A B a b  - 420B a b)c
+--R              + 
+--R                  2 5            4       2 2 3  2            6       2   5
+--R                (A b  + 80A B a b  + 385B a b )c  + (- 6A B b  - 105B a b )c
+--R              + 
+--R                  2 7
+--R                9B b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                4 10            3 2           4   9
+--R                      - 12288A a c   + (10240A a b  + 16384B a b)c
+--R                    + 
+--R                                2 4           3 3  8
+--R                      (- 3072A a b  - 15360B a b )c
+--R                    + 
+--R                               6          2 5  7           8           7  6
+--R                      (384A a b  + 5376B a b )c  + (- 16A b  - 832B a b )c
+--R                    + 
+--R                           9 5
+--R                      48B b c
+--R                 *
+--R                    ROOT
+--R                                4 2 6       4   2       3   2        2 2 3  5
+--R                           - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                         + 
+--R                                  4 4       3     3        2 2 2 2          3 3
+--R                               - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                             + 
+--R                                     4 4
+--R                               - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5       2 2   4          3 2 3
+--R                                 12A B b  + 792A B a b  + 4788A B a b
+--R                               + 
+--R                                      4 3 2
+--R                                 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5        4 2 4  2
+--R                           (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                         + 
+--R                                  3 7       4   6        4 8
+--R                           (108A B b  + 918B a b )c - 81B b
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                         3 3         2   4  6
+--R                  (- 144A a b - 1440A B a )c
+--R                + 
+--R                      3 2 3        2   3 2          2 4         3 5  5
+--R                  (88A a b  + 2016A B a b  + 7440A B a b + 4000B a )c
+--R                + 
+--R                        3   5       2   2 4          2 3 3         3 4 2  4
+--R                  (- 17A a b  - 882A B a b  - 7608A B a b  - 11360B a b )c
+--R                + 
+--R                    3 7       2     6          2 2 5        3 3 4  3
+--R                  (A b  + 153A B a b  + 2841A B a b  + 8818B a b )c
+--R                + 
+--R                       2   8         2   7        3 2 6  2
+--R                  (- 9A B b  - 459A B a b  - 2961B a b )c
+--R                + 
+--R                        2 9       3   8        3 10
+--R                  (27A B b  + 459B a b )c - 27B b
+--R             *
+--R                ROOT
+--R                                 3 8       2 2 7         4 6      6 5
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                     4 2 6
+--R                                - 81A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3  5
+--R                                (18A a b  + 792A B a b + 450A B a )c
+--R                              + 
+--R                                       4 4       3     3        2 2 2 2
+--R                                    - A b  - 196A B a b  - 2904A B a b
+--R                                  + 
+--R                                             3 3        4 4
+--R                                    - 2200A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                       3   5       2 2   4          3 2 3
+--R                                    12A B b  + 792A B a b  + 4788A B a b
+--R                                  + 
+--R                                         4 3 2
+--R                                    2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5        4 2 4  2
+--R                                (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                              + 
+--R                                       3 7       4   6        4 8
+--R                                (108A B b  + 918B a b )c - 81B b
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                           2 2            3  4
+--R                       (60A a b + 240A B a )c
+--R                     + 
+--R                             2   3           2 2       2 3   3
+--R                       (- 15A a b  - 300A B a b  - 420B a b)c
+--R                     + 
+--R                         2 5            4       2 2 3  2
+--R                       (A b  + 80A B a b  + 385B a b )c
+--R                     + 
+--R                                6       2   5       2 7
+--R                       (- 6A B b  - 105B a b )c + 9B b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                      4 3 5         4 2 2        3   3   4
+--R                  324A a c  + (- 81A a b  - 2268A B a b)c
+--R                + 
+--R                        4   4       3   2 3        2 2 3 2          3 4
+--R                      5A a b  + 647A B a b  + 5016A B a b  - 2500A B a b
+--R                    + 
+--R                             4 5
+--R                      - 2500B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3     5        2 2 2 4          3 3 3        4 4 2  2
+--R                  (- 45A B a b  - 1674A B a b  - 2727A B a b  + 5625B a b )c
+--R                + 
+--R                       2 2   6          3 2 5        4 3 4           3   7
+--R                  (135A B a b  + 1323A B a b  - 1971B a b )c - 135A B a b
+--R                + 
+--R                      4 2 6
+--R                  189B a b
+--R             *
+--R                x
+--R     + 
+--R                 4    2 3  4            3    3 2  2     2 3      2 2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c )x  - 4a c  + a b c )
+--R      *
+--R         ROOT
+--R                        3 8       2 2 7         4 6      6 5
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                  ROOT
+--R                              4 2 6       4   2       3   2        2 2 3  5
+--R                         - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                       + 
+--R                                4 4       3     3        2 2 2 2          3 3
+--R                             - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                           + 
+--R                                   4 4
+--R                             - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                             3   5       2 2   4          3 2 3        4 3 2  3
+--R                         (12A B b  + 792A B a b  + 4788A B a b  + 2550B a b )c
+--R                       + 
+--R                               2 2 6          3   5        4 2 4  2
+--R                         (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                       + 
+--R                                3 7       4   6        4 8
+--R                         (108A B b  + 918B a b )c - 81B b
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                    2 2            3  4
+--R                (60A a b + 240A B a )c
+--R              + 
+--R                      2   3           2 2       2 3   3
+--R                (- 15A a b  - 300A B a b  - 420B a b)c
+--R              + 
+--R                  2 5            4       2 2 3  2            6       2   5
+--R                (A b  + 80A B a b  + 385B a b )c  + (- 6A B b  - 105B a b )c
+--R              + 
+--R                  2 7
+--R                9B b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                4 10            3 2           4   9
+--R                      - 12288A a c   + (10240A a b  + 16384B a b)c
+--R                    + 
+--R                                2 4           3 3  8
+--R                      (- 3072A a b  - 15360B a b )c
+--R                    + 
+--R                               6          2 5  7           8           7  6
+--R                      (384A a b  + 5376B a b )c  + (- 16A b  - 832B a b )c
+--R                    + 
+--R                           9 5
+--R                      48B b c
+--R                 *
+--R                    ROOT
+--R                                4 2 6       4   2       3   2        2 2 3  5
+--R                           - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                         + 
+--R                                  4 4       3     3        2 2 2 2          3 3
+--R                               - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                             + 
+--R                                     4 4
+--R                               - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5       2 2   4          3 2 3
+--R                                 12A B b  + 792A B a b  + 4788A B a b
+--R                               + 
+--R                                      4 3 2
+--R                                 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5        4 2 4  2
+--R                           (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                         + 
+--R                                  3 7       4   6        4 8
+--R                           (108A B b  + 918B a b )c - 81B b
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                       3 3         2   4  6
+--R                  (144A a b + 1440A B a )c
+--R                + 
+--R                        3 2 3        2   3 2          2 4         3 5  5
+--R                  (- 88A a b  - 2016A B a b  - 7440A B a b - 4000B a )c
+--R                + 
+--R                      3   5       2   2 4          2 3 3         3 4 2  4
+--R                  (17A a b  + 882A B a b  + 7608A B a b  + 11360B a b )c
+--R                + 
+--R                      3 7       2     6          2 2 5        3 3 4  3
+--R                  (- A b  - 153A B a b  - 2841A B a b  - 8818B a b )c
+--R                + 
+--R                     2   8         2   7        3 2 6  2
+--R                  (9A B b  + 459A B a b  + 2961B a b )c
+--R                + 
+--R                          2 9       3   8        3 10
+--R                  (- 27A B b  - 459B a b )c + 27B b
+--R             *
+--R                ROOT
+--R                               3 8       2 2 7         4 6      6 5
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                         ROOT
+--R                                     4 2 6
+--R                                - 81A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3  5
+--R                                (18A a b  + 792A B a b + 450A B a )c
+--R                              + 
+--R                                       4 4       3     3        2 2 2 2
+--R                                    - A b  - 196A B a b  - 2904A B a b
+--R                                  + 
+--R                                             3 3        4 4
+--R                                    - 2200A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                       3   5       2 2   4          3 2 3
+--R                                    12A B b  + 792A B a b  + 4788A B a b
+--R                                  + 
+--R                                         4 3 2
+--R                                    2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5        4 2 4  2
+--R                                (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                              + 
+--R                                       3 7       4   6        4 8
+--R                                (108A B b  + 918B a b )c - 81B b
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                           2 2            3  4
+--R                       (60A a b + 240A B a )c
+--R                     + 
+--R                             2   3           2 2       2 3   3
+--R                       (- 15A a b  - 300A B a b  - 420B a b)c
+--R                     + 
+--R                         2 5            4       2 2 3  2
+--R                       (A b  + 80A B a b  + 385B a b )c
+--R                     + 
+--R                                6       2   5       2 7
+--R                       (- 6A B b  - 105B a b )c + 9B b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                      4 3 5         4 2 2        3   3   4
+--R                  324A a c  + (- 81A a b  - 2268A B a b)c
+--R                + 
+--R                        4   4       3   2 3        2 2 3 2          3 4
+--R                      5A a b  + 647A B a b  + 5016A B a b  - 2500A B a b
+--R                    + 
+--R                             4 5
+--R                      - 2500B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3     5        2 2 2 4          3 3 3        4 4 2  2
+--R                  (- 45A B a b  - 1674A B a b  - 2727A B a b  + 5625B a b )c
+--R                + 
+--R                       2 2   6          3 2 5        4 3 4           3   7
+--R                  (135A B a b  + 1323A B a b  - 1971B a b )c - 135A B a b
+--R                + 
+--R                      4 2 6
+--R                  189B a b
+--R             *
+--R                x
+--R     + 
+--R              2       2   5            2       2                   3  3
+--R       (8B a c  - 2B b c)x  + (- 2A a c  + (A b  + 11B a b)c - 3B b )x
+--R     + 
+--R                      2           2
+--R       ((A a b + 10B a )c - 3B a b )x
+--R  /
+--R          4     2 3  4          3     3 2  2     2 3       2 2
+--R     (8a c  - 2b c )x  + (8a b c  - 2b c )x  + 8a c  - 2a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2219
+
+--S 2220 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +--------------------+
+--R                            +-----------+     |   +-----------+
+--R              3    2 2  +-+ |          2  +-+ |   |          2
+--R         (4a c  - b c )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 8       2 2 7         4 6      6 5
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                  ROOT
+--R                              4 2 6       4   2       3   2        2 2 3  5
+--R                         - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                       + 
+--R                                4 4       3     3        2 2 2 2          3 3
+--R                             - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                           + 
+--R                                   4 4
+--R                             - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                             3   5       2 2   4          3 2 3        4 3 2  3
+--R                         (12A B b  + 792A B a b  + 4788A B a b  + 2550B a b )c
+--R                       + 
+--R                               2 2 6          3   5        4 2 4  2
+--R                         (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                       + 
+--R                                3 7       4   6        4 8
+--R                         (108A B b  + 918B a b )c - 81B b
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                    2 2            3  4
+--R                (60A a b + 240A B a )c
+--R              + 
+--R                      2   3           2 2       2 3   3
+--R                (- 15A a b  - 300A B a b  - 420B a b)c
+--R              + 
+--R                  2 5            4       2 2 3  2            6       2   5
+--R                (A b  + 80A B a b  + 385B a b )c  + (- 6A B b  - 105B a b )c
+--R              + 
+--R                  2 7
+--R                9B b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              4 10              3 2           4   9
+--R                      12288A a c   + (- 10240A a b  - 16384B a b)c
+--R                    + 
+--R                              2 4           3 3  8
+--R                      (3072A a b  + 15360B a b )c
+--R                    + 
+--R                                 6          2 5  7         8           7  6
+--R                      (- 384A a b  - 5376B a b )c  + (16A b  + 832B a b )c
+--R                    + 
+--R                             9 5
+--R                      - 48B b c
+--R                 *
+--R                    ROOT
+--R                                4 2 6       4   2       3   2        2 2 3  5
+--R                           - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                         + 
+--R                                  4 4       3     3        2 2 2 2          3 3
+--R                               - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                             + 
+--R                                     4 4
+--R                               - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5       2 2   4          3 2 3
+--R                                 12A B b  + 792A B a b  + 4788A B a b
+--R                               + 
+--R                                      4 3 2
+--R                                 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5        4 2 4  2
+--R                           (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                         + 
+--R                                  3 7       4   6        4 8
+--R                           (108A B b  + 918B a b )c - 81B b
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                         3 3         2   4  6
+--R                  (- 144A a b - 1440A B a )c
+--R                + 
+--R                      3 2 3        2   3 2          2 4         3 5  5
+--R                  (88A a b  + 2016A B a b  + 7440A B a b + 4000B a )c
+--R                + 
+--R                        3   5       2   2 4          2 3 3         3 4 2  4
+--R                  (- 17A a b  - 882A B a b  - 7608A B a b  - 11360B a b )c
+--R                + 
+--R                    3 7       2     6          2 2 5        3 3 4  3
+--R                  (A b  + 153A B a b  + 2841A B a b  + 8818B a b )c
+--R                + 
+--R                       2   8         2   7        3 2 6  2
+--R                  (- 9A B b  - 459A B a b  - 2961B a b )c
+--R                + 
+--R                        2 9       3   8        3 10
+--R                  (27A B b  + 459B a b )c - 27B b
+--R             *
+--R                ROOT
+--R                               3 8       2 2 7         4 6      6 5
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                         ROOT
+--R                                     4 2 6
+--R                                - 81A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3  5
+--R                                (18A a b  + 792A B a b + 450A B a )c
+--R                              + 
+--R                                       4 4       3     3        2 2 2 2
+--R                                    - A b  - 196A B a b  - 2904A B a b
+--R                                  + 
+--R                                             3 3        4 4
+--R                                    - 2200A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                       3   5       2 2   4          3 2 3
+--R                                    12A B b  + 792A B a b  + 4788A B a b
+--R                                  + 
+--R                                         4 3 2
+--R                                    2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5        4 2 4  2
+--R                                (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                              + 
+--R                                       3 7       4   6        4 8
+--R                                (108A B b  + 918B a b )c - 81B b
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                           2 2            3  4
+--R                       (60A a b + 240A B a )c
+--R                     + 
+--R                             2   3           2 2       2 3   3
+--R                       (- 15A a b  - 300A B a b  - 420B a b)c
+--R                     + 
+--R                         2 5            4       2 2 3  2
+--R                       (A b  + 80A B a b  + 385B a b )c
+--R                     + 
+--R                                6       2   5       2 7
+--R                       (- 6A B b  - 105B a b )c + 9B b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                      4 3 5         4 2 2        3   3   4
+--R                  324A a c  + (- 81A a b  - 2268A B a b)c
+--R                + 
+--R                        4   4       3   2 3        2 2 3 2          3 4
+--R                      5A a b  + 647A B a b  + 5016A B a b  - 2500A B a b
+--R                    + 
+--R                             4 5
+--R                      - 2500B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3     5        2 2 2 4          3 3 3        4 4 2  2
+--R                  (- 45A B a b  - 1674A B a b  - 2727A B a b  + 5625B a b )c
+--R                + 
+--R                       2 2   6          3 2 5        4 3 4           3   7
+--R                  (135A B a b  + 1323A B a b  - 1971B a b )c - 135A B a b
+--R                + 
+--R                      4 2 6
+--R                  189B a b
+--R             *
+--R                x
+--R     + 
+--R                              +-----------+
+--R                3    2 2  +-+ |          2  +-+
+--R         (- 4a c  + b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 8       2 2 7         4 6      6 5
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                  ROOT
+--R                              4 2 6       4   2       3   2        2 2 3  5
+--R                         - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                       + 
+--R                                4 4       3     3        2 2 2 2          3 3
+--R                             - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                           + 
+--R                                   4 4
+--R                             - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                             3   5       2 2   4          3 2 3        4 3 2  3
+--R                         (12A B b  + 792A B a b  + 4788A B a b  + 2550B a b )c
+--R                       + 
+--R                               2 2 6          3   5        4 2 4  2
+--R                         (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                       + 
+--R                                3 7       4   6        4 8
+--R                         (108A B b  + 918B a b )c - 81B b
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                    2 2            3  4
+--R                (60A a b + 240A B a )c
+--R              + 
+--R                      2   3           2 2       2 3   3
+--R                (- 15A a b  - 300A B a b  - 420B a b)c
+--R              + 
+--R                  2 5            4       2 2 3  2            6       2   5
+--R                (A b  + 80A B a b  + 385B a b )c  + (- 6A B b  - 105B a b )c
+--R              + 
+--R                  2 7
+--R                9B b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              4 10              3 2           4   9
+--R                      12288A a c   + (- 10240A a b  - 16384B a b)c
+--R                    + 
+--R                              2 4           3 3  8
+--R                      (3072A a b  + 15360B a b )c
+--R                    + 
+--R                                 6          2 5  7         8           7  6
+--R                      (- 384A a b  - 5376B a b )c  + (16A b  + 832B a b )c
+--R                    + 
+--R                             9 5
+--R                      - 48B b c
+--R                 *
+--R                    ROOT
+--R                                4 2 6       4   2       3   2        2 2 3  5
+--R                           - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                         + 
+--R                                  4 4       3     3        2 2 2 2          3 3
+--R                               - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                             + 
+--R                                     4 4
+--R                               - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5       2 2   4          3 2 3
+--R                                 12A B b  + 792A B a b  + 4788A B a b
+--R                               + 
+--R                                      4 3 2
+--R                                 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5        4 2 4  2
+--R                           (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                         + 
+--R                                  3 7       4   6        4 8
+--R                           (108A B b  + 918B a b )c - 81B b
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                       3 3         2   4  6
+--R                  (144A a b + 1440A B a )c
+--R                + 
+--R                        3 2 3        2   3 2          2 4         3 5  5
+--R                  (- 88A a b  - 2016A B a b  - 7440A B a b - 4000B a )c
+--R                + 
+--R                      3   5       2   2 4          2 3 3         3 4 2  4
+--R                  (17A a b  + 882A B a b  + 7608A B a b  + 11360B a b )c
+--R                + 
+--R                      3 7       2     6          2 2 5        3 3 4  3
+--R                  (- A b  - 153A B a b  - 2841A B a b  - 8818B a b )c
+--R                + 
+--R                     2   8         2   7        3 2 6  2
+--R                  (9A B b  + 459A B a b  + 2961B a b )c
+--R                + 
+--R                          2 9       3   8        3 10
+--R                  (- 27A B b  - 459B a b )c + 27B b
+--R             *
+--R                ROOT
+--R                                 3 8       2 2 7         4 6      6 5
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                     4 2 6
+--R                                - 81A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3  5
+--R                                (18A a b  + 792A B a b + 450A B a )c
+--R                              + 
+--R                                       4 4       3     3        2 2 2 2
+--R                                    - A b  - 196A B a b  - 2904A B a b
+--R                                  + 
+--R                                             3 3        4 4
+--R                                    - 2200A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                       3   5       2 2   4          3 2 3
+--R                                    12A B b  + 792A B a b  + 4788A B a b
+--R                                  + 
+--R                                         4 3 2
+--R                                    2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5        4 2 4  2
+--R                                (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                              + 
+--R                                       3 7       4   6        4 8
+--R                                (108A B b  + 918B a b )c - 81B b
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                           2 2            3  4
+--R                       (60A a b + 240A B a )c
+--R                     + 
+--R                             2   3           2 2       2 3   3
+--R                       (- 15A a b  - 300A B a b  - 420B a b)c
+--R                     + 
+--R                         2 5            4       2 2 3  2
+--R                       (A b  + 80A B a b  + 385B a b )c
+--R                     + 
+--R                                6       2   5       2 7
+--R                       (- 6A B b  - 105B a b )c + 9B b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                      4 3 5         4 2 2        3   3   4
+--R                  324A a c  + (- 81A a b  - 2268A B a b)c
+--R                + 
+--R                        4   4       3   2 3        2 2 3 2          3 4
+--R                      5A a b  + 647A B a b  + 5016A B a b  - 2500A B a b
+--R                    + 
+--R                             4 5
+--R                      - 2500B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3     5        2 2 2 4          3 3 3        4 4 2  2
+--R                  (- 45A B a b  - 1674A B a b  - 2727A B a b  + 5625B a b )c
+--R                + 
+--R                       2 2   6          3 2 5        4 3 4           3   7
+--R                  (135A B a b  + 1323A B a b  - 1971B a b )c - 135A B a b
+--R                + 
+--R                      4 2 6
+--R                  189B a b
+--R             *
+--R                x
+--R     + 
+--R                            +-----------+
+--R              3    2 2  +-+ |          2  +-+
+--R         (4a c  - b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 8       2 2 7         4 6      6 5
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                  ROOT
+--R                              4 2 6       4   2       3   2        2 2 3  5
+--R                         - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                       + 
+--R                                4 4       3     3        2 2 2 2          3 3
+--R                             - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                           + 
+--R                                   4 4
+--R                             - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                             3   5       2 2   4          3 2 3        4 3 2  3
+--R                         (12A B b  + 792A B a b  + 4788A B a b  + 2550B a b )c
+--R                       + 
+--R                               2 2 6          3   5        4 2 4  2
+--R                         (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                       + 
+--R                                3 7       4   6        4 8
+--R                         (108A B b  + 918B a b )c - 81B b
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                    2 2            3  4
+--R                (60A a b + 240A B a )c
+--R              + 
+--R                      2   3           2 2       2 3   3
+--R                (- 15A a b  - 300A B a b  - 420B a b)c
+--R              + 
+--R                  2 5            4       2 2 3  2            6       2   5
+--R                (A b  + 80A B a b  + 385B a b )c  + (- 6A B b  - 105B a b )c
+--R              + 
+--R                  2 7
+--R                9B b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                4 10            3 2           4   9
+--R                      - 12288A a c   + (10240A a b  + 16384B a b)c
+--R                    + 
+--R                                2 4           3 3  8
+--R                      (- 3072A a b  - 15360B a b )c
+--R                    + 
+--R                               6          2 5  7           8           7  6
+--R                      (384A a b  + 5376B a b )c  + (- 16A b  - 832B a b )c
+--R                    + 
+--R                           9 5
+--R                      48B b c
+--R                 *
+--R                    ROOT
+--R                                4 2 6       4   2       3   2        2 2 3  5
+--R                           - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                         + 
+--R                                  4 4       3     3        2 2 2 2          3 3
+--R                               - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                             + 
+--R                                     4 4
+--R                               - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5       2 2   4          3 2 3
+--R                                 12A B b  + 792A B a b  + 4788A B a b
+--R                               + 
+--R                                      4 3 2
+--R                                 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5        4 2 4  2
+--R                           (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                         + 
+--R                                  3 7       4   6        4 8
+--R                           (108A B b  + 918B a b )c - 81B b
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                         3 3         2   4  6
+--R                  (- 144A a b - 1440A B a )c
+--R                + 
+--R                      3 2 3        2   3 2          2 4         3 5  5
+--R                  (88A a b  + 2016A B a b  + 7440A B a b + 4000B a )c
+--R                + 
+--R                        3   5       2   2 4          2 3 3         3 4 2  4
+--R                  (- 17A a b  - 882A B a b  - 7608A B a b  - 11360B a b )c
+--R                + 
+--R                    3 7       2     6          2 2 5        3 3 4  3
+--R                  (A b  + 153A B a b  + 2841A B a b  + 8818B a b )c
+--R                + 
+--R                       2   8         2   7        3 2 6  2
+--R                  (- 9A B b  - 459A B a b  - 2961B a b )c
+--R                + 
+--R                        2 9       3   8        3 10
+--R                  (27A B b  + 459B a b )c - 27B b
+--R             *
+--R                ROOT
+--R                                 3 8       2 2 7         4 6      6 5
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                     4 2 6
+--R                                - 81A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3  5
+--R                                (18A a b  + 792A B a b + 450A B a )c
+--R                              + 
+--R                                       4 4       3     3        2 2 2 2
+--R                                    - A b  - 196A B a b  - 2904A B a b
+--R                                  + 
+--R                                             3 3        4 4
+--R                                    - 2200A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                       3   5       2 2   4          3 2 3
+--R                                    12A B b  + 792A B a b  + 4788A B a b
+--R                                  + 
+--R                                         4 3 2
+--R                                    2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5        4 2 4  2
+--R                                (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                              + 
+--R                                       3 7       4   6        4 8
+--R                                (108A B b  + 918B a b )c - 81B b
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                           2 2            3  4
+--R                       (60A a b + 240A B a )c
+--R                     + 
+--R                             2   3           2 2       2 3   3
+--R                       (- 15A a b  - 300A B a b  - 420B a b)c
+--R                     + 
+--R                         2 5            4       2 2 3  2
+--R                       (A b  + 80A B a b  + 385B a b )c
+--R                     + 
+--R                                6       2   5       2 7
+--R                       (- 6A B b  - 105B a b )c + 9B b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                      4 3 5         4 2 2        3   3   4
+--R                  324A a c  + (- 81A a b  - 2268A B a b)c
+--R                + 
+--R                        4   4       3   2 3        2 2 3 2          3 4
+--R                      5A a b  + 647A B a b  + 5016A B a b  - 2500A B a b
+--R                    + 
+--R                             4 5
+--R                      - 2500B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3     5        2 2 2 4          3 3 3        4 4 2  2
+--R                  (- 45A B a b  - 1674A B a b  - 2727A B a b  + 5625B a b )c
+--R                + 
+--R                       2 2   6          3 2 5        4 3 4           3   7
+--R                  (135A B a b  + 1323A B a b  - 1971B a b )c - 135A B a b
+--R                + 
+--R                      4 2 6
+--R                  189B a b
+--R             *
+--R                x
+--R     + 
+--R                                                +--------------------+
+--R                              +-----------+     |   +-----------+
+--R                3    2 2  +-+ |          2  +-+ |   |          2
+--R         (- 4a c  + b c )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 8       2 2 7         4 6      6 5
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                  ROOT
+--R                              4 2 6       4   2       3   2        2 2 3  5
+--R                         - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                       + 
+--R                                4 4       3     3        2 2 2 2          3 3
+--R                             - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                           + 
+--R                                   4 4
+--R                             - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                             3   5       2 2   4          3 2 3        4 3 2  3
+--R                         (12A B b  + 792A B a b  + 4788A B a b  + 2550B a b )c
+--R                       + 
+--R                               2 2 6          3   5        4 2 4  2
+--R                         (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                       + 
+--R                                3 7       4   6        4 8
+--R                         (108A B b  + 918B a b )c - 81B b
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                    2 2            3  4
+--R                (60A a b + 240A B a )c
+--R              + 
+--R                      2   3           2 2       2 3   3
+--R                (- 15A a b  - 300A B a b  - 420B a b)c
+--R              + 
+--R                  2 5            4       2 2 3  2            6       2   5
+--R                (A b  + 80A B a b  + 385B a b )c  + (- 6A B b  - 105B a b )c
+--R              + 
+--R                  2 7
+--R                9B b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                4 10            3 2           4   9
+--R                      - 12288A a c   + (10240A a b  + 16384B a b)c
+--R                    + 
+--R                                2 4           3 3  8
+--R                      (- 3072A a b  - 15360B a b )c
+--R                    + 
+--R                               6          2 5  7           8           7  6
+--R                      (384A a b  + 5376B a b )c  + (- 16A b  - 832B a b )c
+--R                    + 
+--R                           9 5
+--R                      48B b c
+--R                 *
+--R                    ROOT
+--R                                4 2 6       4   2       3   2        2 2 3  5
+--R                           - 81A a c  + (18A a b  + 792A B a b + 450A B a )c
+--R                         + 
+--R                                  4 4       3     3        2 2 2 2          3 3
+--R                               - A b  - 196A B a b  - 2904A B a b  - 2200A B a b
+--R                             + 
+--R                                     4 4
+--R                               - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5       2 2   4          3 2 3
+--R                                 12A B b  + 792A B a b  + 4788A B a b
+--R                               + 
+--R                                      4 3 2
+--R                                 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5        4 2 4  2
+--R                           (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                         + 
+--R                                  3 7       4   6        4 8
+--R                           (108A B b  + 918B a b )c - 81B b
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                       3 3         2   4  6
+--R                  (144A a b + 1440A B a )c
+--R                + 
+--R                        3 2 3        2   3 2          2 4         3 5  5
+--R                  (- 88A a b  - 2016A B a b  - 7440A B a b - 4000B a )c
+--R                + 
+--R                      3   5       2   2 4          2 3 3         3 4 2  4
+--R                  (17A a b  + 882A B a b  + 7608A B a b  + 11360B a b )c
+--R                + 
+--R                      3 7       2     6          2 2 5        3 3 4  3
+--R                  (- A b  - 153A B a b  - 2841A B a b  - 8818B a b )c
+--R                + 
+--R                     2   8         2   7        3 2 6  2
+--R                  (9A B b  + 459A B a b  + 2961B a b )c
+--R                + 
+--R                          2 9       3   8        3 10
+--R                  (- 27A B b  - 459B a b )c + 27B b
+--R             *
+--R                ROOT
+--R                               3 8       2 2 7         4 6      6 5
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                         ROOT
+--R                                     4 2 6
+--R                                - 81A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3  5
+--R                                (18A a b  + 792A B a b + 450A B a )c
+--R                              + 
+--R                                       4 4       3     3        2 2 2 2
+--R                                    - A b  - 196A B a b  - 2904A B a b
+--R                                  + 
+--R                                             3 3        4 4
+--R                                    - 2200A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                       3   5       2 2   4          3 2 3
+--R                                    12A B b  + 792A B a b  + 4788A B a b
+--R                                  + 
+--R                                         4 3 2
+--R                                    2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5        4 2 4  2
+--R                                (- 54A B b  - 1404A B a b  - 3051B a b )c
+--R                              + 
+--R                                       3 7       4   6        4 8
+--R                                (108A B b  + 918B a b )c - 81B b
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                           2 2            3  4
+--R                       (60A a b + 240A B a )c
+--R                     + 
+--R                             2   3           2 2       2 3   3
+--R                       (- 15A a b  - 300A B a b  - 420B a b)c
+--R                     + 
+--R                         2 5            4       2 2 3  2
+--R                       (A b  + 80A B a b  + 385B a b )c
+--R                     + 
+--R                                6       2   5       2 7
+--R                       (- 6A B b  - 105B a b )c + 9B b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                      4 3 5         4 2 2        3   3   4
+--R                  324A a c  + (- 81A a b  - 2268A B a b)c
+--R                + 
+--R                        4   4       3   2 3        2 2 3 2          3 4
+--R                      5A a b  + 647A B a b  + 5016A B a b  - 2500A B a b
+--R                    + 
+--R                             4 5
+--R                      - 2500B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3     5        2 2 2 4          3 3 3        4 4 2  2
+--R                  (- 45A B a b  - 1674A B a b  - 2727A B a b  + 5625B a b )c
+--R                + 
+--R                       2 2   6          3 2 5        4 3 4           3   7
+--R                  (135A B a b  + 1323A B a b  - 1971B a b )c - 135A B a b
+--R                + 
+--R                      4 2 6
+--R                  189B a b
+--R             *
+--R                x
+--R     + 
+--R                                                   +-----------+
+--R                    2       2                   3  |          2
+--R           (- 6A a c  + (A b  + 13B a b)c - 3B b )\|- 4a c + b
+--R         + 
+--R                          2  2         3          2         4
+--R           (8A a b + 20B a )c  + (- A b  - 19B a b )c + 3B b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                                   +-----------+
+--R                    2       2                   3  |          2
+--R           (- 6A a c  + (A b  + 13B a b)c - 3B b )\|- 4a c + b
+--R         + 
+--R                            2  2       3          2         4
+--R           (- 8A a b - 20B a )c  + (A b  + 19B a b )c - 3B b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                             +--------------------+
+--R                           +-----------+     |   +-----------+
+--R            3     2 2  +-+ |          2  +-+ |   |          2
+--R       (8a c  - 2b c )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2220
+
+--S 2221 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2221
+
+)clear all
+
+--S 2222 of 3139
+t0:=x^4*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            6      4
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2222
+
+--S 2223 of 3139
+r0:=-1/2*(b*B-2*A*c)*x/(c*(b^2-4*a*c))-1/2*x^3*(A*b-2*a*B-(b*B-2*A*c)*_
+   x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*(b^2*B+A*b*c-6*a*B*c+(-b^3*B-A*b^2*c+_
+   8*a*b*B*c-4*a*A*c^2)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*(b^2*B+A*b*c-6*a*B*c+(b^3*B+A*b^2*c-8*a*b*B*c+4*a*A*c^2)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                               2      2   4          2                 3  2
+--R               ((- A b + 6B a)c  - B b c)x  + ((- A b  + 6B a b)c - B b )x
+--R             + 
+--R                              2          2
+--R               (- A a b + 6B a )c - B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  3       2           2      3   4
+--R           (4A a c  + (A b  - 8B a b)c  + B b c)x
+--R         + 
+--R                    2       3         2        4  2       2 2
+--R           (4A a b c  + (A b  - 8B a b )c + B b )x  + 4A a c
+--R         + 
+--R                 2       2           3
+--R           (A a b  - 8B a b)c + B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                               2      2   4          2                 3  2
+--R               ((- A b + 6B a)c  - B b c)x  + ((- A b  + 6B a b)c - B b )x
+--R             + 
+--R                              2          2
+--R               (- A a b + 6B a )c - B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3         2           2      3   4
+--R           (- 4A a c  + (- A b  + 8B a b)c  - B b c)x
+--R         + 
+--R                      2         3         2        4  2       2 2
+--R           (- 4A a b c  + (- A b  + 8B a b )c - B b )x  - 4A a c
+--R         + 
+--R                   2       2           3
+--R           (- A a b  + 8B a b)c - B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                                +-----------+
+--R                                2  3                        +-+ |          2
+--R         (((- A b - 2B a)c + B b )x  + (- 2A a c + B a b)x)\|2 \|- 4a c + b
+--R      *
+--R              +--------------------+ +------------------+
+--R              |   +-----------+      | +-----------+
+--R          +-+ |   |          2       | |          2
+--R         \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R             3     2 2  4          2     3   2     2 2       2   +-+
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|2
+--R    *
+--R                          +--------------------+ +------------------+
+--R        +-----------+     |   +-----------+      | +-----------+
+--R        |          2  +-+ |   |          2       | |          2
+--R       \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2223
+
+--S 2224 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3    2 2  4          2    3   2     2 2      2
+--R         ((4a c  - b c )x  + (4a b c  - b c)x  + 4a c  - a b c)
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                  ROOT
+--R                            4 4        3         2 2   3
+--R                         - A c  + (- 4A B b + 18A B a)c
+--R                       + 
+--R                              2 2 2        3         4 2  2
+--R                         (- 6A B b  + 36A B a b - 81B a )c
+--R                       + 
+--R                                3 3      4   2      4 4
+--R                         (- 4A B b  + 18B a b )c - B b
+--R                    /
+--R                             3 9         2 2 8          4 7       6 6
+--R                       16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                    2             2  3     2 3            2      2 2   2
+--R                (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R              + 
+--R                       4      2   3      2 5
+--R                (2A B b  - 15B a b )c + B b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              3            4  7             2 3           3 2  6
+--R                      (4096A a b - 12288B a )c  + (- 3072A a b  + 10240B a b )c
+--R                    + 
+--R                               5          2 4  5           7           6  4
+--R                      (768A a b  - 3072B a b )c  + (- 64A b  + 384B a b )c
+--R                    + 
+--R                             8 3
+--R                      - 16B b c
+--R                 *
+--R                    ROOT
+--R                              4 4        3         2 2   3
+--R                           - A c  + (- 4A B b + 18A B a)c
+--R                         + 
+--R                                2 2 2        3         4 2  2
+--R                           (- 6A B b  + 36A B a b - 81B a )c
+--R                         + 
+--R                                  3 3      4   2      4 4
+--R                           (- 4A B b  + 18B a b )c - B b
+--R                      /
+--R                               3 9         2 2 8          4 7       6 6
+--R                         16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     3 2 5         3   2      2   2          2 3  4
+--R                  32A a c  + (- 16A a b  + 48A B a b - 288A B a )c
+--R                + 
+--R                     3 4      2     3         2 2 2       3 3   3
+--R                  (2A b  - 24A B a b  + 144A B a b  + 144B a b)c
+--R                + 
+--R                     2   5        2   4      3 2 3  2      3   5     3 7
+--R                  (3A B b  - 18A B a b  - 88B a b )c  + 17B a b c - B b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4        3         2 2   3
+--R                                - A c  + (- 4A B b + 18A B a)c
+--R                              + 
+--R                                     2 2 2        3         4 2  2
+--R                                (- 6A B b  + 36A B a b - 81B a )c
+--R                              + 
+--R                                       3 3      4   2      4 4
+--R                                (- 4A B b  + 18B a b )c - B b
+--R                           /
+--R                                    3 9         2 2 8          4 7       6 6
+--R                              16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                           2             2  3     2 3            2      2 2   2
+--R                       (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R                     + 
+--R                              4      2   3      2 5
+--R                       (2A B b  - 15B a b )c + B b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    4   4      4 2      3       3
+--R                  4A a c  + (3A b  - 20A B a b)c
+--R                + 
+--R                     3   3      2 2   2         3 2        4 3  2
+--R                  (9A B b  - 84A B a b  + 324A B a b - 324B a )c
+--R                + 
+--R                     2 2 4        3   3      4 2 2         3 5     4   4
+--R                  (9A B b  - 65A B a b  + 81B a b )c + 3A B b  - 5B a b
+--R             *
+--R                x
+--R     + 
+--R                 3    2 2  4            2    3   2     2 2      2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c)x  - 4a c  + a b c)
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                  ROOT
+--R                            4 4        3         2 2   3
+--R                         - A c  + (- 4A B b + 18A B a)c
+--R                       + 
+--R                              2 2 2        3         4 2  2
+--R                         (- 6A B b  + 36A B a b - 81B a )c
+--R                       + 
+--R                                3 3      4   2      4 4
+--R                         (- 4A B b  + 18B a b )c - B b
+--R                    /
+--R                             3 9         2 2 8          4 7       6 6
+--R                       16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                    2             2  3     2 3            2      2 2   2
+--R                (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R              + 
+--R                       4      2   3      2 5
+--R                (2A B b  - 15B a b )c + B b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              3            4  7             2 3           3 2  6
+--R                      (4096A a b - 12288B a )c  + (- 3072A a b  + 10240B a b )c
+--R                    + 
+--R                               5          2 4  5           7           6  4
+--R                      (768A a b  - 3072B a b )c  + (- 64A b  + 384B a b )c
+--R                    + 
+--R                             8 3
+--R                      - 16B b c
+--R                 *
+--R                    ROOT
+--R                              4 4        3         2 2   3
+--R                           - A c  + (- 4A B b + 18A B a)c
+--R                         + 
+--R                                2 2 2        3         4 2  2
+--R                           (- 6A B b  + 36A B a b - 81B a )c
+--R                         + 
+--R                                  3 3      4   2      4 4
+--R                           (- 4A B b  + 18B a b )c - B b
+--R                      /
+--R                               3 9         2 2 8          4 7       6 6
+--R                         16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       3 2 5       3   2      2   2          2 3  4
+--R                  - 32A a c  + (16A a b  - 48A B a b + 288A B a )c
+--R                + 
+--R                       3 4      2     3         2 2 2       3 3   3
+--R                  (- 2A b  + 24A B a b  - 144A B a b  - 144B a b)c
+--R                + 
+--R                       2   5        2   4      3 2 3  2      3   5     3 7
+--R                  (- 3A B b  + 18A B a b  + 88B a b )c  - 17B a b c + B b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4        3         2 2   3
+--R                                - A c  + (- 4A B b + 18A B a)c
+--R                              + 
+--R                                     2 2 2        3         4 2  2
+--R                                (- 6A B b  + 36A B a b - 81B a )c
+--R                              + 
+--R                                       3 3      4   2      4 4
+--R                                (- 4A B b  + 18B a b )c - B b
+--R                           /
+--R                                    3 9         2 2 8          4 7       6 6
+--R                              16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                           2             2  3     2 3            2      2 2   2
+--R                       (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R                     + 
+--R                              4      2   3      2 5
+--R                       (2A B b  - 15B a b )c + B b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    4   4      4 2      3       3
+--R                  4A a c  + (3A b  - 20A B a b)c
+--R                + 
+--R                     3   3      2 2   2         3 2        4 3  2
+--R                  (9A B b  - 84A B a b  + 324A B a b - 324B a )c
+--R                + 
+--R                     2 2 4        3   3      4 2 2         3 5     4   4
+--R                  (9A B b  - 65A B a b  + 81B a b )c + 3A B b  - 5B a b
+--R             *
+--R                x
+--R     + 
+--R               3    2 2  4          2    3   2     2 2      2
+--R         ((4a c  - b c )x  + (4a b c  - b c)x  + 4a c  - a b c)
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                  ROOT
+--R                            4 4        3         2 2   3
+--R                         - A c  + (- 4A B b + 18A B a)c
+--R                       + 
+--R                              2 2 2        3         4 2  2
+--R                         (- 6A B b  + 36A B a b - 81B a )c
+--R                       + 
+--R                                3 3      4   2      4 4
+--R                         (- 4A B b  + 18B a b )c - B b
+--R                    /
+--R                             3 9         2 2 8          4 7       6 6
+--R                       16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                    2             2  3     2 3            2      2 2   2
+--R                (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R              + 
+--R                       4      2   3      2 5
+--R                (2A B b  - 15B a b )c + B b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                3            4  7           2 3           3 2  6
+--R                      (- 4096A a b + 12288B a )c  + (3072A a b  - 10240B a b )c
+--R                    + 
+--R                                 5          2 4  5         7           6  4
+--R                      (- 768A a b  + 3072B a b )c  + (64A b  - 384B a b )c
+--R                    + 
+--R                           8 3
+--R                      16B b c
+--R                 *
+--R                    ROOT
+--R                              4 4        3         2 2   3
+--R                           - A c  + (- 4A B b + 18A B a)c
+--R                         + 
+--R                                2 2 2        3         4 2  2
+--R                           (- 6A B b  + 36A B a b - 81B a )c
+--R                         + 
+--R                                  3 3      4   2      4 4
+--R                           (- 4A B b  + 18B a b )c - B b
+--R                      /
+--R                               3 9         2 2 8          4 7       6 6
+--R                         16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     3 2 5         3   2      2   2          2 3  4
+--R                  32A a c  + (- 16A a b  + 48A B a b - 288A B a )c
+--R                + 
+--R                     3 4      2     3         2 2 2       3 3   3
+--R                  (2A b  - 24A B a b  + 144A B a b  + 144B a b)c
+--R                + 
+--R                     2   5        2   4      3 2 3  2      3   5     3 7
+--R                  (3A B b  - 18A B a b  - 88B a b )c  + 17B a b c - B b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4        3         2 2   3
+--R                                - A c  + (- 4A B b + 18A B a)c
+--R                              + 
+--R                                     2 2 2        3         4 2  2
+--R                                (- 6A B b  + 36A B a b - 81B a )c
+--R                              + 
+--R                                       3 3      4   2      4 4
+--R                                (- 4A B b  + 18B a b )c - B b
+--R                           /
+--R                                    3 9         2 2 8          4 7       6 6
+--R                              16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                           2             2  3     2 3            2      2 2   2
+--R                       (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R                     + 
+--R                              4      2   3      2 5
+--R                       (2A B b  - 15B a b )c + B b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    4   4      4 2      3       3
+--R                  4A a c  + (3A b  - 20A B a b)c
+--R                + 
+--R                     3   3      2 2   2         3 2        4 3  2
+--R                  (9A B b  - 84A B a b  + 324A B a b - 324B a )c
+--R                + 
+--R                     2 2 4        3   3      4 2 2         3 5     4   4
+--R                  (9A B b  - 65A B a b  + 81B a b )c + 3A B b  - 5B a b
+--R             *
+--R                x
+--R     + 
+--R                 3    2 2  4            2    3   2     2 2      2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c)x  - 4a c  + a b c)
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                  ROOT
+--R                            4 4        3         2 2   3
+--R                         - A c  + (- 4A B b + 18A B a)c
+--R                       + 
+--R                              2 2 2        3         4 2  2
+--R                         (- 6A B b  + 36A B a b - 81B a )c
+--R                       + 
+--R                                3 3      4   2      4 4
+--R                         (- 4A B b  + 18B a b )c - B b
+--R                    /
+--R                             3 9         2 2 8          4 7       6 6
+--R                       16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                    2             2  3     2 3            2      2 2   2
+--R                (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R              + 
+--R                       4      2   3      2 5
+--R                (2A B b  - 15B a b )c + B b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                3            4  7           2 3           3 2  6
+--R                      (- 4096A a b + 12288B a )c  + (3072A a b  - 10240B a b )c
+--R                    + 
+--R                                 5          2 4  5         7           6  4
+--R                      (- 768A a b  + 3072B a b )c  + (64A b  - 384B a b )c
+--R                    + 
+--R                           8 3
+--R                      16B b c
+--R                 *
+--R                    ROOT
+--R                              4 4        3         2 2   3
+--R                           - A c  + (- 4A B b + 18A B a)c
+--R                         + 
+--R                                2 2 2        3         4 2  2
+--R                           (- 6A B b  + 36A B a b - 81B a )c
+--R                         + 
+--R                                  3 3      4   2      4 4
+--R                           (- 4A B b  + 18B a b )c - B b
+--R                      /
+--R                               3 9         2 2 8          4 7       6 6
+--R                         16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       3 2 5       3   2      2   2          2 3  4
+--R                  - 32A a c  + (16A a b  - 48A B a b + 288A B a )c
+--R                + 
+--R                       3 4      2     3         2 2 2       3 3   3
+--R                  (- 2A b  + 24A B a b  - 144A B a b  - 144B a b)c
+--R                + 
+--R                       2   5        2   4      3 2 3  2      3   5     3 7
+--R                  (- 3A B b  + 18A B a b  + 88B a b )c  - 17B a b c + B b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4        3         2 2   3
+--R                                - A c  + (- 4A B b + 18A B a)c
+--R                              + 
+--R                                     2 2 2        3         4 2  2
+--R                                (- 6A B b  + 36A B a b - 81B a )c
+--R                              + 
+--R                                       3 3      4   2      4 4
+--R                                (- 4A B b  + 18B a b )c - B b
+--R                           /
+--R                                    3 9         2 2 8          4 7       6 6
+--R                              16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                           2             2  3     2 3            2      2 2   2
+--R                       (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R                     + 
+--R                              4      2   3      2 5
+--R                       (2A B b  - 15B a b )c + B b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    4   4      4 2      3       3
+--R                  4A a c  + (3A b  - 20A B a b)c
+--R                + 
+--R                     3   3      2 2   2         3 2        4 3  2
+--R                  (9A B b  - 84A B a b  + 324A B a b - 324B a )c
+--R                + 
+--R                     2 2 4        3   3      4 2 2         3 5     4   4
+--R                  (9A B b  - 65A B a b  + 81B a b )c + 3A B b  - 5B a b
+--R             *
+--R                x
+--R     + 
+--R                             2  3
+--R       ((- A b - 2B a)c + B b )x  + (- 2A a c + B a b)x
+--R  /
+--R          3     2 2  4          2     3   2     2 2       2
+--R     (8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2224
+
+--S 2225 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +--------------------+
+--R                           +-----------+     |   +-----------+
+--R              2    2   +-+ |          2  +-+ |   |          2
+--R         (4a c  - b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                  ROOT
+--R                            4 4        3         2 2   3
+--R                         - A c  + (- 4A B b + 18A B a)c
+--R                       + 
+--R                              2 2 2        3         4 2  2
+--R                         (- 6A B b  + 36A B a b - 81B a )c
+--R                       + 
+--R                                3 3      4   2      4 4
+--R                         (- 4A B b  + 18B a b )c - B b
+--R                    /
+--R                             3 9         2 2 8          4 7       6 6
+--R                       16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                    2             2  3     2 3            2      2 2   2
+--R                (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R              + 
+--R                       4      2   3      2 5
+--R                (2A B b  - 15B a b )c + B b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              3            4  7             2 3           3 2  6
+--R                      (4096A a b - 12288B a )c  + (- 3072A a b  + 10240B a b )c
+--R                    + 
+--R                               5          2 4  5           7           6  4
+--R                      (768A a b  - 3072B a b )c  + (- 64A b  + 384B a b )c
+--R                    + 
+--R                             8 3
+--R                      - 16B b c
+--R                 *
+--R                    ROOT
+--R                              4 4        3         2 2   3
+--R                           - A c  + (- 4A B b + 18A B a)c
+--R                         + 
+--R                                2 2 2        3         4 2  2
+--R                           (- 6A B b  + 36A B a b - 81B a )c
+--R                         + 
+--R                                  3 3      4   2      4 4
+--R                           (- 4A B b  + 18B a b )c - B b
+--R                      /
+--R                               3 9         2 2 8          4 7       6 6
+--R                         16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     3 2 5         3   2      2   2          2 3  4
+--R                  32A a c  + (- 16A a b  + 48A B a b - 288A B a )c
+--R                + 
+--R                     3 4      2     3         2 2 2       3 3   3
+--R                  (2A b  - 24A B a b  + 144A B a b  + 144B a b)c
+--R                + 
+--R                     2   5        2   4      3 2 3  2      3   5     3 7
+--R                  (3A B b  - 18A B a b  - 88B a b )c  + 17B a b c - B b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4        3         2 2   3
+--R                                - A c  + (- 4A B b + 18A B a)c
+--R                              + 
+--R                                     2 2 2        3         4 2  2
+--R                                (- 6A B b  + 36A B a b - 81B a )c
+--R                              + 
+--R                                       3 3      4   2      4 4
+--R                                (- 4A B b  + 18B a b )c - B b
+--R                           /
+--R                                    3 9         2 2 8          4 7       6 6
+--R                              16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                           2             2  3     2 3            2      2 2   2
+--R                       (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R                     + 
+--R                              4      2   3      2 5
+--R                       (2A B b  - 15B a b )c + B b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    4   4      4 2      3       3
+--R                  4A a c  + (3A b  - 20A B a b)c
+--R                + 
+--R                     3   3      2 2   2         3 2        4 3  2
+--R                  (9A B b  - 84A B a b  + 324A B a b - 324B a )c
+--R                + 
+--R                     2 2 4        3   3      4 2 2         3 5     4   4
+--R                  (9A B b  - 65A B a b  + 81B a b )c + 3A B b  - 5B a b
+--R             *
+--R                x
+--R     + 
+--R                             +-----------+
+--R                2    2   +-+ |          2  +-+
+--R         (- 4a c  + b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                  ROOT
+--R                            4 4        3         2 2   3
+--R                         - A c  + (- 4A B b + 18A B a)c
+--R                       + 
+--R                              2 2 2        3         4 2  2
+--R                         (- 6A B b  + 36A B a b - 81B a )c
+--R                       + 
+--R                                3 3      4   2      4 4
+--R                         (- 4A B b  + 18B a b )c - B b
+--R                    /
+--R                             3 9         2 2 8          4 7       6 6
+--R                       16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                    2             2  3     2 3            2      2 2   2
+--R                (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R              + 
+--R                       4      2   3      2 5
+--R                (2A B b  - 15B a b )c + B b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              3            4  7             2 3           3 2  6
+--R                      (4096A a b - 12288B a )c  + (- 3072A a b  + 10240B a b )c
+--R                    + 
+--R                               5          2 4  5           7           6  4
+--R                      (768A a b  - 3072B a b )c  + (- 64A b  + 384B a b )c
+--R                    + 
+--R                             8 3
+--R                      - 16B b c
+--R                 *
+--R                    ROOT
+--R                              4 4        3         2 2   3
+--R                           - A c  + (- 4A B b + 18A B a)c
+--R                         + 
+--R                                2 2 2        3         4 2  2
+--R                           (- 6A B b  + 36A B a b - 81B a )c
+--R                         + 
+--R                                  3 3      4   2      4 4
+--R                           (- 4A B b  + 18B a b )c - B b
+--R                      /
+--R                               3 9         2 2 8          4 7       6 6
+--R                         16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       3 2 5       3   2      2   2          2 3  4
+--R                  - 32A a c  + (16A a b  - 48A B a b + 288A B a )c
+--R                + 
+--R                       3 4      2     3         2 2 2       3 3   3
+--R                  (- 2A b  + 24A B a b  - 144A B a b  - 144B a b)c
+--R                + 
+--R                       2   5        2   4      3 2 3  2      3   5     3 7
+--R                  (- 3A B b  + 18A B a b  + 88B a b )c  - 17B a b c + B b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4        3         2 2   3
+--R                                - A c  + (- 4A B b + 18A B a)c
+--R                              + 
+--R                                     2 2 2        3         4 2  2
+--R                                (- 6A B b  + 36A B a b - 81B a )c
+--R                              + 
+--R                                       3 3      4   2      4 4
+--R                                (- 4A B b  + 18B a b )c - B b
+--R                           /
+--R                                    3 9         2 2 8          4 7       6 6
+--R                              16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                           2             2  3     2 3            2      2 2   2
+--R                       (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R                     + 
+--R                              4      2   3      2 5
+--R                       (2A B b  - 15B a b )c + B b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    4   4      4 2      3       3
+--R                  4A a c  + (3A b  - 20A B a b)c
+--R                + 
+--R                     3   3      2 2   2         3 2        4 3  2
+--R                  (9A B b  - 84A B a b  + 324A B a b - 324B a )c
+--R                + 
+--R                     2 2 4        3   3      4 2 2         3 5     4   4
+--R                  (9A B b  - 65A B a b  + 81B a b )c + 3A B b  - 5B a b
+--R             *
+--R                x
+--R     + 
+--R                           +-----------+
+--R              2    2   +-+ |          2  +-+
+--R         (4a c  - b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                  ROOT
+--R                            4 4        3         2 2   3
+--R                         - A c  + (- 4A B b + 18A B a)c
+--R                       + 
+--R                              2 2 2        3         4 2  2
+--R                         (- 6A B b  + 36A B a b - 81B a )c
+--R                       + 
+--R                                3 3      4   2      4 4
+--R                         (- 4A B b  + 18B a b )c - B b
+--R                    /
+--R                             3 9         2 2 8          4 7       6 6
+--R                       16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                    2             2  3     2 3            2      2 2   2
+--R                (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R              + 
+--R                       4      2   3      2 5
+--R                (2A B b  - 15B a b )c + B b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                3            4  7           2 3           3 2  6
+--R                      (- 4096A a b + 12288B a )c  + (3072A a b  - 10240B a b )c
+--R                    + 
+--R                                 5          2 4  5         7           6  4
+--R                      (- 768A a b  + 3072B a b )c  + (64A b  - 384B a b )c
+--R                    + 
+--R                           8 3
+--R                      16B b c
+--R                 *
+--R                    ROOT
+--R                              4 4        3         2 2   3
+--R                           - A c  + (- 4A B b + 18A B a)c
+--R                         + 
+--R                                2 2 2        3         4 2  2
+--R                           (- 6A B b  + 36A B a b - 81B a )c
+--R                         + 
+--R                                  3 3      4   2      4 4
+--R                           (- 4A B b  + 18B a b )c - B b
+--R                      /
+--R                               3 9         2 2 8          4 7       6 6
+--R                         16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     3 2 5         3   2      2   2          2 3  4
+--R                  32A a c  + (- 16A a b  + 48A B a b - 288A B a )c
+--R                + 
+--R                     3 4      2     3         2 2 2       3 3   3
+--R                  (2A b  - 24A B a b  + 144A B a b  + 144B a b)c
+--R                + 
+--R                     2   5        2   4      3 2 3  2      3   5     3 7
+--R                  (3A B b  - 18A B a b  - 88B a b )c  + 17B a b c - B b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4        3         2 2   3
+--R                                - A c  + (- 4A B b + 18A B a)c
+--R                              + 
+--R                                     2 2 2        3         4 2  2
+--R                                (- 6A B b  + 36A B a b - 81B a )c
+--R                              + 
+--R                                       3 3      4   2      4 4
+--R                                (- 4A B b  + 18B a b )c - B b
+--R                           /
+--R                                    3 9         2 2 8          4 7       6 6
+--R                              16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                           2             2  3     2 3            2      2 2   2
+--R                       (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R                     + 
+--R                              4      2   3      2 5
+--R                       (2A B b  - 15B a b )c + B b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    4   4      4 2      3       3
+--R                  4A a c  + (3A b  - 20A B a b)c
+--R                + 
+--R                     3   3      2 2   2         3 2        4 3  2
+--R                  (9A B b  - 84A B a b  + 324A B a b - 324B a )c
+--R                + 
+--R                     2 2 4        3   3      4 2 2         3 5     4   4
+--R                  (9A B b  - 65A B a b  + 81B a b )c + 3A B b  - 5B a b
+--R             *
+--R                x
+--R     + 
+--R                                               +--------------------+
+--R                             +-----------+     |   +-----------+
+--R                2    2   +-+ |          2  +-+ |   |          2
+--R         (- 4a c  + b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                  ROOT
+--R                            4 4        3         2 2   3
+--R                         - A c  + (- 4A B b + 18A B a)c
+--R                       + 
+--R                              2 2 2        3         4 2  2
+--R                         (- 6A B b  + 36A B a b - 81B a )c
+--R                       + 
+--R                                3 3      4   2      4 4
+--R                         (- 4A B b  + 18B a b )c - B b
+--R                    /
+--R                             3 9         2 2 8          4 7       6 6
+--R                       16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                    2             2  3     2 3            2      2 2   2
+--R                (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R              + 
+--R                       4      2   3      2 5
+--R                (2A B b  - 15B a b )c + B b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                3            4  7           2 3           3 2  6
+--R                      (- 4096A a b + 12288B a )c  + (3072A a b  - 10240B a b )c
+--R                    + 
+--R                                 5          2 4  5         7           6  4
+--R                      (- 768A a b  + 3072B a b )c  + (64A b  - 384B a b )c
+--R                    + 
+--R                           8 3
+--R                      16B b c
+--R                 *
+--R                    ROOT
+--R                              4 4        3         2 2   3
+--R                           - A c  + (- 4A B b + 18A B a)c
+--R                         + 
+--R                                2 2 2        3         4 2  2
+--R                           (- 6A B b  + 36A B a b - 81B a )c
+--R                         + 
+--R                                  3 3      4   2      4 4
+--R                           (- 4A B b  + 18B a b )c - B b
+--R                      /
+--R                               3 9         2 2 8          4 7       6 6
+--R                         16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       3 2 5       3   2      2   2          2 3  4
+--R                  - 32A a c  + (16A a b  - 48A B a b + 288A B a )c
+--R                + 
+--R                       3 4      2     3         2 2 2       3 3   3
+--R                  (- 2A b  + 24A B a b  - 144A B a b  - 144B a b)c
+--R                + 
+--R                       2   5        2   4      3 2 3  2      3   5     3 7
+--R                  (- 3A B b  + 18A B a b  + 88B a b )c  - 17B a b c + B b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                         ROOT
+--R                                   4 4        3         2 2   3
+--R                                - A c  + (- 4A B b + 18A B a)c
+--R                              + 
+--R                                     2 2 2        3         4 2  2
+--R                                (- 6A B b  + 36A B a b - 81B a )c
+--R                              + 
+--R                                       3 3      4   2      4 4
+--R                                (- 4A B b  + 18B a b )c - B b
+--R                           /
+--R                                    3 9         2 2 8          4 7       6 6
+--R                              16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                           2             2  3     2 3            2      2 2   2
+--R                       (12A a b - 48A B a )c  + (A b  - 12A B a b  + 60B a b)c
+--R                     + 
+--R                              4      2   3      2 5
+--R                       (2A B b  - 15B a b )c + B b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    4   4      4 2      3       3
+--R                  4A a c  + (3A b  - 20A B a b)c
+--R                + 
+--R                     3   3      2 2   2         3 2        4 3  2
+--R                  (9A B b  - 84A B a b  + 324A B a b - 324B a )c
+--R                + 
+--R                     2 2 4        3   3      4 2 2         3 5     4   4
+--R                  (9A B b  - 65A B a b  + 81B a b )c + 3A B b  - 5B a b
+--R             *
+--R                x
+--R     + 
+--R                                  +-----------+
+--R                               2  |          2          2         2
+--R           ((A b - 6B a)c + B b )\|- 4a c + b   - 4A a c  + (- A b  + 8B a b)c
+--R         + 
+--R                3
+--R           - B b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                  +-----------+
+--R                               2  |          2          2       2
+--R           ((A b - 6B a)c + B b )\|- 4a c + b   + 4A a c  + (A b  - 8B a b)c
+--R         + 
+--R              3
+--R           B b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                            +--------------------+
+--R                          +-----------+     |   +-----------+
+--R            2     2   +-+ |          2  +-+ |   |          2
+--R       (8a c  - 2b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2225
+
+--S 2226 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2226
+
+)clear all
+
+--S 2227 of 3139
+t0:=x^2*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            4      2
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2227
+
+--S 2228 of 3139
+r0:=-1/2*x*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b*B-2*A*c+_
+   (-b^2*B+4*A*b*c-4*a*B*c)/sqrt(b^2-4*a*c))/((b^2-4*a*c)*sqrt(2)*_
+   sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*(b*B-2*A*c+(b^2*B-4*A*b*c+4*a*B*c)/_
+   sqrt(b^2-4*a*c))/((b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                   2          4                2  2
+--R             ((2A c  - B b c)x  + (2A b c - B b )x  + 2A a c - B a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                            2      2   4           2                 3  2
+--R           ((- 4A b + 4B a)c  + B b c)x  + ((- 4A b  + 4B a b)c + B b )x
+--R         + 
+--R                           2          2
+--R           (- 4A a b + 4B a )c + B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                   2          4                2  2
+--R             ((2A c  - B b c)x  + (2A b c - B b )x  + 2A a c - B a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                          2      2   4         2                 3  2
+--R           ((4A b - 4B a)c  - B b c)x  + ((4A b  - 4B a b)c - B b )x
+--R         + 
+--R                         2          2
+--R           (4A a b - 4B a )c - B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                              +-----------+
+--R                       3                  +-+ |          2  +-+
+--R         ((2A c - B b)x  + (A b - 2B a)x)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                                +-----------+
+--R             2     2   4               3  2     2        2  +-+ |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2 \|- 4a c + b
+--R    *
+--R            +--------------------+ +------------------+
+--R            |   +-----------+      | +-----------+
+--R        +-+ |   |          2       | |          2
+--R       \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2228
+
+--S 2229 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                        4 4       3 2 3       2 4 2        6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16a b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |               4 2     2 2       4 2
+--R                   |            - A c  + 2A B a c - B a
+--R                   |------------------------------------------------
+--R                   |      5 5         4 2 4        3 4 3       2 6 2
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R              + 
+--R                  2             2  2     2 3            2      2 2       2   3
+--R              (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c + B a b
+--R           /
+--R                  4 4       3 2 3      2 4 2       6
+--R              512a c  - 384a b c  + 96a b c  - 8a b c
+--R      *
+--R         log
+--R                             5 5             4 2          5   4          4 3 3
+--R                      4096A a c  + (- 2048A a b  - 4096B a b)c  + 3072B a b c
+--R                    + 
+--R                             2 6         3 5  2             8        2 7
+--R                      (128A a b  - 768B a b )c  + (- 16A a b  + 64B a b )c
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |               4 2     2 2       4 2
+--R                     |            - A c  + 2A B a c - B a
+--R                     |------------------------------------------------
+--R                     |      5 5         4 2 4        3 4 3       2 6 2
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                + 
+--R                        3 2       2   3  3
+--R                  (- 16A a b + 32A B a )c
+--R                + 
+--R                     3   3      2   2 2        2 3       3 4  2
+--R                  (8A a b  - 16A B a b  + 16A B a b - 32B a )c
+--R                + 
+--R                      3 5     2     4       2 2 3      3 3 2        2   5
+--R                  (- A b  + 2A B a b  - 8A B a b  + 16B a b )c + A B a b
+--R                + 
+--R                      3 2 4
+--R                  - 2B a b
+--R             *
+--R                ROOT
+--R                               4 4       3 2 3       2 4 2        6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16a b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |               4 2     2 2       4 2
+--R                          |            - A c  + 2A B a c - B a
+--R                          |------------------------------------------------
+--R                          |      5 5         4 2 4        3 4 3       2 6 2
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                     + 
+--R                           2             2  2     2 3            2      2 2
+--R                       (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c
+--R                     + 
+--R                        2   3
+--R                       B a b
+--R                  /
+--R                         4 4       3 2 3      2 4 2       6
+--R                     512a c  - 384a b c  + 96a b c  - 8a b c
+--R            + 
+--R                    4   3      4 2      3       2
+--R                  4A a c  + (3A b  - 12A B a b)c
+--R                + 
+--R                      3   3        3 2      4 3        3   3     4 2 2
+--R                  (- A B b  + 12A B a b - 4B a )c + A B a b  - 3B a b
+--R             *
+--R                x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                          4 4       3 2 3       2 4 2        6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16a b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |               4 2     2 2       4 2
+--R                   |            - A c  + 2A B a c - B a
+--R                   |------------------------------------------------
+--R                   |      5 5         4 2 4        3 4 3       2 6 2
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R              + 
+--R                  2             2  2     2 3            2      2 2       2   3
+--R              (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c + B a b
+--R           /
+--R                  4 4       3 2 3      2 4 2       6
+--R              512a c  - 384a b c  + 96a b c  - 8a b c
+--R      *
+--R         log
+--R                             5 5             4 2          5   4          4 3 3
+--R                      4096A a c  + (- 2048A a b  - 4096B a b)c  + 3072B a b c
+--R                    + 
+--R                             2 6         3 5  2             8        2 7
+--R                      (128A a b  - 768B a b )c  + (- 16A a b  + 64B a b )c
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |               4 2     2 2       4 2
+--R                     |            - A c  + 2A B a c - B a
+--R                     |------------------------------------------------
+--R                     |      5 5         4 2 4        3 4 3       2 6 2
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                + 
+--R                      3 2       2   3  3
+--R                  (16A a b - 32A B a )c
+--R                + 
+--R                       3   3      2   2 2        2 3       3 4  2
+--R                  (- 8A a b  + 16A B a b  - 16A B a b + 32B a )c
+--R                + 
+--R                  3 5     2     4       2 2 3      3 3 2        2   5     3 2 4
+--R                (A b  - 2A B a b  + 8A B a b  - 16B a b )c - A B a b  + 2B a b
+--R             *
+--R                ROOT
+--R                                 4 4       3 2 3       2 4 2        6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16a b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |               4 2     2 2       4 2
+--R                          |            - A c  + 2A B a c - B a
+--R                          |------------------------------------------------
+--R                          |      5 5         4 2 4        3 4 3       2 6 2
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                     + 
+--R                           2             2  2     2 3            2      2 2
+--R                       (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c
+--R                     + 
+--R                        2   3
+--R                       B a b
+--R                  /
+--R                         4 4       3 2 3      2 4 2       6
+--R                     512a c  - 384a b c  + 96a b c  - 8a b c
+--R            + 
+--R                    4   3      4 2      3       2
+--R                  4A a c  + (3A b  - 12A B a b)c
+--R                + 
+--R                      3   3        3 2      4 3        3   3     4 2 2
+--R                  (- A B b  + 12A B a b - 4B a )c + A B a b  - 3B a b
+--R             *
+--R                x
+--R     + 
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                          4 4       3 2 3       2 4 2        6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16a b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |               4 2     2 2       4 2
+--R                   |            - A c  + 2A B a c - B a
+--R                   |------------------------------------------------
+--R                   |      5 5         4 2 4        3 4 3       2 6 2
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R              + 
+--R                  2             2  2     2 3            2      2 2       2   3
+--R              (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c + B a b
+--R           /
+--R                  4 4       3 2 3      2 4 2       6
+--R              512a c  - 384a b c  + 96a b c  - 8a b c
+--R      *
+--R         log
+--R                               5 5           4 2          5   4          4 3 3
+--R                      - 4096A a c  + (2048A a b  + 4096B a b)c  - 3072B a b c
+--R                    + 
+--R                               2 6         3 5  2           8        2 7
+--R                      (- 128A a b  + 768B a b )c  + (16A a b  - 64B a b )c
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |               4 2     2 2       4 2
+--R                     |            - A c  + 2A B a c - B a
+--R                     |------------------------------------------------
+--R                     |      5 5         4 2 4        3 4 3       2 6 2
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                + 
+--R                        3 2       2   3  3
+--R                  (- 16A a b + 32A B a )c
+--R                + 
+--R                     3   3      2   2 2        2 3       3 4  2
+--R                  (8A a b  - 16A B a b  + 16A B a b - 32B a )c
+--R                + 
+--R                      3 5     2     4       2 2 3      3 3 2        2   5
+--R                  (- A b  + 2A B a b  - 8A B a b  + 16B a b )c + A B a b
+--R                + 
+--R                      3 2 4
+--R                  - 2B a b
+--R             *
+--R                ROOT
+--R                                 4 4       3 2 3       2 4 2        6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16a b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |               4 2     2 2       4 2
+--R                          |            - A c  + 2A B a c - B a
+--R                          |------------------------------------------------
+--R                          |      5 5         4 2 4        3 4 3       2 6 2
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                     + 
+--R                           2             2  2     2 3            2      2 2
+--R                       (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c
+--R                     + 
+--R                        2   3
+--R                       B a b
+--R                  /
+--R                         4 4       3 2 3      2 4 2       6
+--R                     512a c  - 384a b c  + 96a b c  - 8a b c
+--R            + 
+--R                    4   3      4 2      3       2
+--R                  4A a c  + (3A b  - 12A B a b)c
+--R                + 
+--R                      3   3        3 2      4 3        3   3     4 2 2
+--R                  (- A B b  + 12A B a b - 4B a )c + A B a b  - 3B a b
+--R             *
+--R                x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                        4 4       3 2 3       2 4 2        6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16a b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |               4 2     2 2       4 2
+--R                   |            - A c  + 2A B a c - B a
+--R                   |------------------------------------------------
+--R                   |      5 5         4 2 4        3 4 3       2 6 2
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R              + 
+--R                  2             2  2     2 3            2      2 2       2   3
+--R              (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c + B a b
+--R           /
+--R                  4 4       3 2 3      2 4 2       6
+--R              512a c  - 384a b c  + 96a b c  - 8a b c
+--R      *
+--R         log
+--R                               5 5           4 2          5   4          4 3 3
+--R                      - 4096A a c  + (2048A a b  + 4096B a b)c  - 3072B a b c
+--R                    + 
+--R                               2 6         3 5  2           8        2 7
+--R                      (- 128A a b  + 768B a b )c  + (16A a b  - 64B a b )c
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |               4 2     2 2       4 2
+--R                     |            - A c  + 2A B a c - B a
+--R                     |------------------------------------------------
+--R                     |      5 5         4 2 4        3 4 3       2 6 2
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                + 
+--R                      3 2       2   3  3
+--R                  (16A a b - 32A B a )c
+--R                + 
+--R                       3   3      2   2 2        2 3       3 4  2
+--R                  (- 8A a b  + 16A B a b  - 16A B a b + 32B a )c
+--R                + 
+--R                  3 5     2     4       2 2 3      3 3 2        2   5     3 2 4
+--R                (A b  - 2A B a b  + 8A B a b  - 16B a b )c - A B a b  + 2B a b
+--R             *
+--R                ROOT
+--R                               4 4       3 2 3       2 4 2        6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16a b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |               4 2     2 2       4 2
+--R                          |            - A c  + 2A B a c - B a
+--R                          |------------------------------------------------
+--R                          |      5 5         4 2 4        3 4 3       2 6 2
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                     + 
+--R                           2             2  2     2 3            2      2 2
+--R                       (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c
+--R                     + 
+--R                        2   3
+--R                       B a b
+--R                  /
+--R                         4 4       3 2 3      2 4 2       6
+--R                     512a c  - 384a b c  + 96a b c  - 8a b c
+--R            + 
+--R                    4   3      4 2      3       2
+--R                  4A a c  + (3A b  - 12A B a b)c
+--R                + 
+--R                      3   3        3 2      4 3        3   3     4 2 2
+--R                  (- A B b  + 12A B a b - 4B a )c + A B a b  - 3B a b
+--R             *
+--R                x
+--R     + 
+--R                    3
+--R       (2A c - B b)x  + (A b - 2B a)x
+--R  /
+--R          2     2   4               3  2     2        2
+--R     (8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2229
+
+--S 2230 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +--------------------+
+--R                         +-----------+     |   +-----------+
+--R                  2  +-+ |          2  +-+ |   |          2
+--R         (4a c - b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4 4       3 2 3       2 4 2        6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16a b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |               4 2     2 2       4 2
+--R                   |            - A c  + 2A B a c - B a
+--R                   |------------------------------------------------
+--R                   |      5 5         4 2 4        3 4 3       2 6 2
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R              + 
+--R                  2             2  2     2 3            2      2 2       2   3
+--R              (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c + B a b
+--R           /
+--R                  4 4       3 2 3      2 4 2       6
+--R              512a c  - 384a b c  + 96a b c  - 8a b c
+--R      *
+--R         log
+--R                             5 5             4 2          5   4          4 3 3
+--R                      4096A a c  + (- 2048A a b  - 4096B a b)c  + 3072B a b c
+--R                    + 
+--R                             2 6         3 5  2             8        2 7
+--R                      (128A a b  - 768B a b )c  + (- 16A a b  + 64B a b )c
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |               4 2     2 2       4 2
+--R                     |            - A c  + 2A B a c - B a
+--R                     |------------------------------------------------
+--R                     |      5 5         4 2 4        3 4 3       2 6 2
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                + 
+--R                        3 2       2   3  3
+--R                  (- 16A a b + 32A B a )c
+--R                + 
+--R                     3   3      2   2 2        2 3       3 4  2
+--R                  (8A a b  - 16A B a b  + 16A B a b - 32B a )c
+--R                + 
+--R                      3 5     2     4       2 2 3      3 3 2        2   5
+--R                  (- A b  + 2A B a b  - 8A B a b  + 16B a b )c + A B a b
+--R                + 
+--R                      3 2 4
+--R                  - 2B a b
+--R             *
+--R                ROOT
+--R                               4 4       3 2 3       2 4 2        6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16a b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |               4 2     2 2       4 2
+--R                          |            - A c  + 2A B a c - B a
+--R                          |------------------------------------------------
+--R                          |      5 5         4 2 4        3 4 3       2 6 2
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                     + 
+--R                           2             2  2     2 3            2      2 2
+--R                       (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c
+--R                     + 
+--R                        2   3
+--R                       B a b
+--R                  /
+--R                         4 4       3 2 3      2 4 2       6
+--R                     512a c  - 384a b c  + 96a b c  - 8a b c
+--R            + 
+--R                    4   3      4 2      3       2
+--R                  4A a c  + (3A b  - 12A B a b)c
+--R                + 
+--R                      3   3        3 2      4 3        3   3     4 2 2
+--R                  (- A B b  + 12A B a b - 4B a )c + A B a b  - 3B a b
+--R             *
+--R                x
+--R     + 
+--R                           +-----------+
+--R                    2  +-+ |          2  +-+
+--R         (- 4a c + b )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          4 4       3 2 3       2 4 2        6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16a b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |               4 2     2 2       4 2
+--R                   |            - A c  + 2A B a c - B a
+--R                   |------------------------------------------------
+--R                   |      5 5         4 2 4        3 4 3       2 6 2
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R              + 
+--R                  2             2  2     2 3            2      2 2       2   3
+--R              (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c + B a b
+--R           /
+--R                  4 4       3 2 3      2 4 2       6
+--R              512a c  - 384a b c  + 96a b c  - 8a b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                             5 5             4 2          5   4          4 3 3
+--R                      4096A a c  + (- 2048A a b  - 4096B a b)c  + 3072B a b c
+--R                    + 
+--R                             2 6         3 5  2             8        2 7
+--R                      (128A a b  - 768B a b )c  + (- 16A a b  + 64B a b )c
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |               4 2     2 2       4 2
+--R                     |            - A c  + 2A B a c - B a
+--R                     |------------------------------------------------
+--R                     |      5 5         4 2 4        3 4 3       2 6 2
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                + 
+--R                      3 2       2   3  3
+--R                  (16A a b - 32A B a )c
+--R                + 
+--R                       3   3      2   2 2        2 3       3 4  2
+--R                  (- 8A a b  + 16A B a b  - 16A B a b + 32B a )c
+--R                + 
+--R                  3 5     2     4       2 2 3      3 3 2        2   5     3 2 4
+--R                (A b  - 2A B a b  + 8A B a b  - 16B a b )c - A B a b  + 2B a b
+--R             *
+--R                ROOT
+--R                                 4 4       3 2 3       2 4 2        6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16a b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |               4 2     2 2       4 2
+--R                          |            - A c  + 2A B a c - B a
+--R                          |------------------------------------------------
+--R                          |      5 5         4 2 4        3 4 3       2 6 2
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                     + 
+--R                           2             2  2     2 3            2      2 2
+--R                       (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c
+--R                     + 
+--R                        2   3
+--R                       B a b
+--R                  /
+--R                         4 4       3 2 3      2 4 2       6
+--R                     512a c  - 384a b c  + 96a b c  - 8a b c
+--R            + 
+--R                    4   3      4 2      3       2
+--R                  4A a c  + (3A b  - 12A B a b)c
+--R                + 
+--R                      3   3        3 2      4 3        3   3     4 2 2
+--R                  (- A B b  + 12A B a b - 4B a )c + A B a b  - 3B a b
+--R             *
+--R                x
+--R     + 
+--R                         +-----------+
+--R                  2  +-+ |          2  +-+
+--R         (4a c - b )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          4 4       3 2 3       2 4 2        6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16a b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |               4 2     2 2       4 2
+--R                   |            - A c  + 2A B a c - B a
+--R                   |------------------------------------------------
+--R                   |      5 5         4 2 4        3 4 3       2 6 2
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R              + 
+--R                  2             2  2     2 3            2      2 2       2   3
+--R              (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c + B a b
+--R           /
+--R                  4 4       3 2 3      2 4 2       6
+--R              512a c  - 384a b c  + 96a b c  - 8a b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               5 5           4 2          5   4          4 3 3
+--R                      - 4096A a c  + (2048A a b  + 4096B a b)c  - 3072B a b c
+--R                    + 
+--R                               2 6         3 5  2           8        2 7
+--R                      (- 128A a b  + 768B a b )c  + (16A a b  - 64B a b )c
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |               4 2     2 2       4 2
+--R                     |            - A c  + 2A B a c - B a
+--R                     |------------------------------------------------
+--R                     |      5 5         4 2 4        3 4 3       2 6 2
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                + 
+--R                        3 2       2   3  3
+--R                  (- 16A a b + 32A B a )c
+--R                + 
+--R                     3   3      2   2 2        2 3       3 4  2
+--R                  (8A a b  - 16A B a b  + 16A B a b - 32B a )c
+--R                + 
+--R                      3 5     2     4       2 2 3      3 3 2        2   5
+--R                  (- A b  + 2A B a b  - 8A B a b  + 16B a b )c + A B a b
+--R                + 
+--R                      3 2 4
+--R                  - 2B a b
+--R             *
+--R                ROOT
+--R                                 4 4       3 2 3       2 4 2        6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16a b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |               4 2     2 2       4 2
+--R                          |            - A c  + 2A B a c - B a
+--R                          |------------------------------------------------
+--R                          |      5 5         4 2 4        3 4 3       2 6 2
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                     + 
+--R                           2             2  2     2 3            2      2 2
+--R                       (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c
+--R                     + 
+--R                        2   3
+--R                       B a b
+--R                  /
+--R                         4 4       3 2 3      2 4 2       6
+--R                     512a c  - 384a b c  + 96a b c  - 8a b c
+--R            + 
+--R                    4   3      4 2      3       2
+--R                  4A a c  + (3A b  - 12A B a b)c
+--R                + 
+--R                      3   3        3 2      4 3        3   3     4 2 2
+--R                  (- A B b  + 12A B a b - 4B a )c + A B a b  - 3B a b
+--R             *
+--R                x
+--R     + 
+--R                                             +--------------------+
+--R                           +-----------+     |   +-----------+
+--R                    2  +-+ |          2  +-+ |   |          2
+--R         (- 4a c + b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4 4       3 2 3       2 4 2        6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16a b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |               4 2     2 2       4 2
+--R                   |            - A c  + 2A B a c - B a
+--R                   |------------------------------------------------
+--R                   |      5 5         4 2 4        3 4 3       2 6 2
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R              + 
+--R                  2             2  2     2 3            2      2 2       2   3
+--R              (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c + B a b
+--R           /
+--R                  4 4       3 2 3      2 4 2       6
+--R              512a c  - 384a b c  + 96a b c  - 8a b c
+--R      *
+--R         log
+--R                               5 5           4 2          5   4          4 3 3
+--R                      - 4096A a c  + (2048A a b  + 4096B a b)c  - 3072B a b c
+--R                    + 
+--R                               2 6         3 5  2           8        2 7
+--R                      (- 128A a b  + 768B a b )c  + (16A a b  - 64B a b )c
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |               4 2     2 2       4 2
+--R                     |            - A c  + 2A B a c - B a
+--R                     |------------------------------------------------
+--R                     |      5 5         4 2 4        3 4 3       2 6 2
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                + 
+--R                      3 2       2   3  3
+--R                  (16A a b - 32A B a )c
+--R                + 
+--R                       3   3      2   2 2        2 3       3 4  2
+--R                  (- 8A a b  + 16A B a b  - 16A B a b + 32B a )c
+--R                + 
+--R                  3 5     2     4       2 2 3      3 3 2        2   5     3 2 4
+--R                (A b  - 2A B a b  + 8A B a b  - 16B a b )c - A B a b  + 2B a b
+--R             *
+--R                ROOT
+--R                               4 4       3 2 3       2 4 2        6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16a b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |               4 2     2 2       4 2
+--R                          |            - A c  + 2A B a c - B a
+--R                          |------------------------------------------------
+--R                          |      5 5         4 2 4        3 4 3       2 6 2
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256a b c
+--R                     + 
+--R                           2             2  2     2 3            2      2 2
+--R                       (12A a b - 16A B a )c  + (A b  - 12A B a b  + 12B a b)c
+--R                     + 
+--R                        2   3
+--R                       B a b
+--R                  /
+--R                         4 4       3 2 3      2 4 2       6
+--R                     512a c  - 384a b c  + 96a b c  - 8a b c
+--R            + 
+--R                    4   3      4 2      3       2
+--R                  4A a c  + (3A b  - 12A B a b)c
+--R                + 
+--R                      3   3        3 2      4 3        3   3     4 2 2
+--R                  (- A B b  + 12A B a b - 4B a )c + A B a b  - 3B a b
+--R             *
+--R                x
+--R     + 
+--R                         +-----------+
+--R                         |          2                        2
+--R         ((- 2A c + B b)\|- 4a c + b   + (4A b - 4B a)c - B b )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                         +-----------+
+--R                         |          2                          2
+--R         ((- 2A c + B b)\|- 4a c + b   + (- 4A b + 4B a)c + B b )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                          +--------------------+
+--R                        +-----------+     |   +-----------+
+--R                 2  +-+ |          2  +-+ |   |          2
+--R       (8a c - 2b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2230
+
+--S 2231 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2231
+
+)clear all
+
+--S 2232 of 3139
+t0:=(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                              2
+--R                           B x  + A
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2232
+
+--S 2233 of 3139
+r0:=-1/2*x*(a*b*B-A*(b^2-2*a*c)-(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(A*b-2*a*B+(4*a*b*B+A*(b^2-12*a*c))/sqrt(b^2-4*a*c))/(a*(b^2-_
+   4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(A*b-2*a*B+(-A*b^2-4*a*b*B+_
+   12*a*A*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                               4         2           2               2
+--R             ((- A b + 2B a)c x  + (- A b  + 2B a b)x  - A a b + 2B a )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2         2             4                   3         2  2
+--R           (12A a c  + (- A b  - 4B a b)c)x  + (12A a b c - A b  - 4B a b )x
+--R         + 
+--R                2         2       2
+--R           12A a c - A a b  - 4B a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                               4         2           2               2
+--R             ((- A b + 2B a)c x  + (- A b  + 2B a b)x  - A a b + 2B a )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2       2             4                     3         2  2
+--R           (- 12A a c  + (A b  + 4B a b)c)x  + (- 12A a b c + A b  + 4B a b )x
+--R         + 
+--R                  2         2       2
+--R           - 12A a c + A a b  + 4B a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                                             +-----------+
+--R                           3                2            +-+ |          2
+--R         ((- A b + 2B a)c x  + (2A a c - A b  + B a b)x)\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R           2 2       2   4      2          3  2     3      2 2  +-+
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2233
+
+--S 2234 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 2      2   4      2         3  2     3     2 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2       4   2      3   2       2 2 3      4 4
+--R                         - 81A a c  + (18A a b  + 36A B a b + 18A B a )c - A b
+--R                       + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                         - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                    /
+--R                             9 3         8 2 2        7 4        6 6
+--R                       16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                    2 2           3  2         2   3          2 2      2 3
+--R                (60A a b - 48A B a )c  + (- 15A a b  - 12A B a b  + 12B a b)c
+--R              + 
+--R                 2 5           4    2 2 3
+--R                A b  + 2A B a b  + B a b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              7           8  4             6 3          7 2  3
+--R                      (8192A a b - 4096B a )c  + (- 7168A a b  + 2048B a b )c
+--R                    + 
+--R                             5 5 2            4 7         5 6          3 9
+--R                      2304A a b c  + (- 320A a b  - 128B a b )c + 16A a b
+--R                    + 
+--R                           4 8
+--R                      16B a b
+--R                 *
+--R                    ROOT
+--R                                4 2 2       4   2      3   2       2 2 3
+--R                           - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                         + 
+--R                              4 4     3     3     2 2 2 2       3 3     4 4
+--R                           - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                      /
+--R                               9 3         8 2 2        7 4        6 6
+--R                         16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      3 4 4          3 3 2       2   4         2 5  3
+--R                  864A a c  + (- 672A a b  - 336A B a b - 96A B a )c
+--R                + 
+--R                       3 2 4       2   3 3        2 4 2      3 5   2
+--R                  (190A a b  + 216A B a b  + 96A B a b  + 16B a b)c
+--R                + 
+--R                        3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (- 23A a b  - 45A B a b  - 30A B a b  - 8B a b )c + A b
+--R                + 
+--R                    2     7       2 2 6    3 3 5
+--R                  3A B a b  + 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                     4 2 2       4   2      3   2       2 2 3
+--R                                - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                           /
+--R                                    9 3         8 2 2        7 4        6 6
+--R                              16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                           2 2           3  2
+--R                       (60A a b - 48A B a )c
+--R                     + 
+--R                             2   3          2 2      2 3       2 5           4
+--R                       (- 15A a b  - 12A B a b  + 12B a b)c + A b  + 2A B a b
+--R                     + 
+--R                        2 2 3
+--R                       B a b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                      4 2 4         4   2       3   2   3
+--R                  324A a c  + (- 81A a b  - 324A B a b)c
+--R                + 
+--R                     4 4      3     3      2 2 2 2        3 3      4 4  2
+--R                  (5A b  + 65A B a b  + 84A B a b  + 20A B a b - 4B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2
+--R                  (- 3A B b  - 9A B a b  - 9A B a b  - 3B a b )c
+--R             *
+--R                x
+--R     + 
+--R               2 2      2   4        2         3  2     3     2 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2       4   2      3   2       2 2 3      4 4
+--R                         - 81A a c  + (18A a b  + 36A B a b + 18A B a )c - A b
+--R                       + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                         - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                    /
+--R                             9 3         8 2 2        7 4        6 6
+--R                       16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                    2 2           3  2         2   3          2 2      2 3
+--R                (60A a b - 48A B a )c  + (- 15A a b  - 12A B a b  + 12B a b)c
+--R              + 
+--R                 2 5           4    2 2 3
+--R                A b  + 2A B a b  + B a b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              7           8  4             6 3          7 2  3
+--R                      (8192A a b - 4096B a )c  + (- 7168A a b  + 2048B a b )c
+--R                    + 
+--R                             5 5 2            4 7         5 6          3 9
+--R                      2304A a b c  + (- 320A a b  - 128B a b )c + 16A a b
+--R                    + 
+--R                           4 8
+--R                      16B a b
+--R                 *
+--R                    ROOT
+--R                                4 2 2       4   2      3   2       2 2 3
+--R                           - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                         + 
+--R                              4 4     3     3     2 2 2 2       3 3     4 4
+--R                           - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                      /
+--R                               9 3         8 2 2        7 4        6 6
+--R                         16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        3 4 4        3 3 2       2   4         2 5  3
+--R                  - 864A a c  + (672A a b  + 336A B a b + 96A B a )c
+--R                + 
+--R                         3 2 4       2   3 3        2 4 2      3 5   2
+--R                  (- 190A a b  - 216A B a b  - 96A B a b  - 16B a b)c
+--R                + 
+--R                      3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (23A a b  + 45A B a b  + 30A B a b  + 8B a b )c - A b
+--R                + 
+--R                      2     7       2 2 6    3 3 5
+--R                  - 3A B a b  - 3A B a b  - B a b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                     4 2 2       4   2      3   2       2 2 3
+--R                                - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                           /
+--R                                    9 3         8 2 2        7 4        6 6
+--R                              16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                           2 2           3  2
+--R                       (60A a b - 48A B a )c
+--R                     + 
+--R                             2   3          2 2      2 3       2 5           4
+--R                       (- 15A a b  - 12A B a b  + 12B a b)c + A b  + 2A B a b
+--R                     + 
+--R                        2 2 3
+--R                       B a b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                      4 2 4         4   2       3   2   3
+--R                  324A a c  + (- 81A a b  - 324A B a b)c
+--R                + 
+--R                     4 4      3     3      2 2 2 2        3 3      4 4  2
+--R                  (5A b  + 65A B a b  + 84A B a b  + 20A B a b - 4B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2
+--R                  (- 3A B b  - 9A B a b  - 9A B a b  - 3B a b )c
+--R             *
+--R                x
+--R     + 
+--R             2 2      2   4      2         3  2     3     2 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2       4   2      3   2       2 2 3      4 4
+--R                         - 81A a c  + (18A a b  + 36A B a b + 18A B a )c - A b
+--R                       + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                         - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                    /
+--R                             9 3         8 2 2        7 4        6 6
+--R                       16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                    2 2           3  2         2   3          2 2      2 3
+--R                (60A a b - 48A B a )c  + (- 15A a b  - 12A B a b  + 12B a b)c
+--R              + 
+--R                 2 5           4    2 2 3
+--R                A b  + 2A B a b  + B a b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                                7           8  4           6 3          7 2  3
+--R                      (- 8192A a b + 4096B a )c  + (7168A a b  - 2048B a b )c
+--R                    + 
+--R                               5 5 2          4 7         5 6          3 9
+--R                      - 2304A a b c  + (320A a b  + 128B a b )c - 16A a b
+--R                    + 
+--R                             4 8
+--R                      - 16B a b
+--R                 *
+--R                    ROOT
+--R                                4 2 2       4   2      3   2       2 2 3
+--R                           - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                         + 
+--R                              4 4     3     3     2 2 2 2       3 3     4 4
+--R                           - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                      /
+--R                               9 3         8 2 2        7 4        6 6
+--R                         16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      3 4 4          3 3 2       2   4         2 5  3
+--R                  864A a c  + (- 672A a b  - 336A B a b - 96A B a )c
+--R                + 
+--R                       3 2 4       2   3 3        2 4 2      3 5   2
+--R                  (190A a b  + 216A B a b  + 96A B a b  + 16B a b)c
+--R                + 
+--R                        3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (- 23A a b  - 45A B a b  - 30A B a b  - 8B a b )c + A b
+--R                + 
+--R                    2     7       2 2 6    3 3 5
+--R                  3A B a b  + 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                     4 2 2       4   2      3   2       2 2 3
+--R                                - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                           /
+--R                                    9 3         8 2 2        7 4        6 6
+--R                              16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                           2 2           3  2
+--R                       (60A a b - 48A B a )c
+--R                     + 
+--R                             2   3          2 2      2 3       2 5           4
+--R                       (- 15A a b  - 12A B a b  + 12B a b)c + A b  + 2A B a b
+--R                     + 
+--R                        2 2 3
+--R                       B a b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                      4 2 4         4   2       3   2   3
+--R                  324A a c  + (- 81A a b  - 324A B a b)c
+--R                + 
+--R                     4 4      3     3      2 2 2 2        3 3      4 4  2
+--R                  (5A b  + 65A B a b  + 84A B a b  + 20A B a b - 4B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2
+--R                  (- 3A B b  - 9A B a b  - 9A B a b  - 3B a b )c
+--R             *
+--R                x
+--R     + 
+--R               2 2      2   4        2         3  2     3     2 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2       4   2      3   2       2 2 3      4 4
+--R                         - 81A a c  + (18A a b  + 36A B a b + 18A B a )c - A b
+--R                       + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                         - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                    /
+--R                             9 3         8 2 2        7 4        6 6
+--R                       16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                    2 2           3  2         2   3          2 2      2 3
+--R                (60A a b - 48A B a )c  + (- 15A a b  - 12A B a b  + 12B a b)c
+--R              + 
+--R                 2 5           4    2 2 3
+--R                A b  + 2A B a b  + B a b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                                7           8  4           6 3          7 2  3
+--R                      (- 8192A a b + 4096B a )c  + (7168A a b  - 2048B a b )c
+--R                    + 
+--R                               5 5 2          4 7         5 6          3 9
+--R                      - 2304A a b c  + (320A a b  + 128B a b )c - 16A a b
+--R                    + 
+--R                             4 8
+--R                      - 16B a b
+--R                 *
+--R                    ROOT
+--R                                4 2 2       4   2      3   2       2 2 3
+--R                           - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                         + 
+--R                              4 4     3     3     2 2 2 2       3 3     4 4
+--R                           - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                      /
+--R                               9 3         8 2 2        7 4        6 6
+--R                         16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        3 4 4        3 3 2       2   4         2 5  3
+--R                  - 864A a c  + (672A a b  + 336A B a b + 96A B a )c
+--R                + 
+--R                         3 2 4       2   3 3        2 4 2      3 5   2
+--R                  (- 190A a b  - 216A B a b  - 96A B a b  - 16B a b)c
+--R                + 
+--R                      3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (23A a b  + 45A B a b  + 30A B a b  + 8B a b )c - A b
+--R                + 
+--R                      2     7       2 2 6    3 3 5
+--R                  - 3A B a b  - 3A B a b  - B a b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                     4 2 2       4   2      3   2       2 2 3
+--R                                - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                           /
+--R                                    9 3         8 2 2        7 4        6 6
+--R                              16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                           2 2           3  2
+--R                       (60A a b - 48A B a )c
+--R                     + 
+--R                             2   3          2 2      2 3       2 5           4
+--R                       (- 15A a b  - 12A B a b  + 12B a b)c + A b  + 2A B a b
+--R                     + 
+--R                        2 2 3
+--R                       B a b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                      4 2 4         4   2       3   2   3
+--R                  324A a c  + (- 81A a b  - 324A B a b)c
+--R                + 
+--R                     4 4      3     3      2 2 2 2        3 3      4 4  2
+--R                  (5A b  + 65A B a b  + 84A B a b  + 20A B a b - 4B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2
+--R                  (- 3A B b  - 9A B a b  - 9A B a b  - 3B a b )c
+--R             *
+--R                x
+--R     + 
+--R                        3                2
+--R       (- A b + 2B a)c x  + (2A a c - A b  + B a b)x
+--R  /
+--R        2 2       2   4      2          3  2     3      2 2
+--R     (8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2234
+
+--S 2235 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            2       2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2       4   2      3   2       2 2 3      4 4
+--R                         - 81A a c  + (18A a b  + 36A B a b + 18A B a )c - A b
+--R                       + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                         - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                    /
+--R                             9 3         8 2 2        7 4        6 6
+--R                       16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                    2 2           3  2         2   3          2 2      2 3
+--R                (60A a b - 48A B a )c  + (- 15A a b  - 12A B a b  + 12B a b)c
+--R              + 
+--R                 2 5           4    2 2 3
+--R                A b  + 2A B a b  + B a b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              7           8  4             6 3          7 2  3
+--R                      (8192A a b - 4096B a )c  + (- 7168A a b  + 2048B a b )c
+--R                    + 
+--R                             5 5 2            4 7         5 6          3 9
+--R                      2304A a b c  + (- 320A a b  - 128B a b )c + 16A a b
+--R                    + 
+--R                           4 8
+--R                      16B a b
+--R                 *
+--R                    ROOT
+--R                                4 2 2       4   2      3   2       2 2 3
+--R                           - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                         + 
+--R                              4 4     3     3     2 2 2 2       3 3     4 4
+--R                           - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                      /
+--R                               9 3         8 2 2        7 4        6 6
+--R                         16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      3 4 4          3 3 2       2   4         2 5  3
+--R                  864A a c  + (- 672A a b  - 336A B a b - 96A B a )c
+--R                + 
+--R                       3 2 4       2   3 3        2 4 2      3 5   2
+--R                  (190A a b  + 216A B a b  + 96A B a b  + 16B a b)c
+--R                + 
+--R                        3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (- 23A a b  - 45A B a b  - 30A B a b  - 8B a b )c + A b
+--R                + 
+--R                    2     7       2 2 6    3 3 5
+--R                  3A B a b  + 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                     4 2 2       4   2      3   2       2 2 3
+--R                                - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                           /
+--R                                    9 3         8 2 2        7 4        6 6
+--R                              16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                           2 2           3  2
+--R                       (60A a b - 48A B a )c
+--R                     + 
+--R                             2   3          2 2      2 3       2 5           4
+--R                       (- 15A a b  - 12A B a b  + 12B a b)c + A b  + 2A B a b
+--R                     + 
+--R                        2 2 3
+--R                       B a b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                      4 2 4         4   2       3   2   3
+--R                  324A a c  + (- 81A a b  - 324A B a b)c
+--R                + 
+--R                     4 4      3     3      2 2 2 2        3 3      4 4  2
+--R                  (5A b  + 65A B a b  + 84A B a b  + 20A B a b - 4B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2
+--R                  (- 3A B b  - 9A B a b  - 9A B a b  - 3B a b )c
+--R             *
+--R                x
+--R     + 
+--R                             +-----------+
+--R              2       2  +-+ |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2       4   2      3   2       2 2 3      4 4
+--R                         - 81A a c  + (18A a b  + 36A B a b + 18A B a )c - A b
+--R                       + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                         - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                    /
+--R                             9 3         8 2 2        7 4        6 6
+--R                       16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                    2 2           3  2         2   3          2 2      2 3
+--R                (60A a b - 48A B a )c  + (- 15A a b  - 12A B a b  + 12B a b)c
+--R              + 
+--R                 2 5           4    2 2 3
+--R                A b  + 2A B a b  + B a b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              7           8  4             6 3          7 2  3
+--R                      (8192A a b - 4096B a )c  + (- 7168A a b  + 2048B a b )c
+--R                    + 
+--R                             5 5 2            4 7         5 6          3 9
+--R                      2304A a b c  + (- 320A a b  - 128B a b )c + 16A a b
+--R                    + 
+--R                           4 8
+--R                      16B a b
+--R                 *
+--R                    ROOT
+--R                                4 2 2       4   2      3   2       2 2 3
+--R                           - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                         + 
+--R                              4 4     3     3     2 2 2 2       3 3     4 4
+--R                           - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                      /
+--R                               9 3         8 2 2        7 4        6 6
+--R                         16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        3 4 4        3 3 2       2   4         2 5  3
+--R                  - 864A a c  + (672A a b  + 336A B a b + 96A B a )c
+--R                + 
+--R                         3 2 4       2   3 3        2 4 2      3 5   2
+--R                  (- 190A a b  - 216A B a b  - 96A B a b  - 16B a b)c
+--R                + 
+--R                      3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (23A a b  + 45A B a b  + 30A B a b  + 8B a b )c - A b
+--R                + 
+--R                      2     7       2 2 6    3 3 5
+--R                  - 3A B a b  - 3A B a b  - B a b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                     4 2 2       4   2      3   2       2 2 3
+--R                                - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                           /
+--R                                    9 3         8 2 2        7 4        6 6
+--R                              16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                           2 2           3  2
+--R                       (60A a b - 48A B a )c
+--R                     + 
+--R                             2   3          2 2      2 3       2 5           4
+--R                       (- 15A a b  - 12A B a b  + 12B a b)c + A b  + 2A B a b
+--R                     + 
+--R                        2 2 3
+--R                       B a b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                      4 2 4         4   2       3   2   3
+--R                  324A a c  + (- 81A a b  - 324A B a b)c
+--R                + 
+--R                     4 4      3     3      2 2 2 2        3 3      4 4  2
+--R                  (5A b  + 65A B a b  + 84A B a b  + 20A B a b - 4B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2
+--R                  (- 3A B b  - 9A B a b  - 9A B a b  - 3B a b )c
+--R             *
+--R                x
+--R     + 
+--R                           +-----------+
+--R            2       2  +-+ |          2
+--R         (4a c - a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2       4   2      3   2       2 2 3      4 4
+--R                         - 81A a c  + (18A a b  + 36A B a b + 18A B a )c - A b
+--R                       + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                         - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                    /
+--R                             9 3         8 2 2        7 4        6 6
+--R                       16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                    2 2           3  2         2   3          2 2      2 3
+--R                (60A a b - 48A B a )c  + (- 15A a b  - 12A B a b  + 12B a b)c
+--R              + 
+--R                 2 5           4    2 2 3
+--R                A b  + 2A B a b  + B a b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                7           8  4           6 3          7 2  3
+--R                      (- 8192A a b + 4096B a )c  + (7168A a b  - 2048B a b )c
+--R                    + 
+--R                               5 5 2          4 7         5 6          3 9
+--R                      - 2304A a b c  + (320A a b  + 128B a b )c - 16A a b
+--R                    + 
+--R                             4 8
+--R                      - 16B a b
+--R                 *
+--R                    ROOT
+--R                                4 2 2       4   2      3   2       2 2 3
+--R                           - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                         + 
+--R                              4 4     3     3     2 2 2 2       3 3     4 4
+--R                           - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                      /
+--R                               9 3         8 2 2        7 4        6 6
+--R                         16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      3 4 4          3 3 2       2   4         2 5  3
+--R                  864A a c  + (- 672A a b  - 336A B a b - 96A B a )c
+--R                + 
+--R                       3 2 4       2   3 3        2 4 2      3 5   2
+--R                  (190A a b  + 216A B a b  + 96A B a b  + 16B a b)c
+--R                + 
+--R                        3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (- 23A a b  - 45A B a b  - 30A B a b  - 8B a b )c + A b
+--R                + 
+--R                    2     7       2 2 6    3 3 5
+--R                  3A B a b  + 3A B a b  + B a b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                     4 2 2       4   2      3   2       2 2 3
+--R                                - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                           /
+--R                                    9 3         8 2 2        7 4        6 6
+--R                              16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                           2 2           3  2
+--R                       (60A a b - 48A B a )c
+--R                     + 
+--R                             2   3          2 2      2 3       2 5           4
+--R                       (- 15A a b  - 12A B a b  + 12B a b)c + A b  + 2A B a b
+--R                     + 
+--R                        2 2 3
+--R                       B a b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                      4 2 4         4   2       3   2   3
+--R                  324A a c  + (- 81A a b  - 324A B a b)c
+--R                + 
+--R                     4 4      3     3      2 2 2 2        3 3      4 4  2
+--R                  (5A b  + 65A B a b  + 84A B a b  + 20A B a b - 4B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2
+--R                  (- 3A B b  - 9A B a b  - 9A B a b  - 3B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              2       2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2       4   2      3   2       2 2 3      4 4
+--R                         - 81A a c  + (18A a b  + 36A B a b + 18A B a )c - A b
+--R                       + 
+--R                             3     3     2 2 2 2       3 3     4 4
+--R                         - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                    /
+--R                             9 3         8 2 2        7 4        6 6
+--R                       16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                    2 2           3  2         2   3          2 2      2 3
+--R                (60A a b - 48A B a )c  + (- 15A a b  - 12A B a b  + 12B a b)c
+--R              + 
+--R                 2 5           4    2 2 3
+--R                A b  + 2A B a b  + B a b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                                7           8  4           6 3          7 2  3
+--R                      (- 8192A a b + 4096B a )c  + (7168A a b  - 2048B a b )c
+--R                    + 
+--R                               5 5 2          4 7         5 6          3 9
+--R                      - 2304A a b c  + (320A a b  + 128B a b )c - 16A a b
+--R                    + 
+--R                             4 8
+--R                      - 16B a b
+--R                 *
+--R                    ROOT
+--R                                4 2 2       4   2      3   2       2 2 3
+--R                           - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                         + 
+--R                              4 4     3     3     2 2 2 2       3 3     4 4
+--R                           - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                      /
+--R                               9 3         8 2 2        7 4        6 6
+--R                         16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        3 4 4        3 3 2       2   4         2 5  3
+--R                  - 864A a c  + (672A a b  + 336A B a b + 96A B a )c
+--R                + 
+--R                         3 2 4       2   3 3        2 4 2      3 5   2
+--R                  (- 190A a b  - 216A B a b  - 96A B a b  - 16B a b)c
+--R                + 
+--R                      3   6      2   2 5        2 3 4     3 4 3      3 8
+--R                  (23A a b  + 45A B a b  + 30A B a b  + 8B a b )c - A b
+--R                + 
+--R                      2     7       2 2 6    3 3 5
+--R                  - 3A B a b  - 3A B a b  - B a b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                     4 2 2       4   2      3   2       2 2 3
+--R                                - 81A a c  + (18A a b  + 36A B a b + 18A B a )c
+--R                              + 
+--R                                 4 4     3     3     2 2 2 2       3 3     4 4
+--R                              - A b  - 4A B a b  - 6A B a b  - 4A B a b - B a
+--R                           /
+--R                                    9 3         8 2 2        7 4        6 6
+--R                              16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                           2 2           3  2
+--R                       (60A a b - 48A B a )c
+--R                     + 
+--R                             2   3          2 2      2 3       2 5           4
+--R                       (- 15A a b  - 12A B a b  + 12B a b)c + A b  + 2A B a b
+--R                     + 
+--R                        2 2 3
+--R                       B a b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                      4 2 4         4   2       3   2   3
+--R                  324A a c  + (- 81A a b  - 324A B a b)c
+--R                + 
+--R                     4 4      3     3      2 2 2 2        3 3      4 4  2
+--R                  (5A b  + 65A B a b  + 84A B a b  + 20A B a b - 4B a )c
+--R                + 
+--R                       3   5     2 2   4       3 2 3     4 3 2
+--R                  (- 3A B b  - 9A B a b  - 9A B a b  - 3B a b )c
+--R             *
+--R                x
+--R     + 
+--R                       +-----------+
+--R                       |          2                 2           +-+
+--R         ((A b - 2B a)\|- 4a c + b   - 12A a c + A b  + 4B a b)\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                       +-----------+
+--R                       |          2                 2           +-+
+--R         ((A b - 2B a)\|- 4a c + b   + 12A a c - A b  - 4B a b)\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R          2        2  +-+ |          2  |   |          2
+--R       (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2235
+
+--S 2236 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2236
+
+)clear all
+
+--S 2237 of 3139
+t0:=(A+B*x^2)/(x^2*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                               2
+--R                            B x  + A
+--R   (1)  ------------------------------------------------
+--R         2 10         8            2  6         4    2 2
+--R        c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2237
+
+--S 2238 of 3139
+r0:=1/2*(-3*A*b^2+a*b*B+10*a*A*c)/(a^2*(b^2-4*a*c)*x)+1/2*(-a*b*B+_
+   A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*x*(a+b*x^2+c*x^4))-_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(3*A*b^2-_
+   a*b*B-10*a*A*c+(-a*B*(b^2-12*a*c)+A*(3*b^3-16*a*b*c))/sqrt(b^2-4*a*c))/_
+   (a^2*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*A*b^2-a*b*B-10*a*A*c+_
+   (a*B*(b^2-12*a*c)-A*(3*b^3-16*a*b*c))/sqrt(b^2-4*a*c))/(a^2*(b^2-_
+   4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                         2        2            5
+--R               (- 10A a c  + (3A b  - B a b)c)x
+--R             + 
+--R                                3        2  3           2          2      2
+--R             (- 10A a b c + 3A b  - B a b )x  + (- 10A a c + 3A a b  - B a b)x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                              2  2        3        2    5
+--R           ((- 16A a b + 12B a )c  + (3A b  - B a b )c)x
+--R         + 
+--R                      2        2          4        3  3
+--R           ((- 16A a b  + 12B a b)c + 3A b  - B a b )x
+--R         + 
+--R                    2         3           3      2 2
+--R           ((- 16A a b + 12B a )c + 3A a b  - B a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                         2        2            5
+--R               (- 10A a c  + (3A b  - B a b)c)x
+--R             + 
+--R                                3        2  3           2          2      2
+--R             (- 10A a b c + 3A b  - B a b )x  + (- 10A a c + 3A a b  - B a b)x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                            2  2          3        2    5
+--R           ((16A a b - 12B a )c  + (- 3A b  + B a b )c)x
+--R         + 
+--R                    2        2          4        3  3
+--R           ((16A a b  - 12B a b)c - 3A b  + B a b )x
+--R         + 
+--R                  2         3           3      2 2
+--R           ((16A a b - 12B a )c - 3A a b  + B a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                     2        2            4
+--R           (- 10A a c  + (3A b  - B a b)c)x
+--R         + 
+--R                             2         3        2  2       2          2
+--R           ((- 11A a b + 2B a )c + 3A b  - B a b )x  - 8A a c + 2A a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R           3 2     2 2   5      3        2 3  3      4      3 2    +-+
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x)\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2238
+
+--S 2239 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 2    2 2   5        3       2 3  3        4     3 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  + (- 4a c + a b )x)
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                               4 4 4         4 3 2        3   4        2 2 5  3
+--R                         - 625A a c  + (2550A a b  - 2200A B a b + 450A B a )c
+--R                       + 
+--R                                    4 2 4        3   3 3        2 2 4 2
+--R                             - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                           + 
+--R                                   3 5       4 6
+--R                             792A B a b - 81B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                 4   6        3   2 5       2 2 3 4
+--R                             918A a b  - 1404A B a b  + 792A B a b
+--R                           + 
+--R                                     3 4 3      4 5 2
+--R                             - 196A B a b  + 18B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  + 108A B a b  - 54A B a b  + 12A B a b  - B a b
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                       2 3            4  3
+--R                (- 420A a b + 240A B a )c
+--R              + 
+--R                     2 2 3           3 2      2 4   2
+--R                (385A a b  - 300A B a b  + 60B a b)c
+--R              + 
+--R                       2   5          2 4      2 3 3       2 7           6
+--R                (- 105A a b  + 80A B a b  - 15B a b )c + 9A b  - 6A B a b
+--R              + 
+--R                 2 2 5
+--R                B a b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              10 5              9 2          10   4
+--R                      20480A a  c  + (- 34816A a b  + 8192B a  b)c
+--R                    + 
+--R                               8 4          9 3  3
+--R                      (21504A a b  - 7168B a b )c
+--R                    + 
+--R                                7 6          8 5  2          6 8         7 7
+--R                      (- 6272A a b  + 2304B a b )c  + (880A a b  - 320B a b )c
+--R                    + 
+--R                             5 10        6 9
+--R                      - 48A a b   + 16B a b
+--R                 *
+--R                    ROOT
+--R                                 4 4 4
+--R                           - 625A a c
+--R                         + 
+--R                                 4 3 2        3   4        2 2 5  3
+--R                           (2550A a b  - 2200A B a b + 450A B a )c
+--R                         + 
+--R                                      4 2 4        3   3 3        2 2 4 2
+--R                               - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                             + 
+--R                                     3 5       4 6
+--R                               792A B a b - 81B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                   4   6        3   2 5       2 2 3 4
+--R                               918A a b  - 1404A B a b  + 792A B a b
+--R                             + 
+--R                                       3 4 3      4 5 2
+--R                               - 196A B a b  + 18B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        3 5         2   6  5
+--R                  (5200A a b - 2400A B a )c
+--R                + 
+--R                           3 4 3         2   5 2          2 6        3 7  4
+--R                  (- 14408A a b  + 15648A B a b  - 6096A B a b + 864B a )c
+--R                + 
+--R                         3 3 5         2   4 4          2 5 3       3 6 2  3
+--R                  (10549A a b  - 12414A B a b  + 4968A B a b  - 672B a b )c
+--R                + 
+--R                          3 2 7        2   3 6          2 4 5       3 5 4  2
+--R                  (- 3330A a b  + 3855A B a b  - 1485A B a b  + 190B a b )c
+--R                + 
+--R                       3   9       2   2 8         2 3 7      3 4 6        3 11
+--R                  (486A a b  - 531A B a b  + 192A B a b  - 23B a b )c - 27A b
+--R                + 
+--R                     2     10       2 2 9    3 3 8
+--R                  27A B a b   - 9A B a b  + B a b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                      4 4 4
+--R                                - 625A a c
+--R                              + 
+--R                                      4 3 2        3   4        2 2 5  3
+--R                                (2550A a b  - 2200A B a b + 450A B a )c
+--R                              + 
+--R                                           4 2 4        3   3 3        2 2 4 2
+--R                                    - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                                  + 
+--R                                          3 5       4 6
+--R                                    792A B a b - 81B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                        4   6        3   2 5       2 2 3 4
+--R                                    918A a b  - 1404A B a b  + 792A B a b
+--R                                  + 
+--R                                            3 4 3      4 5 2
+--R                                    - 196A B a b  + 18B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                              2 3            4  3
+--R                       (- 420A a b + 240A B a )c
+--R                     + 
+--R                            2 2 3           3 2      2 4   2
+--R                       (385A a b  - 300A B a b  + 60B a b)c
+--R                     + 
+--R                              2   5          2 4      2 3 3       2 7
+--R                       (- 105A a b  + 80A B a b  - 15B a b )c + 9A b
+--R                     + 
+--R                                 6    2 2 5
+--R                       - 6A B a b  + B a b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 3 6           4 2 2        3   3   5
+--R                  2500A a c  + (- 5625A a b  + 2500A B a b)c
+--R                + 
+--R                           4   4        3   2 3        2 2 3 2          3 4
+--R                      1971A a b  + 2727A B a b  - 5016A B a b  + 2268A B a b
+--R                    + 
+--R                            4 5
+--R                      - 324B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 6        3     5        2 2 2 4         3 3 3
+--R                      - 189A b  - 1323A B a b  + 1674A B a b  - 647A B a b
+--R                    + 
+--R                         4 4 2
+--R                      81B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   7       2 2   6        3 2 5     4 3 4  2
+--R                  (135A B b  - 135A B a b  + 45A B a b  - 5B a b )c
+--R             *
+--R                x
+--R     + 
+--R             3 2    2 2   5      3       2 3  3      4     3 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                               4 4 4         4 3 2        3   4        2 2 5  3
+--R                         - 625A a c  + (2550A a b  - 2200A B a b + 450A B a )c
+--R                       + 
+--R                                    4 2 4        3   3 3        2 2 4 2
+--R                             - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                           + 
+--R                                   3 5       4 6
+--R                             792A B a b - 81B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                 4   6        3   2 5       2 2 3 4
+--R                             918A a b  - 1404A B a b  + 792A B a b
+--R                           + 
+--R                                     3 4 3      4 5 2
+--R                             - 196A B a b  + 18B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  + 108A B a b  - 54A B a b  + 12A B a b  - B a b
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                       2 3            4  3
+--R                (- 420A a b + 240A B a )c
+--R              + 
+--R                     2 2 3           3 2      2 4   2
+--R                (385A a b  - 300A B a b  + 60B a b)c
+--R              + 
+--R                       2   5          2 4      2 3 3       2 7           6
+--R                (- 105A a b  + 80A B a b  - 15B a b )c + 9A b  - 6A B a b
+--R              + 
+--R                 2 2 5
+--R                B a b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              10 5              9 2          10   4
+--R                      20480A a  c  + (- 34816A a b  + 8192B a  b)c
+--R                    + 
+--R                               8 4          9 3  3
+--R                      (21504A a b  - 7168B a b )c
+--R                    + 
+--R                                7 6          8 5  2          6 8         7 7
+--R                      (- 6272A a b  + 2304B a b )c  + (880A a b  - 320B a b )c
+--R                    + 
+--R                             5 10        6 9
+--R                      - 48A a b   + 16B a b
+--R                 *
+--R                    ROOT
+--R                                 4 4 4
+--R                           - 625A a c
+--R                         + 
+--R                                 4 3 2        3   4        2 2 5  3
+--R                           (2550A a b  - 2200A B a b + 450A B a )c
+--R                         + 
+--R                                      4 2 4        3   3 3        2 2 4 2
+--R                               - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                             + 
+--R                                     3 5       4 6
+--R                               792A B a b - 81B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                   4   6        3   2 5       2 2 3 4
+--R                               918A a b  - 1404A B a b  + 792A B a b
+--R                             + 
+--R                                       3 4 3      4 5 2
+--R                               - 196A B a b  + 18B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          3 5         2   6  5
+--R                  (- 5200A a b + 2400A B a )c
+--R                + 
+--R                         3 4 3         2   5 2          2 6        3 7  4
+--R                  (14408A a b  - 15648A B a b  + 6096A B a b - 864B a )c
+--R                + 
+--R                           3 3 5         2   4 4          2 5 3       3 6 2  3
+--R                  (- 10549A a b  + 12414A B a b  - 4968A B a b  + 672B a b )c
+--R                + 
+--R                        3 2 7        2   3 6          2 4 5       3 5 4  2
+--R                  (3330A a b  - 3855A B a b  + 1485A B a b  - 190B a b )c
+--R                + 
+--R                         3   9       2   2 8         2 3 7      3 4 6
+--R                  (- 486A a b  + 531A B a b  - 192A B a b  + 23B a b )c
+--R                + 
+--R                     3 11      2     10       2 2 9    3 3 8
+--R                  27A b   - 27A B a b   + 9A B a b  - B a b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                      4 4 4
+--R                                - 625A a c
+--R                              + 
+--R                                      4 3 2        3   4        2 2 5  3
+--R                                (2550A a b  - 2200A B a b + 450A B a )c
+--R                              + 
+--R                                           4 2 4        3   3 3        2 2 4 2
+--R                                    - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                                  + 
+--R                                          3 5       4 6
+--R                                    792A B a b - 81B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                        4   6        3   2 5       2 2 3 4
+--R                                    918A a b  - 1404A B a b  + 792A B a b
+--R                                  + 
+--R                                            3 4 3      4 5 2
+--R                                    - 196A B a b  + 18B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                              2 3            4  3
+--R                       (- 420A a b + 240A B a )c
+--R                     + 
+--R                            2 2 3           3 2      2 4   2
+--R                       (385A a b  - 300A B a b  + 60B a b)c
+--R                     + 
+--R                              2   5          2 4      2 3 3       2 7
+--R                       (- 105A a b  + 80A B a b  - 15B a b )c + 9A b
+--R                     + 
+--R                                 6    2 2 5
+--R                       - 6A B a b  + B a b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 3 6           4 2 2        3   3   5
+--R                  2500A a c  + (- 5625A a b  + 2500A B a b)c
+--R                + 
+--R                           4   4        3   2 3        2 2 3 2          3 4
+--R                      1971A a b  + 2727A B a b  - 5016A B a b  + 2268A B a b
+--R                    + 
+--R                            4 5
+--R                      - 324B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 6        3     5        2 2 2 4         3 3 3
+--R                      - 189A b  - 1323A B a b  + 1674A B a b  - 647A B a b
+--R                    + 
+--R                         4 4 2
+--R                      81B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   7       2 2   6        3 2 5     4 3 4  2
+--R                  (135A B b  - 135A B a b  + 45A B a b  - 5B a b )c
+--R             *
+--R                x
+--R     + 
+--R               3 2    2 2   5        3       2 3  3        4     3 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  + (- 4a c + a b )x)
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                               4 4 4         4 3 2        3   4        2 2 5  3
+--R                         - 625A a c  + (2550A a b  - 2200A B a b + 450A B a )c
+--R                       + 
+--R                                    4 2 4        3   3 3        2 2 4 2
+--R                             - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                           + 
+--R                                   3 5       4 6
+--R                             792A B a b - 81B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                 4   6        3   2 5       2 2 3 4
+--R                             918A a b  - 1404A B a b  + 792A B a b
+--R                           + 
+--R                                     3 4 3      4 5 2
+--R                             - 196A B a b  + 18B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  + 108A B a b  - 54A B a b  + 12A B a b  - B a b
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                       2 3            4  3
+--R                (- 420A a b + 240A B a )c
+--R              + 
+--R                     2 2 3           3 2      2 4   2
+--R                (385A a b  - 300A B a b  + 60B a b)c
+--R              + 
+--R                       2   5          2 4      2 3 3       2 7           6
+--R                (- 105A a b  + 80A B a b  - 15B a b )c + 9A b  - 6A B a b
+--R              + 
+--R                 2 2 5
+--R                B a b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                                10 5            9 2          10   4
+--R                      - 20480A a  c  + (34816A a b  - 8192B a  b)c
+--R                    + 
+--R                                 8 4          9 3  3
+--R                      (- 21504A a b  + 7168B a b )c
+--R                    + 
+--R                              7 6          8 5  2            6 8         7 7
+--R                      (6272A a b  - 2304B a b )c  + (- 880A a b  + 320B a b )c
+--R                    + 
+--R                           5 10        6 9
+--R                      48A a b   - 16B a b
+--R                 *
+--R                    ROOT
+--R                                 4 4 4
+--R                           - 625A a c
+--R                         + 
+--R                                 4 3 2        3   4        2 2 5  3
+--R                           (2550A a b  - 2200A B a b + 450A B a )c
+--R                         + 
+--R                                      4 2 4        3   3 3        2 2 4 2
+--R                               - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                             + 
+--R                                     3 5       4 6
+--R                               792A B a b - 81B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                   4   6        3   2 5       2 2 3 4
+--R                               918A a b  - 1404A B a b  + 792A B a b
+--R                             + 
+--R                                       3 4 3      4 5 2
+--R                               - 196A B a b  + 18B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        3 5         2   6  5
+--R                  (5200A a b - 2400A B a )c
+--R                + 
+--R                           3 4 3         2   5 2          2 6        3 7  4
+--R                  (- 14408A a b  + 15648A B a b  - 6096A B a b + 864B a )c
+--R                + 
+--R                         3 3 5         2   4 4          2 5 3       3 6 2  3
+--R                  (10549A a b  - 12414A B a b  + 4968A B a b  - 672B a b )c
+--R                + 
+--R                          3 2 7        2   3 6          2 4 5       3 5 4  2
+--R                  (- 3330A a b  + 3855A B a b  - 1485A B a b  + 190B a b )c
+--R                + 
+--R                       3   9       2   2 8         2 3 7      3 4 6        3 11
+--R                  (486A a b  - 531A B a b  + 192A B a b  - 23B a b )c - 27A b
+--R                + 
+--R                     2     10       2 2 9    3 3 8
+--R                  27A B a b   - 9A B a b  + B a b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                      4 4 4
+--R                                - 625A a c
+--R                              + 
+--R                                      4 3 2        3   4        2 2 5  3
+--R                                (2550A a b  - 2200A B a b + 450A B a )c
+--R                              + 
+--R                                           4 2 4        3   3 3        2 2 4 2
+--R                                    - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                                  + 
+--R                                          3 5       4 6
+--R                                    792A B a b - 81B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                        4   6        3   2 5       2 2 3 4
+--R                                    918A a b  - 1404A B a b  + 792A B a b
+--R                                  + 
+--R                                            3 4 3      4 5 2
+--R                                    - 196A B a b  + 18B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                              2 3            4  3
+--R                       (- 420A a b + 240A B a )c
+--R                     + 
+--R                            2 2 3           3 2      2 4   2
+--R                       (385A a b  - 300A B a b  + 60B a b)c
+--R                     + 
+--R                              2   5          2 4      2 3 3       2 7
+--R                       (- 105A a b  + 80A B a b  - 15B a b )c + 9A b
+--R                     + 
+--R                                 6    2 2 5
+--R                       - 6A B a b  + B a b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 3 6           4 2 2        3   3   5
+--R                  2500A a c  + (- 5625A a b  + 2500A B a b)c
+--R                + 
+--R                           4   4        3   2 3        2 2 3 2          3 4
+--R                      1971A a b  + 2727A B a b  - 5016A B a b  + 2268A B a b
+--R                    + 
+--R                            4 5
+--R                      - 324B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 6        3     5        2 2 2 4         3 3 3
+--R                      - 189A b  - 1323A B a b  + 1674A B a b  - 647A B a b
+--R                    + 
+--R                         4 4 2
+--R                      81B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   7       2 2   6        3 2 5     4 3 4  2
+--R                  (135A B b  - 135A B a b  + 45A B a b  - 5B a b )c
+--R             *
+--R                x
+--R     + 
+--R             3 2    2 2   5      3       2 3  3      4     3 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                               4 4 4         4 3 2        3   4        2 2 5  3
+--R                         - 625A a c  + (2550A a b  - 2200A B a b + 450A B a )c
+--R                       + 
+--R                                    4 2 4        3   3 3        2 2 4 2
+--R                             - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                           + 
+--R                                   3 5       4 6
+--R                             792A B a b - 81B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                 4   6        3   2 5       2 2 3 4
+--R                             918A a b  - 1404A B a b  + 792A B a b
+--R                           + 
+--R                                     3 4 3      4 5 2
+--R                             - 196A B a b  + 18B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  + 108A B a b  - 54A B a b  + 12A B a b  - B a b
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                       2 3            4  3
+--R                (- 420A a b + 240A B a )c
+--R              + 
+--R                     2 2 3           3 2      2 4   2
+--R                (385A a b  - 300A B a b  + 60B a b)c
+--R              + 
+--R                       2   5          2 4      2 3 3       2 7           6
+--R                (- 105A a b  + 80A B a b  - 15B a b )c + 9A b  - 6A B a b
+--R              + 
+--R                 2 2 5
+--R                B a b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                                10 5            9 2          10   4
+--R                      - 20480A a  c  + (34816A a b  - 8192B a  b)c
+--R                    + 
+--R                                 8 4          9 3  3
+--R                      (- 21504A a b  + 7168B a b )c
+--R                    + 
+--R                              7 6          8 5  2            6 8         7 7
+--R                      (6272A a b  - 2304B a b )c  + (- 880A a b  + 320B a b )c
+--R                    + 
+--R                           5 10        6 9
+--R                      48A a b   - 16B a b
+--R                 *
+--R                    ROOT
+--R                                 4 4 4
+--R                           - 625A a c
+--R                         + 
+--R                                 4 3 2        3   4        2 2 5  3
+--R                           (2550A a b  - 2200A B a b + 450A B a )c
+--R                         + 
+--R                                      4 2 4        3   3 3        2 2 4 2
+--R                               - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                             + 
+--R                                     3 5       4 6
+--R                               792A B a b - 81B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                   4   6        3   2 5       2 2 3 4
+--R                               918A a b  - 1404A B a b  + 792A B a b
+--R                             + 
+--R                                       3 4 3      4 5 2
+--R                               - 196A B a b  + 18B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          3 5         2   6  5
+--R                  (- 5200A a b + 2400A B a )c
+--R                + 
+--R                         3 4 3         2   5 2          2 6        3 7  4
+--R                  (14408A a b  - 15648A B a b  + 6096A B a b - 864B a )c
+--R                + 
+--R                           3 3 5         2   4 4          2 5 3       3 6 2  3
+--R                  (- 10549A a b  + 12414A B a b  - 4968A B a b  + 672B a b )c
+--R                + 
+--R                        3 2 7        2   3 6          2 4 5       3 5 4  2
+--R                  (3330A a b  - 3855A B a b  + 1485A B a b  - 190B a b )c
+--R                + 
+--R                         3   9       2   2 8         2 3 7      3 4 6
+--R                  (- 486A a b  + 531A B a b  - 192A B a b  + 23B a b )c
+--R                + 
+--R                     3 11      2     10       2 2 9    3 3 8
+--R                  27A b   - 27A B a b   + 9A B a b  - B a b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                      4 4 4
+--R                                - 625A a c
+--R                              + 
+--R                                      4 3 2        3   4        2 2 5  3
+--R                                (2550A a b  - 2200A B a b + 450A B a )c
+--R                              + 
+--R                                           4 2 4        3   3 3        2 2 4 2
+--R                                    - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                                  + 
+--R                                          3 5       4 6
+--R                                    792A B a b - 81B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                        4   6        3   2 5       2 2 3 4
+--R                                    918A a b  - 1404A B a b  + 792A B a b
+--R                                  + 
+--R                                            3 4 3      4 5 2
+--R                                    - 196A B a b  + 18B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                              2 3            4  3
+--R                       (- 420A a b + 240A B a )c
+--R                     + 
+--R                            2 2 3           3 2      2 4   2
+--R                       (385A a b  - 300A B a b  + 60B a b)c
+--R                     + 
+--R                              2   5          2 4      2 3 3       2 7
+--R                       (- 105A a b  + 80A B a b  - 15B a b )c + 9A b
+--R                     + 
+--R                                 6    2 2 5
+--R                       - 6A B a b  + B a b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 3 6           4 2 2        3   3   5
+--R                  2500A a c  + (- 5625A a b  + 2500A B a b)c
+--R                + 
+--R                           4   4        3   2 3        2 2 3 2          3 4
+--R                      1971A a b  + 2727A B a b  - 5016A B a b  + 2268A B a b
+--R                    + 
+--R                            4 5
+--R                      - 324B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 6        3     5        2 2 2 4         3 3 3
+--R                      - 189A b  - 1323A B a b  + 1674A B a b  - 647A B a b
+--R                    + 
+--R                         4 4 2
+--R                      81B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   7       2 2   6        3 2 5     4 3 4  2
+--R                  (135A B b  - 135A B a b  + 45A B a b  - 5B a b )c
+--R             *
+--R                x
+--R     + 
+--R                 2        2            4
+--R       (- 10A a c  + (3A b  - B a b)c)x
+--R     + 
+--R                         2         3        2  2       2          2
+--R       ((- 11A a b + 2B a )c + 3A b  - B a b )x  - 8A a c + 2A a b
+--R  /
+--R        3 2     2 2   5      3        2 3  3      4      3 2
+--R     (8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2239
+
+--S 2240 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              3     2 2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                               4 4 4         4 3 2        3   4        2 2 5  3
+--R                         - 625A a c  + (2550A a b  - 2200A B a b + 450A B a )c
+--R                       + 
+--R                                    4 2 4        3   3 3        2 2 4 2
+--R                             - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                           + 
+--R                                   3 5       4 6
+--R                             792A B a b - 81B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                 4   6        3   2 5       2 2 3 4
+--R                             918A a b  - 1404A B a b  + 792A B a b
+--R                           + 
+--R                                     3 4 3      4 5 2
+--R                             - 196A B a b  + 18B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  + 108A B a b  - 54A B a b  + 12A B a b  - B a b
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                       2 3            4  3
+--R                (- 420A a b + 240A B a )c
+--R              + 
+--R                     2 2 3           3 2      2 4   2
+--R                (385A a b  - 300A B a b  + 60B a b)c
+--R              + 
+--R                       2   5          2 4      2 3 3       2 7           6
+--R                (- 105A a b  + 80A B a b  - 15B a b )c + 9A b  - 6A B a b
+--R              + 
+--R                 2 2 5
+--R                B a b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              10 5              9 2          10   4
+--R                      20480A a  c  + (- 34816A a b  + 8192B a  b)c
+--R                    + 
+--R                               8 4          9 3  3
+--R                      (21504A a b  - 7168B a b )c
+--R                    + 
+--R                                7 6          8 5  2          6 8         7 7
+--R                      (- 6272A a b  + 2304B a b )c  + (880A a b  - 320B a b )c
+--R                    + 
+--R                             5 10        6 9
+--R                      - 48A a b   + 16B a b
+--R                 *
+--R                    ROOT
+--R                                 4 4 4
+--R                           - 625A a c
+--R                         + 
+--R                                 4 3 2        3   4        2 2 5  3
+--R                           (2550A a b  - 2200A B a b + 450A B a )c
+--R                         + 
+--R                                      4 2 4        3   3 3        2 2 4 2
+--R                               - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                             + 
+--R                                     3 5       4 6
+--R                               792A B a b - 81B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                   4   6        3   2 5       2 2 3 4
+--R                               918A a b  - 1404A B a b  + 792A B a b
+--R                             + 
+--R                                       3 4 3      4 5 2
+--R                               - 196A B a b  + 18B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        3 5         2   6  5
+--R                  (5200A a b - 2400A B a )c
+--R                + 
+--R                           3 4 3         2   5 2          2 6        3 7  4
+--R                  (- 14408A a b  + 15648A B a b  - 6096A B a b + 864B a )c
+--R                + 
+--R                         3 3 5         2   4 4          2 5 3       3 6 2  3
+--R                  (10549A a b  - 12414A B a b  + 4968A B a b  - 672B a b )c
+--R                + 
+--R                          3 2 7        2   3 6          2 4 5       3 5 4  2
+--R                  (- 3330A a b  + 3855A B a b  - 1485A B a b  + 190B a b )c
+--R                + 
+--R                       3   9       2   2 8         2 3 7      3 4 6        3 11
+--R                  (486A a b  - 531A B a b  + 192A B a b  - 23B a b )c - 27A b
+--R                + 
+--R                     2     10       2 2 9    3 3 8
+--R                  27A B a b   - 9A B a b  + B a b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                      4 4 4
+--R                                - 625A a c
+--R                              + 
+--R                                      4 3 2        3   4        2 2 5  3
+--R                                (2550A a b  - 2200A B a b + 450A B a )c
+--R                              + 
+--R                                           4 2 4        3   3 3        2 2 4 2
+--R                                    - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                                  + 
+--R                                          3 5       4 6
+--R                                    792A B a b - 81B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                        4   6        3   2 5       2 2 3 4
+--R                                    918A a b  - 1404A B a b  + 792A B a b
+--R                                  + 
+--R                                            3 4 3      4 5 2
+--R                                    - 196A B a b  + 18B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                              2 3            4  3
+--R                       (- 420A a b + 240A B a )c
+--R                     + 
+--R                            2 2 3           3 2      2 4   2
+--R                       (385A a b  - 300A B a b  + 60B a b)c
+--R                     + 
+--R                              2   5          2 4      2 3 3       2 7
+--R                       (- 105A a b  + 80A B a b  - 15B a b )c + 9A b
+--R                     + 
+--R                                 6    2 2 5
+--R                       - 6A B a b  + B a b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 3 6           4 2 2        3   3   5
+--R                  2500A a c  + (- 5625A a b  + 2500A B a b)c
+--R                + 
+--R                           4   4        3   2 3        2 2 3 2          3 4
+--R                      1971A a b  + 2727A B a b  - 5016A B a b  + 2268A B a b
+--R                    + 
+--R                            4 5
+--R                      - 324B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 6        3     5        2 2 2 4         3 3 3
+--R                      - 189A b  - 1323A B a b  + 1674A B a b  - 647A B a b
+--R                    + 
+--R                         4 4 2
+--R                      81B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   7       2 2   6        3 2 5     4 3 4  2
+--R                  (135A B b  - 135A B a b  + 45A B a b  - 5B a b )c
+--R             *
+--R                x
+--R     + 
+--R                           +-----------+
+--R            3     2 2  +-+ |          2
+--R         (4a c - a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                               4 4 4         4 3 2        3   4        2 2 5  3
+--R                         - 625A a c  + (2550A a b  - 2200A B a b + 450A B a )c
+--R                       + 
+--R                                    4 2 4        3   3 3        2 2 4 2
+--R                             - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                           + 
+--R                                   3 5       4 6
+--R                             792A B a b - 81B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                 4   6        3   2 5       2 2 3 4
+--R                             918A a b  - 1404A B a b  + 792A B a b
+--R                           + 
+--R                                     3 4 3      4 5 2
+--R                             - 196A B a b  + 18B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  + 108A B a b  - 54A B a b  + 12A B a b  - B a b
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                       2 3            4  3
+--R                (- 420A a b + 240A B a )c
+--R              + 
+--R                     2 2 3           3 2      2 4   2
+--R                (385A a b  - 300A B a b  + 60B a b)c
+--R              + 
+--R                       2   5          2 4      2 3 3       2 7           6
+--R                (- 105A a b  + 80A B a b  - 15B a b )c + 9A b  - 6A B a b
+--R              + 
+--R                 2 2 5
+--R                B a b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              10 5              9 2          10   4
+--R                      20480A a  c  + (- 34816A a b  + 8192B a  b)c
+--R                    + 
+--R                               8 4          9 3  3
+--R                      (21504A a b  - 7168B a b )c
+--R                    + 
+--R                                7 6          8 5  2          6 8         7 7
+--R                      (- 6272A a b  + 2304B a b )c  + (880A a b  - 320B a b )c
+--R                    + 
+--R                             5 10        6 9
+--R                      - 48A a b   + 16B a b
+--R                 *
+--R                    ROOT
+--R                                 4 4 4
+--R                           - 625A a c
+--R                         + 
+--R                                 4 3 2        3   4        2 2 5  3
+--R                           (2550A a b  - 2200A B a b + 450A B a )c
+--R                         + 
+--R                                      4 2 4        3   3 3        2 2 4 2
+--R                               - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                             + 
+--R                                     3 5       4 6
+--R                               792A B a b - 81B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                   4   6        3   2 5       2 2 3 4
+--R                               918A a b  - 1404A B a b  + 792A B a b
+--R                             + 
+--R                                       3 4 3      4 5 2
+--R                               - 196A B a b  + 18B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          3 5         2   6  5
+--R                  (- 5200A a b + 2400A B a )c
+--R                + 
+--R                         3 4 3         2   5 2          2 6        3 7  4
+--R                  (14408A a b  - 15648A B a b  + 6096A B a b - 864B a )c
+--R                + 
+--R                           3 3 5         2   4 4          2 5 3       3 6 2  3
+--R                  (- 10549A a b  + 12414A B a b  - 4968A B a b  + 672B a b )c
+--R                + 
+--R                        3 2 7        2   3 6          2 4 5       3 5 4  2
+--R                  (3330A a b  - 3855A B a b  + 1485A B a b  - 190B a b )c
+--R                + 
+--R                         3   9       2   2 8         2 3 7      3 4 6
+--R                  (- 486A a b  + 531A B a b  - 192A B a b  + 23B a b )c
+--R                + 
+--R                     3 11      2     10       2 2 9    3 3 8
+--R                  27A b   - 27A B a b   + 9A B a b  - B a b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                      4 4 4
+--R                                - 625A a c
+--R                              + 
+--R                                      4 3 2        3   4        2 2 5  3
+--R                                (2550A a b  - 2200A B a b + 450A B a )c
+--R                              + 
+--R                                           4 2 4        3   3 3        2 2 4 2
+--R                                    - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                                  + 
+--R                                          3 5       4 6
+--R                                    792A B a b - 81B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                        4   6        3   2 5       2 2 3 4
+--R                                    918A a b  - 1404A B a b  + 792A B a b
+--R                                  + 
+--R                                            3 4 3      4 5 2
+--R                                    - 196A B a b  + 18B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                              2 3            4  3
+--R                       (- 420A a b + 240A B a )c
+--R                     + 
+--R                            2 2 3           3 2      2 4   2
+--R                       (385A a b  - 300A B a b  + 60B a b)c
+--R                     + 
+--R                              2   5          2 4      2 3 3       2 7
+--R                       (- 105A a b  + 80A B a b  - 15B a b )c + 9A b
+--R                     + 
+--R                                 6    2 2 5
+--R                       - 6A B a b  + B a b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 3 6           4 2 2        3   3   5
+--R                  2500A a c  + (- 5625A a b  + 2500A B a b)c
+--R                + 
+--R                           4   4        3   2 3        2 2 3 2          3 4
+--R                      1971A a b  + 2727A B a b  - 5016A B a b  + 2268A B a b
+--R                    + 
+--R                            4 5
+--R                      - 324B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 6        3     5        2 2 2 4         3 3 3
+--R                      - 189A b  - 1323A B a b  + 1674A B a b  - 647A B a b
+--R                    + 
+--R                         4 4 2
+--R                      81B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   7       2 2   6        3 2 5     4 3 4  2
+--R                  (135A B b  - 135A B a b  + 45A B a b  - 5B a b )c
+--R             *
+--R                x
+--R     + 
+--R                             +-----------+
+--R              3     2 2  +-+ |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                               4 4 4         4 3 2        3   4        2 2 5  3
+--R                         - 625A a c  + (2550A a b  - 2200A B a b + 450A B a )c
+--R                       + 
+--R                                    4 2 4        3   3 3        2 2 4 2
+--R                             - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                           + 
+--R                                   3 5       4 6
+--R                             792A B a b - 81B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                 4   6        3   2 5       2 2 3 4
+--R                             918A a b  - 1404A B a b  + 792A B a b
+--R                           + 
+--R                                     3 4 3      4 5 2
+--R                             - 196A B a b  + 18B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  + 108A B a b  - 54A B a b  + 12A B a b  - B a b
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                       2 3            4  3
+--R                (- 420A a b + 240A B a )c
+--R              + 
+--R                     2 2 3           3 2      2 4   2
+--R                (385A a b  - 300A B a b  + 60B a b)c
+--R              + 
+--R                       2   5          2 4      2 3 3       2 7           6
+--R                (- 105A a b  + 80A B a b  - 15B a b )c + 9A b  - 6A B a b
+--R              + 
+--R                 2 2 5
+--R                B a b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                10 5            9 2          10   4
+--R                      - 20480A a  c  + (34816A a b  - 8192B a  b)c
+--R                    + 
+--R                                 8 4          9 3  3
+--R                      (- 21504A a b  + 7168B a b )c
+--R                    + 
+--R                              7 6          8 5  2            6 8         7 7
+--R                      (6272A a b  - 2304B a b )c  + (- 880A a b  + 320B a b )c
+--R                    + 
+--R                           5 10        6 9
+--R                      48A a b   - 16B a b
+--R                 *
+--R                    ROOT
+--R                                 4 4 4
+--R                           - 625A a c
+--R                         + 
+--R                                 4 3 2        3   4        2 2 5  3
+--R                           (2550A a b  - 2200A B a b + 450A B a )c
+--R                         + 
+--R                                      4 2 4        3   3 3        2 2 4 2
+--R                               - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                             + 
+--R                                     3 5       4 6
+--R                               792A B a b - 81B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                   4   6        3   2 5       2 2 3 4
+--R                               918A a b  - 1404A B a b  + 792A B a b
+--R                             + 
+--R                                       3 4 3      4 5 2
+--R                               - 196A B a b  + 18B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        3 5         2   6  5
+--R                  (5200A a b - 2400A B a )c
+--R                + 
+--R                           3 4 3         2   5 2          2 6        3 7  4
+--R                  (- 14408A a b  + 15648A B a b  - 6096A B a b + 864B a )c
+--R                + 
+--R                         3 3 5         2   4 4          2 5 3       3 6 2  3
+--R                  (10549A a b  - 12414A B a b  + 4968A B a b  - 672B a b )c
+--R                + 
+--R                          3 2 7        2   3 6          2 4 5       3 5 4  2
+--R                  (- 3330A a b  + 3855A B a b  - 1485A B a b  + 190B a b )c
+--R                + 
+--R                       3   9       2   2 8         2 3 7      3 4 6        3 11
+--R                  (486A a b  - 531A B a b  + 192A B a b  - 23B a b )c - 27A b
+--R                + 
+--R                     2     10       2 2 9    3 3 8
+--R                  27A B a b   - 9A B a b  + B a b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                      4 4 4
+--R                                - 625A a c
+--R                              + 
+--R                                      4 3 2        3   4        2 2 5  3
+--R                                (2550A a b  - 2200A B a b + 450A B a )c
+--R                              + 
+--R                                           4 2 4        3   3 3        2 2 4 2
+--R                                    - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                                  + 
+--R                                          3 5       4 6
+--R                                    792A B a b - 81B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                        4   6        3   2 5       2 2 3 4
+--R                                    918A a b  - 1404A B a b  + 792A B a b
+--R                                  + 
+--R                                            3 4 3      4 5 2
+--R                                    - 196A B a b  + 18B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                              2 3            4  3
+--R                       (- 420A a b + 240A B a )c
+--R                     + 
+--R                            2 2 3           3 2      2 4   2
+--R                       (385A a b  - 300A B a b  + 60B a b)c
+--R                     + 
+--R                              2   5          2 4      2 3 3       2 7
+--R                       (- 105A a b  + 80A B a b  - 15B a b )c + 9A b
+--R                     + 
+--R                                 6    2 2 5
+--R                       - 6A B a b  + B a b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 3 6           4 2 2        3   3   5
+--R                  2500A a c  + (- 5625A a b  + 2500A B a b)c
+--R                + 
+--R                           4   4        3   2 3        2 2 3 2          3 4
+--R                      1971A a b  + 2727A B a b  - 5016A B a b  + 2268A B a b
+--R                    + 
+--R                            4 5
+--R                      - 324B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 6        3     5        2 2 2 4         3 3 3
+--R                      - 189A b  - 1323A B a b  + 1674A B a b  - 647A B a b
+--R                    + 
+--R                         4 4 2
+--R                      81B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   7       2 2   6        3 2 5     4 3 4  2
+--R                  (135A B b  - 135A B a b  + 45A B a b  - 5B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            3     2 2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                               4 4 4         4 3 2        3   4        2 2 5  3
+--R                         - 625A a c  + (2550A a b  - 2200A B a b + 450A B a )c
+--R                       + 
+--R                                    4 2 4        3   3 3        2 2 4 2
+--R                             - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                           + 
+--R                                   3 5       4 6
+--R                             792A B a b - 81B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                 4   6        3   2 5       2 2 3 4
+--R                             918A a b  - 1404A B a b  + 792A B a b
+--R                           + 
+--R                                     3 4 3      4 5 2
+--R                             - 196A B a b  + 18B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  + 108A B a b  - 54A B a b  + 12A B a b  - B a b
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                       2 3            4  3
+--R                (- 420A a b + 240A B a )c
+--R              + 
+--R                     2 2 3           3 2      2 4   2
+--R                (385A a b  - 300A B a b  + 60B a b)c
+--R              + 
+--R                       2   5          2 4      2 3 3       2 7           6
+--R                (- 105A a b  + 80A B a b  - 15B a b )c + 9A b  - 6A B a b
+--R              + 
+--R                 2 2 5
+--R                B a b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                                10 5            9 2          10   4
+--R                      - 20480A a  c  + (34816A a b  - 8192B a  b)c
+--R                    + 
+--R                                 8 4          9 3  3
+--R                      (- 21504A a b  + 7168B a b )c
+--R                    + 
+--R                              7 6          8 5  2            6 8         7 7
+--R                      (6272A a b  - 2304B a b )c  + (- 880A a b  + 320B a b )c
+--R                    + 
+--R                           5 10        6 9
+--R                      48A a b   - 16B a b
+--R                 *
+--R                    ROOT
+--R                                 4 4 4
+--R                           - 625A a c
+--R                         + 
+--R                                 4 3 2        3   4        2 2 5  3
+--R                           (2550A a b  - 2200A B a b + 450A B a )c
+--R                         + 
+--R                                      4 2 4        3   3 3        2 2 4 2
+--R                               - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                             + 
+--R                                     3 5       4 6
+--R                               792A B a b - 81B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                   4   6        3   2 5       2 2 3 4
+--R                               918A a b  - 1404A B a b  + 792A B a b
+--R                             + 
+--R                                       3 4 3      4 5 2
+--R                               - 196A B a b  + 18B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          3 5         2   6  5
+--R                  (- 5200A a b + 2400A B a )c
+--R                + 
+--R                         3 4 3         2   5 2          2 6        3 7  4
+--R                  (14408A a b  - 15648A B a b  + 6096A B a b - 864B a )c
+--R                + 
+--R                           3 3 5         2   4 4          2 5 3       3 6 2  3
+--R                  (- 10549A a b  + 12414A B a b  - 4968A B a b  + 672B a b )c
+--R                + 
+--R                        3 2 7        2   3 6          2 4 5       3 5 4  2
+--R                  (3330A a b  - 3855A B a b  + 1485A B a b  - 190B a b )c
+--R                + 
+--R                         3   9       2   2 8         2 3 7      3 4 6
+--R                  (- 486A a b  + 531A B a b  - 192A B a b  + 23B a b )c
+--R                + 
+--R                     3 11      2     10       2 2 9    3 3 8
+--R                  27A b   - 27A B a b   + 9A B a b  - B a b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                      4 4 4
+--R                                - 625A a c
+--R                              + 
+--R                                      4 3 2        3   4        2 2 5  3
+--R                                (2550A a b  - 2200A B a b + 450A B a )c
+--R                              + 
+--R                                           4 2 4        3   3 3        2 2 4 2
+--R                                    - 3051A a b  + 4788A B a b  - 2904A B a b
+--R                                  + 
+--R                                          3 5       4 6
+--R                                    792A B a b - 81B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                        4   6        3   2 5       2 2 3 4
+--R                                    918A a b  - 1404A B a b  + 792A B a b
+--R                                  + 
+--R                                            3 4 3      4 5 2
+--R                                    - 196A B a b  + 18B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  + 108A B a b  - 54A B a b  + 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                              2 3            4  3
+--R                       (- 420A a b + 240A B a )c
+--R                     + 
+--R                            2 2 3           3 2      2 4   2
+--R                       (385A a b  - 300A B a b  + 60B a b)c
+--R                     + 
+--R                              2   5          2 4      2 3 3       2 7
+--R                       (- 105A a b  + 80A B a b  - 15B a b )c + 9A b
+--R                     + 
+--R                                 6    2 2 5
+--R                       - 6A B a b  + B a b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 3 6           4 2 2        3   3   5
+--R                  2500A a c  + (- 5625A a b  + 2500A B a b)c
+--R                + 
+--R                           4   4        3   2 3        2 2 3 2          3 4
+--R                      1971A a b  + 2727A B a b  - 5016A B a b  + 2268A B a b
+--R                    + 
+--R                            4 5
+--R                      - 324B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 6        3     5        2 2 2 4         3 3 3
+--R                      - 189A b  - 1323A B a b  + 1674A B a b  - 647A B a b
+--R                    + 
+--R                         4 4 2
+--R                      81B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   7       2 2   6        3 2 5     4 3 4  2
+--R                  (135A B b  - 135A B a b  + 45A B a b  - 5B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                     +-----------+
+--R                          2          |          2                    2         3
+--R           (10A a c - 3A b  + B a b)\|- 4a c + b   + (16A a b - 12B a )c - 3A b
+--R         + 
+--R                2
+--R           B a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                     +-----------+
+--R                          2          |          2                      2
+--R           (10A a c - 3A b  + B a b)\|- 4a c + b   + (- 16A a b + 12B a )c
+--R         + 
+--R               3        2
+--R           3A b  - B a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R          3      2 2  +-+ |          2  |   |          2
+--R       (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2240
+
+--S 2241 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2241
+
+)clear all
+
+--S 2242 of 3139
+t0:=(A+B*x^2)/(x^4*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                2
+--R                             B x  + A
+--R   (1)  -------------------------------------------------
+--R         2 12         10            2  8         6    2 4
+--R        c x   + 2b c x   + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2242
+
+--S 2243 of 3139
+r0:=1/6*(-5*A*b^2+3*a*b*B+14*a*A*c)/(a^2*(b^2-4*a*c)*x^3)+_
+   1/2*(-a*B*(3*b^2-10*a*c)+A*(5*b^3-19*a*b*c))/(a^3*(b^2-4*a*c)*x)+_
+   1/2*(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+   x^3*(a+b*x^2+c*x^4))-1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(a*B*(3*b^2-10*a*c)-A*(5*b^3-19*a*b*c)+_
+   (a*b*B*(3*b^2-16*a*c)-A*(5*b^4-29*a*b^2*c+28*a^2*c^2))/sqrt(b^2-_
+   4*a*c))/(a^3*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (a*B*(3*b^2-10*a*c)-A*(5*b^3-19*a*b*c)+(-a*b*B*(3*b^2-16*a*c)+_
+   A*(5*b^4-29*a*b^2*c+28*a^2*c^2))/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                2  2           3         2    7
+--R               ((57A a b - 30B a )c  + (- 15A b  + 9B a b )c)x
+--R             + 
+--R                        2        2           4         3  5
+--R               ((57A a b  - 30B a b)c - 15A b  + 9B a b )x
+--R             + 
+--R                      2         3            3       2 2  3
+--R               ((57A a b - 30B a )c - 15A a b  + 9B a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2 3           2        2   2           4         3    7
+--R           (- 84A a c  + (87A a b  - 48B a b)c  + (- 15A b  + 9B a b )c)x
+--R         + 
+--R                   2   2           3        2 2          5         4  5
+--R           (- 84A a b c  + (87A a b  - 48B a b )c - 15A b  + 9B a b )x
+--R         + 
+--R                   3 2         2 2        3             4       2 3  3
+--R           (- 84A a c  + (87A a b  - 48B a b)c - 15A a b  + 9B a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                2  2           3         2    7
+--R               ((57A a b - 30B a )c  + (- 15A b  + 9B a b )c)x
+--R             + 
+--R                        2        2           4         3  5
+--R               ((57A a b  - 30B a b)c - 15A b  + 9B a b )x
+--R             + 
+--R                      2         3            3       2 2  3
+--R               ((57A a b - 30B a )c - 15A a b  + 9B a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 3             2        2   2         4         3    7
+--R           (84A a c  + (- 87A a b  + 48B a b)c  + (15A b  - 9B a b )c)x
+--R         + 
+--R                 2   2             3        2 2          5         4  5
+--R           (84A a b c  + (- 87A a b  + 48B a b )c + 15A b  - 9B a b )x
+--R         + 
+--R                 3 2           2 2        3             4       2 3  3
+--R           (84A a c  + (- 87A a b  + 48B a b)c + 15A a b  - 9B a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                            2  2           3         2    6
+--R           ((57A a b - 30B a )c  + (- 15A b  + 9B a b )c)x
+--R         + 
+--R                   2 2           2        2           4         3  4
+--R           (- 14A a c  + (62A a b  - 33B a b)c - 15A b  + 9B a b )x
+--R         + 
+--R                  2         3            3       2 2  2       3        2 2
+--R           ((40A a b - 24B a )c - 10A a b  + 6B a b )x  - 8A a c + 2A a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            4 2     3 2   7       4        3 3  5       5      4 2  3  +-+
+--R       ((24a c  - 6a b c)x  + (24a b c - 6a b )x  + (24a c - 6a b )x )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2243
+
+--S 2244 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4 2     3 2   7         4        3 3  5         5      4 2  3
+--R         ((- 12a c  + 3a b c)x  + (- 12a b c + 3a b )x  + (- 12a c + 3a b )x )
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                4 6 6
+--R                         - 2401A a c
+--R                       + 
+--R                                4 5 2         3   6         2 2 7  5
+--R                         (24108A a b  - 18228A B a b + 2450A B a )c
+--R                       + 
+--R                                     4 4 4          3   5 3         2 2 6 2
+--R                             - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                           + 
+--R                                    3 7        4 8
+--R                             9300A B a b - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                   4 3 6          3   4 5          2 2 5 4
+--R                             83630A a b  - 154848A B a b  + 102672A B a b
+--R                           + 
+--R                                       3 6 3        4 7 2
+--R                             - 28172A B a b  + 2550B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                                     4 2 8         3   3 7         2 2 4 6
+--R                             - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                           + 
+--R                                     3 5 5        4 6 4
+--R                             23616A B a b  - 3051B a b
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   10         3   2 9         2 2 3 8
+--R                             8250A a b   - 19100A B a b  + 16560A B a b
+--R                           + 
+--R                                      3 4 7       4 5 6
+--R                             - 6372A B a b  + 918B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                               4 12        3     11        2 2 2 10
+--R                         - 625A b   + 1500A B a b   - 1350A B a b
+--R                       + 
+--R                               3 3 9      4 4 8
+--R                         540A B a b  - 81B a b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      2 4            5  4
+--R                (1260A a b - 560A B a )c
+--R              + 
+--R                        2 3 3            4 2       2 5   3
+--R                (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1386A a b  - 1470A B a b  + 385B a b )c
+--R              + 
+--R                       2   7           2 6       2 3 5        2 9            8
+--R                (- 315A a b  + 364A B a b  - 105B a b )c + 25A b  - 30A B a b
+--R              + 
+--R                  2 2 7
+--R                9B a b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                               12            13  5
+--R                      (53248A a  b - 20480B a  )c
+--R                    + 
+--R                                 11 3           12 2  4
+--R                      (- 74752A a  b  + 34816B a  b )c
+--R                    + 
+--R                               10 5           11 4  3
+--R                      (41216A a  b  - 21504B a  b )c
+--R                    + 
+--R                                 9 7          10 6  2
+--R                      (- 11200A a b  + 6272B a  b )c
+--R                    + 
+--R                              8 9         9 8          7 11        8 10
+--R                      (1504A a b  - 880B a b )c - 80A a b   + 48B a b
+--R                 *
+--R                    ROOT
+--R                                  4 6 6
+--R                           - 2401A a c
+--R                         + 
+--R                                  4 5 2         3   6         2 2 7  5
+--R                           (24108A a b  - 18228A B a b + 2450A B a )c
+--R                         + 
+--R                                       4 4 4          3   5 3         2 2 6 2
+--R                               - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                             + 
+--R                                      3 7        4 8
+--R                               9300A B a b - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                     4 3 6          3   4 5          2 2 5 4
+--R                               83630A a b  - 154848A B a b  + 102672A B a b
+--R                             + 
+--R                                         3 6 3        4 7 2
+--R                               - 28172A B a b  + 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                       4 2 8         3   3 7         2 2 4 6
+--R                               - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                             + 
+--R                                       3 5 5        4 6 4
+--R                               23616A B a b  - 3051B a b
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   10         3   2 9         2 2 3 8
+--R                               8250A a b   - 19100A B a b  + 16560A B a b
+--R                             + 
+--R                                        3 4 7       4 5 6
+--R                               - 6372A B a b  + 918B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                 4 12        3     11        2 2 2 10
+--R                           - 625A b   + 1500A B a b   - 1350A B a b
+--R                         + 
+--R                                 3 3 9      4 4 8
+--R                           540A B a b  - 81B a b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        3 7 7            3 6 2         2   7           2 8  6
+--R                  10976A a c  + (- 79408A a b  + 51856A B a b - 5600A B a )c
+--R                + 
+--R                          3 5 4          2   6 3           2 7 2        3 8   5
+--R                  (172990A a b  - 192088A B a b  + 62512A B a b  - 5200B a b)c
+--R                + 
+--R                               3 4 6          2   5 5            2 6 4
+--R                      - 160932A a b  + 224705A B a b  - 101006A B a b
+--R                    + 
+--R                            3 7 3
+--R                      14408B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 3 8          2   4 7           2 5 6         3 6 5  3
+--R                  (75579A a b  - 118937A B a b  + 61740A B a b  - 10549B a b )c
+--R                + 
+--R                                3 2 10         2   3 9           2 4 8
+--R                        - 18940A a b   + 31929A B a b  - 17889A B a b
+--R                      + 
+--R                             3 5 7
+--R                        3330B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   12        2   2 11          2 3 10       3 4 9
+--R                  (2425A a b   - 4260A B a b   + 2493A B a b   - 486B a b )c
+--R                + 
+--R                        3 14       2     13         2 2 12      3 3 11
+--R                  - 125A b   + 225A B a b   - 135A B a b   + 27B a b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       4 6 6
+--R                                - 2401A a c
+--R                              + 
+--R                                       4 5 2         3   6         2 2 7  5
+--R                                (24108A a b  - 18228A B a b + 2450A B a )c
+--R                              + 
+--R                                            4 4 4          3   5 3
+--R                                    - 76686A a b  + 109544A B a b
+--R                                  + 
+--R                                            2 2 6 2          3 7        4 8
+--R                                    - 51894A B a b  + 9300A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                          4 3 6          3   4 5
+--R                                    83630A a b  - 154848A B a b
+--R                                  + 
+--R                                           2 2 5 4           3 6 3        4 7 2
+--R                                    102672A B a b  - 28172A B a b  + 2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                            4 2 8         3   3 7
+--R                                    - 39525A a b  + 84780A B a b
+--R                                  + 
+--R                                          2 2 4 6           3 5 5        4 6 4
+--R                                  - 67524A B a b  + 23616A B a b  - 3051B a b
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   10         3   2 9         2 2 3 8
+--R                                    8250A a b   - 19100A B a b  + 16560A B a b
+--R                                  + 
+--R                                             3 4 7       4 5 6
+--R                                    - 6372A B a b  + 918B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                      4 12        3     11        2 2 2 10
+--R                                - 625A b   + 1500A B a b   - 1350A B a b
+--R                              + 
+--R                                      3 3 9      4 4 8
+--R                                540A B a b  - 81B a b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             2 4            5  4
+--R                       (1260A a b - 560A B a )c
+--R                     + 
+--R                               2 3 3            4 2       2 5   3
+--R                       (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1386A a b  - 1470A B a b  + 385B a b )c
+--R                     + 
+--R                              2   7           2 6       2 3 5        2 9
+--R                       (- 315A a b  + 364A B a b  - 105B a b )c + 25A b
+--R                     + 
+--R                                  8     2 2 7
+--R                       - 30A B a b  + 9B a b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 4 8            4 3 2         3   4   7
+--R                  9604A a c  + (- 50421A a b  + 28812A B a b)c
+--R                + 
+--R                            4 2 4        3   3 3         2 2 4 2           3 5
+--R                      43410A a b  - 4343A B a b  - 43524A B a b  + 22500A B a b
+--R                    + 
+--R                             4 6
+--R                      - 2500B a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                              4   6         3   2 5         2 2 3 4
+--R                      - 12325A a b  - 20190A B a b  + 52821A B a b
+--R                    + 
+--R                                3 4 3        4 5 2
+--R                      - 31137A B a b  + 5625B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4 8        3     7         2 2 2 6           3 3 5
+--R                      1125A b  + 8325A B a b  - 16680A B a b  + 10053A B a b
+--R                    + 
+--R                             4 4 4
+--R                      - 1971B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3   9        2 2   8         3 2 7       4 3 6  3
+--R                  (- 875A B b  + 1575A B a b  - 945A B a b  + 189B a b )c
+--R             *
+--R                x
+--R     + 
+--R              4 2     3 2   7       4        3 3  5       5      4 2  3
+--R         ((12a c  - 3a b c)x  + (12a b c - 3a b )x  + (12a c - 3a b )x )
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                4 6 6
+--R                         - 2401A a c
+--R                       + 
+--R                                4 5 2         3   6         2 2 7  5
+--R                         (24108A a b  - 18228A B a b + 2450A B a )c
+--R                       + 
+--R                                     4 4 4          3   5 3         2 2 6 2
+--R                             - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                           + 
+--R                                    3 7        4 8
+--R                             9300A B a b - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                   4 3 6          3   4 5          2 2 5 4
+--R                             83630A a b  - 154848A B a b  + 102672A B a b
+--R                           + 
+--R                                       3 6 3        4 7 2
+--R                             - 28172A B a b  + 2550B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                                     4 2 8         3   3 7         2 2 4 6
+--R                             - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                           + 
+--R                                     3 5 5        4 6 4
+--R                             23616A B a b  - 3051B a b
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   10         3   2 9         2 2 3 8
+--R                             8250A a b   - 19100A B a b  + 16560A B a b
+--R                           + 
+--R                                      3 4 7       4 5 6
+--R                             - 6372A B a b  + 918B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                               4 12        3     11        2 2 2 10
+--R                         - 625A b   + 1500A B a b   - 1350A B a b
+--R                       + 
+--R                               3 3 9      4 4 8
+--R                         540A B a b  - 81B a b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      2 4            5  4
+--R                (1260A a b - 560A B a )c
+--R              + 
+--R                        2 3 3            4 2       2 5   3
+--R                (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1386A a b  - 1470A B a b  + 385B a b )c
+--R              + 
+--R                       2   7           2 6       2 3 5        2 9            8
+--R                (- 315A a b  + 364A B a b  - 105B a b )c + 25A b  - 30A B a b
+--R              + 
+--R                  2 2 7
+--R                9B a b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                               12            13  5
+--R                      (53248A a  b - 20480B a  )c
+--R                    + 
+--R                                 11 3           12 2  4
+--R                      (- 74752A a  b  + 34816B a  b )c
+--R                    + 
+--R                               10 5           11 4  3
+--R                      (41216A a  b  - 21504B a  b )c
+--R                    + 
+--R                                 9 7          10 6  2
+--R                      (- 11200A a b  + 6272B a  b )c
+--R                    + 
+--R                              8 9         9 8          7 11        8 10
+--R                      (1504A a b  - 880B a b )c - 80A a b   + 48B a b
+--R                 *
+--R                    ROOT
+--R                                  4 6 6
+--R                           - 2401A a c
+--R                         + 
+--R                                  4 5 2         3   6         2 2 7  5
+--R                           (24108A a b  - 18228A B a b + 2450A B a )c
+--R                         + 
+--R                                       4 4 4          3   5 3         2 2 6 2
+--R                               - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                             + 
+--R                                      3 7        4 8
+--R                               9300A B a b - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                     4 3 6          3   4 5          2 2 5 4
+--R                               83630A a b  - 154848A B a b  + 102672A B a b
+--R                             + 
+--R                                         3 6 3        4 7 2
+--R                               - 28172A B a b  + 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                       4 2 8         3   3 7         2 2 4 6
+--R                               - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                             + 
+--R                                       3 5 5        4 6 4
+--R                               23616A B a b  - 3051B a b
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   10         3   2 9         2 2 3 8
+--R                               8250A a b   - 19100A B a b  + 16560A B a b
+--R                             + 
+--R                                        3 4 7       4 5 6
+--R                               - 6372A B a b  + 918B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                 4 12        3     11        2 2 2 10
+--R                           - 625A b   + 1500A B a b   - 1350A B a b
+--R                         + 
+--R                                 3 3 9      4 4 8
+--R                           540A B a b  - 81B a b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          3 7 7          3 6 2         2   7           2 8  6
+--R                  - 10976A a c  + (79408A a b  - 51856A B a b + 5600A B a )c
+--R                + 
+--R                                 3 5 4          2   6 3           2 7 2
+--R                        - 172990A a b  + 192088A B a b  - 62512A B a b
+--R                      + 
+--R                             3 8
+--R                        5200B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                               3 4 6          2   5 5            2 6 4
+--R                        160932A a b  - 224705A B a b  + 101006A B a b
+--R                      + 
+--R                                3 7 3
+--R                        - 14408B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                3 3 8          2   4 7           2 5 6
+--R                        - 75579A a b  + 118937A B a b  - 61740A B a b
+--R                      + 
+--R                              3 6 5
+--R                        10549B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3 2 10         2   3 9           2 4 8        3 5 7  2
+--R                  (18940A a b   - 31929A B a b  + 17889A B a b  - 3330B a b )c
+--R                + 
+--R                          3   12        2   2 11          2 3 10       3 4 9
+--R                  (- 2425A a b   + 4260A B a b   - 2493A B a b   + 486B a b )c
+--R                + 
+--R                      3 14       2     13         2 2 12      3 3 11
+--R                  125A b   - 225A B a b   + 135A B a b   - 27B a b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       4 6 6
+--R                                - 2401A a c
+--R                              + 
+--R                                       4 5 2         3   6         2 2 7  5
+--R                                (24108A a b  - 18228A B a b + 2450A B a )c
+--R                              + 
+--R                                            4 4 4          3   5 3
+--R                                    - 76686A a b  + 109544A B a b
+--R                                  + 
+--R                                            2 2 6 2          3 7        4 8
+--R                                    - 51894A B a b  + 9300A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                          4 3 6          3   4 5
+--R                                    83630A a b  - 154848A B a b
+--R                                  + 
+--R                                           2 2 5 4           3 6 3        4 7 2
+--R                                    102672A B a b  - 28172A B a b  + 2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                            4 2 8         3   3 7
+--R                                    - 39525A a b  + 84780A B a b
+--R                                  + 
+--R                                          2 2 4 6           3 5 5        4 6 4
+--R                                  - 67524A B a b  + 23616A B a b  - 3051B a b
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   10         3   2 9         2 2 3 8
+--R                                    8250A a b   - 19100A B a b  + 16560A B a b
+--R                                  + 
+--R                                             3 4 7       4 5 6
+--R                                    - 6372A B a b  + 918B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                      4 12        3     11        2 2 2 10
+--R                                - 625A b   + 1500A B a b   - 1350A B a b
+--R                              + 
+--R                                      3 3 9      4 4 8
+--R                                540A B a b  - 81B a b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             2 4            5  4
+--R                       (1260A a b - 560A B a )c
+--R                     + 
+--R                               2 3 3            4 2       2 5   3
+--R                       (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1386A a b  - 1470A B a b  + 385B a b )c
+--R                     + 
+--R                              2   7           2 6       2 3 5        2 9
+--R                       (- 315A a b  + 364A B a b  - 105B a b )c + 25A b
+--R                     + 
+--R                                  8     2 2 7
+--R                       - 30A B a b  + 9B a b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 4 8            4 3 2         3   4   7
+--R                  9604A a c  + (- 50421A a b  + 28812A B a b)c
+--R                + 
+--R                            4 2 4        3   3 3         2 2 4 2           3 5
+--R                      43410A a b  - 4343A B a b  - 43524A B a b  + 22500A B a b
+--R                    + 
+--R                             4 6
+--R                      - 2500B a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                              4   6         3   2 5         2 2 3 4
+--R                      - 12325A a b  - 20190A B a b  + 52821A B a b
+--R                    + 
+--R                                3 4 3        4 5 2
+--R                      - 31137A B a b  + 5625B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4 8        3     7         2 2 2 6           3 3 5
+--R                      1125A b  + 8325A B a b  - 16680A B a b  + 10053A B a b
+--R                    + 
+--R                             4 4 4
+--R                      - 1971B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3   9        2 2   8         3 2 7       4 3 6  3
+--R                  (- 875A B b  + 1575A B a b  - 945A B a b  + 189B a b )c
+--R             *
+--R                x
+--R     + 
+--R                4 2     3 2   7         4        3 3  5         5      4 2  3
+--R         ((- 12a c  + 3a b c)x  + (- 12a b c + 3a b )x  + (- 12a c + 3a b )x )
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                4 6 6
+--R                         - 2401A a c
+--R                       + 
+--R                                4 5 2         3   6         2 2 7  5
+--R                         (24108A a b  - 18228A B a b + 2450A B a )c
+--R                       + 
+--R                                     4 4 4          3   5 3         2 2 6 2
+--R                             - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                           + 
+--R                                    3 7        4 8
+--R                             9300A B a b - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                   4 3 6          3   4 5          2 2 5 4
+--R                             83630A a b  - 154848A B a b  + 102672A B a b
+--R                           + 
+--R                                       3 6 3        4 7 2
+--R                             - 28172A B a b  + 2550B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                                     4 2 8         3   3 7         2 2 4 6
+--R                             - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                           + 
+--R                                     3 5 5        4 6 4
+--R                             23616A B a b  - 3051B a b
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   10         3   2 9         2 2 3 8
+--R                             8250A a b   - 19100A B a b  + 16560A B a b
+--R                           + 
+--R                                      3 4 7       4 5 6
+--R                             - 6372A B a b  + 918B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                               4 12        3     11        2 2 2 10
+--R                         - 625A b   + 1500A B a b   - 1350A B a b
+--R                       + 
+--R                               3 3 9      4 4 8
+--R                         540A B a b  - 81B a b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      2 4            5  4
+--R                (1260A a b - 560A B a )c
+--R              + 
+--R                        2 3 3            4 2       2 5   3
+--R                (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1386A a b  - 1470A B a b  + 385B a b )c
+--R              + 
+--R                       2   7           2 6       2 3 5        2 9            8
+--R                (- 315A a b  + 364A B a b  - 105B a b )c + 25A b  - 30A B a b
+--R              + 
+--R                  2 2 7
+--R                9B a b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                                 12            13  5
+--R                      (- 53248A a  b + 20480B a  )c
+--R                    + 
+--R                               11 3           12 2  4
+--R                      (74752A a  b  - 34816B a  b )c
+--R                    + 
+--R                                 10 5           11 4  3
+--R                      (- 41216A a  b  + 21504B a  b )c
+--R                    + 
+--R                               9 7          10 6  2
+--R                      (11200A a b  - 6272B a  b )c
+--R                    + 
+--R                                8 9         9 8          7 11        8 10
+--R                      (- 1504A a b  + 880B a b )c + 80A a b   - 48B a b
+--R                 *
+--R                    ROOT
+--R                                  4 6 6
+--R                           - 2401A a c
+--R                         + 
+--R                                  4 5 2         3   6         2 2 7  5
+--R                           (24108A a b  - 18228A B a b + 2450A B a )c
+--R                         + 
+--R                                       4 4 4          3   5 3         2 2 6 2
+--R                               - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                             + 
+--R                                      3 7        4 8
+--R                               9300A B a b - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                     4 3 6          3   4 5          2 2 5 4
+--R                               83630A a b  - 154848A B a b  + 102672A B a b
+--R                             + 
+--R                                         3 6 3        4 7 2
+--R                               - 28172A B a b  + 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                       4 2 8         3   3 7         2 2 4 6
+--R                               - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                             + 
+--R                                       3 5 5        4 6 4
+--R                               23616A B a b  - 3051B a b
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   10         3   2 9         2 2 3 8
+--R                               8250A a b   - 19100A B a b  + 16560A B a b
+--R                             + 
+--R                                        3 4 7       4 5 6
+--R                               - 6372A B a b  + 918B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                 4 12        3     11        2 2 2 10
+--R                           - 625A b   + 1500A B a b   - 1350A B a b
+--R                         + 
+--R                                 3 3 9      4 4 8
+--R                           540A B a b  - 81B a b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        3 7 7            3 6 2         2   7           2 8  6
+--R                  10976A a c  + (- 79408A a b  + 51856A B a b - 5600A B a )c
+--R                + 
+--R                          3 5 4          2   6 3           2 7 2        3 8   5
+--R                  (172990A a b  - 192088A B a b  + 62512A B a b  - 5200B a b)c
+--R                + 
+--R                               3 4 6          2   5 5            2 6 4
+--R                      - 160932A a b  + 224705A B a b  - 101006A B a b
+--R                    + 
+--R                            3 7 3
+--R                      14408B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 3 8          2   4 7           2 5 6         3 6 5  3
+--R                  (75579A a b  - 118937A B a b  + 61740A B a b  - 10549B a b )c
+--R                + 
+--R                                3 2 10         2   3 9           2 4 8
+--R                        - 18940A a b   + 31929A B a b  - 17889A B a b
+--R                      + 
+--R                             3 5 7
+--R                        3330B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   12        2   2 11          2 3 10       3 4 9
+--R                  (2425A a b   - 4260A B a b   + 2493A B a b   - 486B a b )c
+--R                + 
+--R                        3 14       2     13         2 2 12      3 3 11
+--R                  - 125A b   + 225A B a b   - 135A B a b   + 27B a b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       4 6 6
+--R                                - 2401A a c
+--R                              + 
+--R                                       4 5 2         3   6         2 2 7  5
+--R                                (24108A a b  - 18228A B a b + 2450A B a )c
+--R                              + 
+--R                                            4 4 4          3   5 3
+--R                                    - 76686A a b  + 109544A B a b
+--R                                  + 
+--R                                            2 2 6 2          3 7        4 8
+--R                                    - 51894A B a b  + 9300A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                          4 3 6          3   4 5
+--R                                    83630A a b  - 154848A B a b
+--R                                  + 
+--R                                           2 2 5 4           3 6 3        4 7 2
+--R                                    102672A B a b  - 28172A B a b  + 2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                            4 2 8         3   3 7
+--R                                    - 39525A a b  + 84780A B a b
+--R                                  + 
+--R                                          2 2 4 6           3 5 5        4 6 4
+--R                                  - 67524A B a b  + 23616A B a b  - 3051B a b
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   10         3   2 9         2 2 3 8
+--R                                    8250A a b   - 19100A B a b  + 16560A B a b
+--R                                  + 
+--R                                             3 4 7       4 5 6
+--R                                    - 6372A B a b  + 918B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                      4 12        3     11        2 2 2 10
+--R                                - 625A b   + 1500A B a b   - 1350A B a b
+--R                              + 
+--R                                      3 3 9      4 4 8
+--R                                540A B a b  - 81B a b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             2 4            5  4
+--R                       (1260A a b - 560A B a )c
+--R                     + 
+--R                               2 3 3            4 2       2 5   3
+--R                       (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1386A a b  - 1470A B a b  + 385B a b )c
+--R                     + 
+--R                              2   7           2 6       2 3 5        2 9
+--R                       (- 315A a b  + 364A B a b  - 105B a b )c + 25A b
+--R                     + 
+--R                                  8     2 2 7
+--R                       - 30A B a b  + 9B a b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 4 8            4 3 2         3   4   7
+--R                  9604A a c  + (- 50421A a b  + 28812A B a b)c
+--R                + 
+--R                            4 2 4        3   3 3         2 2 4 2           3 5
+--R                      43410A a b  - 4343A B a b  - 43524A B a b  + 22500A B a b
+--R                    + 
+--R                             4 6
+--R                      - 2500B a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                              4   6         3   2 5         2 2 3 4
+--R                      - 12325A a b  - 20190A B a b  + 52821A B a b
+--R                    + 
+--R                                3 4 3        4 5 2
+--R                      - 31137A B a b  + 5625B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4 8        3     7         2 2 2 6           3 3 5
+--R                      1125A b  + 8325A B a b  - 16680A B a b  + 10053A B a b
+--R                    + 
+--R                             4 4 4
+--R                      - 1971B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3   9        2 2   8         3 2 7       4 3 6  3
+--R                  (- 875A B b  + 1575A B a b  - 945A B a b  + 189B a b )c
+--R             *
+--R                x
+--R     + 
+--R              4 2     3 2   7       4        3 3  5       5      4 2  3
+--R         ((12a c  - 3a b c)x  + (12a b c - 3a b )x  + (12a c - 3a b )x )
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                4 6 6
+--R                         - 2401A a c
+--R                       + 
+--R                                4 5 2         3   6         2 2 7  5
+--R                         (24108A a b  - 18228A B a b + 2450A B a )c
+--R                       + 
+--R                                     4 4 4          3   5 3         2 2 6 2
+--R                             - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                           + 
+--R                                    3 7        4 8
+--R                             9300A B a b - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                   4 3 6          3   4 5          2 2 5 4
+--R                             83630A a b  - 154848A B a b  + 102672A B a b
+--R                           + 
+--R                                       3 6 3        4 7 2
+--R                             - 28172A B a b  + 2550B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                                     4 2 8         3   3 7         2 2 4 6
+--R                             - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                           + 
+--R                                     3 5 5        4 6 4
+--R                             23616A B a b  - 3051B a b
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   10         3   2 9         2 2 3 8
+--R                             8250A a b   - 19100A B a b  + 16560A B a b
+--R                           + 
+--R                                      3 4 7       4 5 6
+--R                             - 6372A B a b  + 918B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                               4 12        3     11        2 2 2 10
+--R                         - 625A b   + 1500A B a b   - 1350A B a b
+--R                       + 
+--R                               3 3 9      4 4 8
+--R                         540A B a b  - 81B a b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      2 4            5  4
+--R                (1260A a b - 560A B a )c
+--R              + 
+--R                        2 3 3            4 2       2 5   3
+--R                (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1386A a b  - 1470A B a b  + 385B a b )c
+--R              + 
+--R                       2   7           2 6       2 3 5        2 9            8
+--R                (- 315A a b  + 364A B a b  - 105B a b )c + 25A b  - 30A B a b
+--R              + 
+--R                  2 2 7
+--R                9B a b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                                 12            13  5
+--R                      (- 53248A a  b + 20480B a  )c
+--R                    + 
+--R                               11 3           12 2  4
+--R                      (74752A a  b  - 34816B a  b )c
+--R                    + 
+--R                                 10 5           11 4  3
+--R                      (- 41216A a  b  + 21504B a  b )c
+--R                    + 
+--R                               9 7          10 6  2
+--R                      (11200A a b  - 6272B a  b )c
+--R                    + 
+--R                                8 9         9 8          7 11        8 10
+--R                      (- 1504A a b  + 880B a b )c + 80A a b   - 48B a b
+--R                 *
+--R                    ROOT
+--R                                  4 6 6
+--R                           - 2401A a c
+--R                         + 
+--R                                  4 5 2         3   6         2 2 7  5
+--R                           (24108A a b  - 18228A B a b + 2450A B a )c
+--R                         + 
+--R                                       4 4 4          3   5 3         2 2 6 2
+--R                               - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                             + 
+--R                                      3 7        4 8
+--R                               9300A B a b - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                     4 3 6          3   4 5          2 2 5 4
+--R                               83630A a b  - 154848A B a b  + 102672A B a b
+--R                             + 
+--R                                         3 6 3        4 7 2
+--R                               - 28172A B a b  + 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                       4 2 8         3   3 7         2 2 4 6
+--R                               - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                             + 
+--R                                       3 5 5        4 6 4
+--R                               23616A B a b  - 3051B a b
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   10         3   2 9         2 2 3 8
+--R                               8250A a b   - 19100A B a b  + 16560A B a b
+--R                             + 
+--R                                        3 4 7       4 5 6
+--R                               - 6372A B a b  + 918B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                 4 12        3     11        2 2 2 10
+--R                           - 625A b   + 1500A B a b   - 1350A B a b
+--R                         + 
+--R                                 3 3 9      4 4 8
+--R                           540A B a b  - 81B a b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          3 7 7          3 6 2         2   7           2 8  6
+--R                  - 10976A a c  + (79408A a b  - 51856A B a b + 5600A B a )c
+--R                + 
+--R                                 3 5 4          2   6 3           2 7 2
+--R                        - 172990A a b  + 192088A B a b  - 62512A B a b
+--R                      + 
+--R                             3 8
+--R                        5200B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                               3 4 6          2   5 5            2 6 4
+--R                        160932A a b  - 224705A B a b  + 101006A B a b
+--R                      + 
+--R                                3 7 3
+--R                        - 14408B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                3 3 8          2   4 7           2 5 6
+--R                        - 75579A a b  + 118937A B a b  - 61740A B a b
+--R                      + 
+--R                              3 6 5
+--R                        10549B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3 2 10         2   3 9           2 4 8        3 5 7  2
+--R                  (18940A a b   - 31929A B a b  + 17889A B a b  - 3330B a b )c
+--R                + 
+--R                          3   12        2   2 11          2 3 10       3 4 9
+--R                  (- 2425A a b   + 4260A B a b   - 2493A B a b   + 486B a b )c
+--R                + 
+--R                      3 14       2     13         2 2 12      3 3 11
+--R                  125A b   - 225A B a b   + 135A B a b   - 27B a b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       4 6 6
+--R                                - 2401A a c
+--R                              + 
+--R                                       4 5 2         3   6         2 2 7  5
+--R                                (24108A a b  - 18228A B a b + 2450A B a )c
+--R                              + 
+--R                                            4 4 4          3   5 3
+--R                                    - 76686A a b  + 109544A B a b
+--R                                  + 
+--R                                            2 2 6 2          3 7        4 8
+--R                                    - 51894A B a b  + 9300A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                          4 3 6          3   4 5
+--R                                    83630A a b  - 154848A B a b
+--R                                  + 
+--R                                           2 2 5 4           3 6 3        4 7 2
+--R                                    102672A B a b  - 28172A B a b  + 2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                            4 2 8         3   3 7
+--R                                    - 39525A a b  + 84780A B a b
+--R                                  + 
+--R                                          2 2 4 6           3 5 5        4 6 4
+--R                                  - 67524A B a b  + 23616A B a b  - 3051B a b
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   10         3   2 9         2 2 3 8
+--R                                    8250A a b   - 19100A B a b  + 16560A B a b
+--R                                  + 
+--R                                             3 4 7       4 5 6
+--R                                    - 6372A B a b  + 918B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                      4 12        3     11        2 2 2 10
+--R                                - 625A b   + 1500A B a b   - 1350A B a b
+--R                              + 
+--R                                      3 3 9      4 4 8
+--R                                540A B a b  - 81B a b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             2 4            5  4
+--R                       (1260A a b - 560A B a )c
+--R                     + 
+--R                               2 3 3            4 2       2 5   3
+--R                       (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1386A a b  - 1470A B a b  + 385B a b )c
+--R                     + 
+--R                              2   7           2 6       2 3 5        2 9
+--R                       (- 315A a b  + 364A B a b  - 105B a b )c + 25A b
+--R                     + 
+--R                                  8     2 2 7
+--R                       - 30A B a b  + 9B a b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 4 8            4 3 2         3   4   7
+--R                  9604A a c  + (- 50421A a b  + 28812A B a b)c
+--R                + 
+--R                            4 2 4        3   3 3         2 2 4 2           3 5
+--R                      43410A a b  - 4343A B a b  - 43524A B a b  + 22500A B a b
+--R                    + 
+--R                             4 6
+--R                      - 2500B a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                              4   6         3   2 5         2 2 3 4
+--R                      - 12325A a b  - 20190A B a b  + 52821A B a b
+--R                    + 
+--R                                3 4 3        4 5 2
+--R                      - 31137A B a b  + 5625B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4 8        3     7         2 2 2 6           3 3 5
+--R                      1125A b  + 8325A B a b  - 16680A B a b  + 10053A B a b
+--R                    + 
+--R                             4 4 4
+--R                      - 1971B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3   9        2 2   8         3 2 7       4 3 6  3
+--R                  (- 875A B b  + 1575A B a b  - 945A B a b  + 189B a b )c
+--R             *
+--R                x
+--R     + 
+--R                        2  2           3         2    6
+--R       ((57A a b - 30B a )c  + (- 15A b  + 9B a b )c)x
+--R     + 
+--R               2 2           2        2           4         3  4
+--R       (- 14A a c  + (62A a b  - 33B a b)c - 15A b  + 9B a b )x
+--R     + 
+--R              2         3            3       2 2  2       3        2 2
+--R       ((40A a b - 24B a )c - 10A a b  + 6B a b )x  - 8A a c + 2A a b
+--R  /
+--R         4 2     3 2   7       4        3 3  5       5      4 2  3
+--R     (24a c  - 6a b c)x  + (24a b c - 6a b )x  + (24a c - 6a b )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2244
+
+--S 2245 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              4     3 2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                4 6 6
+--R                         - 2401A a c
+--R                       + 
+--R                                4 5 2         3   6         2 2 7  5
+--R                         (24108A a b  - 18228A B a b + 2450A B a )c
+--R                       + 
+--R                                     4 4 4          3   5 3         2 2 6 2
+--R                             - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                           + 
+--R                                    3 7        4 8
+--R                             9300A B a b - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                   4 3 6          3   4 5          2 2 5 4
+--R                             83630A a b  - 154848A B a b  + 102672A B a b
+--R                           + 
+--R                                       3 6 3        4 7 2
+--R                             - 28172A B a b  + 2550B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                                     4 2 8         3   3 7         2 2 4 6
+--R                             - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                           + 
+--R                                     3 5 5        4 6 4
+--R                             23616A B a b  - 3051B a b
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   10         3   2 9         2 2 3 8
+--R                             8250A a b   - 19100A B a b  + 16560A B a b
+--R                           + 
+--R                                      3 4 7       4 5 6
+--R                             - 6372A B a b  + 918B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                               4 12        3     11        2 2 2 10
+--R                         - 625A b   + 1500A B a b   - 1350A B a b
+--R                       + 
+--R                               3 3 9      4 4 8
+--R                         540A B a b  - 81B a b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      2 4            5  4
+--R                (1260A a b - 560A B a )c
+--R              + 
+--R                        2 3 3            4 2       2 5   3
+--R                (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1386A a b  - 1470A B a b  + 385B a b )c
+--R              + 
+--R                       2   7           2 6       2 3 5        2 9            8
+--R                (- 315A a b  + 364A B a b  - 105B a b )c + 25A b  - 30A B a b
+--R              + 
+--R                  2 2 7
+--R                9B a b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               12            13  5
+--R                      (53248A a  b - 20480B a  )c
+--R                    + 
+--R                                 11 3           12 2  4
+--R                      (- 74752A a  b  + 34816B a  b )c
+--R                    + 
+--R                               10 5           11 4  3
+--R                      (41216A a  b  - 21504B a  b )c
+--R                    + 
+--R                                 9 7          10 6  2
+--R                      (- 11200A a b  + 6272B a  b )c
+--R                    + 
+--R                              8 9         9 8          7 11        8 10
+--R                      (1504A a b  - 880B a b )c - 80A a b   + 48B a b
+--R                 *
+--R                    ROOT
+--R                                  4 6 6
+--R                           - 2401A a c
+--R                         + 
+--R                                  4 5 2         3   6         2 2 7  5
+--R                           (24108A a b  - 18228A B a b + 2450A B a )c
+--R                         + 
+--R                                       4 4 4          3   5 3         2 2 6 2
+--R                               - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                             + 
+--R                                      3 7        4 8
+--R                               9300A B a b - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                     4 3 6          3   4 5          2 2 5 4
+--R                               83630A a b  - 154848A B a b  + 102672A B a b
+--R                             + 
+--R                                         3 6 3        4 7 2
+--R                               - 28172A B a b  + 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                       4 2 8         3   3 7         2 2 4 6
+--R                               - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                             + 
+--R                                       3 5 5        4 6 4
+--R                               23616A B a b  - 3051B a b
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   10         3   2 9         2 2 3 8
+--R                               8250A a b   - 19100A B a b  + 16560A B a b
+--R                             + 
+--R                                        3 4 7       4 5 6
+--R                               - 6372A B a b  + 918B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                 4 12        3     11        2 2 2 10
+--R                           - 625A b   + 1500A B a b   - 1350A B a b
+--R                         + 
+--R                                 3 3 9      4 4 8
+--R                           540A B a b  - 81B a b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        3 7 7            3 6 2         2   7           2 8  6
+--R                  10976A a c  + (- 79408A a b  + 51856A B a b - 5600A B a )c
+--R                + 
+--R                          3 5 4          2   6 3           2 7 2        3 8   5
+--R                  (172990A a b  - 192088A B a b  + 62512A B a b  - 5200B a b)c
+--R                + 
+--R                               3 4 6          2   5 5            2 6 4
+--R                      - 160932A a b  + 224705A B a b  - 101006A B a b
+--R                    + 
+--R                            3 7 3
+--R                      14408B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 3 8          2   4 7           2 5 6         3 6 5  3
+--R                  (75579A a b  - 118937A B a b  + 61740A B a b  - 10549B a b )c
+--R                + 
+--R                                3 2 10         2   3 9           2 4 8
+--R                        - 18940A a b   + 31929A B a b  - 17889A B a b
+--R                      + 
+--R                             3 5 7
+--R                        3330B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   12        2   2 11          2 3 10       3 4 9
+--R                  (2425A a b   - 4260A B a b   + 2493A B a b   - 486B a b )c
+--R                + 
+--R                        3 14       2     13         2 2 12      3 3 11
+--R                  - 125A b   + 225A B a b   - 135A B a b   + 27B a b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       4 6 6
+--R                                - 2401A a c
+--R                              + 
+--R                                       4 5 2         3   6         2 2 7  5
+--R                                (24108A a b  - 18228A B a b + 2450A B a )c
+--R                              + 
+--R                                            4 4 4          3   5 3
+--R                                    - 76686A a b  + 109544A B a b
+--R                                  + 
+--R                                            2 2 6 2          3 7        4 8
+--R                                    - 51894A B a b  + 9300A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                          4 3 6          3   4 5
+--R                                    83630A a b  - 154848A B a b
+--R                                  + 
+--R                                           2 2 5 4           3 6 3        4 7 2
+--R                                    102672A B a b  - 28172A B a b  + 2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                            4 2 8         3   3 7
+--R                                    - 39525A a b  + 84780A B a b
+--R                                  + 
+--R                                          2 2 4 6           3 5 5        4 6 4
+--R                                  - 67524A B a b  + 23616A B a b  - 3051B a b
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   10         3   2 9         2 2 3 8
+--R                                    8250A a b   - 19100A B a b  + 16560A B a b
+--R                                  + 
+--R                                             3 4 7       4 5 6
+--R                                    - 6372A B a b  + 918B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                      4 12        3     11        2 2 2 10
+--R                                - 625A b   + 1500A B a b   - 1350A B a b
+--R                              + 
+--R                                      3 3 9      4 4 8
+--R                                540A B a b  - 81B a b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             2 4            5  4
+--R                       (1260A a b - 560A B a )c
+--R                     + 
+--R                               2 3 3            4 2       2 5   3
+--R                       (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1386A a b  - 1470A B a b  + 385B a b )c
+--R                     + 
+--R                              2   7           2 6       2 3 5        2 9
+--R                       (- 315A a b  + 364A B a b  - 105B a b )c + 25A b
+--R                     + 
+--R                                  8     2 2 7
+--R                       - 30A B a b  + 9B a b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 4 8            4 3 2         3   4   7
+--R                  9604A a c  + (- 50421A a b  + 28812A B a b)c
+--R                + 
+--R                            4 2 4        3   3 3         2 2 4 2           3 5
+--R                      43410A a b  - 4343A B a b  - 43524A B a b  + 22500A B a b
+--R                    + 
+--R                             4 6
+--R                      - 2500B a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                              4   6         3   2 5         2 2 3 4
+--R                      - 12325A a b  - 20190A B a b  + 52821A B a b
+--R                    + 
+--R                                3 4 3        4 5 2
+--R                      - 31137A B a b  + 5625B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4 8        3     7         2 2 2 6           3 3 5
+--R                      1125A b  + 8325A B a b  - 16680A B a b  + 10053A B a b
+--R                    + 
+--R                             4 4 4
+--R                      - 1971B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3   9        2 2   8         3 2 7       4 3 6  3
+--R                  (- 875A B b  + 1575A B a b  - 945A B a b  + 189B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            4     3 2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                4 6 6
+--R                         - 2401A a c
+--R                       + 
+--R                                4 5 2         3   6         2 2 7  5
+--R                         (24108A a b  - 18228A B a b + 2450A B a )c
+--R                       + 
+--R                                     4 4 4          3   5 3         2 2 6 2
+--R                             - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                           + 
+--R                                    3 7        4 8
+--R                             9300A B a b - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                   4 3 6          3   4 5          2 2 5 4
+--R                             83630A a b  - 154848A B a b  + 102672A B a b
+--R                           + 
+--R                                       3 6 3        4 7 2
+--R                             - 28172A B a b  + 2550B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                                     4 2 8         3   3 7         2 2 4 6
+--R                             - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                           + 
+--R                                     3 5 5        4 6 4
+--R                             23616A B a b  - 3051B a b
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   10         3   2 9         2 2 3 8
+--R                             8250A a b   - 19100A B a b  + 16560A B a b
+--R                           + 
+--R                                      3 4 7       4 5 6
+--R                             - 6372A B a b  + 918B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                               4 12        3     11        2 2 2 10
+--R                         - 625A b   + 1500A B a b   - 1350A B a b
+--R                       + 
+--R                               3 3 9      4 4 8
+--R                         540A B a b  - 81B a b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      2 4            5  4
+--R                (1260A a b - 560A B a )c
+--R              + 
+--R                        2 3 3            4 2       2 5   3
+--R                (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1386A a b  - 1470A B a b  + 385B a b )c
+--R              + 
+--R                       2   7           2 6       2 3 5        2 9            8
+--R                (- 315A a b  + 364A B a b  - 105B a b )c + 25A b  - 30A B a b
+--R              + 
+--R                  2 2 7
+--R                9B a b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               12            13  5
+--R                      (53248A a  b - 20480B a  )c
+--R                    + 
+--R                                 11 3           12 2  4
+--R                      (- 74752A a  b  + 34816B a  b )c
+--R                    + 
+--R                               10 5           11 4  3
+--R                      (41216A a  b  - 21504B a  b )c
+--R                    + 
+--R                                 9 7          10 6  2
+--R                      (- 11200A a b  + 6272B a  b )c
+--R                    + 
+--R                              8 9         9 8          7 11        8 10
+--R                      (1504A a b  - 880B a b )c - 80A a b   + 48B a b
+--R                 *
+--R                    ROOT
+--R                                  4 6 6
+--R                           - 2401A a c
+--R                         + 
+--R                                  4 5 2         3   6         2 2 7  5
+--R                           (24108A a b  - 18228A B a b + 2450A B a )c
+--R                         + 
+--R                                       4 4 4          3   5 3         2 2 6 2
+--R                               - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                             + 
+--R                                      3 7        4 8
+--R                               9300A B a b - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                     4 3 6          3   4 5          2 2 5 4
+--R                               83630A a b  - 154848A B a b  + 102672A B a b
+--R                             + 
+--R                                         3 6 3        4 7 2
+--R                               - 28172A B a b  + 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                       4 2 8         3   3 7         2 2 4 6
+--R                               - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                             + 
+--R                                       3 5 5        4 6 4
+--R                               23616A B a b  - 3051B a b
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   10         3   2 9         2 2 3 8
+--R                               8250A a b   - 19100A B a b  + 16560A B a b
+--R                             + 
+--R                                        3 4 7       4 5 6
+--R                               - 6372A B a b  + 918B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                 4 12        3     11        2 2 2 10
+--R                           - 625A b   + 1500A B a b   - 1350A B a b
+--R                         + 
+--R                                 3 3 9      4 4 8
+--R                           540A B a b  - 81B a b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          3 7 7          3 6 2         2   7           2 8  6
+--R                  - 10976A a c  + (79408A a b  - 51856A B a b + 5600A B a )c
+--R                + 
+--R                                 3 5 4          2   6 3           2 7 2
+--R                        - 172990A a b  + 192088A B a b  - 62512A B a b
+--R                      + 
+--R                             3 8
+--R                        5200B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                               3 4 6          2   5 5            2 6 4
+--R                        160932A a b  - 224705A B a b  + 101006A B a b
+--R                      + 
+--R                                3 7 3
+--R                        - 14408B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                3 3 8          2   4 7           2 5 6
+--R                        - 75579A a b  + 118937A B a b  - 61740A B a b
+--R                      + 
+--R                              3 6 5
+--R                        10549B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3 2 10         2   3 9           2 4 8        3 5 7  2
+--R                  (18940A a b   - 31929A B a b  + 17889A B a b  - 3330B a b )c
+--R                + 
+--R                          3   12        2   2 11          2 3 10       3 4 9
+--R                  (- 2425A a b   + 4260A B a b   - 2493A B a b   + 486B a b )c
+--R                + 
+--R                      3 14       2     13         2 2 12      3 3 11
+--R                  125A b   - 225A B a b   + 135A B a b   - 27B a b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       4 6 6
+--R                                - 2401A a c
+--R                              + 
+--R                                       4 5 2         3   6         2 2 7  5
+--R                                (24108A a b  - 18228A B a b + 2450A B a )c
+--R                              + 
+--R                                            4 4 4          3   5 3
+--R                                    - 76686A a b  + 109544A B a b
+--R                                  + 
+--R                                            2 2 6 2          3 7        4 8
+--R                                    - 51894A B a b  + 9300A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                          4 3 6          3   4 5
+--R                                    83630A a b  - 154848A B a b
+--R                                  + 
+--R                                           2 2 5 4           3 6 3        4 7 2
+--R                                    102672A B a b  - 28172A B a b  + 2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                            4 2 8         3   3 7
+--R                                    - 39525A a b  + 84780A B a b
+--R                                  + 
+--R                                          2 2 4 6           3 5 5        4 6 4
+--R                                  - 67524A B a b  + 23616A B a b  - 3051B a b
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   10         3   2 9         2 2 3 8
+--R                                    8250A a b   - 19100A B a b  + 16560A B a b
+--R                                  + 
+--R                                             3 4 7       4 5 6
+--R                                    - 6372A B a b  + 918B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                      4 12        3     11        2 2 2 10
+--R                                - 625A b   + 1500A B a b   - 1350A B a b
+--R                              + 
+--R                                      3 3 9      4 4 8
+--R                                540A B a b  - 81B a b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             2 4            5  4
+--R                       (1260A a b - 560A B a )c
+--R                     + 
+--R                               2 3 3            4 2       2 5   3
+--R                       (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1386A a b  - 1470A B a b  + 385B a b )c
+--R                     + 
+--R                              2   7           2 6       2 3 5        2 9
+--R                       (- 315A a b  + 364A B a b  - 105B a b )c + 25A b
+--R                     + 
+--R                                  8     2 2 7
+--R                       - 30A B a b  + 9B a b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 4 8            4 3 2         3   4   7
+--R                  9604A a c  + (- 50421A a b  + 28812A B a b)c
+--R                + 
+--R                            4 2 4        3   3 3         2 2 4 2           3 5
+--R                      43410A a b  - 4343A B a b  - 43524A B a b  + 22500A B a b
+--R                    + 
+--R                             4 6
+--R                      - 2500B a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                              4   6         3   2 5         2 2 3 4
+--R                      - 12325A a b  - 20190A B a b  + 52821A B a b
+--R                    + 
+--R                                3 4 3        4 5 2
+--R                      - 31137A B a b  + 5625B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4 8        3     7         2 2 2 6           3 3 5
+--R                      1125A b  + 8325A B a b  - 16680A B a b  + 10053A B a b
+--R                    + 
+--R                             4 4 4
+--R                      - 1971B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3   9        2 2   8         3 2 7       4 3 6  3
+--R                  (- 875A B b  + 1575A B a b  - 945A B a b  + 189B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              4     3 2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                4 6 6
+--R                         - 2401A a c
+--R                       + 
+--R                                4 5 2         3   6         2 2 7  5
+--R                         (24108A a b  - 18228A B a b + 2450A B a )c
+--R                       + 
+--R                                     4 4 4          3   5 3         2 2 6 2
+--R                             - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                           + 
+--R                                    3 7        4 8
+--R                             9300A B a b - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                   4 3 6          3   4 5          2 2 5 4
+--R                             83630A a b  - 154848A B a b  + 102672A B a b
+--R                           + 
+--R                                       3 6 3        4 7 2
+--R                             - 28172A B a b  + 2550B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                                     4 2 8         3   3 7         2 2 4 6
+--R                             - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                           + 
+--R                                     3 5 5        4 6 4
+--R                             23616A B a b  - 3051B a b
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   10         3   2 9         2 2 3 8
+--R                             8250A a b   - 19100A B a b  + 16560A B a b
+--R                           + 
+--R                                      3 4 7       4 5 6
+--R                             - 6372A B a b  + 918B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                               4 12        3     11        2 2 2 10
+--R                         - 625A b   + 1500A B a b   - 1350A B a b
+--R                       + 
+--R                               3 3 9      4 4 8
+--R                         540A B a b  - 81B a b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      2 4            5  4
+--R                (1260A a b - 560A B a )c
+--R              + 
+--R                        2 3 3            4 2       2 5   3
+--R                (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1386A a b  - 1470A B a b  + 385B a b )c
+--R              + 
+--R                       2   7           2 6       2 3 5        2 9            8
+--R                (- 315A a b  + 364A B a b  - 105B a b )c + 25A b  - 30A B a b
+--R              + 
+--R                  2 2 7
+--R                9B a b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 12            13  5
+--R                      (- 53248A a  b + 20480B a  )c
+--R                    + 
+--R                               11 3           12 2  4
+--R                      (74752A a  b  - 34816B a  b )c
+--R                    + 
+--R                                 10 5           11 4  3
+--R                      (- 41216A a  b  + 21504B a  b )c
+--R                    + 
+--R                               9 7          10 6  2
+--R                      (11200A a b  - 6272B a  b )c
+--R                    + 
+--R                                8 9         9 8          7 11        8 10
+--R                      (- 1504A a b  + 880B a b )c + 80A a b   - 48B a b
+--R                 *
+--R                    ROOT
+--R                                  4 6 6
+--R                           - 2401A a c
+--R                         + 
+--R                                  4 5 2         3   6         2 2 7  5
+--R                           (24108A a b  - 18228A B a b + 2450A B a )c
+--R                         + 
+--R                                       4 4 4          3   5 3         2 2 6 2
+--R                               - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                             + 
+--R                                      3 7        4 8
+--R                               9300A B a b - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                     4 3 6          3   4 5          2 2 5 4
+--R                               83630A a b  - 154848A B a b  + 102672A B a b
+--R                             + 
+--R                                         3 6 3        4 7 2
+--R                               - 28172A B a b  + 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                       4 2 8         3   3 7         2 2 4 6
+--R                               - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                             + 
+--R                                       3 5 5        4 6 4
+--R                               23616A B a b  - 3051B a b
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   10         3   2 9         2 2 3 8
+--R                               8250A a b   - 19100A B a b  + 16560A B a b
+--R                             + 
+--R                                        3 4 7       4 5 6
+--R                               - 6372A B a b  + 918B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                 4 12        3     11        2 2 2 10
+--R                           - 625A b   + 1500A B a b   - 1350A B a b
+--R                         + 
+--R                                 3 3 9      4 4 8
+--R                           540A B a b  - 81B a b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        3 7 7            3 6 2         2   7           2 8  6
+--R                  10976A a c  + (- 79408A a b  + 51856A B a b - 5600A B a )c
+--R                + 
+--R                          3 5 4          2   6 3           2 7 2        3 8   5
+--R                  (172990A a b  - 192088A B a b  + 62512A B a b  - 5200B a b)c
+--R                + 
+--R                               3 4 6          2   5 5            2 6 4
+--R                      - 160932A a b  + 224705A B a b  - 101006A B a b
+--R                    + 
+--R                            3 7 3
+--R                      14408B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 3 8          2   4 7           2 5 6         3 6 5  3
+--R                  (75579A a b  - 118937A B a b  + 61740A B a b  - 10549B a b )c
+--R                + 
+--R                                3 2 10         2   3 9           2 4 8
+--R                        - 18940A a b   + 31929A B a b  - 17889A B a b
+--R                      + 
+--R                             3 5 7
+--R                        3330B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   12        2   2 11          2 3 10       3 4 9
+--R                  (2425A a b   - 4260A B a b   + 2493A B a b   - 486B a b )c
+--R                + 
+--R                        3 14       2     13         2 2 12      3 3 11
+--R                  - 125A b   + 225A B a b   - 135A B a b   + 27B a b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       4 6 6
+--R                                - 2401A a c
+--R                              + 
+--R                                       4 5 2         3   6         2 2 7  5
+--R                                (24108A a b  - 18228A B a b + 2450A B a )c
+--R                              + 
+--R                                            4 4 4          3   5 3
+--R                                    - 76686A a b  + 109544A B a b
+--R                                  + 
+--R                                            2 2 6 2          3 7        4 8
+--R                                    - 51894A B a b  + 9300A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                          4 3 6          3   4 5
+--R                                    83630A a b  - 154848A B a b
+--R                                  + 
+--R                                           2 2 5 4           3 6 3        4 7 2
+--R                                    102672A B a b  - 28172A B a b  + 2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                            4 2 8         3   3 7
+--R                                    - 39525A a b  + 84780A B a b
+--R                                  + 
+--R                                          2 2 4 6           3 5 5        4 6 4
+--R                                  - 67524A B a b  + 23616A B a b  - 3051B a b
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   10         3   2 9         2 2 3 8
+--R                                    8250A a b   - 19100A B a b  + 16560A B a b
+--R                                  + 
+--R                                             3 4 7       4 5 6
+--R                                    - 6372A B a b  + 918B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                      4 12        3     11        2 2 2 10
+--R                                - 625A b   + 1500A B a b   - 1350A B a b
+--R                              + 
+--R                                      3 3 9      4 4 8
+--R                                540A B a b  - 81B a b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             2 4            5  4
+--R                       (1260A a b - 560A B a )c
+--R                     + 
+--R                               2 3 3            4 2       2 5   3
+--R                       (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1386A a b  - 1470A B a b  + 385B a b )c
+--R                     + 
+--R                              2   7           2 6       2 3 5        2 9
+--R                       (- 315A a b  + 364A B a b  - 105B a b )c + 25A b
+--R                     + 
+--R                                  8     2 2 7
+--R                       - 30A B a b  + 9B a b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 4 8            4 3 2         3   4   7
+--R                  9604A a c  + (- 50421A a b  + 28812A B a b)c
+--R                + 
+--R                            4 2 4        3   3 3         2 2 4 2           3 5
+--R                      43410A a b  - 4343A B a b  - 43524A B a b  + 22500A B a b
+--R                    + 
+--R                             4 6
+--R                      - 2500B a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                              4   6         3   2 5         2 2 3 4
+--R                      - 12325A a b  - 20190A B a b  + 52821A B a b
+--R                    + 
+--R                                3 4 3        4 5 2
+--R                      - 31137A B a b  + 5625B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4 8        3     7         2 2 2 6           3 3 5
+--R                      1125A b  + 8325A B a b  - 16680A B a b  + 10053A B a b
+--R                    + 
+--R                             4 4 4
+--R                      - 1971B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3   9        2 2   8         3 2 7       4 3 6  3
+--R                  (- 875A B b  + 1575A B a b  - 945A B a b  + 189B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            4     3 2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                4 6 6
+--R                         - 2401A a c
+--R                       + 
+--R                                4 5 2         3   6         2 2 7  5
+--R                         (24108A a b  - 18228A B a b + 2450A B a )c
+--R                       + 
+--R                                     4 4 4          3   5 3         2 2 6 2
+--R                             - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                           + 
+--R                                    3 7        4 8
+--R                             9300A B a b - 625B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                   4 3 6          3   4 5          2 2 5 4
+--R                             83630A a b  - 154848A B a b  + 102672A B a b
+--R                           + 
+--R                                       3 6 3        4 7 2
+--R                             - 28172A B a b  + 2550B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                                     4 2 8         3   3 7         2 2 4 6
+--R                             - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                           + 
+--R                                     3 5 5        4 6 4
+--R                             23616A B a b  - 3051B a b
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   10         3   2 9         2 2 3 8
+--R                             8250A a b   - 19100A B a b  + 16560A B a b
+--R                           + 
+--R                                      3 4 7       4 5 6
+--R                             - 6372A B a b  + 918B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                               4 12        3     11        2 2 2 10
+--R                         - 625A b   + 1500A B a b   - 1350A B a b
+--R                       + 
+--R                               3 3 9      4 4 8
+--R                         540A B a b  - 81B a b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      2 4            5  4
+--R                (1260A a b - 560A B a )c
+--R              + 
+--R                        2 3 3            4 2       2 5   3
+--R                (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1386A a b  - 1470A B a b  + 385B a b )c
+--R              + 
+--R                       2   7           2 6       2 3 5        2 9            8
+--R                (- 315A a b  + 364A B a b  - 105B a b )c + 25A b  - 30A B a b
+--R              + 
+--R                  2 2 7
+--R                9B a b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 12            13  5
+--R                      (- 53248A a  b + 20480B a  )c
+--R                    + 
+--R                               11 3           12 2  4
+--R                      (74752A a  b  - 34816B a  b )c
+--R                    + 
+--R                                 10 5           11 4  3
+--R                      (- 41216A a  b  + 21504B a  b )c
+--R                    + 
+--R                               9 7          10 6  2
+--R                      (11200A a b  - 6272B a  b )c
+--R                    + 
+--R                                8 9         9 8          7 11        8 10
+--R                      (- 1504A a b  + 880B a b )c + 80A a b   - 48B a b
+--R                 *
+--R                    ROOT
+--R                                  4 6 6
+--R                           - 2401A a c
+--R                         + 
+--R                                  4 5 2         3   6         2 2 7  5
+--R                           (24108A a b  - 18228A B a b + 2450A B a )c
+--R                         + 
+--R                                       4 4 4          3   5 3         2 2 6 2
+--R                               - 76686A a b  + 109544A B a b  - 51894A B a b
+--R                             + 
+--R                                      3 7        4 8
+--R                               9300A B a b - 625B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                     4 3 6          3   4 5          2 2 5 4
+--R                               83630A a b  - 154848A B a b  + 102672A B a b
+--R                             + 
+--R                                         3 6 3        4 7 2
+--R                               - 28172A B a b  + 2550B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                       4 2 8         3   3 7         2 2 4 6
+--R                               - 39525A a b  + 84780A B a b  - 67524A B a b
+--R                             + 
+--R                                       3 5 5        4 6 4
+--R                               23616A B a b  - 3051B a b
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   10         3   2 9         2 2 3 8
+--R                               8250A a b   - 19100A B a b  + 16560A B a b
+--R                             + 
+--R                                        3 4 7       4 5 6
+--R                               - 6372A B a b  + 918B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                 4 12        3     11        2 2 2 10
+--R                           - 625A b   + 1500A B a b   - 1350A B a b
+--R                         + 
+--R                                 3 3 9      4 4 8
+--R                           540A B a b  - 81B a b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          3 7 7          3 6 2         2   7           2 8  6
+--R                  - 10976A a c  + (79408A a b  - 51856A B a b + 5600A B a )c
+--R                + 
+--R                                 3 5 4          2   6 3           2 7 2
+--R                        - 172990A a b  + 192088A B a b  - 62512A B a b
+--R                      + 
+--R                             3 8
+--R                        5200B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                               3 4 6          2   5 5            2 6 4
+--R                        160932A a b  - 224705A B a b  + 101006A B a b
+--R                      + 
+--R                                3 7 3
+--R                        - 14408B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                3 3 8          2   4 7           2 5 6
+--R                        - 75579A a b  + 118937A B a b  - 61740A B a b
+--R                      + 
+--R                              3 6 5
+--R                        10549B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3 2 10         2   3 9           2 4 8        3 5 7  2
+--R                  (18940A a b   - 31929A B a b  + 17889A B a b  - 3330B a b )c
+--R                + 
+--R                          3   12        2   2 11          2 3 10       3 4 9
+--R                  (- 2425A a b   + 4260A B a b   - 2493A B a b   + 486B a b )c
+--R                + 
+--R                      3 14       2     13         2 2 12      3 3 11
+--R                  125A b   - 225A B a b   + 135A B a b   - 27B a b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       4 6 6
+--R                                - 2401A a c
+--R                              + 
+--R                                       4 5 2         3   6         2 2 7  5
+--R                                (24108A a b  - 18228A B a b + 2450A B a )c
+--R                              + 
+--R                                            4 4 4          3   5 3
+--R                                    - 76686A a b  + 109544A B a b
+--R                                  + 
+--R                                            2 2 6 2          3 7        4 8
+--R                                    - 51894A B a b  + 9300A B a b - 625B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                          4 3 6          3   4 5
+--R                                    83630A a b  - 154848A B a b
+--R                                  + 
+--R                                           2 2 5 4           3 6 3        4 7 2
+--R                                    102672A B a b  - 28172A B a b  + 2550B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                            4 2 8         3   3 7
+--R                                    - 39525A a b  + 84780A B a b
+--R                                  + 
+--R                                          2 2 4 6           3 5 5        4 6 4
+--R                                  - 67524A B a b  + 23616A B a b  - 3051B a b
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   10         3   2 9         2 2 3 8
+--R                                    8250A a b   - 19100A B a b  + 16560A B a b
+--R                                  + 
+--R                                             3 4 7       4 5 6
+--R                                    - 6372A B a b  + 918B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                      4 12        3     11        2 2 2 10
+--R                                - 625A b   + 1500A B a b   - 1350A B a b
+--R                              + 
+--R                                      3 3 9      4 4 8
+--R                                540A B a b  - 81B a b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             2 4            5  4
+--R                       (1260A a b - 560A B a )c
+--R                     + 
+--R                               2 3 3            4 2       2 5   3
+--R                       (- 2415A a b  + 2100A B a b  - 420B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1386A a b  - 1470A B a b  + 385B a b )c
+--R                     + 
+--R                              2   7           2 6       2 3 5        2 9
+--R                       (- 315A a b  + 364A B a b  - 105B a b )c + 25A b
+--R                     + 
+--R                                  8     2 2 7
+--R                       - 30A B a b  + 9B a b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                       4 4 8            4 3 2         3   4   7
+--R                  9604A a c  + (- 50421A a b  + 28812A B a b)c
+--R                + 
+--R                            4 2 4        3   3 3         2 2 4 2           3 5
+--R                      43410A a b  - 4343A B a b  - 43524A B a b  + 22500A B a b
+--R                    + 
+--R                             4 6
+--R                      - 2500B a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                              4   6         3   2 5         2 2 3 4
+--R                      - 12325A a b  - 20190A B a b  + 52821A B a b
+--R                    + 
+--R                                3 4 3        4 5 2
+--R                      - 31137A B a b  + 5625B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4 8        3     7         2 2 2 6           3 3 5
+--R                      1125A b  + 8325A B a b  - 16680A B a b  + 10053A B a b
+--R                    + 
+--R                             4 4 4
+--R                      - 1971B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3   9        2 2   8         3 2 7       4 3 6  3
+--R                  (- 875A B b  + 1575A B a b  - 945A B a b  + 189B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                                     +-----------+
+--R                              2         3         2  |          2         2 2
+--R           ((- 19A a b + 10B a )c + 5A b  - 3B a b )\|- 4a c + b   + 28A a c
+--R         + 
+--R                     2        2          4         3
+--R           (- 29A a b  + 16B a b)c + 5A b  - 3B a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                                     +-----------+
+--R                              2         3         2  |          2         2 2
+--R           ((- 19A a b + 10B a )c + 5A b  - 3B a b )\|- 4a c + b   - 28A a c
+--R         + 
+--R                   2        2          4         3
+--R           (29A a b  - 16B a b)c - 5A b  + 3B a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R          4      3 2  +-+ |          2  |   |          2
+--R       (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2245
+
+--S 2246 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2246
+
+)clear all
+
+--S 2247 of 3139
+t0:=x^11*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        13      11
+--R     B x   + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2247
+
+--S 2248 of 3139
+r0:=1/2*(3*b^4*B-A*b^3*c-21*a*b^2*B*c+7*a*A*b*c^2+30*a^2*B*c^2)*x^2/_
+   (c^3*(b^2-4*a*c)^2)-1/4*(3*b^3*B-A*b^2*c-18*a*b*B*c+16*a*A*c^2)*_
+   x^4/(c^2*(b^2-4*a*c)^2)+1/2*(b^2*B+3*A*b*c-10*a*B*c)*x^6/(c*(b^2-_
+   4*a*c)^2)-1/4*x^10*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4)^2)-1/4*x^8*(5*A*b^2-6*a*b*B-8*a*A*c+2*(b^2*B+3*A*b*c-_
+   10*a*B*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))-1/2*(3*b^6*B-_
+   A*b^5*c-30*a*b^4*B*c+10*a*A*b^3*c^2+90*a^2*b^2*B*c^2-_
+   30*a^2*A*b*c^3-60*a^3*B*c^3)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c^4*(b^2-4*a*c)^(5/2))-1/4*(3*b*B-A*c)*log(a+b*x^2+c*x^4)/c^4
+--R 
+--R
+--R   (2)
+--R                     2          3  5             3         2 2  4
+--R               (60A a b + 120B a )c  + (- 20A a b  - 180B a b )c
+--R             + 
+--R                    5          4  3       6 2
+--R               (2A b  + 60B a b )c  - 6B b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      2 2         3   4             4         2 3  3
+--R               (120A a b  + 240B a b)c  + (- 40A a b  - 360B a b )c
+--R             + 
+--R                    6           5  2        7
+--R               (4A b  + 120B a b )c  - 12B b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      3          4  4         2 3         3 2  3
+--R               (120A a b + 240B a )c  + (20A a b  - 240B a b )c
+--R             + 
+--R                         5        2 4  2        7          6         8
+--R               (- 16A a b  - 60B a b )c  + (2A b  + 48B a b )c - 6B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      3 2         4   3           2 4         3 3  2
+--R               (120A a b  + 240B a b)c  + (- 40A a b  - 360B a b )c
+--R             + 
+--R                      6         2 5            7
+--R               (4A a b  + 120B a b )c - 12B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                 4          5  3           3 3         4 2  2
+--R           (60A a b + 120B a )c  + (- 20A a b  - 180B a b )c
+--R         + 
+--R                2 5        3 4         2 6
+--R           (2A a b  + 60B a b )c - 6B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                        2 5            2        2   4       4          3  3
+--R                   16A a c  + (- 8A a b  - 48B a b)c  + (A b  + 24B a b )c
+--R                 + 
+--R                         5 2
+--R                   - 3B b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                        2   4             3        2 2  3        5          4  2
+--R                   32A a b c  + (- 16A a b  - 96B a b )c  + (2A b  + 48B a b )c
+--R                 + 
+--R                         6
+--R                   - 6B b c
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          3 4        3   3         4 2       6          5
+--R                     32A a c  - 96B a b c  - 6A a b c  + (A b  + 18B a b )c
+--R                   + 
+--R                           7
+--R                     - 3B b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        3   3           2 3        3 2  2
+--R                   32A a b c  + (- 16A a b  - 96B a b )c
+--R                 + 
+--R                          5        2 4           6
+--R                   (2A a b  + 48B a b )c - 6B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                  4 3          3 2        4   2       2 4        3 3         2 5
+--R             16A a c  + (- 8A a b  - 48B a b)c  + (A a b  + 24B a b )c - 3B a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                 2 5          2 4       4 3  10
+--R           (32B a c  - 16B a b c  + 2B b c )x
+--R         + 
+--R                      2 5           2         2   4          4          3  3
+--R               - 24A a c  + (21A a b  + 122B a b)c  + (- 3A b  - 68B a b )c
+--R             + 
+--R                   5 2
+--R               9B b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    2          3  4           3        2 2  3
+--R               (2A a b + 100B a )c  + (12A a b  + 14B a b )c
+--R             + 
+--R                      5          4  2       6
+--R               (- 2A b  - 36B a b )c  + 6B b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      3 4         2 2         3   3            4        2 3  2
+--R               - 16A a c  + (29A a b  + 138B a b)c  + (- 4A a b  - 87B a b )c
+--R             + 
+--R                      5
+--R               12B a b c
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                  3         4  3          2 3        3 2  2       2 4   2
+--R           ((14A a b + 60B a )c  + (- 2A a b  - 42B a b )c  + 6B a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 8        2 7     4 6  8        2   7        3 6     5 5  6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R       + 
+--R              3 7        4 5     6 4  4        3   6      2 3 5       5 4  2
+--R         (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R       + 
+--R            4 6      3 2 5     2 4 4
+--R         64a c  - 32a b c  + 4a b c
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2248
+
+--S 2249 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       2         3  5             3        2 2  4
+--R                 (30A a b + 60B a )c  + (- 10A a b  - 90B a b )c
+--R               + 
+--R                     5          4  3       6 2
+--R                 (A b  + 30B a b )c  - 3B b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                       2 2         3   4             4         2 3  3
+--R                 (60A a b  + 120B a b)c  + (- 20A a b  - 180B a b )c
+--R               + 
+--R                      6          5  2       7
+--R                 (2A b  + 60B a b )c  - 6B b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                       3          4  4         2 3         3 2  3
+--R                 (60A a b + 120B a )c  + (10A a b  - 120B a b )c
+--R               + 
+--R                          5        2 4  2       7          6         8
+--R                 (- 8A a b  - 30B a b )c  + (A b  + 24B a b )c - 3B b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       3 2         4   3           2 4         3 3  2
+--R                 (60A a b  + 120B a b)c  + (- 20A a b  - 180B a b )c
+--R               + 
+--R                        6        2 5           7
+--R                 (2A a b  + 60B a b )c - 6B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                   4         5  3           3 3        4 2  2
+--R             (30A a b + 60B a )c  + (- 10A a b  - 90B a b )c
+--R           + 
+--R                 2 5        3 4         2 6
+--R             (A a b  + 30B a b )c - 3B a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                          2 5            2        2   4       4          3  3
+--R                     16A a c  + (- 8A a b  - 48B a b)c  + (A b  + 24B a b )c
+--R                   + 
+--R                           5 2
+--R                     - 3B b c
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                          2   4             3        2 2  3
+--R                     32A a b c  + (- 16A a b  - 96B a b )c
+--R                   + 
+--R                          5          4  2       6
+--R                     (2A b  + 48B a b )c  - 6B b c
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                          3 4        3   3         4 2       6          5
+--R                     32A a c  - 96B a b c  - 6A a b c  + (A b  + 18B a b )c
+--R                   + 
+--R                           7
+--R                     - 3B b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                          3   3           2 3        3 2  2
+--R                     32A a b c  + (- 16A a b  - 96B a b )c
+--R                   + 
+--R                            5        2 4           6
+--R                     (2A a b  + 48B a b )c - 6B a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                      4 3          3 2        4   2       2 4        3 3
+--R                 16A a c  + (- 8A a b  - 48B a b)c  + (A a b  + 24B a b )c
+--R               + 
+--R                       2 5
+--R                 - 3B a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                   2 5          2 4       4 3  10
+--R             (32B a c  - 16B a b c  + 2B b c )x
+--R           + 
+--R                   2   4          3 3       5 2  8
+--R             (64B a b c  - 32B a b c  + 4B b c )x
+--R           + 
+--R                       2          3  4             3         2 2  3
+--R                 (50A a b + 100B a )c  + (- 30A a b  - 102B a b )c
+--R               + 
+--R                      5          4  2       6
+--R                 (4A b  + 36B a b )c  - 4B b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                      3 4         2 2        3   3             4        2 3  2
+--R                 32A a c  + (11A a b  + 22B a b)c  + (- 19A a b  - 73B a b )c
+--R               + 
+--R                      6          5         7
+--R                 (3A b  + 38B a b )c - 5B b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       3         4  3           2 3         3 2  2
+--R                 (62A a b + 60B a )c  + (- 44A a b  - 158B a b )c
+--R               + 
+--R                        5        2 4            6
+--R                 (6A a b  + 78B a b )c - 10B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                4 3           3 2        4   2        2 4        3 3         2 5
+--R           24A a c  + (- 21A a b  - 58B a b)c  + (3A a b  + 36B a b )c - 5B a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 8        2 7     4 6  8        2   7        3 6     5 5  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 7        4 5     6 4  4        3   6      2 3 5       5 4  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 6      3 2 5     2 4 4
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                         2          3  5           3         2 2  4
+--R                 (- 60A a b - 120B a )c  + (20A a b  + 180B a b )c
+--R               + 
+--R                        5          4  3       6 2
+--R                 (- 2A b  - 60B a b )c  + 6B b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          2 2         3   4           4         2 3  3
+--R                 (- 120A a b  - 240B a b)c  + (40A a b  + 360B a b )c
+--R               + 
+--R                        6           5  2        7
+--R                 (- 4A b  - 120B a b )c  + 12B b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          3          4  4           2 3         3 2  3
+--R                 (- 120A a b - 240B a )c  + (- 20A a b  + 240B a b )c
+--R               + 
+--R                         5        2 4  2          7          6         8
+--R                 (16A a b  + 60B a b )c  + (- 2A b  - 48B a b )c + 6B b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          3 2         4   3         2 4         3 3  2
+--R                 (- 120A a b  - 240B a b)c  + (40A a b  + 360B a b )c
+--R               + 
+--R                          6         2 5            7
+--R                 (- 4A a b  - 120B a b )c + 12B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4          5  3         3 3         4 2  2
+--R             (- 60A a b - 120B a )c  + (20A a b  + 180B a b )c
+--R           + 
+--R                    2 5        3 4         2 6
+--R             (- 2A a b  - 60B a b )c + 6B a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                          2 5            2        2   4       4          3  3
+--R                     16A a c  + (- 8A a b  - 48B a b)c  + (A b  + 24B a b )c
+--R                   + 
+--R                           5 2
+--R                     - 3B b c
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                          2   4             3        2 2  3
+--R                     32A a b c  + (- 16A a b  - 96B a b )c
+--R                   + 
+--R                          5          4  2       6
+--R                     (2A b  + 48B a b )c  - 6B b c
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                          3 4        3   3         4 2       6          5
+--R                     32A a c  - 96B a b c  - 6A a b c  + (A b  + 18B a b )c
+--R                   + 
+--R                           7
+--R                     - 3B b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                          3   3           2 3        3 2  2
+--R                     32A a b c  + (- 16A a b  - 96B a b )c
+--R                   + 
+--R                            5        2 4           6
+--R                     (2A a b  + 48B a b )c - 6B a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                      4 3          3 2        4   2       2 4        3 3
+--R                 16A a c  + (- 8A a b  - 48B a b)c  + (A a b  + 24B a b )c
+--R               + 
+--R                       2 5
+--R                 - 3B a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                   2 5          2 4       4 3  10
+--R             (32B a c  - 16B a b c  + 2B b c )x
+--R           + 
+--R                   2   4          3 3       5 2  8
+--R             (64B a b c  - 32B a b c  + 4B b c )x
+--R           + 
+--R                       2          3  4             3         2 2  3
+--R                 (50A a b + 100B a )c  + (- 30A a b  - 102B a b )c
+--R               + 
+--R                      5          4  2       6
+--R                 (4A b  + 36B a b )c  - 4B b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                      3 4         2 2        3   3             4        2 3  2
+--R                 32A a c  + (11A a b  + 22B a b)c  + (- 19A a b  - 73B a b )c
+--R               + 
+--R                      6          5         7
+--R                 (3A b  + 38B a b )c - 5B b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       3         4  3           2 3         3 2  2
+--R                 (62A a b + 60B a )c  + (- 44A a b  - 158B a b )c
+--R               + 
+--R                        5        2 4            6
+--R                 (6A a b  + 78B a b )c - 10B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                4 3           3 2        4   2        2 4        3 3         2 5
+--R           24A a c  + (- 21A a b  - 58B a b)c  + (3A a b  + 36B a b )c - 5B a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 8        2 7     4 6  8        2   7        3 6     5 5  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 7        4 5     6 4  4        3   6      2 3 5       5 4  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 6      3 2 5     2 4 4
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2249
+
+--S 2250 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 2         3  3             3        2 2  2       5          4
+--R           (30A a b + 60B a )c  + (- 10A a b  - 90B a b )c  + (A b  + 30B a b )c
+--R         + 
+--R                 6
+--R           - 3B b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                   2          3  3           3         2 2  2
+--R           (- 60A a b - 120B a )c  + (20A a b  + 180B a b )c
+--R         + 
+--R                  5          4         6
+--R           (- 2A b  - 60B a b )c + 6B b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R               2 3             2        2   2        4          3         5
+--R         (24A a c  + (- 21A a b  - 58B a b)c  + (3A b  + 36B a b )c - 5B b )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                 +-----------+
+--R         2 6        2 5     4 4  |          2
+--R     (64a c  - 32a b c  + 4b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2250
+
+--S 2251 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2251
+
+--S 2252 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                   2          3  3           3         2 2  2
+--R           (- 60A a b - 120B a )c  + (20A a b  + 180B a b )c
+--R         + 
+--R                  5          4         6
+--R           (- 2A b  - 60B a b )c + 6B b
+--R      *
+--R          +---------+             2
+--R          |        2          2c x  + b
+--R         \|4a c - b  atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                   2          3  3           3         2 2  2
+--R           (- 60A a b - 120B a )c  + (20A a b  + 180B a b )c
+--R         + 
+--R                  5          4         6
+--R           (- 2A b  - 60B a b )c + 6B b
+--R      *
+--R                                        +---------+
+--R          +-----------+          2      |        2
+--R          |          2      (2c x  + b)\|4a c - b
+--R         \|- 4a c + b  atan(-----------------------)
+--R                                           2
+--R                                   4a c - b
+--R     + 
+--R               2 3             2        2   2        4          3         5
+--R         (24A a c  + (- 21A a b  - 58B a b)c  + (3A b  + 36B a b )c - 5B b )
+--R      *
+--R          +-----------+ +---------+
+--R          |          2  |        2
+--R         \|- 4a c + b  \|4a c - b
+--R  /
+--R                                 +-----------+ +---------+
+--R         2 6        2 5     4 4  |          2  |        2
+--R     (64a c  - 32a b c  + 4b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2252
+
+--S 2253 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2253
+
+)clear all
+
+--S 2254 of 3139
+t0:=x^9*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        11      9
+--R     B x   + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2254
+
+--S 2255 of 3139
+r0:=-1/2*(b^3*B-7*a*b*B*c+6*a*A*c^2)*x^2/(c^2*(b^2-4*a*c)^2)+_
+   1/4*(b^2*B+6*A*b*c-16*a*B*c)*x^4/(c*(b^2-4*a*c)^2)-1/4*x^8*(A*b-2*a*B-_
+   (b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-1/4*x^6*(2*(2*A*b^2-_
+   3*a*b*B-2*a*A*c)+(b^2*B+6*A*b*c-16*a*B*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+_
+   c*x^4))+1/2*(b^5*B-10*a*b^3*B*c+30*a^2*b*B*c^2-12*a^2*A*c^3)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^3*(b^2-4*a*c)^(5/2))+_
+   1/4*B*log(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R                   2 5        2   4          3 3       5 2  8
+--R           (- 24A a c  + 60B a b c  - 20B a b c  + 2B b c )x
+--R         + 
+--R                   2   4         2 2 3          4 2       6   6
+--R           (- 48A a b c  + 120B a b c  - 40B a b c  + 4B b c)x
+--R         + 
+--R                      3 4           2 2         3   3        2 3 2          5
+--R               - 48A a c  + (- 24A a b  + 120B a b)c  + 20B a b c  - 16B a b c
+--R             + 
+--R                   7
+--R               2B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   3   3         3 2 2        2 4          6  2        4 3
+--R           (- 48A a b c  + 120B a b c  - 40B a b c + 4B a b )x  - 24A a c
+--R         + 
+--R                4   2        3 3        2 5
+--R           60B a b c  - 20B a b c + 2B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2 4         2 3      4 2  8
+--R               (16B a c  - 8B a b c  + B b c )x
+--R             + 
+--R                     2   3          3 2       5   6
+--R               (32B a b c  - 16B a b c  + 2B b c)x
+--R             + 
+--R                     3 3         4       6  4
+--R               (32B a c  - 6B a b c + B b )x
+--R             + 
+--R                   3   2        2 3          5  2        4 2       3 2       2 4
+--R             (32B a b c  - 16B a b c + 2B a b )x  + 16B a c  - 8B a b c + B a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                              2  4       3          2  3       4 2  8
+--R           ((- 10A a b - 24B a )c  + (A b  + 21B a b )c  - 3B b c )x
+--R         + 
+--R                   2 4            2       2   3          3 2       5   6
+--R           (- 20A a c  + (- 4A a b  + 2B a b)c  + 12B a b c  - 2B b c)x
+--R         + 
+--R                    2         3  3        2 2 2         4   4
+--R           ((- 18A a b - 16B a )c  + 29B a b c  - 4B a b c)x
+--R         + 
+--R                   3 3        3   2       2 3   2
+--R           (- 12A a c  + 14B a b c  - 2B a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 7        2 6     4 5  8        2   6        3 5     5 4  6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R       + 
+--R              3 6        4 4     6 3  4        3   5      2 3 4       5 3  2
+--R         (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R       + 
+--R            4 5      3 2 4     2 4 3
+--R         64a c  - 32a b c  + 4a b c
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2255
+
+--S 2256 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2 5        2   4          3 3      5 2  8
+--R             (12A a c  - 30B a b c  + 10B a b c  - B b c )x
+--R           + 
+--R                   2   4        2 2 3          4 2       6   6
+--R             (24A a b c  - 60B a b c  + 20B a b c  - 2B b c)x
+--R           + 
+--R                        3 4         2 2        3   3        2 3 2         5
+--R                   24A a c  + (12A a b  - 60B a b)c  - 10B a b c  + 8B a b c
+--R                 + 
+--R                        7
+--R                   - B b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                   3   3        3 2 2        2 4          6  2        4 3
+--R             (24A a b c  - 60B a b c  + 20B a b c - 2B a b )x  + 12A a c
+--R           + 
+--R                    4   2        3 3       2 5
+--R             - 30B a b c  + 10B a b c - B a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                       2 4         2 3      4 2  8
+--R                 (16B a c  - 8B a b c  + B b c )x
+--R               + 
+--R                       2   3          3 2       5   6
+--R                 (32B a b c  - 16B a b c  + 2B b c)x
+--R               + 
+--R                       3 3         4       6  4
+--R                 (32B a c  - 6B a b c + B b )x
+--R               + 
+--R                       3   2        2 3          5  2        4 2       3 2
+--R                 (32B a b c  - 16B a b c + 2B a b )x  + 16B a c  - 8B a b c
+--R               + 
+--R                    2 4
+--R                 B a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                        2 4           2        2   3          4          3  2
+--R                 - 20A a c  + (16A a b  + 50B a b)c  + (- 2A b  - 30B a b )c
+--R               + 
+--R                     5
+--R                 4B b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                      2         3  3          3        2 2  2
+--R                 (2A a b + 32B a )c  + (8A a b  + 11B a b )c
+--R               + 
+--R                       5          4         6
+--R                 (- A b  - 19B a b )c + 3B b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        3 3         2 2        3   2            4        2 3
+--R                 - 12A a c  + (20A a b  + 62B a b)c  + (- 2A a b  - 44B a b )c
+--R               + 
+--R                       5
+--R                 6B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                   3         4  2         2 3        3 2         2 4
+--R             (10A a b + 24B a )c  + (- A a b  - 21B a b )c + 3B a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 7        2 6     4 5  8        2   6        3 5     5 4  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 6        4 4     6 3  4        3   5      2 3 4       5 3  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 5      3 2 4     2 4 3
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2 5        2   4          3 3       5 2  8
+--R             (24A a c  - 60B a b c  + 20B a b c  - 2B b c )x
+--R           + 
+--R                   2   4         2 2 3          4 2       6   6
+--R             (48A a b c  - 120B a b c  + 40B a b c  - 4B b c)x
+--R           + 
+--R                      3 4         2 2         3   3        2 3 2          5
+--R                 48A a c  + (24A a b  - 120B a b)c  - 20B a b c  + 16B a b c
+--R               + 
+--R                       7
+--R                 - 2B b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                   3   3         3 2 2        2 4          6  2        4 3
+--R             (48A a b c  - 120B a b c  + 40B a b c - 4B a b )x  + 24A a c
+--R           + 
+--R                    4   2        3 3        2 5
+--R             - 60B a b c  + 20B a b c - 2B a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2 4         2 3      4 2  8
+--R                 (16B a c  - 8B a b c  + B b c )x
+--R               + 
+--R                       2   3          3 2       5   6
+--R                 (32B a b c  - 16B a b c  + 2B b c)x
+--R               + 
+--R                       3 3         4       6  4
+--R                 (32B a c  - 6B a b c + B b )x
+--R               + 
+--R                       3   2        2 3          5  2        4 2       3 2
+--R                 (32B a b c  - 16B a b c + 2B a b )x  + 16B a c  - 8B a b c
+--R               + 
+--R                    2 4
+--R                 B a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                        2 4           2        2   3          4          3  2
+--R                 - 20A a c  + (16A a b  + 50B a b)c  + (- 2A b  - 30B a b )c
+--R               + 
+--R                     5
+--R                 4B b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                      2         3  3          3        2 2  2
+--R                 (2A a b + 32B a )c  + (8A a b  + 11B a b )c
+--R               + 
+--R                       5          4         6
+--R                 (- A b  - 19B a b )c + 3B b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        3 3         2 2        3   2            4        2 3
+--R                 - 12A a c  + (20A a b  + 62B a b)c  + (- 2A a b  - 44B a b )c
+--R               + 
+--R                       5
+--R                 6B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                   3         4  2         2 3        3 2         2 4
+--R             (10A a b + 24B a )c  + (- A a b  - 21B a b )c + 3B a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 7        2 6     4 5  8        2   6        3 5     5 4  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 6        4 4     6 3  4        3   5      2 3 4       5 3  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 5      3 2 4     2 4 3
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2256
+
+--S 2257 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               2 3        2   2          3       5
+--R         (12A a c  - 30B a b c  + 10B a b c - B b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                                               2
+--R             2 3        2   2          3        5          2c x  + b
+--R       (24A a c  - 60B a b c  + 20B a b c - 2B b )atanh(--------------)
+--R                                                         +-----------+
+--R                                                         |          2
+--R                                                        \|- 4a c + b
+--R     + 
+--R                                                             +-----------+
+--R                        2  2         3          2         4  |          2
+--R       ((10A a b + 24B a )c  + (- A b  - 21B a b )c + 3B b )\|- 4a c + b
+--R  /
+--R                                 +-----------+
+--R         2 5        2 4     4 3  |          2
+--R     (64a c  - 32a b c  + 4b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2257
+
+--S 2258 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2258
+
+--S 2259 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                     +---------+
+--R               2 3        2   2          3        5  |        2
+--R         (24A a c  - 60B a b c  + 20B a b c - 2B b )\|4a c - b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R               2 3        2   2          3        5  |          2
+--R         (24A a c  - 60B a b c  + 20B a b c - 2B b )\|- 4a c + b
+--R      *
+--R                          +---------+
+--R                   2      |        2
+--R              (2c x  + b)\|4a c - b
+--R         atan(-----------------------)
+--R                             2
+--R                     4a c - b
+--R     + 
+--R                                                               +-----------+
+--R                          2  2         3          2         4  |          2
+--R         ((10A a b + 24B a )c  + (- A b  - 21B a b )c + 3B b )\|- 4a c + b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R  /
+--R                                 +-----------+ +---------+
+--R         2 5        2 4     4 3  |          2  |        2
+--R     (64a c  - 32a b c  + 4b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2259
+
+--S 2260 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2260
+
+)clear all
+
+--S 2261 of 3139
+t0:=x^7*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        9      7
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2261
+
+--S 2262 of 3139
+r0:=-1/4*x^6*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   3/4*(A*b-2*a*B)*x^2*(2*a+b*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+_
+   3*a*(A*b-2*a*B)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                           2  2 8           2        2     6
+--R           (12A a b - 24B a )c x  + (24A a b  - 48B a b)c x
+--R         + 
+--R                  2         3            3        2 2  4
+--R           ((24A a b - 48B a )c + 12A a b  - 24B a b )x
+--R         + 
+--R                 2 2        3   2        3         4
+--R           (24A a b  - 48B a b)x  + 12A a b - 24B a
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                  2       2                  3  8
+--R           (8A a c  + (A b  - 10B a b)c + B b )x
+--R         + 
+--R                            2         3         2  6          2        2   4
+--R           ((10A a b - 20B a )c + 2A b  - 4B a b )x  + (9A a b  - 18B a b)x
+--R         + 
+--R                2         3  2
+--R           (6A a b - 12B a )x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2262
+
+--S 2263 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            2  4 8           2        2   3 6
+--R             (6A a b - 12B a )c x  + (12A a b  - 24B a b)c x
+--R           + 
+--R                    2         3  3          3        2 2  2  4
+--R             ((12A a b - 24B a )c  + (6A a b  - 12B a b )c )x
+--R           + 
+--R                   2 2        3   2 2        3         4  2
+--R             (12A a b  - 24B a b)c x  + (6A a b - 12B a )c
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                               2  3          2 2       4   6
+--R             ((- 6A a b - 20B a )c  + 16B a b c  - 2B b c)x
+--R           + 
+--R                     2 3           2       2   2         4         3        5  4
+--R             (- 16A a c  + (- A a b  + 2B a b)c  + (- A b  + 8B a b )c - B b )x
+--R           + 
+--R                      2         3  2            3        2 2           4  2
+--R             ((- 10A a b - 12B a )c  + (- 2A a b  + 20B a b )c - 2B a b )x
+--R           + 
+--R                   3 2         2 2        3         2 3
+--R             - 8A a c  + (- A a b  + 10B a b)c - B a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 6        2 5     4 4  8        2   5        3 4     5 3  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 5        4 3     6 2  4        3   4      2 3 3       5 2  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 4      3 2 3     2 4 2
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                               2  4 8             2        2   3 6
+--R             (- 12A a b + 24B a )c x  + (- 24A a b  + 48B a b)c x
+--R           + 
+--R                      2         3  3             3        2 2  2  4
+--R             ((- 24A a b + 48B a )c  + (- 12A a b  + 24B a b )c )x
+--R           + 
+--R                     2 2        3   2 2           3         4  2
+--R             (- 24A a b  + 48B a b)c x  + (- 12A a b + 24B a )c
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                               2  3          2 2       4   6
+--R             ((- 6A a b - 20B a )c  + 16B a b c  - 2B b c)x
+--R           + 
+--R                     2 3           2       2   2         4         3        5  4
+--R             (- 16A a c  + (- A a b  + 2B a b)c  + (- A b  + 8B a b )c - B b )x
+--R           + 
+--R                      2         3  2            3        2 2           4  2
+--R             ((- 10A a b - 12B a )c  + (- 2A a b  + 20B a b )c - 2B a b )x
+--R           + 
+--R                   3 2         2 2        3         2 3
+--R             - 8A a c  + (- A a b  + 10B a b)c - B a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 6        2 5     4 4  8        2   5        3 4     5 3  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 5        4 3     6 2  4        3   4      2 3 3       5 2  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 4      3 2 3     2 4 2
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2263
+
+--S 2264 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        2  2
+--R         (6A a b - 12B a )c
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                          2
+--R                         2  2         2c x  + b
+--R       (- 12A a b + 24B a )c atanh(--------------)
+--R                                    +-----------+
+--R                                    |          2
+--R                                   \|- 4a c + b
+--R     + 
+--R                                                +-----------+
+--R                2         2                  3  |          2
+--R       (- 8A a c  + (- A b  + 10B a b)c - B b )\|- 4a c + b
+--R  /
+--R                                 +-----------+
+--R         2 4        2 3     4 2  |          2
+--R     (64a c  - 32a b c  + 4b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2264
+
+--S 2265 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2265
+
+--S 2266 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                              +---------+             2
+--R                         2  2 |        2          2c x  + b
+--R       (- 12A a b + 24B a )c \|4a c - b  atanh(--------------)
+--R                                                +-----------+
+--R                                                |          2
+--R                                               \|- 4a c + b
+--R     + 
+--R                                                            +---------+
+--R                              +-----------+          2      |        2
+--R                         2  2 |          2      (2c x  + b)\|4a c - b
+--R       (- 12A a b + 24B a )c \|- 4a c + b  atan(-----------------------)
+--R                                                               2
+--R                                                       4a c - b
+--R     + 
+--R                                                +-----------+ +---------+
+--R                2         2                  3  |          2  |        2
+--R       (- 8A a c  + (- A b  + 10B a b)c - B b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                                 +-----------+ +---------+
+--R         2 4        2 3     4 2  |          2  |        2
+--R     (64a c  - 32a b c  + 4b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2266
+
+--S 2267 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2267
+
+)clear all
+
+--S 2268 of 3139
+t0:=x^5*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        7      5
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2268
+
+--S 2269 of 3139
+r0:=-1/4*x^4*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/4*(2*a+b*x^2)*(2*(A*b-2*a*B)+(b*B-2*A*c)*x^2)/((b^2-4*a*c)^2*_
+   (a+b*x^2+c*x^4))+(3*a*b*B-A*(b^2+2*a*c))*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                    3          2            2  8
+--R           (- 8A a c  + (- 4A b  + 12B a b)c )x
+--R         + 
+--R                       2          3          2    6
+--R           (- 16A a b c  + (- 8A b  + 24B a b )c)x
+--R         + 
+--R                   2 2             2        2          4          3  4
+--R           (- 16A a c  + (- 16A a b  + 24B a b)c - 4A b  + 12B a b )x
+--R         + 
+--R                   2            3        2 2  2       3        2 2        3
+--R           (- 16A a b c - 8A a b  + 24B a b )x  - 8A a c - 4A a b  + 12B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                    2      2   8          2          2                  3  6
+--R           (- 2A b c  + B b c)x  + (4A a c  + (- 2A b  - 6B a b)c + 2B b )x
+--R         + 
+--R                           2        3        2  4
+--R           ((2A a b - 16B a )c + A b  + B a b )x
+--R         + 
+--R                  2          2        2   2       2        3
+--R           (- 4A a c + 6A a b  - 10B a b)x  + 4A a b - 8B a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2269
+
+--S 2270 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    4        2           3  8
+--R             (4A a c  + (2A b  - 6B a b)c )x
+--R           + 
+--R                      3        3          2  2  6
+--R             (8A a b c  + (4A b  - 12B a b )c )x
+--R           + 
+--R                  2 3          2        2   2        4         3    4
+--R             (8A a c  + (8A a b  - 12B a b)c  + (2A b  - 6B a b )c)x
+--R           + 
+--R                2   2          3        2 2    2       3 2        2 2       3
+--R           (8A a b c  + (4A a b  - 12B a b )c)x  + 4A a c  + (2A a b  - 6B a b)c
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                    3        2           2  6
+--R             (4A a c  + (2A b  - 6B a b)c )x
+--R           + 
+--R                             2  2        3        2        4  4
+--R             ((6A a b - 16B a )c  + (3A b  - B a b )c - B b )x
+--R           + 
+--R                    2 2           2        2            3  2        2        3
+--R             (- 4A a c  + (10A a b  - 10B a b)c - 2B a b )x  + (6A a b - 8B a )c
+--R           + 
+--R                  2 2
+--R             - B a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 5        2 4     4 3  8        2   4        3 3     5 2  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 4        4 2     6   4        3   3      2 3 2       5   2
+--R           (128a c  - 24a b c  + 4b c)x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R              4 3      3 2 2     2 4
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    4        2            3  8
+--R             (8A a c  + (4A b  - 12B a b)c )x
+--R           + 
+--R                       3        3          2  2  6
+--R             (16A a b c  + (8A b  - 24B a b )c )x
+--R           + 
+--R                   2 3           2        2   2        4          3    4
+--R             (16A a c  + (16A a b  - 24B a b)c  + (4A b  - 12B a b )c)x
+--R           + 
+--R                   2   2          3        2 2    2       3 2
+--R             (16A a b c  + (8A a b  - 24B a b )c)x  + 8A a c
+--R           + 
+--R                  2 2        3
+--R             (4A a b  - 12B a b)c
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                    3        2           2  6
+--R             (4A a c  + (2A b  - 6B a b)c )x
+--R           + 
+--R                             2  2        3        2        4  4
+--R             ((6A a b - 16B a )c  + (3A b  - B a b )c - B b )x
+--R           + 
+--R                    2 2           2        2            3  2        2        3
+--R             (- 4A a c  + (10A a b  - 10B a b)c - 2B a b )x  + (6A a b - 8B a )c
+--R           + 
+--R                  2 2
+--R             - B a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 5        2 4     4 3  8        2   4        3 3     5 2  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 4        4 2     6   4        3   3      2 3 2       5   2
+--R           (128a c  - 24a b c  + 4b c)x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R              4 3      3 2 2     2 4
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2270
+
+--S 2271 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                2        2
+--R         (4A a c  + (2A b  - 6B a b)c)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                                  2
+--R              2        2                      2c x  + b
+--R       (8A a c  + (4A b  - 12B a b)c)atanh(--------------)
+--R                                            +-----------+
+--R                                            |          2
+--R                                           \|- 4a c + b
+--R     + 
+--R                       +-----------+
+--R                    2  |          2
+--R       (2A b c - B b )\|- 4a c + b
+--R  /
+--R                                +-----------+
+--R         2 3        2 2     4   |          2
+--R     (64a c  - 32a b c  + 4b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2271
+
+--S 2272 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2272
+
+--S 2273 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                      +---------+             2
+--R              2        2              |        2          2c x  + b
+--R       (8A a c  + (4A b  - 12B a b)c)\|4a c - b  atanh(--------------)
+--R                                                        +-----------+
+--R                                                        |          2
+--R                                                       \|- 4a c + b
+--R     + 
+--R                                                                    +---------+
+--R                                      +-----------+          2      |        2
+--R              2        2              |          2      (2c x  + b)\|4a c - b
+--R       (8A a c  + (4A b  - 12B a b)c)\|- 4a c + b  atan(-----------------------)
+--R                                                                       2
+--R                                                               4a c - b
+--R     + 
+--R                       +-----------+ +---------+
+--R                    2  |          2  |        2
+--R       (2A b c - B b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                                +-----------+ +---------+
+--R         2 3        2 2     4   |          2  |        2
+--R     (64a c  - 32a b c  + 4b c)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2273
+
+--S 2274 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2274
+
+)clear all
+
+--S 2275 of 3139
+t0:=x^3*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        5      3
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2275
+
+--S 2276 of 3139
+r0:=1/4*(2*a+b*x^2)*(A+B*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/4*(-3*b*(A*b-2*a*B)+2*(b^2*B-3*A*b*c+2*a*B*c)*x^2)/((b^2-4*a*c)^2*_
+   (a+b*x^2+c*x^4))-(b^2*B-3*A*b*c+2*a*B*c)*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                           3       2 2  8          2            2       3   6
+--R           ((12A b - 8B a)c  - 4B b c )x  + ((24A b  - 16B a b)c  - 8B b c)x
+--R         + 
+--R                            2  2         3          2         4  4
+--R           ((24A a b - 16B a )c  + (12A b  - 16B a b )c - 4B b )x
+--R         + 
+--R                    2        2            3  2         2        3         2 2
+--R           ((24A a b  - 16B a b)c - 8B a b )x  + (12A a b - 8B a )c - 4B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                            2       2   6           2                  3  4
+--R           ((- 6A b + 4B a)c  + 2B b c)x  + ((- 9A b  + 6B a b)c + 3B b )x
+--R         + 
+--R                           2         3          2  2       2         2       2
+--R         ((- 10A a b - 4B a )c - 2A b  + 10B a b )x  - 8A a c - A a b  + 6B a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2276
+
+--S 2277 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            3       2 2  8          2           2       3   6
+--R             ((6A b - 4B a)c  - 2B b c )x  + ((12A b  - 8B a b)c  - 4B b c)x
+--R           + 
+--R                             2  2        3         2         4  4
+--R             ((12A a b - 8B a )c  + (6A b  - 8B a b )c - 2B b )x
+--R           + 
+--R                      2       2            3  2        2        3         2 2
+--R             ((12A a b  - 8B a b)c - 4B a b )x  + (6A a b - 4B a )c - 2B a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                              2       2   6           2                  3  4
+--R             ((- 6A b + 4B a)c  + 2B b c)x  + ((- 9A b  + 6B a b)c + 3B b )x
+--R           + 
+--R                               2         3          2  2       2         2
+--R             ((- 10A a b - 4B a )c - 2A b  + 10B a b )x  - 8A a c - A a b
+--R           + 
+--R                 2
+--R             6B a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                               3       2 2  8
+--R             ((- 12A b + 8B a)c  + 4B b c )x
+--R           + 
+--R                      2            2       3   6
+--R             ((- 24A b  + 16B a b)c  + 8B b c)x
+--R           + 
+--R                                2  2           3          2         4  4
+--R             ((- 24A a b + 16B a )c  + (- 12A b  + 16B a b )c + 4B b )x
+--R           + 
+--R                        2        2            3  2           2        3
+--R             ((- 24A a b  + 16B a b)c + 8B a b )x  + (- 12A a b + 8B a )c
+--R           + 
+--R                 2 2
+--R             4B a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                              2       2   6           2                  3  4
+--R             ((- 6A b + 4B a)c  + 2B b c)x  + ((- 9A b  + 6B a b)c + 3B b )x
+--R           + 
+--R                               2         3          2  2       2         2
+--R             ((- 10A a b - 4B a )c - 2A b  + 10B a b )x  - 8A a c - A a b
+--R           + 
+--R                 2
+--R             6B a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2277
+
+--S 2278 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                              2
+--R         ((3A b - 2B a)c - B b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                              2
+--R                               2          2c x  + b
+--R       ((- 6A b + 4B a)c + 2B b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R                              +-----------+
+--R         2 2        2      4  |          2
+--R     (32a c  - 16a b c + 2b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2278
+
+--S 2279 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2279
+
+--S 2280 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                 +---------+             2
+--R                              2  |        2          2c x  + b
+--R       ((- 3A b + 2B a)c + B b )\|4a c - b  atanh(--------------)
+--R                                                   +-----------+
+--R                                                   |          2
+--R                                                  \|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R                                 +-----------+          2      |        2
+--R                              2  |          2      (2c x  + b)\|4a c - b
+--R       ((- 3A b + 2B a)c + B b )\|- 4a c + b  atan(-----------------------)
+--R                                                                  2
+--R                                                          4a c - b
+--R  /
+--R                            +-----------+ +---------+
+--R         2 2       2     4  |          2  |        2
+--R     (16a c  - 8a b c + b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2280
+
+--S 2281 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2281
+
+)clear all
+
+--S 2282 of 3139
+t0:=x*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2282
+
+--S 2283 of 3139
+r0:=1/4*(-A*b+2*a*B+(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-_
+   3/4*(b*B-2*A*c)*(b+2*c*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+_
+   3*c*(b*B-2*A*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                   4          3  8             3        2 2  6
+--R           (- 24A c  + 12B b c )x  + (- 48A b c  + 24B b c )x
+--R         + 
+--R                     3           2            2        3   4
+--R           (- 48A a c  + (- 24A b  + 24B a b)c  + 12B b c)x
+--R         + 
+--R                       2          2   2        2 2        2
+--R           (- 48A a b c  + 24B a b c)x  - 24A a c  + 12B a b c
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 3         2  6           2       2   4
+--R           (12A c  - 6B b c )x  + (18A b c  - 9B b c)x
+--R         + 
+--R                   2        2                   3  2                  2        3
+--R           (20A a c  + (4A b  - 10B a b)c - 2B b )x  + (10A a b - 8B a )c - A b
+--R         + 
+--R                  2
+--R           - B a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2283
+
+--S 2284 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   4         3  8           3        2 2  6
+--R             (12A c  - 6B b c )x  + (24A b c  - 12B b c )x
+--R           + 
+--R                     3         2            2       3   4
+--R             (24A a c  + (12A b  - 12B a b)c  - 6B b c)x
+--R           + 
+--R                       2          2   2        2 2       2
+--R             (24A a b c  - 12B a b c)x  + 12A a c  - 6B a b c
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                   3         2  6           2       2   4
+--R             (12A c  - 6B b c )x  + (18A b c  - 9B b c)x
+--R           + 
+--R                     2        2                   3  2                  2
+--R             (20A a c  + (4A b  - 10B a b)c - 2B b )x  + (10A a b - 8B a )c
+--R           + 
+--R                  3        2
+--R             - A b  - B a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   4          3  8           3        2 2  6
+--R             (24A c  - 12B b c )x  + (48A b c  - 24B b c )x
+--R           + 
+--R                     3         2            2        3   4
+--R             (48A a c  + (24A b  - 24B a b)c  - 12B b c)x
+--R           + 
+--R                       2          2   2        2 2        2
+--R             (48A a b c  - 24B a b c)x  + 24A a c  - 12B a b c
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                   3         2  6           2       2   4
+--R             (12A c  - 6B b c )x  + (18A b c  - 9B b c)x
+--R           + 
+--R                     2        2                   3  2                  2
+--R             (20A a c  + (4A b  - 10B a b)c - 2B b )x  + (10A a b - 8B a )c
+--R           + 
+--R                  3        2
+--R             - A b  - B a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2284
+
+--S 2285 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2
+--R         (6A c  - 3B b c)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                     2
+--R             2                   2c x  + b
+--R       (12A c  - 6B b c)atanh(--------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                              +-----------+
+--R         2 2        2      4  |          2
+--R     (32a c  - 16a b c + 2b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2285
+
+--S 2286 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2286
+
+--S 2287 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        +---------+             2
+--R            2           |        2          2c x  + b
+--R       (6A c  - 3B b c)\|4a c - b  atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R     + 
+--R                                                      +---------+
+--R                        +-----------+          2      |        2
+--R            2           |          2      (2c x  + b)\|4a c - b
+--R       (6A c  - 3B b c)\|- 4a c + b  atan(-----------------------)
+--R                                                         2
+--R                                                 4a c - b
+--R  /
+--R                            +-----------+ +---------+
+--R         2 2       2     4  |          2  |        2
+--R     (16a c  - 8a b c + b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2287
+
+--S 2288 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2288
+
+)clear all
+
+--S 2289 of 3139
+t0:=(A+B*x^2)/(x*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R        2
+--R     B x  + A
+--R  /
+--R        3 13       2 11        2     2   9              3  7      2        2  5
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   3    3
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2289
+
+--S 2290 of 3139
+r0:=1/4*(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+   (a+b*x^2+c*x^4)^2)+1/4*(6*a^2*b*B*c+A*(2*b^4-15*a*b^2*c+16*a^2*c^2)+_
+   2*c*(6*a^2*B*c+A*(b^3-7*a*b*c))*x^2)/(a^2*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))-_
+   1/2*(12*a^3*B*c^2-A*(b^5-10*a*b^3*c+30*a^2*b*c^2))*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(5/2))+A*log(x)/a^3-_
+   1/4*A*log(a+b*x^2+c*x^4)/a^3
+--R 
+--R
+--R   (2)
+--R                  2         3  4          3 3       5 2  8
+--R           ((60A a b - 24B a )c  - 20A a b c  + 2A b c )x
+--R         + 
+--R                   2 2        3   3          4 2       6   6
+--R           ((120A a b  - 48B a b)c  - 40A a b c  + 4A b c)x
+--R         + 
+--R                        3         4  3         2 3        3 2  2          5
+--R                 (120A a b - 48B a )c  + (20A a b  - 24B a b )c  - 16A a b c
+--R               + 
+--R                     7
+--R                 2A b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   3 2        4   2        2 4          6  2
+--R           ((120A a b  - 48B a b)c  - 40A a b c + 4A a b )x
+--R         + 
+--R                 4         5  2        3 3        2 5
+--R           (60A a b - 24B a )c  - 20A a b c + 2A a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                       2 4         2 3      4 2  8
+--R               (- 16A a c  + 8A a b c  - A b c )x
+--R             + 
+--R                       2   3          3 2       5   6
+--R               (- 32A a b c  + 16A a b c  - 2A b c)x
+--R             + 
+--R                       3 3         4       6  4
+--R               (- 32A a c  + 6A a b c - A b )x
+--R             + 
+--R                       3   2        2 3          5  2        4 2       3 2
+--R               (- 32A a b c  + 16A a b c - 2A a b )x  - 16A a c  + 8A a b c
+--R             + 
+--R                    2 4
+--R               - A a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                     2 4          2 3       4 2  8
+--R               (64A a c  - 32A a b c  + 4A b c )x
+--R             + 
+--R                      2   3          3 2       5   6
+--R               (128A a b c  - 64A a b c  + 8A b c)x
+--R             + 
+--R                      3 3          4        6  4
+--R               (128A a c  - 24A a b c + 4A b )x
+--R             + 
+--R                      3   2        2 3          5  2        4 2        3 2
+--R               (128A a b c  - 64A a b c + 8A a b )x  + 64A a c  - 32A a b c
+--R             + 
+--R                   2 4
+--R               4A a b
+--R          *
+--R             log(x)
+--R         + 
+--R                    2         3  3         3 2  6
+--R           ((- 14A a b + 12B a )c  + 2A a b c )x
+--R         + 
+--R                 3 3           2 2        3   2         4   4
+--R           (16A a c  + (- 29A a b  + 18B a b)c  + 4A a b c)x
+--R         + 
+--R                   3         4  2           2 3       3 2           5  2
+--R           ((- 2A a b + 20B a )c  + (- 12A a b  + 4B a b )c + 2A a b )x
+--R         + 
+--R                4 2           3 2        4          2 4      3 3
+--R           24A a c  + (- 21A a b  + 10B a b)c + 3A a b  - B a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R         (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R       + 
+--R              6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R         (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R       + 
+--R            7 2      6 2      5 4
+--R         64a c  - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2290
+
+--S 2291 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2         3  4          3 3      5 2  8
+--R             ((30A a b - 12B a )c  - 10A a b c  + A b c )x
+--R           + 
+--R                    2 2        3   3          4 2       6   6
+--R             ((60A a b  - 24B a b)c  - 20A a b c  + 2A b c)x
+--R           + 
+--R                         3         4  3         2 3        3 2  2         5
+--R                   (60A a b - 24B a )c  + (10A a b  - 12B a b )c  - 8A a b c
+--R                 + 
+--R                      7
+--R                   A b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                    3 2        4   2        2 4          6  2
+--R             ((60A a b  - 24B a b)c  - 20A a b c + 2A a b )x
+--R           + 
+--R                   4         5  2        3 3       2 5
+--R             (30A a b - 12B a )c  - 10A a b c + A a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                         2 4         2 3      4 2  8
+--R                 (- 16A a c  + 8A a b c  - A b c )x
+--R               + 
+--R                         2   3          3 2       5   6
+--R                 (- 32A a b c  + 16A a b c  - 2A b c)x
+--R               + 
+--R                         3 3         4       6  4
+--R                 (- 32A a c  + 6A a b c - A b )x
+--R               + 
+--R                         3   2        2 3          5  2        4 2       3 2
+--R                 (- 32A a b c  + 16A a b c - 2A a b )x  - 16A a c  + 8A a b c
+--R               + 
+--R                      2 4
+--R                 - A a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                       2 4          2 3       4 2  8
+--R                 (64A a c  - 32A a b c  + 4A b c )x
+--R               + 
+--R                        2   3          3 2       5   6
+--R                 (128A a b c  - 64A a b c  + 8A b c)x
+--R               + 
+--R                        3 3          4        6  4
+--R                 (128A a c  - 24A a b c + 4A b )x
+--R               + 
+--R                        3   2        2 3          5  2        4 2        3 2
+--R                 (128A a b c  - 64A a b c + 8A a b )x  + 64A a c  - 32A a b c
+--R               + 
+--R                     2 4
+--R                 4A a b
+--R            *
+--R               log(x)
+--R           + 
+--R                      2         3  3         3 2  6
+--R             ((- 14A a b + 12B a )c  + 2A a b c )x
+--R           + 
+--R                   3 3           2 2        3   2         4   4
+--R             (16A a c  + (- 29A a b  + 18B a b)c  + 4A a b c)x
+--R           + 
+--R                     3         4  2           2 3       3 2           5  2
+--R             ((- 2A a b + 20B a )c  + (- 12A a b  + 4B a b )c + 2A a b )x
+--R           + 
+--R                  4 2           3 2        4          2 4      3 3
+--R             24A a c  + (- 21A a b  + 10B a b)c + 3A a b  - B a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              7 2      6 2      5 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                      2         3  4          3 3       5 2  8
+--R             ((- 60A a b + 24B a )c  + 20A a b c  - 2A b c )x
+--R           + 
+--R                       2 2        3   3          4 2       6   6
+--R             ((- 120A a b  + 48B a b)c  + 40A a b c  - 4A b c)x
+--R           + 
+--R                          3         4  3           2 3        3 2  2          5
+--R                 (- 120A a b + 48B a )c  + (- 20A a b  + 24B a b )c  + 16A a b c
+--R               + 
+--R                       7
+--R                 - 2A b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       3 2        4   2        2 4          6  2
+--R             ((- 120A a b  + 48B a b)c  + 40A a b c - 4A a b )x
+--R           + 
+--R                     4         5  2        3 3        2 5
+--R             (- 60A a b + 24B a )c  + 20A a b c - 2A a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                         2 4         2 3      4 2  8
+--R                 (- 16A a c  + 8A a b c  - A b c )x
+--R               + 
+--R                         2   3          3 2       5   6
+--R                 (- 32A a b c  + 16A a b c  - 2A b c)x
+--R               + 
+--R                         3 3         4       6  4
+--R                 (- 32A a c  + 6A a b c - A b )x
+--R               + 
+--R                         3   2        2 3          5  2        4 2       3 2
+--R                 (- 32A a b c  + 16A a b c - 2A a b )x  - 16A a c  + 8A a b c
+--R               + 
+--R                      2 4
+--R                 - A a b
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                       2 4          2 3       4 2  8
+--R                 (64A a c  - 32A a b c  + 4A b c )x
+--R               + 
+--R                        2   3          3 2       5   6
+--R                 (128A a b c  - 64A a b c  + 8A b c)x
+--R               + 
+--R                        3 3          4        6  4
+--R                 (128A a c  - 24A a b c + 4A b )x
+--R               + 
+--R                        3   2        2 3          5  2        4 2        3 2
+--R                 (128A a b c  - 64A a b c + 8A a b )x  + 64A a c  - 32A a b c
+--R               + 
+--R                     2 4
+--R                 4A a b
+--R            *
+--R               log(x)
+--R           + 
+--R                      2         3  3         3 2  6
+--R             ((- 14A a b + 12B a )c  + 2A a b c )x
+--R           + 
+--R                   3 3           2 2        3   2         4   4
+--R             (16A a c  + (- 29A a b  + 18B a b)c  + 4A a b c)x
+--R           + 
+--R                     3         4  2           2 3       3 2           5  2
+--R             ((- 2A a b + 20B a )c  + (- 12A a b  + 4B a b )c + 2A a b )x
+--R           + 
+--R                  4 2           3 2        4          2 4      3 3
+--R             24A a c  + (- 21A a b  + 10B a b)c + 3A a b  - B a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              7 2      6 2      5 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2291
+
+--S 2292 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                2         3  2          3       5
+--R         ((30A a b - 12B a )c  - 10A a b c + A b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                                                2
+--R                2         3  2          3        5          2c x  + b
+--R       ((- 60A a b + 24B a )c  + 20A a b c - 2A b )atanh(--------------)
+--R                                                          +-----------+
+--R                                                          |          2
+--R                                                         \|- 4a c + b
+--R  /
+--R                                +-----------+
+--R         5 2      4 2      3 4  |          2
+--R     (64a c  - 32a b c + 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2292
+
+--S 2293 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2293
+
+--S 2294 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                     +---------+
+--R                  2         3  2          3       5  |        2
+--R         ((- 30A a b + 12B a )c  + 10A a b c - A b )\|4a c - b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R                  2         3  2          3       5  |          2
+--R         ((- 30A a b + 12B a )c  + 10A a b c - A b )\|- 4a c + b
+--R      *
+--R                          +---------+
+--R                   2      |        2
+--R              (2c x  + b)\|4a c - b
+--R         atan(-----------------------)
+--R                             2
+--R                     4a c - b
+--R  /
+--R                                +-----------+ +---------+
+--R         5 2      4 2      3 4  |          2  |        2
+--R     (32a c  - 16a b c + 2a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2294
+
+--S 2295 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2295
+
+)clear all
+
+--S 2296 of 3139
+t0:=(A+B*x^2)/(x^3*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R        2
+--R     B x  + A
+--R  /
+--R        3 15       2 13        2     2   11              3  9      2        2  7
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   5    3 3
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2296
+
+--S 2297 of 3139
+r0:=1/2*(a*b*B*(b^2-7*a*c)-3*A*(b^4-7*a*b^2*c+10*a^2*c^2))/(a^3*(b^2-_
+   4*a*c)^2*x^2)+1/4*(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-_
+   4*a*c)*x^2*(a+b*x^2+c*x^4)^2)+1/4*(-a*b*B*(b^2-10*a*c)+A*(3*b^4-_
+   20*a*b^2*c+20*a^2*c^2)-c*(a*B*(b^2-16*a*c)-3*A*(b^3-6*a*b*c))*x^2)/_
+   (a^2*(b^2-4*a*c)^2*x^2*(a+b*x^2+c*x^4))+1/2*(a*b*B*(b^4-10*a*b^2*c+_
+   30*a^2*c^2)-3*A*(b^6-10*a*b^4*c+30*a^2*b^2*c^2-20*a^3*c^3))*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(5/2))-_
+   (3*A*b-a*B)*log(x)/a^4+1/4*(3*A*b-a*B)*log(a+b*x^2+c*x^4)/a^4
+--R 
+--R
+--R   (2)
+--R                     3 5            2 2        3   4           4        2 3  3
+--R               120A a c  + (- 180A a b  + 60B a b)c  + (60A a b  - 20B a b )c
+--R             + 
+--R                      6         5  2
+--R               (- 6A b  + 2B a b )c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                     3   4            2 3         3 2  3
+--R               240A a b c  + (- 360A a b  + 120B a b )c
+--R             + 
+--R                        5        2 4  2           7         6
+--R               (120A a b  - 40B a b )c  + (- 12A b  + 4B a b )c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                     4 4            3 2         4   3
+--R               240A a c  + (- 240A a b  + 120B a b)c
+--R             + 
+--R                       2 4        3 3  2           6        2 5         8
+--R               (- 60A a b  + 20B a b )c  + (48A a b  - 16B a b )c - 6A b
+--R             + 
+--R                     7
+--R               2B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                     4   3            3 3         4 2  2
+--R               240A a b c  + (- 360A a b  + 120B a b )c
+--R             + 
+--R                      2 5        3 4            7       2 6
+--R               (120A a b  - 40B a b )c - 12A a b  + 4B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     5 3            4 2        5   2         3 4        4 3
+--R               120A a c  + (- 180A a b  + 60B a b)c  + (60A a b  - 20B a b )c
+--R             + 
+--R                     2 6       3 5
+--R               - 6A a b  + 2B a b
+--R          *
+--R              2
+--R             x
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                         2         3  4             3       2 2  3
+--R                   (48A a b - 16B a )c  + (- 24A a b  + 8B a b )c
+--R                 + 
+--R                        5        4  2
+--R                   (3A b  - B a b )c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                         2 2        3   3             4        2 3  2
+--R                   (96A a b  - 32B a b)c  + (- 48A a b  + 16B a b )c
+--R                 + 
+--R                        6         5
+--R                   (6A b  - 2B a b )c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           3         4  3             5       2 4         7
+--R                     (96A a b - 32B a )c  + (- 18A a b  + 6B a b )c + 3A b
+--R                   + 
+--R                            6
+--R                     - B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         3 2        4   2           2 4        3 3           6
+--R                   (96A a b  - 32B a b)c  + (- 48A a b  + 16B a b )c + 6A a b
+--R                 + 
+--R                         2 5
+--R                   - 2B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         4         5  2           3 3       4 2         2 5
+--R                   (48A a b - 16B a )c  + (- 24A a b  + 8B a b )c + 3A a b
+--R                 + 
+--R                        3 4
+--R                   - B a b
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                            2         3  4           3        2 2  3
+--R                   (- 192A a b + 64B a )c  + (96A a b  - 32B a b )c
+--R                 + 
+--R                           5         4  2
+--R                   (- 12A b  + 4B a b )c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            2 2         3   3            4        2 3  2
+--R                   (- 384A a b  + 128B a b)c  + (192A a b  - 64B a b )c
+--R                 + 
+--R                           6         5
+--R                   (- 24A b  + 8B a b )c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            3          4  3           5        2 4          7
+--R                   (- 384A a b + 128B a )c  + (72A a b  - 24B a b )c - 12A b
+--R                 + 
+--R                         6
+--R                   4B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            3 2         4   2          2 4        3 3
+--R                   (- 384A a b  + 128B a b)c  + (192A a b  - 64B a b )c
+--R                 + 
+--R                            6       2 5
+--R                   - 24A a b  + 8B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            4         5  2         3 3        4 2          2 5
+--R                   (- 192A a b + 64B a )c  + (96A a b  - 32B a b )c - 12A a b
+--R                 + 
+--R                       3 4
+--R                   4B a b
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R             log(x)
+--R         + 
+--R                   3 4         2 2        3   3            4       2 3  2  8
+--R           (- 60A a c  + (42A a b  - 14B a b)c  + (- 6A a b  + 2B a b )c )x
+--R         + 
+--R                        3         4  3         2 3        3 2  2
+--R               (- 138A a b + 16B a )c  + (87A a b  - 29B a b )c
+--R             + 
+--R                         5       2 4
+--R               (- 12A a b  + 4B a b )c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                       4 3           3 2       4   2         2 4        3 3
+--R               - 100A a c  + (- 14A a b  - 2B a b)c  + (36A a b  - 12B a b )c
+--R             + 
+--R                       6       2 5
+--R               - 6A a b  + 2B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        4         5  2         3 3        4 2         2 5
+--R               (- 122A a b + 24B a )c  + (68A a b  - 21B a b )c - 9A a b
+--R             + 
+--R                   3 4
+--R               3B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                  5 2        4 2        3 4
+--R           - 32A a c  + 16A a b c - 2A a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             6 4      5 2 3     4 4 2  10        6   3      5 3 2     4 5   8
+--R         (64a c  - 32a b c  + 4a b c )x   + (128a b c  - 64a b c  + 8a b c)x
+--R       + 
+--R              7 3      5 4      4 6  6        7   2      6 3      5 5  4
+--R         (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R       + 
+--R             8 2      7 2      6 4  2
+--R         (64a c  - 32a b c + 4a b )x
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2297
+
+--S 2298 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3 5           2 2        3   4           4        2 3  3
+--R                 60A a c  + (- 90A a b  + 30B a b)c  + (30A a b  - 10B a b )c
+--R               + 
+--R                        6        5  2
+--R                 (- 3A b  + B a b )c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                       3   4            2 3        3 2  3
+--R                 120A a b c  + (- 180A a b  + 60B a b )c
+--R               + 
+--R                         5        2 4  2          7         6
+--R                 (60A a b  - 20B a b )c  + (- 6A b  + 2B a b )c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                       4 4            3 2        4   3
+--R                 120A a c  + (- 120A a b  + 60B a b)c
+--R               + 
+--R                         2 4        3 3  2           6       2 5         8
+--R                 (- 30A a b  + 10B a b )c  + (24A a b  - 8B a b )c - 3A b
+--R               + 
+--R                      7
+--R                 B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                       4   3            3 3        4 2  2
+--R                 120A a b c  + (- 180A a b  + 60B a b )c
+--R               + 
+--R                       2 5        3 4           7       2 6
+--R                 (60A a b  - 20B a b )c - 6A a b  + 2B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      5 3           4 2        5   2         3 4        4 3
+--R                 60A a c  + (- 90A a b  + 30B a b)c  + (30A a b  - 10B a b )c
+--R               + 
+--R                       2 6      3 5
+--R                 - 3A a b  + B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                           2         3  4             3       2 2  3
+--R                     (48A a b - 16B a )c  + (- 24A a b  + 8B a b )c
+--R                   + 
+--R                          5        4  2
+--R                     (3A b  - B a b )c
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                           2 2        3   3             4        2 3  2
+--R                     (96A a b  - 32B a b)c  + (- 48A a b  + 16B a b )c
+--R                   + 
+--R                          6         5
+--R                     (6A b  - 2B a b )c
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                           3         4  3             5       2 4         7
+--R                     (96A a b - 32B a )c  + (- 18A a b  + 6B a b )c + 3A b
+--R                   + 
+--R                            6
+--R                     - B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                           3 2        4   2           2 4        3 3           6
+--R                     (96A a b  - 32B a b)c  + (- 48A a b  + 16B a b )c + 6A a b
+--R                   + 
+--R                           2 5
+--R                     - 2B a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                           4         5  2           3 3       4 2         2 5
+--R                     (48A a b - 16B a )c  + (- 24A a b  + 8B a b )c + 3A a b
+--R                   + 
+--R                          3 4
+--R                     - B a b
+--R                *
+--R                    2
+--R                   x
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                              2         3  4           3        2 2  3
+--R                     (- 192A a b + 64B a )c  + (96A a b  - 32B a b )c
+--R                   + 
+--R                             5         4  2
+--R                     (- 12A b  + 4B a b )c
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              2 2         3   3            4        2 3  2
+--R                     (- 384A a b  + 128B a b)c  + (192A a b  - 64B a b )c
+--R                   + 
+--R                             6         5
+--R                     (- 24A b  + 8B a b )c
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                              3          4  3           5        2 4          7
+--R                     (- 384A a b + 128B a )c  + (72A a b  - 24B a b )c - 12A b
+--R                   + 
+--R                           6
+--R                     4B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                              3 2         4   2          2 4        3 3
+--R                     (- 384A a b  + 128B a b)c  + (192A a b  - 64B a b )c
+--R                   + 
+--R                              6       2 5
+--R                     - 24A a b  + 8B a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                              4         5  2         3 3        4 2          2 5
+--R                     (- 192A a b + 64B a )c  + (96A a b  - 32B a b )c - 12A a b
+--R                   + 
+--R                         3 4
+--R                     4B a b
+--R                *
+--R                    2
+--R                   x
+--R            *
+--R               log(x)
+--R           + 
+--R                     3 4         2 2        3   3            4       2 3  2  8
+--R             (- 60A a c  + (42A a b  - 14B a b)c  + (- 6A a b  + 2B a b )c )x
+--R           + 
+--R                          3         4  3         2 3        3 2  2
+--R                 (- 138A a b + 16B a )c  + (87A a b  - 29B a b )c
+--R               + 
+--R                           5       2 4
+--R                 (- 12A a b  + 4B a b )c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                         4 3           3 2       4   2         2 4        3 3
+--R                 - 100A a c  + (- 14A a b  - 2B a b)c  + (36A a b  - 12B a b )c
+--R               + 
+--R                         6       2 5
+--R                 - 6A a b  + 2B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          4         5  2         3 3        4 2         2 5
+--R                 (- 122A a b + 24B a )c  + (68A a b  - 21B a b )c - 9A a b
+--R               + 
+--R                     3 4
+--R                 3B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    5 2        4 2        3 4
+--R             - 32A a c  + 16A a b c - 2A a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               6 4      5 2 3     4 4 2  10        6   3      5 3 2     4 5   8
+--R           (64a c  - 32a b c  + 4a b c )x   + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                7 3      5 4      4 6  6        7   2      6 3      5 5  4
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R               8 2      7 2      6 4  2
+--R           (64a c  - 32a b c + 4a b )x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                         3 5          2 2        3   4
+--R                 - 120A a c  + (180A a b  - 60B a b)c
+--R               + 
+--R                           4        2 3  3        6         5  2
+--R                 (- 60A a b  + 20B a b )c  + (6A b  - 2B a b )c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                         3   4          2 3         3 2  3
+--R                 - 240A a b c  + (360A a b  - 120B a b )c
+--R               + 
+--R                            5        2 4  2         7         6
+--R                 (- 120A a b  + 40B a b )c  + (12A b  - 4B a b )c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                         4 4          3 2         4   3
+--R                 - 240A a c  + (240A a b  - 120B a b)c
+--R               + 
+--R                       2 4        3 3  2             6        2 5         8
+--R                 (60A a b  - 20B a b )c  + (- 48A a b  + 16B a b )c + 6A b
+--R               + 
+--R                         7
+--R                 - 2B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                         4   3          3 3         4 2  2
+--R                 - 240A a b c  + (360A a b  - 120B a b )c
+--R               + 
+--R                          2 5        3 4            7       2 6
+--R                 (- 120A a b  + 40B a b )c + 12A a b  - 4B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         5 3          4 2        5   2
+--R                 - 120A a c  + (180A a b  - 60B a b)c
+--R               + 
+--R                         3 4        4 3         2 6       3 5
+--R                 (- 60A a b  + 20B a b )c + 6A a b  - 2B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                           2         3  4             3       2 2  3
+--R                     (48A a b - 16B a )c  + (- 24A a b  + 8B a b )c
+--R                   + 
+--R                          5        4  2
+--R                     (3A b  - B a b )c
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                           2 2        3   3             4        2 3  2
+--R                     (96A a b  - 32B a b)c  + (- 48A a b  + 16B a b )c
+--R                   + 
+--R                          6         5
+--R                     (6A b  - 2B a b )c
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                           3         4  3             5       2 4         7
+--R                     (96A a b - 32B a )c  + (- 18A a b  + 6B a b )c + 3A b
+--R                   + 
+--R                            6
+--R                     - B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                           3 2        4   2           2 4        3 3           6
+--R                     (96A a b  - 32B a b)c  + (- 48A a b  + 16B a b )c + 6A a b
+--R                   + 
+--R                           2 5
+--R                     - 2B a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                           4         5  2           3 3       4 2         2 5
+--R                     (48A a b - 16B a )c  + (- 24A a b  + 8B a b )c + 3A a b
+--R                   + 
+--R                          3 4
+--R                     - B a b
+--R                *
+--R                    2
+--R                   x
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                              2         3  4           3        2 2  3
+--R                     (- 192A a b + 64B a )c  + (96A a b  - 32B a b )c
+--R                   + 
+--R                             5         4  2
+--R                     (- 12A b  + 4B a b )c
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              2 2         3   3            4        2 3  2
+--R                     (- 384A a b  + 128B a b)c  + (192A a b  - 64B a b )c
+--R                   + 
+--R                             6         5
+--R                     (- 24A b  + 8B a b )c
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                              3          4  3           5        2 4          7
+--R                     (- 384A a b + 128B a )c  + (72A a b  - 24B a b )c - 12A b
+--R                   + 
+--R                           6
+--R                     4B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                              3 2         4   2          2 4        3 3
+--R                     (- 384A a b  + 128B a b)c  + (192A a b  - 64B a b )c
+--R                   + 
+--R                              6       2 5
+--R                     - 24A a b  + 8B a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                              4         5  2         3 3        4 2          2 5
+--R                     (- 192A a b + 64B a )c  + (96A a b  - 32B a b )c - 12A a b
+--R                   + 
+--R                         3 4
+--R                     4B a b
+--R                *
+--R                    2
+--R                   x
+--R            *
+--R               log(x)
+--R           + 
+--R                     3 4         2 2        3   3            4       2 3  2  8
+--R             (- 60A a c  + (42A a b  - 14B a b)c  + (- 6A a b  + 2B a b )c )x
+--R           + 
+--R                          3         4  3         2 3        3 2  2
+--R                 (- 138A a b + 16B a )c  + (87A a b  - 29B a b )c
+--R               + 
+--R                           5       2 4
+--R                 (- 12A a b  + 4B a b )c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                         4 3           3 2       4   2         2 4        3 3
+--R                 - 100A a c  + (- 14A a b  - 2B a b)c  + (36A a b  - 12B a b )c
+--R               + 
+--R                         6       2 5
+--R                 - 6A a b  + 2B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          4         5  2         3 3        4 2         2 5
+--R                 (- 122A a b + 24B a )c  + (68A a b  - 21B a b )c - 9A a b
+--R               + 
+--R                     3 4
+--R                 3B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    5 2        4 2        3 4
+--R             - 32A a c  + 16A a b c - 2A a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               6 4      5 2 3     4 4 2  10        6   3      5 3 2     4 5   8
+--R           (64a c  - 32a b c  + 4a b c )x   + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                7 3      5 4      4 6  6        7   2      6 3      5 5  4
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R               8 2      7 2      6 4  2
+--R           (64a c  - 32a b c + 4a b )x
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2298
+
+--S 2299 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                3 3           2 2        3   2           4        2 3         6
+--R           60A a c  + (- 90A a b  + 30B a b)c  + (30A a b  - 10B a b )c - 3A b
+--R         + 
+--R                5
+--R           B a b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                   3 3          2 2        3   2             4        2 3
+--R           - 120A a c  + (180A a b  - 60B a b)c  + (- 60A a b  + 20B a b )c
+--R         + 
+--R               6         5
+--R           6A b  - 2B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R  /
+--R                                +-----------+
+--R         6 2      5 2      4 4  |          2
+--R     (64a c  - 32a b c + 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2299
+
+--S 2300 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2300
+
+--S 2301 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                  3 3         2 2        3   2             4        2 3
+--R           - 60A a c  + (90A a b  - 30B a b)c  + (- 30A a b  + 10B a b )c
+--R         + 
+--R               6        5
+--R           3A b  - B a b
+--R      *
+--R          +---------+             2
+--R          |        2          2c x  + b
+--R         \|4a c - b  atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                  3 3         2 2        3   2             4        2 3
+--R           - 60A a c  + (90A a b  - 30B a b)c  + (- 30A a b  + 10B a b )c
+--R         + 
+--R               6        5
+--R           3A b  - B a b
+--R      *
+--R                                        +---------+
+--R          +-----------+          2      |        2
+--R          |          2      (2c x  + b)\|4a c - b
+--R         \|- 4a c + b  atan(-----------------------)
+--R                                           2
+--R                                   4a c - b
+--R  /
+--R                                +-----------+ +---------+
+--R         6 2      5 2      4 4  |          2  |        2
+--R     (32a c  - 16a b c + 2a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2301
+
+--S 2302 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2302
+
+)clear all
+
+--S 2303 of 3139
+t0:=x^8*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        10      8
+--R     B x   + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2303
+
+--S 2304 of 3139
+r0:=-1/8*(3*b^3*B+A*b^2*c-24*a*b*B*c+20*a*A*c^2)*x/(c^2*(b^2-4*a*c)^2)+_
+   1/8*(b^2*B+12*A*b*c-28*a*B*c)*x^3/(c*(b^2-4*a*c)^2)-1/4*x^7*(A*b-_
+   2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-1/8*x^5*_
+   (7*A*b^2-12*a*b*B-4*a*A*c+(b^2*B+12*A*b*c-28*a*B*c)*x^2)/_
+   ((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+1/8*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*(3*b^4*B+A*b^3*c-27*a*b^2*B*c-_
+   16*a*A*b*c^2+84*a^2*B*c^2+(-3*b^5*B-A*b^4*c+33*a*b^3*B*c+_
+   18*a*A*b^2*c^2-132*a^2*b*B*c^2+40*a^2*A*c^3)/sqrt(b^2-4*a*c))/_
+   (c^(5/2)*(b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(3*b^4*B+A*b^3*c-_
+   27*a*b^2*B*c-16*a*A*b*c^2+84*a^2*B*c^2+(3*b^5*B+A*b^4*c-33*a*b^3*B*c-_
+   18*a*A*b^2*c^2+132*a^2*b*B*c^2-40*a^2*A*c^3)/sqrt(b^2-4*a*c))/_
+   (c^(5/2)*(b^2-4*a*c)^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                  2  4       3          2  3       4 2  8
+--R               ((- 16A a b + 84B a )c  + (A b  - 27B a b )c  + 3B b c )x
+--R             + 
+--R                          2         2   3        4          3  2       5   6
+--R               ((- 32A a b  + 168B a b)c  + (2A b  - 54B a b )c  + 6B b c)x
+--R             + 
+--R                           2          3  3             3        2 2  2
+--R                   (- 32A a b + 168B a )c  + (- 14A a b  + 30B a b )c
+--R                 + 
+--R                       5          4         6
+--R                   (A b  - 21B a b )c + 3B b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        2 2         3   2          4        2 3           5  2
+--R               ((- 32A a b  + 168B a b)c  + (2A a b  - 54B a b )c + 6B a b )x
+--R             + 
+--R                       3         4  2       2 3        3 2         2 4
+--R               (- 16A a b + 84B a )c  + (A a b  - 27B a b )c + 3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    2 5           2         2   4         4          3  3
+--R               40A a c  + (18A a b  - 132B a b)c  + (- A b  + 33B a b )c
+--R             + 
+--R                     5 2
+--R               - 3B b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    2   4           3         2 2  3          5          4  2
+--R               80A a b c  + (36A a b  - 264B a b )c  + (- 2A b  + 66B a b )c
+--R             + 
+--R                     6
+--R               - 6B b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                    3 4         2 2         3   3           4        2 3  2
+--R               80A a c  + (76A a b  - 264B a b)c  + (16A a b  - 66B a b )c
+--R             + 
+--R                     6          5         7
+--R               (- A b  + 27B a b )c - 3B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    3   3         2 3         3 2  2            5        2 4
+--R               80A a b c  + (36A a b  - 264B a b )c  + (- 2A a b  + 66B a b )c
+--R             + 
+--R                       6
+--R               - 6B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R              4 3         3 2         4   2         2 4        3 3         2 5
+--R         40A a c  + (18A a b  - 132B a b)c  + (- A a b  + 33B a b )c - 3B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                  2  4       3          2  3       4 2  8
+--R               ((- 16A a b + 84B a )c  + (A b  - 27B a b )c  + 3B b c )x
+--R             + 
+--R                          2         2   3        4          3  2       5   6
+--R               ((- 32A a b  + 168B a b)c  + (2A b  - 54B a b )c  + 6B b c)x
+--R             + 
+--R                           2          3  3             3        2 2  2
+--R                   (- 32A a b + 168B a )c  + (- 14A a b  + 30B a b )c
+--R                 + 
+--R                       5          4         6
+--R                   (A b  - 21B a b )c + 3B b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        2 2         3   2          4        2 3           5  2
+--R               ((- 32A a b  + 168B a b)c  + (2A a b  - 54B a b )c + 6B a b )x
+--R             + 
+--R                       3         4  2       2 3        3 2         2 4
+--R               (- 16A a b + 84B a )c  + (A a b  - 27B a b )c + 3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      2 5             2         2   4       4          3  3
+--R               - 40A a c  + (- 18A a b  + 132B a b)c  + (A b  - 33B a b )c
+--R             + 
+--R                   5 2
+--R               3B b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      2   4             3         2 2  3        5          4  2
+--R               - 80A a b c  + (- 36A a b  + 264B a b )c  + (2A b  - 66B a b )c
+--R             + 
+--R                   6
+--R               6B b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      3 4           2 2         3   3
+--R               - 80A a c  + (- 76A a b  + 264B a b)c
+--R             + 
+--R                         4        2 3  2       6          5         7
+--R               (- 16A a b  + 66B a b )c  + (A b  - 27B a b )c + 3B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      3   3           2 3         3 2  2          5        2 4
+--R               - 80A a b c  + (- 36A a b  + 264B a b )c  + (2A a b  - 66B a b )c
+--R             + 
+--R                     6
+--R               6B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                4 3           3 2         4   2       2 4        3 3         2 5
+--R         - 40A a c  + (- 18A a b  + 132B a b)c  + (A a b  - 33B a b )c + 3B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                              2  3       3          2  2       4   7
+--R           ((- 16A a b - 44B a )c  + (A b  + 37B a b )c  - 5B b c)x
+--R         + 
+--R                        2 3            2       2   2         4          3
+--R                 - 36A a c  + (- 5A a b  + 4B a b)c  + (- A b  + 20B a b )c
+--R               + 
+--R                       5
+--R                 - 3B b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    2         3  2            3        2 2           4  3
+--R           ((- 28A a b - 28B a )c  + (- 2A a b  + 49B a b )c - 6B a b )x
+--R         + 
+--R                   3 2         2 2        3          2 3
+--R           (- 20A a c  + (- A a b  + 24B a b)c - 3B a b )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 6        2 5     4 4  8        2   5         3 4      5 3  6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R       + 
+--R              3 5        4 3     6 2  4        3   4       2 3 3        5 2  2
+--R         (256a c  - 48a b c  + 8b c )x  + (256a b c  - 128a b c  + 16a b c )x
+--R       + 
+--R             4 4      3 2 3     2 4 2
+--R         128a c  - 64a b c  + 8a b c
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2304
+
+--S 2305 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 6        2 5     4 4  8        2   5        3 4     5 3  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 5        4 3     6 2  4        3   4      2 3 3       5 2  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 4      3 2 3     2 4 2
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R         ROOT
+--R                           5 10          4 2 9          3 4 8         2 6 7
+--R                    262144a c   - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 6       10 5
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                               4 2 6       4   2        3   2          2 2 3  5
+--R                         - 625A a c  + (50A a b  - 5400A B a b + 22050A B a )c
+--R                       + 
+--R                                4 4       3     3         2 2 2 2           3 3
+--R                             - A b  + 516A B a b  - 17496A B a b  + 95256A B a b
+--R                           + 
+--R                                      4 4
+--R                             - 194481B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                  3   5        2 2   4           3 2 3
+--R                             - 12A B b  + 1944A B a b  - 26676A B a b
+--R                           + 
+--R                                   4 3 2
+--R                             87318B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                               2 2 6          3   5         4 2 4  2
+--R                         (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                       + 
+--R                                  3 7        4   6        4 8
+--R                         (- 108A B b  + 1782B a b )c - 81B b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      2 3             4  5
+--R                (1680A a b - 6720A B a )c
+--R              + 
+--R                     2 2 3            3 2         2 4   4
+--R                (280A a b  - 3360A B a b  + 15120B a b)c
+--R              + 
+--R                      2   5            2 4        2 3 3  3
+--R                (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R              + 
+--R                  2 7             6        2 2 5  2          8       2   7
+--R                (A b  - 168A B a b  + 1701B a b )c  + (6A B b  - 189B a b )c
+--R              + 
+--R                  2 9
+--R                9B b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                  6                7  12
+--R                      (54525952A a b - 176160768B a )c
+--R                    + 
+--R                                    5 3               6 2  11
+--R                      (- 69206016A a b  + 251658240B a b )c
+--R                    + 
+--R                                  4 5               5 4  10
+--R                      (35389440A a b  - 152567808B a b )c
+--R                    + 
+--R                                   3 7              4 6  9
+--R                      (- 9175040A a b  + 51118080B a b )c
+--R                    + 
+--R                                 2 9              3 8  8
+--R                      (1228800A a b  - 10321920B a b )c
+--R                    + 
+--R                                   11             2 10  7
+--R                      (- 73728A a b   + 1277952B a b  )c
+--R                    + 
+--R                              13             12  6          14 5
+--R                      (1024A b   - 92160B a b  )c  + 3072B b  c
+--R                 *
+--R                    ROOT
+--R                                 4 2 6
+--R                           - 625A a c
+--R                         + 
+--R                               4   2        3   2          2 2 3  5
+--R                           (50A a b  - 5400A B a b + 22050A B a )c
+--R                         + 
+--R                                  4 4       3     3         2 2 2 2
+--R                               - A b  + 516A B a b  - 17496A B a b
+--R                             + 
+--R                                       3 3           4 4
+--R                               95256A B a b - 194481B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5        2 2   4           3 2 3
+--R                               - 12A B b  + 1944A B a b  - 26676A B a b
+--R                             + 
+--R                                     4 3 2
+--R                               87318B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5         4 2 4  2
+--R                           (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                         + 
+--R                                    3 7        4   6        4 8
+--R                           (- 108A B b  + 1782B a b )c - 81B b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                         3 5 8
+--R                  128000A a c
+--R                + 
+--R                           3 4 2          2   5              2 6  7
+--R                  (- 94720A a b  + 399360A B a b - 2257920A B a )c
+--R                + 
+--R                            3 3 4          2   4 3             2 5 2
+--R                      22784A a b  - 277248A B a b  + 1423872A B a b
+--R                    + 
+--R                              3 6
+--R                      2709504B a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                             3 2 6         2   3 5            2 4 4
+--R                      - 1568A a b  + 55872A B a b  - 122112A B a b
+--R                    + 
+--R                                3 5 3
+--R                      - 2979072B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        3   8       2   2 7           2 3 6           3 4 5  4
+--R                  (- 68A a b  - 336A B a b  - 96480A B a b  + 1349568B a b )c
+--R                + 
+--R                     3 10       2     9           2 2 8          3 3 7  3
+--R                  (4A b   - 780A B a b  + 27972A B a b  - 325296B a b )c
+--R                + 
+--R                      2   11          2   10         3 2 9  2
+--R                  (36A B b   - 2844A B a b   + 44604B a b )c
+--R                + 
+--R                         2 12        3   11         3 13
+--R                  (108A B b   - 3348B a b  )c + 108B b
+--R             *
+--R                ROOT
+--R                                  5 10          4 2 9          3 4 8
+--R                           262144a c   - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 7          8 6       10 5
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                      4 2 6
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2        3   2          2 2 3  5
+--R                                (50A a b  - 5400A B a b + 22050A B a )c
+--R                              + 
+--R                                       4 4       3     3         2 2 2 2
+--R                                    - A b  + 516A B a b  - 17496A B a b
+--R                                  + 
+--R                                            3 3           4 4
+--R                                    95256A B a b - 194481B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                         3   5        2 2   4           3 2 3
+--R                                    - 12A B b  + 1944A B a b  - 26676A B a b
+--R                                  + 
+--R                                          4 3 2
+--R                                    87318B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5         4 2 4  2
+--R                                (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                              + 
+--R                                         3 7        4   6        4 8
+--R                                (- 108A B b  + 1782B a b )c - 81B b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             2 3             4  5
+--R                       (1680A a b - 6720A B a )c
+--R                     + 
+--R                            2 2 3            3 2         2 4   4
+--R                       (280A a b  - 3360A B a b  + 15120B a b)c
+--R                     + 
+--R                             2   5            2 4        2 3 3  3
+--R                       (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R                     + 
+--R                         2 7             6        2 2 5  2
+--R                       (A b  - 168A B a b  + 1701B a b )c
+--R                     + 
+--R                              8       2   7       2 9
+--R                       (6A B b  - 189B a b )c + 9B b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                        4 4 6          4 3 2         3   4   5
+--R                  10000A a c  + (15000A a b  - 90000A B a b)c
+--R                + 
+--R                             4 2 4         3   3 3          2 2 4 2
+--R                      - 1491A a b  + 98856A B a b  - 863136A B a b
+--R                    + 
+--R                                3 5            4 6
+--R                      3111696A B a b - 3111696B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         4   6         3   2 5          2 2 3 4
+--R                      35A a b  - 11277A B a b  + 238464A B a b
+--R                    + 
+--R                                  3 4 3           4 5 2
+--R                      - 1298376A B a b  + 1555848B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            3     7         2 2 2 6            3 3 5
+--R                        315A B a b  - 27594A B a b  + 242757A B a b
+--R                      + 
+--R                                 4 4 4
+--R                        - 339309B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       2 2   8           3 2 7         4 3 6           3   9
+--R                  (945A B a b  - 22113A B a b  + 36207B a b )c + 945A B a b
+--R                + 
+--R                         4 2 8
+--R                  - 1701B a b
+--R             *
+--R                x
+--R     + 
+--R                 2 6        2 5     4 4  8          2   5        3 4     5 3  6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c )x
+--R         + 
+--R                  3 5        4 3     6 2  4
+--R           (- 128a c  + 24a b c  - 4b c )x
+--R         + 
+--R                  3   4      2 3 3       5 2  2      4 4      3 2 3     2 4 2
+--R           (- 128a b c  + 64a b c  - 8a b c )x  - 64a c  + 32a b c  - 4a b c
+--R      *
+--R         ROOT
+--R                             5 10          4 2 9          3 4 8         2 6 7
+--R                    - 262144a c   + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 6       10 5
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                               4 2 6       4   2        3   2          2 2 3  5
+--R                         - 625A a c  + (50A a b  - 5400A B a b + 22050A B a )c
+--R                       + 
+--R                                4 4       3     3         2 2 2 2           3 3
+--R                             - A b  + 516A B a b  - 17496A B a b  + 95256A B a b
+--R                           + 
+--R                                      4 4
+--R                             - 194481B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                  3   5        2 2   4           3 2 3
+--R                             - 12A B b  + 1944A B a b  - 26676A B a b
+--R                           + 
+--R                                   4 3 2
+--R                             87318B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                               2 2 6          3   5         4 2 4  2
+--R                         (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                       + 
+--R                                  3 7        4   6        4 8
+--R                         (- 108A B b  + 1782B a b )c - 81B b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      2 3             4  5
+--R                (1680A a b - 6720A B a )c
+--R              + 
+--R                     2 2 3            3 2         2 4   4
+--R                (280A a b  - 3360A B a b  + 15120B a b)c
+--R              + 
+--R                      2   5            2 4        2 3 3  3
+--R                (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R              + 
+--R                  2 7             6        2 2 5  2          8       2   7
+--R                (A b  - 168A B a b  + 1701B a b )c  + (6A B b  - 189B a b )c
+--R              + 
+--R                  2 9
+--R                9B b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                  6                7  12
+--R                      (54525952A a b - 176160768B a )c
+--R                    + 
+--R                                    5 3               6 2  11
+--R                      (- 69206016A a b  + 251658240B a b )c
+--R                    + 
+--R                                  4 5               5 4  10
+--R                      (35389440A a b  - 152567808B a b )c
+--R                    + 
+--R                                   3 7              4 6  9
+--R                      (- 9175040A a b  + 51118080B a b )c
+--R                    + 
+--R                                 2 9              3 8  8
+--R                      (1228800A a b  - 10321920B a b )c
+--R                    + 
+--R                                   11             2 10  7
+--R                      (- 73728A a b   + 1277952B a b  )c
+--R                    + 
+--R                              13             12  6          14 5
+--R                      (1024A b   - 92160B a b  )c  + 3072B b  c
+--R                 *
+--R                    ROOT
+--R                                 4 2 6
+--R                           - 625A a c
+--R                         + 
+--R                               4   2        3   2          2 2 3  5
+--R                           (50A a b  - 5400A B a b + 22050A B a )c
+--R                         + 
+--R                                  4 4       3     3         2 2 2 2
+--R                               - A b  + 516A B a b  - 17496A B a b
+--R                             + 
+--R                                       3 3           4 4
+--R                               95256A B a b - 194481B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5        2 2   4           3 2 3
+--R                               - 12A B b  + 1944A B a b  - 26676A B a b
+--R                             + 
+--R                                     4 3 2
+--R                               87318B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5         4 2 4  2
+--R                           (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                         + 
+--R                                    3 7        4   6        4 8
+--R                           (- 108A B b  + 1782B a b )c - 81B b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                           3 5 8
+--R                  - 128000A a c
+--R                + 
+--R                         3 4 2          2   5              2 6  7
+--R                  (94720A a b  - 399360A B a b + 2257920A B a )c
+--R                + 
+--R                              3 3 4          2   4 3             2 5 2
+--R                      - 22784A a b  + 277248A B a b  - 1423872A B a b
+--R                    + 
+--R                                3 6
+--R                      - 2709504B a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                             3 2 6         2   3 5            2 4 4
+--R                        1568A a b  - 55872A B a b  + 122112A B a b
+--R                      + 
+--R                                3 5 3
+--R                        2979072B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                      3   8       2   2 7           2 3 6           3 4 5  4
+--R                  (68A a b  + 336A B a b  + 96480A B a b  - 1349568B a b )c
+--R                + 
+--R                       3 10       2     9           2 2 8          3 3 7  3
+--R                  (- 4A b   + 780A B a b  - 27972A B a b  + 325296B a b )c
+--R                + 
+--R                        2   11          2   10         3 2 9  2
+--R                  (- 36A B b   + 2844A B a b   - 44604B a b )c
+--R                + 
+--R                           2 12        3   11         3 13
+--R                  (- 108A B b   + 3348B a b  )c - 108B b
+--R             *
+--R                ROOT
+--R                                    5 10          4 2 9          3 4 8
+--R                           - 262144a c   + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 7          8 6       10 5
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                      4 2 6
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2        3   2          2 2 3  5
+--R                                (50A a b  - 5400A B a b + 22050A B a )c
+--R                              + 
+--R                                       4 4       3     3         2 2 2 2
+--R                                    - A b  + 516A B a b  - 17496A B a b
+--R                                  + 
+--R                                            3 3           4 4
+--R                                    95256A B a b - 194481B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                         3   5        2 2   4           3 2 3
+--R                                    - 12A B b  + 1944A B a b  - 26676A B a b
+--R                                  + 
+--R                                          4 3 2
+--R                                    87318B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5         4 2 4  2
+--R                                (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                              + 
+--R                                         3 7        4   6        4 8
+--R                                (- 108A B b  + 1782B a b )c - 81B b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             2 3             4  5
+--R                       (1680A a b - 6720A B a )c
+--R                     + 
+--R                            2 2 3            3 2         2 4   4
+--R                       (280A a b  - 3360A B a b  + 15120B a b)c
+--R                     + 
+--R                             2   5            2 4        2 3 3  3
+--R                       (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R                     + 
+--R                         2 7             6        2 2 5  2
+--R                       (A b  - 168A B a b  + 1701B a b )c
+--R                     + 
+--R                              8       2   7       2 9
+--R                       (6A B b  - 189B a b )c + 9B b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                        4 4 6          4 3 2         3   4   5
+--R                  10000A a c  + (15000A a b  - 90000A B a b)c
+--R                + 
+--R                             4 2 4         3   3 3          2 2 4 2
+--R                      - 1491A a b  + 98856A B a b  - 863136A B a b
+--R                    + 
+--R                                3 5            4 6
+--R                      3111696A B a b - 3111696B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         4   6         3   2 5          2 2 3 4
+--R                      35A a b  - 11277A B a b  + 238464A B a b
+--R                    + 
+--R                                  3 4 3           4 5 2
+--R                      - 1298376A B a b  + 1555848B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            3     7         2 2 2 6            3 3 5
+--R                        315A B a b  - 27594A B a b  + 242757A B a b
+--R                      + 
+--R                                 4 4 4
+--R                        - 339309B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       2 2   8           3 2 7         4 3 6           3   9
+--R                  (945A B a b  - 22113A B a b  + 36207B a b )c + 945A B a b
+--R                + 
+--R                         4 2 8
+--R                  - 1701B a b
+--R             *
+--R                x
+--R     + 
+--R               2 6        2 5     4 4  8        2   5        3 4     5 3  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 5        4 3     6 2  4        3   4      2 3 3       5 2  2
+--R           (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R         + 
+--R              4 4      3 2 3     2 4 2
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R         ROOT
+--R                             5 10          4 2 9          3 4 8         2 6 7
+--R                    - 262144a c   + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 6       10 5
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                               4 2 6       4   2        3   2          2 2 3  5
+--R                         - 625A a c  + (50A a b  - 5400A B a b + 22050A B a )c
+--R                       + 
+--R                                4 4       3     3         2 2 2 2           3 3
+--R                             - A b  + 516A B a b  - 17496A B a b  + 95256A B a b
+--R                           + 
+--R                                      4 4
+--R                             - 194481B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                  3   5        2 2   4           3 2 3
+--R                             - 12A B b  + 1944A B a b  - 26676A B a b
+--R                           + 
+--R                                   4 3 2
+--R                             87318B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                               2 2 6          3   5         4 2 4  2
+--R                         (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                       + 
+--R                                  3 7        4   6        4 8
+--R                         (- 108A B b  + 1782B a b )c - 81B b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      2 3             4  5
+--R                (1680A a b - 6720A B a )c
+--R              + 
+--R                     2 2 3            3 2         2 4   4
+--R                (280A a b  - 3360A B a b  + 15120B a b)c
+--R              + 
+--R                      2   5            2 4        2 3 3  3
+--R                (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R              + 
+--R                  2 7             6        2 2 5  2          8       2   7
+--R                (A b  - 168A B a b  + 1701B a b )c  + (6A B b  - 189B a b )c
+--R              + 
+--R                  2 9
+--R                9B b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                    6                7  12
+--R                      (- 54525952A a b + 176160768B a )c
+--R                    + 
+--R                                  5 3               6 2  11
+--R                      (69206016A a b  - 251658240B a b )c
+--R                    + 
+--R                                    4 5               5 4  10
+--R                      (- 35389440A a b  + 152567808B a b )c
+--R                    + 
+--R                                 3 7              4 6  9
+--R                      (9175040A a b  - 51118080B a b )c
+--R                    + 
+--R                                   2 9              3 8  8
+--R                      (- 1228800A a b  + 10321920B a b )c
+--R                    + 
+--R                                 11             2 10  7
+--R                      (73728A a b   - 1277952B a b  )c
+--R                    + 
+--R                                13             12  6          14 5
+--R                      (- 1024A b   + 92160B a b  )c  - 3072B b  c
+--R                 *
+--R                    ROOT
+--R                                 4 2 6
+--R                           - 625A a c
+--R                         + 
+--R                               4   2        3   2          2 2 3  5
+--R                           (50A a b  - 5400A B a b + 22050A B a )c
+--R                         + 
+--R                                  4 4       3     3         2 2 2 2
+--R                               - A b  + 516A B a b  - 17496A B a b
+--R                             + 
+--R                                       3 3           4 4
+--R                               95256A B a b - 194481B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5        2 2   4           3 2 3
+--R                               - 12A B b  + 1944A B a b  - 26676A B a b
+--R                             + 
+--R                                     4 3 2
+--R                               87318B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5         4 2 4  2
+--R                           (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                         + 
+--R                                    3 7        4   6        4 8
+--R                           (- 108A B b  + 1782B a b )c - 81B b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                         3 5 8
+--R                  128000A a c
+--R                + 
+--R                           3 4 2          2   5              2 6  7
+--R                  (- 94720A a b  + 399360A B a b - 2257920A B a )c
+--R                + 
+--R                            3 3 4          2   4 3             2 5 2
+--R                      22784A a b  - 277248A B a b  + 1423872A B a b
+--R                    + 
+--R                              3 6
+--R                      2709504B a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                             3 2 6         2   3 5            2 4 4
+--R                      - 1568A a b  + 55872A B a b  - 122112A B a b
+--R                    + 
+--R                                3 5 3
+--R                      - 2979072B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        3   8       2   2 7           2 3 6           3 4 5  4
+--R                  (- 68A a b  - 336A B a b  - 96480A B a b  + 1349568B a b )c
+--R                + 
+--R                     3 10       2     9           2 2 8          3 3 7  3
+--R                  (4A b   - 780A B a b  + 27972A B a b  - 325296B a b )c
+--R                + 
+--R                      2   11          2   10         3 2 9  2
+--R                  (36A B b   - 2844A B a b   + 44604B a b )c
+--R                + 
+--R                         2 12        3   11         3 13
+--R                  (108A B b   - 3348B a b  )c + 108B b
+--R             *
+--R                ROOT
+--R                                    5 10          4 2 9          3 4 8
+--R                           - 262144a c   + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 7          8 6       10 5
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                      4 2 6
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2        3   2          2 2 3  5
+--R                                (50A a b  - 5400A B a b + 22050A B a )c
+--R                              + 
+--R                                       4 4       3     3         2 2 2 2
+--R                                    - A b  + 516A B a b  - 17496A B a b
+--R                                  + 
+--R                                            3 3           4 4
+--R                                    95256A B a b - 194481B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                         3   5        2 2   4           3 2 3
+--R                                    - 12A B b  + 1944A B a b  - 26676A B a b
+--R                                  + 
+--R                                          4 3 2
+--R                                    87318B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5         4 2 4  2
+--R                                (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                              + 
+--R                                         3 7        4   6        4 8
+--R                                (- 108A B b  + 1782B a b )c - 81B b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             2 3             4  5
+--R                       (1680A a b - 6720A B a )c
+--R                     + 
+--R                            2 2 3            3 2         2 4   4
+--R                       (280A a b  - 3360A B a b  + 15120B a b)c
+--R                     + 
+--R                             2   5            2 4        2 3 3  3
+--R                       (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R                     + 
+--R                         2 7             6        2 2 5  2
+--R                       (A b  - 168A B a b  + 1701B a b )c
+--R                     + 
+--R                              8       2   7       2 9
+--R                       (6A B b  - 189B a b )c + 9B b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                        4 4 6          4 3 2         3   4   5
+--R                  10000A a c  + (15000A a b  - 90000A B a b)c
+--R                + 
+--R                             4 2 4         3   3 3          2 2 4 2
+--R                      - 1491A a b  + 98856A B a b  - 863136A B a b
+--R                    + 
+--R                                3 5            4 6
+--R                      3111696A B a b - 3111696B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         4   6         3   2 5          2 2 3 4
+--R                      35A a b  - 11277A B a b  + 238464A B a b
+--R                    + 
+--R                                  3 4 3           4 5 2
+--R                      - 1298376A B a b  + 1555848B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            3     7         2 2 2 6            3 3 5
+--R                        315A B a b  - 27594A B a b  + 242757A B a b
+--R                      + 
+--R                                 4 4 4
+--R                        - 339309B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       2 2   8           3 2 7         4 3 6           3   9
+--R                  (945A B a b  - 22113A B a b  + 36207B a b )c + 945A B a b
+--R                + 
+--R                         4 2 8
+--R                  - 1701B a b
+--R             *
+--R                x
+--R     + 
+--R                 2 6        2 5     4 4  8          2   5        3 4     5 3  6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c )x
+--R         + 
+--R                  3 5        4 3     6 2  4
+--R           (- 128a c  + 24a b c  - 4b c )x
+--R         + 
+--R                  3   4      2 3 3       5 2  2      4 4      3 2 3     2 4 2
+--R           (- 128a b c  + 64a b c  - 8a b c )x  - 64a c  + 32a b c  - 4a b c
+--R      *
+--R         ROOT
+--R                           5 10          4 2 9          3 4 8         2 6 7
+--R                    262144a c   - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 6       10 5
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                               4 2 6       4   2        3   2          2 2 3  5
+--R                         - 625A a c  + (50A a b  - 5400A B a b + 22050A B a )c
+--R                       + 
+--R                                4 4       3     3         2 2 2 2           3 3
+--R                             - A b  + 516A B a b  - 17496A B a b  + 95256A B a b
+--R                           + 
+--R                                      4 4
+--R                             - 194481B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                  3   5        2 2   4           3 2 3
+--R                             - 12A B b  + 1944A B a b  - 26676A B a b
+--R                           + 
+--R                                   4 3 2
+--R                             87318B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                               2 2 6          3   5         4 2 4  2
+--R                         (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                       + 
+--R                                  3 7        4   6        4 8
+--R                         (- 108A B b  + 1782B a b )c - 81B b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      2 3             4  5
+--R                (1680A a b - 6720A B a )c
+--R              + 
+--R                     2 2 3            3 2         2 4   4
+--R                (280A a b  - 3360A B a b  + 15120B a b)c
+--R              + 
+--R                      2   5            2 4        2 3 3  3
+--R                (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R              + 
+--R                  2 7             6        2 2 5  2          8       2   7
+--R                (A b  - 168A B a b  + 1701B a b )c  + (6A B b  - 189B a b )c
+--R              + 
+--R                  2 9
+--R                9B b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                    6                7  12
+--R                      (- 54525952A a b + 176160768B a )c
+--R                    + 
+--R                                  5 3               6 2  11
+--R                      (69206016A a b  - 251658240B a b )c
+--R                    + 
+--R                                    4 5               5 4  10
+--R                      (- 35389440A a b  + 152567808B a b )c
+--R                    + 
+--R                                 3 7              4 6  9
+--R                      (9175040A a b  - 51118080B a b )c
+--R                    + 
+--R                                   2 9              3 8  8
+--R                      (- 1228800A a b  + 10321920B a b )c
+--R                    + 
+--R                                 11             2 10  7
+--R                      (73728A a b   - 1277952B a b  )c
+--R                    + 
+--R                                13             12  6          14 5
+--R                      (- 1024A b   + 92160B a b  )c  - 3072B b  c
+--R                 *
+--R                    ROOT
+--R                                 4 2 6
+--R                           - 625A a c
+--R                         + 
+--R                               4   2        3   2          2 2 3  5
+--R                           (50A a b  - 5400A B a b + 22050A B a )c
+--R                         + 
+--R                                  4 4       3     3         2 2 2 2
+--R                               - A b  + 516A B a b  - 17496A B a b
+--R                             + 
+--R                                       3 3           4 4
+--R                               95256A B a b - 194481B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5        2 2   4           3 2 3
+--R                               - 12A B b  + 1944A B a b  - 26676A B a b
+--R                             + 
+--R                                     4 3 2
+--R                               87318B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5         4 2 4  2
+--R                           (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                         + 
+--R                                    3 7        4   6        4 8
+--R                           (- 108A B b  + 1782B a b )c - 81B b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                           3 5 8
+--R                  - 128000A a c
+--R                + 
+--R                         3 4 2          2   5              2 6  7
+--R                  (94720A a b  - 399360A B a b + 2257920A B a )c
+--R                + 
+--R                              3 3 4          2   4 3             2 5 2
+--R                      - 22784A a b  + 277248A B a b  - 1423872A B a b
+--R                    + 
+--R                                3 6
+--R                      - 2709504B a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                             3 2 6         2   3 5            2 4 4
+--R                        1568A a b  - 55872A B a b  + 122112A B a b
+--R                      + 
+--R                                3 5 3
+--R                        2979072B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                      3   8       2   2 7           2 3 6           3 4 5  4
+--R                  (68A a b  + 336A B a b  + 96480A B a b  - 1349568B a b )c
+--R                + 
+--R                       3 10       2     9           2 2 8          3 3 7  3
+--R                  (- 4A b   + 780A B a b  - 27972A B a b  + 325296B a b )c
+--R                + 
+--R                        2   11          2   10         3 2 9  2
+--R                  (- 36A B b   + 2844A B a b   - 44604B a b )c
+--R                + 
+--R                           2 12        3   11         3 13
+--R                  (- 108A B b   + 3348B a b  )c - 108B b
+--R             *
+--R                ROOT
+--R                                  5 10          4 2 9          3 4 8
+--R                           262144a c   - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 7          8 6       10 5
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                      4 2 6
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2        3   2          2 2 3  5
+--R                                (50A a b  - 5400A B a b + 22050A B a )c
+--R                              + 
+--R                                       4 4       3     3         2 2 2 2
+--R                                    - A b  + 516A B a b  - 17496A B a b
+--R                                  + 
+--R                                            3 3           4 4
+--R                                    95256A B a b - 194481B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                         3   5        2 2   4           3 2 3
+--R                                    - 12A B b  + 1944A B a b  - 26676A B a b
+--R                                  + 
+--R                                          4 3 2
+--R                                    87318B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5         4 2 4  2
+--R                                (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                              + 
+--R                                         3 7        4   6        4 8
+--R                                (- 108A B b  + 1782B a b )c - 81B b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             2 3             4  5
+--R                       (1680A a b - 6720A B a )c
+--R                     + 
+--R                            2 2 3            3 2         2 4   4
+--R                       (280A a b  - 3360A B a b  + 15120B a b)c
+--R                     + 
+--R                             2   5            2 4        2 3 3  3
+--R                       (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R                     + 
+--R                         2 7             6        2 2 5  2
+--R                       (A b  - 168A B a b  + 1701B a b )c
+--R                     + 
+--R                              8       2   7       2 9
+--R                       (6A B b  - 189B a b )c + 9B b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                        4 4 6          4 3 2         3   4   5
+--R                  10000A a c  + (15000A a b  - 90000A B a b)c
+--R                + 
+--R                             4 2 4         3   3 3          2 2 4 2
+--R                      - 1491A a b  + 98856A B a b  - 863136A B a b
+--R                    + 
+--R                                3 5            4 6
+--R                      3111696A B a b - 3111696B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         4   6         3   2 5          2 2 3 4
+--R                      35A a b  - 11277A B a b  + 238464A B a b
+--R                    + 
+--R                                  3 4 3           4 5 2
+--R                      - 1298376A B a b  + 1555848B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            3     7         2 2 2 6            3 3 5
+--R                        315A B a b  - 27594A B a b  + 242757A B a b
+--R                      + 
+--R                                 4 4 4
+--R                        - 339309B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       2 2   8           3 2 7         4 3 6           3   9
+--R                  (945A B a b  - 22113A B a b  + 36207B a b )c + 945A B a b
+--R                + 
+--R                         4 2 8
+--R                  - 1701B a b
+--R             *
+--R                x
+--R     + 
+--R                          2  3       3          2  2       4   7
+--R       ((- 16A a b - 44B a )c  + (A b  + 37B a b )c  - 5B b c)x
+--R     + 
+--R               2 3            2       2   2         4          3         5  5
+--R       (- 36A a c  + (- 5A a b  + 4B a b)c  + (- A b  + 20B a b )c - 3B b )x
+--R     + 
+--R                2         3  2            3        2 2           4  3
+--R       ((- 28A a b - 28B a )c  + (- 2A a b  + 49B a b )c - 6B a b )x
+--R     + 
+--R               3 2         2 2        3          2 3
+--R       (- 20A a c  + (- A a b  + 24B a b)c - 3B a b )x
+--R  /
+--R            2 6        2 5     4 4  8        2   5         3 4      5 3  6
+--R       (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R     + 
+--R            3 5        4 3     6 2  4        3   4       2 3 3        5 2  2
+--R       (256a c  - 48a b c  + 8b c )x  + (256a b c  - 128a b c  + 16a b c )x
+--R     + 
+--R           4 4      3 2 3     2 4 2
+--R       128a c  - 64a b c  + 8a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2305
+
+--S 2306 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +-----------+
+--R             2 4        2 3     4 2  +-+ |          2  +-+
+--R         (64a c  - 32a b c  + 4b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           5 10          4 2 9          3 4 8         2 6 7
+--R                    262144a c   - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 6       10 5
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                               4 2 6       4   2        3   2          2 2 3  5
+--R                         - 625A a c  + (50A a b  - 5400A B a b + 22050A B a )c
+--R                       + 
+--R                                4 4       3     3         2 2 2 2           3 3
+--R                             - A b  + 516A B a b  - 17496A B a b  + 95256A B a b
+--R                           + 
+--R                                      4 4
+--R                             - 194481B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                  3   5        2 2   4           3 2 3
+--R                             - 12A B b  + 1944A B a b  - 26676A B a b
+--R                           + 
+--R                                   4 3 2
+--R                             87318B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                               2 2 6          3   5         4 2 4  2
+--R                         (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                       + 
+--R                                  3 7        4   6        4 8
+--R                         (- 108A B b  + 1782B a b )c - 81B b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      2 3             4  5
+--R                (1680A a b - 6720A B a )c
+--R              + 
+--R                     2 2 3            3 2         2 4   4
+--R                (280A a b  - 3360A B a b  + 15120B a b)c
+--R              + 
+--R                      2   5            2 4        2 3 3  3
+--R                (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R              + 
+--R                  2 7             6        2 2 5  2          8       2   7
+--R                (A b  - 168A B a b  + 1701B a b )c  + (6A B b  - 189B a b )c
+--R              + 
+--R                  2 9
+--R                9B b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                  6                7  12
+--R                      (54525952A a b - 176160768B a )c
+--R                    + 
+--R                                    5 3               6 2  11
+--R                      (- 69206016A a b  + 251658240B a b )c
+--R                    + 
+--R                                  4 5               5 4  10
+--R                      (35389440A a b  - 152567808B a b )c
+--R                    + 
+--R                                   3 7              4 6  9
+--R                      (- 9175040A a b  + 51118080B a b )c
+--R                    + 
+--R                                 2 9              3 8  8
+--R                      (1228800A a b  - 10321920B a b )c
+--R                    + 
+--R                                   11             2 10  7
+--R                      (- 73728A a b   + 1277952B a b  )c
+--R                    + 
+--R                              13             12  6          14 5
+--R                      (1024A b   - 92160B a b  )c  + 3072B b  c
+--R                 *
+--R                    ROOT
+--R                                 4 2 6
+--R                           - 625A a c
+--R                         + 
+--R                               4   2        3   2          2 2 3  5
+--R                           (50A a b  - 5400A B a b + 22050A B a )c
+--R                         + 
+--R                                  4 4       3     3         2 2 2 2
+--R                               - A b  + 516A B a b  - 17496A B a b
+--R                             + 
+--R                                       3 3           4 4
+--R                               95256A B a b - 194481B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5        2 2   4           3 2 3
+--R                               - 12A B b  + 1944A B a b  - 26676A B a b
+--R                             + 
+--R                                     4 3 2
+--R                               87318B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5         4 2 4  2
+--R                           (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                         + 
+--R                                    3 7        4   6        4 8
+--R                           (- 108A B b  + 1782B a b )c - 81B b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                         3 5 8
+--R                  128000A a c
+--R                + 
+--R                           3 4 2          2   5              2 6  7
+--R                  (- 94720A a b  + 399360A B a b - 2257920A B a )c
+--R                + 
+--R                            3 3 4          2   4 3             2 5 2
+--R                      22784A a b  - 277248A B a b  + 1423872A B a b
+--R                    + 
+--R                              3 6
+--R                      2709504B a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                             3 2 6         2   3 5            2 4 4
+--R                      - 1568A a b  + 55872A B a b  - 122112A B a b
+--R                    + 
+--R                                3 5 3
+--R                      - 2979072B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        3   8       2   2 7           2 3 6           3 4 5  4
+--R                  (- 68A a b  - 336A B a b  - 96480A B a b  + 1349568B a b )c
+--R                + 
+--R                     3 10       2     9           2 2 8          3 3 7  3
+--R                  (4A b   - 780A B a b  + 27972A B a b  - 325296B a b )c
+--R                + 
+--R                      2   11          2   10         3 2 9  2
+--R                  (36A B b   - 2844A B a b   + 44604B a b )c
+--R                + 
+--R                         2 12        3   11         3 13
+--R                  (108A B b   - 3348B a b  )c + 108B b
+--R             *
+--R                ROOT
+--R                                  5 10          4 2 9          3 4 8
+--R                           262144a c   - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 7          8 6       10 5
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                      4 2 6
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2        3   2          2 2 3  5
+--R                                (50A a b  - 5400A B a b + 22050A B a )c
+--R                              + 
+--R                                       4 4       3     3         2 2 2 2
+--R                                    - A b  + 516A B a b  - 17496A B a b
+--R                                  + 
+--R                                            3 3           4 4
+--R                                    95256A B a b - 194481B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                         3   5        2 2   4           3 2 3
+--R                                    - 12A B b  + 1944A B a b  - 26676A B a b
+--R                                  + 
+--R                                          4 3 2
+--R                                    87318B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5         4 2 4  2
+--R                                (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                              + 
+--R                                         3 7        4   6        4 8
+--R                                (- 108A B b  + 1782B a b )c - 81B b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             2 3             4  5
+--R                       (1680A a b - 6720A B a )c
+--R                     + 
+--R                            2 2 3            3 2         2 4   4
+--R                       (280A a b  - 3360A B a b  + 15120B a b)c
+--R                     + 
+--R                             2   5            2 4        2 3 3  3
+--R                       (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R                     + 
+--R                         2 7             6        2 2 5  2
+--R                       (A b  - 168A B a b  + 1701B a b )c
+--R                     + 
+--R                              8       2   7       2 9
+--R                       (6A B b  - 189B a b )c + 9B b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                        4 4 6          4 3 2         3   4   5
+--R                  10000A a c  + (15000A a b  - 90000A B a b)c
+--R                + 
+--R                             4 2 4         3   3 3          2 2 4 2
+--R                      - 1491A a b  + 98856A B a b  - 863136A B a b
+--R                    + 
+--R                                3 5            4 6
+--R                      3111696A B a b - 3111696B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         4   6         3   2 5          2 2 3 4
+--R                      35A a b  - 11277A B a b  + 238464A B a b
+--R                    + 
+--R                                  3 4 3           4 5 2
+--R                      - 1298376A B a b  + 1555848B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            3     7         2 2 2 6            3 3 5
+--R                        315A B a b  - 27594A B a b  + 242757A B a b
+--R                      + 
+--R                                 4 4 4
+--R                        - 339309B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       2 2   8           3 2 7         4 3 6           3   9
+--R                  (945A B a b  - 22113A B a b  + 36207B a b )c + 945A B a b
+--R                + 
+--R                         4 2 8
+--R                  - 1701B a b
+--R             *
+--R                x
+--R     + 
+--R                                           +-----------+
+--R               2 4        2 3     4 2  +-+ |          2  +-+
+--R         (- 64a c  + 32a b c  - 4b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                             5 10          4 2 9          3 4 8         2 6 7
+--R                    - 262144a c   + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 6       10 5
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                               4 2 6       4   2        3   2          2 2 3  5
+--R                         - 625A a c  + (50A a b  - 5400A B a b + 22050A B a )c
+--R                       + 
+--R                                4 4       3     3         2 2 2 2           3 3
+--R                             - A b  + 516A B a b  - 17496A B a b  + 95256A B a b
+--R                           + 
+--R                                      4 4
+--R                             - 194481B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                  3   5        2 2   4           3 2 3
+--R                             - 12A B b  + 1944A B a b  - 26676A B a b
+--R                           + 
+--R                                   4 3 2
+--R                             87318B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                               2 2 6          3   5         4 2 4  2
+--R                         (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                       + 
+--R                                  3 7        4   6        4 8
+--R                         (- 108A B b  + 1782B a b )c - 81B b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      2 3             4  5
+--R                (1680A a b - 6720A B a )c
+--R              + 
+--R                     2 2 3            3 2         2 4   4
+--R                (280A a b  - 3360A B a b  + 15120B a b)c
+--R              + 
+--R                      2   5            2 4        2 3 3  3
+--R                (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R              + 
+--R                  2 7             6        2 2 5  2          8       2   7
+--R                (A b  - 168A B a b  + 1701B a b )c  + (6A B b  - 189B a b )c
+--R              + 
+--R                  2 9
+--R                9B b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                  6                7  12
+--R                      (54525952A a b - 176160768B a )c
+--R                    + 
+--R                                    5 3               6 2  11
+--R                      (- 69206016A a b  + 251658240B a b )c
+--R                    + 
+--R                                  4 5               5 4  10
+--R                      (35389440A a b  - 152567808B a b )c
+--R                    + 
+--R                                   3 7              4 6  9
+--R                      (- 9175040A a b  + 51118080B a b )c
+--R                    + 
+--R                                 2 9              3 8  8
+--R                      (1228800A a b  - 10321920B a b )c
+--R                    + 
+--R                                   11             2 10  7
+--R                      (- 73728A a b   + 1277952B a b  )c
+--R                    + 
+--R                              13             12  6          14 5
+--R                      (1024A b   - 92160B a b  )c  + 3072B b  c
+--R                 *
+--R                    ROOT
+--R                                 4 2 6
+--R                           - 625A a c
+--R                         + 
+--R                               4   2        3   2          2 2 3  5
+--R                           (50A a b  - 5400A B a b + 22050A B a )c
+--R                         + 
+--R                                  4 4       3     3         2 2 2 2
+--R                               - A b  + 516A B a b  - 17496A B a b
+--R                             + 
+--R                                       3 3           4 4
+--R                               95256A B a b - 194481B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5        2 2   4           3 2 3
+--R                               - 12A B b  + 1944A B a b  - 26676A B a b
+--R                             + 
+--R                                     4 3 2
+--R                               87318B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5         4 2 4  2
+--R                           (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                         + 
+--R                                    3 7        4   6        4 8
+--R                           (- 108A B b  + 1782B a b )c - 81B b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                           3 5 8
+--R                  - 128000A a c
+--R                + 
+--R                         3 4 2          2   5              2 6  7
+--R                  (94720A a b  - 399360A B a b + 2257920A B a )c
+--R                + 
+--R                              3 3 4          2   4 3             2 5 2
+--R                      - 22784A a b  + 277248A B a b  - 1423872A B a b
+--R                    + 
+--R                                3 6
+--R                      - 2709504B a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                             3 2 6         2   3 5            2 4 4
+--R                        1568A a b  - 55872A B a b  + 122112A B a b
+--R                      + 
+--R                                3 5 3
+--R                        2979072B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                      3   8       2   2 7           2 3 6           3 4 5  4
+--R                  (68A a b  + 336A B a b  + 96480A B a b  - 1349568B a b )c
+--R                + 
+--R                       3 10       2     9           2 2 8          3 3 7  3
+--R                  (- 4A b   + 780A B a b  - 27972A B a b  + 325296B a b )c
+--R                + 
+--R                        2   11          2   10         3 2 9  2
+--R                  (- 36A B b   + 2844A B a b   - 44604B a b )c
+--R                + 
+--R                           2 12        3   11         3 13
+--R                  (- 108A B b   + 3348B a b  )c - 108B b
+--R             *
+--R                ROOT
+--R                                    5 10          4 2 9          3 4 8
+--R                           - 262144a c   + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 7          8 6       10 5
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                      4 2 6
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2        3   2          2 2 3  5
+--R                                (50A a b  - 5400A B a b + 22050A B a )c
+--R                              + 
+--R                                       4 4       3     3         2 2 2 2
+--R                                    - A b  + 516A B a b  - 17496A B a b
+--R                                  + 
+--R                                            3 3           4 4
+--R                                    95256A B a b - 194481B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                         3   5        2 2   4           3 2 3
+--R                                    - 12A B b  + 1944A B a b  - 26676A B a b
+--R                                  + 
+--R                                          4 3 2
+--R                                    87318B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5         4 2 4  2
+--R                                (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                              + 
+--R                                         3 7        4   6        4 8
+--R                                (- 108A B b  + 1782B a b )c - 81B b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             2 3             4  5
+--R                       (1680A a b - 6720A B a )c
+--R                     + 
+--R                            2 2 3            3 2         2 4   4
+--R                       (280A a b  - 3360A B a b  + 15120B a b)c
+--R                     + 
+--R                             2   5            2 4        2 3 3  3
+--R                       (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R                     + 
+--R                         2 7             6        2 2 5  2
+--R                       (A b  - 168A B a b  + 1701B a b )c
+--R                     + 
+--R                              8       2   7       2 9
+--R                       (6A B b  - 189B a b )c + 9B b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                        4 4 6          4 3 2         3   4   5
+--R                  10000A a c  + (15000A a b  - 90000A B a b)c
+--R                + 
+--R                             4 2 4         3   3 3          2 2 4 2
+--R                      - 1491A a b  + 98856A B a b  - 863136A B a b
+--R                    + 
+--R                                3 5            4 6
+--R                      3111696A B a b - 3111696B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         4   6         3   2 5          2 2 3 4
+--R                      35A a b  - 11277A B a b  + 238464A B a b
+--R                    + 
+--R                                  3 4 3           4 5 2
+--R                      - 1298376A B a b  + 1555848B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            3     7         2 2 2 6            3 3 5
+--R                        315A B a b  - 27594A B a b  + 242757A B a b
+--R                      + 
+--R                                 4 4 4
+--R                        - 339309B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       2 2   8           3 2 7         4 3 6           3   9
+--R                  (945A B a b  - 22113A B a b  + 36207B a b )c + 945A B a b
+--R                + 
+--R                         4 2 8
+--R                  - 1701B a b
+--R             *
+--R                x
+--R     + 
+--R                                         +-----------+
+--R             2 4        2 3     4 2  +-+ |          2  +-+
+--R         (64a c  - 32a b c  + 4b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                             5 10          4 2 9          3 4 8         2 6 7
+--R                    - 262144a c   + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 6       10 5
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                               4 2 6       4   2        3   2          2 2 3  5
+--R                         - 625A a c  + (50A a b  - 5400A B a b + 22050A B a )c
+--R                       + 
+--R                                4 4       3     3         2 2 2 2           3 3
+--R                             - A b  + 516A B a b  - 17496A B a b  + 95256A B a b
+--R                           + 
+--R                                      4 4
+--R                             - 194481B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                  3   5        2 2   4           3 2 3
+--R                             - 12A B b  + 1944A B a b  - 26676A B a b
+--R                           + 
+--R                                   4 3 2
+--R                             87318B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                               2 2 6          3   5         4 2 4  2
+--R                         (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                       + 
+--R                                  3 7        4   6        4 8
+--R                         (- 108A B b  + 1782B a b )c - 81B b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      2 3             4  5
+--R                (1680A a b - 6720A B a )c
+--R              + 
+--R                     2 2 3            3 2         2 4   4
+--R                (280A a b  - 3360A B a b  + 15120B a b)c
+--R              + 
+--R                      2   5            2 4        2 3 3  3
+--R                (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R              + 
+--R                  2 7             6        2 2 5  2          8       2   7
+--R                (A b  - 168A B a b  + 1701B a b )c  + (6A B b  - 189B a b )c
+--R              + 
+--R                  2 9
+--R                9B b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                    6                7  12
+--R                      (- 54525952A a b + 176160768B a )c
+--R                    + 
+--R                                  5 3               6 2  11
+--R                      (69206016A a b  - 251658240B a b )c
+--R                    + 
+--R                                    4 5               5 4  10
+--R                      (- 35389440A a b  + 152567808B a b )c
+--R                    + 
+--R                                 3 7              4 6  9
+--R                      (9175040A a b  - 51118080B a b )c
+--R                    + 
+--R                                   2 9              3 8  8
+--R                      (- 1228800A a b  + 10321920B a b )c
+--R                    + 
+--R                                 11             2 10  7
+--R                      (73728A a b   - 1277952B a b  )c
+--R                    + 
+--R                                13             12  6          14 5
+--R                      (- 1024A b   + 92160B a b  )c  - 3072B b  c
+--R                 *
+--R                    ROOT
+--R                                 4 2 6
+--R                           - 625A a c
+--R                         + 
+--R                               4   2        3   2          2 2 3  5
+--R                           (50A a b  - 5400A B a b + 22050A B a )c
+--R                         + 
+--R                                  4 4       3     3         2 2 2 2
+--R                               - A b  + 516A B a b  - 17496A B a b
+--R                             + 
+--R                                       3 3           4 4
+--R                               95256A B a b - 194481B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5        2 2   4           3 2 3
+--R                               - 12A B b  + 1944A B a b  - 26676A B a b
+--R                             + 
+--R                                     4 3 2
+--R                               87318B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5         4 2 4  2
+--R                           (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                         + 
+--R                                    3 7        4   6        4 8
+--R                           (- 108A B b  + 1782B a b )c - 81B b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                         3 5 8
+--R                  128000A a c
+--R                + 
+--R                           3 4 2          2   5              2 6  7
+--R                  (- 94720A a b  + 399360A B a b - 2257920A B a )c
+--R                + 
+--R                            3 3 4          2   4 3             2 5 2
+--R                      22784A a b  - 277248A B a b  + 1423872A B a b
+--R                    + 
+--R                              3 6
+--R                      2709504B a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                             3 2 6         2   3 5            2 4 4
+--R                      - 1568A a b  + 55872A B a b  - 122112A B a b
+--R                    + 
+--R                                3 5 3
+--R                      - 2979072B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        3   8       2   2 7           2 3 6           3 4 5  4
+--R                  (- 68A a b  - 336A B a b  - 96480A B a b  + 1349568B a b )c
+--R                + 
+--R                     3 10       2     9           2 2 8          3 3 7  3
+--R                  (4A b   - 780A B a b  + 27972A B a b  - 325296B a b )c
+--R                + 
+--R                      2   11          2   10         3 2 9  2
+--R                  (36A B b   - 2844A B a b   + 44604B a b )c
+--R                + 
+--R                         2 12        3   11         3 13
+--R                  (108A B b   - 3348B a b  )c + 108B b
+--R             *
+--R                ROOT
+--R                                    5 10          4 2 9          3 4 8
+--R                           - 262144a c   + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 7          8 6       10 5
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                      4 2 6
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2        3   2          2 2 3  5
+--R                                (50A a b  - 5400A B a b + 22050A B a )c
+--R                              + 
+--R                                       4 4       3     3         2 2 2 2
+--R                                    - A b  + 516A B a b  - 17496A B a b
+--R                                  + 
+--R                                            3 3           4 4
+--R                                    95256A B a b - 194481B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                         3   5        2 2   4           3 2 3
+--R                                    - 12A B b  + 1944A B a b  - 26676A B a b
+--R                                  + 
+--R                                          4 3 2
+--R                                    87318B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5         4 2 4  2
+--R                                (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                              + 
+--R                                         3 7        4   6        4 8
+--R                                (- 108A B b  + 1782B a b )c - 81B b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             2 3             4  5
+--R                       (1680A a b - 6720A B a )c
+--R                     + 
+--R                            2 2 3            3 2         2 4   4
+--R                       (280A a b  - 3360A B a b  + 15120B a b)c
+--R                     + 
+--R                             2   5            2 4        2 3 3  3
+--R                       (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R                     + 
+--R                         2 7             6        2 2 5  2
+--R                       (A b  - 168A B a b  + 1701B a b )c
+--R                     + 
+--R                              8       2   7       2 9
+--R                       (6A B b  - 189B a b )c + 9B b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                        4 4 6          4 3 2         3   4   5
+--R                  10000A a c  + (15000A a b  - 90000A B a b)c
+--R                + 
+--R                             4 2 4         3   3 3          2 2 4 2
+--R                      - 1491A a b  + 98856A B a b  - 863136A B a b
+--R                    + 
+--R                                3 5            4 6
+--R                      3111696A B a b - 3111696B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         4   6         3   2 5          2 2 3 4
+--R                      35A a b  - 11277A B a b  + 238464A B a b
+--R                    + 
+--R                                  3 4 3           4 5 2
+--R                      - 1298376A B a b  + 1555848B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            3     7         2 2 2 6            3 3 5
+--R                        315A B a b  - 27594A B a b  + 242757A B a b
+--R                      + 
+--R                                 4 4 4
+--R                        - 339309B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       2 2   8           3 2 7         4 3 6           3   9
+--R                  (945A B a b  - 22113A B a b  + 36207B a b )c + 945A B a b
+--R                + 
+--R                         4 2 8
+--R                  - 1701B a b
+--R             *
+--R                x
+--R     + 
+--R                                           +-----------+
+--R               2 4        2 3     4 2  +-+ |          2  +-+
+--R         (- 64a c  + 32a b c  - 4b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           5 10          4 2 9          3 4 8         2 6 7
+--R                    262144a c   - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 6       10 5
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                               4 2 6       4   2        3   2          2 2 3  5
+--R                         - 625A a c  + (50A a b  - 5400A B a b + 22050A B a )c
+--R                       + 
+--R                                4 4       3     3         2 2 2 2           3 3
+--R                             - A b  + 516A B a b  - 17496A B a b  + 95256A B a b
+--R                           + 
+--R                                      4 4
+--R                             - 194481B a
+--R                        *
+--R                            4
+--R                           c
+--R                       + 
+--R                                  3   5        2 2   4           3 2 3
+--R                             - 12A B b  + 1944A B a b  - 26676A B a b
+--R                           + 
+--R                                   4 3 2
+--R                             87318B a b
+--R                        *
+--R                            3
+--R                           c
+--R                       + 
+--R                               2 2 6          3   5         4 2 4  2
+--R                         (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                       + 
+--R                                  3 7        4   6        4 8
+--R                         (- 108A B b  + 1782B a b )c - 81B b
+--R                    /
+--R                                  5 15            4 2 14            3 4 13
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 12             8 11         10 10
+--R                         - 10485760a b c   + 1310720a b c   - 65536b  c
+--R              + 
+--R                      2 3             4  5
+--R                (1680A a b - 6720A B a )c
+--R              + 
+--R                     2 2 3            3 2         2 4   4
+--R                (280A a b  - 3360A B a b  + 15120B a b)c
+--R              + 
+--R                      2   5            2 4        2 3 3  3
+--R                (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R              + 
+--R                  2 7             6        2 2 5  2          8       2   7
+--R                (A b  - 168A B a b  + 1701B a b )c  + (6A B b  - 189B a b )c
+--R              + 
+--R                  2 9
+--R                9B b
+--R           /
+--R                       5 10          4 2 9         3 4 8         2 6 7
+--R                131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 6       10 5
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                    6                7  12
+--R                      (- 54525952A a b + 176160768B a )c
+--R                    + 
+--R                                  5 3               6 2  11
+--R                      (69206016A a b  - 251658240B a b )c
+--R                    + 
+--R                                    4 5               5 4  10
+--R                      (- 35389440A a b  + 152567808B a b )c
+--R                    + 
+--R                                 3 7              4 6  9
+--R                      (9175040A a b  - 51118080B a b )c
+--R                    + 
+--R                                   2 9              3 8  8
+--R                      (- 1228800A a b  + 10321920B a b )c
+--R                    + 
+--R                                 11             2 10  7
+--R                      (73728A a b   - 1277952B a b  )c
+--R                    + 
+--R                                13             12  6          14 5
+--R                      (- 1024A b   + 92160B a b  )c  - 3072B b  c
+--R                 *
+--R                    ROOT
+--R                                 4 2 6
+--R                           - 625A a c
+--R                         + 
+--R                               4   2        3   2          2 2 3  5
+--R                           (50A a b  - 5400A B a b + 22050A B a )c
+--R                         + 
+--R                                  4 4       3     3         2 2 2 2
+--R                               - A b  + 516A B a b  - 17496A B a b
+--R                             + 
+--R                                       3 3           4 4
+--R                               95256A B a b - 194481B a
+--R                          *
+--R                              4
+--R                             c
+--R                         + 
+--R                                    3   5        2 2   4           3 2 3
+--R                               - 12A B b  + 1944A B a b  - 26676A B a b
+--R                             + 
+--R                                     4 3 2
+--R                               87318B a b
+--R                          *
+--R                              3
+--R                             c
+--R                         + 
+--R                                 2 2 6          3   5         4 2 4  2
+--R                           (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                         + 
+--R                                    3 7        4   6        4 8
+--R                           (- 108A B b  + 1782B a b )c - 81B b
+--R                      /
+--R                                    5 15            4 2 14            3 4 13
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 12             8 11         10 10
+--R                           - 10485760a b c   + 1310720a b c   - 65536b  c
+--R                + 
+--R                           3 5 8
+--R                  - 128000A a c
+--R                + 
+--R                         3 4 2          2   5              2 6  7
+--R                  (94720A a b  - 399360A B a b + 2257920A B a )c
+--R                + 
+--R                              3 3 4          2   4 3             2 5 2
+--R                      - 22784A a b  + 277248A B a b  - 1423872A B a b
+--R                    + 
+--R                                3 6
+--R                      - 2709504B a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                             3 2 6         2   3 5            2 4 4
+--R                        1568A a b  - 55872A B a b  + 122112A B a b
+--R                      + 
+--R                                3 5 3
+--R                        2979072B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                      3   8       2   2 7           2 3 6           3 4 5  4
+--R                  (68A a b  + 336A B a b  + 96480A B a b  - 1349568B a b )c
+--R                + 
+--R                       3 10       2     9           2 2 8          3 3 7  3
+--R                  (- 4A b   + 780A B a b  - 27972A B a b  + 325296B a b )c
+--R                + 
+--R                        2   11          2   10         3 2 9  2
+--R                  (- 36A B b   + 2844A B a b   - 44604B a b )c
+--R                + 
+--R                           2 12        3   11         3 13
+--R                  (- 108A B b   + 3348B a b  )c - 108B b
+--R             *
+--R                ROOT
+--R                                  5 10          4 2 9          3 4 8
+--R                           262144a c   - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 7          8 6       10 5
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                      4 2 6
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2        3   2          2 2 3  5
+--R                                (50A a b  - 5400A B a b + 22050A B a )c
+--R                              + 
+--R                                       4 4       3     3         2 2 2 2
+--R                                    - A b  + 516A B a b  - 17496A B a b
+--R                                  + 
+--R                                            3 3           4 4
+--R                                    95256A B a b - 194481B a
+--R                               *
+--R                                   4
+--R                                  c
+--R                              + 
+--R                                         3   5        2 2   4           3 2 3
+--R                                    - 12A B b  + 1944A B a b  - 26676A B a b
+--R                                  + 
+--R                                          4 3 2
+--R                                    87318B a b
+--R                               *
+--R                                   3
+--R                                  c
+--R                              + 
+--R                                      2 2 6          3   5         4 2 4  2
+--R                                (- 54A B b  + 3132A B a b  - 17739B a b )c
+--R                              + 
+--R                                         3 7        4   6        4 8
+--R                                (- 108A B b  + 1782B a b )c - 81B b
+--R                           /
+--R                                         5 15            4 2 14
+--R                                67108864a c   - 83886080a b c
+--R                              + 
+--R                                         3 4 13            2 6 12
+--R                                41943040a b c   - 10485760a b c
+--R                              + 
+--R                                          8 11         10 10
+--R                                1310720a b c   - 65536b  c
+--R                     + 
+--R                             2 3             4  5
+--R                       (1680A a b - 6720A B a )c
+--R                     + 
+--R                            2 2 3            3 2         2 4   4
+--R                       (280A a b  - 3360A B a b  + 15120B a b)c
+--R                     + 
+--R                             2   5            2 4        2 3 3  3
+--R                       (- 35A a b  + 1260A B a b  - 7560B a b )c
+--R                     + 
+--R                         2 7             6        2 2 5  2
+--R                       (A b  - 168A B a b  + 1701B a b )c
+--R                     + 
+--R                              8       2   7       2 9
+--R                       (6A B b  - 189B a b )c + 9B b
+--R                  /
+--R                              5 10          4 2 9         3 4 8         2 6 7
+--R                       131072a c   - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 6       10 5
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                        4 4 6          4 3 2         3   4   5
+--R                  10000A a c  + (15000A a b  - 90000A B a b)c
+--R                + 
+--R                             4 2 4         3   3 3          2 2 4 2
+--R                      - 1491A a b  + 98856A B a b  - 863136A B a b
+--R                    + 
+--R                                3 5            4 6
+--R                      3111696A B a b - 3111696B a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         4   6         3   2 5          2 2 3 4
+--R                      35A a b  - 11277A B a b  + 238464A B a b
+--R                    + 
+--R                                  3 4 3           4 5 2
+--R                      - 1298376A B a b  + 1555848B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            3     7         2 2 2 6            3 3 5
+--R                        315A B a b  - 27594A B a b  + 242757A B a b
+--R                      + 
+--R                                 4 4 4
+--R                        - 339309B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       2 2   8           3 2 7         4 3 6           3   9
+--R                  (945A B a b  - 22113A B a b  + 36207B a b )c + 945A B a b
+--R                + 
+--R                         4 2 8
+--R                  - 1701B a b
+--R             *
+--R                x
+--R     + 
+--R                                                                 +-----------+
+--R                            2  2         3          2         4  |          2
+--R           ((16A a b - 84B a )c  + (- A b  + 27B a b )c - 3B b )\|- 4a c + b
+--R         + 
+--R                  2 3             2         2   2       4          3         5
+--R           - 40A a c  + (- 18A a b  + 132B a b)c  + (A b  - 33B a b )c + 3B b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                                                 +-----------+
+--R                            2  2         3          2         4  |          2
+--R           ((16A a b - 84B a )c  + (- A b  + 27B a b )c - 3B b )\|- 4a c + b
+--R         + 
+--R                2 3           2         2   2         4          3         5
+--R           40A a c  + (18A a b  - 132B a b)c  + (- A b  + 33B a b )c - 3B b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                          +--------------------+
+--R                                        +-----------+     |   +-----------+
+--R            2 4        2 3     4 2  +-+ |          2  +-+ |   |          2
+--R       (128a c  - 64a b c  + 8b c )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2306
+
+--S 2307 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2307
+
+)clear all
+
+--S 2308 of 3139
+t0:=x^6*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        8      6
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2308
+
+--S 2309 of 3139
+r0:=-1/8*(b^2*B-12*A*b*c+20*a*B*c)*x/(c*(b^2-4*a*c)^2)-1/4*x^5*(A*b-2*a*B-_
+   (b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-1/8*x^3*(5*A*b^2-_
+   12*a*b*B+4*a*A*c-(b^2*B-12*A*b*c+20*a*B*c)*x^2)/((b^2-4*a*c)^2*_
+   (a+b*x^2+c*x^4))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b^3*B+3*A*b^2*c-16*a*b*B*c+12*a*A*c^2+(-b^4*B-3*A*b^3*c+18*a*b^2*B*c-_
+   36*a*A*b*c^2+40*a^2*B*c^2)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)^2*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*(b^3*B+3*A*b^2*c-16*a*b*B*c+12*a*A*c^2+(b^4*B+_
+   3*A*b^3*c-18*a*b^2*B*c+36*a*A*b*c^2-40*a^2*B*c^2)/sqrt(b^2-4*a*c))/_
+   (c^(3/2)*(b^2-4*a*c)^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       4        2            3      3 2  8
+--R               (12A a c  + (3A b  - 16B a b)c  + B b c )x
+--R             + 
+--R                         3        3          2  2       4   6
+--R               (24A a b c  + (6A b  - 32B a b )c  + 2B b c)x
+--R             + 
+--R                          2 3           2        2   2        4          3
+--R                     24A a c  + (18A a b  - 32B a b)c  + (3A b  - 14B a b )c
+--R                   + 
+--R                        5
+--R                     B b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                     2   2          3        2 2           4  2        3 2
+--R               (24A a b c  + (6A a b  - 32B a b )c + 2B a b )x  + 12A a c
+--R             + 
+--R                    2 2        3         2 3
+--R               (3A a b  - 16B a b)c + B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                              2  4          3          2  3      4 2  8
+--R           ((- 36A a b + 40B a )c  + (- 3A b  + 18B a b )c  - B b c )x
+--R         + 
+--R                      2        2   3          4          3  2       5   6
+--R           ((- 72A a b  + 80B a b)c  + (- 6A b  + 36B a b )c  - 2B b c)x
+--R         + 
+--R                       2         3  3             3        2 2  2
+--R               (- 72A a b + 80B a )c  + (- 42A a b  + 76B a b )c
+--R             + 
+--R                      5          4        6
+--R               (- 3A b  + 16B a b )c - B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    2 2        3   2            4        2 3           5  2
+--R           ((- 72A a b  + 80B a b)c  + (- 6A a b  + 36B a b )c - 2B a b )x
+--R         + 
+--R                   3         4  2          2 3        3 2        2 4
+--R           (- 36A a b + 40B a )c  + (- 3A a b  + 18B a b )c - B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                       4        2            3      3 2  8
+--R               (12A a c  + (3A b  - 16B a b)c  + B b c )x
+--R             + 
+--R                         3        3          2  2       4   6
+--R               (24A a b c  + (6A b  - 32B a b )c  + 2B b c)x
+--R             + 
+--R                          2 3           2        2   2        4          3
+--R                     24A a c  + (18A a b  - 32B a b)c  + (3A b  - 14B a b )c
+--R                   + 
+--R                        5
+--R                     B b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                     2   2          3        2 2           4  2        3 2
+--R               (24A a b c  + (6A a b  - 32B a b )c + 2B a b )x  + 12A a c
+--R             + 
+--R                    2 2        3         2 3
+--R               (3A a b  - 16B a b)c + B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                            2  4        3          2  3      4 2  8
+--R           ((36A a b - 40B a )c  + (3A b  - 18B a b )c  + B b c )x
+--R         + 
+--R                    2        2   3        4          3  2       5   6
+--R           ((72A a b  - 80B a b)c  + (6A b  - 36B a b )c  + 2B b c)x
+--R         + 
+--R                     2         3  3           3        2 2  2
+--R               (72A a b - 80B a )c  + (42A a b  - 76B a b )c
+--R             + 
+--R                    5          4        6
+--R               (3A b  - 16B a b )c + B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                  2 2        3   2          4        2 3           5  2
+--R           ((72A a b  - 80B a b)c  + (6A a b  - 36B a b )c + 2B a b )x
+--R         + 
+--R                 3         4  2        2 3        3 2        2 4
+--R           (36A a b - 40B a )c  + (3A a b  - 18B a b )c + B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                   3        2            2      3   7
+--R           (12A a c  + (3A b  - 16B a b)c  + B b c)x
+--R         + 
+--R                            2  2        3         2        4  5
+--R           ((16A a b - 36B a )c  + (5A b  - 5B a b )c - B b )x
+--R         + 
+--R                  2 2           2        2            3  3
+--R           (- 4A a c  + (19A a b  - 28B a b)c - 2B a b )x
+--R         + 
+--R                  2         3        2 2
+--R           ((12A a b - 20B a )c - B a b )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 5        2 4     4 3  8        2   4         3 3      5 2  6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R       + 
+--R              3 4        4 2     6   4        3   3       2 3 2        5   2
+--R         (256a c  - 48a b c  + 8b c)x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R             4 3      3 2 2     2 4
+--R         128a c  - 64a b c  + 8a b c
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2309
+
+--S 2310 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 5        2 4     4 3  8        2   4        3 3     5 2  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 4        4 2     6   4        3   3      2 3 2       5   2
+--R           (128a c  - 24a b c  + 4b c)x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R              4 3      3 2 2     2 4
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R         ROOT
+--R                           5 8          4 2 7          3 4 6         2 6 5
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 4       10 3
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                              4 4          3          2 2   3
+--R                         - 81A c  + (- 108A B b + 450A B a)c
+--R                       + 
+--R                               2 2 2         3          4 2  2
+--R                         (- 54A B b  + 300A B a b - 625B a )c
+--R                       + 
+--R                                 3 3      4   2      4 4
+--R                         (- 12A B b  + 50B a b )c - B b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     2 2            3  4
+--R                (720A a b - 960A B a )c
+--R              + 
+--R                     2   3            2 2        2 3   3
+--R                (360A a b  - 1920A B a b  + 1680B a b)c
+--R              + 
+--R                 2 5            4       2 2 3  2          6      2   5      2 7
+--R              (9A b  - 60A B a b  + 280B a b )c  + (6A B b  - 35B a b )c + B b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                 6 10                 5 2              6   9
+--R                      25165824A a c   + (- 12582912A a b  - 54525952B a b)c
+--R                    + 
+--R                                   4 4              5 3  8
+--R                      (- 7864320A a b  + 69206016B a b )c
+--R                    + 
+--R                                 3 6              4 5  7
+--R                      (7864320A a b  - 35389440B a b )c
+--R                    + 
+--R                                   2 8             3 7  6
+--R                      (- 2457600A a b  + 9175040B a b )c
+--R                    + 
+--R                                  10             2 9  5
+--R                      (344064A a b   - 1228800B a b )c
+--R                    + 
+--R                                 12             11  4          13 3
+--R                      (- 18432A b   + 73728B a b  )c  - 1024B b  c
+--R                 *
+--R                    ROOT
+--R                                4 4          3          2 2   3
+--R                           - 81A c  + (- 108A B b + 450A B a)c
+--R                         + 
+--R                                 2 2 2         3          4 2  2
+--R                           (- 54A B b  + 300A B a b - 625B a )c
+--R                         + 
+--R                                   3 3      4   2      4 4
+--R                           (- 12A B b  + 50B a b )c - B b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                           3 3          2   4  6
+--R                  (- 27648A a b + 46080A B a )c
+--R                + 
+--R                         3 2 3         2   3 2            2 4           3 5  5
+--R                  (20736A a b  - 50688A B a b  + 107520A B a b - 128000B a )c
+--R                + 
+--R                          3   5         2   2 4           2 3 3         3 4 2  4
+--R                  (- 5184A a b  + 20736A B a b  - 82176A B a b  + 94720B a b )c
+--R                + 
+--R                       3 7        2     6           2 2 5         3 3 4  3
+--R                  (432A b  - 3744A B a b  + 21312A B a b  - 22784B a b )c
+--R                + 
+--R                       2   8          2   7        3 2 6  2
+--R                  (252A B b  - 1968A B a b  + 1568B a b )c
+--R                + 
+--R                        2 9      3   8       3 10
+--R                  (24A B b  + 68B a b )c - 4B b
+--R             *
+--R                ROOT
+--R                                  5 8          4 2 7          3 4 6
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 5          8 4       10 3
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                     4 4          3          2 2   3
+--R                                - 81A c  + (- 108A B b + 450A B a)c
+--R                              + 
+--R                                      2 2 2         3          4 2  2
+--R                                (- 54A B b  + 300A B a b - 625B a )c
+--R                              + 
+--R                                        3 3      4   2      4 4
+--R                                (- 12A B b  + 50B a b )c - B b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            2 2            3  4
+--R                       (720A a b - 960A B a )c
+--R                     + 
+--R                            2   3            2 2        2 3   3
+--R                       (360A a b  - 1920A B a b  + 1680B a b)c
+--R                     + 
+--R                          2 5            4       2 2 3  2
+--R                       (9A b  - 60A B a b  + 280B a b )c
+--R                     + 
+--R                              6      2   5      2 7
+--R                       (6A B b  - 35B a b )c + B b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                       4 2 5         4   2        3   2   4
+--R                  1296A a c  + (3240A a b  - 9072A B a b)c
+--R                + 
+--R                          4 4        3     3        2 2 2 2           3 3
+--R                      405A b  - 1080A B a b  - 9936A B a b  + 30000A B a b
+--R                    + 
+--R                              4 4
+--R                      - 10000B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   5        2 2   4           3 2 3         4 3 2  2
+--R                  (405A B b  - 3240A B a b  + 11592A B a b  - 15000B a b )c
+--R                + 
+--R                       2 2 6         3   5        4 2 4          3 7      4   6
+--R                  (135A B b  - 945A B a b  + 1491B a b )c + 15A B b  - 35B a b
+--R             *
+--R                x
+--R     + 
+--R                 2 5        2 4     4 3  8          2   4        3 3     5 2  6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c )x
+--R         + 
+--R                  3 4        4 2     6   4          3   3      2 3 2       5   2
+--R           (- 128a c  + 24a b c  - 4b c)x  + (- 128a b c  + 64a b c  - 8a b c)x
+--R         + 
+--R                4 3      3 2 2     2 4
+--R           - 64a c  + 32a b c  - 4a b c
+--R      *
+--R         ROOT
+--R                             5 8          4 2 7          3 4 6         2 6 5
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 4       10 3
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                              4 4          3          2 2   3
+--R                         - 81A c  + (- 108A B b + 450A B a)c
+--R                       + 
+--R                               2 2 2         3          4 2  2
+--R                         (- 54A B b  + 300A B a b - 625B a )c
+--R                       + 
+--R                                 3 3      4   2      4 4
+--R                         (- 12A B b  + 50B a b )c - B b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     2 2            3  4
+--R                (720A a b - 960A B a )c
+--R              + 
+--R                     2   3            2 2        2 3   3
+--R                (360A a b  - 1920A B a b  + 1680B a b)c
+--R              + 
+--R                 2 5            4       2 2 3  2          6      2   5      2 7
+--R              (9A b  - 60A B a b  + 280B a b )c  + (6A B b  - 35B a b )c + B b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                 6 10                 5 2              6   9
+--R                      25165824A a c   + (- 12582912A a b  - 54525952B a b)c
+--R                    + 
+--R                                   4 4              5 3  8
+--R                      (- 7864320A a b  + 69206016B a b )c
+--R                    + 
+--R                                 3 6              4 5  7
+--R                      (7864320A a b  - 35389440B a b )c
+--R                    + 
+--R                                   2 8             3 7  6
+--R                      (- 2457600A a b  + 9175040B a b )c
+--R                    + 
+--R                                  10             2 9  5
+--R                      (344064A a b   - 1228800B a b )c
+--R                    + 
+--R                                 12             11  4          13 3
+--R                      (- 18432A b   + 73728B a b  )c  - 1024B b  c
+--R                 *
+--R                    ROOT
+--R                                4 4          3          2 2   3
+--R                           - 81A c  + (- 108A B b + 450A B a)c
+--R                         + 
+--R                                 2 2 2         3          4 2  2
+--R                           (- 54A B b  + 300A B a b - 625B a )c
+--R                         + 
+--R                                   3 3      4   2      4 4
+--R                           (- 12A B b  + 50B a b )c - B b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         3 3          2   4  6
+--R                  (27648A a b - 46080A B a )c
+--R                + 
+--R                           3 2 3         2   3 2            2 4           3 5  5
+--R                  (- 20736A a b  + 50688A B a b  - 107520A B a b + 128000B a )c
+--R                + 
+--R                        3   5         2   2 4           2 3 3         3 4 2  4
+--R                  (5184A a b  - 20736A B a b  + 82176A B a b  - 94720B a b )c
+--R                + 
+--R                         3 7        2     6           2 2 5         3 3 4  3
+--R                  (- 432A b  + 3744A B a b  - 21312A B a b  + 22784B a b )c
+--R                + 
+--R                         2   8          2   7        3 2 6  2
+--R                  (- 252A B b  + 1968A B a b  - 1568B a b )c
+--R                + 
+--R                          2 9      3   8       3 10
+--R                  (- 24A B b  - 68B a b )c + 4B b
+--R             *
+--R                ROOT
+--R                                    5 8          4 2 7          3 4 6
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 5          8 4       10 3
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                     4 4          3          2 2   3
+--R                                - 81A c  + (- 108A B b + 450A B a)c
+--R                              + 
+--R                                      2 2 2         3          4 2  2
+--R                                (- 54A B b  + 300A B a b - 625B a )c
+--R                              + 
+--R                                        3 3      4   2      4 4
+--R                                (- 12A B b  + 50B a b )c - B b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            2 2            3  4
+--R                       (720A a b - 960A B a )c
+--R                     + 
+--R                            2   3            2 2        2 3   3
+--R                       (360A a b  - 1920A B a b  + 1680B a b)c
+--R                     + 
+--R                          2 5            4       2 2 3  2
+--R                       (9A b  - 60A B a b  + 280B a b )c
+--R                     + 
+--R                              6      2   5      2 7
+--R                       (6A B b  - 35B a b )c + B b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                       4 2 5         4   2        3   2   4
+--R                  1296A a c  + (3240A a b  - 9072A B a b)c
+--R                + 
+--R                          4 4        3     3        2 2 2 2           3 3
+--R                      405A b  - 1080A B a b  - 9936A B a b  + 30000A B a b
+--R                    + 
+--R                              4 4
+--R                      - 10000B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   5        2 2   4           3 2 3         4 3 2  2
+--R                  (405A B b  - 3240A B a b  + 11592A B a b  - 15000B a b )c
+--R                + 
+--R                       2 2 6         3   5        4 2 4          3 7      4   6
+--R                  (135A B b  - 945A B a b  + 1491B a b )c + 15A B b  - 35B a b
+--R             *
+--R                x
+--R     + 
+--R               2 5        2 4     4 3  8        2   4        3 3     5 2  6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R         + 
+--R                3 4        4 2     6   4        3   3      2 3 2       5   2
+--R           (128a c  - 24a b c  + 4b c)x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R              4 3      3 2 2     2 4
+--R           64a c  - 32a b c  + 4a b c
+--R      *
+--R         ROOT
+--R                             5 8          4 2 7          3 4 6         2 6 5
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 4       10 3
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                              4 4          3          2 2   3
+--R                         - 81A c  + (- 108A B b + 450A B a)c
+--R                       + 
+--R                               2 2 2         3          4 2  2
+--R                         (- 54A B b  + 300A B a b - 625B a )c
+--R                       + 
+--R                                 3 3      4   2      4 4
+--R                         (- 12A B b  + 50B a b )c - B b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     2 2            3  4
+--R                (720A a b - 960A B a )c
+--R              + 
+--R                     2   3            2 2        2 3   3
+--R                (360A a b  - 1920A B a b  + 1680B a b)c
+--R              + 
+--R                 2 5            4       2 2 3  2          6      2   5      2 7
+--R              (9A b  - 60A B a b  + 280B a b )c  + (6A B b  - 35B a b )c + B b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                   6 10               5 2              6   9
+--R                      - 25165824A a c   + (12582912A a b  + 54525952B a b)c
+--R                    + 
+--R                                 4 4              5 3  8
+--R                      (7864320A a b  - 69206016B a b )c
+--R                    + 
+--R                                   3 6              4 5  7
+--R                      (- 7864320A a b  + 35389440B a b )c
+--R                    + 
+--R                                 2 8             3 7  6
+--R                      (2457600A a b  - 9175040B a b )c
+--R                    + 
+--R                                    10             2 9  5
+--R                      (- 344064A a b   + 1228800B a b )c
+--R                    + 
+--R                               12             11  4          13 3
+--R                      (18432A b   - 73728B a b  )c  + 1024B b  c
+--R                 *
+--R                    ROOT
+--R                                4 4          3          2 2   3
+--R                           - 81A c  + (- 108A B b + 450A B a)c
+--R                         + 
+--R                                 2 2 2         3          4 2  2
+--R                           (- 54A B b  + 300A B a b - 625B a )c
+--R                         + 
+--R                                   3 3      4   2      4 4
+--R                           (- 12A B b  + 50B a b )c - B b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                           3 3          2   4  6
+--R                  (- 27648A a b + 46080A B a )c
+--R                + 
+--R                         3 2 3         2   3 2            2 4           3 5  5
+--R                  (20736A a b  - 50688A B a b  + 107520A B a b - 128000B a )c
+--R                + 
+--R                          3   5         2   2 4           2 3 3         3 4 2  4
+--R                  (- 5184A a b  + 20736A B a b  - 82176A B a b  + 94720B a b )c
+--R                + 
+--R                       3 7        2     6           2 2 5         3 3 4  3
+--R                  (432A b  - 3744A B a b  + 21312A B a b  - 22784B a b )c
+--R                + 
+--R                       2   8          2   7        3 2 6  2
+--R                  (252A B b  - 1968A B a b  + 1568B a b )c
+--R                + 
+--R                        2 9      3   8       3 10
+--R                  (24A B b  + 68B a b )c - 4B b
+--R             *
+--R                ROOT
+--R                                    5 8          4 2 7          3 4 6
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 5          8 4       10 3
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                     4 4          3          2 2   3
+--R                                - 81A c  + (- 108A B b + 450A B a)c
+--R                              + 
+--R                                      2 2 2         3          4 2  2
+--R                                (- 54A B b  + 300A B a b - 625B a )c
+--R                              + 
+--R                                        3 3      4   2      4 4
+--R                                (- 12A B b  + 50B a b )c - B b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            2 2            3  4
+--R                       (720A a b - 960A B a )c
+--R                     + 
+--R                            2   3            2 2        2 3   3
+--R                       (360A a b  - 1920A B a b  + 1680B a b)c
+--R                     + 
+--R                          2 5            4       2 2 3  2
+--R                       (9A b  - 60A B a b  + 280B a b )c
+--R                     + 
+--R                              6      2   5      2 7
+--R                       (6A B b  - 35B a b )c + B b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                       4 2 5         4   2        3   2   4
+--R                  1296A a c  + (3240A a b  - 9072A B a b)c
+--R                + 
+--R                          4 4        3     3        2 2 2 2           3 3
+--R                      405A b  - 1080A B a b  - 9936A B a b  + 30000A B a b
+--R                    + 
+--R                              4 4
+--R                      - 10000B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   5        2 2   4           3 2 3         4 3 2  2
+--R                  (405A B b  - 3240A B a b  + 11592A B a b  - 15000B a b )c
+--R                + 
+--R                       2 2 6         3   5        4 2 4          3 7      4   6
+--R                  (135A B b  - 945A B a b  + 1491B a b )c + 15A B b  - 35B a b
+--R             *
+--R                x
+--R     + 
+--R                 2 5        2 4     4 3  8          2   4        3 3     5 2  6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c )x
+--R         + 
+--R                  3 4        4 2     6   4          3   3      2 3 2       5   2
+--R           (- 128a c  + 24a b c  - 4b c)x  + (- 128a b c  + 64a b c  - 8a b c)x
+--R         + 
+--R                4 3      3 2 2     2 4
+--R           - 64a c  + 32a b c  - 4a b c
+--R      *
+--R         ROOT
+--R                           5 8          4 2 7          3 4 6         2 6 5
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 4       10 3
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                              4 4          3          2 2   3
+--R                         - 81A c  + (- 108A B b + 450A B a)c
+--R                       + 
+--R                               2 2 2         3          4 2  2
+--R                         (- 54A B b  + 300A B a b - 625B a )c
+--R                       + 
+--R                                 3 3      4   2      4 4
+--R                         (- 12A B b  + 50B a b )c - B b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     2 2            3  4
+--R                (720A a b - 960A B a )c
+--R              + 
+--R                     2   3            2 2        2 3   3
+--R                (360A a b  - 1920A B a b  + 1680B a b)c
+--R              + 
+--R                 2 5            4       2 2 3  2          6      2   5      2 7
+--R              (9A b  - 60A B a b  + 280B a b )c  + (6A B b  - 35B a b )c + B b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                   6 10               5 2              6   9
+--R                      - 25165824A a c   + (12582912A a b  + 54525952B a b)c
+--R                    + 
+--R                                 4 4              5 3  8
+--R                      (7864320A a b  - 69206016B a b )c
+--R                    + 
+--R                                   3 6              4 5  7
+--R                      (- 7864320A a b  + 35389440B a b )c
+--R                    + 
+--R                                 2 8             3 7  6
+--R                      (2457600A a b  - 9175040B a b )c
+--R                    + 
+--R                                    10             2 9  5
+--R                      (- 344064A a b   + 1228800B a b )c
+--R                    + 
+--R                               12             11  4          13 3
+--R                      (18432A b   - 73728B a b  )c  + 1024B b  c
+--R                 *
+--R                    ROOT
+--R                                4 4          3          2 2   3
+--R                           - 81A c  + (- 108A B b + 450A B a)c
+--R                         + 
+--R                                 2 2 2         3          4 2  2
+--R                           (- 54A B b  + 300A B a b - 625B a )c
+--R                         + 
+--R                                   3 3      4   2      4 4
+--R                           (- 12A B b  + 50B a b )c - B b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         3 3          2   4  6
+--R                  (27648A a b - 46080A B a )c
+--R                + 
+--R                           3 2 3         2   3 2            2 4           3 5  5
+--R                  (- 20736A a b  + 50688A B a b  - 107520A B a b + 128000B a )c
+--R                + 
+--R                        3   5         2   2 4           2 3 3         3 4 2  4
+--R                  (5184A a b  - 20736A B a b  + 82176A B a b  - 94720B a b )c
+--R                + 
+--R                         3 7        2     6           2 2 5         3 3 4  3
+--R                  (- 432A b  + 3744A B a b  - 21312A B a b  + 22784B a b )c
+--R                + 
+--R                         2   8          2   7        3 2 6  2
+--R                  (- 252A B b  + 1968A B a b  - 1568B a b )c
+--R                + 
+--R                          2 9      3   8       3 10
+--R                  (- 24A B b  - 68B a b )c + 4B b
+--R             *
+--R                ROOT
+--R                                  5 8          4 2 7          3 4 6
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 5          8 4       10 3
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                     4 4          3          2 2   3
+--R                                - 81A c  + (- 108A B b + 450A B a)c
+--R                              + 
+--R                                      2 2 2         3          4 2  2
+--R                                (- 54A B b  + 300A B a b - 625B a )c
+--R                              + 
+--R                                        3 3      4   2      4 4
+--R                                (- 12A B b  + 50B a b )c - B b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            2 2            3  4
+--R                       (720A a b - 960A B a )c
+--R                     + 
+--R                            2   3            2 2        2 3   3
+--R                       (360A a b  - 1920A B a b  + 1680B a b)c
+--R                     + 
+--R                          2 5            4       2 2 3  2
+--R                       (9A b  - 60A B a b  + 280B a b )c
+--R                     + 
+--R                              6      2   5      2 7
+--R                       (6A B b  - 35B a b )c + B b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                       4 2 5         4   2        3   2   4
+--R                  1296A a c  + (3240A a b  - 9072A B a b)c
+--R                + 
+--R                          4 4        3     3        2 2 2 2           3 3
+--R                      405A b  - 1080A B a b  - 9936A B a b  + 30000A B a b
+--R                    + 
+--R                              4 4
+--R                      - 10000B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   5        2 2   4           3 2 3         4 3 2  2
+--R                  (405A B b  - 3240A B a b  + 11592A B a b  - 15000B a b )c
+--R                + 
+--R                       2 2 6         3   5        4 2 4          3 7      4   6
+--R                  (135A B b  - 945A B a b  + 1491B a b )c + 15A B b  - 35B a b
+--R             *
+--R                x
+--R     + 
+--R               3        2            2      3   7
+--R       (12A a c  + (3A b  - 16B a b)c  + B b c)x
+--R     + 
+--R                        2  2        3         2        4  5
+--R       ((16A a b - 36B a )c  + (5A b  - 5B a b )c - B b )x
+--R     + 
+--R              2 2           2        2            3  3
+--R       (- 4A a c  + (19A a b  - 28B a b)c - 2B a b )x
+--R     + 
+--R              2         3        2 2
+--R       ((12A a b - 20B a )c - B a b )x
+--R  /
+--R            2 5        2 4     4 3  8        2   4         3 3      5 2  6
+--R       (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R     + 
+--R            3 4        4 2     6   4        3   3       2 3 2        5   2
+--R       (256a c  - 48a b c  + 8b c)x  + (256a b c  - 128a b c  + 16a b c)x
+--R     + 
+--R           4 3      3 2 2     2 4
+--R       128a c  - 64a b c  + 8a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2310
+
+--S 2311 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +--------------------+
+--R                                        +-----------+     |   +-----------+
+--R             2 3        2 2     4   +-+ |          2  +-+ |   |          2
+--R         (64a c  - 32a b c  + 4b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           5 8          4 2 7          3 4 6         2 6 5
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 4       10 3
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                              4 4          3          2 2   3
+--R                         - 81A c  + (- 108A B b + 450A B a)c
+--R                       + 
+--R                               2 2 2         3          4 2  2
+--R                         (- 54A B b  + 300A B a b - 625B a )c
+--R                       + 
+--R                                 3 3      4   2      4 4
+--R                         (- 12A B b  + 50B a b )c - B b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     2 2            3  4
+--R                (720A a b - 960A B a )c
+--R              + 
+--R                     2   3            2 2        2 3   3
+--R                (360A a b  - 1920A B a b  + 1680B a b)c
+--R              + 
+--R                 2 5            4       2 2 3  2          6      2   5      2 7
+--R              (9A b  - 60A B a b  + 280B a b )c  + (6A B b  - 35B a b )c + B b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                 6 10                 5 2              6   9
+--R                      25165824A a c   + (- 12582912A a b  - 54525952B a b)c
+--R                    + 
+--R                                   4 4              5 3  8
+--R                      (- 7864320A a b  + 69206016B a b )c
+--R                    + 
+--R                                 3 6              4 5  7
+--R                      (7864320A a b  - 35389440B a b )c
+--R                    + 
+--R                                   2 8             3 7  6
+--R                      (- 2457600A a b  + 9175040B a b )c
+--R                    + 
+--R                                  10             2 9  5
+--R                      (344064A a b   - 1228800B a b )c
+--R                    + 
+--R                                 12             11  4          13 3
+--R                      (- 18432A b   + 73728B a b  )c  - 1024B b  c
+--R                 *
+--R                    ROOT
+--R                                4 4          3          2 2   3
+--R                           - 81A c  + (- 108A B b + 450A B a)c
+--R                         + 
+--R                                 2 2 2         3          4 2  2
+--R                           (- 54A B b  + 300A B a b - 625B a )c
+--R                         + 
+--R                                   3 3      4   2      4 4
+--R                           (- 12A B b  + 50B a b )c - B b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                           3 3          2   4  6
+--R                  (- 27648A a b + 46080A B a )c
+--R                + 
+--R                         3 2 3         2   3 2            2 4           3 5  5
+--R                  (20736A a b  - 50688A B a b  + 107520A B a b - 128000B a )c
+--R                + 
+--R                          3   5         2   2 4           2 3 3         3 4 2  4
+--R                  (- 5184A a b  + 20736A B a b  - 82176A B a b  + 94720B a b )c
+--R                + 
+--R                       3 7        2     6           2 2 5         3 3 4  3
+--R                  (432A b  - 3744A B a b  + 21312A B a b  - 22784B a b )c
+--R                + 
+--R                       2   8          2   7        3 2 6  2
+--R                  (252A B b  - 1968A B a b  + 1568B a b )c
+--R                + 
+--R                        2 9      3   8       3 10
+--R                  (24A B b  + 68B a b )c - 4B b
+--R             *
+--R                ROOT
+--R                                  5 8          4 2 7          3 4 6
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 5          8 4       10 3
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                     4 4          3          2 2   3
+--R                                - 81A c  + (- 108A B b + 450A B a)c
+--R                              + 
+--R                                      2 2 2         3          4 2  2
+--R                                (- 54A B b  + 300A B a b - 625B a )c
+--R                              + 
+--R                                        3 3      4   2      4 4
+--R                                (- 12A B b  + 50B a b )c - B b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            2 2            3  4
+--R                       (720A a b - 960A B a )c
+--R                     + 
+--R                            2   3            2 2        2 3   3
+--R                       (360A a b  - 1920A B a b  + 1680B a b)c
+--R                     + 
+--R                          2 5            4       2 2 3  2
+--R                       (9A b  - 60A B a b  + 280B a b )c
+--R                     + 
+--R                              6      2   5      2 7
+--R                       (6A B b  - 35B a b )c + B b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                       4 2 5         4   2        3   2   4
+--R                  1296A a c  + (3240A a b  - 9072A B a b)c
+--R                + 
+--R                          4 4        3     3        2 2 2 2           3 3
+--R                      405A b  - 1080A B a b  - 9936A B a b  + 30000A B a b
+--R                    + 
+--R                              4 4
+--R                      - 10000B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   5        2 2   4           3 2 3         4 3 2  2
+--R                  (405A B b  - 3240A B a b  + 11592A B a b  - 15000B a b )c
+--R                + 
+--R                       2 2 6         3   5        4 2 4          3 7      4   6
+--R                  (135A B b  - 945A B a b  + 1491B a b )c + 15A B b  - 35B a b
+--R             *
+--R                x
+--R     + 
+--R                                          +-----------+
+--R               2 3        2 2     4   +-+ |          2  +-+
+--R         (- 64a c  + 32a b c  - 4b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                             5 8          4 2 7          3 4 6         2 6 5
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 4       10 3
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                              4 4          3          2 2   3
+--R                         - 81A c  + (- 108A B b + 450A B a)c
+--R                       + 
+--R                               2 2 2         3          4 2  2
+--R                         (- 54A B b  + 300A B a b - 625B a )c
+--R                       + 
+--R                                 3 3      4   2      4 4
+--R                         (- 12A B b  + 50B a b )c - B b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     2 2            3  4
+--R                (720A a b - 960A B a )c
+--R              + 
+--R                     2   3            2 2        2 3   3
+--R                (360A a b  - 1920A B a b  + 1680B a b)c
+--R              + 
+--R                 2 5            4       2 2 3  2          6      2   5      2 7
+--R              (9A b  - 60A B a b  + 280B a b )c  + (6A B b  - 35B a b )c + B b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 6 10                 5 2              6   9
+--R                      25165824A a c   + (- 12582912A a b  - 54525952B a b)c
+--R                    + 
+--R                                   4 4              5 3  8
+--R                      (- 7864320A a b  + 69206016B a b )c
+--R                    + 
+--R                                 3 6              4 5  7
+--R                      (7864320A a b  - 35389440B a b )c
+--R                    + 
+--R                                   2 8             3 7  6
+--R                      (- 2457600A a b  + 9175040B a b )c
+--R                    + 
+--R                                  10             2 9  5
+--R                      (344064A a b   - 1228800B a b )c
+--R                    + 
+--R                                 12             11  4          13 3
+--R                      (- 18432A b   + 73728B a b  )c  - 1024B b  c
+--R                 *
+--R                    ROOT
+--R                                4 4          3          2 2   3
+--R                           - 81A c  + (- 108A B b + 450A B a)c
+--R                         + 
+--R                                 2 2 2         3          4 2  2
+--R                           (- 54A B b  + 300A B a b - 625B a )c
+--R                         + 
+--R                                   3 3      4   2      4 4
+--R                           (- 12A B b  + 50B a b )c - B b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         3 3          2   4  6
+--R                  (27648A a b - 46080A B a )c
+--R                + 
+--R                           3 2 3         2   3 2            2 4           3 5  5
+--R                  (- 20736A a b  + 50688A B a b  - 107520A B a b + 128000B a )c
+--R                + 
+--R                        3   5         2   2 4           2 3 3         3 4 2  4
+--R                  (5184A a b  - 20736A B a b  + 82176A B a b  - 94720B a b )c
+--R                + 
+--R                         3 7        2     6           2 2 5         3 3 4  3
+--R                  (- 432A b  + 3744A B a b  - 21312A B a b  + 22784B a b )c
+--R                + 
+--R                         2   8          2   7        3 2 6  2
+--R                  (- 252A B b  + 1968A B a b  - 1568B a b )c
+--R                + 
+--R                          2 9      3   8       3 10
+--R                  (- 24A B b  - 68B a b )c + 4B b
+--R             *
+--R                ROOT
+--R                                    5 8          4 2 7          3 4 6
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 5          8 4       10 3
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                     4 4          3          2 2   3
+--R                                - 81A c  + (- 108A B b + 450A B a)c
+--R                              + 
+--R                                      2 2 2         3          4 2  2
+--R                                (- 54A B b  + 300A B a b - 625B a )c
+--R                              + 
+--R                                        3 3      4   2      4 4
+--R                                (- 12A B b  + 50B a b )c - B b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            2 2            3  4
+--R                       (720A a b - 960A B a )c
+--R                     + 
+--R                            2   3            2 2        2 3   3
+--R                       (360A a b  - 1920A B a b  + 1680B a b)c
+--R                     + 
+--R                          2 5            4       2 2 3  2
+--R                       (9A b  - 60A B a b  + 280B a b )c
+--R                     + 
+--R                              6      2   5      2 7
+--R                       (6A B b  - 35B a b )c + B b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                       4 2 5         4   2        3   2   4
+--R                  1296A a c  + (3240A a b  - 9072A B a b)c
+--R                + 
+--R                          4 4        3     3        2 2 2 2           3 3
+--R                      405A b  - 1080A B a b  - 9936A B a b  + 30000A B a b
+--R                    + 
+--R                              4 4
+--R                      - 10000B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   5        2 2   4           3 2 3         4 3 2  2
+--R                  (405A B b  - 3240A B a b  + 11592A B a b  - 15000B a b )c
+--R                + 
+--R                       2 2 6         3   5        4 2 4          3 7      4   6
+--R                  (135A B b  - 945A B a b  + 1491B a b )c + 15A B b  - 35B a b
+--R             *
+--R                x
+--R     + 
+--R                                        +-----------+
+--R             2 3        2 2     4   +-+ |          2  +-+
+--R         (64a c  - 32a b c  + 4b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                             5 8          4 2 7          3 4 6         2 6 5
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                             8 4       10 3
+--R                    - 5120a b c  + 256b  c
+--R               *
+--R                  ROOT
+--R                              4 4          3          2 2   3
+--R                         - 81A c  + (- 108A B b + 450A B a)c
+--R                       + 
+--R                               2 2 2         3          4 2  2
+--R                         (- 54A B b  + 300A B a b - 625B a )c
+--R                       + 
+--R                                 3 3      4   2      4 4
+--R                         (- 12A B b  + 50B a b )c - B b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     2 2            3  4
+--R                (720A a b - 960A B a )c
+--R              + 
+--R                     2   3            2 2        2 3   3
+--R                (360A a b  - 1920A B a b  + 1680B a b)c
+--R              + 
+--R                 2 5            4       2 2 3  2          6      2   5      2 7
+--R              (9A b  - 60A B a b  + 280B a b )c  + (6A B b  - 35B a b )c + B b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                   6 10               5 2              6   9
+--R                      - 25165824A a c   + (12582912A a b  + 54525952B a b)c
+--R                    + 
+--R                                 4 4              5 3  8
+--R                      (7864320A a b  - 69206016B a b )c
+--R                    + 
+--R                                   3 6              4 5  7
+--R                      (- 7864320A a b  + 35389440B a b )c
+--R                    + 
+--R                                 2 8             3 7  6
+--R                      (2457600A a b  - 9175040B a b )c
+--R                    + 
+--R                                    10             2 9  5
+--R                      (- 344064A a b   + 1228800B a b )c
+--R                    + 
+--R                               12             11  4          13 3
+--R                      (18432A b   - 73728B a b  )c  + 1024B b  c
+--R                 *
+--R                    ROOT
+--R                                4 4          3          2 2   3
+--R                           - 81A c  + (- 108A B b + 450A B a)c
+--R                         + 
+--R                                 2 2 2         3          4 2  2
+--R                           (- 54A B b  + 300A B a b - 625B a )c
+--R                         + 
+--R                                   3 3      4   2      4 4
+--R                           (- 12A B b  + 50B a b )c - B b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                           3 3          2   4  6
+--R                  (- 27648A a b + 46080A B a )c
+--R                + 
+--R                         3 2 3         2   3 2            2 4           3 5  5
+--R                  (20736A a b  - 50688A B a b  + 107520A B a b - 128000B a )c
+--R                + 
+--R                          3   5         2   2 4           2 3 3         3 4 2  4
+--R                  (- 5184A a b  + 20736A B a b  - 82176A B a b  + 94720B a b )c
+--R                + 
+--R                       3 7        2     6           2 2 5         3 3 4  3
+--R                  (432A b  - 3744A B a b  + 21312A B a b  - 22784B a b )c
+--R                + 
+--R                       2   8          2   7        3 2 6  2
+--R                  (252A B b  - 1968A B a b  + 1568B a b )c
+--R                + 
+--R                        2 9      3   8       3 10
+--R                  (24A B b  + 68B a b )c - 4B b
+--R             *
+--R                ROOT
+--R                                    5 8          4 2 7          3 4 6
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 2 6 5          8 4       10 3
+--R                           40960a b c  - 5120a b c  + 256b  c
+--R                      *
+--R                         ROOT
+--R                                     4 4          3          2 2   3
+--R                                - 81A c  + (- 108A B b + 450A B a)c
+--R                              + 
+--R                                      2 2 2         3          4 2  2
+--R                                (- 54A B b  + 300A B a b - 625B a )c
+--R                              + 
+--R                                        3 3      4   2      4 4
+--R                                (- 12A B b  + 50B a b )c - B b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            2 2            3  4
+--R                       (720A a b - 960A B a )c
+--R                     + 
+--R                            2   3            2 2        2 3   3
+--R                       (360A a b  - 1920A B a b  + 1680B a b)c
+--R                     + 
+--R                          2 5            4       2 2 3  2
+--R                       (9A b  - 60A B a b  + 280B a b )c
+--R                     + 
+--R                              6      2   5      2 7
+--R                       (6A B b  - 35B a b )c + B b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                       4 2 5         4   2        3   2   4
+--R                  1296A a c  + (3240A a b  - 9072A B a b)c
+--R                + 
+--R                          4 4        3     3        2 2 2 2           3 3
+--R                      405A b  - 1080A B a b  - 9936A B a b  + 30000A B a b
+--R                    + 
+--R                              4 4
+--R                      - 10000B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   5        2 2   4           3 2 3         4 3 2  2
+--R                  (405A B b  - 3240A B a b  + 11592A B a b  - 15000B a b )c
+--R                + 
+--R                       2 2 6         3   5        4 2 4          3 7      4   6
+--R                  (135A B b  - 945A B a b  + 1491B a b )c + 15A B b  - 35B a b
+--R             *
+--R                x
+--R     + 
+--R                                          +-----------+
+--R               2 3        2 2     4   +-+ |          2  +-+
+--R         (- 64a c  + 32a b c  - 4b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           5 8          4 2 7          3 4 6         2 6 5
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                           8 4       10 3
+--R                    5120a b c  - 256b  c
+--R               *
+--R                  ROOT
+--R                              4 4          3          2 2   3
+--R                         - 81A c  + (- 108A B b + 450A B a)c
+--R                       + 
+--R                               2 2 2         3          4 2  2
+--R                         (- 54A B b  + 300A B a b - 625B a )c
+--R                       + 
+--R                                 3 3      4   2      4 4
+--R                         (- 12A B b  + 50B a b )c - B b
+--R                    /
+--R                                  5 11            4 2 10            3 4 9
+--R                         67108864a c   - 83886080a b c   + 41943040a b c
+--R                       + 
+--R                                    2 6 8             8 7         10 6
+--R                         - 10485760a b c  + 1310720a b c  - 65536b  c
+--R              + 
+--R                     2 2            3  4
+--R                (720A a b - 960A B a )c
+--R              + 
+--R                     2   3            2 2        2 3   3
+--R                (360A a b  - 1920A B a b  + 1680B a b)c
+--R              + 
+--R                 2 5            4       2 2 3  2          6      2   5      2 7
+--R              (9A b  - 60A B a b  + 280B a b )c  + (6A B b  - 35B a b )c + B b
+--R           /
+--R                       5 8          4 2 7         3 4 6         2 6 5
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                       8 4       10 3
+--R                2560a b c  - 128b  c
+--R      *
+--R         log
+--R                                   6 10               5 2              6   9
+--R                      - 25165824A a c   + (12582912A a b  + 54525952B a b)c
+--R                    + 
+--R                                 4 4              5 3  8
+--R                      (7864320A a b  - 69206016B a b )c
+--R                    + 
+--R                                   3 6              4 5  7
+--R                      (- 7864320A a b  + 35389440B a b )c
+--R                    + 
+--R                                 2 8             3 7  6
+--R                      (2457600A a b  - 9175040B a b )c
+--R                    + 
+--R                                    10             2 9  5
+--R                      (- 344064A a b   + 1228800B a b )c
+--R                    + 
+--R                               12             11  4          13 3
+--R                      (18432A b   - 73728B a b  )c  + 1024B b  c
+--R                 *
+--R                    ROOT
+--R                                4 4          3          2 2   3
+--R                           - 81A c  + (- 108A B b + 450A B a)c
+--R                         + 
+--R                                 2 2 2         3          4 2  2
+--R                           (- 54A B b  + 300A B a b - 625B a )c
+--R                         + 
+--R                                   3 3      4   2      4 4
+--R                           (- 12A B b  + 50B a b )c - B b
+--R                      /
+--R                                    5 11            4 2 10            3 4 9
+--R                           67108864a c   - 83886080a b c   + 41943040a b c
+--R                         + 
+--R                                      2 6 8             8 7         10 6
+--R                           - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                + 
+--R                         3 3          2   4  6
+--R                  (27648A a b - 46080A B a )c
+--R                + 
+--R                           3 2 3         2   3 2            2 4           3 5  5
+--R                  (- 20736A a b  + 50688A B a b  - 107520A B a b + 128000B a )c
+--R                + 
+--R                        3   5         2   2 4           2 3 3         3 4 2  4
+--R                  (5184A a b  - 20736A B a b  + 82176A B a b  - 94720B a b )c
+--R                + 
+--R                         3 7        2     6           2 2 5         3 3 4  3
+--R                  (- 432A b  + 3744A B a b  - 21312A B a b  + 22784B a b )c
+--R                + 
+--R                         2   8          2   7        3 2 6  2
+--R                  (- 252A B b  + 1968A B a b  - 1568B a b )c
+--R                + 
+--R                          2 9      3   8       3 10
+--R                  (- 24A B b  - 68B a b )c + 4B b
+--R             *
+--R                ROOT
+--R                                  5 8          4 2 7          3 4 6
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   2 6 5          8 4       10 3
+--R                           - 40960a b c  + 5120a b c  - 256b  c
+--R                      *
+--R                         ROOT
+--R                                     4 4          3          2 2   3
+--R                                - 81A c  + (- 108A B b + 450A B a)c
+--R                              + 
+--R                                      2 2 2         3          4 2  2
+--R                                (- 54A B b  + 300A B a b - 625B a )c
+--R                              + 
+--R                                        3 3      4   2      4 4
+--R                                (- 12A B b  + 50B a b )c - B b
+--R                           /
+--R                                         5 11            4 2 10            3 4 9
+--R                                67108864a c   - 83886080a b c   + 41943040a b c
+--R                              + 
+--R                                           2 6 8             8 7         10 6
+--R                                - 10485760a b c  + 1310720a b c  - 65536b  c
+--R                     + 
+--R                            2 2            3  4
+--R                       (720A a b - 960A B a )c
+--R                     + 
+--R                            2   3            2 2        2 3   3
+--R                       (360A a b  - 1920A B a b  + 1680B a b)c
+--R                     + 
+--R                          2 5            4       2 2 3  2
+--R                       (9A b  - 60A B a b  + 280B a b )c
+--R                     + 
+--R                              6      2   5      2 7
+--R                       (6A B b  - 35B a b )c + B b
+--R                  /
+--R                              5 8          4 2 7         3 4 6         2 6 5
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                              8 4       10 3
+--R                       2560a b c  - 128b  c
+--R            + 
+--R                       4 2 5         4   2        3   2   4
+--R                  1296A a c  + (3240A a b  - 9072A B a b)c
+--R                + 
+--R                          4 4        3     3        2 2 2 2           3 3
+--R                      405A b  - 1080A B a b  - 9936A B a b  + 30000A B a b
+--R                    + 
+--R                              4 4
+--R                      - 10000B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       3   5        2 2   4           3 2 3         4 3 2  2
+--R                  (405A B b  - 3240A B a b  + 11592A B a b  - 15000B a b )c
+--R                + 
+--R                       2 2 6         3   5        4 2 4          3 7      4   6
+--R                  (135A B b  - 945A B a b  + 1491B a b )c + 15A B b  - 35B a b
+--R             *
+--R                x
+--R     + 
+--R                                                      +-----------+
+--R                     2          2                  3  |          2
+--R           (- 12A a c  + (- 3A b  + 16B a b)c - B b )\|- 4a c + b
+--R         + 
+--R                           2  2        3          2        4
+--R           (36A a b - 40B a )c  + (3A b  - 18B a b )c + B b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                                      +-----------+
+--R                     2          2                  3  |          2
+--R           (- 12A a c  + (- 3A b  + 16B a b)c - B b )\|- 4a c + b
+--R         + 
+--R                             2  2          3          2        4
+--R           (- 36A a b + 40B a )c  + (- 3A b  + 18B a b )c - B b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                         +--------------------+
+--R                                       +-----------+     |   +-----------+
+--R            2 3        2 2     4   +-+ |          2  +-+ |   |          2
+--R       (128a c  - 64a b c  + 8b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2311
+
+-- Table construction failed in MLIFT
+--S 2312 of 3139
+--d0:=D(m0,x)
+--E 2312
+
+)clear all
+
+--S 2313 of 3139
+t0:=x^4*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        6      4
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2313
+
+--S 2314 of 3139
+r0:=-1/4*x^3*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   3/8*x*(4*a*b*B-A*(b^2+4*a*c)+(b^2*B-4*A*b*c+4*a*B*c)*x^2)/((b^2-_
+   4*a*c)^2*(a+b*x^2+c*x^4))+3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*(b^2*B-4*A*b*c+4*a*B*c+(-b^3*B+6*A*b^2*c-_
+   12*a*b*B*c+8*a*A*c^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^2*sqrt(2)*sqrt(c)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*(b^2*B-4*A*b*c+4*a*B*c+(b^3*B-6*A*b^2*c+12*a*b*B*c-_
+   8*a*A*c^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^2*sqrt(2)*sqrt(c)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                  3       2 2  8
+--R               ((- 12A b + 12B a)c  + 3B b c )x
+--R             + 
+--R                        2            2       3   6
+--R               ((- 24A b  + 24B a b)c  + 6B b c)x
+--R             + 
+--R                                  2  2           3          2         4  4
+--R               ((- 24A a b + 24B a )c  + (- 12A b  + 18B a b )c + 3B b )x
+--R             + 
+--R                          2        2            3  2           2         3
+--R               ((- 24A a b  + 24B a b)c + 6B a b )x  + (- 12A a b + 12B a )c
+--R             + 
+--R                   2 2
+--R               3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   4         2            3       3 2  8
+--R           (24A a c  + (18A b  - 36B a b)c  - 3B b c )x
+--R         + 
+--R                     3         3          2  2       4   6
+--R           (48A a b c  + (36A b  - 72B a b )c  - 6B b c)x
+--R         + 
+--R                 2 3           2        2   2         4          3         5  4
+--R           (48A a c  + (60A a b  - 72B a b)c  + (18A b  - 42B a b )c - 3B b )x
+--R         + 
+--R                 2   2           3        2 2           4  2        3 2
+--R           (48A a b c  + (36A a b  - 72B a b )c - 6B a b )x  + 24A a c
+--R         + 
+--R                 2 2        3          2 3
+--R           (18A a b  - 36B a b)c - 3B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                  3       2 2  8
+--R               ((- 12A b + 12B a)c  + 3B b c )x
+--R             + 
+--R                        2            2       3   6
+--R               ((- 24A b  + 24B a b)c  + 6B b c)x
+--R             + 
+--R                                  2  2           3          2         4  4
+--R               ((- 24A a b + 24B a )c  + (- 12A b  + 18B a b )c + 3B b )x
+--R             + 
+--R                          2        2            3  2           2         3
+--R               ((- 24A a b  + 24B a b)c + 6B a b )x  + (- 12A a b + 12B a )c
+--R             + 
+--R                   2 2
+--R               3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     4           2            3       3 2  8
+--R           (- 24A a c  + (- 18A b  + 36B a b)c  + 3B b c )x
+--R         + 
+--R                       3           3          2  2       4   6
+--R           (- 48A a b c  + (- 36A b  + 72B a b )c  + 6B b c)x
+--R         + 
+--R                      2 3             2        2   2           4          3
+--R               - 48A a c  + (- 60A a b  + 72B a b)c  + (- 18A b  + 42B a b )c
+--R             + 
+--R                   5
+--R               3B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   2   2             3        2 2           4  2        3 2
+--R           (- 48A a b c  + (- 36A a b  + 72B a b )c + 6B a b )x  - 24A a c
+--R         + 
+--R                   2 2        3          2 3
+--R           (- 18A a b  + 36B a b)c + 3B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                              2       2   7
+--R           ((- 12A b + 12B a)c  + 3B b c)x
+--R         + 
+--R                  2           2                   3  5
+--R           (4A a c  + (- 19A b  + 16B a b)c + 5B b )x
+--R         + 
+--R                             2         3          2  3
+--R           ((- 16A a b - 4B a )c - 5A b  + 19B a b )x
+--R         + 
+--R                   2          2        2
+--R           (- 12A a c - 3A a b  + 12B a b)x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 4        2 3     4 2  8        2   3         3 2      5   6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R       + 
+--R              3 3        4      6  4        3   2       2 3         5  2
+--R         (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             4 2      3 2      2 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2314
+
+--S 2315 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                           6 6          5 2 5          4 4 4         3 6 3
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         2 8 2         10
+--R                    5120a b c  - 256a b  c
+--R               *
+--R                  ROOT
+--R                            4 2       2 2         4 2
+--R                       - 81A c  + 162A B a c - 81B a
+--R                    /
+--R                                  7 7            6 2 6            5 4 5
+--R                         67108864a c  - 83886080a b c  + 41943040a b c
+--R                       + 
+--R                                    4 6 4           3 8 3         2 10 2
+--R                         - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R              + 
+--R                     2 2            3  3
+--R                (720A a b - 576A B a )c
+--R              + 
+--R                     2   3            2 2       2 3   2
+--R                (360A a b  - 1440A B a b  + 720B a b)c
+--R              + 
+--R                   2 5             4       2 2 3       2   5
+--R                (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R           /
+--R                       6 6          5 2 5         4 4 4         3 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8 2         10
+--R                2560a b c  - 128a b  c
+--R      *
+--R         log
+--R                                  7              8  7
+--R                      (12582912A a b - 8388608B a )c
+--R                    + 
+--R                                    6 3             7 2  6
+--R                      (- 14680064A a b  + 4194304B a b )c
+--R                    + 
+--R                                 5 5             6 4  5
+--R                      (6553600A a b  + 2621440B a b )c
+--R                    + 
+--R                                   4 7             5 6  4
+--R                      (- 1310720A a b  - 2621440B a b )c
+--R                    + 
+--R                               3 9            4 8  3
+--R                      (81920A a b  + 819200B a b )c
+--R                    + 
+--R                              2 11            3 10  2
+--R                      (8192A a b   - 114688B a b  )c
+--R                    + 
+--R                                  13          2 12
+--R                      (- 1024A a b   + 6144B a b  )c
+--R                 *
+--R                    ROOT
+--R                              4 2       2 2         4 2
+--R                         - 81A c  + 162A B a c - 81B a
+--R                      /
+--R                                    7 7            6 2 6            5 4 5
+--R                           67108864a c  - 83886080a b c  + 41943040a b c
+--R                         + 
+--R                                      4 6 4           3 8 3         2 10 2
+--R                           - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                + 
+--R                       3 4 5           3 3 2        2   4           2 5  4
+--R                  9216A a c  + (- 4608A a b  - 9216A B a b - 9216A B a )c
+--R                + 
+--R                        2   3 3          2 4 2        3 5   3
+--R                  (6912A B a b  + 4608A B a b  + 9216B a b)c
+--R                + 
+--R                       3   6        2   2 5        3 4 3  2
+--R                  (288A a b  - 1728A B a b  - 6912B a b )c
+--R                + 
+--R                        3 8       2     7         2 2 6        3 3 5
+--R                  (- 36A b  + 144A B a b  - 288A B a b  + 1728B a b )c
+--R                + 
+--R                       2   8       3 2 7
+--R                  36A B a b  - 144B a b
+--R             *
+--R                ROOT
+--R                                  6 6          5 2 5          4 4 4
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   3 6 3        2 8 2         10
+--R                           - 40960a b c  + 5120a b c  - 256a b  c
+--R                      *
+--R                         ROOT
+--R                                   4 2       2 2         4 2
+--R                              - 81A c  + 162A B a c - 81B a
+--R                           /
+--R                                         7 7            6 2 6            5 4 5
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 4           3 8 3         2 10 2
+--R                                - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                     + 
+--R                            2 2            3  3
+--R                       (720A a b - 576A B a )c
+--R                     + 
+--R                            2   3            2 2       2 3   2
+--R                       (360A a b  - 1440A B a b  + 720B a b)c
+--R                     + 
+--R                          2 5             4       2 2 3       2   5
+--R                       (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R                  /
+--R                              6 6          5 2 5         4 4 4         3 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8 2         10
+--R                       2560a b c  - 128a b  c
+--R            + 
+--R                      4 2 4         4   2        3   2   3
+--R                  432A a c  + (1080A a b  - 2160A B a b)c
+--R                + 
+--R                       4 4        3     3          3 3        4 4  2
+--R                  (135A b  - 1080A B a b  + 2160A B a b - 432B a )c
+--R                + 
+--R                        3   5          3 2 3        4 3 2          3   5
+--R                  (- 27A B b  + 1080A B a b  - 1080B a b )c + 27A B a b
+--R                + 
+--R                        4 2 4
+--R                  - 135B a b
+--R             *
+--R                x
+--R     + 
+--R                 2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c)x
+--R         + 
+--R                  3 3        4      6  4          3   2      2 3        5  2
+--R           (- 128a c  + 24a b c - 4b )x  + (- 128a b c  + 64a b c - 8a b )x
+--R         + 
+--R                4 2      3 2      2 4
+--R           - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                             6 6          5 2 5          4 4 4         3 6 3
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           2 8 2         10
+--R                    - 5120a b c  + 256a b  c
+--R               *
+--R                  ROOT
+--R                            4 2       2 2         4 2
+--R                       - 81A c  + 162A B a c - 81B a
+--R                    /
+--R                                  7 7            6 2 6            5 4 5
+--R                         67108864a c  - 83886080a b c  + 41943040a b c
+--R                       + 
+--R                                    4 6 4           3 8 3         2 10 2
+--R                         - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R              + 
+--R                     2 2            3  3
+--R                (720A a b - 576A B a )c
+--R              + 
+--R                     2   3            2 2       2 3   2
+--R                (360A a b  - 1440A B a b  + 720B a b)c
+--R              + 
+--R                   2 5             4       2 2 3       2   5
+--R                (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R           /
+--R                       6 6          5 2 5         4 4 4         3 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8 2         10
+--R                2560a b c  - 128a b  c
+--R      *
+--R         log
+--R                                  7              8  7
+--R                      (12582912A a b - 8388608B a )c
+--R                    + 
+--R                                    6 3             7 2  6
+--R                      (- 14680064A a b  + 4194304B a b )c
+--R                    + 
+--R                                 5 5             6 4  5
+--R                      (6553600A a b  + 2621440B a b )c
+--R                    + 
+--R                                   4 7             5 6  4
+--R                      (- 1310720A a b  - 2621440B a b )c
+--R                    + 
+--R                               3 9            4 8  3
+--R                      (81920A a b  + 819200B a b )c
+--R                    + 
+--R                              2 11            3 10  2
+--R                      (8192A a b   - 114688B a b  )c
+--R                    + 
+--R                                  13          2 12
+--R                      (- 1024A a b   + 6144B a b  )c
+--R                 *
+--R                    ROOT
+--R                              4 2       2 2         4 2
+--R                         - 81A c  + 162A B a c - 81B a
+--R                      /
+--R                                    7 7            6 2 6            5 4 5
+--R                           67108864a c  - 83886080a b c  + 41943040a b c
+--R                         + 
+--R                                      4 6 4           3 8 3         2 10 2
+--R                           - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                + 
+--R                         3 4 5         3 3 2        2   4           2 5  4
+--R                  - 9216A a c  + (4608A a b  + 9216A B a b + 9216A B a )c
+--R                + 
+--R                          2   3 3          2 4 2        3 5   3
+--R                  (- 6912A B a b  - 4608A B a b  - 9216B a b)c
+--R                + 
+--R                         3   6        2   2 5        3 4 3  2
+--R                  (- 288A a b  + 1728A B a b  + 6912B a b )c
+--R                + 
+--R                      3 8       2     7         2 2 6        3 3 5
+--R                  (36A b  - 144A B a b  + 288A B a b  - 1728B a b )c
+--R                + 
+--R                         2   8       3 2 7
+--R                  - 36A B a b  + 144B a b
+--R             *
+--R                ROOT
+--R                                    6 6          5 2 5          4 4 4
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 3 6 3        2 8 2         10
+--R                           40960a b c  - 5120a b c  + 256a b  c
+--R                      *
+--R                         ROOT
+--R                                   4 2       2 2         4 2
+--R                              - 81A c  + 162A B a c - 81B a
+--R                           /
+--R                                         7 7            6 2 6            5 4 5
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 4           3 8 3         2 10 2
+--R                                - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                     + 
+--R                            2 2            3  3
+--R                       (720A a b - 576A B a )c
+--R                     + 
+--R                            2   3            2 2       2 3   2
+--R                       (360A a b  - 1440A B a b  + 720B a b)c
+--R                     + 
+--R                          2 5             4       2 2 3       2   5
+--R                       (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R                  /
+--R                              6 6          5 2 5         4 4 4         3 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8 2         10
+--R                       2560a b c  - 128a b  c
+--R            + 
+--R                      4 2 4         4   2        3   2   3
+--R                  432A a c  + (1080A a b  - 2160A B a b)c
+--R                + 
+--R                       4 4        3     3          3 3        4 4  2
+--R                  (135A b  - 1080A B a b  + 2160A B a b - 432B a )c
+--R                + 
+--R                        3   5          3 2 3        4 3 2          3   5
+--R                  (- 27A B b  + 1080A B a b  - 1080B a b )c + 27A B a b
+--R                + 
+--R                        4 2 4
+--R                  - 135B a b
+--R             *
+--R                x
+--R     + 
+--R               2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R         + 
+--R                3 3        4      6  4        3   2      2 3        5  2
+--R           (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              4 2      3 2      2 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                             6 6          5 2 5          4 4 4         3 6 3
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           2 8 2         10
+--R                    - 5120a b c  + 256a b  c
+--R               *
+--R                  ROOT
+--R                            4 2       2 2         4 2
+--R                       - 81A c  + 162A B a c - 81B a
+--R                    /
+--R                                  7 7            6 2 6            5 4 5
+--R                         67108864a c  - 83886080a b c  + 41943040a b c
+--R                       + 
+--R                                    4 6 4           3 8 3         2 10 2
+--R                         - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R              + 
+--R                     2 2            3  3
+--R                (720A a b - 576A B a )c
+--R              + 
+--R                     2   3            2 2       2 3   2
+--R                (360A a b  - 1440A B a b  + 720B a b)c
+--R              + 
+--R                   2 5             4       2 2 3       2   5
+--R                (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R           /
+--R                       6 6          5 2 5         4 4 4         3 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8 2         10
+--R                2560a b c  - 128a b  c
+--R      *
+--R         log
+--R                                    7              8  7
+--R                      (- 12582912A a b + 8388608B a )c
+--R                    + 
+--R                                  6 3             7 2  6
+--R                      (14680064A a b  - 4194304B a b )c
+--R                    + 
+--R                                   5 5             6 4  5
+--R                      (- 6553600A a b  - 2621440B a b )c
+--R                    + 
+--R                                 4 7             5 6  4
+--R                      (1310720A a b  + 2621440B a b )c
+--R                    + 
+--R                                 3 9            4 8  3
+--R                      (- 81920A a b  - 819200B a b )c
+--R                    + 
+--R                                2 11            3 10  2
+--R                      (- 8192A a b   + 114688B a b  )c
+--R                    + 
+--R                                13          2 12
+--R                      (1024A a b   - 6144B a b  )c
+--R                 *
+--R                    ROOT
+--R                              4 2       2 2         4 2
+--R                         - 81A c  + 162A B a c - 81B a
+--R                      /
+--R                                    7 7            6 2 6            5 4 5
+--R                           67108864a c  - 83886080a b c  + 41943040a b c
+--R                         + 
+--R                                      4 6 4           3 8 3         2 10 2
+--R                           - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                + 
+--R                       3 4 5           3 3 2        2   4           2 5  4
+--R                  9216A a c  + (- 4608A a b  - 9216A B a b - 9216A B a )c
+--R                + 
+--R                        2   3 3          2 4 2        3 5   3
+--R                  (6912A B a b  + 4608A B a b  + 9216B a b)c
+--R                + 
+--R                       3   6        2   2 5        3 4 3  2
+--R                  (288A a b  - 1728A B a b  - 6912B a b )c
+--R                + 
+--R                        3 8       2     7         2 2 6        3 3 5
+--R                  (- 36A b  + 144A B a b  - 288A B a b  + 1728B a b )c
+--R                + 
+--R                       2   8       3 2 7
+--R                  36A B a b  - 144B a b
+--R             *
+--R                ROOT
+--R                                    6 6          5 2 5          4 4 4
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 3 6 3        2 8 2         10
+--R                           40960a b c  - 5120a b c  + 256a b  c
+--R                      *
+--R                         ROOT
+--R                                   4 2       2 2         4 2
+--R                              - 81A c  + 162A B a c - 81B a
+--R                           /
+--R                                         7 7            6 2 6            5 4 5
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 4           3 8 3         2 10 2
+--R                                - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                     + 
+--R                            2 2            3  3
+--R                       (720A a b - 576A B a )c
+--R                     + 
+--R                            2   3            2 2       2 3   2
+--R                       (360A a b  - 1440A B a b  + 720B a b)c
+--R                     + 
+--R                          2 5             4       2 2 3       2   5
+--R                       (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R                  /
+--R                              6 6          5 2 5         4 4 4         3 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8 2         10
+--R                       2560a b c  - 128a b  c
+--R            + 
+--R                      4 2 4         4   2        3   2   3
+--R                  432A a c  + (1080A a b  - 2160A B a b)c
+--R                + 
+--R                       4 4        3     3          3 3        4 4  2
+--R                  (135A b  - 1080A B a b  + 2160A B a b - 432B a )c
+--R                + 
+--R                        3   5          3 2 3        4 3 2          3   5
+--R                  (- 27A B b  + 1080A B a b  - 1080B a b )c + 27A B a b
+--R                + 
+--R                        4 2 4
+--R                  - 135B a b
+--R             *
+--R                x
+--R     + 
+--R                 2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 64a c  + 32a b c  - 4b c )x  + (- 128a b c  + 64a b c  - 8b c)x
+--R         + 
+--R                  3 3        4      6  4          3   2      2 3        5  2
+--R           (- 128a c  + 24a b c - 4b )x  + (- 128a b c  + 64a b c - 8a b )x
+--R         + 
+--R                4 2      3 2      2 4
+--R           - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                           6 6          5 2 5          4 4 4         3 6 3
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         2 8 2         10
+--R                    5120a b c  - 256a b  c
+--R               *
+--R                  ROOT
+--R                            4 2       2 2         4 2
+--R                       - 81A c  + 162A B a c - 81B a
+--R                    /
+--R                                  7 7            6 2 6            5 4 5
+--R                         67108864a c  - 83886080a b c  + 41943040a b c
+--R                       + 
+--R                                    4 6 4           3 8 3         2 10 2
+--R                         - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R              + 
+--R                     2 2            3  3
+--R                (720A a b - 576A B a )c
+--R              + 
+--R                     2   3            2 2       2 3   2
+--R                (360A a b  - 1440A B a b  + 720B a b)c
+--R              + 
+--R                   2 5             4       2 2 3       2   5
+--R                (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R           /
+--R                       6 6          5 2 5         4 4 4         3 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8 2         10
+--R                2560a b c  - 128a b  c
+--R      *
+--R         log
+--R                                    7              8  7
+--R                      (- 12582912A a b + 8388608B a )c
+--R                    + 
+--R                                  6 3             7 2  6
+--R                      (14680064A a b  - 4194304B a b )c
+--R                    + 
+--R                                   5 5             6 4  5
+--R                      (- 6553600A a b  - 2621440B a b )c
+--R                    + 
+--R                                 4 7             5 6  4
+--R                      (1310720A a b  + 2621440B a b )c
+--R                    + 
+--R                                 3 9            4 8  3
+--R                      (- 81920A a b  - 819200B a b )c
+--R                    + 
+--R                                2 11            3 10  2
+--R                      (- 8192A a b   + 114688B a b  )c
+--R                    + 
+--R                                13          2 12
+--R                      (1024A a b   - 6144B a b  )c
+--R                 *
+--R                    ROOT
+--R                              4 2       2 2         4 2
+--R                         - 81A c  + 162A B a c - 81B a
+--R                      /
+--R                                    7 7            6 2 6            5 4 5
+--R                           67108864a c  - 83886080a b c  + 41943040a b c
+--R                         + 
+--R                                      4 6 4           3 8 3         2 10 2
+--R                           - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                + 
+--R                         3 4 5         3 3 2        2   4           2 5  4
+--R                  - 9216A a c  + (4608A a b  + 9216A B a b + 9216A B a )c
+--R                + 
+--R                          2   3 3          2 4 2        3 5   3
+--R                  (- 6912A B a b  - 4608A B a b  - 9216B a b)c
+--R                + 
+--R                         3   6        2   2 5        3 4 3  2
+--R                  (- 288A a b  + 1728A B a b  + 6912B a b )c
+--R                + 
+--R                      3 8       2     7         2 2 6        3 3 5
+--R                  (36A b  - 144A B a b  + 288A B a b  - 1728B a b )c
+--R                + 
+--R                         2   8       3 2 7
+--R                  - 36A B a b  + 144B a b
+--R             *
+--R                ROOT
+--R                                  6 6          5 2 5          4 4 4
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   3 6 3        2 8 2         10
+--R                           - 40960a b c  + 5120a b c  - 256a b  c
+--R                      *
+--R                         ROOT
+--R                                   4 2       2 2         4 2
+--R                              - 81A c  + 162A B a c - 81B a
+--R                           /
+--R                                         7 7            6 2 6            5 4 5
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 4           3 8 3         2 10 2
+--R                                - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                     + 
+--R                            2 2            3  3
+--R                       (720A a b - 576A B a )c
+--R                     + 
+--R                            2   3            2 2       2 3   2
+--R                       (360A a b  - 1440A B a b  + 720B a b)c
+--R                     + 
+--R                          2 5             4       2 2 3       2   5
+--R                       (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R                  /
+--R                              6 6          5 2 5         4 4 4         3 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8 2         10
+--R                       2560a b c  - 128a b  c
+--R            + 
+--R                      4 2 4         4   2        3   2   3
+--R                  432A a c  + (1080A a b  - 2160A B a b)c
+--R                + 
+--R                       4 4        3     3          3 3        4 4  2
+--R                  (135A b  - 1080A B a b  + 2160A B a b - 432B a )c
+--R                + 
+--R                        3   5          3 2 3        4 3 2          3   5
+--R                  (- 27A B b  + 1080A B a b  - 1080B a b )c + 27A B a b
+--R                + 
+--R                        4 2 4
+--R                  - 135B a b
+--R             *
+--R                x
+--R     + 
+--R                          2       2   7
+--R       ((- 12A b + 12B a)c  + 3B b c)x
+--R     + 
+--R              2           2                   3  5
+--R       (4A a c  + (- 19A b  + 16B a b)c + 5B b )x
+--R     + 
+--R                         2         3          2  3
+--R       ((- 16A a b - 4B a )c - 5A b  + 19B a b )x
+--R     + 
+--R               2          2        2
+--R       (- 12A a c - 3A a b  + 12B a b)x
+--R  /
+--R            2 4        2 3     4 2  8        2   3         3 2      5   6
+--R       (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R     + 
+--R            3 3        4      6  4        3   2       2 3         5  2       4 2
+--R       (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x  + 128a c
+--R     + 
+--R            3 2      2 4
+--R       - 64a b c + 8a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2315
+
+--S 2316 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                        +--------------------+
+--R                                      +-----------+     |   +-----------+
+--R             2 2        2      4  +-+ |          2  +-+ |   |          2
+--R         (64a c  - 32a b c + 4b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           6 6          5 2 5          4 4 4         3 6 3
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         2 8 2         10
+--R                    5120a b c  - 256a b  c
+--R               *
+--R                  ROOT
+--R                            4 2       2 2         4 2
+--R                       - 81A c  + 162A B a c - 81B a
+--R                    /
+--R                                  7 7            6 2 6            5 4 5
+--R                         67108864a c  - 83886080a b c  + 41943040a b c
+--R                       + 
+--R                                    4 6 4           3 8 3         2 10 2
+--R                         - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R              + 
+--R                     2 2            3  3
+--R                (720A a b - 576A B a )c
+--R              + 
+--R                     2   3            2 2       2 3   2
+--R                (360A a b  - 1440A B a b  + 720B a b)c
+--R              + 
+--R                   2 5             4       2 2 3       2   5
+--R                (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R           /
+--R                       6 6          5 2 5         4 4 4         3 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8 2         10
+--R                2560a b c  - 128a b  c
+--R      *
+--R         log
+--R                                  7              8  7
+--R                      (12582912A a b - 8388608B a )c
+--R                    + 
+--R                                    6 3             7 2  6
+--R                      (- 14680064A a b  + 4194304B a b )c
+--R                    + 
+--R                                 5 5             6 4  5
+--R                      (6553600A a b  + 2621440B a b )c
+--R                    + 
+--R                                   4 7             5 6  4
+--R                      (- 1310720A a b  - 2621440B a b )c
+--R                    + 
+--R                               3 9            4 8  3
+--R                      (81920A a b  + 819200B a b )c
+--R                    + 
+--R                              2 11            3 10  2
+--R                      (8192A a b   - 114688B a b  )c
+--R                    + 
+--R                                  13          2 12
+--R                      (- 1024A a b   + 6144B a b  )c
+--R                 *
+--R                    ROOT
+--R                              4 2       2 2         4 2
+--R                         - 81A c  + 162A B a c - 81B a
+--R                      /
+--R                                    7 7            6 2 6            5 4 5
+--R                           67108864a c  - 83886080a b c  + 41943040a b c
+--R                         + 
+--R                                      4 6 4           3 8 3         2 10 2
+--R                           - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                + 
+--R                       3 4 5           3 3 2        2   4           2 5  4
+--R                  9216A a c  + (- 4608A a b  - 9216A B a b - 9216A B a )c
+--R                + 
+--R                        2   3 3          2 4 2        3 5   3
+--R                  (6912A B a b  + 4608A B a b  + 9216B a b)c
+--R                + 
+--R                       3   6        2   2 5        3 4 3  2
+--R                  (288A a b  - 1728A B a b  - 6912B a b )c
+--R                + 
+--R                        3 8       2     7         2 2 6        3 3 5
+--R                  (- 36A b  + 144A B a b  - 288A B a b  + 1728B a b )c
+--R                + 
+--R                       2   8       3 2 7
+--R                  36A B a b  - 144B a b
+--R             *
+--R                ROOT
+--R                                  6 6          5 2 5          4 4 4
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   3 6 3        2 8 2         10
+--R                           - 40960a b c  + 5120a b c  - 256a b  c
+--R                      *
+--R                         ROOT
+--R                                   4 2       2 2         4 2
+--R                              - 81A c  + 162A B a c - 81B a
+--R                           /
+--R                                         7 7            6 2 6            5 4 5
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 4           3 8 3         2 10 2
+--R                                - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                     + 
+--R                            2 2            3  3
+--R                       (720A a b - 576A B a )c
+--R                     + 
+--R                            2   3            2 2       2 3   2
+--R                       (360A a b  - 1440A B a b  + 720B a b)c
+--R                     + 
+--R                          2 5             4       2 2 3       2   5
+--R                       (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R                  /
+--R                              6 6          5 2 5         4 4 4         3 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8 2         10
+--R                       2560a b c  - 128a b  c
+--R            + 
+--R                      4 2 4         4   2        3   2   3
+--R                  432A a c  + (1080A a b  - 2160A B a b)c
+--R                + 
+--R                       4 4        3     3          3 3        4 4  2
+--R                  (135A b  - 1080A B a b  + 2160A B a b - 432B a )c
+--R                + 
+--R                        3   5          3 2 3        4 3 2          3   5
+--R                  (- 27A B b  + 1080A B a b  - 1080B a b )c + 27A B a b
+--R                + 
+--R                        4 2 4
+--R                  - 135B a b
+--R             *
+--R                x
+--R     + 
+--R                                        +-----------+
+--R               2 2        2      4  +-+ |          2  +-+
+--R         (- 64a c  + 32a b c - 4b )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                             6 6          5 2 5          4 4 4         3 6 3
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           2 8 2         10
+--R                    - 5120a b c  + 256a b  c
+--R               *
+--R                  ROOT
+--R                            4 2       2 2         4 2
+--R                       - 81A c  + 162A B a c - 81B a
+--R                    /
+--R                                  7 7            6 2 6            5 4 5
+--R                         67108864a c  - 83886080a b c  + 41943040a b c
+--R                       + 
+--R                                    4 6 4           3 8 3         2 10 2
+--R                         - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R              + 
+--R                     2 2            3  3
+--R                (720A a b - 576A B a )c
+--R              + 
+--R                     2   3            2 2       2 3   2
+--R                (360A a b  - 1440A B a b  + 720B a b)c
+--R              + 
+--R                   2 5             4       2 2 3       2   5
+--R                (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R           /
+--R                       6 6          5 2 5         4 4 4         3 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8 2         10
+--R                2560a b c  - 128a b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                  7              8  7
+--R                      (12582912A a b - 8388608B a )c
+--R                    + 
+--R                                    6 3             7 2  6
+--R                      (- 14680064A a b  + 4194304B a b )c
+--R                    + 
+--R                                 5 5             6 4  5
+--R                      (6553600A a b  + 2621440B a b )c
+--R                    + 
+--R                                   4 7             5 6  4
+--R                      (- 1310720A a b  - 2621440B a b )c
+--R                    + 
+--R                               3 9            4 8  3
+--R                      (81920A a b  + 819200B a b )c
+--R                    + 
+--R                              2 11            3 10  2
+--R                      (8192A a b   - 114688B a b  )c
+--R                    + 
+--R                                  13          2 12
+--R                      (- 1024A a b   + 6144B a b  )c
+--R                 *
+--R                    ROOT
+--R                              4 2       2 2         4 2
+--R                         - 81A c  + 162A B a c - 81B a
+--R                      /
+--R                                    7 7            6 2 6            5 4 5
+--R                           67108864a c  - 83886080a b c  + 41943040a b c
+--R                         + 
+--R                                      4 6 4           3 8 3         2 10 2
+--R                           - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                + 
+--R                         3 4 5         3 3 2        2   4           2 5  4
+--R                  - 9216A a c  + (4608A a b  + 9216A B a b + 9216A B a )c
+--R                + 
+--R                          2   3 3          2 4 2        3 5   3
+--R                  (- 6912A B a b  - 4608A B a b  - 9216B a b)c
+--R                + 
+--R                         3   6        2   2 5        3 4 3  2
+--R                  (- 288A a b  + 1728A B a b  + 6912B a b )c
+--R                + 
+--R                      3 8       2     7         2 2 6        3 3 5
+--R                  (36A b  - 144A B a b  + 288A B a b  - 1728B a b )c
+--R                + 
+--R                         2   8       3 2 7
+--R                  - 36A B a b  + 144B a b
+--R             *
+--R                ROOT
+--R                                    6 6          5 2 5          4 4 4
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 3 6 3        2 8 2         10
+--R                           40960a b c  - 5120a b c  + 256a b  c
+--R                      *
+--R                         ROOT
+--R                                   4 2       2 2         4 2
+--R                              - 81A c  + 162A B a c - 81B a
+--R                           /
+--R                                         7 7            6 2 6            5 4 5
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 4           3 8 3         2 10 2
+--R                                - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                     + 
+--R                            2 2            3  3
+--R                       (720A a b - 576A B a )c
+--R                     + 
+--R                            2   3            2 2       2 3   2
+--R                       (360A a b  - 1440A B a b  + 720B a b)c
+--R                     + 
+--R                          2 5             4       2 2 3       2   5
+--R                       (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R                  /
+--R                              6 6          5 2 5         4 4 4         3 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8 2         10
+--R                       2560a b c  - 128a b  c
+--R            + 
+--R                      4 2 4         4   2        3   2   3
+--R                  432A a c  + (1080A a b  - 2160A B a b)c
+--R                + 
+--R                       4 4        3     3          3 3        4 4  2
+--R                  (135A b  - 1080A B a b  + 2160A B a b - 432B a )c
+--R                + 
+--R                        3   5          3 2 3        4 3 2          3   5
+--R                  (- 27A B b  + 1080A B a b  - 1080B a b )c + 27A B a b
+--R                + 
+--R                        4 2 4
+--R                  - 135B a b
+--R             *
+--R                x
+--R     + 
+--R                                      +-----------+
+--R             2 2        2      4  +-+ |          2  +-+
+--R         (64a c  - 32a b c + 4b )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                             6 6          5 2 5          4 4 4         3 6 3
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           2 8 2         10
+--R                    - 5120a b c  + 256a b  c
+--R               *
+--R                  ROOT
+--R                            4 2       2 2         4 2
+--R                       - 81A c  + 162A B a c - 81B a
+--R                    /
+--R                                  7 7            6 2 6            5 4 5
+--R                         67108864a c  - 83886080a b c  + 41943040a b c
+--R                       + 
+--R                                    4 6 4           3 8 3         2 10 2
+--R                         - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R              + 
+--R                     2 2            3  3
+--R                (720A a b - 576A B a )c
+--R              + 
+--R                     2   3            2 2       2 3   2
+--R                (360A a b  - 1440A B a b  + 720B a b)c
+--R              + 
+--R                   2 5             4       2 2 3       2   5
+--R                (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R           /
+--R                       6 6          5 2 5         4 4 4         3 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8 2         10
+--R                2560a b c  - 128a b  c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                    7              8  7
+--R                      (- 12582912A a b + 8388608B a )c
+--R                    + 
+--R                                  6 3             7 2  6
+--R                      (14680064A a b  - 4194304B a b )c
+--R                    + 
+--R                                   5 5             6 4  5
+--R                      (- 6553600A a b  - 2621440B a b )c
+--R                    + 
+--R                                 4 7             5 6  4
+--R                      (1310720A a b  + 2621440B a b )c
+--R                    + 
+--R                                 3 9            4 8  3
+--R                      (- 81920A a b  - 819200B a b )c
+--R                    + 
+--R                                2 11            3 10  2
+--R                      (- 8192A a b   + 114688B a b  )c
+--R                    + 
+--R                                13          2 12
+--R                      (1024A a b   - 6144B a b  )c
+--R                 *
+--R                    ROOT
+--R                              4 2       2 2         4 2
+--R                         - 81A c  + 162A B a c - 81B a
+--R                      /
+--R                                    7 7            6 2 6            5 4 5
+--R                           67108864a c  - 83886080a b c  + 41943040a b c
+--R                         + 
+--R                                      4 6 4           3 8 3         2 10 2
+--R                           - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                + 
+--R                       3 4 5           3 3 2        2   4           2 5  4
+--R                  9216A a c  + (- 4608A a b  - 9216A B a b - 9216A B a )c
+--R                + 
+--R                        2   3 3          2 4 2        3 5   3
+--R                  (6912A B a b  + 4608A B a b  + 9216B a b)c
+--R                + 
+--R                       3   6        2   2 5        3 4 3  2
+--R                  (288A a b  - 1728A B a b  - 6912B a b )c
+--R                + 
+--R                        3 8       2     7         2 2 6        3 3 5
+--R                  (- 36A b  + 144A B a b  - 288A B a b  + 1728B a b )c
+--R                + 
+--R                       2   8       3 2 7
+--R                  36A B a b  - 144B a b
+--R             *
+--R                ROOT
+--R                                    6 6          5 2 5          4 4 4
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 3 6 3        2 8 2         10
+--R                           40960a b c  - 5120a b c  + 256a b  c
+--R                      *
+--R                         ROOT
+--R                                   4 2       2 2         4 2
+--R                              - 81A c  + 162A B a c - 81B a
+--R                           /
+--R                                         7 7            6 2 6            5 4 5
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 4           3 8 3         2 10 2
+--R                                - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                     + 
+--R                            2 2            3  3
+--R                       (720A a b - 576A B a )c
+--R                     + 
+--R                            2   3            2 2       2 3   2
+--R                       (360A a b  - 1440A B a b  + 720B a b)c
+--R                     + 
+--R                          2 5             4       2 2 3       2   5
+--R                       (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R                  /
+--R                              6 6          5 2 5         4 4 4         3 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8 2         10
+--R                       2560a b c  - 128a b  c
+--R            + 
+--R                      4 2 4         4   2        3   2   3
+--R                  432A a c  + (1080A a b  - 2160A B a b)c
+--R                + 
+--R                       4 4        3     3          3 3        4 4  2
+--R                  (135A b  - 1080A B a b  + 2160A B a b - 432B a )c
+--R                + 
+--R                        3   5          3 2 3        4 3 2          3   5
+--R                  (- 27A B b  + 1080A B a b  - 1080B a b )c + 27A B a b
+--R                + 
+--R                        4 2 4
+--R                  - 135B a b
+--R             *
+--R                x
+--R     + 
+--R                                                          +--------------------+
+--R                                        +-----------+     |   +-----------+
+--R               2 2        2      4  +-+ |          2  +-+ |   |          2
+--R         (- 64a c  + 32a b c - 4b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           6 6          5 2 5          4 4 4         3 6 3
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         2 8 2         10
+--R                    5120a b c  - 256a b  c
+--R               *
+--R                  ROOT
+--R                            4 2       2 2         4 2
+--R                       - 81A c  + 162A B a c - 81B a
+--R                    /
+--R                                  7 7            6 2 6            5 4 5
+--R                         67108864a c  - 83886080a b c  + 41943040a b c
+--R                       + 
+--R                                    4 6 4           3 8 3         2 10 2
+--R                         - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R              + 
+--R                     2 2            3  3
+--R                (720A a b - 576A B a )c
+--R              + 
+--R                     2   3            2 2       2 3   2
+--R                (360A a b  - 1440A B a b  + 720B a b)c
+--R              + 
+--R                   2 5             4       2 2 3       2   5
+--R                (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R           /
+--R                       6 6          5 2 5         4 4 4         3 6 3
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     2 8 2         10
+--R                2560a b c  - 128a b  c
+--R      *
+--R         log
+--R                                    7              8  7
+--R                      (- 12582912A a b + 8388608B a )c
+--R                    + 
+--R                                  6 3             7 2  6
+--R                      (14680064A a b  - 4194304B a b )c
+--R                    + 
+--R                                   5 5             6 4  5
+--R                      (- 6553600A a b  - 2621440B a b )c
+--R                    + 
+--R                                 4 7             5 6  4
+--R                      (1310720A a b  + 2621440B a b )c
+--R                    + 
+--R                                 3 9            4 8  3
+--R                      (- 81920A a b  - 819200B a b )c
+--R                    + 
+--R                                2 11            3 10  2
+--R                      (- 8192A a b   + 114688B a b  )c
+--R                    + 
+--R                                13          2 12
+--R                      (1024A a b   - 6144B a b  )c
+--R                 *
+--R                    ROOT
+--R                              4 2       2 2         4 2
+--R                         - 81A c  + 162A B a c - 81B a
+--R                      /
+--R                                    7 7            6 2 6            5 4 5
+--R                           67108864a c  - 83886080a b c  + 41943040a b c
+--R                         + 
+--R                                      4 6 4           3 8 3         2 10 2
+--R                           - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                + 
+--R                         3 4 5         3 3 2        2   4           2 5  4
+--R                  - 9216A a c  + (4608A a b  + 9216A B a b + 9216A B a )c
+--R                + 
+--R                          2   3 3          2 4 2        3 5   3
+--R                  (- 6912A B a b  - 4608A B a b  - 9216B a b)c
+--R                + 
+--R                         3   6        2   2 5        3 4 3  2
+--R                  (- 288A a b  + 1728A B a b  + 6912B a b )c
+--R                + 
+--R                      3 8       2     7         2 2 6        3 3 5
+--R                  (36A b  - 144A B a b  + 288A B a b  - 1728B a b )c
+--R                + 
+--R                         2   8       3 2 7
+--R                  - 36A B a b  + 144B a b
+--R             *
+--R                ROOT
+--R                                  6 6          5 2 5          4 4 4
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   3 6 3        2 8 2         10
+--R                           - 40960a b c  + 5120a b c  - 256a b  c
+--R                      *
+--R                         ROOT
+--R                                   4 2       2 2         4 2
+--R                              - 81A c  + 162A B a c - 81B a
+--R                           /
+--R                                         7 7            6 2 6            5 4 5
+--R                                67108864a c  - 83886080a b c  + 41943040a b c
+--R                              + 
+--R                                           4 6 4           3 8 3         2 10 2
+--R                                - 10485760a b c  + 1310720a b c  - 65536a b  c
+--R                     + 
+--R                            2 2            3  3
+--R                       (720A a b - 576A B a )c
+--R                     + 
+--R                            2   3            2 2       2 3   2
+--R                       (360A a b  - 1440A B a b  + 720B a b)c
+--R                     + 
+--R                          2 5             4       2 2 3       2   5
+--R                       (9A b  - 180A B a b  + 360B a b )c + 9B a b
+--R                  /
+--R                              6 6          5 2 5         4 4 4         3 6 3
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            2 8 2         10
+--R                       2560a b c  - 128a b  c
+--R            + 
+--R                      4 2 4         4   2        3   2   3
+--R                  432A a c  + (1080A a b  - 2160A B a b)c
+--R                + 
+--R                       4 4        3     3          3 3        4 4  2
+--R                  (135A b  - 1080A B a b  + 2160A B a b - 432B a )c
+--R                + 
+--R                        3   5          3 2 3        4 3 2          3   5
+--R                  (- 27A B b  + 1080A B a b  - 1080B a b )c + 27A B a b
+--R                + 
+--R                        4 2 4
+--R                  - 135B a b
+--R             *
+--R                x
+--R     + 
+--R                                      +-----------+
+--R                                   2  |          2           2
+--R           ((12A b - 12B a)c - 3B b )\|- 4a c + b   - 24A a c
+--R         + 
+--R                   2                   3
+--R           (- 18A b  + 36B a b)c + 3B b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                      +-----------+
+--R                                   2  |          2           2
+--R           ((12A b - 12B a)c - 3B b )\|- 4a c + b   + 24A a c
+--R         + 
+--R                 2                   3
+--R           (18A b  - 36B a b)c - 3B b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                                       +--------------------+
+--R                                     +-----------+     |   +-----------+
+--R            2 2        2      4  +-+ |          2  +-+ |   |          2
+--R       (128a c  - 64a b c + 8b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2316
+
+--S 2317 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2317
+
+)clear all
+
+--S 2318 of 3139
+t0:=x^2*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        4      2
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2318
+
+--S 2319 of 3139
+r0:=-1/4*x*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-_
+   1/8*x*(a*B*(7*b^2-4*a*c)-A*(b^3+8*a*b*c)+c*(12*a*b*B-A*(b^2+20*a*c))*_
+   x^2)/(a*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))-1/8*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(12*a*b*B-A*(b^2+20*a*c)+(-6*a*B*_
+   (3*b^2+4*a*c)-A*(b^3-52*a*b*c))/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(12*a*b*B-A*(b^2+20*a*c)+(6*a*B*(3*b^2+_
+   4*a*c)+A*(b^3-52*a*b*c))/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       3       2            2  8
+--R               (20A a c  + (A b  - 12B a b)c )x
+--R             + 
+--R                         2        3          2    6
+--R               (40A a b c  + (2A b  - 24B a b )c)x
+--R             + 
+--R                     2 2           2        2         4          3  4
+--R               (40A a c  + (22A a b  - 24B a b)c + A b  - 12B a b )x
+--R             + 
+--R                     2            3        2 2  2        3       2 2        3
+--R               (40A a b c + 2A a b  - 24B a b )x  + 20A a c + A a b  - 12B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                              2  3       3          2  2  8
+--R           ((- 52A a b + 24B a )c  + (A b  + 18B a b )c )x
+--R         + 
+--R                       2        2   2        4          3    6
+--R           ((- 104A a b  + 48B a b)c  + (2A b  + 36B a b )c)x
+--R         + 
+--R                        2         3  2             3        2 2        5
+--R               (- 104A a b + 48B a )c  + (- 50A a b  + 60B a b )c + A b
+--R             + 
+--R                      4
+--R               18B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     2 2        3            4        2 3  2
+--R           ((- 104A a b  + 48B a b)c + 2A a b  + 36B a b )x
+--R         + 
+--R                   3         4        2 3        3 2
+--R           (- 52A a b + 24B a )c + A a b  + 18B a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                       3       2            2  8
+--R               (20A a c  + (A b  - 12B a b)c )x
+--R             + 
+--R                         2        3          2    6
+--R               (40A a b c  + (2A b  - 24B a b )c)x
+--R             + 
+--R                     2 2           2        2         4          3  4
+--R               (40A a c  + (22A a b  - 24B a b)c + A b  - 12B a b )x
+--R             + 
+--R                     2            3        2 2  2        3       2 2        3
+--R               (40A a b c + 2A a b  - 24B a b )x  + 20A a c + A a b  - 12B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                            2  3         3          2  2  8
+--R           ((52A a b - 24B a )c  + (- A b  - 18B a b )c )x
+--R         + 
+--R                     2        2   2          4          3    6
+--R           ((104A a b  - 48B a b)c  + (- 2A b  - 36B a b )c)x
+--R         + 
+--R                   2         3  2           3        2 2        5          4  4
+--R           ((104A a b - 48B a )c  + (50A a b  - 60B a b )c - A b  - 18B a b )x
+--R         + 
+--R                   2 2        3            4        2 3  2         3         4
+--R           ((104A a b  - 48B a b)c - 2A a b  - 36B a b )x  + (52A a b - 24B a )c
+--R         + 
+--R                2 3        3 2
+--R           - A a b  - 18B a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   3       2            2  7
+--R           (20A a c  + (A b  - 12B a b)c )x
+--R         + 
+--R                           2  2        3          2    5
+--R           ((28A a b + 4B a )c  + (2A b  - 19B a b )c)x
+--R         + 
+--R                 2 2          2        2         4         3  3
+--R           (36A a c  + (5A a b  - 16B a b)c + A b  - 5B a b )x
+--R         + 
+--R                  2         3          3       2 2
+--R           ((16A a b - 12B a )c - A a b  - 3B a b )x
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              3 4      2 2 3       4 2  8        3   3       2 3 2        5   6
+--R         (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R              4 3      2 4        6  4        4   2       3 3       2 5  2
+--R         (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             5 2      4 2      3 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2319
+
+--S 2320 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 4      2 2 3       4 2  8        3   3      2 3 2       5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                4 3      2 4        6  4        4   2      3 3      2 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              5 2      4 2      3 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                               4 2 2       4   2       3   2        2 2 3
+--R                         - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                       + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                      2 3            4  3
+--R                (1680A a b - 960A B a )c
+--R              + 
+--R                     2 2 3            3 2       2 4   2
+--R                (280A a b  - 1920A B a b  + 720B a b)c
+--R              + 
+--R                      2   5          2 4       2 3 3      2 7           6
+--R                (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R              + 
+--R                  2 2 5
+--R                9B a b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 10 7                 9 2              10   6
+--R                      41943040A a  c  + (- 33554432A a b  - 37748736B a  b)c
+--R                    + 
+--R                                 8 4              9 3  5
+--R                      (1572864A a b  + 44040192B a b )c
+--R                    + 
+--R                                 7 6              8 5  4
+--R                      (6553600A a b  - 19660800B a b )c
+--R                    + 
+--R                                   6 8             7 7  3
+--R                      (- 2785280A a b  + 3932160B a b )c
+--R                    + 
+--R                                5 10            6 9  2
+--R                      (491520A a b   - 245760B a b )c
+--R                    + 
+--R                               4 12           5 11            3 14          4 13
+--R                    (- 38912A a b   - 24576B a b  )c + 1024A a b   + 3072B a b
+--R                 *
+--R                    ROOT
+--R                                 4 2 2       4   2       3   2        2 2 3
+--R                           - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                         + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                            3 5          2   6  5
+--R                  (- 102400A a b + 76800A B a )c
+--R                + 
+--R                         3 4 3         2   5 2           2 6          3 7  4
+--R                  (87296A a b  - 16896A B a b  + 18432A B a b - 27648B a )c
+--R                + 
+--R                                3 3 5         2   4 4           2 5 3
+--R                        - 27328A a b  - 18432A B a b  - 20736A B a b
+--R                      + 
+--R                              3 6 2
+--R                        13824B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3 2 7        2   3 6          2 4 5  2
+--R                  (3760A a b  + 8160A B a b  + 8640A B a b )c
+--R                + 
+--R                         3   9        2   2 8          2 3 7       3 4 6
+--R                  (- 212A a b  - 1068A B a b  - 1584A B a b  - 864B a b )c
+--R                + 
+--R                    3 11      2     10         2 2 9       3 3 8
+--R                  4A b   + 36A B a b   + 108A B a b  + 108B a b
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                      4 2 2
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3      4 4
+--R                                (50A a b  + 300A B a b + 450A B a )c - A b
+--R                              + 
+--R                                     3     3      2 2 2 2         3 3       4 4
+--R                                - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                             2 3            4  3
+--R                       (1680A a b - 960A B a )c
+--R                     + 
+--R                            2 2 3            3 2       2 4   2
+--R                       (280A a b  - 1920A B a b  + 720B a b)c
+--R                     + 
+--R                             2   5          2 4       2 3 3      2 7           6
+--R                       (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R                     + 
+--R                         2 2 5
+--R                       9B a b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                        4 3 5          4 2 2         3   3   4
+--R                  10000A a c  + (15000A a b  - 30000A B a b)c
+--R                + 
+--R                             4   4         3   2 3        2 2 3 2          3 4
+--R                      - 1491A a b  - 11592A B a b  + 9936A B a b  + 9072A B a b
+--R                    + 
+--R                             4 5
+--R                      - 1296B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         4 6       3     5        2 2 2 4          3 3 3
+--R                      35A b  + 945A B a b  + 3240A B a b  + 1080A B a b
+--R                    + 
+--R                             4 4 2
+--R                      - 3240B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   7       2 2   6         3 2 5       4 3 4
+--R                  (- 15A B b  - 135A B a b  - 405A B a b  - 405B a b )c
+--R             *
+--R                x
+--R     + 
+--R                 3 4      2 2 3       4 2  8
+--R           (- 64a c  + 32a b c  - 4a b c )x
+--R         + 
+--R                  3   3      2 3 2       5   6          4 3      2 4        6  4
+--R           (- 128a b c  + 64a b c  - 8a b c)x  + (- 128a c  + 24a b c - 4a b )x
+--R         + 
+--R                  4   2      3 3      2 5  2      5 2      4 2      3 4
+--R           (- 128a b c  + 64a b c - 8a b )x  - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                               4 2 2       4   2       3   2        2 2 3
+--R                         - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                       + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                      2 3            4  3
+--R                (1680A a b - 960A B a )c
+--R              + 
+--R                     2 2 3            3 2       2 4   2
+--R                (280A a b  - 1920A B a b  + 720B a b)c
+--R              + 
+--R                      2   5          2 4       2 3 3      2 7           6
+--R                (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R              + 
+--R                  2 2 5
+--R                9B a b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 10 7                 9 2              10   6
+--R                      41943040A a  c  + (- 33554432A a b  - 37748736B a  b)c
+--R                    + 
+--R                                 8 4              9 3  5
+--R                      (1572864A a b  + 44040192B a b )c
+--R                    + 
+--R                                 7 6              8 5  4
+--R                      (6553600A a b  - 19660800B a b )c
+--R                    + 
+--R                                   6 8             7 7  3
+--R                      (- 2785280A a b  + 3932160B a b )c
+--R                    + 
+--R                                5 10            6 9  2
+--R                      (491520A a b   - 245760B a b )c
+--R                    + 
+--R                               4 12           5 11            3 14          4 13
+--R                    (- 38912A a b   - 24576B a b  )c + 1024A a b   + 3072B a b
+--R                 *
+--R                    ROOT
+--R                                 4 2 2       4   2       3   2        2 2 3
+--R                           - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                         + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                          3 5          2   6  5
+--R                  (102400A a b - 76800A B a )c
+--R                + 
+--R                           3 4 3         2   5 2           2 6          3 7  4
+--R                  (- 87296A a b  + 16896A B a b  - 18432A B a b + 27648B a )c
+--R                + 
+--R                         3 3 5         2   4 4           2 5 3         3 6 2  3
+--R                  (27328A a b  + 18432A B a b  + 20736A B a b  - 13824B a b )c
+--R                + 
+--R                          3 2 7        2   3 6          2 4 5  2
+--R                  (- 3760A a b  - 8160A B a b  - 8640A B a b )c
+--R                + 
+--R                       3   9        2   2 8          2 3 7       3 4 6
+--R                  (212A a b  + 1068A B a b  + 1584A B a b  + 864B a b )c
+--R                + 
+--R                      3 11      2     10         2 2 9       3 3 8
+--R                  - 4A b   - 36A B a b   - 108A B a b  - 108B a b
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                      4 2 2
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3      4 4
+--R                                (50A a b  + 300A B a b + 450A B a )c - A b
+--R                              + 
+--R                                     3     3      2 2 2 2         3 3       4 4
+--R                                - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                             2 3            4  3
+--R                       (1680A a b - 960A B a )c
+--R                     + 
+--R                            2 2 3            3 2       2 4   2
+--R                       (280A a b  - 1920A B a b  + 720B a b)c
+--R                     + 
+--R                             2   5          2 4       2 3 3      2 7           6
+--R                       (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R                     + 
+--R                         2 2 5
+--R                       9B a b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                        4 3 5          4 2 2         3   3   4
+--R                  10000A a c  + (15000A a b  - 30000A B a b)c
+--R                + 
+--R                             4   4         3   2 3        2 2 3 2          3 4
+--R                      - 1491A a b  - 11592A B a b  + 9936A B a b  + 9072A B a b
+--R                    + 
+--R                             4 5
+--R                      - 1296B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         4 6       3     5        2 2 2 4          3 3 3
+--R                      35A b  + 945A B a b  + 3240A B a b  + 1080A B a b
+--R                    + 
+--R                             4 4 2
+--R                      - 3240B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   7       2 2   6         3 2 5       4 3 4
+--R                  (- 15A B b  - 135A B a b  - 405A B a b  - 405B a b )c
+--R             *
+--R                x
+--R     + 
+--R               3 4      2 2 3       4 2  8        3   3      2 3 2       5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                4 3      2 4        6  4        4   2      3 3      2 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              5 2      4 2      3 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                               4 2 2       4   2       3   2        2 2 3
+--R                         - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                       + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                      2 3            4  3
+--R                (1680A a b - 960A B a )c
+--R              + 
+--R                     2 2 3            3 2       2 4   2
+--R                (280A a b  - 1920A B a b  + 720B a b)c
+--R              + 
+--R                      2   5          2 4       2 3 3      2 7           6
+--R                (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R              + 
+--R                  2 2 5
+--R                9B a b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                   10 7               9 2              10   6
+--R                      - 41943040A a  c  + (33554432A a b  + 37748736B a  b)c
+--R                    + 
+--R                                   8 4              9 3  5
+--R                      (- 1572864A a b  - 44040192B a b )c
+--R                    + 
+--R                                   7 6              8 5  4
+--R                      (- 6553600A a b  + 19660800B a b )c
+--R                    + 
+--R                                 6 8             7 7  3
+--R                      (2785280A a b  - 3932160B a b )c
+--R                    + 
+--R                                  5 10            6 9  2
+--R                      (- 491520A a b   + 245760B a b )c
+--R                    + 
+--R                             4 12           5 11            3 14          4 13
+--R                    (38912A a b   + 24576B a b  )c - 1024A a b   - 3072B a b
+--R                 *
+--R                    ROOT
+--R                                 4 2 2       4   2       3   2        2 2 3
+--R                           - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                         + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                            3 5          2   6  5
+--R                  (- 102400A a b + 76800A B a )c
+--R                + 
+--R                         3 4 3         2   5 2           2 6          3 7  4
+--R                  (87296A a b  - 16896A B a b  + 18432A B a b - 27648B a )c
+--R                + 
+--R                                3 3 5         2   4 4           2 5 3
+--R                        - 27328A a b  - 18432A B a b  - 20736A B a b
+--R                      + 
+--R                              3 6 2
+--R                        13824B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3 2 7        2   3 6          2 4 5  2
+--R                  (3760A a b  + 8160A B a b  + 8640A B a b )c
+--R                + 
+--R                         3   9        2   2 8          2 3 7       3 4 6
+--R                  (- 212A a b  - 1068A B a b  - 1584A B a b  - 864B a b )c
+--R                + 
+--R                    3 11      2     10         2 2 9       3 3 8
+--R                  4A b   + 36A B a b   + 108A B a b  + 108B a b
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                      4 2 2
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3      4 4
+--R                                (50A a b  + 300A B a b + 450A B a )c - A b
+--R                              + 
+--R                                     3     3      2 2 2 2         3 3       4 4
+--R                                - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                             2 3            4  3
+--R                       (1680A a b - 960A B a )c
+--R                     + 
+--R                            2 2 3            3 2       2 4   2
+--R                       (280A a b  - 1920A B a b  + 720B a b)c
+--R                     + 
+--R                             2   5          2 4       2 3 3      2 7           6
+--R                       (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R                     + 
+--R                         2 2 5
+--R                       9B a b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                        4 3 5          4 2 2         3   3   4
+--R                  10000A a c  + (15000A a b  - 30000A B a b)c
+--R                + 
+--R                             4   4         3   2 3        2 2 3 2          3 4
+--R                      - 1491A a b  - 11592A B a b  + 9936A B a b  + 9072A B a b
+--R                    + 
+--R                             4 5
+--R                      - 1296B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         4 6       3     5        2 2 2 4          3 3 3
+--R                      35A b  + 945A B a b  + 3240A B a b  + 1080A B a b
+--R                    + 
+--R                             4 4 2
+--R                      - 3240B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   7       2 2   6         3 2 5       4 3 4
+--R                  (- 15A B b  - 135A B a b  - 405A B a b  - 405B a b )c
+--R             *
+--R                x
+--R     + 
+--R                 3 4      2 2 3       4 2  8
+--R           (- 64a c  + 32a b c  - 4a b c )x
+--R         + 
+--R                  3   3      2 3 2       5   6          4 3      2 4        6  4
+--R           (- 128a b c  + 64a b c  - 8a b c)x  + (- 128a c  + 24a b c - 4a b )x
+--R         + 
+--R                  4   2      3 3      2 5  2      5 2      4 2      3 4
+--R           (- 128a b c  + 64a b c - 8a b )x  - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                               4 2 2       4   2       3   2        2 2 3
+--R                         - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                       + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                      2 3            4  3
+--R                (1680A a b - 960A B a )c
+--R              + 
+--R                     2 2 3            3 2       2 4   2
+--R                (280A a b  - 1920A B a b  + 720B a b)c
+--R              + 
+--R                      2   5          2 4       2 3 3      2 7           6
+--R                (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R              + 
+--R                  2 2 5
+--R                9B a b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                   10 7               9 2              10   6
+--R                      - 41943040A a  c  + (33554432A a b  + 37748736B a  b)c
+--R                    + 
+--R                                   8 4              9 3  5
+--R                      (- 1572864A a b  - 44040192B a b )c
+--R                    + 
+--R                                   7 6              8 5  4
+--R                      (- 6553600A a b  + 19660800B a b )c
+--R                    + 
+--R                                 6 8             7 7  3
+--R                      (2785280A a b  - 3932160B a b )c
+--R                    + 
+--R                                  5 10            6 9  2
+--R                      (- 491520A a b   + 245760B a b )c
+--R                    + 
+--R                             4 12           5 11            3 14          4 13
+--R                    (38912A a b   + 24576B a b  )c - 1024A a b   - 3072B a b
+--R                 *
+--R                    ROOT
+--R                                 4 2 2       4   2       3   2        2 2 3
+--R                           - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                         + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                          3 5          2   6  5
+--R                  (102400A a b - 76800A B a )c
+--R                + 
+--R                           3 4 3         2   5 2           2 6          3 7  4
+--R                  (- 87296A a b  + 16896A B a b  - 18432A B a b + 27648B a )c
+--R                + 
+--R                         3 3 5         2   4 4           2 5 3         3 6 2  3
+--R                  (27328A a b  + 18432A B a b  + 20736A B a b  - 13824B a b )c
+--R                + 
+--R                          3 2 7        2   3 6          2 4 5  2
+--R                  (- 3760A a b  - 8160A B a b  - 8640A B a b )c
+--R                + 
+--R                       3   9        2   2 8          2 3 7       3 4 6
+--R                  (212A a b  + 1068A B a b  + 1584A B a b  + 864B a b )c
+--R                + 
+--R                      3 11      2     10         2 2 9       3 3 8
+--R                  - 4A b   - 36A B a b   - 108A B a b  - 108B a b
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                      4 2 2
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3      4 4
+--R                                (50A a b  + 300A B a b + 450A B a )c - A b
+--R                              + 
+--R                                     3     3      2 2 2 2         3 3       4 4
+--R                                - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                             2 3            4  3
+--R                       (1680A a b - 960A B a )c
+--R                     + 
+--R                            2 2 3            3 2       2 4   2
+--R                       (280A a b  - 1920A B a b  + 720B a b)c
+--R                     + 
+--R                             2   5          2 4       2 3 3      2 7           6
+--R                       (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R                     + 
+--R                         2 2 5
+--R                       9B a b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                        4 3 5          4 2 2         3   3   4
+--R                  10000A a c  + (15000A a b  - 30000A B a b)c
+--R                + 
+--R                             4   4         3   2 3        2 2 3 2          3 4
+--R                      - 1491A a b  - 11592A B a b  + 9936A B a b  + 9072A B a b
+--R                    + 
+--R                             4 5
+--R                      - 1296B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         4 6       3     5        2 2 2 4          3 3 3
+--R                      35A b  + 945A B a b  + 3240A B a b  + 1080A B a b
+--R                    + 
+--R                             4 4 2
+--R                      - 3240B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   7       2 2   6         3 2 5       4 3 4
+--R                  (- 15A B b  - 135A B a b  - 405A B a b  - 405B a b )c
+--R             *
+--R                x
+--R     + 
+--R               3       2            2  7
+--R       (20A a c  + (A b  - 12B a b)c )x
+--R     + 
+--R                       2  2        3          2    5
+--R       ((28A a b + 4B a )c  + (2A b  - 19B a b )c)x
+--R     + 
+--R             2 2          2        2         4         3  3
+--R       (36A a c  + (5A a b  - 16B a b)c + A b  - 5B a b )x
+--R     + 
+--R              2         3          3       2 2
+--R       ((16A a b - 12B a )c - A a b  - 3B a b )x
+--R  /
+--R            3 4      2 2 3       4 2  8        3   3       2 3 2        5   6
+--R       (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R     + 
+--R            4 3      2 4        6  4        4   2       3 3       2 5  2
+--R       (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R     + 
+--R           5 2      4 2      3 4
+--R       128a c  - 64a b c + 8a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2320
+
+--S 2321 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R             3 2      2 2        4  +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                               4 2 2       4   2       3   2        2 2 3
+--R                         - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                       + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                      2 3            4  3
+--R                (1680A a b - 960A B a )c
+--R              + 
+--R                     2 2 3            3 2       2 4   2
+--R                (280A a b  - 1920A B a b  + 720B a b)c
+--R              + 
+--R                      2   5          2 4       2 3 3      2 7           6
+--R                (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R              + 
+--R                  2 2 5
+--R                9B a b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                 10 7                 9 2              10   6
+--R                      41943040A a  c  + (- 33554432A a b  - 37748736B a  b)c
+--R                    + 
+--R                                 8 4              9 3  5
+--R                      (1572864A a b  + 44040192B a b )c
+--R                    + 
+--R                                 7 6              8 5  4
+--R                      (6553600A a b  - 19660800B a b )c
+--R                    + 
+--R                                   6 8             7 7  3
+--R                      (- 2785280A a b  + 3932160B a b )c
+--R                    + 
+--R                                5 10            6 9  2
+--R                      (491520A a b   - 245760B a b )c
+--R                    + 
+--R                               4 12           5 11            3 14          4 13
+--R                    (- 38912A a b   - 24576B a b  )c + 1024A a b   + 3072B a b
+--R                 *
+--R                    ROOT
+--R                                 4 2 2       4   2       3   2        2 2 3
+--R                           - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                         + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                            3 5          2   6  5
+--R                  (- 102400A a b + 76800A B a )c
+--R                + 
+--R                         3 4 3         2   5 2           2 6          3 7  4
+--R                  (87296A a b  - 16896A B a b  + 18432A B a b - 27648B a )c
+--R                + 
+--R                                3 3 5         2   4 4           2 5 3
+--R                        - 27328A a b  - 18432A B a b  - 20736A B a b
+--R                      + 
+--R                              3 6 2
+--R                        13824B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3 2 7        2   3 6          2 4 5  2
+--R                  (3760A a b  + 8160A B a b  + 8640A B a b )c
+--R                + 
+--R                         3   9        2   2 8          2 3 7       3 4 6
+--R                  (- 212A a b  - 1068A B a b  - 1584A B a b  - 864B a b )c
+--R                + 
+--R                    3 11      2     10         2 2 9       3 3 8
+--R                  4A b   + 36A B a b   + 108A B a b  + 108B a b
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                      4 2 2
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3      4 4
+--R                                (50A a b  + 300A B a b + 450A B a )c - A b
+--R                              + 
+--R                                     3     3      2 2 2 2         3 3       4 4
+--R                                - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                             2 3            4  3
+--R                       (1680A a b - 960A B a )c
+--R                     + 
+--R                            2 2 3            3 2       2 4   2
+--R                       (280A a b  - 1920A B a b  + 720B a b)c
+--R                     + 
+--R                             2   5          2 4       2 3 3      2 7           6
+--R                       (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R                     + 
+--R                         2 2 5
+--R                       9B a b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                        4 3 5          4 2 2         3   3   4
+--R                  10000A a c  + (15000A a b  - 30000A B a b)c
+--R                + 
+--R                             4   4         3   2 3        2 2 3 2          3 4
+--R                      - 1491A a b  - 11592A B a b  + 9936A B a b  + 9072A B a b
+--R                    + 
+--R                             4 5
+--R                      - 1296B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         4 6       3     5        2 2 2 4          3 3 3
+--R                      35A b  + 945A B a b  + 3240A B a b  + 1080A B a b
+--R                    + 
+--R                             4 4 2
+--R                      - 3240B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   7       2 2   6         3 2 5       4 3 4
+--R                  (- 15A B b  - 135A B a b  - 405A B a b  - 405B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                          +-----------+
+--R               3 2      2 2        4  +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                               4 2 2       4   2       3   2        2 2 3
+--R                         - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                       + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                      2 3            4  3
+--R                (1680A a b - 960A B a )c
+--R              + 
+--R                     2 2 3            3 2       2 4   2
+--R                (280A a b  - 1920A B a b  + 720B a b)c
+--R              + 
+--R                      2   5          2 4       2 3 3      2 7           6
+--R                (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R              + 
+--R                  2 2 5
+--R                9B a b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 10 7                 9 2              10   6
+--R                      41943040A a  c  + (- 33554432A a b  - 37748736B a  b)c
+--R                    + 
+--R                                 8 4              9 3  5
+--R                      (1572864A a b  + 44040192B a b )c
+--R                    + 
+--R                                 7 6              8 5  4
+--R                      (6553600A a b  - 19660800B a b )c
+--R                    + 
+--R                                   6 8             7 7  3
+--R                      (- 2785280A a b  + 3932160B a b )c
+--R                    + 
+--R                                5 10            6 9  2
+--R                      (491520A a b   - 245760B a b )c
+--R                    + 
+--R                               4 12           5 11            3 14          4 13
+--R                    (- 38912A a b   - 24576B a b  )c + 1024A a b   + 3072B a b
+--R                 *
+--R                    ROOT
+--R                                 4 2 2       4   2       3   2        2 2 3
+--R                           - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                         + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                          3 5          2   6  5
+--R                  (102400A a b - 76800A B a )c
+--R                + 
+--R                           3 4 3         2   5 2           2 6          3 7  4
+--R                  (- 87296A a b  + 16896A B a b  - 18432A B a b + 27648B a )c
+--R                + 
+--R                         3 3 5         2   4 4           2 5 3         3 6 2  3
+--R                  (27328A a b  + 18432A B a b  + 20736A B a b  - 13824B a b )c
+--R                + 
+--R                          3 2 7        2   3 6          2 4 5  2
+--R                  (- 3760A a b  - 8160A B a b  - 8640A B a b )c
+--R                + 
+--R                       3   9        2   2 8          2 3 7       3 4 6
+--R                  (212A a b  + 1068A B a b  + 1584A B a b  + 864B a b )c
+--R                + 
+--R                      3 11      2     10         2 2 9       3 3 8
+--R                  - 4A b   - 36A B a b   - 108A B a b  - 108B a b
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                      4 2 2
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3      4 4
+--R                                (50A a b  + 300A B a b + 450A B a )c - A b
+--R                              + 
+--R                                     3     3      2 2 2 2         3 3       4 4
+--R                                - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                             2 3            4  3
+--R                       (1680A a b - 960A B a )c
+--R                     + 
+--R                            2 2 3            3 2       2 4   2
+--R                       (280A a b  - 1920A B a b  + 720B a b)c
+--R                     + 
+--R                             2   5          2 4       2 3 3      2 7           6
+--R                       (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R                     + 
+--R                         2 2 5
+--R                       9B a b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                        4 3 5          4 2 2         3   3   4
+--R                  10000A a c  + (15000A a b  - 30000A B a b)c
+--R                + 
+--R                             4   4         3   2 3        2 2 3 2          3 4
+--R                      - 1491A a b  - 11592A B a b  + 9936A B a b  + 9072A B a b
+--R                    + 
+--R                             4 5
+--R                      - 1296B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         4 6       3     5        2 2 2 4          3 3 3
+--R                      35A b  + 945A B a b  + 3240A B a b  + 1080A B a b
+--R                    + 
+--R                             4 4 2
+--R                      - 3240B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   7       2 2   6         3 2 5       4 3 4
+--R                  (- 15A B b  - 135A B a b  - 405A B a b  - 405B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                        +-----------+
+--R             3 2      2 2        4  +-+ |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             8 5          7 2 4          6 4 3         5 6 2
+--R                    - 262144a c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           4 8        3 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                               4 2 2       4   2       3   2        2 2 3
+--R                         - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                       + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                      2 3            4  3
+--R                (1680A a b - 960A B a )c
+--R              + 
+--R                     2 2 3            3 2       2 4   2
+--R                (280A a b  - 1920A B a b  + 720B a b)c
+--R              + 
+--R                      2   5          2 4       2 3 3      2 7           6
+--R                (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R              + 
+--R                  2 2 5
+--R                9B a b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                   10 7               9 2              10   6
+--R                      - 41943040A a  c  + (33554432A a b  + 37748736B a  b)c
+--R                    + 
+--R                                   8 4              9 3  5
+--R                      (- 1572864A a b  - 44040192B a b )c
+--R                    + 
+--R                                   7 6              8 5  4
+--R                      (- 6553600A a b  + 19660800B a b )c
+--R                    + 
+--R                                 6 8             7 7  3
+--R                      (2785280A a b  - 3932160B a b )c
+--R                    + 
+--R                                  5 10            6 9  2
+--R                      (- 491520A a b   + 245760B a b )c
+--R                    + 
+--R                             4 12           5 11            3 14          4 13
+--R                    (38912A a b   + 24576B a b  )c - 1024A a b   - 3072B a b
+--R                 *
+--R                    ROOT
+--R                                 4 2 2       4   2       3   2        2 2 3
+--R                           - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                         + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                            3 5          2   6  5
+--R                  (- 102400A a b + 76800A B a )c
+--R                + 
+--R                         3 4 3         2   5 2           2 6          3 7  4
+--R                  (87296A a b  - 16896A B a b  + 18432A B a b - 27648B a )c
+--R                + 
+--R                                3 3 5         2   4 4           2 5 3
+--R                        - 27328A a b  - 18432A B a b  - 20736A B a b
+--R                      + 
+--R                              3 6 2
+--R                        13824B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3 2 7        2   3 6          2 4 5  2
+--R                  (3760A a b  + 8160A B a b  + 8640A B a b )c
+--R                + 
+--R                         3   9        2   2 8          2 3 7       3 4 6
+--R                  (- 212A a b  - 1068A B a b  - 1584A B a b  - 864B a b )c
+--R                + 
+--R                    3 11      2     10         2 2 9       3 3 8
+--R                  4A b   + 36A B a b   + 108A B a b  + 108B a b
+--R             *
+--R                ROOT
+--R                                    8 5          7 2 4          6 4 3
+--R                           - 262144a c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 5 6 2        4 8        3 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                      4 2 2
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3      4 4
+--R                                (50A a b  + 300A B a b + 450A B a )c - A b
+--R                              + 
+--R                                     3     3      2 2 2 2         3 3       4 4
+--R                                - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                             2 3            4  3
+--R                       (1680A a b - 960A B a )c
+--R                     + 
+--R                            2 2 3            3 2       2 4   2
+--R                       (280A a b  - 1920A B a b  + 720B a b)c
+--R                     + 
+--R                             2   5          2 4       2 3 3      2 7           6
+--R                       (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R                     + 
+--R                         2 2 5
+--R                       9B a b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                        4 3 5          4 2 2         3   3   4
+--R                  10000A a c  + (15000A a b  - 30000A B a b)c
+--R                + 
+--R                             4   4         3   2 3        2 2 3 2          3 4
+--R                      - 1491A a b  - 11592A B a b  + 9936A B a b  + 9072A B a b
+--R                    + 
+--R                             4 5
+--R                      - 1296B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         4 6       3     5        2 2 2 4          3 3 3
+--R                      35A b  + 945A B a b  + 3240A B a b  + 1080A B a b
+--R                    + 
+--R                             4 4 2
+--R                      - 3240B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   7       2 2   6         3 2 5       4 3 4
+--R                  (- 15A B b  - 135A B a b  - 405A B a b  - 405B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R               3 2      2 2        4  +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           8 5          7 2 4          6 4 3         5 6 2
+--R                    262144a c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         4 8        3 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                               4 2 2       4   2       3   2        2 2 3
+--R                         - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                       + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                    /
+--R                                  11 5            10 2 4            9 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                       + 
+--R                                    8 6 2           7 8          6 10
+--R                         - 10485760a b c  + 1310720a b c - 65536a b
+--R              + 
+--R                      2 3            4  3
+--R                (1680A a b - 960A B a )c
+--R              + 
+--R                     2 2 3            3 2       2 4   2
+--R                (280A a b  - 1920A B a b  + 720B a b)c
+--R              + 
+--R                      2   5          2 4       2 3 3      2 7           6
+--R                (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R              + 
+--R                  2 2 5
+--R                9B a b
+--R           /
+--R                       8 5          7 2 4         6 4 3         5 6 2
+--R                131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     4 8        3 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                   10 7               9 2              10   6
+--R                      - 41943040A a  c  + (33554432A a b  + 37748736B a  b)c
+--R                    + 
+--R                                   8 4              9 3  5
+--R                      (- 1572864A a b  - 44040192B a b )c
+--R                    + 
+--R                                   7 6              8 5  4
+--R                      (- 6553600A a b  + 19660800B a b )c
+--R                    + 
+--R                                 6 8             7 7  3
+--R                      (2785280A a b  - 3932160B a b )c
+--R                    + 
+--R                                  5 10            6 9  2
+--R                      (- 491520A a b   + 245760B a b )c
+--R                    + 
+--R                             4 12           5 11            3 14          4 13
+--R                    (38912A a b   + 24576B a b  )c - 1024A a b   - 3072B a b
+--R                 *
+--R                    ROOT
+--R                                 4 2 2       4   2       3   2        2 2 3
+--R                           - 625A a c  + (50A a b  + 300A B a b + 450A B a )c
+--R                         + 
+--R                            4 4      3     3      2 2 2 2         3 3       4 4
+--R                         - A b  - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                      /
+--R                                    11 5            10 2 4            9 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                         + 
+--R                                      8 6 2           7 8          6 10
+--R                           - 10485760a b c  + 1310720a b c - 65536a b
+--R                + 
+--R                          3 5          2   6  5
+--R                  (102400A a b - 76800A B a )c
+--R                + 
+--R                           3 4 3         2   5 2           2 6          3 7  4
+--R                  (- 87296A a b  + 16896A B a b  - 18432A B a b + 27648B a )c
+--R                + 
+--R                         3 3 5         2   4 4           2 5 3         3 6 2  3
+--R                  (27328A a b  + 18432A B a b  + 20736A B a b  - 13824B a b )c
+--R                + 
+--R                          3 2 7        2   3 6          2 4 5  2
+--R                  (- 3760A a b  - 8160A B a b  - 8640A B a b )c
+--R                + 
+--R                       3   9        2   2 8          2 3 7       3 4 6
+--R                  (212A a b  + 1068A B a b  + 1584A B a b  + 864B a b )c
+--R                + 
+--R                      3 11      2     10         2 2 9       3 3 8
+--R                  - 4A b   - 36A B a b   - 108A B a b  - 108B a b
+--R             *
+--R                ROOT
+--R                                  8 5          7 2 4          6 4 3
+--R                           262144a c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   5 6 2        4 8        3 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                      4 2 2
+--R                                - 625A a c
+--R                              + 
+--R                                    4   2       3   2        2 2 3      4 4
+--R                                (50A a b  + 300A B a b + 450A B a )c - A b
+--R                              + 
+--R                                     3     3      2 2 2 2         3 3       4 4
+--R                                - 12A B a b  - 54A B a b  - 108A B a b - 81B a
+--R                           /
+--R                                         11 5            10 2 4            9 4 3
+--R                                67108864a  c  - 83886080a  b c  + 41943040a b c
+--R                              + 
+--R                                           8 6 2           7 8          6 10
+--R                                - 10485760a b c  + 1310720a b c - 65536a b
+--R                     + 
+--R                             2 3            4  3
+--R                       (1680A a b - 960A B a )c
+--R                     + 
+--R                            2 2 3            3 2       2 4   2
+--R                       (280A a b  - 1920A B a b  + 720B a b)c
+--R                     + 
+--R                             2   5          2 4       2 3 3      2 7           6
+--R                       (- 35A a b  - 60A B a b  + 360B a b )c + A b  + 6A B a b
+--R                     + 
+--R                         2 2 5
+--R                       9B a b
+--R                  /
+--R                              8 5          7 2 4         6 4 3         5 6 2
+--R                       131072a c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            4 8        3 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                        4 3 5          4 2 2         3   3   4
+--R                  10000A a c  + (15000A a b  - 30000A B a b)c
+--R                + 
+--R                             4   4         3   2 3        2 2 3 2          3 4
+--R                      - 1491A a b  - 11592A B a b  + 9936A B a b  + 9072A B a b
+--R                    + 
+--R                             4 5
+--R                      - 1296B a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         4 6       3     5        2 2 2 4          3 3 3
+--R                      35A b  + 945A B a b  + 3240A B a b  + 1080A B a b
+--R                    + 
+--R                             4 4 2
+--R                      - 3240B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   7       2 2   6         3 2 5       4 3 4
+--R                  (- 15A B b  - 135A B a b  - 405A B a b  - 405B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                        +-----------+
+--R                           2            |          2                    2
+--R           (- 20A a c - A b  + 12B a b)\|- 4a c + b   + (52A a b - 24B a )c
+--R         + 
+--R                3          2
+--R           - A b  - 18B a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                        +-----------+
+--R                           2            |          2                      2
+--R           (- 20A a c - A b  + 12B a b)\|- 4a c + b   + (- 52A a b + 24B a )c
+--R         + 
+--R              3          2
+--R           A b  + 18B a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R            3 2      2 2        4  +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2321
+
+--S 2322 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2322
+
+)clear all
+
+--S 2323 of 3139
+t0:=(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        2
+--R     B x  + A
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2323
+
+--S 2324 of 3139
+r0:=-1/4*x*(a*b*B-A*(b^2-2*a*c)-(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+   (a+b*x^2+c*x^4)^2)+1/8*x*(a*b*B*(b^2+8*a*c)+A*(3*b^4-25*a*b^2*c+_
+   28*a^2*c^2)+c*(a*B*(b^2+20*a*c)+3*A*(b^3-8*a*b*c))*x^2)/(a^2*(b^2-_
+   4*a*c)^2*(a+b*x^2+c*x^4))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(a*B*(b^2+20*a*c)+3*A*(b^3-8*a*b*c)+(a*b*B*(b^2-_
+   52*a*c)+3*A*(b^4-10*a*b^2*c+56*a^2*c^2))/sqrt(b^2-4*a*c))/(a^2*(b^2-_
+   4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/8*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(a*B*(b^2+20*a*c)+3*A*(b^3-8*a*b*c)+_
+   (-a*b*B*(b^2-52*a*c)-3*A*(b^4-10*a*b^2*c+56*a^2*c^2))/sqrt(b^2-4*a*c))/_
+   (a^2*(b^2-4*a*c)^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                  2  3        3        2  2  8
+--R               ((- 24A a b + 20B a )c  + (3A b  + B a b )c )x
+--R             + 
+--R                          2        2   2        4         3    6
+--R               ((- 48A a b  + 40B a b)c  + (6A b  + 2B a b )c)x
+--R             + 
+--R                           2         3  2             3        2 2         5
+--R                   (- 48A a b + 40B a )c  + (- 18A a b  + 22B a b )c + 3A b
+--R                 + 
+--R                        4
+--R                   B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        2 2        3            4       2 3  2
+--R               ((- 48A a b  + 40B a b)c + 6A a b  + 2B a b )x
+--R             + 
+--R                       3         4         2 3      3 2
+--R               (- 24A a b + 20B a )c + 3A a b  + B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4             2        2   3        4        3  2  8
+--R           (168A a c  + (- 30A a b  - 52B a b)c  + (3A b  + B a b )c )x
+--R         + 
+--R                  2   3             3         2 2  2        5         4    6
+--R           (336A a b c  + (- 60A a b  - 104B a b )c  + (6A b  + 2B a b )c)x
+--R         + 
+--R                     3 3          2 2         3   2             4        2 3
+--R               336A a c  + (108A a b  - 104B a b)c  + (- 24A a b  - 50B a b )c
+--R             + 
+--R                   6        5
+--R               3A b  + B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                  3   2           2 3         3 2           5       2 4  2
+--R           (336A a b c  + (- 60A a b  - 104B a b )c + 6A a b  + 2B a b )x
+--R         + 
+--R                 4 2           3 2        4          2 4      3 3
+--R           168A a c  + (- 30A a b  - 52B a b)c + 3A a b  + B a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                  2  3        3        2  2  8
+--R               ((- 24A a b + 20B a )c  + (3A b  + B a b )c )x
+--R             + 
+--R                          2        2   2        4         3    6
+--R               ((- 48A a b  + 40B a b)c  + (6A b  + 2B a b )c)x
+--R             + 
+--R                           2         3  2             3        2 2         5
+--R                   (- 48A a b + 40B a )c  + (- 18A a b  + 22B a b )c + 3A b
+--R                 + 
+--R                        4
+--R                   B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        2 2        3            4       2 3  2
+--R               ((- 48A a b  + 40B a b)c + 6A a b  + 2B a b )x
+--R             + 
+--R                       3         4         2 3      3 2
+--R               (- 24A a b + 20B a )c + 3A a b  + B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    2 4           2        2   3          4        3  2  8
+--R           (- 168A a c  + (30A a b  + 52B a b)c  + (- 3A b  - B a b )c )x
+--R         + 
+--R                    2   3           3         2 2  2          5         4    6
+--R           (- 336A a b c  + (60A a b  + 104B a b )c  + (- 6A b  - 2B a b )c)x
+--R         + 
+--R                       3 3            2 2         3   2           4        2 3
+--R               - 336A a c  + (- 108A a b  + 104B a b)c  + (24A a b  + 50B a b )c
+--R             + 
+--R                     6        5
+--R               - 3A b  - B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    3   2         2 3         3 2           5       2 4  2
+--R           (- 336A a b c  + (60A a b  + 104B a b )c - 6A a b  - 2B a b )x
+--R         + 
+--R                   4 2         3 2        4          2 4      3 3
+--R           - 168A a c  + (30A a b  + 52B a b)c - 3A a b  - B a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                              2  3        3        2  2  7
+--R           ((- 24A a b + 20B a )c  + (3A b  + B a b )c )x
+--R         + 
+--R                 2 3             2        2   2        4         3    5
+--R           (28A a c  + (- 49A a b  + 28B a b)c  + (6A b  + 2B a b )c)x
+--R         + 
+--R                   2         3  2             3       2 2         5        4  3
+--R           ((- 4A a b + 36B a )c  + (- 20A a b  + 5B a b )c + 3A b  + B a b )x
+--R         + 
+--R                 3 2           2 2        3            4      2 3
+--R           (44A a c  + (- 37A a b  + 16B a b)c + 5A a b  - B a b )x
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              4 4      3 2 3     2 4 2  8        4   3       3 3 2      2 5   6
+--R         (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R              5 3      3 4      2 6  4        5   2       4 3       3 5  2
+--R         (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             6 2      5 2      4 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2324
+
+--S 2325 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 4      3 2 3     2 4 2  8        4   3      3 3 2     2 5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                5 3      3 4      2 6  4        5   2      4 3      3 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              6 2      5 2      4 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4 4
+--R                         - 194481A a c
+--R                       + 
+--R                                4 3 2         3   4          2 2 5  3
+--R                         (87318A a b  + 95256A B a b + 22050A B a )c
+--R                       + 
+--R                                     4 2 4         3   3 3         2 2 4 2
+--R                             - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                           + 
+--R                                      3 5        4 6
+--R                             - 5400A B a b - 625B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   6        3   2 5        2 2 3 4
+--R                             1782A a b  + 3132A B a b  + 1944A B a b
+--R                           + 
+--R                                   3 4 3      4 5 2
+--R                             516A B a b  + 50B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  - 108A B a b  - 54A B a b  - 12A B a b  - B a b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       2 4             5  4
+--R                (15120A a b - 6720A B a )c
+--R              + 
+--R                        2 3 3            4 2        2 5   3
+--R                (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1701A a b  + 1260A B a b  + 280B a b )c
+--R              + 
+--R                       2   7           2 6      2 3 5       2 9           8
+--R                (- 189A a b  - 168A B a b  - 35B a b )c + 9A b  + 6A B a b
+--R              + 
+--R                 2 2 7
+--R                B a b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                   12               13  7
+--R                      (138412032A a  b - 41943040B a  )c
+--R                    + 
+--R                                     11 3              12 2  6
+--R                      (- 207618048A a  b  + 33554432B a  b )c
+--R                    + 
+--R                                   10 5             11 4  5
+--R                      (132907008A a  b  - 1572864B a  b )c
+--R                    + 
+--R                                    9 7             10 6  4
+--R                      (- 47185920A a b  - 6553600B a  b )c
+--R                    + 
+--R                                  8 9             9 8  3
+--R                      (10076160A a b  + 2785280B a b )c
+--R                    + 
+--R                                   7 11            8 10  2
+--R                      (- 1302528A a b   - 491520B a b  )c
+--R                    + 
+--R                             6 13           7 12            5 15          6 14
+--R                    (95232A a b   + 38912B a b  )c - 3072A a b   - 1024B a b
+--R                 *
+--R                    ROOT
+--R                                    4 4 4
+--R                           - 194481A a c
+--R                         + 
+--R                                  4 3 2         3   4          2 2 5  3
+--R                           (87318A a b  + 95256A B a b + 22050A B a )c
+--R                         + 
+--R                                       4 2 4         3   3 3         2 2 4 2
+--R                               - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                             + 
+--R                                        3 5        4 6
+--R                               - 5400A B a b - 625B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   6        3   2 5        2 2 3 4
+--R                               1782A a b  + 3132A B a b  + 1944A B a b
+--R                             + 
+--R                                     3 4 3      4 5 2
+--R                               516A B a b  + 50B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                          3 7 7
+--R                  9483264A a c
+--R                + 
+--R                              3 6 2           2   7             2 8  6
+--R                  (- 12289536A a b  - 4128768A B a b - 537600A B a )c
+--R                + 
+--R                              3 5 4           2   6 3             2 7 2
+--R                      6877440A a b  + 4490496A B a b  + 1039872A B a b
+--R                    + 
+--R                             3 8
+--R                      102400B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                                3 4 6           2   5 5            2 6 4
+--R                      - 2169504A a b  - 2006208A B a b  - 656640A B a b
+--R                    + 
+--R                              3 7 3
+--R                      - 87296B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                               3 3 8          2   4 7            2 5 6
+--R                        419580A a b  + 472752A B a b  + 188832A B a b
+--R                      + 
+--R                              3 6 5
+--R                        27328B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                                3 2 10         2   3 9           2 4 8
+--R                        - 50112A a b   - 61956A B a b  - 26364A B a b
+--R                      + 
+--R                               3 5 7
+--R                        - 3760B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   12        2   2 11          2 3 10       3 4 9
+--R                  (3456A a b   + 4212A B a b   + 1656A B a b   + 212B a b )c
+--R                + 
+--R                        3 14       2     13        2 2 12     3 3 11
+--R                  - 108A b   - 108A B a b   - 36A B a b   - 4B a b
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4 4
+--R                                - 194481A a c
+--R                              + 
+--R                                       4 3 2         3   4          2 2 5  3
+--R                                (87318A a b  + 95256A B a b + 22050A B a )c
+--R                              + 
+--R                                            4 2 4         3   3 3
+--R                                    - 17739A a b  - 26676A B a b
+--R                                  + 
+--R                                            2 2 4 2          3 5        4 6
+--R                                    - 17496A B a b  - 5400A B a b - 625B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   6        3   2 5        2 2 3 4
+--R                                    1782A a b  + 3132A B a b  + 1944A B a b
+--R                                  + 
+--R                                          3 4 3      4 5 2
+--R                                    516A B a b  + 50B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              2 4             5  4
+--R                       (15120A a b - 6720A B a )c
+--R                     + 
+--R                               2 3 3            4 2        2 5   3
+--R                       (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1701A a b  + 1260A B a b  + 280B a b )c
+--R                     + 
+--R                              2   7           2 6      2 3 5       2 9
+--R                       (- 189A a b  - 168A B a b  - 35B a b )c + 9A b
+--R                     + 
+--R                               8    2 2 7
+--R                       6A B a b  + B a b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                          4 4 7              4 3 2           3   4   6
+--R                  3111696A a c  + (- 1555848A a b  - 3111696A B a b)c
+--R                + 
+--R                             4 2 4           3   3 3          2 2 4 2
+--R                      339309A a b  + 1298376A B a b  + 863136A B a b
+--R                    + 
+--R                              3 5          4 6
+--R                      90000A B a b - 10000B a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              4   6          3   2 5          2 2 3 4
+--R                      - 36207A a b  - 242757A B a b  - 238464A B a b
+--R                    + 
+--R                                3 4 3         4 5 2
+--R                      - 98856A B a b  - 15000B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           4 8         3     7         2 2 2 6           3 3 5
+--R                      1701A b  + 22113A B a b  + 27594A B a b  + 11277A B a b
+--R                    + 
+--R                           4 4 4
+--R                      1491B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   9       2 2   8         3 2 7      4 3 6  2
+--R                  (- 945A B b  - 945A B a b  - 315A B a b  - 35B a b )c
+--R             *
+--R                x
+--R     + 
+--R                 4 4      3 2 3     2 4 2  8
+--R           (- 64a c  + 32a b c  - 4a b c )x
+--R         + 
+--R                  4   3      3 3 2     2 5   6          5 3      3 4      2 6  4
+--R           (- 128a b c  + 64a b c  - 8a b c)x  + (- 128a c  + 24a b c - 4a b )x
+--R         + 
+--R                  5   2      4 3      3 5  2      6 2      5 2      4 4
+--R           (- 128a b c  + 64a b c - 8a b )x  - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4 4
+--R                         - 194481A a c
+--R                       + 
+--R                                4 3 2         3   4          2 2 5  3
+--R                         (87318A a b  + 95256A B a b + 22050A B a )c
+--R                       + 
+--R                                     4 2 4         3   3 3         2 2 4 2
+--R                             - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                           + 
+--R                                      3 5        4 6
+--R                             - 5400A B a b - 625B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   6        3   2 5        2 2 3 4
+--R                             1782A a b  + 3132A B a b  + 1944A B a b
+--R                           + 
+--R                                   3 4 3      4 5 2
+--R                             516A B a b  + 50B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  - 108A B a b  - 54A B a b  - 12A B a b  - B a b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       2 4             5  4
+--R                (15120A a b - 6720A B a )c
+--R              + 
+--R                        2 3 3            4 2        2 5   3
+--R                (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1701A a b  + 1260A B a b  + 280B a b )c
+--R              + 
+--R                       2   7           2 6      2 3 5       2 9           8
+--R                (- 189A a b  - 168A B a b  - 35B a b )c + 9A b  + 6A B a b
+--R              + 
+--R                 2 2 7
+--R                B a b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                   12               13  7
+--R                      (138412032A a  b - 41943040B a  )c
+--R                    + 
+--R                                     11 3              12 2  6
+--R                      (- 207618048A a  b  + 33554432B a  b )c
+--R                    + 
+--R                                   10 5             11 4  5
+--R                      (132907008A a  b  - 1572864B a  b )c
+--R                    + 
+--R                                    9 7             10 6  4
+--R                      (- 47185920A a b  - 6553600B a  b )c
+--R                    + 
+--R                                  8 9             9 8  3
+--R                      (10076160A a b  + 2785280B a b )c
+--R                    + 
+--R                                   7 11            8 10  2
+--R                      (- 1302528A a b   - 491520B a b  )c
+--R                    + 
+--R                             6 13           7 12            5 15          6 14
+--R                    (95232A a b   + 38912B a b  )c - 3072A a b   - 1024B a b
+--R                 *
+--R                    ROOT
+--R                                    4 4 4
+--R                           - 194481A a c
+--R                         + 
+--R                                  4 3 2         3   4          2 2 5  3
+--R                           (87318A a b  + 95256A B a b + 22050A B a )c
+--R                         + 
+--R                                       4 2 4         3   3 3         2 2 4 2
+--R                               - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                             + 
+--R                                        3 5        4 6
+--R                               - 5400A B a b - 625B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   6        3   2 5        2 2 3 4
+--R                               1782A a b  + 3132A B a b  + 1944A B a b
+--R                             + 
+--R                                     3 4 3      4 5 2
+--R                               516A B a b  + 50B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            3 7 7
+--R                  - 9483264A a c
+--R                + 
+--R                            3 6 2           2   7             2 8  6
+--R                  (12289536A a b  + 4128768A B a b + 537600A B a )c
+--R                + 
+--R                                3 5 4           2   6 3             2 7 2
+--R                      - 6877440A a b  - 4490496A B a b  - 1039872A B a b
+--R                    + 
+--R                               3 8
+--R                      - 102400B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              3 4 6           2   5 5            2 6 4
+--R                      2169504A a b  + 2006208A B a b  + 656640A B a b
+--R                    + 
+--R                            3 7 3
+--R                      87296B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                               3 3 8          2   4 7            2 5 6
+--R                      - 419580A a b  - 472752A B a b  - 188832A B a b
+--R                    + 
+--R                              3 6 5
+--R                      - 27328B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3 2 10         2   3 9           2 4 8        3 5 7  2
+--R                  (50112A a b   + 61956A B a b  + 26364A B a b  + 3760B a b )c
+--R                + 
+--R                          3   12        2   2 11          2 3 10       3 4 9
+--R                  (- 3456A a b   - 4212A B a b   - 1656A B a b   - 212B a b )c
+--R                + 
+--R                      3 14       2     13        2 2 12     3 3 11
+--R                  108A b   + 108A B a b   + 36A B a b   + 4B a b
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4 4
+--R                                - 194481A a c
+--R                              + 
+--R                                       4 3 2         3   4          2 2 5  3
+--R                                (87318A a b  + 95256A B a b + 22050A B a )c
+--R                              + 
+--R                                            4 2 4         3   3 3
+--R                                    - 17739A a b  - 26676A B a b
+--R                                  + 
+--R                                            2 2 4 2          3 5        4 6
+--R                                    - 17496A B a b  - 5400A B a b - 625B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   6        3   2 5        2 2 3 4
+--R                                    1782A a b  + 3132A B a b  + 1944A B a b
+--R                                  + 
+--R                                          3 4 3      4 5 2
+--R                                    516A B a b  + 50B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              2 4             5  4
+--R                       (15120A a b - 6720A B a )c
+--R                     + 
+--R                               2 3 3            4 2        2 5   3
+--R                       (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1701A a b  + 1260A B a b  + 280B a b )c
+--R                     + 
+--R                              2   7           2 6      2 3 5       2 9
+--R                       (- 189A a b  - 168A B a b  - 35B a b )c + 9A b
+--R                     + 
+--R                               8    2 2 7
+--R                       6A B a b  + B a b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                          4 4 7              4 3 2           3   4   6
+--R                  3111696A a c  + (- 1555848A a b  - 3111696A B a b)c
+--R                + 
+--R                             4 2 4           3   3 3          2 2 4 2
+--R                      339309A a b  + 1298376A B a b  + 863136A B a b
+--R                    + 
+--R                              3 5          4 6
+--R                      90000A B a b - 10000B a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              4   6          3   2 5          2 2 3 4
+--R                      - 36207A a b  - 242757A B a b  - 238464A B a b
+--R                    + 
+--R                                3 4 3         4 5 2
+--R                      - 98856A B a b  - 15000B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           4 8         3     7         2 2 2 6           3 3 5
+--R                      1701A b  + 22113A B a b  + 27594A B a b  + 11277A B a b
+--R                    + 
+--R                           4 4 4
+--R                      1491B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   9       2 2   8         3 2 7      4 3 6  2
+--R                  (- 945A B b  - 945A B a b  - 315A B a b  - 35B a b )c
+--R             *
+--R                x
+--R     + 
+--R               4 4      3 2 3     2 4 2  8        4   3      3 3 2     2 5   6
+--R           (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R         + 
+--R                5 3      3 4      2 6  4        5   2      4 3      3 5  2
+--R           (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R         + 
+--R              6 2      5 2      4 4
+--R           64a c  - 32a b c + 4a b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4 4
+--R                         - 194481A a c
+--R                       + 
+--R                                4 3 2         3   4          2 2 5  3
+--R                         (87318A a b  + 95256A B a b + 22050A B a )c
+--R                       + 
+--R                                     4 2 4         3   3 3         2 2 4 2
+--R                             - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                           + 
+--R                                      3 5        4 6
+--R                             - 5400A B a b - 625B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   6        3   2 5        2 2 3 4
+--R                             1782A a b  + 3132A B a b  + 1944A B a b
+--R                           + 
+--R                                   3 4 3      4 5 2
+--R                             516A B a b  + 50B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  - 108A B a b  - 54A B a b  - 12A B a b  - B a b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       2 4             5  4
+--R                (15120A a b - 6720A B a )c
+--R              + 
+--R                        2 3 3            4 2        2 5   3
+--R                (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1701A a b  + 1260A B a b  + 280B a b )c
+--R              + 
+--R                       2   7           2 6      2 3 5       2 9           8
+--R                (- 189A a b  - 168A B a b  - 35B a b )c + 9A b  + 6A B a b
+--R              + 
+--R                 2 2 7
+--R                B a b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                     12               13  7
+--R                      (- 138412032A a  b + 41943040B a  )c
+--R                    + 
+--R                                   11 3              12 2  6
+--R                      (207618048A a  b  - 33554432B a  b )c
+--R                    + 
+--R                                     10 5             11 4  5
+--R                      (- 132907008A a  b  + 1572864B a  b )c
+--R                    + 
+--R                                  9 7             10 6  4
+--R                      (47185920A a b  + 6553600B a  b )c
+--R                    + 
+--R                                    8 9             9 8  3
+--R                      (- 10076160A a b  - 2785280B a b )c
+--R                    + 
+--R                                 7 11            8 10  2
+--R                      (1302528A a b   + 491520B a b  )c
+--R                    + 
+--R                               6 13           7 12            5 15          6 14
+--R                    (- 95232A a b   - 38912B a b  )c + 3072A a b   + 1024B a b
+--R                 *
+--R                    ROOT
+--R                                    4 4 4
+--R                           - 194481A a c
+--R                         + 
+--R                                  4 3 2         3   4          2 2 5  3
+--R                           (87318A a b  + 95256A B a b + 22050A B a )c
+--R                         + 
+--R                                       4 2 4         3   3 3         2 2 4 2
+--R                               - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                             + 
+--R                                        3 5        4 6
+--R                               - 5400A B a b - 625B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   6        3   2 5        2 2 3 4
+--R                               1782A a b  + 3132A B a b  + 1944A B a b
+--R                             + 
+--R                                     3 4 3      4 5 2
+--R                               516A B a b  + 50B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                          3 7 7
+--R                  9483264A a c
+--R                + 
+--R                              3 6 2           2   7             2 8  6
+--R                  (- 12289536A a b  - 4128768A B a b - 537600A B a )c
+--R                + 
+--R                              3 5 4           2   6 3             2 7 2
+--R                      6877440A a b  + 4490496A B a b  + 1039872A B a b
+--R                    + 
+--R                             3 8
+--R                      102400B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                                3 4 6           2   5 5            2 6 4
+--R                      - 2169504A a b  - 2006208A B a b  - 656640A B a b
+--R                    + 
+--R                              3 7 3
+--R                      - 87296B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                               3 3 8          2   4 7            2 5 6
+--R                        419580A a b  + 472752A B a b  + 188832A B a b
+--R                      + 
+--R                              3 6 5
+--R                        27328B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                                3 2 10         2   3 9           2 4 8
+--R                        - 50112A a b   - 61956A B a b  - 26364A B a b
+--R                      + 
+--R                               3 5 7
+--R                        - 3760B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   12        2   2 11          2 3 10       3 4 9
+--R                  (3456A a b   + 4212A B a b   + 1656A B a b   + 212B a b )c
+--R                + 
+--R                        3 14       2     13        2 2 12     3 3 11
+--R                  - 108A b   - 108A B a b   - 36A B a b   - 4B a b
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4 4
+--R                                - 194481A a c
+--R                              + 
+--R                                       4 3 2         3   4          2 2 5  3
+--R                                (87318A a b  + 95256A B a b + 22050A B a )c
+--R                              + 
+--R                                            4 2 4         3   3 3
+--R                                    - 17739A a b  - 26676A B a b
+--R                                  + 
+--R                                            2 2 4 2          3 5        4 6
+--R                                    - 17496A B a b  - 5400A B a b - 625B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   6        3   2 5        2 2 3 4
+--R                                    1782A a b  + 3132A B a b  + 1944A B a b
+--R                                  + 
+--R                                          3 4 3      4 5 2
+--R                                    516A B a b  + 50B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              2 4             5  4
+--R                       (15120A a b - 6720A B a )c
+--R                     + 
+--R                               2 3 3            4 2        2 5   3
+--R                       (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1701A a b  + 1260A B a b  + 280B a b )c
+--R                     + 
+--R                              2   7           2 6      2 3 5       2 9
+--R                       (- 189A a b  - 168A B a b  - 35B a b )c + 9A b
+--R                     + 
+--R                               8    2 2 7
+--R                       6A B a b  + B a b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                          4 4 7              4 3 2           3   4   6
+--R                  3111696A a c  + (- 1555848A a b  - 3111696A B a b)c
+--R                + 
+--R                             4 2 4           3   3 3          2 2 4 2
+--R                      339309A a b  + 1298376A B a b  + 863136A B a b
+--R                    + 
+--R                              3 5          4 6
+--R                      90000A B a b - 10000B a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              4   6          3   2 5          2 2 3 4
+--R                      - 36207A a b  - 242757A B a b  - 238464A B a b
+--R                    + 
+--R                                3 4 3         4 5 2
+--R                      - 98856A B a b  - 15000B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           4 8         3     7         2 2 2 6           3 3 5
+--R                      1701A b  + 22113A B a b  + 27594A B a b  + 11277A B a b
+--R                    + 
+--R                           4 4 4
+--R                      1491B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   9       2 2   8         3 2 7      4 3 6  2
+--R                  (- 945A B b  - 945A B a b  - 315A B a b  - 35B a b )c
+--R             *
+--R                x
+--R     + 
+--R                 4 4      3 2 3     2 4 2  8
+--R           (- 64a c  + 32a b c  - 4a b c )x
+--R         + 
+--R                  4   3      3 3 2     2 5   6          5 3      3 4      2 6  4
+--R           (- 128a b c  + 64a b c  - 8a b c)x  + (- 128a c  + 24a b c - 4a b )x
+--R         + 
+--R                  5   2      4 3      3 5  2      6 2      5 2      4 4
+--R           (- 128a b c  + 64a b c - 8a b )x  - 64a c  + 32a b c - 4a b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4 4
+--R                         - 194481A a c
+--R                       + 
+--R                                4 3 2         3   4          2 2 5  3
+--R                         (87318A a b  + 95256A B a b + 22050A B a )c
+--R                       + 
+--R                                     4 2 4         3   3 3         2 2 4 2
+--R                             - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                           + 
+--R                                      3 5        4 6
+--R                             - 5400A B a b - 625B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   6        3   2 5        2 2 3 4
+--R                             1782A a b  + 3132A B a b  + 1944A B a b
+--R                           + 
+--R                                   3 4 3      4 5 2
+--R                             516A B a b  + 50B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  - 108A B a b  - 54A B a b  - 12A B a b  - B a b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       2 4             5  4
+--R                (15120A a b - 6720A B a )c
+--R              + 
+--R                        2 3 3            4 2        2 5   3
+--R                (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1701A a b  + 1260A B a b  + 280B a b )c
+--R              + 
+--R                       2   7           2 6      2 3 5       2 9           8
+--R                (- 189A a b  - 168A B a b  - 35B a b )c + 9A b  + 6A B a b
+--R              + 
+--R                 2 2 7
+--R                B a b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                     12               13  7
+--R                      (- 138412032A a  b + 41943040B a  )c
+--R                    + 
+--R                                   11 3              12 2  6
+--R                      (207618048A a  b  - 33554432B a  b )c
+--R                    + 
+--R                                     10 5             11 4  5
+--R                      (- 132907008A a  b  + 1572864B a  b )c
+--R                    + 
+--R                                  9 7             10 6  4
+--R                      (47185920A a b  + 6553600B a  b )c
+--R                    + 
+--R                                    8 9             9 8  3
+--R                      (- 10076160A a b  - 2785280B a b )c
+--R                    + 
+--R                                 7 11            8 10  2
+--R                      (1302528A a b   + 491520B a b  )c
+--R                    + 
+--R                               6 13           7 12            5 15          6 14
+--R                    (- 95232A a b   - 38912B a b  )c + 3072A a b   + 1024B a b
+--R                 *
+--R                    ROOT
+--R                                    4 4 4
+--R                           - 194481A a c
+--R                         + 
+--R                                  4 3 2         3   4          2 2 5  3
+--R                           (87318A a b  + 95256A B a b + 22050A B a )c
+--R                         + 
+--R                                       4 2 4         3   3 3         2 2 4 2
+--R                               - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                             + 
+--R                                        3 5        4 6
+--R                               - 5400A B a b - 625B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   6        3   2 5        2 2 3 4
+--R                               1782A a b  + 3132A B a b  + 1944A B a b
+--R                             + 
+--R                                     3 4 3      4 5 2
+--R                               516A B a b  + 50B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            3 7 7
+--R                  - 9483264A a c
+--R                + 
+--R                            3 6 2           2   7             2 8  6
+--R                  (12289536A a b  + 4128768A B a b + 537600A B a )c
+--R                + 
+--R                                3 5 4           2   6 3             2 7 2
+--R                      - 6877440A a b  - 4490496A B a b  - 1039872A B a b
+--R                    + 
+--R                               3 8
+--R                      - 102400B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              3 4 6           2   5 5            2 6 4
+--R                      2169504A a b  + 2006208A B a b  + 656640A B a b
+--R                    + 
+--R                            3 7 3
+--R                      87296B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                               3 3 8          2   4 7            2 5 6
+--R                      - 419580A a b  - 472752A B a b  - 188832A B a b
+--R                    + 
+--R                              3 6 5
+--R                      - 27328B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3 2 10         2   3 9           2 4 8        3 5 7  2
+--R                  (50112A a b   + 61956A B a b  + 26364A B a b  + 3760B a b )c
+--R                + 
+--R                          3   12        2   2 11          2 3 10       3 4 9
+--R                  (- 3456A a b   - 4212A B a b   - 1656A B a b   - 212B a b )c
+--R                + 
+--R                      3 14       2     13        2 2 12     3 3 11
+--R                  108A b   + 108A B a b   + 36A B a b   + 4B a b
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4 4
+--R                                - 194481A a c
+--R                              + 
+--R                                       4 3 2         3   4          2 2 5  3
+--R                                (87318A a b  + 95256A B a b + 22050A B a )c
+--R                              + 
+--R                                            4 2 4         3   3 3
+--R                                    - 17739A a b  - 26676A B a b
+--R                                  + 
+--R                                            2 2 4 2          3 5        4 6
+--R                                    - 17496A B a b  - 5400A B a b - 625B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   6        3   2 5        2 2 3 4
+--R                                    1782A a b  + 3132A B a b  + 1944A B a b
+--R                                  + 
+--R                                          3 4 3      4 5 2
+--R                                    516A B a b  + 50B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              2 4             5  4
+--R                       (15120A a b - 6720A B a )c
+--R                     + 
+--R                               2 3 3            4 2        2 5   3
+--R                       (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1701A a b  + 1260A B a b  + 280B a b )c
+--R                     + 
+--R                              2   7           2 6      2 3 5       2 9
+--R                       (- 189A a b  - 168A B a b  - 35B a b )c + 9A b
+--R                     + 
+--R                               8    2 2 7
+--R                       6A B a b  + B a b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                          4 4 7              4 3 2           3   4   6
+--R                  3111696A a c  + (- 1555848A a b  - 3111696A B a b)c
+--R                + 
+--R                             4 2 4           3   3 3          2 2 4 2
+--R                      339309A a b  + 1298376A B a b  + 863136A B a b
+--R                    + 
+--R                              3 5          4 6
+--R                      90000A B a b - 10000B a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              4   6          3   2 5          2 2 3 4
+--R                      - 36207A a b  - 242757A B a b  - 238464A B a b
+--R                    + 
+--R                                3 4 3         4 5 2
+--R                      - 98856A B a b  - 15000B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           4 8         3     7         2 2 2 6           3 3 5
+--R                      1701A b  + 22113A B a b  + 27594A B a b  + 11277A B a b
+--R                    + 
+--R                           4 4 4
+--R                      1491B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   9       2 2   8         3 2 7      4 3 6  2
+--R                  (- 945A B b  - 945A B a b  - 315A B a b  - 35B a b )c
+--R             *
+--R                x
+--R     + 
+--R                          2  3        3        2  2  7
+--R       ((- 24A a b + 20B a )c  + (3A b  + B a b )c )x
+--R     + 
+--R             2 3             2        2   2        4         3    5
+--R       (28A a c  + (- 49A a b  + 28B a b)c  + (6A b  + 2B a b )c)x
+--R     + 
+--R               2         3  2             3       2 2         5        4  3
+--R       ((- 4A a b + 36B a )c  + (- 20A a b  + 5B a b )c + 3A b  + B a b )x
+--R     + 
+--R             3 2           2 2        3            4      2 3
+--R       (44A a c  + (- 37A a b  + 16B a b)c + 5A a b  - B a b )x
+--R  /
+--R            4 4      3 2 3     2 4 2  8        4   3       3 3 2      2 5   6
+--R       (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R     + 
+--R            5 3      3 4      2 6  4        5   2       4 3       3 5  2
+--R       (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R     + 
+--R           6 2      5 2      4 4
+--R       128a c  - 64a b c + 8a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2325
+
+--S 2326 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +--------------------+
+--R                                        +-----------+ |   +-----------+
+--R             4 2      3 2      2 4  +-+ |          2  |   |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4 4
+--R                         - 194481A a c
+--R                       + 
+--R                                4 3 2         3   4          2 2 5  3
+--R                         (87318A a b  + 95256A B a b + 22050A B a )c
+--R                       + 
+--R                                     4 2 4         3   3 3         2 2 4 2
+--R                             - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                           + 
+--R                                      3 5        4 6
+--R                             - 5400A B a b - 625B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   6        3   2 5        2 2 3 4
+--R                             1782A a b  + 3132A B a b  + 1944A B a b
+--R                           + 
+--R                                   3 4 3      4 5 2
+--R                             516A B a b  + 50B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  - 108A B a b  - 54A B a b  - 12A B a b  - B a b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       2 4             5  4
+--R                (15120A a b - 6720A B a )c
+--R              + 
+--R                        2 3 3            4 2        2 5   3
+--R                (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1701A a b  + 1260A B a b  + 280B a b )c
+--R              + 
+--R                       2   7           2 6      2 3 5       2 9           8
+--R                (- 189A a b  - 168A B a b  - 35B a b )c + 9A b  + 6A B a b
+--R              + 
+--R                 2 2 7
+--R                B a b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                   12               13  7
+--R                      (138412032A a  b - 41943040B a  )c
+--R                    + 
+--R                                     11 3              12 2  6
+--R                      (- 207618048A a  b  + 33554432B a  b )c
+--R                    + 
+--R                                   10 5             11 4  5
+--R                      (132907008A a  b  - 1572864B a  b )c
+--R                    + 
+--R                                    9 7             10 6  4
+--R                      (- 47185920A a b  - 6553600B a  b )c
+--R                    + 
+--R                                  8 9             9 8  3
+--R                      (10076160A a b  + 2785280B a b )c
+--R                    + 
+--R                                   7 11            8 10  2
+--R                      (- 1302528A a b   - 491520B a b  )c
+--R                    + 
+--R                             6 13           7 12            5 15          6 14
+--R                    (95232A a b   + 38912B a b  )c - 3072A a b   - 1024B a b
+--R                 *
+--R                    ROOT
+--R                                    4 4 4
+--R                           - 194481A a c
+--R                         + 
+--R                                  4 3 2         3   4          2 2 5  3
+--R                           (87318A a b  + 95256A B a b + 22050A B a )c
+--R                         + 
+--R                                       4 2 4         3   3 3         2 2 4 2
+--R                               - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                             + 
+--R                                        3 5        4 6
+--R                               - 5400A B a b - 625B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   6        3   2 5        2 2 3 4
+--R                               1782A a b  + 3132A B a b  + 1944A B a b
+--R                             + 
+--R                                     3 4 3      4 5 2
+--R                               516A B a b  + 50B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                          3 7 7
+--R                  9483264A a c
+--R                + 
+--R                              3 6 2           2   7             2 8  6
+--R                  (- 12289536A a b  - 4128768A B a b - 537600A B a )c
+--R                + 
+--R                              3 5 4           2   6 3             2 7 2
+--R                      6877440A a b  + 4490496A B a b  + 1039872A B a b
+--R                    + 
+--R                             3 8
+--R                      102400B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                                3 4 6           2   5 5            2 6 4
+--R                      - 2169504A a b  - 2006208A B a b  - 656640A B a b
+--R                    + 
+--R                              3 7 3
+--R                      - 87296B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                               3 3 8          2   4 7            2 5 6
+--R                        419580A a b  + 472752A B a b  + 188832A B a b
+--R                      + 
+--R                              3 6 5
+--R                        27328B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                                3 2 10         2   3 9           2 4 8
+--R                        - 50112A a b   - 61956A B a b  - 26364A B a b
+--R                      + 
+--R                               3 5 7
+--R                        - 3760B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   12        2   2 11          2 3 10       3 4 9
+--R                  (3456A a b   + 4212A B a b   + 1656A B a b   + 212B a b )c
+--R                + 
+--R                        3 14       2     13        2 2 12     3 3 11
+--R                  - 108A b   - 108A B a b   - 36A B a b   - 4B a b
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4 4
+--R                                - 194481A a c
+--R                              + 
+--R                                       4 3 2         3   4          2 2 5  3
+--R                                (87318A a b  + 95256A B a b + 22050A B a )c
+--R                              + 
+--R                                            4 2 4         3   3 3
+--R                                    - 17739A a b  - 26676A B a b
+--R                                  + 
+--R                                            2 2 4 2          3 5        4 6
+--R                                    - 17496A B a b  - 5400A B a b - 625B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   6        3   2 5        2 2 3 4
+--R                                    1782A a b  + 3132A B a b  + 1944A B a b
+--R                                  + 
+--R                                          3 4 3      4 5 2
+--R                                    516A B a b  + 50B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              2 4             5  4
+--R                       (15120A a b - 6720A B a )c
+--R                     + 
+--R                               2 3 3            4 2        2 5   3
+--R                       (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1701A a b  + 1260A B a b  + 280B a b )c
+--R                     + 
+--R                              2   7           2 6      2 3 5       2 9
+--R                       (- 189A a b  - 168A B a b  - 35B a b )c + 9A b
+--R                     + 
+--R                               8    2 2 7
+--R                       6A B a b  + B a b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                          4 4 7              4 3 2           3   4   6
+--R                  3111696A a c  + (- 1555848A a b  - 3111696A B a b)c
+--R                + 
+--R                             4 2 4           3   3 3          2 2 4 2
+--R                      339309A a b  + 1298376A B a b  + 863136A B a b
+--R                    + 
+--R                              3 5          4 6
+--R                      90000A B a b - 10000B a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              4   6          3   2 5          2 2 3 4
+--R                      - 36207A a b  - 242757A B a b  - 238464A B a b
+--R                    + 
+--R                                3 4 3         4 5 2
+--R                      - 98856A B a b  - 15000B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           4 8         3     7         2 2 2 6           3 3 5
+--R                      1701A b  + 22113A B a b  + 27594A B a b  + 11277A B a b
+--R                    + 
+--R                           4 4 4
+--R                      1491B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   9       2 2   8         3 2 7      4 3 6  2
+--R                  (- 945A B b  - 945A B a b  - 315A B a b  - 35B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                          +-----------+
+--R               4 2      3 2      2 4  +-+ |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4 4
+--R                         - 194481A a c
+--R                       + 
+--R                                4 3 2         3   4          2 2 5  3
+--R                         (87318A a b  + 95256A B a b + 22050A B a )c
+--R                       + 
+--R                                     4 2 4         3   3 3         2 2 4 2
+--R                             - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                           + 
+--R                                      3 5        4 6
+--R                             - 5400A B a b - 625B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   6        3   2 5        2 2 3 4
+--R                             1782A a b  + 3132A B a b  + 1944A B a b
+--R                           + 
+--R                                   3 4 3      4 5 2
+--R                             516A B a b  + 50B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  - 108A B a b  - 54A B a b  - 12A B a b  - B a b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       2 4             5  4
+--R                (15120A a b - 6720A B a )c
+--R              + 
+--R                        2 3 3            4 2        2 5   3
+--R                (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1701A a b  + 1260A B a b  + 280B a b )c
+--R              + 
+--R                       2   7           2 6      2 3 5       2 9           8
+--R                (- 189A a b  - 168A B a b  - 35B a b )c + 9A b  + 6A B a b
+--R              + 
+--R                 2 2 7
+--R                B a b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                   12               13  7
+--R                      (138412032A a  b - 41943040B a  )c
+--R                    + 
+--R                                     11 3              12 2  6
+--R                      (- 207618048A a  b  + 33554432B a  b )c
+--R                    + 
+--R                                   10 5             11 4  5
+--R                      (132907008A a  b  - 1572864B a  b )c
+--R                    + 
+--R                                    9 7             10 6  4
+--R                      (- 47185920A a b  - 6553600B a  b )c
+--R                    + 
+--R                                  8 9             9 8  3
+--R                      (10076160A a b  + 2785280B a b )c
+--R                    + 
+--R                                   7 11            8 10  2
+--R                      (- 1302528A a b   - 491520B a b  )c
+--R                    + 
+--R                             6 13           7 12            5 15          6 14
+--R                    (95232A a b   + 38912B a b  )c - 3072A a b   - 1024B a b
+--R                 *
+--R                    ROOT
+--R                                    4 4 4
+--R                           - 194481A a c
+--R                         + 
+--R                                  4 3 2         3   4          2 2 5  3
+--R                           (87318A a b  + 95256A B a b + 22050A B a )c
+--R                         + 
+--R                                       4 2 4         3   3 3         2 2 4 2
+--R                               - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                             + 
+--R                                        3 5        4 6
+--R                               - 5400A B a b - 625B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   6        3   2 5        2 2 3 4
+--R                               1782A a b  + 3132A B a b  + 1944A B a b
+--R                             + 
+--R                                     3 4 3      4 5 2
+--R                               516A B a b  + 50B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            3 7 7
+--R                  - 9483264A a c
+--R                + 
+--R                            3 6 2           2   7             2 8  6
+--R                  (12289536A a b  + 4128768A B a b + 537600A B a )c
+--R                + 
+--R                                3 5 4           2   6 3             2 7 2
+--R                      - 6877440A a b  - 4490496A B a b  - 1039872A B a b
+--R                    + 
+--R                               3 8
+--R                      - 102400B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              3 4 6           2   5 5            2 6 4
+--R                      2169504A a b  + 2006208A B a b  + 656640A B a b
+--R                    + 
+--R                            3 7 3
+--R                      87296B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                               3 3 8          2   4 7            2 5 6
+--R                      - 419580A a b  - 472752A B a b  - 188832A B a b
+--R                    + 
+--R                              3 6 5
+--R                      - 27328B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3 2 10         2   3 9           2 4 8        3 5 7  2
+--R                  (50112A a b   + 61956A B a b  + 26364A B a b  + 3760B a b )c
+--R                + 
+--R                          3   12        2   2 11          2 3 10       3 4 9
+--R                  (- 3456A a b   - 4212A B a b   - 1656A B a b   - 212B a b )c
+--R                + 
+--R                      3 14       2     13        2 2 12     3 3 11
+--R                  108A b   + 108A B a b   + 36A B a b   + 4B a b
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4 4
+--R                                - 194481A a c
+--R                              + 
+--R                                       4 3 2         3   4          2 2 5  3
+--R                                (87318A a b  + 95256A B a b + 22050A B a )c
+--R                              + 
+--R                                            4 2 4         3   3 3
+--R                                    - 17739A a b  - 26676A B a b
+--R                                  + 
+--R                                            2 2 4 2          3 5        4 6
+--R                                    - 17496A B a b  - 5400A B a b - 625B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   6        3   2 5        2 2 3 4
+--R                                    1782A a b  + 3132A B a b  + 1944A B a b
+--R                                  + 
+--R                                          3 4 3      4 5 2
+--R                                    516A B a b  + 50B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              2 4             5  4
+--R                       (15120A a b - 6720A B a )c
+--R                     + 
+--R                               2 3 3            4 2        2 5   3
+--R                       (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1701A a b  + 1260A B a b  + 280B a b )c
+--R                     + 
+--R                              2   7           2 6      2 3 5       2 9
+--R                       (- 189A a b  - 168A B a b  - 35B a b )c + 9A b
+--R                     + 
+--R                               8    2 2 7
+--R                       6A B a b  + B a b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                          4 4 7              4 3 2           3   4   6
+--R                  3111696A a c  + (- 1555848A a b  - 3111696A B a b)c
+--R                + 
+--R                             4 2 4           3   3 3          2 2 4 2
+--R                      339309A a b  + 1298376A B a b  + 863136A B a b
+--R                    + 
+--R                              3 5          4 6
+--R                      90000A B a b - 10000B a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              4   6          3   2 5          2 2 3 4
+--R                      - 36207A a b  - 242757A B a b  - 238464A B a b
+--R                    + 
+--R                                3 4 3         4 5 2
+--R                      - 98856A B a b  - 15000B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           4 8         3     7         2 2 2 6           3 3 5
+--R                      1701A b  + 22113A B a b  + 27594A B a b  + 11277A B a b
+--R                    + 
+--R                           4 4 4
+--R                      1491B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   9       2 2   8         3 2 7      4 3 6  2
+--R                  (- 945A B b  - 945A B a b  - 315A B a b  - 35B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                        +-----------+
+--R             4 2      3 2      2 4  +-+ |          2
+--R         (64a c  - 32a b c + 4a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                             10 5          9 2 4          8 4 3         7 6 2
+--R                    - 262144a  c  + 327680a b c  - 163840a b c  + 40960a b c
+--R                  + 
+--R                           6 8        5 10
+--R                    - 5120a b c + 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4 4
+--R                         - 194481A a c
+--R                       + 
+--R                                4 3 2         3   4          2 2 5  3
+--R                         (87318A a b  + 95256A B a b + 22050A B a )c
+--R                       + 
+--R                                     4 2 4         3   3 3         2 2 4 2
+--R                             - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                           + 
+--R                                      3 5        4 6
+--R                             - 5400A B a b - 625B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   6        3   2 5        2 2 3 4
+--R                             1782A a b  + 3132A B a b  + 1944A B a b
+--R                           + 
+--R                                   3 4 3      4 5 2
+--R                             516A B a b  + 50B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  - 108A B a b  - 54A B a b  - 12A B a b  - B a b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       2 4             5  4
+--R                (15120A a b - 6720A B a )c
+--R              + 
+--R                        2 3 3            4 2        2 5   3
+--R                (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1701A a b  + 1260A B a b  + 280B a b )c
+--R              + 
+--R                       2   7           2 6      2 3 5       2 9           8
+--R                (- 189A a b  - 168A B a b  - 35B a b )c + 9A b  + 6A B a b
+--R              + 
+--R                 2 2 7
+--R                B a b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                     12               13  7
+--R                      (- 138412032A a  b + 41943040B a  )c
+--R                    + 
+--R                                   11 3              12 2  6
+--R                      (207618048A a  b  - 33554432B a  b )c
+--R                    + 
+--R                                     10 5             11 4  5
+--R                      (- 132907008A a  b  + 1572864B a  b )c
+--R                    + 
+--R                                  9 7             10 6  4
+--R                      (47185920A a b  + 6553600B a  b )c
+--R                    + 
+--R                                    8 9             9 8  3
+--R                      (- 10076160A a b  - 2785280B a b )c
+--R                    + 
+--R                                 7 11            8 10  2
+--R                      (1302528A a b   + 491520B a b  )c
+--R                    + 
+--R                               6 13           7 12            5 15          6 14
+--R                    (- 95232A a b   - 38912B a b  )c + 3072A a b   + 1024B a b
+--R                 *
+--R                    ROOT
+--R                                    4 4 4
+--R                           - 194481A a c
+--R                         + 
+--R                                  4 3 2         3   4          2 2 5  3
+--R                           (87318A a b  + 95256A B a b + 22050A B a )c
+--R                         + 
+--R                                       4 2 4         3   3 3         2 2 4 2
+--R                               - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                             + 
+--R                                        3 5        4 6
+--R                               - 5400A B a b - 625B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   6        3   2 5        2 2 3 4
+--R                               1782A a b  + 3132A B a b  + 1944A B a b
+--R                             + 
+--R                                     3 4 3      4 5 2
+--R                               516A B a b  + 50B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                          3 7 7
+--R                  9483264A a c
+--R                + 
+--R                              3 6 2           2   7             2 8  6
+--R                  (- 12289536A a b  - 4128768A B a b - 537600A B a )c
+--R                + 
+--R                              3 5 4           2   6 3             2 7 2
+--R                      6877440A a b  + 4490496A B a b  + 1039872A B a b
+--R                    + 
+--R                             3 8
+--R                      102400B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                                3 4 6           2   5 5            2 6 4
+--R                      - 2169504A a b  - 2006208A B a b  - 656640A B a b
+--R                    + 
+--R                              3 7 3
+--R                      - 87296B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                               3 3 8          2   4 7            2 5 6
+--R                        419580A a b  + 472752A B a b  + 188832A B a b
+--R                      + 
+--R                              3 6 5
+--R                        27328B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                                3 2 10         2   3 9           2 4 8
+--R                        - 50112A a b   - 61956A B a b  - 26364A B a b
+--R                      + 
+--R                               3 5 7
+--R                        - 3760B a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3   12        2   2 11          2 3 10       3 4 9
+--R                  (3456A a b   + 4212A B a b   + 1656A B a b   + 212B a b )c
+--R                + 
+--R                        3 14       2     13        2 2 12     3 3 11
+--R                  - 108A b   - 108A B a b   - 36A B a b   - 4B a b
+--R             *
+--R                ROOT
+--R                                    10 5          9 2 4          8 4 3
+--R                           - 262144a  c  + 327680a b c  - 163840a b c
+--R                         + 
+--R                                 7 6 2        6 8        5 10
+--R                           40960a b c  - 5120a b c + 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4 4
+--R                                - 194481A a c
+--R                              + 
+--R                                       4 3 2         3   4          2 2 5  3
+--R                                (87318A a b  + 95256A B a b + 22050A B a )c
+--R                              + 
+--R                                            4 2 4         3   3 3
+--R                                    - 17739A a b  - 26676A B a b
+--R                                  + 
+--R                                            2 2 4 2          3 5        4 6
+--R                                    - 17496A B a b  - 5400A B a b - 625B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   6        3   2 5        2 2 3 4
+--R                                    1782A a b  + 3132A B a b  + 1944A B a b
+--R                                  + 
+--R                                          3 4 3      4 5 2
+--R                                    516A B a b  + 50B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              2 4             5  4
+--R                       (15120A a b - 6720A B a )c
+--R                     + 
+--R                               2 3 3            4 2        2 5   3
+--R                       (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1701A a b  + 1260A B a b  + 280B a b )c
+--R                     + 
+--R                              2   7           2 6      2 3 5       2 9
+--R                       (- 189A a b  - 168A B a b  - 35B a b )c + 9A b
+--R                     + 
+--R                               8    2 2 7
+--R                       6A B a b  + B a b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                          4 4 7              4 3 2           3   4   6
+--R                  3111696A a c  + (- 1555848A a b  - 3111696A B a b)c
+--R                + 
+--R                             4 2 4           3   3 3          2 2 4 2
+--R                      339309A a b  + 1298376A B a b  + 863136A B a b
+--R                    + 
+--R                              3 5          4 6
+--R                      90000A B a b - 10000B a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              4   6          3   2 5          2 2 3 4
+--R                      - 36207A a b  - 242757A B a b  - 238464A B a b
+--R                    + 
+--R                                3 4 3         4 5 2
+--R                      - 98856A B a b  - 15000B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           4 8         3     7         2 2 2 6           3 3 5
+--R                      1701A b  + 22113A B a b  + 27594A B a b  + 11277A B a b
+--R                    + 
+--R                           4 4 4
+--R                      1491B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   9       2 2   8         3 2 7      4 3 6  2
+--R                  (- 945A B b  - 945A B a b  - 315A B a b  - 35B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                                        +--------------------+
+--R                                          +-----------+ |   +-----------+
+--R               4 2      3 2      2 4  +-+ |          2  |   |          2
+--R         (- 64a c  + 32a b c - 4a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           10 5          9 2 4          8 4 3         7 6 2
+--R                    262144a  c  - 327680a b c  + 163840a b c  - 40960a b c
+--R                  + 
+--R                         6 8        5 10
+--R                    5120a b c - 256a b
+--R               *
+--R                  ROOT
+--R                                  4 4 4
+--R                         - 194481A a c
+--R                       + 
+--R                                4 3 2         3   4          2 2 5  3
+--R                         (87318A a b  + 95256A B a b + 22050A B a )c
+--R                       + 
+--R                                     4 2 4         3   3 3         2 2 4 2
+--R                             - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                           + 
+--R                                      3 5        4 6
+--R                             - 5400A B a b - 625B a
+--R                        *
+--R                            2
+--R                           c
+--R                       + 
+--R                                  4   6        3   2 5        2 2 3 4
+--R                             1782A a b  + 3132A B a b  + 1944A B a b
+--R                           + 
+--R                                   3 4 3      4 5 2
+--R                             516A B a b  + 50B a b
+--R                        *
+--R                           c
+--R                       + 
+--R                            4 8       3     7      2 2 2 6        3 3 5    4 4 4
+--R                       - 81A b  - 108A B a b  - 54A B a b  - 12A B a b  - B a b
+--R                    /
+--R                                  15 5            14 2 4            13 4 3
+--R                         67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                       + 
+--R                                    12 6 2           11 8          10 10
+--R                         - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R              + 
+--R                       2 4             5  4
+--R                (15120A a b - 6720A B a )c
+--R              + 
+--R                        2 3 3            4 2        2 5   3
+--R                (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R              + 
+--R                      2 2 5            3 4       2 4 3  2
+--R                (1701A a b  + 1260A B a b  + 280B a b )c
+--R              + 
+--R                       2   7           2 6      2 3 5       2 9           8
+--R                (- 189A a b  - 168A B a b  - 35B a b )c + 9A b  + 6A B a b
+--R              + 
+--R                 2 2 7
+--R                B a b
+--R           /
+--R                       10 5          9 2 4         8 4 3         7 6 2
+--R                131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R              + 
+--R                     6 8        5 10
+--R                2560a b c - 128a b
+--R      *
+--R         log
+--R                                     12               13  7
+--R                      (- 138412032A a  b + 41943040B a  )c
+--R                    + 
+--R                                   11 3              12 2  6
+--R                      (207618048A a  b  - 33554432B a  b )c
+--R                    + 
+--R                                     10 5             11 4  5
+--R                      (- 132907008A a  b  + 1572864B a  b )c
+--R                    + 
+--R                                  9 7             10 6  4
+--R                      (47185920A a b  + 6553600B a  b )c
+--R                    + 
+--R                                    8 9             9 8  3
+--R                      (- 10076160A a b  - 2785280B a b )c
+--R                    + 
+--R                                 7 11            8 10  2
+--R                      (1302528A a b   + 491520B a b  )c
+--R                    + 
+--R                               6 13           7 12            5 15          6 14
+--R                    (- 95232A a b   - 38912B a b  )c + 3072A a b   + 1024B a b
+--R                 *
+--R                    ROOT
+--R                                    4 4 4
+--R                           - 194481A a c
+--R                         + 
+--R                                  4 3 2         3   4          2 2 5  3
+--R                           (87318A a b  + 95256A B a b + 22050A B a )c
+--R                         + 
+--R                                       4 2 4         3   3 3         2 2 4 2
+--R                               - 17739A a b  - 26676A B a b  - 17496A B a b
+--R                             + 
+--R                                        3 5        4 6
+--R                               - 5400A B a b - 625B a
+--R                          *
+--R                              2
+--R                             c
+--R                         + 
+--R                                    4   6        3   2 5        2 2 3 4
+--R                               1782A a b  + 3132A B a b  + 1944A B a b
+--R                             + 
+--R                                     3 4 3      4 5 2
+--R                               516A B a b  + 50B a b
+--R                          *
+--R                             c
+--R                         + 
+--R                                4 8       3     7      2 2 2 6        3 3 5
+--R                           - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                         + 
+--R                              4 4 4
+--R                           - B a b
+--R                      /
+--R                                    15 5            14 2 4            13 4 3
+--R                           67108864a  c  - 83886080a  b c  + 41943040a  b c
+--R                         + 
+--R                                      12 6 2           11 8          10 10
+--R                           - 10485760a  b c  + 1310720a  b c - 65536a  b
+--R                + 
+--R                            3 7 7
+--R                  - 9483264A a c
+--R                + 
+--R                            3 6 2           2   7             2 8  6
+--R                  (12289536A a b  + 4128768A B a b + 537600A B a )c
+--R                + 
+--R                                3 5 4           2   6 3             2 7 2
+--R                      - 6877440A a b  - 4490496A B a b  - 1039872A B a b
+--R                    + 
+--R                               3 8
+--R                      - 102400B a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              3 4 6           2   5 5            2 6 4
+--R                      2169504A a b  + 2006208A B a b  + 656640A B a b
+--R                    + 
+--R                            3 7 3
+--R                      87296B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                               3 3 8          2   4 7            2 5 6
+--R                      - 419580A a b  - 472752A B a b  - 188832A B a b
+--R                    + 
+--R                              3 6 5
+--R                      - 27328B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3 2 10         2   3 9           2 4 8        3 5 7  2
+--R                  (50112A a b   + 61956A B a b  + 26364A B a b  + 3760B a b )c
+--R                + 
+--R                          3   12        2   2 11          2 3 10       3 4 9
+--R                  (- 3456A a b   - 4212A B a b   - 1656A B a b   - 212B a b )c
+--R                + 
+--R                      3 14       2     13        2 2 12     3 3 11
+--R                  108A b   + 108A B a b   + 36A B a b   + 4B a b
+--R             *
+--R                ROOT
+--R                                  10 5          9 2 4          8 4 3
+--R                           262144a  c  - 327680a b c  + 163840a b c
+--R                         + 
+--R                                   7 6 2        6 8        5 10
+--R                           - 40960a b c  + 5120a b c - 256a b
+--R                      *
+--R                         ROOT
+--R                                         4 4 4
+--R                                - 194481A a c
+--R                              + 
+--R                                       4 3 2         3   4          2 2 5  3
+--R                                (87318A a b  + 95256A B a b + 22050A B a )c
+--R                              + 
+--R                                            4 2 4         3   3 3
+--R                                    - 17739A a b  - 26676A B a b
+--R                                  + 
+--R                                            2 2 4 2          3 5        4 6
+--R                                    - 17496A B a b  - 5400A B a b - 625B a
+--R                               *
+--R                                   2
+--R                                  c
+--R                              + 
+--R                                         4   6        3   2 5        2 2 3 4
+--R                                    1782A a b  + 3132A B a b  + 1944A B a b
+--R                                  + 
+--R                                          3 4 3      4 5 2
+--R                                    516A B a b  + 50B a b
+--R                               *
+--R                                  c
+--R                              + 
+--R                                     4 8       3     7      2 2 2 6        3 3 5
+--R                                - 81A b  - 108A B a b  - 54A B a b  - 12A B a b
+--R                              + 
+--R                                   4 4 4
+--R                                - B a b
+--R                           /
+--R                                         15 5            14 2 4
+--R                                67108864a  c  - 83886080a  b c
+--R                              + 
+--R                                         13 4 3            12 6 2
+--R                                41943040a  b c  - 10485760a  b c
+--R                              + 
+--R                                        11 8          10 10
+--R                                1310720a  b c - 65536a  b
+--R                     + 
+--R                              2 4             5  4
+--R                       (15120A a b - 6720A B a )c
+--R                     + 
+--R                               2 3 3            4 2        2 5   3
+--R                       (- 7560A a b  - 3360A B a b  + 1680B a b)c
+--R                     + 
+--R                             2 2 5            3 4       2 4 3  2
+--R                       (1701A a b  + 1260A B a b  + 280B a b )c
+--R                     + 
+--R                              2   7           2 6      2 3 5       2 9
+--R                       (- 189A a b  - 168A B a b  - 35B a b )c + 9A b
+--R                     + 
+--R                               8    2 2 7
+--R                       6A B a b  + B a b
+--R                  /
+--R                              10 5          9 2 4         8 4 3         7 6 2
+--R                       131072a  c  - 163840a b c  + 81920a b c  - 20480a b c
+--R                     + 
+--R                            6 8        5 10
+--R                       2560a b c - 128a b
+--R            + 
+--R                          4 4 7              4 3 2           3   4   6
+--R                  3111696A a c  + (- 1555848A a b  - 3111696A B a b)c
+--R                + 
+--R                             4 2 4           3   3 3          2 2 4 2
+--R                      339309A a b  + 1298376A B a b  + 863136A B a b
+--R                    + 
+--R                              3 5          4 6
+--R                      90000A B a b - 10000B a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              4   6          3   2 5          2 2 3 4
+--R                      - 36207A a b  - 242757A B a b  - 238464A B a b
+--R                    + 
+--R                                3 4 3         4 5 2
+--R                      - 98856A B a b  - 15000B a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           4 8         3     7         2 2 2 6           3 3 5
+--R                      1701A b  + 22113A B a b  + 27594A B a b  + 11277A B a b
+--R                    + 
+--R                           4 4 4
+--R                      1491B a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   9       2 2   8         3 2 7      4 3 6  2
+--R                  (- 945A B b  - 945A B a b  - 315A B a b  - 35B a b )c
+--R             *
+--R                x
+--R     + 
+--R                                                  +-----------+
+--R                            2         3        2  |          2          2 2
+--R           ((24A a b - 20B a )c - 3A b  - B a b )\|- 4a c + b   - 168A a c
+--R         + 
+--R                   2        2          4        3
+--R           (30A a b  + 52B a b)c - 3A b  - B a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                                  +-----------+
+--R                            2         3        2  |          2          2 2
+--R           ((24A a b - 20B a )c - 3A b  - B a b )\|- 4a c + b   + 168A a c
+--R         + 
+--R                     2        2          4        3
+--R           (- 30A a b  - 52B a b)c + 3A b  + B a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R            4 2      3 2      2 4  +-+ |          2  |   |          2
+--R       (128a c  - 64a b c + 8a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2326
+
+--S 2327 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2327
+
+)clear all
+
+--S 2328 of 3139
+t0:=(3+x^2)/(1+3*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 3
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2328
+
+--S 2329 of 3139
+r0:=1/2*atan(x*sqrt(1/2*(3+sqrt(5))))*(3+sqrt(5))^(3/2)/sqrt(10)-_
+   atan(x*sqrt(2/(3+sqrt(5))))*sqrt(1/5*(9-4*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                    +--------+
+--R                   +--------+       | +-+
+--R          +-+      | +-+          x\|\|5  + 3
+--R       (3\|5  + 5)\|\|5  + 3 atan(------------)
+--R                                       +-+
+--R                                      \|2
+--R     + 
+--R                                    +----------+
+--R                +-----------+       |   +-+
+--R           +--+ |    +-+          x\|- \|5  + 3
+--R       - 2\|10 \|- 4\|5  + 9 atan(--------------)
+--R                                        +-+
+--R                                       \|2
+--R  /
+--R       +-+ +--+
+--R     2\|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 2329
+
+--S 2330 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                     +----------+
+--R                                     |  +-+
+--R                           +-+       |9\|5  + 20
+--R      +----------+     (15\|5  - 35) |----------
+--R      |  +-+                         |     +-+
+--R      |9\|5  + 20                   \|   5\|5
+--R      |---------- atan(--------------------------)
+--R      |     +-+                     +-+
+--R     \|   5\|5                   2x\|5
+--R   + 
+--R                                     +----------+
+--R                                     |  +-+
+--R                           +-+       |9\|5  - 20
+--R      +----------+     (15\|5  + 35) |----------
+--R      |  +-+                         |     +-+
+--R      |9\|5  - 20                   \|   5\|5
+--R      |---------- atan(--------------------------)
+--R      |     +-+                     +-+
+--R     \|   5\|5                   2x\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 2330
+
+--S 2331 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +--------+
+--R                     +--------+       | +-+
+--R            +-+      | +-+          x\|\|5  + 3
+--R       (- 3\|5  - 5)\|\|5  + 3 atan(------------)
+--R                                         +-+
+--R                                        \|2
+--R     + 
+--R                                                 +----------+
+--R                                                 |  +-+
+--R                                       +-+       |9\|5  + 20
+--R                  +----------+     (15\|5  - 35) |----------
+--R                  |  +-+                         |     +-+
+--R         +-+ +--+ |9\|5  + 20                   \|   5\|5
+--R       2\|5 \|10  |---------- atan(--------------------------)
+--R                  |     +-+                     +-+
+--R                 \|   5\|5                   2x\|5
+--R     + 
+--R                                                 +----------+
+--R                                                 |  +-+
+--R                                       +-+       |9\|5  - 20
+--R                  +----------+     (15\|5  + 35) |----------
+--R                  |  +-+                         |     +-+
+--R         +-+ +--+ |9\|5  - 20                   \|   5\|5
+--R       2\|5 \|10  |---------- atan(--------------------------)
+--R                  |     +-+                     +-+
+--R                 \|   5\|5                   2x\|5
+--R     + 
+--R                                  +----------+
+--R              +-----------+       |   +-+
+--R         +--+ |    +-+          x\|- \|5  + 3
+--R       2\|10 \|- 4\|5  + 9 atan(--------------)
+--R                                      +-+
+--R                                     \|2
+--R  /
+--R       +-+ +--+
+--R     2\|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 2331
+
+--S 2332 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                     +-----------+ +----------+
+--R           2      +-+ +-+     2 +-+  |    +-+      |   +-+
+--R       ((3x  + 2)\|2 \|5  + 5x \|2 )\|- 4\|5  + 9 \|- \|5  + 3
+--R     + 
+--R            2      +-+ +-+        2      +-+  +--+      2
+--R       ((- x  - 3)\|2 \|5  + (- 3x  - 7)\|2 )\|10  + 20x  + 60
+--R  /
+--R        4      2
+--R     20x  + 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 2332
+
+)clear all
+
+--S 2333 of 3139
+t0:=(a+b*x^2)/(1+x^2+x^4)
+--R 
+--R
+--R             2
+--R          b x  + a
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2333
+
+--S 2334 of 3139
+r0:=-1/4*(a-b)*log(1-x+x^2)+1/4*(a-b)*log(1+x+x^2)-_
+   1/2*(a+b)*atan((1-2*x)/sqrt(3))/sqrt(3)+1/2*(a+b)*atan((1+2*x)/_
+   sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                 +-+     2                    +-+     2
+--R       (- b + a)\|3 log(x  + x + 1) + (b - a)\|3 log(x  - x + 1)
+--R     + 
+--R                              +-+                           +-+
+--R                     (2x + 1)\|3                   (2x - 1)\|3
+--R       (2b + 2a)atan(------------) + (2b + 2a)atan(------------)
+--R                           3                             3
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 2334
+
+--S 2335 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 +-+     2                    +-+     2
+--R       (- b + a)\|3 log(x  + x + 1) + (b - a)\|3 log(x  - x + 1)
+--R     + 
+--R                              +-+                           +-+
+--R                     (2x + 1)\|3                   (2x - 1)\|3
+--R       (2b + 2a)atan(------------) + (2b + 2a)atan(------------)
+--R                           3                             3
+--R  /
+--R       +-+
+--R     4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 2335
+
+--S 2336 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2336
+
+--S 2337 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2337
+
+)clear all
+
+--S 2338 of 3139
+t0:=(a+b*x^2)/(1+x^2+x^4)^2
+--R 
+--R
+--R                   2
+--R                b x  + a
+--R   (1)  ------------------------
+--R         8     6     4     2
+--R        x  + 2x  + 3x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2338
+
+--S 2339 of 3139
+r0:=1/6*x*(a+b-(a-2*b)*x^2)/(1+x^2+x^4)-1/8*(2*a-b)*log(1-x+x^2)+_
+   1/8*(2*a-b)*log(1+x+x^2)-1/12*(4*a+b)*atan((1-2*x)/sqrt(3))/sqrt(3)+_
+   1/12*(4*a+b)*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                    4               2            +-+     2
+--R       ((- 3b + 6a)x  + (- 3b + 6a)x  - 3b + 6a)\|3 log(x  + x + 1)
+--R     + 
+--R                  4             2            +-+     2
+--R       ((3b - 6a)x  + (3b - 6a)x  + 3b - 6a)\|3 log(x  - x + 1)
+--R     + 
+--R                                                          +-+
+--R                  4             2                (2x + 1)\|3
+--R       ((2b + 8a)x  + (2b + 8a)x  + 2b + 8a)atan(------------)
+--R                                                       3
+--R     + 
+--R                                                          +-+
+--R                  4             2                (2x - 1)\|3
+--R       ((2b + 8a)x  + (2b + 8a)x  + 2b + 8a)atan(------------)
+--R                                                       3
+--R     + 
+--R                  3               +-+
+--R       ((8b - 4a)x  + (4b + 4a)x)\|3
+--R  /
+--R         4      2       +-+
+--R     (24x  + 24x  + 24)\|3
+--R                                                    Type: Expression(Integer)
+--E 2339
+
+--S 2340 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    4               2            +-+     2
+--R       ((- 3b + 6a)x  + (- 3b + 6a)x  - 3b + 6a)\|3 log(x  + x + 1)
+--R     + 
+--R                  4             2            +-+     2
+--R       ((3b - 6a)x  + (3b - 6a)x  + 3b - 6a)\|3 log(x  - x + 1)
+--R     + 
+--R                                                          +-+
+--R                  4             2                (2x + 1)\|3
+--R       ((2b + 8a)x  + (2b + 8a)x  + 2b + 8a)atan(------------)
+--R                                                       3
+--R     + 
+--R                                                          +-+
+--R                  4             2                (2x - 1)\|3
+--R       ((2b + 8a)x  + (2b + 8a)x  + 2b + 8a)atan(------------)
+--R                                                       3
+--R     + 
+--R                  3               +-+
+--R       ((8b - 4a)x  + (4b + 4a)x)\|3
+--R  /
+--R         4      2       +-+
+--R     (24x  + 24x  + 24)\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 2340
+
+--S 2341 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2341
+
+--S 2342 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2342
+
+)clear all
+
+--S 2343 of 3139
+t0:=(a+b*x^2)/(2+x^2+x^4)
+--R 
+--R
+--R             2
+--R          b x  + a
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2343
+
+--S 2344 of 3139
+r0:=-1/4*log(x^2+sqrt(2)-x*sqrt(-1+2*sqrt(2)))*(a-b*sqrt(2))*sqrt(1/14*_
+   (1+2*sqrt(2)))+1/4*log(x^2+sqrt(2)+x*sqrt(-1+2*sqrt(2)))*(a-b*sqrt(2))*_
+   sqrt(1/14*(1+2*sqrt(2)))-1/2*atan((-2*x+sqrt(-1+2*sqrt(2)))/sqrt(1+_
+   2*sqrt(2)))*(a+b*sqrt(2))/sqrt(2*(1+2*sqrt(2)))+1/2*atan((2*x+sqrt(-1+_
+   2*sqrt(2)))/sqrt(1+2*sqrt(2)))*(a+b*sqrt(2))/sqrt(2*(1+2*sqrt(2)))
+--R 
+--R
+--R   (2)
+--R                     +---------+ +---------+      +---------+
+--R            +-+      |  +-+      |  +-+           |  +-+         +-+    2
+--R       (- b\|2  + a)\|2\|2  + 1 \|4\|2  + 2 log(x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R                   +---------+ +---------+        +---------+
+--R          +-+      |  +-+      |  +-+             |  +-+         +-+    2
+--R       (b\|2  - a)\|2\|2  + 1 \|4\|2  + 2 log(- x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R             +-+       +--+
+--R         (2b\|2  + 2a)\|14
+--R      *
+--R                           +---------+                +---------+
+--R                  +-+      |  +-+           +-+       |  +-+
+--R              ((2\|2  - 1)\|2\|2  - 1  + 4x\|2  - 2x)\|2\|2  + 1
+--R         atan(---------------------------------------------------)
+--R                                       7
+--R     + 
+--R               +-+       +--+
+--R         (- 2b\|2  - 2a)\|14
+--R      *
+--R                           +---------+                +---------+
+--R                  +-+      |  +-+           +-+       |  +-+
+--R              ((2\|2  - 1)\|2\|2  - 1  - 4x\|2  + 2x)\|2\|2  + 1
+--R         atan(---------------------------------------------------)
+--R                                       7
+--R  /
+--R            +---------+
+--R       +--+ |  +-+
+--R     4\|14 \|4\|2  + 2
+--R                                                    Type: Expression(Integer)
+--E 2344
+
+--S 2345 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                                                          +----------------+
+--R                                                          |  4     2 2    4
+--R                                                        7\|4b  - 4a b  + a
+--R                                                  atan(---------------------)
+--R             +-------------------------------+            2           2  +-+
+--R            4|  4       3     2 2     3     4          (2b  - 8a b + a )\|7
+--R            \|4b  - 4a b  + 5a b  - 2a b + a  cos(---------------------------)
+--R                                                               2
+--R         *
+--R            log
+--R                                 +-------------------------------+2
+--R                       2      2 4|  4       3     2 2     3     4
+--R                   (28b  - 14a )\|4b  - 4a b  + 5a b  - 2a b + a
+--R                *
+--R                               +----------------+  2
+--R                               |  4     2 2    4
+--R                             7\|4b  - 4a b  + a
+--R                       atan(---------------------)
+--R                               2           2  +-+
+--R                            (2b  - 8a b + a )\|7
+--R                   sin(---------------------------)
+--R                                    2
+--R               + 
+--R                                      +-------------------------------+
+--R                             +-+4+--+4|  4       3     2 2     3     4
+--R                   (4b - a)x\|7 \|98 \|4b  - 4a b  + 5a b  - 2a b + a
+--R                *
+--R                                                  +----------------+
+--R                                                  |  4     2 2    4
+--R                                                7\|4b  - 4a b  + a
+--R                                          atan(---------------------)
+--R                    +----------------+            2           2  +-+
+--R                    |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                   \|4b  - 4a b  + a  sin(---------------------------)
+--R                                                       2
+--R               + 
+--R                                 +-------------------------------+2
+--R                       2      2 4|  4       3     2 2     3     4
+--R                   (28b  - 14a )\|4b  - 4a b  + 5a b  - 2a b + a
+--R                *
+--R                               +----------------+  2
+--R                               |  4     2 2    4
+--R                             7\|4b  - 4a b  + a
+--R                       atan(---------------------)
+--R                               2           2  +-+
+--R                            (2b  - 8a b + a )\|7
+--R                   cos(---------------------------)
+--R                                    2
+--R               + 
+--R                                          +-------------------------------+
+--R                           2     3  4+--+4|  4       3     2 2     3     4
+--R                   (- 14a b  + 7a )x\|98 \|4b  - 4a b  + 5a b  - 2a b + a
+--R                *
+--R                               +----------------+
+--R                               |  4     2 2    4
+--R                             7\|4b  - 4a b  + a
+--R                       atan(---------------------)
+--R                               2           2  +-+
+--R                            (2b  - 8a b + a )\|7
+--R                   cos(---------------------------)
+--R                                    2
+--R               + 
+--R                    4       3    3     4  2 4+--+2
+--R                 (4b  - 2a b  + a b - a )x  \|98
+--R     + 
+--R                                                       +----------------+
+--R                                                       |  4     2 2    4
+--R                                                     7\|4b  - 4a b  + a
+--R                                               atan(---------------------)
+--R          +-------------------------------+            2           2  +-+
+--R         4|  4       3     2 2     3     4          (2b  - 8a b + a )\|7
+--R         \|4b  - 4a b  + 5a b  - 2a b + a  cos(---------------------------)
+--R                                                            2
+--R      *
+--R         log
+--R                              +-------------------------------+2
+--R                    2      2 4|  4       3     2 2     3     4
+--R                (28b  - 14a )\|4b  - 4a b  + 5a b  - 2a b + a
+--R             *
+--R                            +----------------+  2
+--R                            |  4     2 2    4
+--R                          7\|4b  - 4a b  + a
+--R                    atan(---------------------)
+--R                            2           2  +-+
+--R                         (2b  - 8a b + a )\|7
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R                                     +-------------------------------+
+--R                            +-+4+--+4|  4       3     2 2     3     4
+--R                (- 4b + a)x\|7 \|98 \|4b  - 4a b  + 5a b  - 2a b + a
+--R             *
+--R                                               +----------------+
+--R                                               |  4     2 2    4
+--R                                             7\|4b  - 4a b  + a
+--R                                       atan(---------------------)
+--R                 +----------------+            2           2  +-+
+--R                 |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                \|4b  - 4a b  + a  sin(---------------------------)
+--R                                                    2
+--R            + 
+--R                              +-------------------------------+2
+--R                    2      2 4|  4       3     2 2     3     4
+--R                (28b  - 14a )\|4b  - 4a b  + 5a b  - 2a b + a
+--R             *
+--R                            +----------------+  2
+--R                            |  4     2 2    4
+--R                          7\|4b  - 4a b  + a
+--R                    atan(---------------------)
+--R                            2           2  +-+
+--R                         (2b  - 8a b + a )\|7
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                                     +-------------------------------+
+--R                      2     3  4+--+4|  4       3     2 2     3     4
+--R                (14a b  - 7a )x\|98 \|4b  - 4a b  + 5a b  - 2a b + a
+--R             *
+--R                            +----------------+
+--R                            |  4     2 2    4
+--R                          7\|4b  - 4a b  + a
+--R                    atan(---------------------)
+--R                            2           2  +-+
+--R                         (2b  - 8a b + a )\|7
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                 4       3    3     4  2 4+--+2
+--R              (4b  - 2a b  + a b - a )x  \|98
+--R     + 
+--R                                                        +----------------+
+--R                                                        |  4     2 2    4
+--R                                                      7\|4b  - 4a b  + a
+--R                                                atan(---------------------)
+--R           +-------------------------------+            2           2  +-+
+--R          4|  4       3     2 2     3     4          (2b  - 8a b + a )\|7
+--R         2\|4b  - 4a b  + 5a b  - 2a b + a  sin(---------------------------)
+--R                                                             2
+--R      *
+--R         atan
+--R                                     +-------------------------------+
+--R                        2     3  +-+4|  4       3     2 2     3     4
+--R                  (14a b  - 7a )\|7 \|4b  - 4a b  + 5a b  - 2a b + a
+--R               *
+--R                              +----------------+
+--R                              |  4     2 2    4
+--R                            7\|4b  - 4a b  + a
+--R                      atan(---------------------)
+--R                              2           2  +-+
+--R                           (2b  - 8a b + a )\|7
+--R                  sin(---------------------------)
+--R                                   2
+--R              + 
+--R                             +-------------------------------+
+--R                            4|  4       3     2 2     3     4
+--R                  (28b - 7a)\|4b  - 4a b  + 5a b  - 2a b + a
+--R               *
+--R                                                 +----------------+
+--R                                                 |  4     2 2    4
+--R                                               7\|4b  - 4a b  + a
+--R                                         atan(---------------------)
+--R                   +----------------+            2           2  +-+
+--R                   |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                  \|4b  - 4a b  + a  cos(---------------------------)
+--R                                                      2
+--R           /
+--R                             +-------------------------------+
+--R                            4|  4       3     2 2     3     4
+--R                  (28b - 7a)\|4b  - 4a b  + 5a b  - 2a b + a
+--R               *
+--R                                                 +----------------+
+--R                                                 |  4     2 2    4
+--R                                               7\|4b  - 4a b  + a
+--R                                         atan(---------------------)
+--R                   +----------------+            2           2  +-+
+--R                   |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                  \|4b  - 4a b  + a  sin(---------------------------)
+--R                                                      2
+--R              + 
+--R                                       +-------------------------------+
+--R                          2     3  +-+4|  4       3     2 2     3     4
+--R                  (- 14a b  + 7a )\|7 \|4b  - 4a b  + 5a b  - 2a b + a
+--R               *
+--R                              +----------------+
+--R                              |  4     2 2    4
+--R                            7\|4b  - 4a b  + a
+--R                      atan(---------------------)
+--R                              2           2  +-+
+--R                           (2b  - 8a b + a )\|7
+--R                  cos(---------------------------)
+--R                                   2
+--R              + 
+--R                     4       3     3      4   +-+4+--+
+--R                (- 8b  + 4a b  - 2a b + 2a )x\|7 \|98
+--R     + 
+--R       -
+--R                                                           +----------------+
+--R                                                           |  4     2 2    4
+--R                                                         7\|4b  - 4a b  + a
+--R                                                   atan(---------------------)
+--R              +-------------------------------+            2           2  +-+
+--R             4|  4       3     2 2     3     4          (2b  - 8a b + a )\|7
+--R            2\|4b  - 4a b  + 5a b  - 2a b + a  sin(---------------------------)
+--R                                                                2
+--R         *
+--R            atan
+--R                                        +-------------------------------+
+--R                           2     3  +-+4|  4       3     2 2     3     4
+--R                     (14a b  - 7a )\|7 \|4b  - 4a b  + 5a b  - 2a b + a
+--R                  *
+--R                                 +----------------+
+--R                                 |  4     2 2    4
+--R                               7\|4b  - 4a b  + a
+--R                         atan(---------------------)
+--R                                 2           2  +-+
+--R                              (2b  - 8a b + a )\|7
+--R                     sin(---------------------------)
+--R                                      2
+--R                 + 
+--R                                +-------------------------------+
+--R                               4|  4       3     2 2     3     4
+--R                     (28b - 7a)\|4b  - 4a b  + 5a b  - 2a b + a
+--R                  *
+--R                                                    +----------------+
+--R                                                    |  4     2 2    4
+--R                                                  7\|4b  - 4a b  + a
+--R                                            atan(---------------------)
+--R                      +----------------+            2           2  +-+
+--R                      |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                     \|4b  - 4a b  + a  cos(---------------------------)
+--R                                                         2
+--R              /
+--R                                +-------------------------------+
+--R                               4|  4       3     2 2     3     4
+--R                     (28b - 7a)\|4b  - 4a b  + 5a b  - 2a b + a
+--R                  *
+--R                                                    +----------------+
+--R                                                    |  4     2 2    4
+--R                                                  7\|4b  - 4a b  + a
+--R                                            atan(---------------------)
+--R                      +----------------+            2           2  +-+
+--R                      |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                     \|4b  - 4a b  + a  sin(---------------------------)
+--R                                                         2
+--R                 + 
+--R                                          +-------------------------------+
+--R                             2     3  +-+4|  4       3     2 2     3     4
+--R                     (- 14a b  + 7a )\|7 \|4b  - 4a b  + 5a b  - 2a b + a
+--R                  *
+--R                                 +----------------+
+--R                                 |  4     2 2    4
+--R                               7\|4b  - 4a b  + a
+--R                         atan(---------------------)
+--R                                 2           2  +-+
+--R                              (2b  - 8a b + a )\|7
+--R                     cos(---------------------------)
+--R                                      2
+--R                 + 
+--R                      4       3     3      4   +-+4+--+
+--R                   (8b  - 4a b  + 2a b - 2a )x\|7 \|98
+--R  /
+--R      4+--+
+--R     2\|98
+--R                                         Type: Union(Expression(Integer),...)
+--E 2345
+
+--S 2346 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                   +-------------------------------+ +---------+
+--R              +--+4|  4       3     2 2     3     4  |  +-+
+--R            2\|14 \|4b  - 4a b  + 5a b  - 2a b + a  \|4\|2  + 2
+--R         *
+--R                        +----------------+
+--R                        |  4     2 2    4
+--R                      7\|4b  - 4a b  + a
+--R                atan(---------------------)
+--R                        2           2  +-+
+--R                     (2b  - 8a b + a )\|7
+--R            cos(---------------------------)
+--R                             2
+--R         *
+--R            log
+--R                                 +-------------------------------+2
+--R                       2      2 4|  4       3     2 2     3     4
+--R                   (28b  - 14a )\|4b  - 4a b  + 5a b  - 2a b + a
+--R                *
+--R                               +----------------+  2
+--R                               |  4     2 2    4
+--R                             7\|4b  - 4a b  + a
+--R                       atan(---------------------)
+--R                               2           2  +-+
+--R                            (2b  - 8a b + a )\|7
+--R                   sin(---------------------------)
+--R                                    2
+--R               + 
+--R                                      +-------------------------------+
+--R                             +-+4+--+4|  4       3     2 2     3     4
+--R                   (4b - a)x\|7 \|98 \|4b  - 4a b  + 5a b  - 2a b + a
+--R                *
+--R                                                  +----------------+
+--R                                                  |  4     2 2    4
+--R                                                7\|4b  - 4a b  + a
+--R                                          atan(---------------------)
+--R                    +----------------+            2           2  +-+
+--R                    |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                   \|4b  - 4a b  + a  sin(---------------------------)
+--R                                                       2
+--R               + 
+--R                                 +-------------------------------+2
+--R                       2      2 4|  4       3     2 2     3     4
+--R                   (28b  - 14a )\|4b  - 4a b  + 5a b  - 2a b + a
+--R                *
+--R                               +----------------+  2
+--R                               |  4     2 2    4
+--R                             7\|4b  - 4a b  + a
+--R                       atan(---------------------)
+--R                               2           2  +-+
+--R                            (2b  - 8a b + a )\|7
+--R                   cos(---------------------------)
+--R                                    2
+--R               + 
+--R                                          +-------------------------------+
+--R                           2     3  4+--+4|  4       3     2 2     3     4
+--R                   (- 14a b  + 7a )x\|98 \|4b  - 4a b  + 5a b  - 2a b + a
+--R                *
+--R                               +----------------+
+--R                               |  4     2 2    4
+--R                             7\|4b  - 4a b  + a
+--R                       atan(---------------------)
+--R                               2           2  +-+
+--R                            (2b  - 8a b + a )\|7
+--R                   cos(---------------------------)
+--R                                    2
+--R               + 
+--R                    4       3    3     4  2 4+--+2
+--R                 (4b  - 2a b  + a b - a )x  \|98
+--R     + 
+--R                +-------------------------------+ +---------+
+--R           +--+4|  4       3     2 2     3     4  |  +-+
+--R         2\|14 \|4b  - 4a b  + 5a b  - 2a b + a  \|4\|2  + 2
+--R      *
+--R                     +----------------+
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         cos(---------------------------)
+--R                          2
+--R      *
+--R         log
+--R                              +-------------------------------+2
+--R                    2      2 4|  4       3     2 2     3     4
+--R                (28b  - 14a )\|4b  - 4a b  + 5a b  - 2a b + a
+--R             *
+--R                            +----------------+  2
+--R                            |  4     2 2    4
+--R                          7\|4b  - 4a b  + a
+--R                    atan(---------------------)
+--R                            2           2  +-+
+--R                         (2b  - 8a b + a )\|7
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R                                     +-------------------------------+
+--R                            +-+4+--+4|  4       3     2 2     3     4
+--R                (- 4b + a)x\|7 \|98 \|4b  - 4a b  + 5a b  - 2a b + a
+--R             *
+--R                                               +----------------+
+--R                                               |  4     2 2    4
+--R                                             7\|4b  - 4a b  + a
+--R                                       atan(---------------------)
+--R                 +----------------+            2           2  +-+
+--R                 |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                \|4b  - 4a b  + a  sin(---------------------------)
+--R                                                    2
+--R            + 
+--R                              +-------------------------------+2
+--R                    2      2 4|  4       3     2 2     3     4
+--R                (28b  - 14a )\|4b  - 4a b  + 5a b  - 2a b + a
+--R             *
+--R                            +----------------+  2
+--R                            |  4     2 2    4
+--R                          7\|4b  - 4a b  + a
+--R                    atan(---------------------)
+--R                            2           2  +-+
+--R                         (2b  - 8a b + a )\|7
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                                     +-------------------------------+
+--R                      2     3  4+--+4|  4       3     2 2     3     4
+--R                (14a b  - 7a )x\|98 \|4b  - 4a b  + 5a b  - 2a b + a
+--R             *
+--R                            +----------------+
+--R                            |  4     2 2    4
+--R                          7\|4b  - 4a b  + a
+--R                    atan(---------------------)
+--R                            2           2  +-+
+--R                         (2b  - 8a b + a )\|7
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                 4       3    3     4  2 4+--+2
+--R              (4b  - 2a b  + a b - a )x  \|98
+--R     + 
+--R                +-------------------------------+ +---------+
+--R           +--+4|  4       3     2 2     3     4  |  +-+
+--R         4\|14 \|4b  - 4a b  + 5a b  - 2a b + a  \|4\|2  + 2
+--R      *
+--R                     +----------------+
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R      *
+--R         atan
+--R                                     +-------------------------------+
+--R                        2     3  +-+4|  4       3     2 2     3     4
+--R                  (14a b  - 7a )\|7 \|4b  - 4a b  + 5a b  - 2a b + a
+--R               *
+--R                              +----------------+
+--R                              |  4     2 2    4
+--R                            7\|4b  - 4a b  + a
+--R                      atan(---------------------)
+--R                              2           2  +-+
+--R                           (2b  - 8a b + a )\|7
+--R                  sin(---------------------------)
+--R                                   2
+--R              + 
+--R                             +-------------------------------+
+--R                            4|  4       3     2 2     3     4
+--R                  (28b - 7a)\|4b  - 4a b  + 5a b  - 2a b + a
+--R               *
+--R                                                 +----------------+
+--R                                                 |  4     2 2    4
+--R                                               7\|4b  - 4a b  + a
+--R                                         atan(---------------------)
+--R                   +----------------+            2           2  +-+
+--R                   |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                  \|4b  - 4a b  + a  cos(---------------------------)
+--R                                                      2
+--R           /
+--R                             +-------------------------------+
+--R                            4|  4       3     2 2     3     4
+--R                  (28b - 7a)\|4b  - 4a b  + 5a b  - 2a b + a
+--R               *
+--R                                                 +----------------+
+--R                                                 |  4     2 2    4
+--R                                               7\|4b  - 4a b  + a
+--R                                         atan(---------------------)
+--R                   +----------------+            2           2  +-+
+--R                   |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                  \|4b  - 4a b  + a  sin(---------------------------)
+--R                                                      2
+--R              + 
+--R                                       +-------------------------------+
+--R                          2     3  +-+4|  4       3     2 2     3     4
+--R                  (- 14a b  + 7a )\|7 \|4b  - 4a b  + 5a b  - 2a b + a
+--R               *
+--R                              +----------------+
+--R                              |  4     2 2    4
+--R                            7\|4b  - 4a b  + a
+--R                      atan(---------------------)
+--R                              2           2  +-+
+--R                           (2b  - 8a b + a )\|7
+--R                  cos(---------------------------)
+--R                                   2
+--R              + 
+--R                     4       3     3      4   +-+4+--+
+--R                (- 8b  + 4a b  - 2a b + 2a )x\|7 \|98
+--R     + 
+--R       -
+--R                   +-------------------------------+ +---------+
+--R              +--+4|  4       3     2 2     3     4  |  +-+
+--R            4\|14 \|4b  - 4a b  + 5a b  - 2a b + a  \|4\|2  + 2
+--R         *
+--R                        +----------------+
+--R                        |  4     2 2    4
+--R                      7\|4b  - 4a b  + a
+--R                atan(---------------------)
+--R                        2           2  +-+
+--R                     (2b  - 8a b + a )\|7
+--R            sin(---------------------------)
+--R                             2
+--R         *
+--R            atan
+--R                                        +-------------------------------+
+--R                           2     3  +-+4|  4       3     2 2     3     4
+--R                     (14a b  - 7a )\|7 \|4b  - 4a b  + 5a b  - 2a b + a
+--R                  *
+--R                                 +----------------+
+--R                                 |  4     2 2    4
+--R                               7\|4b  - 4a b  + a
+--R                         atan(---------------------)
+--R                                 2           2  +-+
+--R                              (2b  - 8a b + a )\|7
+--R                     sin(---------------------------)
+--R                                      2
+--R                 + 
+--R                                +-------------------------------+
+--R                               4|  4       3     2 2     3     4
+--R                     (28b - 7a)\|4b  - 4a b  + 5a b  - 2a b + a
+--R                  *
+--R                                                    +----------------+
+--R                                                    |  4     2 2    4
+--R                                                  7\|4b  - 4a b  + a
+--R                                            atan(---------------------)
+--R                      +----------------+            2           2  +-+
+--R                      |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                     \|4b  - 4a b  + a  cos(---------------------------)
+--R                                                         2
+--R              /
+--R                                +-------------------------------+
+--R                               4|  4       3     2 2     3     4
+--R                     (28b - 7a)\|4b  - 4a b  + 5a b  - 2a b + a
+--R                  *
+--R                                                    +----------------+
+--R                                                    |  4     2 2    4
+--R                                                  7\|4b  - 4a b  + a
+--R                                            atan(---------------------)
+--R                      +----------------+            2           2  +-+
+--R                      |  4     2 2    4          (2b  - 8a b + a )\|7
+--R                     \|4b  - 4a b  + a  sin(---------------------------)
+--R                                                         2
+--R                 + 
+--R                                          +-------------------------------+
+--R                             2     3  +-+4|  4       3     2 2     3     4
+--R                     (- 14a b  + 7a )\|7 \|4b  - 4a b  + 5a b  - 2a b + a
+--R                  *
+--R                                 +----------------+
+--R                                 |  4     2 2    4
+--R                               7\|4b  - 4a b  + a
+--R                         atan(---------------------)
+--R                                 2           2  +-+
+--R                              (2b  - 8a b + a )\|7
+--R                     cos(---------------------------)
+--R                                      2
+--R                 + 
+--R                      4       3     3      4   +-+4+--+
+--R                   (8b  - 4a b  + 2a b - 2a )x\|7 \|98
+--R     + 
+--R                        +---------+ +---------+      +---------+
+--R          +-+     4+--+ |  +-+      |  +-+           |  +-+         +-+    2
+--R       (b\|2  - a)\|98 \|2\|2  + 1 \|4\|2  + 2 log(x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R                            +---------+ +---------+
+--R              +-+     4+--+ |  +-+      |  +-+
+--R         (- b\|2  + a)\|98 \|2\|2  + 1 \|4\|2  + 2
+--R      *
+--R                 +---------+
+--R                 |  +-+         +-+    2
+--R         log(- x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R               +-+       +--+4+--+
+--R         (- 2b\|2  - 2a)\|14 \|98
+--R      *
+--R                           +---------+                +---------+
+--R                  +-+      |  +-+           +-+       |  +-+
+--R              ((2\|2  - 1)\|2\|2  - 1  + 4x\|2  - 2x)\|2\|2  + 1
+--R         atan(---------------------------------------------------)
+--R                                       7
+--R     + 
+--R             +-+       +--+4+--+
+--R         (2b\|2  + 2a)\|14 \|98
+--R      *
+--R                           +---------+                +---------+
+--R                  +-+      |  +-+           +-+       |  +-+
+--R              ((2\|2  - 1)\|2\|2  - 1  - 4x\|2  + 2x)\|2\|2  + 1
+--R         atan(---------------------------------------------------)
+--R                                       7
+--R  /
+--R                 +---------+
+--R       +--+4+--+ |  +-+
+--R     4\|14 \|98 \|4\|2  + 2
+--R                                                    Type: Expression(Integer)
+--E 2346
+
+--S 2347 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                             7         6       2 5       3 4       4 3       5 2
+--R                       - 576b  + 832a b  - 688a b  + 192a b  + 216a b  - 240a b
+--R                     + 
+--R                           6       7
+--R                       136a b - 32a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                       7          6       2 5       3 4       4 3       5 2
+--R                   512b  - 1088a b  + 960a b  - 432a b  - 192a b  + 344a b
+--R                 + 
+--R                         6       7
+--R                   - 208a b + 72a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       7          6       2 5       3 4       4 3       5 2
+--R                   512b  - 1088a b  + 960a b  - 432a b  - 192a b  + 344a b
+--R                 + 
+--R                         6       7
+--R                   - 208a b + 72a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                      7          6        2 5       3 4       4 3       5 2
+--R               - 1152b  + 1664a b  - 1376a b  + 384a b  + 432a b  - 480a b
+--R             + 
+--R                   6       7
+--R               272a b - 64a
+--R          *
+--R                    +---------+ +---------+
+--R             4+--+2 |  +-+      |  +-+
+--R             \|98  \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                          7        6      2 5      3 4      4 3      5 2      6
+--R                       64b  + 64a b  - 80a b  + 96a b  - 24a b  - 32a b  + 24a b
+--R                     + 
+--R                            7
+--R                       - 16a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                       7         6       2 5      3 4      4 3      5 2      6
+--R                   256b  - 192a b  + 128a b  + 48a b  - 96a b  + 40a b  - 16a b
+--R                 + 
+--R                       7
+--R                   - 8a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         7         6       2 5      3 4      4 3      5 2
+--R                   - 256b  + 192a b  - 128a b  - 48a b  + 96a b  - 40a b
+--R                 + 
+--R                      6      7
+--R                   16a b + 8a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                     7         6       2 5       3 4      4 3      5 2      6
+--R               - 128b  - 128a b  + 160a b  - 192a b  + 48a b  + 64a b  - 48a b
+--R             + 
+--R                  7
+--R               32a
+--R          *
+--R                         +---------+ +---------+
+--R              +--+4+--+2 |  +-+      |  +-+
+--R             \|14 \|98  \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                           6        2 5        3 4       5 2       6        7  4
+--R                   (1792a b  - 1792a b  + 1344a b  - 672a b  + 448a b - 224a )x
+--R                 + 
+--R                           6        2 5        3 4       5 2       6        7  2
+--R                   (1792a b  - 1792a b  + 1344a b  - 672a b  + 448a b - 224a )x
+--R                 + 
+--R                          6        2 5        3 4        5 2       6        7
+--R                   3584a b  - 3584a b  + 2688a b  - 1344a b  + 896a b - 448a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                        6       2 5       3 4       5 2       6        7  4
+--R               (- 896a b  + 896a b  - 672a b  + 336a b  - 224a b + 112a )x
+--R             + 
+--R                        6       2 5       3 4       5 2       6        7  2
+--R               (- 896a b  + 896a b  - 672a b  + 336a b  - 224a b + 112a )x
+--R             + 
+--R                        6        2 5        3 4       5 2       6        7
+--R               - 1792a b  + 1792a b  - 1344a b  + 672a b  - 448a b + 224a
+--R          *
+--R             4+--+2
+--R             \|98
+--R      *
+--R                     +----------------+  8
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                  7          6        2 5       3 4       4 3
+--R                           - 2304b  + 3328a b  - 2752a b  + 768a b  + 864a b
+--R                         + 
+--R                                 5 2       6        7
+--R                           - 960a b  + 544a b - 128a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                            7          6        2 5        3 4       4 3
+--R                       2048b  - 4352a b  + 3840a b  - 1728a b  - 768a b
+--R                     + 
+--R                            5 2       6        7
+--R                       1376a b  - 832a b + 288a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                            7          6        2 5        3 4       4 3
+--R                       2048b  - 4352a b  + 3840a b  - 1728a b  - 768a b
+--R                     + 
+--R                            5 2       6        7
+--R                       1376a b  - 832a b + 288a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                          7          6        2 5        3 4        4 3
+--R                   - 4608b  + 6656a b  - 5504a b  + 1536a b  + 1728a b
+--R                 + 
+--R                          5 2        6        7
+--R                   - 1920a b  + 1088a b - 256a
+--R              *
+--R                        +---------+ +---------+
+--R                 4+--+2 |  +-+      |  +-+
+--R                 \|98  \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                               7         6       2 5       3 4      4 3
+--R                           256b  + 256a b  - 320a b  + 384a b  - 96a b
+--R                         + 
+--R                                 5 2      6       7
+--R                           - 128a b  + 96a b - 64a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                            7         6       2 5       3 4       4 3       5 2
+--R                       1024b  - 768a b  + 512a b  + 192a b  - 384a b  + 160a b
+--R                     + 
+--R                            6       7
+--R                       - 64a b - 32a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              7         6       2 5       3 4       4 3
+--R                       - 1024b  + 768a b  - 512a b  - 192a b  + 384a b
+--R                     + 
+--R                             5 2      6       7
+--R                       - 160a b  + 64a b + 32a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                         7         6       2 5       3 4       4 3       5 2
+--R                   - 512b  - 512a b  + 640a b  - 768a b  + 192a b  + 256a b
+--R                 + 
+--R                         6        7
+--R                   - 192a b + 128a
+--R              *
+--R                             +---------+ +---------+
+--R                  +--+4+--+2 |  +-+      |  +-+
+--R                 \|14 \|98  \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                  6        2 5        3 4        5 2        6
+--R                           7168a b  - 7168a b  + 5376a b  - 2688a b  + 1792a b
+--R                         + 
+--R                                 7
+--R                           - 896a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                  6        2 5        3 4        5 2        6
+--R                           7168a b  - 7168a b  + 5376a b  - 2688a b  + 1792a b
+--R                         + 
+--R                                 7
+--R                           - 896a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                               6         2 5         3 4        5 2        6
+--R                       14336a b  - 14336a b  + 10752a b  - 5376a b  + 3584a b
+--R                     + 
+--R                              7
+--R                       - 1792a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                6        2 5        3 4        5 2       6
+--R                       - 3584a b  + 3584a b  - 2688a b  + 1344a b  - 896a b
+--R                     + 
+--R                           7
+--R                       448a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                6        2 5        3 4        5 2       6
+--R                       - 3584a b  + 3584a b  - 2688a b  + 1344a b  - 896a b
+--R                     + 
+--R                           7
+--R                       448a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                          6        2 5        3 4        5 2        6        7
+--R                 - 7168a b  + 7168a b  - 5376a b  + 2688a b  - 1792a b + 896a
+--R              *
+--R                 4+--+2
+--R                 \|98
+--R          *
+--R                         +----------------+  2
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                         5          4        2 3        3 2       4        5  4
+--R                   (8064b  - 7616a b  - 5264a b  + 5152a b  + 616a b - 672a )x
+--R                 + 
+--R                              5           4        2 3        3 2       4
+--R                       - 7168b  + 11648a b  + 2240a b  - 8848a b  + 672a b
+--R                     + 
+--R                            5
+--R                       1512a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       5           4        2 3        3 2       4         5  4
+--R               (- 7168b  + 11648a b  + 2240a b  - 8848a b  + 672a b + 1512a )x
+--R             + 
+--R                    5           4         2 3         3 2        4         5  2
+--R             (16128b  - 15232a b  - 10528a b  + 10304a b  + 1232a b - 1344a )x
+--R          *
+--R              +-------------------------------+2 +---------+ +---------+
+--R             4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R             \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                          5          4        2 3        3 2       4        5  4
+--R                   (- 896b  - 1344a b  + 1680a b  + 1344a b  - 616a b - 336a )x
+--R                 + 
+--R                           5         4        2 3       3 2       4        5  2
+--R                   (- 3584b  + 896a b  + 3584a b  - 112a b  - 896a b - 168a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                     5         4        2 3       3 2       4        5  4
+--R               (3584b  - 896a b  - 3584a b  + 112a b  + 896a b + 168a )x
+--R             + 
+--R                     5          4        2 3        3 2        4        5  2
+--R               (1792b  + 2688a b  - 3360a b  - 2688a b  + 1232a b + 672a )x
+--R          *
+--R                   +-------------------------------+2 +---------+ +---------+
+--R              +--+4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R             \|14 \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                             4        2 3         3 2        4         5  6
+--R                   (- 6272a b  + 3136a b  + 10976a b  - 1568a b - 3920a )x
+--R                 + 
+--R                             4        2 3         3 2        4         5  4
+--R                   (- 6272a b  + 3136a b  + 10976a b  - 1568a b - 3920a )x
+--R                 + 
+--R                              4        2 3         3 2        4         5  2
+--R                   (- 12544a b  + 6272a b  + 21952a b  - 3136a b - 7840a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       4        2 3        3 2       4         5  6
+--R               (3136a b  - 1568a b  - 5488a b  + 784a b + 1960a )x
+--R             + 
+--R                       4        2 3        3 2       4         5  4
+--R               (3136a b  - 1568a b  - 5488a b  + 784a b + 1960a )x
+--R             + 
+--R                       4        2 3         3 2        4         5  2
+--R               (6272a b  - 3136a b  - 10976a b  + 1568a b + 3920a )x
+--R          *
+--R              +-------------------------------+2
+--R             4|  4       3     2 2     3     4
+--R             \|4b  - 4a b  + 5a b  - 2a b + a
+--R      *
+--R                     +----------------+  6
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                             2        2        3  4
+--R                   (- 4032a b  + 2800a b - 448a )x
+--R                 + 
+--R                           2        2         3  2
+--R                   (3584a b  - 4928a b + 1008a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                     2        2         3  4             2        2        3  2
+--R             (3584a b  - 4928a b + 1008a )x  + (- 8064a b  + 5600a b - 896a )x
+--R          *
+--R                  +-------------------------------+2 +----------------+
+--R              +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R             \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R          *
+--R              +---------+ +---------+
+--R              |  +-+      |  +-+
+--R             \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                       2       2        3  4           2       3  2  +-+
+--R               ((448a b  + 784a b - 224a )x  + (1792a b  - 112a )x )\|2
+--R             + 
+--R                         2       3  4            2        2        3  2
+--R               (- 1792a b  + 112a )x  + (- 896a b  - 1568a b + 448a )x
+--R          *
+--R                       +-------------------------------+2 +----------------+
+--R              +-+ +--+4|  4       3     2 2     3     4   |  4     2 2    4
+--R             \|7 \|14 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R          *
+--R              +---------+ +---------+
+--R              |  +-+      |  +-+
+--R             \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                         3          2        2         3  6
+--R                   (3584b  - 2688a b  + 8512a b - 2016a )x
+--R                 + 
+--R                         3          2        2         3  4
+--R                   (3584b  - 2688a b  + 8512a b - 2016a )x
+--R                 + 
+--R                         3          2         2         3  2
+--R                   (7168b  - 5376a b  + 17024a b - 4032a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       3          2        2         3  6
+--R               (- 1792b  + 1344a b  - 4256a b + 1008a )x
+--R             + 
+--R                       3          2        2         3  4
+--R               (- 1792b  + 1344a b  - 4256a b + 1008a )x
+--R             + 
+--R                       3          2        2         3  2
+--R               (- 3584b  + 2688a b  - 8512a b + 2016a )x
+--R          *
+--R                  +-------------------------------+2 +----------------+
+--R              +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R             \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R      *
+--R                     +----------------+              +----------------+  5
+--R                     |  4     2 2    4               |  4     2 2    4
+--R                   7\|4b  - 4a b  + a              7\|4b  - 4a b  + a
+--R             atan(---------------------)     atan(---------------------)
+--R                     2           2  +-+              2           2  +-+
+--R                  (2b  - 8a b + a )\|7            (2b  - 8a b + a )\|7
+--R         cos(---------------------------)sin(---------------------------)
+--R                          2                               2
+--R     + 
+--R                                  7          6        2 5        3 4        4 3
+--R                           - 3456b  + 4992a b  - 4128a b  + 1152a b  + 1296a b
+--R                         + 
+--R                                  5 2       6        7
+--R                           - 1440a b  + 816a b - 192a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                            7          6        2 5        3 4        4 3
+--R                       3072b  - 6528a b  + 5760a b  - 2592a b  - 1152a b
+--R                     + 
+--R                            5 2        6        7
+--R                       2064a b  - 1248a b + 432a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                            7          6        2 5        3 4        4 3
+--R                       3072b  - 6528a b  + 5760a b  - 2592a b  - 1152a b
+--R                     + 
+--R                            5 2        6        7
+--R                       2064a b  - 1248a b + 432a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                          7          6        2 5        3 4        4 3
+--R                   - 6912b  + 9984a b  - 8256a b  + 2304a b  + 2592a b
+--R                 + 
+--R                          5 2        6        7
+--R                   - 2880a b  + 1632a b - 384a
+--R              *
+--R                        +---------+ +---------+
+--R                 4+--+2 |  +-+      |  +-+
+--R                 \|98  \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                               7         6       2 5       3 4       4 3
+--R                           384b  + 384a b  - 480a b  + 576a b  - 144a b
+--R                         + 
+--R                                 5 2       6       7
+--R                           - 192a b  + 144a b - 96a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                            7          6       2 5       3 4       4 3       5 2
+--R                       1536b  - 1152a b  + 768a b  + 288a b  - 576a b  + 240a b
+--R                     + 
+--R                            6       7
+--R                       - 96a b - 48a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              7          6       2 5       3 4       4 3
+--R                       - 1536b  + 1152a b  - 768a b  - 288a b  + 576a b
+--R                     + 
+--R                             5 2      6       7
+--R                       - 240a b  + 96a b + 48a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                         7         6       2 5        3 4       4 3       5 2
+--R                   - 768b  - 768a b  + 960a b  - 1152a b  + 288a b  + 384a b
+--R                 + 
+--R                         6        7
+--R                   - 288a b + 192a
+--R              *
+--R                             +---------+ +---------+
+--R                  +--+4+--+2 |  +-+      |  +-+
+--R                 \|14 \|98  \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                   6         2 5        3 4        5 2        6
+--R                           10752a b  - 10752a b  + 8064a b  - 4032a b  + 2688a b
+--R                         + 
+--R                                  7
+--R                           - 1344a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                   6         2 5        3 4        5 2        6
+--R                           10752a b  - 10752a b  + 8064a b  - 4032a b  + 2688a b
+--R                         + 
+--R                                  7
+--R                           - 1344a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                               6         2 5         3 4        5 2        6
+--R                       21504a b  - 21504a b  + 16128a b  - 8064a b  + 5376a b
+--R                     + 
+--R                              7
+--R                       - 2688a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                6        2 5        3 4        5 2        6
+--R                       - 5376a b  + 5376a b  - 4032a b  + 2016a b  - 1344a b
+--R                     + 
+--R                           7
+--R                       672a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                6        2 5        3 4        5 2        6
+--R                       - 5376a b  + 5376a b  - 4032a b  + 2016a b  - 1344a b
+--R                     + 
+--R                           7
+--R                       672a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                             6         2 5        3 4        5 2        6
+--R                   - 10752a b  + 10752a b  - 8064a b  + 4032a b  - 2688a b
+--R                 + 
+--R                        7
+--R                   1344a
+--R              *
+--R                 4+--+2
+--R                 \|98
+--R          *
+--R                         +----------------+  4
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                                5          4        2 3        3 2       4
+--R                           8064b  - 7616a b  - 5264a b  + 5152a b  + 616a b
+--R                         + 
+--R                                 5
+--R                           - 672a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                  5           4        2 3        3 2       4
+--R                           - 7168b  + 11648a b  + 2240a b  - 8848a b  + 672a b
+--R                         + 
+--R                                5
+--R                           1512a
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              5           4        2 3        3 2       4
+--R                       - 7168b  + 11648a b  + 2240a b  - 8848a b  + 672a b
+--R                     + 
+--R                            5
+--R                       1512a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                             5           4         2 3         3 2        4
+--R                       16128b  - 15232a b  - 10528a b  + 10304a b  + 1232a b
+--R                     + 
+--R                              5
+--R                       - 1344a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-------------------------------+2 +---------+ +---------+
+--R                 4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R                 \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                                 5          4        2 3        3 2       4
+--R                           - 896b  - 1344a b  + 1680a b  + 1344a b  - 616a b
+--R                         + 
+--R                                 5
+--R                           - 336a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                  5         4        2 3       3 2       4
+--R                           - 3584b  + 896a b  + 3584a b  - 112a b  - 896a b
+--R                         + 
+--R                                 5
+--R                           - 168a
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                         5         4        2 3       3 2       4        5  4
+--R                   (3584b  - 896a b  - 3584a b  + 112a b  + 896a b + 168a )x
+--R                 + 
+--R                       5          4        2 3        3 2        4        5  2
+--R                 (1792b  + 2688a b  - 3360a b  - 2688a b  + 1232a b + 672a )x
+--R              *
+--R                     +-------------------------------+2 +---------+ +---------+
+--R                +--+4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R               \|14 \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                 4        2 3         3 2        4         5  6
+--R                       (- 6272a b  + 3136a b  + 10976a b  - 1568a b - 3920a )x
+--R                     + 
+--R                                 4        2 3         3 2        4         5  4
+--R                       (- 6272a b  + 3136a b  + 10976a b  - 1568a b - 3920a )x
+--R                     + 
+--R                                4        2 3         3 2        4         5  2
+--R                     (- 12544a b  + 6272a b  + 21952a b  - 3136a b - 7840a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           4        2 3        3 2       4         5  6
+--R                   (3136a b  - 1568a b  - 5488a b  + 784a b + 1960a )x
+--R                 + 
+--R                           4        2 3        3 2       4         5  4
+--R                   (3136a b  - 1568a b  - 5488a b  + 784a b + 1960a )x
+--R                 + 
+--R                           4        2 3         3 2        4         5  2
+--R                   (6272a b  - 3136a b  - 10976a b  + 1568a b + 3920a )x
+--R              *
+--R                  +-------------------------------+2
+--R                 4|  4       3     2 2     3     4
+--R                 \|4b  - 4a b  + 5a b  - 2a b + a
+--R          *
+--R                         +----------------+  2
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                              7          6      2 5        3 4       4 3
+--R                       - 1728b  + 2496a b  - 48a b  - 1328a b  + 214a b
+--R                     + 
+--R                           5 2       6       7
+--R                       176a b  + 121a b - 68a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                            7          6        2 5        3 4       4 3
+--R                       1536b  - 3264a b  + 1088a b  + 1616a b  - 800a b
+--R                     + 
+--R                             5 2      6        7
+--R                       - 298a b  - 64a b + 153a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                        7          6        2 5        3 4       4 3       5 2
+--R                   1536b  - 3264a b  + 1088a b  + 1616a b  - 800a b  - 298a b
+--R                 + 
+--R                        6        7
+--R                   - 64a b + 153a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          7          6      2 5        3 4       4 3       5 2
+--R                   - 3456b  + 4992a b  - 96a b  - 2656a b  + 428a b  + 352a b
+--R                 + 
+--R                       6        7
+--R                   242a b - 136a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                    +---------+ +---------+
+--R             4+--+2 |  +-+      |  +-+
+--R             \|98  \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                           7         6       2 5      3 4       4 3      5 2
+--R                       192b  + 192a b  - 464a b  - 48a b  + 250a b  + 44a b
+--R                     + 
+--R                            6       7
+--R                       - 33a b - 34a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                           7         6       2 5       3 4       4 3     5 2
+--R                       768b  - 576a b  - 512a b  + 368a b  + 216a b  - 6a b
+--R                     + 
+--R                            6       7
+--R                       - 76a b - 17a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         7         6       2 5       3 4       4 3     5 2
+--R                   - 768b  + 576a b  + 512a b  - 368a b  - 216a b  + 6a b
+--R                 + 
+--R                      6       7
+--R                   76a b + 17a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         7         6       2 5      3 4       4 3      5 2
+--R                   - 384b  - 384a b  + 928a b  + 96a b  - 500a b  - 88a b
+--R                 + 
+--R                      6       7
+--R                   66a b + 68a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                         +---------+ +---------+
+--R              +--+4+--+2 |  +-+      |  +-+
+--R             \|14 \|98  \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                               6       2 5       3 4       4 3       5 2
+--R                       - 896a b  + 896a b  + 896a b  - 784a b  + 336a b
+--R                     + 
+--R                           6        7
+--R                       168a b - 280a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                               6       2 5       3 4       4 3       5 2
+--R                       - 896a b  + 896a b  + 896a b  - 784a b  + 336a b
+--R                     + 
+--R                           6        7
+--R                       168a b - 280a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                6        2 5        3 4        4 3       5 2
+--R                       - 1792a b  + 1792a b  + 1792a b  - 1568a b  + 672a b
+--R                     + 
+--R                           6        7
+--R                       336a b - 560a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           6       2 5       3 4       4 3       5 2      6
+--R                     448a b  - 448a b  - 448a b  + 392a b  - 168a b  - 84a b
+--R                   + 
+--R                         7
+--R                     140a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           6       2 5       3 4       4 3       5 2      6
+--R                     448a b  - 448a b  - 448a b  + 392a b  - 168a b  - 84a b
+--R                   + 
+--R                         7
+--R                     140a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         6       2 5       3 4       4 3       5 2       6
+--R                   896a b  - 896a b  - 896a b  + 784a b  - 336a b  - 168a b
+--R                 + 
+--R                       7
+--R                   280a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R             4+--+2
+--R             \|98
+--R      *
+--R                     +----------------+  4
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                 2        2        3  4
+--R                       (- 8064a b  + 5600a b - 896a )x
+--R                     + 
+--R                               2        2         3  2
+--R                       (7168a b  - 9856a b + 2016a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           2        2         3  4
+--R                   (7168a b  - 9856a b + 2016a )x
+--R                 + 
+--R                              2         2         3  2
+--R                   (- 16128a b  + 11200a b - 1792a )x
+--R              *
+--R                      +-------------------------------+2 +----------------+
+--R                  +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R                 \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                           2        2        3  4           2       3  2  +-+
+--R                   ((896a b  + 1568a b - 448a )x  + (3584a b  - 224a )x )\|2
+--R                 + 
+--R                             2       3  4             2        2        3  2
+--R                   (- 3584a b  + 224a )x  + (- 1792a b  - 3136a b + 896a )x
+--R              *
+--R                           +-------------------------------+2 +----------------+
+--R                  +-+ +--+4|  4       3     2 2     3     4   |  4     2 2    4
+--R                 \|7 \|14 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                             3          2         2         3  6
+--R                       (7168b  - 5376a b  + 17024a b - 4032a )x
+--R                     + 
+--R                             3          2         2         3  4
+--R                       (7168b  - 5376a b  + 17024a b - 4032a )x
+--R                     + 
+--R                              3           2         2         3  2
+--R                       (14336b  - 10752a b  + 34048a b - 8064a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           3          2        2         3  6
+--R                   (- 3584b  + 2688a b  - 8512a b + 2016a )x
+--R                 + 
+--R                           3          2        2         3  4
+--R                   (- 3584b  + 2688a b  - 8512a b + 2016a )x
+--R                 + 
+--R                           3          2         2         3  2
+--R                   (- 7168b  + 5376a b  - 17024a b + 4032a )x
+--R              *
+--R                      +-------------------------------+2 +----------------+
+--R                  +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R                 \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R          *
+--R                         +----------------+  3
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                               4        2 3      3 2       4       5  6
+--R                       (1152a b  - 1376a b  + 96a b  + 236a b - 48a )x
+--R                     + 
+--R                                 4        2 3       3 2       4        5  4
+--R                       (- 1024a b  + 1920a b  - 608a b  - 384a b + 108a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                             4        2 3       3 2       4        5  6
+--R                   (- 1024a b  + 1920a b  - 608a b  - 384a b + 108a )x
+--R                 + 
+--R                           4        2 3       3 2       4       5  4
+--R                   (2304a b  - 2752a b  + 192a b  + 472a b - 96a )x
+--R              *
+--R                            +----------------+ +---------+ +---------+
+--R                  +-+4+--+2 |  4     2 2    4  |  +-+      |  +-+
+--R                 \|7 \|98  \|4b  - 4a b  + a  \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                                4       2 3       3 2      4       5  6
+--R                       (- 128a b  - 160a b  + 224a b  + 52a b - 24a )x
+--R                     + 
+--R                                4       2 3       3 2      4       5  4
+--R                       (- 512a b  + 256a b  + 224a b  - 16a b - 12a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                          4       2 3       3 2      4       5  6
+--R                   (512a b  - 256a b  - 224a b  + 16a b + 12a )x
+--R                 + 
+--R                          4       2 3       3 2       4       5  4
+--R                   (256a b  + 320a b  - 448a b  - 104a b + 48a )x
+--R              *
+--R                                 +----------------+ +---------+ +---------+
+--R                  +-+ +--+4+--+2 |  4     2 2    4  |  +-+      |  +-+
+--R                 \|7 \|14 \|98  \|4b  - 4a b  + a  \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                  5          4       2 3       3 2       4
+--R                           - 1024b  + 1280a b  + 256a b  - 512a b  + 736a b
+--R                         + 
+--R                                 5
+--R                           - 160a
+--R                      *
+--R                          8
+--R                         x
+--R                     + 
+--R                                  5          4       2 3       3 2       4
+--R                           - 1024b  + 1280a b  + 256a b  - 512a b  + 736a b
+--R                         + 
+--R                                 5
+--R                           - 160a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                  5          4       2 3        3 2        4
+--R                           - 2048b  + 2560a b  + 512a b  - 1024a b  + 1472a b
+--R                         + 
+--R                                 5
+--R                           - 320a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                        5         4       2 3       3 2       4       5  8
+--R                   (512b  - 640a b  - 128a b  + 256a b  - 368a b + 80a )x
+--R                 + 
+--R                        5         4       2 3       3 2       4       5  6
+--R                   (512b  - 640a b  - 128a b  + 256a b  - 368a b + 80a )x
+--R                 + 
+--R                         5          4       2 3       3 2       4        5  4
+--R                   (1024b  - 1280a b  - 256a b  + 512a b  - 736a b + 160a )x
+--R              *
+--R                            +----------------+
+--R                  +-+4+--+2 |  4     2 2    4
+--R                 \|7 \|98  \|4b  - 4a b  + a
+--R          *
+--R                         +----------------+
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R      *
+--R                     +----------------+  3
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                  7          6        2 5       3 4       4 3
+--R                           - 2304b  + 3328a b  - 2752a b  + 768a b  + 864a b
+--R                         + 
+--R                                 5 2       6        7
+--R                           - 960a b  + 544a b - 128a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                            7          6        2 5        3 4       4 3
+--R                       2048b  - 4352a b  + 3840a b  - 1728a b  - 768a b
+--R                     + 
+--R                            5 2       6        7
+--R                       1376a b  - 832a b + 288a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                            7          6        2 5        3 4       4 3
+--R                       2048b  - 4352a b  + 3840a b  - 1728a b  - 768a b
+--R                     + 
+--R                            5 2       6        7
+--R                       1376a b  - 832a b + 288a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                          7          6        2 5        3 4        4 3
+--R                   - 4608b  + 6656a b  - 5504a b  + 1536a b  + 1728a b
+--R                 + 
+--R                          5 2        6        7
+--R                   - 1920a b  + 1088a b - 256a
+--R              *
+--R                        +---------+ +---------+
+--R                 4+--+2 |  +-+      |  +-+
+--R                 \|98  \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                               7         6       2 5       3 4      4 3
+--R                           256b  + 256a b  - 320a b  + 384a b  - 96a b
+--R                         + 
+--R                                 5 2      6       7
+--R                           - 128a b  + 96a b - 64a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                            7         6       2 5       3 4       4 3       5 2
+--R                       1024b  - 768a b  + 512a b  + 192a b  - 384a b  + 160a b
+--R                     + 
+--R                            6       7
+--R                       - 64a b - 32a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              7         6       2 5       3 4       4 3
+--R                       - 1024b  + 768a b  - 512a b  - 192a b  + 384a b
+--R                     + 
+--R                             5 2      6       7
+--R                       - 160a b  + 64a b + 32a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                         7         6       2 5       3 4       4 3       5 2
+--R                   - 512b  - 512a b  + 640a b  - 768a b  + 192a b  + 256a b
+--R                 + 
+--R                         6        7
+--R                   - 192a b + 128a
+--R              *
+--R                             +---------+ +---------+
+--R                  +--+4+--+2 |  +-+      |  +-+
+--R                 \|14 \|98  \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                  6        2 5        3 4        5 2        6
+--R                           7168a b  - 7168a b  + 5376a b  - 2688a b  + 1792a b
+--R                         + 
+--R                                 7
+--R                           - 896a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                  6        2 5        3 4        5 2        6
+--R                           7168a b  - 7168a b  + 5376a b  - 2688a b  + 1792a b
+--R                         + 
+--R                                 7
+--R                           - 896a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                               6         2 5         3 4        5 2        6
+--R                       14336a b  - 14336a b  + 10752a b  - 5376a b  + 3584a b
+--R                     + 
+--R                              7
+--R                       - 1792a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                6        2 5        3 4        5 2       6
+--R                       - 3584a b  + 3584a b  - 2688a b  + 1344a b  - 896a b
+--R                     + 
+--R                           7
+--R                       448a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                6        2 5        3 4        5 2       6
+--R                       - 3584a b  + 3584a b  - 2688a b  + 1344a b  - 896a b
+--R                     + 
+--R                           7
+--R                       448a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                          6        2 5        3 4        5 2        6        7
+--R                 - 7168a b  + 7168a b  - 5376a b  + 2688a b  - 1792a b + 896a
+--R              *
+--R                 4+--+2
+--R                 \|98
+--R          *
+--R                         +----------------+  6
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                                  5          4        2 3        3 2       4
+--R                           - 8064b  + 7616a b  + 5264a b  - 5152a b  - 616a b
+--R                         + 
+--R                               5
+--R                           672a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                5           4        2 3        3 2       4
+--R                           7168b  - 11648a b  - 2240a b  + 8848a b  - 672a b
+--R                         + 
+--R                                  5
+--R                           - 1512a
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              5           4        2 3        3 2       4
+--R                         7168b  - 11648a b  - 2240a b  + 8848a b  - 672a b
+--R                       + 
+--R                                5
+--R                         - 1512a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                               5           4         2 3         3 2        4
+--R                       - 16128b  + 15232a b  + 10528a b  - 10304a b  - 1232a b
+--R                     + 
+--R                            5
+--R                       1344a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-------------------------------+2 +---------+ +---------+
+--R                 4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R                 \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                                 5          4        2 3        3 2       4
+--R                             896b  + 1344a b  - 1680a b  - 1344a b  + 616a b
+--R                           + 
+--R                                 5
+--R                             336a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                           5         4        2 3       3 2       4        5  2
+--R                     (3584b  - 896a b  - 3584a b  + 112a b  + 896a b + 168a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           5         4        2 3       3 2       4        5  4
+--R                   (- 3584b  + 896a b  + 3584a b  - 112a b  - 896a b - 168a )x
+--R                 + 
+--R                         5          4        2 3        3 2        4        5  2
+--R                 (- 1792b  - 2688a b  + 3360a b  + 2688a b  - 1232a b - 672a )x
+--R              *
+--R                     +-------------------------------+2 +---------+ +---------+
+--R                +--+4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R               \|14 \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                               4        2 3         3 2        4         5  6
+--R                       (6272a b  - 3136a b  - 10976a b  + 1568a b + 3920a )x
+--R                     + 
+--R                               4        2 3         3 2        4         5  4
+--R                       (6272a b  - 3136a b  - 10976a b  + 1568a b + 3920a )x
+--R                     + 
+--R                                4        2 3         3 2        4         5  2
+--R                       (12544a b  - 6272a b  - 21952a b  + 3136a b + 7840a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                             4        2 3        3 2       4         5  6
+--R                   (- 3136a b  + 1568a b  + 5488a b  - 784a b - 1960a )x
+--R                 + 
+--R                             4        2 3        3 2       4         5  4
+--R                   (- 3136a b  + 1568a b  + 5488a b  - 784a b - 1960a )x
+--R                 + 
+--R                             4        2 3         3 2        4         5  2
+--R                   (- 6272a b  + 3136a b  + 10976a b  - 1568a b - 3920a )x
+--R              *
+--R                  +-------------------------------+2
+--R                 4|  4       3     2 2     3     4
+--R                 \|4b  - 4a b  + 5a b  - 2a b + a
+--R          *
+--R                         +----------------+  4
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                                7          6         2 5         3 4        4 3
+--R                           1152b  - 1664a b  - 10720a b  + 11040a b  + 2172a b
+--R                         + 
+--R                                  5 2        6        7
+--R                           - 4896a b  + 1450a b - 104a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                  7          6        2 5         3 4        4 3
+--R                           - 1024b  + 2176a b  + 8832a b  - 16608a b  + 1728a b
+--R                         + 
+--R                                5 2        6        7
+--R                           7292a b  - 2944a b + 234a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              7          6        2 5         3 4        4 3
+--R                       - 1024b  + 2176a b  + 8832a b  - 16608a b  + 1728a b
+--R                     + 
+--R                            5 2        6        7
+--R                       7292a b  - 2944a b + 234a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                            7          6         2 5         3 4        4 3
+--R                       2304b  - 3328a b  - 21440a b  + 22080a b  + 4344a b
+--R                     + 
+--R                              5 2        6        7
+--R                       - 9792a b  + 2900a b - 208a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                        +---------+ +---------+
+--R                 4+--+2 |  +-+      |  +-+
+--R                 \|98  \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                                 7         6        2 5        3 4        4 3
+--R                           - 128b  - 128a b  + 1504a b  + 1824a b  - 1884a b
+--R                         + 
+--R                                 5 2       6       7
+--R                           - 776a b  + 582a b - 52a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                 7         6        2 5        3 4        4 3
+--R                           - 512b  + 384a b  + 5120a b  - 1440a b  - 2832a b
+--R                         + 
+--R                               5 2       6       7
+--R                           676a b  + 200a b - 26a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           7         6        2 5        3 4        4 3
+--R                       512b  - 384a b  - 5120a b  + 1440a b  + 2832a b
+--R                     + 
+--R                             5 2       6       7
+--R                       - 676a b  - 200a b + 26a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                           7         6        2 5        3 4        4 3
+--R                       256b  + 256a b  - 3008a b  - 3648a b  + 3768a b
+--R                     + 
+--R                            5 2        6        7
+--R                       1552a b  - 1164a b + 104a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                             +---------+ +---------+
+--R                  +--+4+--+2 |  +-+      |  +-+
+--R                 \|14 \|98  \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                   6         2 5        3 4        4 3
+--R                           19712a b  - 19712a b  + 5376a b  + 4704a b
+--R                         + 
+--R                                  5 2        6        7
+--R                           - 7392a b  + 2576a b - 112a
+--R                      *
+--R                          8
+--R                         x
+--R                     + 
+--R                                   6         2 5        3 4        4 3
+--R                           19712a b  - 19712a b  + 5376a b  + 4704a b
+--R                         + 
+--R                                  5 2        6        7
+--R                           - 7392a b  + 2576a b - 112a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                   6         2 5         3 4        4 3
+--R                           39424a b  - 39424a b  + 10752a b  + 9408a b
+--R                         + 
+--R                                   5 2        6        7
+--R                           - 14784a b  + 5152a b - 224a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                6        2 5        3 4        4 3        5 2
+--R                       - 9856a b  + 9856a b  - 2688a b  - 2352a b  + 3696a b
+--R                     + 
+--R                              6       7
+--R                       - 1288a b + 56a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                6        2 5        3 4        4 3        5 2
+--R                       - 9856a b  + 9856a b  - 2688a b  - 2352a b  + 3696a b
+--R                     + 
+--R                              6       7
+--R                       - 1288a b + 56a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                 6         2 5        3 4        4 3        5 2
+--R                       - 19712a b  + 19712a b  - 5376a b  - 4704a b  + 7392a b
+--R                     + 
+--R                              6        7
+--R                       - 2576a b + 112a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                 4+--+2
+--R                 \|98
+--R          *
+--R                         +----------------+  2
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                         5          4        2 3        3 2       4        5  8
+--R                   (4032b  - 3808a b  - 2632a b  + 2576a b  + 308a b - 336a )x
+--R                 + 
+--R                         5          4        2 3        3 2       4        5  6
+--R                 (- 3584b  + 5824a b  + 1120a b  - 4424a b  + 336a b + 756a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       5          4        2 3        3 2       4        5  8
+--R               (- 3584b  + 5824a b  + 1120a b  - 4424a b  + 336a b + 756a )x
+--R             + 
+--R                     5          4        2 3        3 2       4        5  6
+--R               (8064b  - 7616a b  - 5264a b  + 5152a b  + 616a b - 672a )x
+--R          *
+--R              +-------------------------------+2 +---------+ +---------+
+--R             4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R             \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                          5         4       2 3       3 2       4        5  8
+--R                   (- 448b  - 672a b  + 840a b  + 672a b  - 308a b - 168a )x
+--R                 + 
+--R                           5         4        2 3      3 2       4       5  6
+--R                   (- 1792b  + 448a b  + 1792a b  - 56a b  - 448a b - 84a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                     5         4        2 3      3 2       4       5  8
+--R               (1792b  - 448a b  - 1792a b  + 56a b  + 448a b + 84a )x
+--R             + 
+--R                    5          4        2 3        3 2       4        5  6
+--R               (896b  + 1344a b  - 1680a b  - 1344a b  + 616a b + 336a )x
+--R          *
+--R                   +-------------------------------+2 +---------+ +---------+
+--R              +--+4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R             \|14 \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                           4        2 3       4        5  10
+--R                   (3136a b  - 1568a b  + 784a b - 784a )x
+--R                 + 
+--R                           4        2 3       4        5  8
+--R                   (3136a b  - 1568a b  + 784a b - 784a )x
+--R                 + 
+--R                           4        2 3        4         5  6
+--R                   (6272a b  - 3136a b  + 1568a b - 1568a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         4       2 3       4        5  10
+--R               (- 1568a b  + 784a b  - 392a b + 392a )x
+--R             + 
+--R                         4       2 3       4        5  8
+--R               (- 1568a b  + 784a b  - 392a b + 392a )x
+--R             + 
+--R                         4        2 3       4        5  6
+--R               (- 3136a b  + 1568a b  - 784a b + 784a )x
+--R          *
+--R              +-------------------------------+2
+--R             4|  4       3     2 2     3     4
+--R             \|4b  - 4a b  + 5a b  - 2a b + a
+--R      *
+--R                     +----------------+  2
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                 2        2        3  4
+--R                       (- 4032a b  + 2800a b - 448a )x
+--R                     + 
+--R                               2        2         3  2
+--R                       (3584a b  - 4928a b + 1008a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           2        2         3  4
+--R                   (3584a b  - 4928a b + 1008a )x
+--R                 + 
+--R                             2        2        3  2
+--R                   (- 8064a b  + 5600a b - 896a )x
+--R              *
+--R                      +-------------------------------+2 +----------------+
+--R                  +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R                 \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                           2       2        3  4           2       3  2  +-+
+--R                   ((448a b  + 784a b - 224a )x  + (1792a b  - 112a )x )\|2
+--R                 + 
+--R                             2       3  4            2        2        3  2
+--R                   (- 1792a b  + 112a )x  + (- 896a b  - 1568a b + 448a )x
+--R              *
+--R                           +-------------------------------+2 +----------------+
+--R                  +-+ +--+4|  4       3     2 2     3     4   |  4     2 2    4
+--R                 \|7 \|14 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                             3          2        2         3  6
+--R                       (3584b  - 2688a b  + 8512a b - 2016a )x
+--R                     + 
+--R                             3          2        2         3  4
+--R                       (3584b  - 2688a b  + 8512a b - 2016a )x
+--R                     + 
+--R                             3          2         2         3  2
+--R                       (7168b  - 5376a b  + 17024a b - 4032a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           3          2        2         3  6
+--R                   (- 1792b  + 1344a b  - 4256a b + 1008a )x
+--R                 + 
+--R                           3          2        2         3  4
+--R                   (- 1792b  + 1344a b  - 4256a b + 1008a )x
+--R                 + 
+--R                           3          2        2         3  2
+--R                   (- 3584b  + 2688a b  - 8512a b + 2016a )x
+--R              *
+--R                      +-------------------------------+2 +----------------+
+--R                  +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R                 \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R          *
+--R                         +----------------+  5
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                                 4        2 3      3 2       4       5  6
+--R                       (- 1152a b  + 1376a b  - 96a b  - 236a b + 48a )x
+--R                     + 
+--R                               4        2 3       3 2       4        5  4
+--R                       (1024a b  - 1920a b  + 608a b  + 384a b - 108a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           4        2 3       3 2       4        5  6
+--R                   (1024a b  - 1920a b  + 608a b  + 384a b - 108a )x
+--R                 + 
+--R                             4        2 3       3 2       4       5  4
+--R                   (- 2304a b  + 2752a b  - 192a b  - 472a b + 96a )x
+--R              *
+--R                            +----------------+ +---------+ +---------+
+--R                  +-+4+--+2 |  4     2 2    4  |  +-+      |  +-+
+--R                 \|7 \|98  \|4b  - 4a b  + a  \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                              4       2 3       3 2      4       5  6
+--R                       (128a b  + 160a b  - 224a b  - 52a b + 24a )x
+--R                     + 
+--R                              4       2 3       3 2      4       5  4
+--R                       (512a b  - 256a b  - 224a b  + 16a b + 12a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                            4       2 3       3 2      4       5  6
+--R                   (- 512a b  + 256a b  + 224a b  - 16a b - 12a )x
+--R                 + 
+--R                            4       2 3       3 2       4       5  4
+--R                   (- 256a b  - 320a b  + 448a b  + 104a b - 48a )x
+--R              *
+--R                                 +----------------+ +---------+ +---------+
+--R                  +-+ +--+4+--+2 |  4     2 2    4  |  +-+      |  +-+
+--R                 \|7 \|14 \|98  \|4b  - 4a b  + a  \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                  5          4       2 3       3 2       4
+--R                             1024b  - 1280a b  - 256a b  + 512a b  - 736a b
+--R                           + 
+--R                                 5
+--R                             160a
+--R                      *
+--R                          8
+--R                         x
+--R                     + 
+--R                                  5          4       2 3       3 2       4
+--R                             1024b  - 1280a b  - 256a b  + 512a b  - 736a b
+--R                           + 
+--R                                 5
+--R                             160a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                5          4       2 3        3 2        4
+--R                           2048b  - 2560a b  - 512a b  + 1024a b  - 1472a b
+--R                         + 
+--R                               5
+--R                           320a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                          5         4       2 3       3 2       4       5  8
+--R                   (- 512b  + 640a b  + 128a b  - 256a b  + 368a b - 80a )x
+--R                 + 
+--R                          5         4       2 3       3 2       4       5  6
+--R                   (- 512b  + 640a b  + 128a b  - 256a b  + 368a b - 80a )x
+--R                 + 
+--R                           5          4       2 3       3 2       4        5  4
+--R                   (- 1024b  + 1280a b  + 256a b  - 512a b  + 736a b - 160a )x
+--R              *
+--R                            +----------------+
+--R                  +-+4+--+2 |  4     2 2    4
+--R                 \|7 \|98  \|4b  - 4a b  + a
+--R          *
+--R                         +----------------+  3
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                                 2        2        3  8
+--R                       (- 2016a b  + 1400a b - 224a )x
+--R                     + 
+--R                               2        2        3  6
+--R                       (1792a b  - 2464a b + 504a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           2        2        3  8
+--R                   (1792a b  - 2464a b + 504a )x
+--R                 + 
+--R                             2        2        3  6
+--R                   (- 4032a b  + 2800a b - 448a )x
+--R              *
+--R                      +-------------------------------+2 +----------------+
+--R                  +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R                 \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                           2       2        3  8          2      3  6  +-+
+--R                   ((224a b  + 392a b - 112a )x  + (896a b  - 56a )x )\|2
+--R                 + 
+--R                            2      3  8            2       2        3  6
+--R                   (- 896a b  + 56a )x  + (- 448a b  - 784a b + 224a )x
+--R              *
+--R                           +-------------------------------+2 +----------------+
+--R                  +-+ +--+4|  4       3     2 2     3     4   |  4     2 2    4
+--R                 \|7 \|14 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                             3          2        2        3  10
+--R                       (1792b  - 1344a b  + 1120a b - 224a )x
+--R                     + 
+--R                             3          2        2        3  8
+--R                       (1792b  - 1344a b  + 1120a b - 224a )x
+--R                     + 
+--R                             3          2        2        3  6
+--R                       (3584b  - 2688a b  + 2240a b - 448a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                          3         2       2        3  10
+--R                   (- 896b  + 672a b  - 560a b + 112a )x
+--R                 + 
+--R                          3         2       2        3  8
+--R                   (- 896b  + 672a b  - 560a b + 112a )x
+--R                 + 
+--R                           3          2        2        3  6
+--R                   (- 1792b  + 1344a b  - 1120a b + 224a )x
+--R              *
+--R                      +-------------------------------+2 +----------------+
+--R                  +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R                 \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R          *
+--R                         +----------------+
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R      *
+--R                     +----------------+
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                             7         6       2 5       3 4       4 3       5 2
+--R                       - 576b  + 832a b  - 688a b  + 192a b  + 216a b  - 240a b
+--R                     + 
+--R                           6       7
+--R                       136a b - 32a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                       7          6       2 5       3 4       4 3       5 2
+--R                   512b  - 1088a b  + 960a b  - 432a b  - 192a b  + 344a b
+--R                 + 
+--R                         6       7
+--R                   - 208a b + 72a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       7          6       2 5       3 4       4 3       5 2
+--R                   512b  - 1088a b  + 960a b  - 432a b  - 192a b  + 344a b
+--R                 + 
+--R                         6       7
+--R                   - 208a b + 72a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                      7          6        2 5       3 4       4 3       5 2
+--R               - 1152b  + 1664a b  - 1376a b  + 384a b  + 432a b  - 480a b
+--R             + 
+--R                   6       7
+--R               272a b - 64a
+--R          *
+--R                    +---------+ +---------+
+--R             4+--+2 |  +-+      |  +-+
+--R             \|98  \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                          7        6      2 5      3 4      4 3      5 2      6
+--R                       64b  + 64a b  - 80a b  + 96a b  - 24a b  - 32a b  + 24a b
+--R                     + 
+--R                            7
+--R                       - 16a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                       7         6       2 5      3 4      4 3      5 2      6
+--R                   256b  - 192a b  + 128a b  + 48a b  - 96a b  + 40a b  - 16a b
+--R                 + 
+--R                       7
+--R                   - 8a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         7         6       2 5      3 4      4 3      5 2
+--R                   - 256b  + 192a b  - 128a b  - 48a b  + 96a b  - 40a b
+--R                 + 
+--R                      6      7
+--R                   16a b + 8a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                     7         6       2 5       3 4      4 3      5 2      6
+--R               - 128b  - 128a b  + 160a b  - 192a b  + 48a b  + 64a b  - 48a b
+--R             + 
+--R                  7
+--R               32a
+--R          *
+--R                         +---------+ +---------+
+--R              +--+4+--+2 |  +-+      |  +-+
+--R             \|14 \|98  \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                           6        2 5        3 4       5 2       6        7  4
+--R                   (1792a b  - 1792a b  + 1344a b  - 672a b  + 448a b - 224a )x
+--R                 + 
+--R                           6        2 5        3 4       5 2       6        7  2
+--R                   (1792a b  - 1792a b  + 1344a b  - 672a b  + 448a b - 224a )x
+--R                 + 
+--R                          6        2 5        3 4        5 2       6        7
+--R                   3584a b  - 3584a b  + 2688a b  - 1344a b  + 896a b - 448a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                        6       2 5       3 4       5 2       6        7  4
+--R               (- 896a b  + 896a b  - 672a b  + 336a b  - 224a b + 112a )x
+--R             + 
+--R                        6       2 5       3 4       5 2       6        7  2
+--R               (- 896a b  + 896a b  - 672a b  + 336a b  - 224a b + 112a )x
+--R             + 
+--R                        6        2 5        3 4       5 2       6        7
+--R               - 1792a b  + 1792a b  - 1344a b  + 672a b  - 448a b + 224a
+--R          *
+--R             4+--+2
+--R             \|98
+--R      *
+--R                     +----------------+  8
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         cos(---------------------------)
+--R                          2
+--R     + 
+--R                                5          4        2 3        3 2       4
+--R                         - 8064b  + 7616a b  + 5264a b  - 5152a b  - 616a b
+--R                       + 
+--R                             5
+--R                         672a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                       5           4        2 3        3 2       4         5  2
+--R                 (7168b  - 11648a b  - 2240a b  + 8848a b  - 672a b - 1512a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                     5           4        2 3        3 2       4         5  4
+--R               (7168b  - 11648a b  - 2240a b  + 8848a b  - 672a b - 1512a )x
+--R             + 
+--R                           5           4         2 3         3 2        4
+--R                   - 16128b  + 15232a b  + 10528a b  - 10304a b  - 1232a b
+--R                 + 
+--R                        5
+--R                   1344a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R              +-------------------------------+2 +---------+ +---------+
+--R             4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R             \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                        5          4        2 3        3 2       4        5  4
+--R                   (896b  + 1344a b  - 1680a b  - 1344a b  + 616a b + 336a )x
+--R                 + 
+--R                         5         4        2 3       3 2       4        5  2
+--R                   (3584b  - 896a b  - 3584a b  + 112a b  + 896a b + 168a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       5         4        2 3       3 2       4        5  4
+--R               (- 3584b  + 896a b  + 3584a b  - 112a b  - 896a b - 168a )x
+--R             + 
+--R                       5          4        2 3        3 2        4        5  2
+--R               (- 1792b  - 2688a b  + 3360a b  + 2688a b  - 1232a b - 672a )x
+--R          *
+--R                   +-------------------------------+2 +---------+ +---------+
+--R              +--+4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R             \|14 \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                           4        2 3         3 2        4         5  6
+--R                   (6272a b  - 3136a b  - 10976a b  + 1568a b + 3920a )x
+--R                 + 
+--R                           4        2 3         3 2        4         5  4
+--R                   (6272a b  - 3136a b  - 10976a b  + 1568a b + 3920a )x
+--R                 + 
+--R                            4        2 3         3 2        4         5  2
+--R                   (12544a b  - 6272a b  - 21952a b  + 3136a b + 7840a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         4        2 3        3 2       4         5  6
+--R               (- 3136a b  + 1568a b  + 5488a b  - 784a b - 1960a )x
+--R             + 
+--R                         4        2 3        3 2       4         5  4
+--R               (- 3136a b  + 1568a b  + 5488a b  - 784a b - 1960a )x
+--R             + 
+--R                         4        2 3         3 2        4         5  2
+--R               (- 6272a b  + 3136a b  + 10976a b  - 1568a b - 3920a )x
+--R          *
+--R              +-------------------------------+2
+--R             4|  4       3     2 2     3     4
+--R             \|4b  - 4a b  + 5a b  - 2a b + a
+--R      *
+--R                     +----------------+  6
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         cos(---------------------------)
+--R                          2
+--R     + 
+--R                              7          6      2 5        3 4       4 3
+--R                       - 1728b  + 2496a b  - 48a b  - 1328a b  + 214a b
+--R                     + 
+--R                           5 2       6       7
+--R                       176a b  + 121a b - 68a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                            7          6        2 5        3 4       4 3
+--R                       1536b  - 3264a b  + 1088a b  + 1616a b  - 800a b
+--R                     + 
+--R                             5 2      6        7
+--R                       - 298a b  - 64a b + 153a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                        7          6        2 5        3 4       4 3       5 2
+--R                   1536b  - 3264a b  + 1088a b  + 1616a b  - 800a b  - 298a b
+--R                 + 
+--R                        6        7
+--R                   - 64a b + 153a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          7          6      2 5        3 4       4 3       5 2
+--R                   - 3456b  + 4992a b  - 96a b  - 2656a b  + 428a b  + 352a b
+--R                 + 
+--R                       6        7
+--R                   242a b - 136a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                    +---------+ +---------+
+--R             4+--+2 |  +-+      |  +-+
+--R             \|98  \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                           7         6       2 5      3 4       4 3      5 2
+--R                       192b  + 192a b  - 464a b  - 48a b  + 250a b  + 44a b
+--R                     + 
+--R                            6       7
+--R                       - 33a b - 34a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                           7         6       2 5       3 4       4 3     5 2
+--R                       768b  - 576a b  - 512a b  + 368a b  + 216a b  - 6a b
+--R                     + 
+--R                            6       7
+--R                       - 76a b - 17a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         7         6       2 5       3 4       4 3     5 2
+--R                   - 768b  + 576a b  + 512a b  - 368a b  - 216a b  + 6a b
+--R                 + 
+--R                      6       7
+--R                   76a b + 17a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         7         6       2 5      3 4       4 3      5 2
+--R                   - 384b  - 384a b  + 928a b  + 96a b  - 500a b  - 88a b
+--R                 + 
+--R                      6       7
+--R                   66a b + 68a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                         +---------+ +---------+
+--R              +--+4+--+2 |  +-+      |  +-+
+--R             \|14 \|98  \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                               6       2 5       3 4       4 3       5 2
+--R                       - 896a b  + 896a b  + 896a b  - 784a b  + 336a b
+--R                     + 
+--R                           6        7
+--R                       168a b - 280a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                               6       2 5       3 4       4 3       5 2
+--R                       - 896a b  + 896a b  + 896a b  - 784a b  + 336a b
+--R                     + 
+--R                           6        7
+--R                       168a b - 280a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                6        2 5        3 4        4 3       5 2
+--R                       - 1792a b  + 1792a b  + 1792a b  - 1568a b  + 672a b
+--R                     + 
+--R                           6        7
+--R                       336a b - 560a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           6       2 5       3 4       4 3       5 2      6
+--R                     448a b  - 448a b  - 448a b  + 392a b  - 168a b  - 84a b
+--R                   + 
+--R                         7
+--R                     140a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           6       2 5       3 4       4 3       5 2      6
+--R                     448a b  - 448a b  - 448a b  + 392a b  - 168a b  - 84a b
+--R                   + 
+--R                         7
+--R                     140a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         6       2 5       3 4       4 3       5 2       6
+--R                   896a b  - 896a b  - 896a b  + 784a b  - 336a b  - 168a b
+--R                 + 
+--R                       7
+--R                   280a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R             4+--+2
+--R             \|98
+--R      *
+--R                     +----------------+  4
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         cos(---------------------------)
+--R                          2
+--R     + 
+--R                                5          4        2 3        3 2       4
+--R                         - 4032b  + 3808a b  + 2632a b  - 2576a b  - 308a b
+--R                       + 
+--R                             5
+--R                         336a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                         5          4        2 3        3 2       4        5  6
+--R                   (3584b  - 5824a b  - 1120a b  + 4424a b  - 336a b - 756a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                     5          4        2 3        3 2       4        5  8
+--R               (3584b  - 5824a b  - 1120a b  + 4424a b  - 336a b - 756a )x
+--R             + 
+--R                       5          4        2 3        3 2       4        5  6
+--R               (- 8064b  + 7616a b  + 5264a b  - 5152a b  - 616a b + 672a )x
+--R          *
+--R              +-------------------------------+2 +---------+ +---------+
+--R             4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R             \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                        5         4       2 3       3 2       4        5  8
+--R                   (448b  + 672a b  - 840a b  - 672a b  + 308a b + 168a )x
+--R                 + 
+--R                         5         4        2 3      3 2       4       5  6
+--R                   (1792b  - 448a b  - 1792a b  + 56a b  + 448a b + 84a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       5         4        2 3      3 2       4       5  8
+--R               (- 1792b  + 448a b  + 1792a b  - 56a b  - 448a b - 84a )x
+--R             + 
+--R                      5          4        2 3        3 2       4        5  6
+--R               (- 896b  - 1344a b  + 1680a b  + 1344a b  - 616a b - 336a )x
+--R          *
+--R                   +-------------------------------+2 +---------+ +---------+
+--R              +--+4|  4       3     2 2     3     4   |  +-+      |  +-+
+--R             \|14 \|4b  - 4a b  + 5a b  - 2a b + a   \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                             4        2 3       4        5  10
+--R                   (- 3136a b  + 1568a b  - 784a b + 784a )x
+--R                 + 
+--R                             4        2 3       4        5  8
+--R                   (- 3136a b  + 1568a b  - 784a b + 784a )x
+--R                 + 
+--R                             4        2 3        4         5  6
+--R                   (- 6272a b  + 3136a b  - 1568a b + 1568a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       4       2 3       4        5  10
+--R               (1568a b  - 784a b  + 392a b - 392a )x
+--R             + 
+--R                       4       2 3       4        5  8
+--R               (1568a b  - 784a b  + 392a b - 392a )x
+--R             + 
+--R                       4        2 3       4        5  6
+--R               (3136a b  - 1568a b  + 784a b - 784a )x
+--R          *
+--R              +-------------------------------+2
+--R             4|  4       3     2 2     3     4
+--R             \|4b  - 4a b  + 5a b  - 2a b + a
+--R      *
+--R                     +----------------+  2
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         cos(---------------------------)
+--R                          2
+--R     + 
+--R                         7         6       2 5      3 4      4 3      5 2
+--R                   - 144b  + 208a b  - 172a b  + 48a b  + 54a b  - 60a b
+--R                 + 
+--R                      6      7
+--R                   34a b - 8a
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                       7         6       2 5       3 4      4 3      5 2      6
+--R                   128b  - 272a b  + 240a b  - 108a b  - 48a b  + 86a b  - 52a b
+--R                 + 
+--R                      7
+--R                   18a
+--R              *
+--R                  8
+--R                 x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                   7         6       2 5       3 4      4 3      5 2      6
+--R               128b  - 272a b  + 240a b  - 108a b  - 48a b  + 86a b  - 52a b
+--R             + 
+--R                  7
+--R               18a
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                     7         6       2 5      3 4       4 3       5 2      6
+--R               - 288b  + 416a b  - 344a b  + 96a b  + 108a b  - 120a b  + 68a b
+--R             + 
+--R                    7
+--R               - 16a
+--R          *
+--R              8
+--R             x
+--R      *
+--R                +---------+ +---------+
+--R         4+--+2 |  +-+      |  +-+
+--R         \|98  \|2\|2  + 1 \|4\|2  + 2
+--R     + 
+--R                   7        6      2 5      3 4     4 3     5 2     6      7  10
+--R               (16b  + 16a b  - 20a b  + 24a b  - 6a b  - 8a b  + 6a b - 4a )x
+--R             + 
+--R                 7        6      2 5      3 4      4 3      5 2     6      7  8
+--R             (64b  - 48a b  + 32a b  + 12a b  - 24a b  + 10a b  - 4a b - 2a )x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                 7        6      2 5      3 4      4 3      5 2     6      7  10
+--R           (- 64b  + 48a b  - 32a b  - 12a b  + 24a b  - 10a b  + 4a b + 2a )x
+--R         + 
+--R               7        6      2 5      3 4      4 3      5 2      6      7  8
+--R         (- 32b  - 32a b  + 40a b  - 48a b  + 12a b  + 16a b  - 12a b + 8a )x
+--R      *
+--R                     +---------+ +---------+
+--R          +--+4+--+2 |  +-+      |  +-+
+--R         \|14 \|98  \|2\|2  - 1 \|2\|2  + 1
+--R  /
+--R                     6          5        2 4        4 2       5        6  4
+--R               (3584b  - 3584a b  + 2688a b  - 1344a b  + 896a b - 448a )x
+--R             + 
+--R                     6          5        2 4        4 2       5        6  2
+--R               (3584b  - 3584a b  + 2688a b  - 1344a b  + 896a b - 448a )x
+--R             + 
+--R                    6          5        2 4        4 2        5        6
+--R               7168b  - 7168a b  + 5376a b  - 2688a b  + 1792a b - 896a
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                   6          5        2 4       4 2       5        6  4
+--R           (- 1792b  + 1792a b  - 1344a b  + 672a b  - 448a b + 224a )x
+--R         + 
+--R                   6          5        2 4       4 2       5        6  2
+--R           (- 1792b  + 1792a b  - 1344a b  + 672a b  - 448a b + 224a )x
+--R         + 
+--R                  6          5        2 4        4 2       5        6
+--R           - 3584b  + 3584a b  - 2688a b  + 1344a b  - 896a b + 448a
+--R      *
+--R                           +----------------+  8
+--R                           |  4     2 2    4
+--R                         7\|4b  - 4a b  + a
+--R                   atan(---------------------)
+--R                           2           2  +-+
+--R         4+--+2         (2b  - 8a b + a )\|7
+--R         \|98  sin(---------------------------)
+--R                                2
+--R     + 
+--R                             6           5         2 4        4 2        5
+--R                       14336b  - 14336a b  + 10752a b  - 5376a b  + 3584a b
+--R                     + 
+--R                              6
+--R                       - 1792a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                             6           5         2 4        4 2        5
+--R                       14336b  - 14336a b  + 10752a b  - 5376a b  + 3584a b
+--R                     + 
+--R                              6
+--R                       - 1792a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                       6           5         2 4         4 2        5         6
+--R                 28672b  - 28672a b  + 21504a b  - 10752a b  + 7168a b - 3584a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       6          5        2 4        4 2        5        6  4
+--R               (- 7168b  + 7168a b  - 5376a b  + 2688a b  - 1792a b + 896a )x
+--R             + 
+--R                       6          5        2 4        4 2        5        6  2
+--R               (- 7168b  + 7168a b  - 5376a b  + 2688a b  - 1792a b + 896a )x
+--R             + 
+--R                       6           5         2 4        4 2        5         6
+--R               - 14336b  + 14336a b  - 10752a b  + 5376a b  - 3584a b + 1792a
+--R          *
+--R                               +----------------+  2
+--R                               |  4     2 2    4
+--R                             7\|4b  - 4a b  + a
+--R                       atan(---------------------)
+--R                               2           2  +-+
+--R             4+--+2         (2b  - 8a b + a )\|7
+--R             \|98  cos(---------------------------)
+--R                                    2
+--R         + 
+--R                            4           3         2 2         3         4  6
+--R                   (- 50176b  + 25088a b  + 43904a b  - 12544a b - 9408a )x
+--R                 + 
+--R                            4           3         2 2         3         4  4
+--R                   (- 50176b  + 25088a b  + 43904a b  - 12544a b - 9408a )x
+--R                 + 
+--R                             4           3         2 2         3          4  2
+--R                   (- 100352b  + 50176a b  + 87808a b  - 25088a b - 18816a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                      4           3         2 2        3         4  6
+--R               (25088b  - 12544a b  - 21952a b  + 6272a b + 4704a )x
+--R             + 
+--R                      4           3         2 2        3         4  4
+--R               (25088b  - 12544a b  - 21952a b  + 6272a b + 4704a )x
+--R             + 
+--R                      4           3         2 2         3         4  2
+--R               (50176b  - 25088a b  - 43904a b  + 12544a b + 9408a )x
+--R          *
+--R              +-------------------------------+2
+--R             4|  4       3     2 2     3     4
+--R             \|4b  - 4a b  + 5a b  - 2a b + a
+--R      *
+--R                     +----------------+  6
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                2  6                    2  4
+--R               (25088a b - 6272a )x  + (25088a b - 6272a )x
+--R             + 
+--R                                 2  2
+--R               (50176a b - 12544a )x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                              2  6                      2  4
+--R           (- 12544a b + 3136a )x  + (- 12544a b + 3136a )x
+--R         + 
+--R                              2  2
+--R           (- 25088a b + 6272a )x
+--R      *
+--R              +-------------------------------+2 +----------------+
+--R          +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R         \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R      *
+--R                     +----------------+              +----------------+  5
+--R                     |  4     2 2    4               |  4     2 2    4
+--R                   7\|4b  - 4a b  + a              7\|4b  - 4a b  + a
+--R             atan(---------------------)     atan(---------------------)
+--R                     2           2  +-+              2           2  +-+
+--R                  (2b  - 8a b + a )\|7            (2b  - 8a b + a )\|7
+--R         cos(---------------------------)sin(---------------------------)
+--R                          2                               2
+--R     + 
+--R                             6           5         2 4        4 2        5
+--R                       21504b  - 21504a b  + 16128a b  - 8064a b  + 5376a b
+--R                     + 
+--R                              6
+--R                       - 2688a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                             6           5         2 4        4 2        5
+--R                       21504b  - 21504a b  + 16128a b  - 8064a b  + 5376a b
+--R                     + 
+--R                              6
+--R                       - 2688a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                       6           5         2 4         4 2         5         6
+--R                 43008b  - 43008a b  + 32256a b  - 16128a b  + 10752a b - 5376a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                             6           5        2 4        4 2        5
+--R                     - 10752b  + 10752a b  - 8064a b  + 4032a b  - 2688a b
+--R                   + 
+--R                          6
+--R                     1344a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             6           5        2 4        4 2        5
+--R                     - 10752b  + 10752a b  - 8064a b  + 4032a b  - 2688a b
+--R                   + 
+--R                          6
+--R                     1344a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                       6           5         2 4        4 2        5         6
+--R               - 21504b  + 21504a b  - 16128a b  + 8064a b  - 5376a b + 2688a
+--R          *
+--R                               +----------------+  4
+--R                               |  4     2 2    4
+--R                             7\|4b  - 4a b  + a
+--R                       atan(---------------------)
+--R                               2           2  +-+
+--R             4+--+2         (2b  - 8a b + a )\|7
+--R             \|98  cos(---------------------------)
+--R                                    2
+--R         + 
+--R                            4           3         2 2         3         4  6
+--R                   (- 50176b  + 25088a b  + 43904a b  - 12544a b - 9408a )x
+--R                 + 
+--R                            4           3         2 2         3         4  4
+--R                   (- 50176b  + 25088a b  + 43904a b  - 12544a b - 9408a )x
+--R                 + 
+--R                             4           3         2 2         3          4  2
+--R                   (- 100352b  + 50176a b  + 87808a b  - 25088a b - 18816a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                      4           3         2 2        3         4  6
+--R               (25088b  - 12544a b  - 21952a b  + 6272a b + 4704a )x
+--R             + 
+--R                      4           3         2 2        3         4  4
+--R               (25088b  - 12544a b  - 21952a b  + 6272a b + 4704a )x
+--R             + 
+--R                      4           3         2 2         3         4  2
+--R               (50176b  - 25088a b  - 43904a b  + 12544a b + 9408a )x
+--R          *
+--R                                                          +----------------+  2
+--R                                                          |  4     2 2    4
+--R                                                        7\|4b  - 4a b  + a
+--R                                                  atan(---------------------)
+--R            +-------------------------------+2            2           2  +-+
+--R           4|  4       3     2 2     3     4           (2b  - 8a b + a )\|7
+--R           \|4b  - 4a b  + 5a b  - 2a b + a   cos(---------------------------)
+--R                                                               2
+--R         + 
+--R                             6           5        2 4        3 3        4 2
+--R                       10752b  - 10752a b  - 4480a b  + 6272a b  + 1456a b
+--R                     + 
+--R                             5        6
+--R                       - 448a b - 952a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                             6           5        2 4        3 3        4 2
+--R                       10752b  - 10752a b  - 4480a b  + 6272a b  + 1456a b
+--R                     + 
+--R                             5        6
+--R                       - 448a b - 952a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                             6           5        2 4         3 3        4 2
+--R                       21504b  - 21504a b  - 8960a b  + 12544a b  + 2912a b
+--R                     + 
+--R                             5         6
+--R                       - 896a b - 1904a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                          6          5        2 4        3 3       4 2       5
+--R                   - 5376b  + 5376a b  + 2240a b  - 3136a b  - 728a b  + 224a b
+--R                 + 
+--R                       6
+--R                   476a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          6          5        2 4        3 3       4 2       5
+--R                   - 5376b  + 5376a b  + 2240a b  - 3136a b  - 728a b  + 224a b
+--R                 + 
+--R                       6
+--R                   476a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                           6           5        2 4        3 3        4 2
+--R                   - 10752b  + 10752a b  + 4480a b  - 6272a b  - 1456a b
+--R                 + 
+--R                       5        6
+--R                   448a b + 952a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R             4+--+2
+--R             \|98
+--R      *
+--R                     +----------------+  4
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                     2  6                     2  4
+--R                   (50176a b - 12544a )x  + (50176a b - 12544a )x
+--R                 + 
+--R                                      2  2
+--R                   (100352a b - 25088a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                                  2  6                      2  4
+--R               (- 25088a b + 6272a )x  + (- 25088a b + 6272a )x
+--R             + 
+--R                                   2  2
+--R               (- 50176a b + 12544a )x
+--R          *
+--R                  +-------------------------------+2 +----------------+
+--R              +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R             \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R          *
+--R                         +----------------+  3
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                             3        2 2        3        4  8
+--R                   (- 7168a b  + 5376a b  + 1792a b - 672a )x
+--R                 + 
+--R                             3        2 2        3        4  6
+--R                   (- 7168a b  + 5376a b  + 1792a b - 672a )x
+--R                 + 
+--R                              3         2 2        3         4  4
+--R                   (- 14336a b  + 10752a b  + 3584a b - 1344a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       3        2 2       3        4  8
+--R               (3584a b  - 2688a b  - 896a b + 336a )x
+--R             + 
+--R                       3        2 2       3        4  6
+--R               (3584a b  - 2688a b  - 896a b + 336a )x
+--R             + 
+--R                       3        2 2        3        4  4
+--R               (7168a b  - 5376a b  - 1792a b + 672a )x
+--R          *
+--R                                                      +----------------+
+--R                                                      |  4     2 2    4
+--R                                                    7\|4b  - 4a b  + a
+--R                                              atan(---------------------)
+--R                        +----------------+            2           2  +-+
+--R              +-+4+--+2 |  4     2 2    4          (2b  - 8a b + a )\|7
+--R             \|7 \|98  \|4b  - 4a b  + a  cos(---------------------------)
+--R                                                           2
+--R      *
+--R                     +----------------+  3
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                             6           5         2 4        4 2        5
+--R                       14336b  - 14336a b  + 10752a b  - 5376a b  + 3584a b
+--R                     + 
+--R                              6
+--R                       - 1792a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                             6           5         2 4        4 2        5
+--R                       14336b  - 14336a b  + 10752a b  - 5376a b  + 3584a b
+--R                     + 
+--R                              6
+--R                       - 1792a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                       6           5         2 4         4 2        5         6
+--R                 28672b  - 28672a b  + 21504a b  - 10752a b  + 7168a b - 3584a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       6          5        2 4        4 2        5        6  4
+--R               (- 7168b  + 7168a b  - 5376a b  + 2688a b  - 1792a b + 896a )x
+--R             + 
+--R                       6          5        2 4        4 2        5        6  2
+--R               (- 7168b  + 7168a b  - 5376a b  + 2688a b  - 1792a b + 896a )x
+--R             + 
+--R                       6           5         2 4        4 2        5         6
+--R               - 14336b  + 14336a b  - 10752a b  + 5376a b  - 3584a b + 1792a
+--R          *
+--R                               +----------------+  6
+--R                               |  4     2 2    4
+--R                             7\|4b  - 4a b  + a
+--R                       atan(---------------------)
+--R                               2           2  +-+
+--R             4+--+2         (2b  - 8a b + a )\|7
+--R             \|98  cos(---------------------------)
+--R                                    2
+--R         + 
+--R                          4           3         2 2         3         4  6
+--R                   (50176b  - 25088a b  - 43904a b  + 12544a b + 9408a )x
+--R                 + 
+--R                          4           3         2 2         3         4  4
+--R                   (50176b  - 25088a b  - 43904a b  + 12544a b + 9408a )x
+--R                 + 
+--R                           4           3         2 2         3          4  2
+--R                   (100352b  - 50176a b  - 87808a b  + 25088a b + 18816a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                        4           3         2 2        3         4  6
+--R               (- 25088b  + 12544a b  + 21952a b  - 6272a b - 4704a )x
+--R             + 
+--R                        4           3         2 2        3         4  4
+--R               (- 25088b  + 12544a b  + 21952a b  - 6272a b - 4704a )x
+--R             + 
+--R                        4           3         2 2         3         4  2
+--R               (- 50176b  + 25088a b  + 43904a b  - 12544a b - 9408a )x
+--R          *
+--R                                                          +----------------+  4
+--R                                                          |  4     2 2    4
+--R                                                        7\|4b  - 4a b  + a
+--R                                                  atan(---------------------)
+--R            +-------------------------------+2            2           2  +-+
+--R           4|  4       3     2 2     3     4           (2b  - 8a b + a )\|7
+--R           \|4b  - 4a b  + 5a b  - 2a b + a   cos(---------------------------)
+--R                                                               2
+--R         + 
+--R                              6          5         2 4         3 3         4 2
+--R                       - 7168b  + 7168a b  + 69888a b  - 37632a b  - 30240a b
+--R                     + 
+--R                             5         6
+--R                       17024a b - 1456a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                              6          5         2 4         3 3         4 2
+--R                       - 7168b  + 7168a b  + 69888a b  - 37632a b  - 30240a b
+--R                     + 
+--R                             5         6
+--R                       17024a b - 1456a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               6           5          2 4         3 3
+--R                       - 14336b  + 14336a b  + 139776a b  - 75264a b
+--R                     + 
+--R                               4 2         5         6
+--R                       - 60480a b  + 34048a b - 2912a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                        6          5         2 4         3 3         4 2
+--R                   3584b  - 3584a b  - 34944a b  + 18816a b  + 15120a b
+--R                 + 
+--R                          5        6
+--R                   - 8512a b + 728a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                        6          5         2 4         3 3         4 2
+--R                   3584b  - 3584a b  - 34944a b  + 18816a b  + 15120a b
+--R                 + 
+--R                          5        6
+--R                   - 8512a b + 728a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                        6          5         2 4         3 3         4 2
+--R                   7168b  - 7168a b  - 69888a b  + 37632a b  + 30240a b
+--R                 + 
+--R                           5         6
+--R                   - 17024a b + 1456a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                               +----------------+  2
+--R                               |  4     2 2    4
+--R                             7\|4b  - 4a b  + a
+--R                       atan(---------------------)
+--R                               2           2  +-+
+--R             4+--+2         (2b  - 8a b + a )\|7
+--R             \|98  cos(---------------------------)
+--R                                    2
+--R         + 
+--R                            4           3         2 2        3         4  10
+--R                   (- 25088b  + 12544a b  + 21952a b  - 6272a b - 4704a )x
+--R                 + 
+--R                            4           3         2 2        3         4  8
+--R                   (- 25088b  + 12544a b  + 21952a b  - 6272a b - 4704a )x
+--R                 + 
+--R                            4           3         2 2         3         4  6
+--R                   (- 50176b  + 25088a b  + 43904a b  - 12544a b - 9408a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                      4          3         2 2        3         4  10
+--R               (12544b  - 6272a b  - 10976a b  + 3136a b + 2352a )x
+--R             + 
+--R                      4          3         2 2        3         4  8
+--R               (12544b  - 6272a b  - 10976a b  + 3136a b + 2352a )x
+--R             + 
+--R                      4           3         2 2        3         4  6
+--R               (25088b  - 12544a b  - 21952a b  + 6272a b + 4704a )x
+--R          *
+--R              +-------------------------------+2
+--R             4|  4       3     2 2     3     4
+--R             \|4b  - 4a b  + 5a b  - 2a b + a
+--R      *
+--R                     +----------------+  2
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                    2  6                    2  4
+--R                   (25088a b - 6272a )x  + (25088a b - 6272a )x
+--R                 + 
+--R                                     2  2
+--R                   (50176a b - 12544a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                                  2  6                      2  4
+--R               (- 12544a b + 3136a )x  + (- 12544a b + 3136a )x
+--R             + 
+--R                                  2  2
+--R               (- 25088a b + 6272a )x
+--R          *
+--R                  +-------------------------------+2 +----------------+
+--R              +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R             \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R          *
+--R                         +----------------+  5
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                           3        2 2        3        4  8
+--R                   (7168a b  - 5376a b  - 1792a b + 672a )x
+--R                 + 
+--R                           3        2 2        3        4  6
+--R                   (7168a b  - 5376a b  - 1792a b + 672a )x
+--R                 + 
+--R                            3         2 2        3         4  4
+--R                   (14336a b  - 10752a b  - 3584a b + 1344a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         3        2 2       3        4  8
+--R               (- 3584a b  + 2688a b  + 896a b - 336a )x
+--R             + 
+--R                         3        2 2       3        4  6
+--R               (- 3584a b  + 2688a b  + 896a b - 336a )x
+--R             + 
+--R                         3        2 2        3        4  4
+--R               (- 7168a b  + 5376a b  + 1792a b - 672a )x
+--R          *
+--R                                                      +----------------+  3
+--R                                                      |  4     2 2    4
+--R                                                    7\|4b  - 4a b  + a
+--R                                              atan(---------------------)
+--R                        +----------------+            2           2  +-+
+--R              +-+4+--+2 |  4     2 2    4          (2b  - 8a b + a )\|7
+--R             \|7 \|98  \|4b  - 4a b  + a  cos(---------------------------)
+--R                                                           2
+--R         + 
+--R                                    2  10                    2  8
+--R                   (12544a b - 3136a )x   + (12544a b - 3136a )x
+--R                 + 
+--R                                    2  6
+--R                   (25088a b - 6272a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                                 2  10                     2  8
+--R               (- 6272a b + 1568a )x   + (- 6272a b + 1568a )x
+--R             + 
+--R                                  2  6
+--R               (- 12544a b + 3136a )x
+--R          *
+--R                  +-------------------------------+2 +----------------+
+--R              +-+4|  4       3     2 2     3     4   |  4     2 2    4
+--R             \|7 \|4b  - 4a b  + 5a b  - 2a b + a   \|4b  - 4a b  + a
+--R          *
+--R                         +----------------+
+--R                         |  4     2 2    4
+--R                       7\|4b  - 4a b  + a
+--R                 atan(---------------------)
+--R                         2           2  +-+
+--R                      (2b  - 8a b + a )\|7
+--R             cos(---------------------------)
+--R                              2
+--R      *
+--R                     +----------------+
+--R                     |  4     2 2    4
+--R                   7\|4b  - 4a b  + a
+--R             atan(---------------------)
+--R                     2           2  +-+
+--R                  (2b  - 8a b + a )\|7
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                     6          5        2 4        4 2       5        6  4
+--R               (3584b  - 3584a b  + 2688a b  - 1344a b  + 896a b - 448a )x
+--R             + 
+--R                     6          5        2 4        4 2       5        6  2
+--R               (3584b  - 3584a b  + 2688a b  - 1344a b  + 896a b - 448a )x
+--R             + 
+--R                    6          5        2 4        4 2        5        6
+--R               7168b  - 7168a b  + 5376a b  - 2688a b  + 1792a b - 896a
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                   6          5        2 4       4 2       5        6  4
+--R           (- 1792b  + 1792a b  - 1344a b  + 672a b  - 448a b + 224a )x
+--R         + 
+--R                   6          5        2 4       4 2       5        6  2
+--R           (- 1792b  + 1792a b  - 1344a b  + 672a b  - 448a b + 224a )x
+--R         + 
+--R                  6          5        2 4        4 2       5        6
+--R           - 3584b  + 3584a b  - 2688a b  + 1344a b  - 896a b + 448a
+--R      *
+--R                           +----------------+  8
+--R                           |  4     2 2    4
+--R                         7\|4b  - 4a b  + a
+--R                   atan(---------------------)
+--R                           2           2  +-+
+--R         4+--+2         (2b  - 8a b + a )\|7
+--R         \|98  cos(---------------------------)
+--R                                2
+--R     + 
+--R                      4           3         2 2         3         4  6
+--R               (50176b  - 25088a b  - 43904a b  + 12544a b + 9408a )x
+--R             + 
+--R                      4           3         2 2         3         4  4
+--R               (50176b  - 25088a b  - 43904a b  + 12544a b + 9408a )x
+--R             + 
+--R                       4           3         2 2         3          4  2
+--R               (100352b  - 50176a b  - 87808a b  + 25088a b + 18816a )x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                    4           3         2 2        3         4  6
+--R           (- 25088b  + 12544a b  + 21952a b  - 6272a b - 4704a )x
+--R         + 
+--R                    4           3         2 2        3         4  4
+--R           (- 25088b  + 12544a b  + 21952a b  - 6272a b - 4704a )x
+--R         + 
+--R                    4           3         2 2         3         4  2
+--R           (- 50176b  + 25088a b  + 43904a b  - 12544a b - 9408a )x
+--R      *
+--R                                                        +----------------+  6
+--R                                                        |  4     2 2    4
+--R                                                      7\|4b  - 4a b  + a
+--R                                                atan(---------------------)
+--R          +-------------------------------+2            2           2  +-+
+--R         4|  4       3     2 2     3     4           (2b  - 8a b + a )\|7
+--R         \|4b  - 4a b  + 5a b  - 2a b + a   cos(---------------------------)
+--R                                                             2
+--R     + 
+--R                         6           5        2 4        3 3        4 2       5
+--R                   10752b  - 10752a b  - 4480a b  + 6272a b  + 1456a b  - 448a b
+--R                 + 
+--R                         6
+--R                   - 952a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                         6           5        2 4        3 3        4 2       5
+--R                   10752b  - 10752a b  - 4480a b  + 6272a b  + 1456a b  - 448a b
+--R                 + 
+--R                         6
+--R                   - 952a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         6           5        2 4         3 3        4 2
+--R                   21504b  - 21504a b  - 8960a b  + 12544a b  + 2912a b
+--R                 + 
+--R                         5         6
+--R                   - 896a b - 1904a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                      6          5        2 4        3 3       4 2       5
+--R               - 5376b  + 5376a b  + 2240a b  - 3136a b  - 728a b  + 224a b
+--R             + 
+--R                   6
+--R               476a
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      6          5        2 4        3 3       4 2       5
+--R               - 5376b  + 5376a b  + 2240a b  - 3136a b  - 728a b  + 224a b
+--R             + 
+--R                   6
+--R               476a
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                       6           5        2 4        3 3        4 2       5
+--R               - 10752b  + 10752a b  + 4480a b  - 6272a b  - 1456a b  + 448a b
+--R             + 
+--R                   6
+--R               952a
+--R          *
+--R              4
+--R             x
+--R      *
+--R                           +----------------+  4
+--R                           |  4     2 2    4
+--R                         7\|4b  - 4a b  + a
+--R                   atan(---------------------)
+--R                           2           2  +-+
+--R         4+--+2         (2b  - 8a b + a )\|7
+--R         \|98  cos(---------------------------)
+--R                                2
+--R     + 
+--R                      4           3         2 2        3         4  10
+--R               (25088b  - 12544a b  - 21952a b  + 6272a b + 4704a )x
+--R             + 
+--R                      4           3         2 2        3         4  8
+--R               (25088b  - 12544a b  - 21952a b  + 6272a b + 4704a )x
+--R             + 
+--R                      4           3         2 2         3         4  6
+--R               (50176b  - 25088a b  - 43904a b  + 12544a b + 9408a )x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                    4          3         2 2        3         4  10
+--R           (- 12544b  + 6272a b  + 10976a b  - 3136a b - 2352a )x
+--R         + 
+--R                    4          3         2 2        3         4  8
+--R           (- 12544b  + 6272a b  + 10976a b  - 3136a b - 2352a )x
+--R         + 
+--R                    4           3         2 2        3         4  6
+--R           (- 25088b  + 12544a b  + 21952a b  - 6272a b - 4704a )x
+--R      *
+--R                                                        +----------------+  2
+--R                                                        |  4     2 2    4
+--R                                                      7\|4b  - 4a b  + a
+--R                                                atan(---------------------)
+--R          +-------------------------------+2            2           2  +-+
+--R         4|  4       3     2 2     3     4           (2b  - 8a b + a )\|7
+--R         \|4b  - 4a b  + 5a b  - 2a b + a   cos(---------------------------)
+--R                                                             2
+--R     + 
+--R                    6         5       2 4       4 2       5        6  12
+--R               (896b  - 896a b  + 672a b  - 336a b  + 224a b - 112a )x
+--R             + 
+--R                    6         5       2 4       4 2       5        6  10
+--R               (896b  - 896a b  + 672a b  - 336a b  + 224a b - 112a )x
+--R             + 
+--R                     6          5        2 4       4 2       5        6  8
+--R               (1792b  - 1792a b  + 1344a b  - 672a b  + 448a b - 224a )x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                  6         5       2 4       4 2       5       6  12
+--R           (- 448b  + 448a b  - 336a b  + 168a b  - 112a b + 56a )x
+--R         + 
+--R                  6         5       2 4       4 2       5       6  10
+--R           (- 448b  + 448a b  - 336a b  + 168a b  - 112a b + 56a )x
+--R         + 
+--R                  6         5       2 4       4 2       5        6  8
+--R           (- 896b  + 896a b  - 672a b  + 336a b  - 224a b + 112a )x
+--R      *
+--R         4+--+2
+--R         \|98
+--R                                                    Type: Expression(Integer)
+--E 2347
+
+)clear all
+
+--S 2348 of 3139
+t0:=(a+b*x^2)/(2+x^2+x^4)^2
+--R 
+--R
+--R                   2
+--R                b x  + a
+--R   (1)  ------------------------
+--R         8     6     4     2
+--R        x  + 2x  + 5x  + 4x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2348
+
+--S 2349 of 3139
+r0:=1/28*x*(3*a+2*b-(a-4*b)*x^2)/(2+x^2+x^4)-1/112*log(x^2+sqrt(2)-_
+   x*sqrt(-1+2*sqrt(2)))*(a*(11+sqrt(2))-2*(b+2*b*sqrt(2)))*sqrt(1/14*(1+_
+   2*sqrt(2)))+1/112*log(x^2+sqrt(2)+x*sqrt(-1+2*sqrt(2)))*(a*(11+sqrt(2))-_
+   2*(b+2*b*sqrt(2)))*sqrt(1/14*(1+2*sqrt(2)))-1/56*atan((-2*x+sqrt(-1+_
+   2*sqrt(2)))/sqrt(1+2*sqrt(2)))*(11*a-2*b-(a-4*b)*sqrt(2))/sqrt(2*(1+_
+   2*sqrt(2)))+1/56*atan((2*x+sqrt(-1+2*sqrt(2)))/sqrt(1+2*sqrt(2)))*_
+   (11*a-2*b-(a-4*b)*sqrt(2))/sqrt(2*(1+2*sqrt(2)))
+--R 
+--R
+--R   (2)
+--R                       4              2            +-+                4
+--R           ((- 4b + a)x  + (- 4b + a)x  - 8b + 2a)\|2  + (- 2b + 11a)x
+--R         + 
+--R                        2
+--R           (- 2b + 11a)x  - 4b + 22a
+--R      *
+--R          +---------+ +---------+      +---------+
+--R          |  +-+      |  +-+           |  +-+         +-+    2
+--R         \|2\|2  + 1 \|4\|2  + 2 log(x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R                     4            2            +-+              4              2
+--R           ((4b - a)x  + (4b - a)x  + 8b - 2a)\|2  + (2b - 11a)x  + (2b - 11a)x
+--R         + 
+--R           4b - 22a
+--R      *
+--R          +---------+ +---------+        +---------+
+--R          |  +-+      |  +-+             |  +-+         +-+    2
+--R         \|2\|2  + 1 \|4\|2  + 2 log(- x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R                      4             2             +-+                4
+--R           ((8b - 2a)x  + (8b - 2a)x  + 16b - 4a)\|2  + (- 4b + 22a)x
+--R         + 
+--R                        2
+--R           (- 4b + 22a)x  - 8b + 44a
+--R      *
+--R                                +---------+                +---------+
+--R                       +-+      |  +-+           +-+       |  +-+
+--R          +--+     ((2\|2  - 1)\|2\|2  - 1  + 4x\|2  - 2x)\|2\|2  + 1
+--R         \|14 atan(---------------------------------------------------)
+--R                                            7
+--R     + 
+--R                        4               2             +-+              4
+--R           ((- 8b + 2a)x  + (- 8b + 2a)x  - 16b + 4a)\|2  + (4b - 22a)x
+--R         + 
+--R                      2
+--R           (4b - 22a)x  + 8b - 44a
+--R      *
+--R                                +---------+                +---------+
+--R                       +-+      |  +-+           +-+       |  +-+
+--R          +--+     ((2\|2  - 1)\|2\|2  - 1  - 4x\|2  + 2x)\|2\|2  + 1
+--R         \|14 atan(---------------------------------------------------)
+--R                                            7
+--R     + 
+--R                                         +---------+
+--R                   3                +--+ |  +-+
+--R       ((16b - 4a)x  + (8b + 12a)x)\|14 \|4\|2  + 2
+--R  /
+--R                                +---------+
+--R          4       2        +--+ |  +-+
+--R     (112x  + 112x  + 224)\|14 \|4\|2  + 2
+--R                                                    Type: Expression(Integer)
+--E 2349
+
+--S 2350 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         +----------------------------------------------+
+--R             4    2     4|    4          3        2 2        3         4
+--R         (- x  - x  - 2)\|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R      *
+--R         log
+--R                     2                2
+--R                (112b  + 112a b - 476a )
+--R             *
+--R                 +----------------------------------------------+2
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+  2
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                sin(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                             +-+4+---+
+--R                (18b - 15a)x\|7 \|392
+--R             *
+--R                 +----------------------------------------+
+--R                 |   4        3       2 2       3        4
+--R                \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             *
+--R                 +----------------------------------------------+
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                sin(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                     2                2
+--R                (112b  + 112a b - 476a )
+--R             *
+--R                 +----------------------------------------------+2
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+  2
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                cos(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                    3         2       2         3  4+---+
+--R                (56b  - 252a b  - 546a b + 1309a )x\|392
+--R             *
+--R                 +----------------------------------------------+
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                cos(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                  4         3       2 2        3         4  2 4+---+2
+--R              (88b  - 124a b  - 318a b  + 1169a b - 1139a )x  \|392
+--R     + 
+--R                       +----------------------------------------------+
+--R           4    2     4|    4          3        2 2        3         4
+--R         (x  + x  + 2)\|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R      *
+--R         log
+--R                     2                2
+--R                (112b  + 112a b - 476a )
+--R             *
+--R                 +----------------------------------------------+2
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+  2
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                sin(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                               +-+4+---+
+--R                (- 18b + 15a)x\|7 \|392
+--R             *
+--R                 +----------------------------------------+
+--R                 |   4        3       2 2       3        4
+--R                \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             *
+--R                 +----------------------------------------------+
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                sin(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                     2                2
+--R                (112b  + 112a b - 476a )
+--R             *
+--R                 +----------------------------------------------+2
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+  2
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                cos(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                      3         2       2         3  4+---+
+--R                (- 56b  + 252a b  + 546a b - 1309a )x\|392
+--R             *
+--R                 +----------------------------------------------+
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                cos(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                  4         3       2 2        3         4  2 4+---+2
+--R              (88b  - 124a b  - 318a b  + 1169a b - 1139a )x  \|392
+--R     + 
+--R                           +----------------------------------------------+
+--R              4     2     4|    4          3        2 2        3         4
+--R         (- 2x  - 2x  - 4)\|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R      *
+--R         atan
+--R                      3         2       2         3  +-+
+--R                  (56b  - 252a b  - 546a b + 1309a )\|7
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  sin(---------------------------------------------------)
+--R                                               2
+--R              + 
+--R                                  +----------------------------------------+
+--R                                  |   4        3       2 2       3        4
+--R                  (- 126b + 105a)\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  cos(---------------------------------------------------)
+--R                                               2
+--R           /
+--R                                +----------------------------------------+
+--R                                |   4        3       2 2       3        4
+--R                  (126b - 105a)\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  sin(---------------------------------------------------)
+--R                                               2
+--R              + 
+--R                      3         2       2         3  +-+
+--R                  (56b  - 252a b  - 546a b + 1309a )\|7
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  cos(---------------------------------------------------)
+--R                                               2
+--R              + 
+--R                       4         3       2 2        3         4   +-+4+---+
+--R                (- 176b  + 248a b  + 636a b  - 2338a b + 2278a )x\|7 \|392
+--R     + 
+--R                         +----------------------------------------------+
+--R            4     2     4|    4          3        2 2        3         4
+--R         (2x  + 2x  + 4)\|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R      *
+--R         atan
+--R                      3         2       2         3  +-+
+--R                  (56b  - 252a b  - 546a b + 1309a )\|7
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  sin(---------------------------------------------------)
+--R                                               2
+--R              + 
+--R                                  +----------------------------------------+
+--R                                  |   4        3       2 2       3        4
+--R                  (- 126b + 105a)\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  cos(---------------------------------------------------)
+--R                                               2
+--R           /
+--R                                +----------------------------------------+
+--R                                |   4        3       2 2       3        4
+--R                  (126b - 105a)\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  sin(---------------------------------------------------)
+--R                                               2
+--R              + 
+--R                      3         2       2         3  +-+
+--R                  (56b  - 252a b  - 546a b + 1309a )\|7
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  cos(---------------------------------------------------)
+--R                                               2
+--R              + 
+--R                     4         3       2 2        3         4   +-+4+---+
+--R                (176b  - 248a b  - 636a b  + 2338a b - 2278a )x\|7 \|392
+--R     + 
+--R                 3              4+---+
+--R       ((4b - a)x  + (2b + 3a)x)\|392
+--R  /
+--R         4      2      4+---+
+--R     (28x  + 28x  + 56)\|392
+--R                                         Type: Union(Expression(Integer),...)
+--E 2350
+
+--S 2351 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                   +----------------------------------------------+ +---------+
+--R              +--+4|    4          3        2 2        3         4  |  +-+
+--R            4\|14 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a  \|4\|2  + 2
+--R         *
+--R                        +----------------------------------------+
+--R                        |   4        3       2 2       3        4
+--R                     49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                atan(---------------------------------------------)
+--R                                   2                2  +-+
+--R                              (100b  - 428a b + 211a )\|7
+--R            cos(---------------------------------------------------)
+--R                                         2
+--R         *
+--R            log
+--R                        2                2
+--R                   (112b  + 112a b - 476a )
+--R                *
+--R                    +----------------------------------------------+2
+--R                   4|    4          3        2 2        3         4
+--R                   \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R                *
+--R                               +----------------------------------------+  2
+--R                               |   4        3       2 2       3        4
+--R                            49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                       atan(---------------------------------------------)
+--R                                          2                2  +-+
+--R                                     (100b  - 428a b + 211a )\|7
+--R                   sin(---------------------------------------------------)
+--R                                                2
+--R               + 
+--R                                +-+4+---+
+--R                   (18b - 15a)x\|7 \|392
+--R                *
+--R                    +----------------------------------------+
+--R                    |   4        3       2 2       3        4
+--R                   \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                *
+--R                    +----------------------------------------------+
+--R                   4|    4          3        2 2        3         4
+--R                   \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R                *
+--R                               +----------------------------------------+
+--R                               |   4        3       2 2       3        4
+--R                            49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                       atan(---------------------------------------------)
+--R                                          2                2  +-+
+--R                                     (100b  - 428a b + 211a )\|7
+--R                   sin(---------------------------------------------------)
+--R                                                2
+--R               + 
+--R                        2                2
+--R                   (112b  + 112a b - 476a )
+--R                *
+--R                    +----------------------------------------------+2
+--R                   4|    4          3        2 2        3         4
+--R                   \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R                *
+--R                               +----------------------------------------+  2
+--R                               |   4        3       2 2       3        4
+--R                            49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                       atan(---------------------------------------------)
+--R                                          2                2  +-+
+--R                                     (100b  - 428a b + 211a )\|7
+--R                   cos(---------------------------------------------------)
+--R                                                2
+--R               + 
+--R                       3         2       2         3  4+---+
+--R                   (56b  - 252a b  - 546a b + 1309a )x\|392
+--R                *
+--R                    +----------------------------------------------+
+--R                   4|    4          3        2 2        3         4
+--R                   \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R                *
+--R                               +----------------------------------------+
+--R                               |   4        3       2 2       3        4
+--R                            49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                       atan(---------------------------------------------)
+--R                                          2                2  +-+
+--R                                     (100b  - 428a b + 211a )\|7
+--R                   cos(---------------------------------------------------)
+--R                                                2
+--R               + 
+--R                     4         3       2 2        3         4  2 4+---+2
+--R                 (88b  - 124a b  - 318a b  + 1169a b - 1139a )x  \|392
+--R     + 
+--R                +----------------------------------------------+ +---------+
+--R           +--+4|    4          3        2 2        3         4  |  +-+
+--R         4\|14 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a  \|4\|2  + 2
+--R      *
+--R                     +----------------------------------------+
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R      *
+--R         log
+--R                     2                2
+--R                (112b  + 112a b - 476a )
+--R             *
+--R                 +----------------------------------------------+2
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+  2
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                sin(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                               +-+4+---+
+--R                (- 18b + 15a)x\|7 \|392
+--R             *
+--R                 +----------------------------------------+
+--R                 |   4        3       2 2       3        4
+--R                \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             *
+--R                 +----------------------------------------------+
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                sin(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                     2                2
+--R                (112b  + 112a b - 476a )
+--R             *
+--R                 +----------------------------------------------+2
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+  2
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                cos(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                      3         2       2         3  4+---+
+--R                (- 56b  + 252a b  + 546a b - 1309a )x\|392
+--R             *
+--R                 +----------------------------------------------+
+--R                4|    4          3        2 2        3         4
+--R                \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R             *
+--R                            +----------------------------------------+
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R                                  (100b  - 428a b + 211a )\|7
+--R                cos(---------------------------------------------------)
+--R                                             2
+--R            + 
+--R                  4         3       2 2        3         4  2 4+---+2
+--R              (88b  - 124a b  - 318a b  + 1169a b - 1139a )x  \|392
+--R     + 
+--R       -
+--R                   +----------------------------------------------+ +---------+
+--R              +--+4|    4          3        2 2        3         4  |  +-+
+--R            8\|14 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a  \|4\|2  + 2
+--R         *
+--R                        +----------------------------------------+
+--R                        |   4        3       2 2       3        4
+--R                     49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                atan(---------------------------------------------)
+--R                                   2                2  +-+
+--R                              (100b  - 428a b + 211a )\|7
+--R            sin(---------------------------------------------------)
+--R                                         2
+--R         *
+--R            atan
+--R                         3         2       2         3  +-+
+--R                     (56b  - 252a b  - 546a b + 1309a )\|7
+--R                  *
+--R                      +----------------------------------------------+
+--R                     4|    4          3        2 2        3         4
+--R                     \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R                  *
+--R                                 +----------------------------------------+
+--R                                 |   4        3       2 2       3        4
+--R                              49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                         atan(---------------------------------------------)
+--R                                            2                2  +-+
+--R                                       (100b  - 428a b + 211a )\|7
+--R                     sin(---------------------------------------------------)
+--R                                                  2
+--R                 + 
+--R                                     +----------------------------------------+
+--R                                     |   4        3       2 2       3        4
+--R                     (- 126b + 105a)\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                  *
+--R                      +----------------------------------------------+
+--R                     4|    4          3        2 2        3         4
+--R                     \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R                  *
+--R                                 +----------------------------------------+
+--R                                 |   4        3       2 2       3        4
+--R                              49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                         atan(---------------------------------------------)
+--R                                            2                2  +-+
+--R                                       (100b  - 428a b + 211a )\|7
+--R                     cos(---------------------------------------------------)
+--R                                                  2
+--R              /
+--R                                   +----------------------------------------+
+--R                                   |   4        3       2 2       3        4
+--R                     (126b - 105a)\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                  *
+--R                      +----------------------------------------------+
+--R                     4|    4          3        2 2        3         4
+--R                     \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R                  *
+--R                                 +----------------------------------------+
+--R                                 |   4        3       2 2       3        4
+--R                              49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                         atan(---------------------------------------------)
+--R                                            2                2  +-+
+--R                                       (100b  - 428a b + 211a )\|7
+--R                     sin(---------------------------------------------------)
+--R                                                  2
+--R                 + 
+--R                         3         2       2         3  +-+
+--R                     (56b  - 252a b  - 546a b + 1309a )\|7
+--R                  *
+--R                      +----------------------------------------------+
+--R                     4|    4          3        2 2        3         4
+--R                     \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R                  *
+--R                                 +----------------------------------------+
+--R                                 |   4        3       2 2       3        4
+--R                              49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                         atan(---------------------------------------------)
+--R                                            2                2  +-+
+--R                                       (100b  - 428a b + 211a )\|7
+--R                     cos(---------------------------------------------------)
+--R                                                  2
+--R                 + 
+--R                          4         3       2 2        3         4   +-+4+---+
+--R                   (- 176b  + 248a b  + 636a b  - 2338a b + 2278a )x\|7 \|392
+--R     + 
+--R                +----------------------------------------------+ +---------+
+--R           +--+4|    4          3        2 2        3         4  |  +-+
+--R         8\|14 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a  \|4\|2  + 2
+--R      *
+--R                     +----------------------------------------+
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R      *
+--R         atan
+--R                      3         2       2         3  +-+
+--R                  (56b  - 252a b  - 546a b + 1309a )\|7
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  sin(---------------------------------------------------)
+--R                                               2
+--R              + 
+--R                                  +----------------------------------------+
+--R                                  |   4        3       2 2       3        4
+--R                  (- 126b + 105a)\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  cos(---------------------------------------------------)
+--R                                               2
+--R           /
+--R                                +----------------------------------------+
+--R                                |   4        3       2 2       3        4
+--R                  (126b - 105a)\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  sin(---------------------------------------------------)
+--R                                               2
+--R              + 
+--R                      3         2       2         3  +-+
+--R                  (56b  - 252a b  - 546a b + 1309a )\|7
+--R               *
+--R                   +----------------------------------------------+
+--R                  4|    4          3        2 2        3         4
+--R                  \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R               *
+--R                              +----------------------------------------+
+--R                              |   4        3       2 2       3        4
+--R                           49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                      atan(---------------------------------------------)
+--R                                         2                2  +-+
+--R                                    (100b  - 428a b + 211a )\|7
+--R                  cos(---------------------------------------------------)
+--R                                               2
+--R              + 
+--R                     4         3       2 2        3         4   +-+4+---+
+--R                (176b  - 248a b  - 636a b  + 2338a b - 2278a )x\|7 \|392
+--R     + 
+--R                                         +---------+ +---------+
+--R                   +-+            4+---+ |  +-+      |  +-+
+--R         ((4b - a)\|2  + 2b - 11a)\|392 \|2\|2  + 1 \|4\|2  + 2
+--R      *
+--R               +---------+
+--R               |  +-+         +-+    2
+--R         log(x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R                                           +---------+ +---------+
+--R                     +-+            4+---+ |  +-+      |  +-+
+--R         ((- 4b + a)\|2  - 2b + 11a)\|392 \|2\|2  + 1 \|4\|2  + 2
+--R      *
+--R                 +---------+
+--R                 |  +-+         +-+    2
+--R         log(- x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R                      +-+             +--+4+---+
+--R         ((- 8b + 2a)\|2  + 4b - 22a)\|14 \|392
+--R      *
+--R                           +---------+                +---------+
+--R                  +-+      |  +-+           +-+       |  +-+
+--R              ((2\|2  - 1)\|2\|2  - 1  + 4x\|2  - 2x)\|2\|2  + 1
+--R         atan(---------------------------------------------------)
+--R                                       7
+--R     + 
+--R                    +-+             +--+4+---+
+--R         ((8b - 2a)\|2  - 4b + 22a)\|14 \|392
+--R      *
+--R                           +---------+                +---------+
+--R                  +-+      |  +-+           +-+       |  +-+
+--R              ((2\|2  - 1)\|2\|2  - 1  - 4x\|2  + 2x)\|2\|2  + 1
+--R         atan(---------------------------------------------------)
+--R                                       7
+--R  /
+--R                    +---------+
+--R         +--+4+---+ |  +-+
+--R     112\|14 \|392 \|4\|2  + 2
+--R                                                    Type: Expression(Integer)
+--E 2351
+
+--S 2352 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                 7              6            2 5            3 4
+--R                       - 2725888b  + 13691392a b  - 20241408a b  - 38963200a b
+--R                     + 
+--R                               4 3             5 2             6              7
+--R                     210627712a b  - 378987936a b  + 342666944a b - 129426848a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                           7              6            2 5            3 4
+--R                   3097600b  - 18456064a b  + 34065408a b  + 36086272a b
+--R                 + 
+--R                               4 3             5 2             6              7
+--R                   - 290633536a b  + 592795104a b  - 596975360a b + 261295712a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           7              6            2 5            3 4
+--R                   3097600b  - 18456064a b  + 34065408a b  + 36086272a b
+--R                 + 
+--R                               4 3             5 2             6              7
+--R                   - 290633536a b  + 592795104a b  - 596975360a b + 261295712a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         7              6            2 5            3 4
+--R               - 5451776b  + 27382784a b  - 40482816a b  - 77926400a b
+--R             + 
+--R                         4 3             5 2             6              7
+--R               421255424a b  - 757975872a b  + 685333888a b - 258853696a
+--R          *
+--R                     +---------+ +---------+
+--R             4+---+2 |  +-+      |  +-+
+--R             \|392  \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                                 6           2 5           3 4            4 3
+--R                       1300992a b  - 4967424a b  + 3677184a b  + 23025408a b
+--R                     + 
+--R                                  5 2            6             7
+--R                       - 72791712a b  + 93199680a b - 51282336a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                          7             6          2 5            3 4
+--R                   867328b  - 2877952a b  + 795648a b  + 16576000a b
+--R                 + 
+--R                              4 3            5 2           6             7
+--R                   - 40852672a b  + 37869216a b  - 3121664a b - 17094112a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                            7             6          2 5            3 4
+--R                   - 867328b  + 2877952a b  - 795648a b  - 16576000a b
+--R                 + 
+--R                            4 3            5 2           6             7
+--R                   40852672a b  - 37869216a b  + 3121664a b + 17094112a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           6           2 5           3 4            4 3
+--R               - 2601984a b  + 9934848a b  - 7354368a b  - 46050816a b
+--R             + 
+--R                         5 2             6              7
+--R               145583424a b  - 186399360a b + 102564672a
+--R          *
+--R                          +---------+ +---------+
+--R              +--+4+---+2 |  +-+      |  +-+
+--R             \|14 \|392  \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                                 7              6            2 5           3 4
+--R                       - 3469312b  + 32327680a b  - 82661376a b  - 7469056a b
+--R                     + 
+--R                                 4 3              5 2              6
+--R                       531817216a b  - 1316144256a b  + 1503681536a b
+--R                     + 
+--R                                   7
+--R                       - 752140928a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 7              6            2 5           3 4
+--R                       - 3469312b  + 32327680a b  - 82661376a b  - 7469056a b
+--R                     + 
+--R                                 4 3              5 2              6
+--R                       531817216a b  - 1316144256a b  + 1503681536a b
+--R                     + 
+--R                                   7
+--R                       - 752140928a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                             7              6             2 5            3 4
+--R                   - 6938624b  + 64655360a b  - 165322752a b  - 14938112a b
+--R                 + 
+--R                            4 3              5 2              6               7
+--R                 1063634432a b  - 2632288512a b  + 3007363072a b - 1504281856a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           7              6            2 5           3 4
+--R                   1734656b  - 16163840a b  + 41330688a b  + 3734528a b
+--R                 + 
+--R                               4 3             5 2             6              7
+--R                   - 265908608a b  + 658072128a b  - 751840768a b + 376070464a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           7              6            2 5           3 4
+--R                   1734656b  - 16163840a b  + 41330688a b  + 3734528a b
+--R                 + 
+--R                               4 3             5 2             6              7
+--R                   - 265908608a b  + 658072128a b  - 751840768a b + 376070464a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                       7              6            2 5           3 4
+--R               3469312b  - 32327680a b  + 82661376a b  + 7469056a b
+--R             + 
+--R                           4 3              5 2              6              7
+--R               - 531817216a b  + 1316144256a b  - 1503681536a b + 752140928a
+--R          *
+--R             4+---+2
+--R             \|392
+--R      *
+--R                     +----------------------------------------+  8
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                                      7              6            2 5
+--R                           - 10903552b  + 54765568a b  - 80965632a b
+--R                         + 
+--R                                       3 4             4 3              5 2
+--R                           - 155852800a b  + 842510848a b  - 1515951744a b
+--R                         + 
+--R                                      6              7
+--R                           1370667776a b - 517707392a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                                7              6             2 5             3 4
+--R                       12390400b  - 73824256a b  + 136261632a b  + 144345088a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 1162534144a b  + 2371180416a b  - 2387901440a b
+--R                     + 
+--R                                  7
+--R                       1045182848a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                7              6             2 5             3 4
+--R                       12390400b  - 73824256a b  + 136261632a b  + 144345088a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 1162534144a b  + 2371180416a b  - 2387901440a b
+--R                     + 
+--R                                  7
+--R                       1045182848a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                              7               6             2 5             3 4
+--R                   - 21807104b  + 109531136a b  - 161931264a b  - 311705600a b
+--R                 + 
+--R                            4 3              5 2              6               7
+--R                 1685021696a b  - 3031903488a b  + 2741335552a b - 1035414784a
+--R              *
+--R                         +---------+ +---------+
+--R                 4+---+2 |  +-+      |  +-+
+--R                 \|392  \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                                     6            2 5            3 4
+--R                           5203968a b  - 19869696a b  + 14708736a b
+--R                         + 
+--R                                    4 3             5 2             6
+--R                           92101632a b  - 291166848a b  + 372798720a b
+--R                         + 
+--R                                       7
+--R                           - 205129344a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                               7              6           2 5            3 4
+--R                       3469312b  - 11511808a b  + 3182592a b  + 66304000a b
+--R                     + 
+--R                                 4 3             5 2            6             7
+--R                     - 163410688a b  + 151476864a b  - 12486656a b - 68376448a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                 7              6           2 5            3 4
+--R                       - 3469312b  + 11511808a b  - 3182592a b  - 66304000a b
+--R                     + 
+--R                                 4 3             5 2            6             7
+--R                       163410688a b  - 151476864a b  + 12486656a b + 68376448a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                                6            2 5            3 4             4 3
+--R                   - 10407936a b  + 39739392a b  - 29417472a b  - 184203264a b
+--R                 + 
+--R                             5 2             6              7
+--R                   582333696a b  - 745597440a b + 410258688a
+--R              *
+--R                              +---------+ +---------+
+--R                  +--+4+---+2 |  +-+      |  +-+
+--R                 \|14 \|392  \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                      7               6             2 5
+--R                           - 13877248b  + 129310720a b  - 330645504a b
+--R                         + 
+--R                                      3 4              4 3              5 2
+--R                           - 29876224a b  + 2127268864a b  - 5264577024a b
+--R                         + 
+--R                                      6               7
+--R                           6014726144a b - 3008563712a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                      7               6             2 5
+--R                           - 13877248b  + 129310720a b  - 330645504a b
+--R                         + 
+--R                                      3 4              4 3              5 2
+--R                           - 29876224a b  + 2127268864a b  - 5264577024a b
+--R                         + 
+--R                                      6               7
+--R                           6014726144a b - 3008563712a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                                  7               6             2 5
+--R                       - 27754496b  + 258621440a b  - 661291008a b
+--R                     + 
+--R                                  3 4              4 3               5 2
+--R                       - 59752448a b  + 4254537728a b  - 10529154048a b
+--R                     + 
+--R                                   6               7
+--R                       12029452288a b - 6017127424a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                               7              6             2 5            3 4
+--R                       6938624b  - 64655360a b  + 165322752a b  + 14938112a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 1063634432a b  + 2632288512a b  - 3007363072a b
+--R                     + 
+--R                                  7
+--R                       1504281856a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                               7              6             2 5            3 4
+--R                       6938624b  - 64655360a b  + 165322752a b  + 14938112a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 1063634432a b  + 2632288512a b  - 3007363072a b
+--R                     + 
+--R                                  7
+--R                       1504281856a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                            7               6             2 5            3 4
+--R                   13877248b  - 129310720a b  + 330645504a b  + 29876224a b
+--R                 + 
+--R                                4 3              5 2              6
+--R                   - 2127268864a b  + 5264577024a b  - 6014726144a b
+--R                 + 
+--R                              7
+--R                   3008563712a
+--R              *
+--R                 4+---+2
+--R                 \|392
+--R          *
+--R                         +----------------------------------------+  2
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                               5             4            2 3            3 2
+--R                       5834752b  - 5766656a b  - 43151360a b  + 57322496a b
+--R                     + 
+--R                                4             5
+--R                       43465856a b - 62767264a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 5              4            2 3             3 2
+--R                       - 6630400b  + 12755456a b  + 50376704a b  - 109394432a b
+--R                     + 
+--R                                  4              5
+--R                       - 41765696a b + 126718816a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                             5              4            2 3             3 2
+--R                   - 6630400b  + 12755456a b  + 50376704a b  - 109394432a b
+--R                 + 
+--R                              4              5
+--R                   - 41765696a b + 126718816a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            5              4            2 3             3 2
+--R                   11669504b  - 11533312a b  - 86302720a b  + 114644992a b
+--R                 + 
+--R                            4              5
+--R                   86931712a b - 125534528a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R              +----------------------------------------------+2 +---------+
+--R             4|    4          3        2 2        3         4   |  +-+
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  + 1
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|4\|2  + 2
+--R         + 
+--R                                   4          2 3            3 2           4
+--R                       - 2784768a b  - 602112a b  + 19869696a b  - 3424512a b
+--R                     + 
+--R                                  5
+--R                       - 24870048a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 5             4            2 3           3 2
+--R                       - 1856512b  - 1329664a b  + 13045760a b  + 4340224a b
+--R                     + 
+--R                                  4            5
+--R                       - 17721536a b - 8290016a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           5             4            2 3           3 2
+--R                   1856512b  + 1329664a b  - 13045760a b  - 4340224a b
+--R                 + 
+--R                            4            5
+--R                   17721536a b + 8290016a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             4           2 3            3 2           4
+--R                   5569536a b  + 1204224a b  - 39739392a b  + 6849024a b
+--R                 + 
+--R                            5
+--R                   49740096a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R                   +----------------------------------------------+2 +---------+
+--R              +--+4|    4          3        2 2        3         4   |  +-+
+--R             \|14 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  - 1
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|2  + 1
+--R         + 
+--R                               5             4            2 3            3 2
+--R                       1505280b  - 4365312a b  - 40040448a b  + 77070336a b
+--R                     + 
+--R                                 4              5
+--R                       197925504a b - 339544128a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               5             4            2 3            3 2
+--R                       1505280b  - 4365312a b  - 40040448a b  + 77070336a b
+--R                     + 
+--R                                 4              5
+--R                       197925504a b - 339544128a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                               5             4            2 3             3 2
+--R                       3010560b  - 8730624a b  - 80080896a b  + 154140672a b
+--R                     + 
+--R                                 4              5
+--R                       395851008a b - 679088256a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                            5             4            2 3            3 2
+--R                   - 752640b  + 2182656a b  + 20020224a b  - 38535168a b
+--R                 + 
+--R                              4              5
+--R                   - 98962752a b + 169772064a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            5             4            2 3            3 2
+--R                   - 752640b  + 2182656a b  + 20020224a b  - 38535168a b
+--R                 + 
+--R                              4              5
+--R                   - 98962752a b + 169772064a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             5             4            2 3            3 2
+--R                   - 1505280b  + 4365312a b  + 40040448a b  - 77070336a b
+--R                 + 
+--R                               4              5
+--R                   - 197925504a b + 339544128a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+  6
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                           3             2           2            3  4
+--R                   (709632b  - 5349120a b  + 8666112a b - 3917760a )x
+--R                 + 
+--R                             3             2            2            3  2
+--R                   (- 806400b  + 6832896a b  - 14625408a b + 7909440a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         3             2            2            3  4
+--R               (- 806400b  + 6832896a b  - 14625408a b + 7909440a )x
+--R             + 
+--R                        3              2            2            3  2
+--R               (1419264b  - 10698240a b  + 17332224a b - 7835520a )x
+--R          *
+--R                  +----------------------------------------+
+--R              +-+ |   4        3       2 2       3        4
+--R             \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R          *
+--R              +----------------------------------------------+2 +---------+
+--R             4|    4          3        2 2        3         4   |  +-+
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  + 1
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|4\|2  + 2
+--R         + 
+--R                               2           2            3  4
+--R                   (- 338688a b  + 2145024a b - 1552320a )x
+--R                 + 
+--R                             3             2          2           3  2
+--R                   (- 225792b  + 1317120a b  - 319872a b - 517440a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                       3             2          2           3  4
+--R               (225792b  - 1317120a b  + 319872a b + 517440a )x
+--R             + 
+--R                         2           2            3  2
+--R               (677376a b  - 4290048a b + 3104640a )x
+--R          *
+--R                       +----------------------------------------+
+--R              +-+ +--+ |   4        3       2 2       3        4
+--R             \|7 \|14 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R          *
+--R              +----------------------------------------------+2 +---------+
+--R             4|    4          3        2 2        3         4   |  +-+
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  - 1
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|2  + 1
+--R         + 
+--R                            3             2            2             3  6
+--R                   (1870848b  - 9945600a b  + 24971520a b - 14985600a )x
+--R                 + 
+--R                            3             2            2             3  4
+--R                   (1870848b  - 9945600a b  + 24971520a b - 14985600a )x
+--R                 + 
+--R                            3              2            2             3  2
+--R                   (3741696b  - 19891200a b  + 49943040a b - 29971200a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         3             2            2            3  6
+--R               (- 935424b  + 4972800a b  - 12485760a b + 7492800a )x
+--R             + 
+--R                         3             2            2            3  4
+--R               (- 935424b  + 4972800a b  - 12485760a b + 7492800a )x
+--R             + 
+--R                          3             2            2             3  2
+--R               (- 1870848b  + 9945600a b  - 24971520a b + 14985600a )x
+--R          *
+--R                  +----------------------------------------+
+--R              +-+ |   4        3       2 2       3        4
+--R             \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R      *
+--R                     +----------------------------------------+  5
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                                      7              6             2 5
+--R                           - 16355328b  + 82148352a b  - 121448448a b
+--R                         + 
+--R                                       3 4              4 3              5 2
+--R                           - 233779200a b  + 1263766272a b  - 2273927616a b
+--R                         + 
+--R                                      6              7
+--R                           2056001664a b - 776561088a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                                7               6             2 5
+--R                       18585600b  - 110736384a b  + 204392448a b
+--R                     + 
+--R                                 3 4              4 3              5 2
+--R                       216517632a b  - 1743801216a b  + 3556770624a b
+--R                     + 
+--R                                    6               7
+--R                       - 3581852160a b + 1567774272a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                7               6             2 5
+--R                       18585600b  - 110736384a b  + 204392448a b
+--R                     + 
+--R                                 3 4              4 3              5 2
+--R                       216517632a b  - 1743801216a b  + 3556770624a b
+--R                     + 
+--R                                    6               7
+--R                       - 3581852160a b + 1567774272a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                              7               6             2 5             3 4
+--R                   - 32710656b  + 164296704a b  - 242896896a b  - 467558400a b
+--R                 + 
+--R                            4 3              5 2              6               7
+--R                 2527532544a b  - 4547855232a b  + 4112003328a b - 1553122176a
+--R              *
+--R                         +---------+ +---------+
+--R                 4+---+2 |  +-+      |  +-+
+--R                 \|392  \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                                     6            2 5            3 4
+--R                           7805952a b  - 29804544a b  + 22063104a b
+--R                         + 
+--R                                     4 3             5 2             6
+--R                           138152448a b  - 436750272a b  + 559198080a b
+--R                         + 
+--R                                       7
+--R                           - 307694016a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                               7              6           2 5            3 4
+--R                       5203968b  - 17267712a b  + 4773888a b  + 99456000a b
+--R                     + 
+--R                                 4 3             5 2            6              7
+--R                     - 245116032a b  + 227215296a b  - 18729984a b - 102564672a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                 7              6           2 5            3 4
+--R                       - 5203968b  + 17267712a b  - 4773888a b  - 99456000a b
+--R                     + 
+--R                               4 3             5 2            6              7
+--R                     245116032a b  - 227215296a b  + 18729984a b + 102564672a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                                6            2 5            3 4             4 3
+--R                   - 15611904a b  + 59609088a b  - 44126208a b  - 276304896a b
+--R                 + 
+--R                             5 2              6              7
+--R                   873500544a b  - 1118396160a b + 615388032a
+--R              *
+--R                              +---------+ +---------+
+--R                  +--+4+---+2 |  +-+      |  +-+
+--R                 \|14 \|392  \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                      7               6             2 5
+--R                           - 20815872b  + 193966080a b  - 495968256a b
+--R                         + 
+--R                                      3 4              4 3              5 2
+--R                           - 44814336a b  + 3190903296a b  - 7896865536a b
+--R                         + 
+--R                                      6               7
+--R                           9022089216a b - 4512845568a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                      7               6             2 5
+--R                           - 20815872b  + 193966080a b  - 495968256a b
+--R                         + 
+--R                                      3 4              4 3              5 2
+--R                           - 44814336a b  + 3190903296a b  - 7896865536a b
+--R                         + 
+--R                                      6               7
+--R                           9022089216a b - 4512845568a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                                  7               6             2 5
+--R                       - 41631744b  + 387932160a b  - 991936512a b
+--R                     + 
+--R                                  3 4              4 3               5 2
+--R                       - 89628672a b  + 6381806592a b  - 15793731072a b
+--R                     + 
+--R                                   6               7
+--R                       18044178432a b - 9025691136a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                7              6             2 5            3 4
+--R                       10407936b  - 96983040a b  + 247984128a b  + 22407168a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 1595451648a b  + 3948432768a b  - 4511044608a b
+--R                     + 
+--R                                  7
+--R                       2256422784a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                7              6             2 5            3 4
+--R                       10407936b  - 96983040a b  + 247984128a b  + 22407168a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 1595451648a b  + 3948432768a b  - 4511044608a b
+--R                     + 
+--R                                  7
+--R                       2256422784a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                            7               6             2 5            3 4
+--R                   20815872b  - 193966080a b  + 495968256a b  + 44814336a b
+--R                 + 
+--R                                4 3              5 2              6
+--R                   - 3190903296a b  + 7896865536a b  - 9022089216a b
+--R                 + 
+--R                              7
+--R                   4512845568a
+--R              *
+--R                 4+---+2
+--R                 \|392
+--R          *
+--R                         +----------------------------------------+  4
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                                   5             4            2 3            3 2
+--R                           5834752b  - 5766656a b  - 43151360a b  + 57322496a b
+--R                         + 
+--R                                    4             5
+--R                           43465856a b - 62767264a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                     5              4            2 3
+--R                           - 6630400b  + 12755456a b  + 50376704a b
+--R                         + 
+--R                                       3 2            4              5
+--R                           - 109394432a b  - 41765696a b + 126718816a
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                 5              4            2 3             3 2
+--R                       - 6630400b  + 12755456a b  + 50376704a b  - 109394432a b
+--R                     + 
+--R                                  4              5
+--R                       - 41765696a b + 126718816a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                5              4            2 3             3 2
+--R                       11669504b  - 11533312a b  - 86302720a b  + 114644992a b
+--R                     + 
+--R                                4              5
+--R                       86931712a b - 125534528a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +----------------------------------------------+2 +---------+
+--R                 4|    4          3        2 2        3         4   |  +-+
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  + 1
+--R              *
+--R                  +---------+
+--R                  |  +-+
+--R                 \|4\|2  + 2
+--R             + 
+--R                                       4          2 3            3 2
+--R                           - 2784768a b  - 602112a b  + 19869696a b
+--R                         + 
+--R                                     4             5
+--R                           - 3424512a b - 24870048a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                     5             4            2 3
+--R                           - 1856512b  - 1329664a b  + 13045760a b
+--R                         + 
+--R                                   3 2            4            5
+--R                           4340224a b  - 17721536a b - 8290016a
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                               5             4            2 3           3 2
+--R                       1856512b  + 1329664a b  - 13045760a b  - 4340224a b
+--R                     + 
+--R                                4            5
+--R                       17721536a b + 8290016a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 4           2 3            3 2           4
+--R                       5569536a b  + 1204224a b  - 39739392a b  + 6849024a b
+--R                     + 
+--R                                5
+--R                       49740096a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                       +----------------------------------------------+2
+--R                  +--+4|    4          3        2 2        3         4
+--R                 \|14 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                   5             4            2 3            3 2
+--R                           1505280b  - 4365312a b  - 40040448a b  + 77070336a b
+--R                         + 
+--R                                     4              5
+--R                           197925504a b - 339544128a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                   5             4            2 3            3 2
+--R                           1505280b  - 4365312a b  - 40040448a b  + 77070336a b
+--R                         + 
+--R                                     4              5
+--R                           197925504a b - 339544128a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                   5             4            2 3
+--R                           3010560b  - 8730624a b  - 80080896a b
+--R                         + 
+--R                                     3 2             4              5
+--R                           154140672a b  + 395851008a b - 679088256a
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                5             4            2 3            3 2
+--R                       - 752640b  + 2182656a b  + 20020224a b  - 38535168a b
+--R                     + 
+--R                                  4              5
+--R                       - 98962752a b + 169772064a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                5             4            2 3            3 2
+--R                       - 752640b  + 2182656a b  + 20020224a b  - 38535168a b
+--R                     + 
+--R                                  4              5
+--R                       - 98962752a b + 169772064a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 5             4            2 3            3 2
+--R                       - 1505280b  + 4365312a b  + 40040448a b  - 77070336a b
+--R                     + 
+--R                                   4              5
+--R                       - 197925504a b + 339544128a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +----------------------------------------------+2
+--R                 4|    4          3        2 2        3         4
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R          *
+--R                         +----------------------------------------+  2
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                                 7              6            2 5             3 4
+--R                       - 6580992b  + 20523072a b  + 13383936a b  - 107189616a b
+--R                     + 
+--R                               4 3             5 2             6              7
+--R                     151683024a b  - 235421460a b  + 370510152a b - 216572469a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               7              6           2 5             3 4
+--R                       7478400b  - 30317376a b  - 1819296a b  + 152162256a b
+--R                     + 
+--R                                   4 3             5 2             6
+--R                       - 249746376a b  + 335559060a b  - 589340310a b
+--R                     + 
+--R                                 7
+--R                       437231211a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           7              6           2 5             3 4
+--R                   7478400b  - 30317376a b  - 1819296a b  + 152162256a b
+--R                 + 
+--R                               4 3             5 2             6              7
+--R                   - 249746376a b  + 335559060a b  - 589340310a b + 437231211a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              7              6            2 5             3 4
+--R                   - 13161984b  + 41046144a b  + 26767872a b  - 214379232a b
+--R                 + 
+--R                             4 3             5 2             6              7
+--R                   303366048a b  - 470842920a b  + 741020304a b - 433144938a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                     +---------+ +---------+
+--R             4+---+2 |  +-+      |  +-+
+--R             \|392  \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                                 6           2 5            3 4            4 3
+--R                       3140928a b  - 6011712a b  - 13629168a b  + 34741728a b
+--R                     + 
+--R                                  5 2            6             7
+--R                       - 30546180a b  + 75565980a b - 85811733a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               7             6            2 5            3 4
+--R                       2093952b  - 2960832a b  - 11090016a b  + 18618096a b
+--R                     + 
+--R                                 4 3            5 2            6             7
+--R                       - 8783544a b  + 40195260a b  - 32019162a b - 28603911a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                             7             6            2 5            3 4
+--R                   - 2093952b  + 2960832a b  + 11090016a b  - 18618096a b
+--R                 + 
+--R                           4 3            5 2            6             7
+--R                   8783544a b  - 40195260a b  + 32019162a b + 28603911a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                               6            2 5            3 4            4 3
+--R                   - 6281856a b  + 12023424a b  + 27258336a b  - 69483456a b
+--R                 + 
+--R                            5 2             6              7
+--R                   61092360a b  - 151131960a b + 171623466a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                          +---------+ +---------+
+--R              +--+4+---+2 |  +-+      |  +-+
+--R             \|14 \|392  \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                               7             6            2 5             3 4
+--R                       1182720b  - 6279168a b  - 19595520a b  + 125900544a b
+--R                     + 
+--R                                  4 3             5 2              6
+--R                       - 86181312a b  - 457011072a b  + 1116315984a b
+--R                     + 
+--R                                   7
+--R                       - 812480592a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                               7             6            2 5             3 4
+--R                       1182720b  - 6279168a b  - 19595520a b  + 125900544a b
+--R                     + 
+--R                                  4 3             5 2              6
+--R                       - 86181312a b  - 457011072a b  + 1116315984a b
+--R                     + 
+--R                                   7
+--R                       - 812480592a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               7              6            2 5             3 4
+--R                       2365440b  - 12558336a b  - 39191040a b  + 251801088a b
+--R                     + 
+--R                                   4 3             5 2              6
+--R                       - 172362624a b  - 914022144a b  + 2232631968a b
+--R                     + 
+--R                                    7
+--R                       - 1624961184a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                            7             6           2 5            3 4
+--R                   - 591360b  + 3139584a b  + 9797760a b  - 62950272a b
+--R                 + 
+--R                            4 3             5 2             6              7
+--R                   43090656a b  + 228505536a b  - 558157992a b + 406240296a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            7             6           2 5            3 4
+--R                   - 591360b  + 3139584a b  + 9797760a b  - 62950272a b
+--R                 + 
+--R                            4 3             5 2             6              7
+--R                   43090656a b  + 228505536a b  - 558157992a b + 406240296a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             7             6            2 5             3 4
+--R                   - 1182720b  + 6279168a b  + 19595520a b  - 125900544a b
+--R                 + 
+--R                            4 3             5 2              6              7
+--R                   86181312a b  + 457011072a b  - 1116315984a b + 812480592a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R             4+---+2
+--R             \|392
+--R      *
+--R                     +----------------------------------------+  4
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                                3              2            2            3  4
+--R                       (1419264b  - 10698240a b  + 17332224a b - 7835520a )x
+--R                     + 
+--R                                3              2            2             3  2
+--R                     (- 1612800b  + 13665792a b  - 29250816a b + 15818880a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              3              2            2             3  4
+--R                   (- 1612800b  + 13665792a b  - 29250816a b + 15818880a )x
+--R                 + 
+--R                            3              2            2             3  2
+--R                   (2838528b  - 21396480a b  + 34664448a b - 15671040a )x
+--R              *
+--R                      +----------------------------------------+
+--R                  +-+ |   4        3       2 2       3        4
+--R                 \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +----------------------------------------------+2 +---------+
+--R                 4|    4          3        2 2        3         4   |  +-+
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  + 1
+--R              *
+--R                  +---------+
+--R                  |  +-+
+--R                 \|4\|2  + 2
+--R             + 
+--R                                   2           2            3  4
+--R                       (- 677376a b  + 4290048a b - 3104640a )x
+--R                     + 
+--R                                 3             2          2            3  2
+--R                       (- 451584b  + 2634240a b  - 639744a b - 1034880a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           3             2          2            3  4
+--R                   (451584b  - 2634240a b  + 639744a b + 1034880a )x
+--R                 + 
+--R                              2           2            3  2
+--R                   (1354752a b  - 8580096a b + 6209280a )x
+--R              *
+--R                           +----------------------------------------+
+--R                  +-+ +--+ |   4        3       2 2       3        4
+--R                 \|7 \|14 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +----------------------------------------------+2 +---------+
+--R                 4|    4          3        2 2        3         4   |  +-+
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  - 1
+--R              *
+--R                  +---------+
+--R                  |  +-+
+--R                 \|2\|2  + 1
+--R             + 
+--R                                3              2            2             3  6
+--R                       (3741696b  - 19891200a b  + 49943040a b - 29971200a )x
+--R                     + 
+--R                                3              2            2             3  4
+--R                       (3741696b  - 19891200a b  + 49943040a b - 29971200a )x
+--R                     + 
+--R                                3              2            2             3  2
+--R                       (7483392b  - 39782400a b  + 99886080a b - 59942400a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              3             2            2             3  6
+--R                   (- 1870848b  + 9945600a b  - 24971520a b + 14985600a )x
+--R                 + 
+--R                              3             2            2             3  4
+--R                   (- 1870848b  + 9945600a b  - 24971520a b + 14985600a )x
+--R                 + 
+--R                              3              2            2             3  2
+--R                   (- 3741696b  + 19891200a b  - 49943040a b + 29971200a )x
+--R              *
+--R                      +----------------------------------------+
+--R                  +-+ |   4        3       2 2       3        4
+--R                 \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +----------------------------------------------+2
+--R                 4|    4          3        2 2        3         4
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R          *
+--R                         +----------------------------------------+  3
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                                    5             4            2 3          3 2
+--R                           - 937728b  + 7803456a b  - 15021312a b  - 700704a b
+--R                         + 
+--R                                    4             5
+--R                           20006256a b - 10878780a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                   5             4            2 3           3 2
+--R                           1065600b  - 9864384a b  + 24164160a b  - 6626016a b
+--R                         + 
+--R                                      4             5
+--R                           - 32419704a b + 21962820a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                               5             4            2 3           3 2
+--R                       1065600b  - 9864384a b  + 24164160a b  - 6626016a b
+--R                     + 
+--R                                  4             5
+--R                       - 32419704a b + 21962820a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                 5              4            2 3           3 2
+--R                       - 1875456b  + 15606912a b  - 30042624a b  - 1401408a b
+--R                     + 
+--R                                4             5
+--R                       40012512a b - 21757560a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                             +----------------------------------------+
+--R                  +-+4+---+2 |   4        3       2 2       3        4
+--R                 \|7 \|392  \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                                    4           2 3           3 2           4
+--R                           447552a b  - 3185280a b  + 3332448a b  + 4348512a b
+--R                         + 
+--R                                     5
+--R                           - 4310460a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                  5             4           2 3           3 2
+--R                           298368b  - 1974336a b  + 1159872a b  + 4009824a b
+--R                         + 
+--R                                     4            5
+--R                           - 1424136a b - 1436820a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                5             4           2 3           3 2
+--R                       - 298368b  + 1974336a b  - 1159872a b  - 4009824a b
+--R                     + 
+--R                               4            5
+--R                       1424136a b + 1436820a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                  4           2 3           3 2           4
+--R                       - 895104a b  + 6370560a b  - 6664896a b  - 8697024a b
+--R                     + 
+--R                               5
+--R                       8620920a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                                  +----------------------------------------+
+--R                  +-+ +--+4+---+2 |   4        3       2 2       3        4
+--R                 \|7 \|14 \|392  \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                     5             4            2 3
+--R                           - 1520640b  + 2497536a b  + 14879232a b
+--R                         + 
+--R                                      3 2            4             5
+--R                           - 56014848a b  + 80323776a b - 37241280a
+--R                      *
+--R                          8
+--R                         x
+--R                     + 
+--R                                     5             4            2 3
+--R                           - 1520640b  + 2497536a b  + 14879232a b
+--R                         + 
+--R                                      3 2            4             5
+--R                           - 56014848a b  + 80323776a b - 37241280a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                     5             4            2 3
+--R                           - 3041280b  + 4995072a b  + 29758464a b
+--R                         + 
+--R                                       3 2             4             5
+--R                           - 112029696a b  + 160647552a b - 74482560a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              5             4           2 3            3 2
+--R                       760320b  - 1248768a b  - 7439616a b  + 28007424a b
+--R                     + 
+--R                                  4             5
+--R                       - 40161888a b + 18620640a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                              5             4           2 3            3 2
+--R                       760320b  - 1248768a b  - 7439616a b  + 28007424a b
+--R                     + 
+--R                                  4             5
+--R                       - 40161888a b + 18620640a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               5             4            2 3            3 2
+--R                       1520640b  - 2497536a b  - 14879232a b  + 56014848a b
+--R                     + 
+--R                                  4             5
+--R                       - 80323776a b + 37241280a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                             +----------------------------------------+
+--R                  +-+4+---+2 |   4        3       2 2       3        4
+--R                 \|7 \|392  \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R          *
+--R                         +----------------------------------------+
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R      *
+--R                     +----------------------------------------+  3
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                                      7              6            2 5
+--R                           - 10903552b  + 54765568a b  - 80965632a b
+--R                         + 
+--R                                       3 4             4 3              5 2
+--R                           - 155852800a b  + 842510848a b  - 1515951744a b
+--R                         + 
+--R                                      6              7
+--R                           1370667776a b - 517707392a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                                7              6             2 5             3 4
+--R                       12390400b  - 73824256a b  + 136261632a b  + 144345088a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 1162534144a b  + 2371180416a b  - 2387901440a b
+--R                     + 
+--R                                  7
+--R                       1045182848a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                7              6             2 5             3 4
+--R                       12390400b  - 73824256a b  + 136261632a b  + 144345088a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 1162534144a b  + 2371180416a b  - 2387901440a b
+--R                     + 
+--R                                  7
+--R                       1045182848a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                              7               6             2 5             3 4
+--R                   - 21807104b  + 109531136a b  - 161931264a b  - 311705600a b
+--R                 + 
+--R                            4 3              5 2              6               7
+--R                 1685021696a b  - 3031903488a b  + 2741335552a b - 1035414784a
+--R              *
+--R                         +---------+ +---------+
+--R                 4+---+2 |  +-+      |  +-+
+--R                 \|392  \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                                     6            2 5            3 4
+--R                           5203968a b  - 19869696a b  + 14708736a b
+--R                         + 
+--R                                    4 3             5 2             6
+--R                           92101632a b  - 291166848a b  + 372798720a b
+--R                         + 
+--R                                       7
+--R                           - 205129344a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                               7              6           2 5            3 4
+--R                       3469312b  - 11511808a b  + 3182592a b  + 66304000a b
+--R                     + 
+--R                                 4 3             5 2            6             7
+--R                     - 163410688a b  + 151476864a b  - 12486656a b - 68376448a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                 7              6           2 5            3 4
+--R                       - 3469312b  + 11511808a b  - 3182592a b  - 66304000a b
+--R                     + 
+--R                                 4 3             5 2            6             7
+--R                       163410688a b  - 151476864a b  + 12486656a b + 68376448a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                                6            2 5            3 4             4 3
+--R                   - 10407936a b  + 39739392a b  - 29417472a b  - 184203264a b
+--R                 + 
+--R                             5 2             6              7
+--R                   582333696a b  - 745597440a b + 410258688a
+--R              *
+--R                              +---------+ +---------+
+--R                  +--+4+---+2 |  +-+      |  +-+
+--R                 \|14 \|392  \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                      7               6             2 5
+--R                           - 13877248b  + 129310720a b  - 330645504a b
+--R                         + 
+--R                                      3 4              4 3              5 2
+--R                           - 29876224a b  + 2127268864a b  - 5264577024a b
+--R                         + 
+--R                                      6               7
+--R                           6014726144a b - 3008563712a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                      7               6             2 5
+--R                           - 13877248b  + 129310720a b  - 330645504a b
+--R                         + 
+--R                                      3 4              4 3              5 2
+--R                           - 29876224a b  + 2127268864a b  - 5264577024a b
+--R                         + 
+--R                                      6               7
+--R                           6014726144a b - 3008563712a
+--R                      *
+--R                          2
+--R                         x
+--R                     + 
+--R                                  7               6             2 5
+--R                       - 27754496b  + 258621440a b  - 661291008a b
+--R                     + 
+--R                                  3 4              4 3               5 2
+--R                       - 59752448a b  + 4254537728a b  - 10529154048a b
+--R                     + 
+--R                                   6               7
+--R                       12029452288a b - 6017127424a
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                               7              6             2 5            3 4
+--R                       6938624b  - 64655360a b  + 165322752a b  + 14938112a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 1063634432a b  + 2632288512a b  - 3007363072a b
+--R                     + 
+--R                                  7
+--R                       1504281856a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                               7              6             2 5            3 4
+--R                       6938624b  - 64655360a b  + 165322752a b  + 14938112a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 1063634432a b  + 2632288512a b  - 3007363072a b
+--R                     + 
+--R                                  7
+--R                       1504281856a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                            7               6             2 5            3 4
+--R                   13877248b  - 129310720a b  + 330645504a b  + 29876224a b
+--R                 + 
+--R                                4 3              5 2              6
+--R                   - 2127268864a b  + 5264577024a b  - 6014726144a b
+--R                 + 
+--R                              7
+--R                   3008563712a
+--R              *
+--R                 4+---+2
+--R                 \|392
+--R          *
+--R                         +----------------------------------------+  6
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                                     5             4            2 3
+--R                           - 5834752b  + 5766656a b  + 43151360a b
+--R                         + 
+--R                                      3 2            4             5
+--R                           - 57322496a b  - 43465856a b + 62767264a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                   5              4            2 3
+--R                           6630400b  - 12755456a b  - 50376704a b
+--R                         + 
+--R                                     3 2            4              5
+--R                           109394432a b  + 41765696a b - 126718816a
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                               5              4            2 3             3 2
+--R                       6630400b  - 12755456a b  - 50376704a b  + 109394432a b
+--R                     + 
+--R                                4              5
+--R                       41765696a b - 126718816a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                  5              4            2 3
+--R                       - 11669504b  + 11533312a b  + 86302720a b
+--R                     + 
+--R                                   3 2            4              5
+--R                       - 114644992a b  - 86931712a b + 125534528a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +----------------------------------------------+2 +---------+
+--R                 4|    4          3        2 2        3         4   |  +-+
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  + 1
+--R              *
+--R                  +---------+
+--R                  |  +-+
+--R                 \|4\|2  + 2
+--R             + 
+--R                                     4          2 3            3 2           4
+--R                           2784768a b  + 602112a b  - 19869696a b  + 3424512a b
+--R                         + 
+--R                                    5
+--R                           24870048a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                   5             4            2 3           3 2
+--R                           1856512b  + 1329664a b  - 13045760a b  - 4340224a b
+--R                         + 
+--R                                    4            5
+--R                           17721536a b + 8290016a
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                 5             4            2 3           3 2
+--R                       - 1856512b  - 1329664a b  + 13045760a b  + 4340224a b
+--R                     + 
+--R                                  4            5
+--R                       - 17721536a b - 8290016a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                   4           2 3            3 2           4
+--R                       - 5569536a b  - 1204224a b  + 39739392a b  - 6849024a b
+--R                     + 
+--R                                  5
+--R                       - 49740096a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                       +----------------------------------------------+2
+--R                  +--+4|    4          3        2 2        3         4
+--R                 \|14 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                     5             4            2 3
+--R                           - 1505280b  + 4365312a b  + 40040448a b
+--R                         + 
+--R                                      3 2             4              5
+--R                           - 77070336a b  - 197925504a b + 339544128a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                     5             4            2 3
+--R                           - 1505280b  + 4365312a b  + 40040448a b
+--R                         + 
+--R                                      3 2             4              5
+--R                           - 77070336a b  - 197925504a b + 339544128a
+--R                      *
+--R                          4
+--R                         x
+--R                     + 
+--R                                     5             4            2 3
+--R                           - 3010560b  + 8730624a b  + 80080896a b
+--R                         + 
+--R                                       3 2             4              5
+--R                           - 154140672a b  - 395851008a b + 679088256a
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              5             4            2 3            3 2
+--R                       752640b  - 2182656a b  - 20020224a b  + 38535168a b
+--R                     + 
+--R                                4              5
+--R                       98962752a b - 169772064a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                              5             4            2 3            3 2
+--R                       752640b  - 2182656a b  - 20020224a b  + 38535168a b
+--R                     + 
+--R                                4              5
+--R                       98962752a b - 169772064a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                               5             4            2 3            3 2
+--R                       1505280b  - 4365312a b  - 40040448a b  + 77070336a b
+--R                     + 
+--R                                 4              5
+--R                       197925504a b - 339544128a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +----------------------------------------------+2
+--R                 4|    4          3        2 2        3         4
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R          *
+--R                         +----------------------------------------+  4
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                                     7              6             2 5
+--R                           - 4128256b  + 95923840a b  - 404166144a b
+--R                         + 
+--R                                    3 4              4 3              5 2
+--R                           19726496a b  + 2459945248a b  - 4651278216a b
+--R                         + 
+--R                                      6              7
+--R                           3259610192a b - 771394754a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                   7               6             2 5
+--R                           4691200b  - 113392768a b  + 555962304a b
+--R                         + 
+--R                                       3 4              4 3              5 2
+--R                           - 335593184a b  - 3151658320a b  + 7471367304a b
+--R                         + 
+--R                                        6               7
+--R                           - 6015563900a b + 1557344126a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                               7               6             2 5             3 4
+--R                       4691200b  - 113392768a b  + 555962304a b  - 335593184a b
+--R                     + 
+--R                                    4 3              5 2              6
+--R                       - 3151658320a b  + 7471367304a b  - 6015563900a b
+--R                     + 
+--R                                  7
+--R                       1557344126a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                 7               6             2 5
+--R                       - 8256512b  + 191847680a b  - 808332288a b
+--R                     + 
+--R                                3 4              4 3              5 2
+--R                       39452992a b  + 4919890496a b  - 9302556432a b
+--R                     + 
+--R                                  6               7
+--R                       6519220384a b - 1542789508a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                         +---------+ +---------+
+--R                 4+---+2 |  +-+      |  +-+
+--R                 \|392  \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                                     6            2 5             3 4
+--R                           1970304a b  - 43408512a b  + 140609952a b
+--R                         + 
+--R                                     4 3             5 2              6
+--R                           159956160a b  - 981390312a b  + 1037799000a b
+--R                         + 
+--R                                       7
+--R                           - 305646978a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                   7              6            2 5
+--R                           1313536b  - 28282240a b  + 79270464a b
+--R                         + 
+--R                                     3 4             4 3             5 2
+--R                           153507424a b  - 600941488a b  + 364735896a b
+--R                         + 
+--R                                     6              7
+--R                           142168348a b - 101882326a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                 7              6            2 5             3 4
+--R                       - 1313536b  + 28282240a b  - 79270464a b  - 153507424a b
+--R                     + 
+--R                               4 3             5 2             6              7
+--R                     600941488a b  - 364735896a b  - 142168348a b + 101882326a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                   6            2 5             3 4
+--R                       - 3940608a b  + 86817024a b  - 281219904a b
+--R                     + 
+--R                                   4 3              5 2              6
+--R                       - 319912320a b  + 1962780624a b  - 2075598000a b
+--R                     + 
+--R                                 7
+--R                       611293956a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                              +---------+ +---------+
+--R                  +--+4+---+2 |  +-+      |  +-+
+--R                 \|14 \|392  \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                      7               6             2 5
+--R                           - 34850816b  + 296296448a b  - 543717888a b
+--R                         + 
+--R                                       3 4              4 3              5 2
+--R                           - 815155712a b  + 4771625600a b  - 7787087616a b
+--R                         + 
+--R                                      6               7
+--R                           5331556384a b - 1142243872a
+--R                      *
+--R                          8
+--R                         x
+--R                     + 
+--R                                      7               6             2 5
+--R                           - 34850816b  + 296296448a b  - 543717888a b
+--R                         + 
+--R                                       3 4              4 3              5 2
+--R                           - 815155712a b  + 4771625600a b  - 7787087616a b
+--R                         + 
+--R                                      6               7
+--R                           5331556384a b - 1142243872a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                      7               6              2 5
+--R                           - 69701632b  + 592592896a b  - 1087435776a b
+--R                         + 
+--R                                        3 4              4 3               5 2
+--R                           - 1630311424a b  + 9543251200a b  - 15574175232a b
+--R                         + 
+--R                                       6               7
+--R                           10663112768a b - 2284487744a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                7               6             2 5
+--R                       17425408b  - 148148224a b  + 271858944a b
+--R                     + 
+--R                                 3 4              4 3              5 2
+--R                       407577856a b  - 2385812800a b  + 3893543808a b
+--R                     + 
+--R                                    6              7
+--R                       - 2665778192a b + 571121936a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                7               6             2 5
+--R                       17425408b  - 148148224a b  + 271858944a b
+--R                     + 
+--R                                 3 4              4 3              5 2
+--R                       407577856a b  - 2385812800a b  + 3893543808a b
+--R                     + 
+--R                                    6              7
+--R                       - 2665778192a b + 571121936a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                7               6             2 5
+--R                       34850816b  - 296296448a b  + 543717888a b
+--R                     + 
+--R                                 3 4              4 3              5 2
+--R                       815155712a b  - 4771625600a b  + 7787087616a b
+--R                     + 
+--R                                    6               7
+--R                       - 5331556384a b + 1142243872a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                 4+---+2
+--R                 \|392
+--R          *
+--R                         +----------------------------------------+  2
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                               5             4            2 3            3 2
+--R                       2917376b  - 2883328a b  - 21575680a b  + 28661248a b
+--R                     + 
+--R                                4             5
+--R                       21732928a b - 31383632a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                 5             4            2 3            3 2
+--R                       - 3315200b  + 6377728a b  + 25188352a b  - 54697216a b
+--R                     + 
+--R                                  4             5
+--R                       - 20882848a b + 63359408a
+--R                  *
+--R                      6
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                             5             4            2 3            3 2
+--R                   - 3315200b  + 6377728a b  + 25188352a b  - 54697216a b
+--R                 + 
+--R                              4             5
+--R                   - 20882848a b + 63359408a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           5             4            2 3            3 2
+--R                   5834752b  - 5766656a b  - 43151360a b  + 57322496a b
+--R                 + 
+--R                            4             5
+--R                   43465856a b - 62767264a
+--R              *
+--R                  6
+--R                 x
+--R          *
+--R              +----------------------------------------------+2 +---------+
+--R             4|    4          3        2 2        3         4   |  +-+
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  + 1
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|4\|2  + 2
+--R         + 
+--R                                   4          2 3           3 2           4
+--R                       - 1392384a b  - 301056a b  + 9934848a b  - 1712256a b
+--R                     + 
+--R                                  5
+--R                       - 12435024a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                5            4           2 3           3 2
+--R                       - 928256b  - 664832a b  + 6522880a b  + 2170112a b
+--R                     + 
+--R                                 4            5
+--R                       - 8860768a b - 4145008a
+--R                  *
+--R                      6
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                          5            4           2 3           3 2
+--R                   928256b  + 664832a b  - 6522880a b  - 2170112a b
+--R                 + 
+--R                           4            5
+--R                   8860768a b + 4145008a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             4          2 3            3 2           4
+--R                   2784768a b  + 602112a b  - 19869696a b  + 3424512a b
+--R                 + 
+--R                            5
+--R                   24870048a
+--R              *
+--R                  6
+--R                 x
+--R          *
+--R                   +----------------------------------------------+2 +---------+
+--R              +--+4|    4          3        2 2        3         4   |  +-+
+--R             \|14 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  - 1
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|2  + 1
+--R         + 
+--R                                 5             4           2 3            3 2
+--R                       - 1103872b  + 7626752a b  - 4566016a b  - 36603392a b
+--R                     + 
+--R                                4             5
+--R                       94939264a b - 78581888a
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                 5             4           2 3            3 2
+--R                       - 1103872b  + 7626752a b  - 4566016a b  - 36603392a b
+--R                     + 
+--R                                4             5
+--R                       94939264a b - 78581888a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                 5              4           2 3            3 2
+--R                       - 2207744b  + 15253504a b  - 9132032a b  - 73206784a b
+--R                     + 
+--R                                 4              5
+--R                       189878528a b - 157163776a
+--R                  *
+--R                      6
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                          5             4           2 3            3 2
+--R                   551936b  - 3813376a b  + 2283008a b  + 18301696a b
+--R                 + 
+--R                              4             5
+--R                   - 47469632a b + 39290944a
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                          5             4           2 3            3 2
+--R                   551936b  - 3813376a b  + 2283008a b  + 18301696a b
+--R                 + 
+--R                              4             5
+--R                   - 47469632a b + 39290944a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           5             4           2 3            3 2
+--R                   1103872b  - 7626752a b  + 4566016a b  + 36603392a b
+--R                 + 
+--R                              4             5
+--R                   - 94939264a b + 78581888a
+--R              *
+--R                  6
+--R                 x
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+  2
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                               3             2           2            3  4
+--R                       (709632b  - 5349120a b  + 8666112a b - 3917760a )x
+--R                     + 
+--R                                 3             2            2            3  2
+--R                       (- 806400b  + 6832896a b  - 14625408a b + 7909440a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                             3             2            2            3  4
+--R                   (- 806400b  + 6832896a b  - 14625408a b + 7909440a )x
+--R                 + 
+--R                            3              2            2            3  2
+--R                   (1419264b  - 10698240a b  + 17332224a b - 7835520a )x
+--R              *
+--R                      +----------------------------------------+
+--R                  +-+ |   4        3       2 2       3        4
+--R                 \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +----------------------------------------------+2 +---------+
+--R                 4|    4          3        2 2        3         4   |  +-+
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  + 1
+--R              *
+--R                  +---------+
+--R                  |  +-+
+--R                 \|4\|2  + 2
+--R             + 
+--R                                   2           2            3  4
+--R                       (- 338688a b  + 2145024a b - 1552320a )x
+--R                     + 
+--R                                 3             2          2           3  2
+--R                       (- 225792b  + 1317120a b  - 319872a b - 517440a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           3             2          2           3  4
+--R                   (225792b  - 1317120a b  + 319872a b + 517440a )x
+--R                 + 
+--R                             2           2            3  2
+--R                   (677376a b  - 4290048a b + 3104640a )x
+--R              *
+--R                           +----------------------------------------+
+--R                  +-+ +--+ |   4        3       2 2       3        4
+--R                 \|7 \|14 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +----------------------------------------------+2 +---------+
+--R                 4|    4          3        2 2        3         4   |  +-+
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  - 1
+--R              *
+--R                  +---------+
+--R                  |  +-+
+--R                 \|2\|2  + 1
+--R             + 
+--R                                3             2            2             3  6
+--R                       (1870848b  - 9945600a b  + 24971520a b - 14985600a )x
+--R                     + 
+--R                                3             2            2             3  4
+--R                       (1870848b  - 9945600a b  + 24971520a b - 14985600a )x
+--R                     + 
+--R                                3              2            2             3  2
+--R                       (3741696b  - 19891200a b  + 49943040a b - 29971200a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                             3             2            2            3  6
+--R                   (- 935424b  + 4972800a b  - 12485760a b + 7492800a )x
+--R                 + 
+--R                             3             2            2            3  4
+--R                   (- 935424b  + 4972800a b  - 12485760a b + 7492800a )x
+--R                 + 
+--R                              3             2            2             3  2
+--R                   (- 1870848b  + 9945600a b  - 24971520a b + 14985600a )x
+--R              *
+--R                      +----------------------------------------+
+--R                  +-+ |   4        3       2 2       3        4
+--R                 \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +----------------------------------------------+2
+--R                 4|    4          3        2 2        3         4
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R          *
+--R                         +----------------------------------------+  5
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                                  5             4            2 3          3 2
+--R                           937728b  - 7803456a b  + 15021312a b  + 700704a b
+--R                         + 
+--R                                      4             5
+--R                           - 20006256a b + 10878780a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                     5             4            2 3
+--R                           - 1065600b  + 9864384a b  - 24164160a b
+--R                         + 
+--R                                   3 2            4             5
+--R                           6626016a b  + 32419704a b - 21962820a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                 5             4            2 3           3 2
+--R                       - 1065600b  + 9864384a b  - 24164160a b  + 6626016a b
+--R                     + 
+--R                                4             5
+--R                       32419704a b - 21962820a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               5              4            2 3           3 2
+--R                       1875456b  - 15606912a b  + 30042624a b  + 1401408a b
+--R                     + 
+--R                                  4             5
+--R                       - 40012512a b + 21757560a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                             +----------------------------------------+
+--R                  +-+4+---+2 |   4        3       2 2       3        4
+--R                 \|7 \|392  \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  + 1 \|4\|2  + 2
+--R             + 
+--R                                      4           2 3           3 2           4
+--R                           - 447552a b  + 3185280a b  - 3332448a b  - 4348512a b
+--R                         + 
+--R                                   5
+--R                           4310460a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                    5             4           2 3           3 2
+--R                           - 298368b  + 1974336a b  - 1159872a b  - 4009824a b
+--R                         + 
+--R                                   4            5
+--R                           1424136a b + 1436820a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                              5             4           2 3           3 2
+--R                       298368b  - 1974336a b  + 1159872a b  + 4009824a b
+--R                     + 
+--R                                 4            5
+--R                       - 1424136a b - 1436820a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                4           2 3           3 2           4
+--R                       895104a b  - 6370560a b  + 6664896a b  + 8697024a b
+--R                     + 
+--R                                 5
+--R                       - 8620920a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                                  +----------------------------------------+
+--R                  +-+ +--+4+---+2 |   4        3       2 2       3        4
+--R                 \|7 \|14 \|392  \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +---------+ +---------+
+--R                  |  +-+      |  +-+
+--R                 \|2\|2  - 1 \|2\|2  + 1
+--R             + 
+--R                                   5             4            2 3            3 2
+--R                           1520640b  - 2497536a b  - 14879232a b  + 56014848a b
+--R                         + 
+--R                                      4             5
+--R                           - 80323776a b + 37241280a
+--R                      *
+--R                          8
+--R                         x
+--R                     + 
+--R                                   5             4            2 3            3 2
+--R                           1520640b  - 2497536a b  - 14879232a b  + 56014848a b
+--R                         + 
+--R                                      4             5
+--R                           - 80323776a b + 37241280a
+--R                      *
+--R                          6
+--R                         x
+--R                     + 
+--R                                   5             4            2 3
+--R                           3041280b  - 4995072a b  - 29758464a b
+--R                         + 
+--R                                     3 2             4             5
+--R                           112029696a b  - 160647552a b + 74482560a
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                                5             4           2 3            3 2
+--R                       - 760320b  + 1248768a b  + 7439616a b  - 28007424a b
+--R                     + 
+--R                                4             5
+--R                       40161888a b - 18620640a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                5             4           2 3            3 2
+--R                       - 760320b  + 1248768a b  + 7439616a b  - 28007424a b
+--R                     + 
+--R                                4             5
+--R                       40161888a b - 18620640a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                 5             4            2 3            3 2
+--R                       - 1520640b  + 2497536a b  + 14879232a b  - 56014848a b
+--R                     + 
+--R                                4             5
+--R                       80323776a b - 37241280a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                             +----------------------------------------+
+--R                  +-+4+---+2 |   4        3       2 2       3        4
+--R                 \|7 \|392  \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R          *
+--R                         +----------------------------------------+  3
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                               3             2           2            3  8
+--R                       (354816b  - 2674560a b  + 4333056a b - 1958880a )x
+--R                     + 
+--R                                 3             2           2            3  6
+--R                       (- 403200b  + 3416448a b  - 7312704a b + 3954720a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                             3             2           2            3  8
+--R                   (- 403200b  + 3416448a b  - 7312704a b + 3954720a )x
+--R                 + 
+--R                           3             2           2            3  6
+--R                   (709632b  - 5349120a b  + 8666112a b - 3917760a )x
+--R              *
+--R                      +----------------------------------------+
+--R                  +-+ |   4        3       2 2       3        4
+--R                 \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +----------------------------------------------+2 +---------+
+--R                 4|    4          3        2 2        3         4   |  +-+
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  + 1
+--R              *
+--R                  +---------+
+--R                  |  +-+
+--R                 \|4\|2  + 2
+--R             + 
+--R                                   2           2           3  8
+--R                       (- 169344a b  + 1072512a b - 776160a )x
+--R                     + 
+--R                                 3            2          2           3  6
+--R                       (- 112896b  + 658560a b  - 159936a b - 258720a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                           3            2          2           3  8
+--R                   (112896b  - 658560a b  + 159936a b + 258720a )x
+--R                 + 
+--R                             2           2            3  6
+--R                   (338688a b  - 2145024a b + 1552320a )x
+--R              *
+--R                           +----------------------------------------+
+--R                  +-+ +--+ |   4        3       2 2       3        4
+--R                 \|7 \|14 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +----------------------------------------------+2 +---------+
+--R                 4|    4          3        2 2        3         4   |  +-+
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  - 1
+--R              *
+--R                  +---------+
+--R                  |  +-+
+--R                 \|2\|2  + 1
+--R             + 
+--R                               3             2           2            3  10
+--R                       (709632b  - 2300928a b  + 3585792a b - 1800960a )x
+--R                     + 
+--R                               3             2           2            3  8
+--R                       (709632b  - 2300928a b  + 3585792a b - 1800960a )x
+--R                     + 
+--R                                3             2           2            3  6
+--R                       (1419264b  - 4601856a b  + 7171584a b - 3601920a )x
+--R                  *
+--R                      +-+
+--R                     \|2
+--R                 + 
+--R                             3             2           2           3  10
+--R                   (- 354816b  + 1150464a b  - 1792896a b + 900480a )x
+--R                 + 
+--R                             3             2           2           3  8
+--R                   (- 354816b  + 1150464a b  - 1792896a b + 900480a )x
+--R                 + 
+--R                             3             2           2            3  6
+--R                   (- 709632b  + 2300928a b  - 3585792a b + 1800960a )x
+--R              *
+--R                      +----------------------------------------+
+--R                  +-+ |   4        3       2 2       3        4
+--R                 \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R              *
+--R                  +----------------------------------------------+2
+--R                 4|    4          3        2 2        3         4
+--R                 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R          *
+--R                         +----------------------------------------+
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R      *
+--R                     +----------------------------------------+
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                                 7              6            2 5            3 4
+--R                       - 2725888b  + 13691392a b  - 20241408a b  - 38963200a b
+--R                     + 
+--R                               4 3             5 2             6              7
+--R                     210627712a b  - 378987936a b  + 342666944a b - 129426848a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                           7              6            2 5            3 4
+--R                   3097600b  - 18456064a b  + 34065408a b  + 36086272a b
+--R                 + 
+--R                               4 3             5 2             6              7
+--R                   - 290633536a b  + 592795104a b  - 596975360a b + 261295712a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           7              6            2 5            3 4
+--R                   3097600b  - 18456064a b  + 34065408a b  + 36086272a b
+--R                 + 
+--R                               4 3             5 2             6              7
+--R                   - 290633536a b  + 592795104a b  - 596975360a b + 261295712a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         7              6            2 5            3 4
+--R               - 5451776b  + 27382784a b  - 40482816a b  - 77926400a b
+--R             + 
+--R                         4 3             5 2             6              7
+--R               421255424a b  - 757975872a b  + 685333888a b - 258853696a
+--R          *
+--R                     +---------+ +---------+
+--R             4+---+2 |  +-+      |  +-+
+--R             \|392  \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                                 6           2 5           3 4            4 3
+--R                       1300992a b  - 4967424a b  + 3677184a b  + 23025408a b
+--R                     + 
+--R                                  5 2            6             7
+--R                       - 72791712a b  + 93199680a b - 51282336a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                          7             6          2 5            3 4
+--R                   867328b  - 2877952a b  + 795648a b  + 16576000a b
+--R                 + 
+--R                              4 3            5 2           6             7
+--R                   - 40852672a b  + 37869216a b  - 3121664a b - 17094112a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                            7             6          2 5            3 4
+--R                   - 867328b  + 2877952a b  - 795648a b  - 16576000a b
+--R                 + 
+--R                            4 3            5 2           6             7
+--R                   40852672a b  - 37869216a b  + 3121664a b + 17094112a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           6           2 5           3 4            4 3
+--R               - 2601984a b  + 9934848a b  - 7354368a b  - 46050816a b
+--R             + 
+--R                         5 2             6              7
+--R               145583424a b  - 186399360a b + 102564672a
+--R          *
+--R                          +---------+ +---------+
+--R              +--+4+---+2 |  +-+      |  +-+
+--R             \|14 \|392  \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                                 7              6            2 5           3 4
+--R                       - 3469312b  + 32327680a b  - 82661376a b  - 7469056a b
+--R                     + 
+--R                                 4 3              5 2              6
+--R                       531817216a b  - 1316144256a b  + 1503681536a b
+--R                     + 
+--R                                   7
+--R                       - 752140928a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 7              6            2 5           3 4
+--R                       - 3469312b  + 32327680a b  - 82661376a b  - 7469056a b
+--R                     + 
+--R                                 4 3              5 2              6
+--R                       531817216a b  - 1316144256a b  + 1503681536a b
+--R                     + 
+--R                                   7
+--R                       - 752140928a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                             7              6             2 5            3 4
+--R                   - 6938624b  + 64655360a b  - 165322752a b  - 14938112a b
+--R                 + 
+--R                            4 3              5 2              6               7
+--R                 1063634432a b  - 2632288512a b  + 3007363072a b - 1504281856a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           7              6            2 5           3 4
+--R                   1734656b  - 16163840a b  + 41330688a b  + 3734528a b
+--R                 + 
+--R                               4 3             5 2             6              7
+--R                   - 265908608a b  + 658072128a b  - 751840768a b + 376070464a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           7              6            2 5           3 4
+--R                   1734656b  - 16163840a b  + 41330688a b  + 3734528a b
+--R                 + 
+--R                               4 3             5 2             6              7
+--R                   - 265908608a b  + 658072128a b  - 751840768a b + 376070464a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                       7              6            2 5           3 4
+--R               3469312b  - 32327680a b  + 82661376a b  + 7469056a b
+--R             + 
+--R                           4 3              5 2              6              7
+--R               - 531817216a b  + 1316144256a b  - 1503681536a b + 752140928a
+--R          *
+--R             4+---+2
+--R             \|392
+--R      *
+--R                     +----------------------------------------+  8
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                                 5             4            2 3            3 2
+--R                       - 5834752b  + 5766656a b  + 43151360a b  - 57322496a b
+--R                     + 
+--R                                  4             5
+--R                       - 43465856a b + 62767264a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                               5              4            2 3             3 2
+--R                       6630400b  - 12755456a b  - 50376704a b  + 109394432a b
+--R                     + 
+--R                                4              5
+--R                       41765696a b - 126718816a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           5              4            2 3             3 2
+--R                   6630400b  - 12755456a b  - 50376704a b  + 109394432a b
+--R                 + 
+--R                            4              5
+--R                   41765696a b - 126718816a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              5              4            2 3             3 2
+--R                   - 11669504b  + 11533312a b  + 86302720a b  - 114644992a b
+--R                 + 
+--R                              4              5
+--R                   - 86931712a b + 125534528a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R              +----------------------------------------------+2 +---------+
+--R             4|    4          3        2 2        3         4   |  +-+
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  + 1
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|4\|2  + 2
+--R         + 
+--R                                 4          2 3            3 2           4
+--R                       2784768a b  + 602112a b  - 19869696a b  + 3424512a b
+--R                     + 
+--R                                5
+--R                       24870048a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                               5             4            2 3           3 2
+--R                       1856512b  + 1329664a b  - 13045760a b  - 4340224a b
+--R                     + 
+--R                                4            5
+--R                       17721536a b + 8290016a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                             5             4            2 3           3 2
+--R                   - 1856512b  - 1329664a b  + 13045760a b  + 4340224a b
+--R                 + 
+--R                              4            5
+--R                   - 17721536a b - 8290016a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               4           2 3            3 2           4
+--R                   - 5569536a b  - 1204224a b  + 39739392a b  - 6849024a b
+--R                 + 
+--R                              5
+--R                   - 49740096a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R                   +----------------------------------------------+2 +---------+
+--R              +--+4|    4          3        2 2        3         4   |  +-+
+--R             \|14 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  - 1
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|2  + 1
+--R         + 
+--R                                 5             4            2 3            3 2
+--R                       - 1505280b  + 4365312a b  + 40040448a b  - 77070336a b
+--R                     + 
+--R                                   4              5
+--R                       - 197925504a b + 339544128a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                 5             4            2 3            3 2
+--R                       - 1505280b  + 4365312a b  + 40040448a b  - 77070336a b
+--R                     + 
+--R                                   4              5
+--R                       - 197925504a b + 339544128a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 5             4            2 3             3 2
+--R                       - 3010560b  + 8730624a b  + 80080896a b  - 154140672a b
+--R                     + 
+--R                                   4              5
+--R                       - 395851008a b + 679088256a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                          5             4            2 3            3 2
+--R                   752640b  - 2182656a b  - 20020224a b  + 38535168a b
+--R                 + 
+--R                            4              5
+--R                   98962752a b - 169772064a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          5             4            2 3            3 2
+--R                   752640b  - 2182656a b  - 20020224a b  + 38535168a b
+--R                 + 
+--R                            4              5
+--R                   98962752a b - 169772064a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           5             4            2 3            3 2
+--R                   1505280b  - 4365312a b  - 40040448a b  + 77070336a b
+--R                 + 
+--R                             4              5
+--R                   197925504a b - 339544128a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+  6
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                                 7              6            2 5             3 4
+--R                       - 6580992b  + 20523072a b  + 13383936a b  - 107189616a b
+--R                     + 
+--R                               4 3             5 2             6              7
+--R                     151683024a b  - 235421460a b  + 370510152a b - 216572469a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               7              6           2 5             3 4
+--R                       7478400b  - 30317376a b  - 1819296a b  + 152162256a b
+--R                     + 
+--R                                   4 3             5 2             6
+--R                       - 249746376a b  + 335559060a b  - 589340310a b
+--R                     + 
+--R                                 7
+--R                       437231211a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           7              6           2 5             3 4
+--R                   7478400b  - 30317376a b  - 1819296a b  + 152162256a b
+--R                 + 
+--R                               4 3             5 2             6              7
+--R                   - 249746376a b  + 335559060a b  - 589340310a b + 437231211a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              7              6            2 5             3 4
+--R                   - 13161984b  + 41046144a b  + 26767872a b  - 214379232a b
+--R                 + 
+--R                             4 3             5 2             6              7
+--R                   303366048a b  - 470842920a b  + 741020304a b - 433144938a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                     +---------+ +---------+
+--R             4+---+2 |  +-+      |  +-+
+--R             \|392  \|2\|2  + 1 \|4\|2  + 2
+--R         + 
+--R                                 6           2 5            3 4            4 3
+--R                       3140928a b  - 6011712a b  - 13629168a b  + 34741728a b
+--R                     + 
+--R                                  5 2            6             7
+--R                       - 30546180a b  + 75565980a b - 85811733a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               7             6            2 5            3 4
+--R                       2093952b  - 2960832a b  - 11090016a b  + 18618096a b
+--R                     + 
+--R                                 4 3            5 2            6             7
+--R                       - 8783544a b  + 40195260a b  - 32019162a b - 28603911a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                             7             6            2 5            3 4
+--R                   - 2093952b  + 2960832a b  + 11090016a b  - 18618096a b
+--R                 + 
+--R                           4 3            5 2            6             7
+--R                   8783544a b  - 40195260a b  + 32019162a b + 28603911a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                               6            2 5            3 4            4 3
+--R                   - 6281856a b  + 12023424a b  + 27258336a b  - 69483456a b
+--R                 + 
+--R                            5 2             6              7
+--R                   61092360a b  - 151131960a b + 171623466a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                          +---------+ +---------+
+--R              +--+4+---+2 |  +-+      |  +-+
+--R             \|14 \|392  \|2\|2  - 1 \|2\|2  + 1
+--R         + 
+--R                               7             6            2 5             3 4
+--R                       1182720b  - 6279168a b  - 19595520a b  + 125900544a b
+--R                     + 
+--R                                  4 3             5 2              6
+--R                       - 86181312a b  - 457011072a b  + 1116315984a b
+--R                     + 
+--R                                   7
+--R                       - 812480592a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                               7             6            2 5             3 4
+--R                       1182720b  - 6279168a b  - 19595520a b  + 125900544a b
+--R                     + 
+--R                                  4 3             5 2              6
+--R                       - 86181312a b  - 457011072a b  + 1116315984a b
+--R                     + 
+--R                                   7
+--R                       - 812480592a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               7              6            2 5             3 4
+--R                       2365440b  - 12558336a b  - 39191040a b  + 251801088a b
+--R                     + 
+--R                                   4 3             5 2              6
+--R                       - 172362624a b  - 914022144a b  + 2232631968a b
+--R                     + 
+--R                                    7
+--R                       - 1624961184a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                            7             6           2 5            3 4
+--R                   - 591360b  + 3139584a b  + 9797760a b  - 62950272a b
+--R                 + 
+--R                            4 3             5 2             6              7
+--R                   43090656a b  + 228505536a b  - 558157992a b + 406240296a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            7             6           2 5            3 4
+--R                   - 591360b  + 3139584a b  + 9797760a b  - 62950272a b
+--R                 + 
+--R                            4 3             5 2             6              7
+--R                   43090656a b  + 228505536a b  - 558157992a b + 406240296a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             7             6            2 5             3 4
+--R                   - 1182720b  + 6279168a b  + 19595520a b  - 125900544a b
+--R                 + 
+--R                            4 3             5 2              6              7
+--R                   86181312a b  + 457011072a b  - 1116315984a b + 812480592a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R             4+---+2
+--R             \|392
+--R      *
+--R                     +----------------------------------------+  4
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                                 5             4            2 3            3 2
+--R                       - 2917376b  + 2883328a b  + 21575680a b  - 28661248a b
+--R                     + 
+--R                                  4             5
+--R                       - 21732928a b + 31383632a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                               5             4            2 3            3 2
+--R                       3315200b  - 6377728a b  - 25188352a b  + 54697216a b
+--R                     + 
+--R                                4             5
+--R                       20882848a b - 63359408a
+--R                  *
+--R                      6
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                           5             4            2 3            3 2
+--R                   3315200b  - 6377728a b  - 25188352a b  + 54697216a b
+--R                 + 
+--R                            4             5
+--R                   20882848a b - 63359408a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             5             4            2 3            3 2
+--R                   - 5834752b  + 5766656a b  + 43151360a b  - 57322496a b
+--R                 + 
+--R                              4             5
+--R                   - 43465856a b + 62767264a
+--R              *
+--R                  6
+--R                 x
+--R          *
+--R              +----------------------------------------------+2 +---------+
+--R             4|    4          3        2 2        3         4   |  +-+
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  + 1
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|4\|2  + 2
+--R         + 
+--R                                 4          2 3           3 2           4
+--R                       1392384a b  + 301056a b  - 9934848a b  + 1712256a b
+--R                     + 
+--R                                5
+--R                       12435024a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                              5            4           2 3           3 2
+--R                       928256b  + 664832a b  - 6522880a b  - 2170112a b
+--R                     + 
+--R                               4            5
+--R                       8860768a b + 4145008a
+--R                  *
+--R                      6
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                            5            4           2 3           3 2
+--R                   - 928256b  - 664832a b  + 6522880a b  + 2170112a b
+--R                 + 
+--R                             4            5
+--R                   - 8860768a b - 4145008a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               4          2 3            3 2           4
+--R                   - 2784768a b  - 602112a b  + 19869696a b  - 3424512a b
+--R                 + 
+--R                              5
+--R                   - 24870048a
+--R              *
+--R                  6
+--R                 x
+--R          *
+--R                   +----------------------------------------------+2 +---------+
+--R              +--+4|    4          3        2 2        3         4   |  +-+
+--R             \|14 \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a   \|2\|2  - 1
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|2  + 1
+--R         + 
+--R                               5             4           2 3            3 2
+--R                       1103872b  - 7626752a b  + 4566016a b  + 36603392a b
+--R                     + 
+--R                                  4             5
+--R                       - 94939264a b + 78581888a
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                               5             4           2 3            3 2
+--R                       1103872b  - 7626752a b  + 4566016a b  + 36603392a b
+--R                     + 
+--R                                  4             5
+--R                       - 94939264a b + 78581888a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                               5              4           2 3            3 2
+--R                       2207744b  - 15253504a b  + 9132032a b  + 73206784a b
+--R                     + 
+--R                                   4              5
+--R                       - 189878528a b + 157163776a
+--R                  *
+--R                      6
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                            5             4           2 3            3 2
+--R                   - 551936b  + 3813376a b  - 2283008a b  - 18301696a b
+--R                 + 
+--R                            4             5
+--R                   47469632a b - 39290944a
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            5             4           2 3            3 2
+--R                   - 551936b  + 3813376a b  - 2283008a b  - 18301696a b
+--R                 + 
+--R                            4             5
+--R                   47469632a b - 39290944a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             5             4           2 3            3 2
+--R                   - 1103872b  + 7626752a b  - 4566016a b  - 36603392a b
+--R                 + 
+--R                            4             5
+--R                   94939264a b - 78581888a
+--R              *
+--R                  6
+--R                 x
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+  2
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                            7             6           2 5           3 4
+--R                   - 681472b  + 3422848a b  - 5060352a b  - 9740800a b
+--R                 + 
+--R                            4 3            5 2            6             7
+--R                   52656928a b  - 94746984a b  + 85666736a b - 32356712a
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                          7             6           2 5           3 4
+--R                   774400b  - 4614016a b  + 8516352a b  + 9021568a b
+--R                 + 
+--R                              4 3             5 2             6             7
+--R                   - 72658384a b  + 148198776a b  - 149243840a b + 65323928a
+--R              *
+--R                  8
+--R                 x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                      7             6           2 5           3 4            4 3
+--R               774400b  - 4614016a b  + 8516352a b  + 9021568a b  - 72658384a b
+--R             + 
+--R                         5 2             6             7
+--R               148198776a b  - 149243840a b + 65323928a
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         7             6            2 5            3 4
+--R               - 1362944b  + 6845696a b  - 10120704a b  - 19481600a b
+--R             + 
+--R                         4 3             5 2             6             7
+--R               105313856a b  - 189493968a b  + 171333472a b - 64713424a
+--R          *
+--R              8
+--R             x
+--R      *
+--R                 +---------+ +---------+
+--R         4+---+2 |  +-+      |  +-+
+--R         \|392  \|2\|2  + 1 \|4\|2  + 2
+--R     + 
+--R                            6           2 5          3 4           4 3
+--R                   325248a b  - 1241856a b  + 919296a b  + 5756352a b
+--R                 + 
+--R                              5 2            6             7
+--R                   - 18197928a b  + 23299920a b - 12820584a
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                          7            6          2 5           3 4
+--R                   216832b  - 719488a b  + 198912a b  + 4144000a b
+--R                 + 
+--R                              4 3           5 2          6            7
+--R                   - 10213168a b  + 9467304a b  - 780416a b - 4273528a
+--R              *
+--R                  8
+--R                 x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                        7            6          2 5           3 4            4 3
+--R               - 216832b  + 719488a b  - 198912a b  - 4144000a b  + 10213168a b
+--R             + 
+--R                         5 2          6            7
+--R               - 9467304a b  + 780416a b + 4273528a
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          6           2 5           3 4            4 3
+--R               - 650496a b  + 2483712a b  - 1838592a b  - 11512704a b
+--R             + 
+--R                        5 2            6             7
+--R               36395856a b  - 46599840a b + 25641168a
+--R          *
+--R              8
+--R             x
+--R      *
+--R                      +---------+ +---------+
+--R          +--+4+---+2 |  +-+      |  +-+
+--R         \|14 \|392  \|2\|2  - 1 \|2\|2  + 1
+--R  /
+--R                            6               5             2 4              3 3
+--R                   97140736b  - 370900992a b  + 274563072a b  + 1719230464a b
+--R                 + 
+--R                                4 2              5               6
+--R                   - 5435114496a b  + 6958909440a b - 3829081088a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            6               5             2 4              3 3
+--R                   97140736b  - 370900992a b  + 274563072a b  + 1719230464a b
+--R                 + 
+--R                                4 2              5               6
+--R                   - 5435114496a b  + 6958909440a b - 3829081088a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         6               5             2 4              3 3
+--R               194281472b  - 741801984a b  + 549126144a b  + 3438460928a b
+--R             + 
+--R                             4 2               5               6
+--R               - 10870228992a b  + 13917818880a b - 7658162176a
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                          6               5             2 4             3 3
+--R               - 48570368b  + 185450496a b  - 137281536a b  - 859615232a b
+--R             + 
+--R                          4 2              5               6
+--R               2717557248a b  - 3479454720a b + 1914540544a
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          6               5             2 4             3 3
+--R               - 48570368b  + 185450496a b  - 137281536a b  - 859615232a b
+--R             + 
+--R                          4 2              5               6
+--R               2717557248a b  - 3479454720a b + 1914540544a
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      6               5             2 4              3 3
+--R           - 97140736b  + 370900992a b  - 274563072a b  - 1719230464a b
+--R         + 
+--R                      4 2              5               6
+--R           5435114496a b  - 6958909440a b + 3829081088a
+--R      *
+--R                            +----------------------------------------+  8
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R         4+---+2                  (100b  - 428a b + 211a )\|7
+--R         \|392  sin(---------------------------------------------------)
+--R                                             2
+--R     + 
+--R                                 6                5              2 4
+--R                       388562944b  - 1483603968a b  + 1098252288a b
+--R                     + 
+--R                                  3 3               4 2               5
+--R                       6876921856a b  - 21740457984a b  + 27835637760a b
+--R                     + 
+--R                                     6
+--R                       - 15316324352a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 6                5              2 4
+--R                       388562944b  - 1483603968a b  + 1098252288a b
+--R                     + 
+--R                                  3 3               4 2               5
+--R                       6876921856a b  - 21740457984a b  + 27835637760a b
+--R                     + 
+--R                                     6
+--R                       - 15316324352a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                             6                5              2 4
+--R                   777125888b  - 2967207936a b  + 2196504576a b
+--R                 + 
+--R                               3 3               4 2               5
+--R                   13753843712a b  - 43480915968a b  + 55671275520a b
+--R                 + 
+--R                                 6
+--R                   - 30632648704a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                               6               5             2 4
+--R                   - 194281472b  + 741801984a b  - 549126144a b
+--R                 + 
+--R                                3 3               4 2               5
+--R                   - 3438460928a b  + 10870228992a b  - 13917818880a b
+--R                 + 
+--R                              6
+--R                   7658162176a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               6               5             2 4
+--R                   - 194281472b  + 741801984a b  - 549126144a b
+--R                 + 
+--R                                3 3               4 2               5
+--R                   - 3438460928a b  + 10870228992a b  - 13917818880a b
+--R                 + 
+--R                              6
+--R                   7658162176a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           6                5              2 4              3 3
+--R               - 388562944b  + 1483603968a b  - 1098252288a b  - 6876921856a b
+--R             + 
+--R                           4 2               5                6
+--R               21740457984a b  - 27835637760a b + 15316324352a
+--R          *
+--R                                +----------------------------------------+  2
+--R                                |   4        3       2 2       3        4
+--R                             49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                        atan(---------------------------------------------)
+--R                                           2                2  +-+
+--R             4+---+2                  (100b  - 428a b + 211a )\|7
+--R             \|392  cos(---------------------------------------------------)
+--R                                                 2
+--R         + 
+--R                                   4              3              2 2
+--R                       - 207929344b  - 44957696a b  + 1483603968a b
+--R                     + 
+--R                                   3               4
+--R                       - 255696896a b - 1856963584a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                   4              3              2 2
+--R                       - 207929344b  - 44957696a b  + 1483603968a b
+--R                     + 
+--R                                   3               4
+--R                       - 255696896a b - 1856963584a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                   4              3              2 2
+--R                       - 415858688b  - 89915392a b  + 2967207936a b
+--R                     + 
+--R                                   3               4
+--R                       - 511393792a b - 3713927168a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                             4              3             2 2             3
+--R                   103964672b  + 22478848a b  - 741801984a b  + 127848448a b
+--R                 + 
+--R                             4
+--R                   928481792a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             4              3             2 2             3
+--R                   103964672b  + 22478848a b  - 741801984a b  + 127848448a b
+--R                 + 
+--R                             4
+--R                   928481792a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             4              3              2 2             3
+--R                   207929344b  + 44957696a b  - 1483603968a b  + 255696896a b
+--R                 + 
+--R                              4
+--R                   1856963584a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+  6
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                           2                            2  6
+--R               (- 25288704b  + 160161792a b - 115906560a )x
+--R             + 
+--R                           2                            2  4
+--R               (- 25288704b  + 160161792a b - 115906560a )x
+--R             + 
+--R                           2                            2  2
+--R               (- 50577408b  + 320323584a b - 231813120a )x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                     2                          2  6
+--R           (12644352b  - 80080896a b + 57953280a )x
+--R         + 
+--R                     2                          2  4
+--R           (12644352b  - 80080896a b + 57953280a )x
+--R         + 
+--R                     2                            2  2
+--R           (25288704b  - 160161792a b + 115906560a )x
+--R      *
+--R              +----------------------------------------+
+--R          +-+ |   4        3       2 2       3        4
+--R         \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R      *
+--R          +----------------------------------------------+2
+--R         4|    4          3        2 2        3         4
+--R         \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R      *
+--R                     +----------------------------------------+  5
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                                 6                5              2 4
+--R                       582844416b  - 2225405952a b  + 1647378432a b
+--R                     + 
+--R                                   3 3               4 2               5
+--R                       10315382784a b  - 32610686976a b  + 41753456640a b
+--R                     + 
+--R                                     6
+--R                       - 22974486528a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 6                5              2 4
+--R                       582844416b  - 2225405952a b  + 1647378432a b
+--R                     + 
+--R                                   3 3               4 2               5
+--R                       10315382784a b  - 32610686976a b  + 41753456640a b
+--R                     + 
+--R                                     6
+--R                       - 22974486528a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                              6                5              2 4
+--R                   1165688832b  - 4450811904a b  + 3294756864a b
+--R                 + 
+--R                               3 3               4 2               5
+--R                   20630765568a b  - 65221373952a b  + 83506913280a b
+--R                 + 
+--R                                 6
+--R                   - 45948973056a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                               6                5             2 4
+--R                   - 291422208b  + 1112702976a b  - 823689216a b
+--R                 + 
+--R                                3 3               4 2               5
+--R                   - 5157691392a b  + 16305343488a b  - 20876728320a b
+--R                 + 
+--R                               6
+--R                   11487243264a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               6                5             2 4
+--R                   - 291422208b  + 1112702976a b  - 823689216a b
+--R                 + 
+--R                                3 3               4 2               5
+--R                   - 5157691392a b  + 16305343488a b  - 20876728320a b
+--R                 + 
+--R                               6
+--R                   11487243264a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           6                5              2 4               3 3
+--R               - 582844416b  + 2225405952a b  - 1647378432a b  - 10315382784a b
+--R             + 
+--R                           4 2               5                6
+--R               32610686976a b  - 41753456640a b + 22974486528a
+--R          *
+--R                                +----------------------------------------+  4
+--R                                |   4        3       2 2       3        4
+--R                             49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                        atan(---------------------------------------------)
+--R                                           2                2  +-+
+--R             4+---+2                  (100b  - 428a b + 211a )\|7
+--R             \|392  cos(---------------------------------------------------)
+--R                                                 2
+--R         + 
+--R                                   4              3              2 2
+--R                       - 207929344b  - 44957696a b  + 1483603968a b
+--R                     + 
+--R                                   3               4
+--R                       - 255696896a b - 1856963584a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                   4              3              2 2
+--R                       - 207929344b  - 44957696a b  + 1483603968a b
+--R                     + 
+--R                                   3               4
+--R                       - 255696896a b - 1856963584a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                   4              3              2 2
+--R                       - 415858688b  - 89915392a b  + 2967207936a b
+--R                     + 
+--R                                   3               4
+--R                       - 511393792a b - 3713927168a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                             4              3             2 2             3
+--R                   103964672b  + 22478848a b  - 741801984a b  + 127848448a b
+--R                 + 
+--R                             4
+--R                   928481792a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             4              3             2 2             3
+--R                   103964672b  + 22478848a b  - 741801984a b  + 127848448a b
+--R                 + 
+--R                             4
+--R                   928481792a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             4              3              2 2             3
+--R                   207929344b  + 44957696a b  - 1483603968a b  + 255696896a b
+--R                 + 
+--R                              4
+--R                   1856963584a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R          *
+--R                         +----------------------------------------+  2
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                                 6               5              2 4
+--R                       234522624b  - 448874496a b  - 1017644544a b
+--R                     + 
+--R                                  3 3              4 2              5
+--R                       2594049024a b  - 2280781440a b  + 5642259840a b
+--R                     + 
+--R                                    6
+--R                       - 6407276064a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                 6               5              2 4
+--R                       234522624b  - 448874496a b  - 1017644544a b
+--R                     + 
+--R                                  3 3              4 2              5
+--R                       2594049024a b  - 2280781440a b  + 5642259840a b
+--R                     + 
+--R                                    6
+--R                       - 6407276064a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                 6               5              2 4
+--R                       469045248b  - 897748992a b  - 2035289088a b
+--R                     + 
+--R                                  3 3              4 2               5
+--R                       5188098048a b  - 4561562880a b  + 11284519680a b
+--R                     + 
+--R                                     6
+--R                       - 12814552128a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                               6               5             2 4
+--R                   - 117261312b  + 224437248a b  + 508822272a b
+--R                 + 
+--R                                3 3              4 2              5
+--R                   - 1297024512a b  + 1140390720a b  - 2821129920a b
+--R                 + 
+--R                              6
+--R                   3203638032a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               6               5             2 4
+--R                   - 117261312b  + 224437248a b  + 508822272a b
+--R                 + 
+--R                                3 3              4 2              5
+--R                   - 1297024512a b  + 1140390720a b  - 2821129920a b
+--R                 + 
+--R                              6
+--R                   3203638032a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                               6               5              2 4
+--R                   - 234522624b  + 448874496a b  + 1017644544a b
+--R                 + 
+--R                                3 3              4 2              5
+--R                   - 2594049024a b  + 2280781440a b  - 5642259840a b
+--R                 + 
+--R                              6
+--R                   6407276064a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R             4+---+2
+--R             \|392
+--R      *
+--R                     +----------------------------------------+  4
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                               2                            2  6
+--R                   (- 50577408b  + 320323584a b - 231813120a )x
+--R                 + 
+--R                               2                            2  4
+--R                   (- 50577408b  + 320323584a b - 231813120a )x
+--R                 + 
+--R                                2                            2  2
+--R                   (- 101154816b  + 640647168a b - 463626240a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         2                            2  6
+--R               (25288704b  - 160161792a b + 115906560a )x
+--R             + 
+--R                         2                            2  4
+--R               (25288704b  - 160161792a b + 115906560a )x
+--R             + 
+--R                         2                            2  2
+--R               (50577408b  - 320323584a b + 231813120a )x
+--R          *
+--R                  +----------------------------------------+
+--R              +-+ |   4        3       2 2       3        4
+--R             \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R          *
+--R                         +----------------------------------------+  3
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                                4               3             2 2             3
+--R                       33417216b  - 237834240a b  + 248822784a b  + 324688896a b
+--R                     + 
+--R                                   4
+--R                       - 321847680a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                4               3             2 2             3
+--R                       33417216b  - 237834240a b  + 248822784a b  + 324688896a b
+--R                     + 
+--R                                   4
+--R                       - 321847680a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                4               3             2 2             3
+--R                       66834432b  - 475668480a b  + 497645568a b  + 649377792a b
+--R                     + 
+--R                                   4
+--R                       - 643695360a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                              4               3             2 2             3
+--R                   - 16708608b  + 118917120a b  - 124411392a b  - 162344448a b
+--R                 + 
+--R                             4
+--R                   160923840a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              4               3             2 2             3
+--R                   - 16708608b  + 118917120a b  - 124411392a b  - 162344448a b
+--R                 + 
+--R                             4
+--R                   160923840a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              4               3             2 2             3
+--R                   - 33417216b  + 237834240a b  - 248822784a b  - 324688896a b
+--R                 + 
+--R                             4
+--R                   321847680a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                         +----------------------------------------+
+--R              +-+4+---+2 |   4        3       2 2       3        4
+--R             \|7 \|392  \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R          *
+--R                         +----------------------------------------+
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R      *
+--R                     +----------------------------------------+  3
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                                 6                5              2 4
+--R                       388562944b  - 1483603968a b  + 1098252288a b
+--R                     + 
+--R                                  3 3               4 2               5
+--R                       6876921856a b  - 21740457984a b  + 27835637760a b
+--R                     + 
+--R                                     6
+--R                       - 15316324352a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 6                5              2 4
+--R                       388562944b  - 1483603968a b  + 1098252288a b
+--R                     + 
+--R                                  3 3               4 2               5
+--R                       6876921856a b  - 21740457984a b  + 27835637760a b
+--R                     + 
+--R                                     6
+--R                       - 15316324352a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                             6                5              2 4
+--R                   777125888b  - 2967207936a b  + 2196504576a b
+--R                 + 
+--R                               3 3               4 2               5
+--R                   13753843712a b  - 43480915968a b  + 55671275520a b
+--R                 + 
+--R                                 6
+--R                   - 30632648704a
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                               6               5             2 4
+--R                   - 194281472b  + 741801984a b  - 549126144a b
+--R                 + 
+--R                                3 3               4 2               5
+--R                   - 3438460928a b  + 10870228992a b  - 13917818880a b
+--R                 + 
+--R                              6
+--R                   7658162176a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               6               5             2 4
+--R                   - 194281472b  + 741801984a b  - 549126144a b
+--R                 + 
+--R                                3 3               4 2               5
+--R                   - 3438460928a b  + 10870228992a b  - 13917818880a b
+--R                 + 
+--R                              6
+--R                   7658162176a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           6                5              2 4              3 3
+--R               - 388562944b  + 1483603968a b  - 1098252288a b  - 6876921856a b
+--R             + 
+--R                           4 2               5                6
+--R               21740457984a b  - 27835637760a b + 15316324352a
+--R          *
+--R                                +----------------------------------------+  6
+--R                                |   4        3       2 2       3        4
+--R                             49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                        atan(---------------------------------------------)
+--R                                           2                2  +-+
+--R             4+---+2                  (100b  - 428a b + 211a )\|7
+--R             \|392  cos(---------------------------------------------------)
+--R                                                 2
+--R         + 
+--R                                 4              3              2 2
+--R                       207929344b  + 44957696a b  - 1483603968a b
+--R                     + 
+--R                                 3               4
+--R                       255696896a b + 1856963584a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                 4              3              2 2
+--R                       207929344b  + 44957696a b  - 1483603968a b
+--R                     + 
+--R                                 3               4
+--R                       255696896a b + 1856963584a
+--R                  *
+--R                      4
+--R                     x
+--R                 + 
+--R                                 4              3              2 2
+--R                       415858688b  + 89915392a b  - 2967207936a b
+--R                     + 
+--R                                 3               4
+--R                       511393792a b + 3713927168a
+--R                  *
+--R                      2
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                               4              3             2 2             3
+--R                   - 103964672b  - 22478848a b  + 741801984a b  - 127848448a b
+--R                 + 
+--R                               4
+--R                   - 928481792a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                               4              3             2 2             3
+--R                   - 103964672b  - 22478848a b  + 741801984a b  - 127848448a b
+--R                 + 
+--R                               4
+--R                   - 928481792a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               4              3              2 2             3
+--R                   - 207929344b  - 44957696a b  + 1483603968a b  - 255696896a b
+--R                 + 
+--R                                4
+--R                   - 1856963584a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R          *
+--R                         +----------------------------------------+  4
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                                 6                5               2 4
+--R                       147116032b  - 3241168896a b  + 10498876416a b
+--R                     + 
+--R                                   3 3               4 2               5
+--R                       11943393280a b  - 73277143296a b  + 77488992000a b
+--R                     + 
+--R                                     6
+--R                       - 22821641024a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                 6                5               2 4
+--R                       147116032b  - 3241168896a b  + 10498876416a b
+--R                     + 
+--R                                   3 3               4 2               5
+--R                       11943393280a b  - 73277143296a b  + 77488992000a b
+--R                     + 
+--R                                     6
+--R                       - 22821641024a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                 6                5               2 4
+--R                       294232064b  - 6482337792a b  + 20997752832a b
+--R                     + 
+--R                                   3 3                4 2                5
+--R                       23886786560a b  - 146554286592a b  + 154977984000a b
+--R                     + 
+--R                                     6
+--R                       - 45643282048a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                              6                5              2 4
+--R                   - 73558016b  + 1620584448a b  - 5249438208a b
+--R                 + 
+--R                                3 3               4 2               5
+--R                   - 5971696640a b  + 36638571648a b  - 38744496000a b
+--R                 + 
+--R                               6
+--R                   11410820512a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              6                5              2 4
+--R                   - 73558016b  + 1620584448a b  - 5249438208a b
+--R                 + 
+--R                                3 3               4 2               5
+--R                   - 5971696640a b  + 36638571648a b  - 38744496000a b
+--R                 + 
+--R                               6
+--R                   11410820512a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                               6                5               2 4
+--R                   - 147116032b  + 3241168896a b  - 10498876416a b
+--R                 + 
+--R                                 3 3               4 2               5
+--R                   - 11943393280a b  + 73277143296a b  - 77488992000a b
+--R                 + 
+--R                               6
+--R                   22821641024a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                                +----------------------------------------+  2
+--R                                |   4        3       2 2       3        4
+--R                             49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                        atan(---------------------------------------------)
+--R                                           2                2  +-+
+--R             4+---+2                  (100b  - 428a b + 211a )\|7
+--R             \|392  cos(---------------------------------------------------)
+--R                                                 2
+--R         + 
+--R                                   4              3             2 2
+--R                       - 103964672b  - 22478848a b  + 741801984a b
+--R                     + 
+--R                                   3              4
+--R                       - 127848448a b - 928481792a
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                   4              3             2 2
+--R                       - 103964672b  - 22478848a b  + 741801984a b
+--R                     + 
+--R                                   3              4
+--R                       - 127848448a b - 928481792a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                   4              3              2 2
+--R                       - 207929344b  - 44957696a b  + 1483603968a b
+--R                     + 
+--R                                   3               4
+--R                       - 255696896a b - 1856963584a
+--R                  *
+--R                      6
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                            4              3             2 2            3
+--R                   51982336b  + 11239424a b  - 370900992a b  + 63924224a b
+--R                 + 
+--R                             4
+--R                   464240896a
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            4              3             2 2            3
+--R                   51982336b  + 11239424a b  - 370900992a b  + 63924224a b
+--R                 + 
+--R                             4
+--R                   464240896a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             4              3             2 2             3
+--R                   103964672b  + 22478848a b  - 741801984a b  + 127848448a b
+--R                 + 
+--R                             4
+--R                   928481792a
+--R              *
+--R                  6
+--R                 x
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+  2
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                               2                            2  6
+--R                   (- 25288704b  + 160161792a b - 115906560a )x
+--R                 + 
+--R                               2                            2  4
+--R                   (- 25288704b  + 160161792a b - 115906560a )x
+--R                 + 
+--R                               2                            2  2
+--R                   (- 50577408b  + 320323584a b - 231813120a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                         2                          2  6
+--R               (12644352b  - 80080896a b + 57953280a )x
+--R             + 
+--R                         2                          2  4
+--R               (12644352b  - 80080896a b + 57953280a )x
+--R             + 
+--R                         2                            2  2
+--R               (25288704b  - 160161792a b + 115906560a )x
+--R          *
+--R                  +----------------------------------------+
+--R              +-+ |   4        3       2 2       3        4
+--R             \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R          *
+--R                         +----------------------------------------+  5
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                                  4               3             2 2
+--R                       - 33417216b  + 237834240a b  - 248822784a b
+--R                     + 
+--R                                   3              4
+--R                       - 324688896a b + 321847680a
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                  4               3             2 2
+--R                       - 33417216b  + 237834240a b  - 248822784a b
+--R                     + 
+--R                                   3              4
+--R                       - 324688896a b + 321847680a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                  4               3             2 2
+--R                       - 66834432b  + 475668480a b  - 497645568a b
+--R                     + 
+--R                                   3              4
+--R                       - 649377792a b + 643695360a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                            4               3             2 2             3
+--R                   16708608b  - 118917120a b  + 124411392a b  + 162344448a b
+--R                 + 
+--R                               4
+--R                   - 160923840a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            4               3             2 2             3
+--R                   16708608b  - 118917120a b  + 124411392a b  + 162344448a b
+--R                 + 
+--R                               4
+--R                   - 160923840a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            4               3             2 2             3
+--R                   33417216b  - 237834240a b  + 248822784a b  + 324688896a b
+--R                 + 
+--R                               4
+--R                   - 321847680a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                         +----------------------------------------+
+--R              +-+4+---+2 |   4        3       2 2       3        4
+--R             \|7 \|392  \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R          *
+--R                         +----------------------------------------+  3
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R         + 
+--R                               2                          2  10
+--R                   (- 12644352b  + 80080896a b - 57953280a )x
+--R                 + 
+--R                               2                          2  8
+--R                   (- 12644352b  + 80080896a b - 57953280a )x
+--R                 + 
+--R                               2                            2  6
+--R                   (- 25288704b  + 160161792a b - 115906560a )x
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                        2                          2  10
+--R               (6322176b  - 40040448a b + 28976640a )x
+--R             + 
+--R                        2                          2  8
+--R               (6322176b  - 40040448a b + 28976640a )x
+--R             + 
+--R                         2                          2  6
+--R               (12644352b  - 80080896a b + 57953280a )x
+--R          *
+--R                  +----------------------------------------+
+--R              +-+ |   4        3       2 2       3        4
+--R             \|7 \|16b  + 32a b  - 120a b  - 136a b + 289a
+--R          *
+--R              +----------------------------------------------+2
+--R             4|    4          3        2 2        3         4
+--R             \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R          *
+--R                         +----------------------------------------+
+--R                         |   4        3       2 2       3        4
+--R                      49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                 atan(---------------------------------------------)
+--R                                    2                2  +-+
+--R                               (100b  - 428a b + 211a )\|7
+--R             cos(---------------------------------------------------)
+--R                                          2
+--R      *
+--R                     +----------------------------------------+
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         sin(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                            6               5             2 4              3 3
+--R                   97140736b  - 370900992a b  + 274563072a b  + 1719230464a b
+--R                 + 
+--R                                4 2              5               6
+--R                   - 5435114496a b  + 6958909440a b - 3829081088a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            6               5             2 4              3 3
+--R                   97140736b  - 370900992a b  + 274563072a b  + 1719230464a b
+--R                 + 
+--R                                4 2              5               6
+--R                   - 5435114496a b  + 6958909440a b - 3829081088a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         6               5             2 4              3 3
+--R               194281472b  - 741801984a b  + 549126144a b  + 3438460928a b
+--R             + 
+--R                             4 2               5               6
+--R               - 10870228992a b  + 13917818880a b - 7658162176a
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                          6               5             2 4             3 3
+--R               - 48570368b  + 185450496a b  - 137281536a b  - 859615232a b
+--R             + 
+--R                          4 2              5               6
+--R               2717557248a b  - 3479454720a b + 1914540544a
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          6               5             2 4             3 3
+--R               - 48570368b  + 185450496a b  - 137281536a b  - 859615232a b
+--R             + 
+--R                          4 2              5               6
+--R               2717557248a b  - 3479454720a b + 1914540544a
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      6               5             2 4              3 3
+--R           - 97140736b  + 370900992a b  - 274563072a b  - 1719230464a b
+--R         + 
+--R                      4 2              5               6
+--R           5435114496a b  - 6958909440a b + 3829081088a
+--R      *
+--R                            +----------------------------------------+  8
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R         4+---+2                  (100b  - 428a b + 211a )\|7
+--R         \|392  cos(---------------------------------------------------)
+--R                                             2
+--R     + 
+--R                             4              3              2 2             3
+--R                   207929344b  + 44957696a b  - 1483603968a b  + 255696896a b
+--R                 + 
+--R                              4
+--R                   1856963584a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             4              3              2 2             3
+--R                   207929344b  + 44957696a b  - 1483603968a b  + 255696896a b
+--R                 + 
+--R                              4
+--R                   1856963584a
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             4              3              2 2             3
+--R                   415858688b  + 89915392a b  - 2967207936a b  + 511393792a b
+--R                 + 
+--R                              4
+--R                   3713927168a
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                           4              3             2 2             3
+--R               - 103964672b  - 22478848a b  + 741801984a b  - 127848448a b
+--R             + 
+--R                           4
+--R               - 928481792a
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           4              3             2 2             3
+--R               - 103964672b  - 22478848a b  + 741801984a b  - 127848448a b
+--R             + 
+--R                           4
+--R               - 928481792a
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                           4              3              2 2             3
+--R               - 207929344b  - 44957696a b  + 1483603968a b  - 255696896a b
+--R             + 
+--R                            4
+--R               - 1856963584a
+--R          *
+--R              2
+--R             x
+--R      *
+--R          +----------------------------------------------+2
+--R         4|    4          3        2 2        3         4
+--R         \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+  6
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                             6               5              2 4              3 3
+--R                   234522624b  - 448874496a b  - 1017644544a b  + 2594049024a b
+--R                 + 
+--R                                4 2              5               6
+--R                   - 2280781440a b  + 5642259840a b - 6407276064a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             6               5              2 4              3 3
+--R                   234522624b  - 448874496a b  - 1017644544a b  + 2594049024a b
+--R                 + 
+--R                                4 2              5               6
+--R                   - 2280781440a b  + 5642259840a b - 6407276064a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             6               5              2 4              3 3
+--R                   469045248b  - 897748992a b  - 2035289088a b  + 5188098048a b
+--R                 + 
+--R                                4 2               5                6
+--R                   - 4561562880a b  + 11284519680a b - 12814552128a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                           6               5             2 4              3 3
+--R               - 117261312b  + 224437248a b  + 508822272a b  - 1297024512a b
+--R             + 
+--R                          4 2              5               6
+--R               1140390720a b  - 2821129920a b + 3203638032a
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                           6               5             2 4              3 3
+--R               - 117261312b  + 224437248a b  + 508822272a b  - 1297024512a b
+--R             + 
+--R                          4 2              5               6
+--R               1140390720a b  - 2821129920a b + 3203638032a
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           6               5              2 4              3 3
+--R               - 234522624b  + 448874496a b  + 1017644544a b  - 2594049024a b
+--R             + 
+--R                          4 2              5               6
+--R               2280781440a b  - 5642259840a b + 6407276064a
+--R          *
+--R              4
+--R             x
+--R      *
+--R                            +----------------------------------------+  4
+--R                            |   4        3       2 2       3        4
+--R                         49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R                    atan(---------------------------------------------)
+--R                                       2                2  +-+
+--R         4+---+2                  (100b  - 428a b + 211a )\|7
+--R         \|392  cos(---------------------------------------------------)
+--R                                             2
+--R     + 
+--R                             4              3             2 2             3
+--R                   103964672b  + 22478848a b  - 741801984a b  + 127848448a b
+--R                 + 
+--R                             4
+--R                   928481792a
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             4              3             2 2             3
+--R                   103964672b  + 22478848a b  - 741801984a b  + 127848448a b
+--R                 + 
+--R                             4
+--R                   928481792a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             4              3              2 2             3
+--R                   207929344b  + 44957696a b  - 1483603968a b  + 255696896a b
+--R                 + 
+--R                              4
+--R                   1856963584a
+--R              *
+--R                  6
+--R                 x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                          4              3             2 2            3
+--R               - 51982336b  - 11239424a b  + 370900992a b  - 63924224a b
+--R             + 
+--R                           4
+--R               - 464240896a
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          4              3             2 2            3
+--R               - 51982336b  - 11239424a b  + 370900992a b  - 63924224a b
+--R             + 
+--R                           4
+--R               - 464240896a
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                           4              3             2 2             3
+--R               - 103964672b  - 22478848a b  + 741801984a b  - 127848448a b
+--R             + 
+--R                           4
+--R               - 928481792a
+--R          *
+--R              6
+--R             x
+--R      *
+--R          +----------------------------------------------+2
+--R         4|    4          3        2 2        3         4
+--R         \|484b  - 2332a b  + 5757a b  - 7102a b + 4489a
+--R      *
+--R                     +----------------------------------------+  2
+--R                     |   4        3       2 2       3        4
+--R                  49\|16b  + 32a b  - 120a b  - 136a b + 289a
+--R             atan(---------------------------------------------)
+--R                                2                2  +-+
+--R                           (100b  - 428a b + 211a )\|7
+--R         cos(---------------------------------------------------)
+--R                                      2
+--R     + 
+--R                            6              5            2 4             3 3
+--R                   24285184b  - 92725248a b  + 68640768a b  + 429807616a b
+--R                 + 
+--R                                4 2              5              6
+--R                   - 1358778624a b  + 1739727360a b - 957270272a
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                            6              5            2 4             3 3
+--R                   24285184b  - 92725248a b  + 68640768a b  + 429807616a b
+--R                 + 
+--R                                4 2              5              6
+--R                   - 1358778624a b  + 1739727360a b - 957270272a
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            6               5             2 4             3 3
+--R                   48570368b  - 185450496a b  + 137281536a b  + 859615232a b
+--R                 + 
+--R                                4 2              5               6
+--R                   - 2717557248a b  + 3479454720a b - 1914540544a
+--R              *
+--R                  8
+--R                 x
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                          6              5            2 4             3 3
+--R               - 12142592b  + 46362624a b  - 34320384a b  - 214903808a b
+--R             + 
+--R                         4 2             5              6
+--R               679389312a b  - 869863680a b + 478635136a
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          6              5            2 4             3 3
+--R               - 12142592b  + 46362624a b  - 34320384a b  - 214903808a b
+--R             + 
+--R                         4 2             5              6
+--R               679389312a b  - 869863680a b + 478635136a
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          6              5            2 4             3 3
+--R               - 24285184b  + 92725248a b  - 68640768a b  - 429807616a b
+--R             + 
+--R                          4 2              5              6
+--R               1358778624a b  - 1739727360a b + 957270272a
+--R          *
+--R              8
+--R             x
+--R      *
+--R         4+---+2
+--R         \|392
+--R                                                    Type: Expression(Integer)
+--E 2352
+
+)clear all
+
+--S 2353 of 3139
+t0:=(-x^2+sqrt(2))/(1+x^4-x^2*sqrt(2))
+--R 
+--R
+--R             2    +-+
+--R          - x  + \|2
+--R   (1)  ---------------
+--R         4    +-+ 2
+--R        x  - \|2 x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 2353
+
+--S 2354 of 3139
+r0:=-1/2*atan((-2*x+sqrt(2+sqrt(2)))/sqrt(2-sqrt(2)))*sqrt(1+(-1)/sqrt(2))+_
+   1/2*atan((2*x+sqrt(2+sqrt(2)))/sqrt(2-sqrt(2)))*sqrt(1+(-1)/sqrt(2))-_
+   1/4*log(1+x^2-x*sqrt(2+sqrt(2)))*sqrt(1+1/sqrt(2))+1/4*log(1+x^2+_
+   x*sqrt(2+sqrt(2)))*sqrt(1+1/sqrt(2))
+--R 
+--R
+--R   (2)
+--R        +--------+      +--------+
+--R        | +-+           | +-+         2
+--R       \|\|2  + 2 log(x\|\|2  + 2  + x  + 1)
+--R     + 
+--R          +--------+        +--------+
+--R          | +-+             | +-+         2
+--R       - \|\|2  + 2 log(- x\|\|2  + 2  + x  + 1)
+--R     + 
+--R           +----------+
+--R           |   +-+
+--R         2\|- \|2  + 2
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R              (\|2  + 2)\|- \|2  + 2 \|\|2  + 2  + (2x\|2  + 4x)\|- \|2  + 2
+--R         atan(---------------------------------------------------------------)
+--R                                             2
+--R     + 
+--R       -
+--R              +----------+
+--R              |   +-+
+--R            2\|- \|2  + 2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|2  + 2)\|- \|2  + 2 \|\|2  + 2  + (- 2x\|2  - 4x)\|- \|2  + 2
+--R               -----------------------------------------------------------------
+--R                                               2
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 2354
+
+--S 2355 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      +----------------+              +----------------+
+--R      |  +---+      +-+           +-+ |  +---+      +-+
+--R     \|(\|- 1  + 1)\|2           \|2 \|(\|- 1  + 1)\|2
+--R     ------------------- log(x + -----------------------)
+--R              4                             2
+--R   + 
+--R      +------------------+              +------------------+
+--R      |    +---+      +-+           +-+ |    +---+      +-+
+--R     \|(- \|- 1  + 1)\|2           \|2 \|(- \|- 1  + 1)\|2
+--R     --------------------- log(x + -------------------------)
+--R               4                               2
+--R   + 
+--R        +------------------+              +------------------+
+--R        |    +---+      +-+           +-+ |    +---+      +-+
+--R       \|(- \|- 1  + 1)\|2           \|2 \|(- \|- 1  + 1)\|2
+--R     - --------------------- log(x - -------------------------)
+--R                 4                               2
+--R   + 
+--R        +----------------+              +----------------+
+--R        |  +---+      +-+           +-+ |  +---+      +-+
+--R       \|(\|- 1  + 1)\|2           \|2 \|(\|- 1  + 1)\|2
+--R     - ------------------- log(x - -----------------------)
+--R                4                             2
+--R                                 Type: Union(Expression(AlgebraicNumber),...)
+--E 2355
+
+--S 2356 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +--------+
+--R        +-+ | +-+                +--------+
+--R       \|2 \|\|2  + 2       2    | +-+
+--R     - --------------- log(x  + \|\|2  + 2 x + 1)
+--R              8
+--R   + 
+--R          +--------+
+--R      +-+ | +-+                +--------+
+--R     \|2 \|\|2  + 2       2    | +-+
+--R     --------------- log(x  - \|\|2  + 2 x + 1)
+--R            8
+--R   + 
+--R      +----------------+              +----------------+
+--R      |  +---+      +-+           +-+ |  +---+      +-+
+--R     \|(\|- 1  + 1)\|2           \|2 \|(\|- 1  + 1)\|2
+--R     ------------------- log(x + -----------------------)
+--R              4                             2
+--R   + 
+--R      +------------------+              +------------------+
+--R      |    +---+      +-+           +-+ |    +---+      +-+
+--R     \|(- \|- 1  + 1)\|2           \|2 \|(- \|- 1  + 1)\|2
+--R     --------------------- log(x + -------------------------)
+--R               4                               2
+--R   + 
+--R        +------------------+              +------------------+
+--R        |    +---+      +-+           +-+ |    +---+      +-+
+--R       \|(- \|- 1  + 1)\|2           \|2 \|(- \|- 1  + 1)\|2
+--R     - --------------------- log(x - -------------------------)
+--R                 4                               2
+--R   + 
+--R        +----------------+              +----------------+
+--R        |  +---+      +-+           +-+ |  +---+      +-+
+--R       \|(\|- 1  + 1)\|2           \|2 \|(\|- 1  + 1)\|2
+--R     - ------------------- log(x - -----------------------)
+--R                4                             2
+--R   + 
+--R     -
+--R               +----------+
+--R           +-+ |   +-+
+--R          \|2 \|- \|2  + 2
+--R          -----------------
+--R                  4
+--R       *
+--R                                                     +----------+ +--------+
+--R                          +----------+      +-+      |   +-+      | +-+
+--R                 +-+      |   +-+         (\|2  + 2)\|- \|2  + 2 \|\|2  + 2
+--R          atan((\|2  + 2)\|- \|2  + 2 x + ----------------------------------)
+--R                                                           2
+--R   + 
+--R     -
+--R               +----------+
+--R           +-+ |   +-+
+--R          \|2 \|- \|2  + 2
+--R          -----------------
+--R                  4
+--R       *
+--R                                                       +----------+ +--------+
+--R                          +----------+        +-+      |   +-+      | +-+
+--R                 +-+      |   +-+         (- \|2  - 2)\|- \|2  + 2 \|\|2  + 2
+--R          atan((\|2  + 2)\|- \|2  + 2 x + ------------------------------------)
+--R                                                            2
+--R                                            Type: Expression(AlgebraicNumber)
+--E 2356
+
+--S 2357 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                            Type: Expression(AlgebraicNumber)
+--E 2357
+
+)clear all
+
+--S 2358 of 3139
+t0:=(x^2+sqrt(2))/(1+x^4+x^2*sqrt(2))
+--R 
+--R
+--R            2    +-+
+--R           x  + \|2
+--R   (1)  ---------------
+--R         4    +-+ 2
+--R        x  + \|2 x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 2358
+
+--S 2359 of 3139
+r0:=-1/4*log(1+x^2-x*sqrt(2-sqrt(2)))*sqrt(1+(-1)/sqrt(2))+1/4*log(1+x^2+_
+   x*sqrt(2-sqrt(2)))*sqrt(1+(-1)/sqrt(2))-1/2*atan((-2*x+sqrt(2-sqrt(2)))/_
+   sqrt(2+sqrt(2)))*sqrt(1+1/sqrt(2))+1/2*atan((2*x+sqrt(2-sqrt(2)))/_
+   sqrt(2+sqrt(2)))*sqrt(1+1/sqrt(2))
+--R 
+--R
+--R   (2)
+--R        +----------+      +----------+
+--R        |   +-+           |   +-+         2
+--R       \|- \|2  + 2 log(x\|- \|2  + 2  + x  + 1)
+--R     + 
+--R          +----------+        +----------+
+--R          |   +-+             |   +-+         2
+--R       - \|- \|2  + 2 log(- x\|- \|2  + 2  + x  + 1)
+--R     + 
+--R                                      +----------+                +--------+
+--R           +--------+        +-+      |   +-+           +-+       | +-+
+--R           | +-+          ((\|2  - 2)\|- \|2  + 2  + 2x\|2  - 4x)\|\|2  + 2
+--R       - 2\|\|2  + 2 atan(--------------------------------------------------)
+--R                                                   2
+--R     + 
+--R                                    +----------+                +--------+
+--R         +--------+        +-+      |   +-+           +-+       | +-+
+--R         | +-+          ((\|2  - 2)\|- \|2  + 2  - 2x\|2  + 4x)\|\|2  + 2
+--R       2\|\|2  + 2 atan(--------------------------------------------------)
+--R                                                 2
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 2359
+
+--S 2360 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      +----------------+              +----------------+
+--R      |  +---+      +-+           +-+ |  +---+      +-+
+--R     \|(\|- 1  - 1)\|2           \|2 \|(\|- 1  - 1)\|2
+--R     ------------------- log(x + -----------------------)
+--R              4                             2
+--R   + 
+--R      +------------------+              +------------------+
+--R      |    +---+      +-+           +-+ |    +---+      +-+
+--R     \|(- \|- 1  - 1)\|2           \|2 \|(- \|- 1  - 1)\|2
+--R     --------------------- log(x + -------------------------)
+--R               4                               2
+--R   + 
+--R        +------------------+              +------------------+
+--R        |    +---+      +-+           +-+ |    +---+      +-+
+--R       \|(- \|- 1  - 1)\|2           \|2 \|(- \|- 1  - 1)\|2
+--R     - --------------------- log(x - -------------------------)
+--R                 4                               2
+--R   + 
+--R        +----------------+              +----------------+
+--R        |  +---+      +-+           +-+ |  +---+      +-+
+--R       \|(\|- 1  - 1)\|2           \|2 \|(\|- 1  - 1)\|2
+--R     - ------------------- log(x - -----------------------)
+--R                4                             2
+--R                                 Type: Union(Expression(AlgebraicNumber),...)
+--E 2360
+
+--S 2361 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +----------+
+--R        +-+ |   +-+                +----------+
+--R       \|2 \|- \|2  + 2       2    |   +-+
+--R     - ----------------- log(x  + \|- \|2  + 2 x + 1)
+--R               8
+--R   + 
+--R          +----------+
+--R      +-+ |   +-+                +----------+
+--R     \|2 \|- \|2  + 2       2    |   +-+
+--R     ----------------- log(x  - \|- \|2  + 2 x + 1)
+--R             8
+--R   + 
+--R      +----------------+              +----------------+
+--R      |  +---+      +-+           +-+ |  +---+      +-+
+--R     \|(\|- 1  - 1)\|2           \|2 \|(\|- 1  - 1)\|2
+--R     ------------------- log(x + -----------------------)
+--R              4                             2
+--R   + 
+--R      +------------------+              +------------------+
+--R      |    +---+      +-+           +-+ |    +---+      +-+
+--R     \|(- \|- 1  - 1)\|2           \|2 \|(- \|- 1  - 1)\|2
+--R     --------------------- log(x + -------------------------)
+--R               4                               2
+--R   + 
+--R        +------------------+              +------------------+
+--R        |    +---+      +-+           +-+ |    +---+      +-+
+--R       \|(- \|- 1  - 1)\|2           \|2 \|(- \|- 1  - 1)\|2
+--R     - --------------------- log(x - -------------------------)
+--R                 4                               2
+--R   + 
+--R        +----------------+              +----------------+
+--R        |  +---+      +-+           +-+ |  +---+      +-+
+--R       \|(\|- 1  - 1)\|2           \|2 \|(\|- 1  - 1)\|2
+--R     - ------------------- log(x - -----------------------)
+--R                4                             2
+--R   + 
+--R            +--------+
+--R        +-+ | +-+
+--R       \|2 \|\|2  + 2
+--R       ---------------
+--R              4
+--R    *
+--R                                                +----------+ +--------+
+--R                       +--------+      +-+      |   +-+      | +-+
+--R              +-+      | +-+         (\|2  - 2)\|- \|2  + 2 \|\|2  + 2
+--R       atan((\|2  - 2)\|\|2  + 2 x + ----------------------------------)
+--R                                                      2
+--R   + 
+--R            +--------+
+--R        +-+ | +-+
+--R       \|2 \|\|2  + 2
+--R       ---------------
+--R              4
+--R    *
+--R                                                  +----------+ +--------+
+--R                       +--------+        +-+      |   +-+      | +-+
+--R              +-+      | +-+         (- \|2  + 2)\|- \|2  + 2 \|\|2  + 2
+--R       atan((\|2  - 2)\|\|2  + 2 x + ------------------------------------)
+--R                                                       2
+--R                                            Type: Expression(AlgebraicNumber)
+--E 2361
+
+--S 2362 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                            Type: Expression(AlgebraicNumber)
+--E 2362
+
+)clear all
+
+--S 2363 of 3139
+t0:=(-x^2+sqrt(2))/(1+b*x^2+x^4)
+--R 
+--R
+--R            2    +-+
+--R         - x  + \|2
+--R   (1)  -------------
+--R         4      2
+--R        x  + b x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 2363
+
+--S 2364 of 3139
+r0:=-atan(x*sqrt(2)/sqrt(b-sqrt(-4+b^2)))*(1+(-b-2*sqrt(2))/sqrt(-4+b^2))/_
+   (sqrt(2)*sqrt(b-sqrt(-4+b^2)))-atan(x*sqrt(2)/sqrt(b+sqrt(-4+b^2)))*_
+   (1+(b+2*sqrt(2))/sqrt(-4+b^2))/(sqrt(2)*sqrt(b+sqrt(-4+b^2)))
+--R 
+--R
+--R   (2)
+--R                                 +-------------+
+--R           +------+              | +------+                   +-+
+--R           | 2          +-+      | | 2                      x\|2
+--R       (- \|b  - 4  + 2\|2  + b)\|\|b  - 4  + b atan(------------------)
+--R                                                      +---------------+
+--R                                                      |   +------+
+--R                                                      |   | 2
+--R                                                     \|- \|b  - 4  + b
+--R     + 
+--R                                 +---------------+
+--R           +------+              |   +------+                  +-+
+--R           | 2          +-+      |   | 2                     x\|2
+--R       (- \|b  - 4  - 2\|2  - b)\|- \|b  - 4  + b atan(----------------)
+--R                                                        +-------------+
+--R                                                        | +------+
+--R                                                        | | 2
+--R                                                       \|\|b  - 4  + b
+--R  /
+--R                   +---------------+ +-------------+
+--R          +------+ |   +------+      | +------+
+--R      +-+ | 2      |   | 2           | | 2
+--R     \|2 \|b  - 4 \|- \|b  - 4  + b \|\|b  - 4  + b
+--R                                                    Type: Expression(Integer)
+--E 2364
+
+--S 2365 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     -
+--R             +--------------------------------+
+--R             |          +------+
+--R             |          |   1
+--R             |          |  --
+--R             |   2      |  16      3       +-+
+--R             |(2b  - 8) |------  - - b - 2\|2
+--R             |          | 2        2
+--R          1  |         \|b  - 4
+--R          -  |--------------------------------
+--R          2  |              2
+--R            \|             b  - 4
+--R       *
+--R          log
+--R                                               +------+
+--R                                               |   1
+--R                                               |  --
+--R                     3     +-+ 2          +-+  |  16      1  2
+--R                 ((2b  + 2\|2 b  - 8b - 8\|2 ) |------  + - b  - 2)
+--R                                               | 2        2
+--R                                              \|b  - 4
+--R              *
+--R                  +--------------------------------+
+--R                  |          +------+
+--R                  |          |   1
+--R                  |          |  --
+--R                  |   2      |  16      3       +-+
+--R                  |(2b  - 8) |------  - - b - 2\|2
+--R                  |          | 2        2
+--R                  |         \|b  - 4
+--R                  |--------------------------------
+--R                  |              2
+--R                 \|             b  - 4
+--R             + 
+--R                      +-+
+--R                    3\|2
+--R               (b + -----)x
+--R                      2
+--R   + 
+--R          +----------------------------------+
+--R          |            +------+
+--R          |            |   1
+--R          |            |  --
+--R          |     2      |  16      3       +-+
+--R          |(- 2b  + 8) |------  - - b - 2\|2
+--R          |            | 2        2
+--R       1  |           \|b  - 4
+--R       -  |----------------------------------
+--R       2  |               2
+--R         \|              b  - 4
+--R    *
+--R       log
+--R                                            +------+
+--R                                            |   1
+--R                                            |  --
+--R                  3     +-+ 2          +-+  |  16      1  2
+--R              ((2b  + 2\|2 b  - 8b - 8\|2 ) |------  - - b  + 2)
+--R                                            | 2        2
+--R                                           \|b  - 4
+--R           *
+--R               +----------------------------------+
+--R               |            +------+
+--R               |            |   1
+--R               |            |  --
+--R               |     2      |  16      3       +-+
+--R               |(- 2b  + 8) |------  - - b - 2\|2
+--R               |            | 2        2
+--R               |           \|b  - 4
+--R               |----------------------------------
+--R               |               2
+--R              \|              b  - 4
+--R          + 
+--R                   +-+
+--R                 3\|2
+--R            (b + -----)x
+--R                   2
+--R   + 
+--R     -
+--R             +----------------------------------+
+--R             |            +------+
+--R             |            |   1
+--R             |            |  --
+--R             |     2      |  16      3       +-+
+--R             |(- 2b  + 8) |------  - - b - 2\|2
+--R             |            | 2        2
+--R          1  |           \|b  - 4
+--R          -  |----------------------------------
+--R          2  |               2
+--R            \|              b  - 4
+--R       *
+--R          log
+--R                                                 +------+
+--R                                                 |   1
+--R                                                 |  --
+--R                       3     +-+ 2          +-+  |  16      1  2
+--R                 ((- 2b  - 2\|2 b  + 8b + 8\|2 ) |------  + - b  - 2)
+--R                                                 | 2        2
+--R                                                \|b  - 4
+--R              *
+--R                  +----------------------------------+
+--R                  |            +------+
+--R                  |            |   1
+--R                  |            |  --
+--R                  |     2      |  16      3       +-+
+--R                  |(- 2b  + 8) |------  - - b - 2\|2
+--R                  |            | 2        2
+--R                  |           \|b  - 4
+--R                  |----------------------------------
+--R                  |               2
+--R                 \|              b  - 4
+--R             + 
+--R                      +-+
+--R                    3\|2
+--R               (b + -----)x
+--R                      2
+--R   + 
+--R          +--------------------------------+
+--R          |          +------+
+--R          |          |   1
+--R          |          |  --
+--R          |   2      |  16      3       +-+
+--R          |(2b  - 8) |------  - - b - 2\|2
+--R          |          | 2        2
+--R       1  |         \|b  - 4
+--R       -  |--------------------------------
+--R       2  |              2
+--R         \|             b  - 4
+--R    *
+--R       log
+--R                                              +------+
+--R                                              |   1
+--R                                              |  --
+--R                    3     +-+ 2          +-+  |  16      1  2
+--R              ((- 2b  - 2\|2 b  + 8b + 8\|2 ) |------  - - b  + 2)
+--R                                              | 2        2
+--R                                             \|b  - 4
+--R           *
+--R               +--------------------------------+
+--R               |          +------+
+--R               |          |   1
+--R               |          |  --
+--R               |   2      |  16      3       +-+
+--R               |(2b  - 8) |------  - - b - 2\|2
+--R               |          | 2        2
+--R               |         \|b  - 4
+--R               |--------------------------------
+--R               |              2
+--R              \|             b  - 4
+--R          + 
+--R                   +-+
+--R                 3\|2
+--R            (b + -----)x
+--R                   2
+--R                                 Type: Union(Expression(AlgebraicNumber),...)
+--E 2365
+
+--S 2366 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                          +--------------------------------+
+--R                                          |          +------+
+--R                                          |          |   1
+--R                                          |          |  --
+--R                                          |   2      |  16      3       +-+
+--R                        +---------------+ |(2b  - 8) |------  - - b - 2\|2
+--R               +------+ |   +------+      |          | 2        2
+--R            1  | 2      |   | 2           |         \|b  - 4
+--R            - \|b  - 4 \|- \|b  - 4  + b  |--------------------------------
+--R            2                             |              2
+--R                                         \|             b  - 4
+--R         *
+--R             +-------------+
+--R             | +------+
+--R             | | 2
+--R            \|\|b  - 4  + b
+--R         *
+--R            log
+--R                                                 +------+
+--R                                                 |   1
+--R                                                 |  --
+--R                       3     +-+ 2          +-+  |  16      1  2
+--R                   ((2b  + 2\|2 b  - 8b - 8\|2 ) |------  + - b  - 2)
+--R                                                 | 2        2
+--R                                                \|b  - 4
+--R                *
+--R                    +--------------------------------+
+--R                    |          +------+
+--R                    |          |   1
+--R                    |          |  --
+--R                    |   2      |  16      3       +-+
+--R                    |(2b  - 8) |------  - - b - 2\|2
+--R                    |          | 2        2
+--R                    |         \|b  - 4
+--R                    |--------------------------------
+--R                    |              2
+--R                   \|             b  - 4
+--R               + 
+--R                        +-+
+--R                      3\|2
+--R                 (b + -----)x
+--R                        2
+--R     + 
+--R                                       +----------------------------------+
+--R                                       |            +------+
+--R                                       |            |   1
+--R                                       |            |  --
+--R                                       |     2      |  16      3       +-+
+--R                     +---------------+ |(- 2b  + 8) |------  - - b - 2\|2
+--R            +------+ |   +------+      |            | 2        2
+--R         1  | 2      |   | 2           |           \|b  - 4
+--R         - \|b  - 4 \|- \|b  - 4  + b  |----------------------------------
+--R         2                             |               2
+--R                                      \|              b  - 4
+--R      *
+--R          +-------------+
+--R          | +------+
+--R          | | 2
+--R         \|\|b  - 4  + b
+--R      *
+--R         log
+--R                                              +------+
+--R                                              |   1
+--R                                              |  --
+--R                    3     +-+ 2          +-+  |  16      1  2
+--R                ((2b  + 2\|2 b  - 8b - 8\|2 ) |------  - - b  + 2)
+--R                                              | 2        2
+--R                                             \|b  - 4
+--R             *
+--R                 +----------------------------------+
+--R                 |            +------+
+--R                 |            |   1
+--R                 |            |  --
+--R                 |     2      |  16      3       +-+
+--R                 |(- 2b  + 8) |------  - - b - 2\|2
+--R                 |            | 2        2
+--R                 |           \|b  - 4
+--R                 |----------------------------------
+--R                 |               2
+--R                \|              b  - 4
+--R            + 
+--R                     +-+
+--R                   3\|2
+--R              (b + -----)x
+--R                     2
+--R     + 
+--R       -
+--R                                          +----------------------------------+
+--R                                          |            +------+
+--R                                          |            |   1
+--R                                          |            |  --
+--R                                          |     2      |  16      3       +-+
+--R                        +---------------+ |(- 2b  + 8) |------  - - b - 2\|2
+--R               +------+ |   +------+      |            | 2        2
+--R            1  | 2      |   | 2           |           \|b  - 4
+--R            - \|b  - 4 \|- \|b  - 4  + b  |----------------------------------
+--R            2                             |               2
+--R                                         \|              b  - 4
+--R         *
+--R             +-------------+
+--R             | +------+
+--R             | | 2
+--R            \|\|b  - 4  + b
+--R         *
+--R            log
+--R                                                   +------+
+--R                                                   |   1
+--R                                                   |  --
+--R                         3     +-+ 2          +-+  |  16      1  2
+--R                   ((- 2b  - 2\|2 b  + 8b + 8\|2 ) |------  + - b  - 2)
+--R                                                   | 2        2
+--R                                                  \|b  - 4
+--R                *
+--R                    +----------------------------------+
+--R                    |            +------+
+--R                    |            |   1
+--R                    |            |  --
+--R                    |     2      |  16      3       +-+
+--R                    |(- 2b  + 8) |------  - - b - 2\|2
+--R                    |            | 2        2
+--R                    |           \|b  - 4
+--R                    |----------------------------------
+--R                    |               2
+--R                   \|              b  - 4
+--R               + 
+--R                        +-+
+--R                      3\|2
+--R                 (b + -----)x
+--R                        2
+--R     + 
+--R                                       +--------------------------------+
+--R                                       |          +------+
+--R                                       |          |   1
+--R                                       |          |  --
+--R                                       |   2      |  16      3       +-+
+--R                     +---------------+ |(2b  - 8) |------  - - b - 2\|2
+--R            +------+ |   +------+      |          | 2        2
+--R         1  | 2      |   | 2           |         \|b  - 4
+--R         - \|b  - 4 \|- \|b  - 4  + b  |--------------------------------
+--R         2                             |              2
+--R                                      \|             b  - 4
+--R      *
+--R          +-------------+
+--R          | +------+
+--R          | | 2
+--R         \|\|b  - 4  + b
+--R      *
+--R         log
+--R                                                +------+
+--R                                                |   1
+--R                                                |  --
+--R                      3     +-+ 2          +-+  |  16      1  2
+--R                ((- 2b  - 2\|2 b  + 8b + 8\|2 ) |------  - - b  + 2)
+--R                                                | 2        2
+--R                                               \|b  - 4
+--R             *
+--R                 +--------------------------------+
+--R                 |          +------+
+--R                 |          |   1
+--R                 |          |  --
+--R                 |   2      |  16      3       +-+
+--R                 |(2b  - 8) |------  - - b - 2\|2
+--R                 |          | 2        2
+--R                 |         \|b  - 4
+--R                 |--------------------------------
+--R                 |              2
+--R                \|             b  - 4
+--R            + 
+--R                     +-+
+--R                   3\|2
+--R              (b + -----)x
+--R                     2
+--R     + 
+--R                                     +-------------+
+--R         +-+  +------+    +-+        | +------+                  +-+
+--R        \|2   | 2        \|2         | | 2                      \|2 x
+--R       (---- \|b  - 4  - ---- b - 2)\|\|b  - 4  + b atan(------------------)
+--R          2                2                              +---------------+
+--R                                                          |   +------+
+--R                                                          |   | 2
+--R                                                         \|- \|b  - 4  + b
+--R     + 
+--R                                     +---------------+
+--R         +-+  +------+    +-+        |   +------+                 +-+
+--R        \|2   | 2        \|2         |   | 2                     \|2 x
+--R       (---- \|b  - 4  + ---- b + 2)\|- \|b  - 4  + b atan(----------------)
+--R          2                2                                +-------------+
+--R                                                            | +------+
+--R                                                            | | 2
+--R                                                           \|\|b  - 4  + b
+--R  /
+--R               +---------------+ +-------------+
+--R      +------+ |   +------+      | +------+
+--R      | 2      |   | 2           | | 2
+--R     \|b  - 4 \|- \|b  - 4  + b \|\|b  - 4  + b
+--R                                            Type: Expression(AlgebraicNumber)
+--E 2366
+
+--S 2367 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                            Type: Expression(AlgebraicNumber)
+--E 2367
+
+)clear all
+
+--S 2368 of 3139
+t0:=(x^2+sqrt(2))/(1+b*x^2+x^4)
+--R 
+--R
+--R           2    +-+
+--R          x  + \|2
+--R   (1)  -------------
+--R         4      2
+--R        x  + b x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 2368
+
+--S 2369 of 3139
+r0:=atan(x*sqrt(2)/sqrt(b-sqrt(-4+b^2)))*(1+(-b+2*sqrt(2))/sqrt(-4+b^2))/_
+   (sqrt(2)*sqrt(b-sqrt(-4+b^2)))+atan(x*sqrt(2)/sqrt(b+sqrt(-4+b^2)))*_
+   (1+(b-2*sqrt(2))/sqrt(-4+b^2))/(sqrt(2)*sqrt(b+sqrt(-4+b^2)))
+--R 
+--R
+--R   (2)
+--R                               +-------------+
+--R         +------+              | +------+                   +-+
+--R         | 2          +-+      | | 2                      x\|2
+--R       (\|b  - 4  + 2\|2  - b)\|\|b  - 4  + b atan(------------------)
+--R                                                    +---------------+
+--R                                                    |   +------+
+--R                                                    |   | 2
+--R                                                   \|- \|b  - 4  + b
+--R     + 
+--R                               +---------------+
+--R         +------+              |   +------+                  +-+
+--R         | 2          +-+      |   | 2                     x\|2
+--R       (\|b  - 4  - 2\|2  + b)\|- \|b  - 4  + b atan(----------------)
+--R                                                      +-------------+
+--R                                                      | +------+
+--R                                                      | | 2
+--R                                                     \|\|b  - 4  + b
+--R  /
+--R                   +---------------+ +-------------+
+--R          +------+ |   +------+      | +------+
+--R      +-+ | 2      |   | 2           | | 2
+--R     \|2 \|b  - 4 \|- \|b  - 4  + b \|\|b  - 4  + b
+--R                                                    Type: Expression(Integer)
+--E 2369
+
+--S 2370 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +--------------------------------+
+--R          |          +------+
+--R          |          |   1
+--R          |          |  --
+--R          |   2      |  16      3       +-+
+--R          |(2b  - 8) |------  - - b + 2\|2
+--R          |          | 2        2
+--R       1  |         \|b  - 4
+--R       -  |--------------------------------
+--R       2  |              2
+--R         \|             b  - 4
+--R    *
+--R       log
+--R                                            +------+
+--R                                            |   1
+--R                                            |  --
+--R                  3     +-+ 2          +-+  |  16      1  2
+--R              ((2b  - 2\|2 b  - 8b + 8\|2 ) |------  + - b  - 2)
+--R                                            | 2        2
+--R                                           \|b  - 4
+--R           *
+--R               +--------------------------------+
+--R               |          +------+
+--R               |          |   1
+--R               |          |  --
+--R               |   2      |  16      3       +-+
+--R               |(2b  - 8) |------  - - b + 2\|2
+--R               |          | 2        2
+--R               |         \|b  - 4
+--R               |--------------------------------
+--R               |              2
+--R              \|             b  - 4
+--R          + 
+--R                   +-+
+--R                 3\|2
+--R            (b - -----)x
+--R                   2
+--R   + 
+--R     -
+--R             +----------------------------------+
+--R             |            +------+
+--R             |            |   1
+--R             |            |  --
+--R             |     2      |  16      3       +-+
+--R             |(- 2b  + 8) |------  - - b + 2\|2
+--R             |            | 2        2
+--R          1  |           \|b  - 4
+--R          -  |----------------------------------
+--R          2  |               2
+--R            \|              b  - 4
+--R       *
+--R          log
+--R                                               +------+
+--R                                               |   1
+--R                                               |  --
+--R                     3     +-+ 2          +-+  |  16      1  2
+--R                 ((2b  - 2\|2 b  - 8b + 8\|2 ) |------  - - b  + 2)
+--R                                               | 2        2
+--R                                              \|b  - 4
+--R              *
+--R                  +----------------------------------+
+--R                  |            +------+
+--R                  |            |   1
+--R                  |            |  --
+--R                  |     2      |  16      3       +-+
+--R                  |(- 2b  + 8) |------  - - b + 2\|2
+--R                  |            | 2        2
+--R                  |           \|b  - 4
+--R                  |----------------------------------
+--R                  |               2
+--R                 \|              b  - 4
+--R             + 
+--R                      +-+
+--R                    3\|2
+--R               (b - -----)x
+--R                      2
+--R   + 
+--R          +----------------------------------+
+--R          |            +------+
+--R          |            |   1
+--R          |            |  --
+--R          |     2      |  16      3       +-+
+--R          |(- 2b  + 8) |------  - - b + 2\|2
+--R          |            | 2        2
+--R       1  |           \|b  - 4
+--R       -  |----------------------------------
+--R       2  |               2
+--R         \|              b  - 4
+--R    *
+--R       log
+--R                                              +------+
+--R                                              |   1
+--R                                              |  --
+--R                    3     +-+ 2          +-+  |  16      1  2
+--R              ((- 2b  + 2\|2 b  + 8b - 8\|2 ) |------  + - b  - 2)
+--R                                              | 2        2
+--R                                             \|b  - 4
+--R           *
+--R               +----------------------------------+
+--R               |            +------+
+--R               |            |   1
+--R               |            |  --
+--R               |     2      |  16      3       +-+
+--R               |(- 2b  + 8) |------  - - b + 2\|2
+--R               |            | 2        2
+--R               |           \|b  - 4
+--R               |----------------------------------
+--R               |               2
+--R              \|              b  - 4
+--R          + 
+--R                   +-+
+--R                 3\|2
+--R            (b - -----)x
+--R                   2
+--R   + 
+--R     -
+--R             +--------------------------------+
+--R             |          +------+
+--R             |          |   1
+--R             |          |  --
+--R             |   2      |  16      3       +-+
+--R             |(2b  - 8) |------  - - b + 2\|2
+--R             |          | 2        2
+--R          1  |         \|b  - 4
+--R          -  |--------------------------------
+--R          2  |              2
+--R            \|             b  - 4
+--R       *
+--R          log
+--R                                                 +------+
+--R                                                 |   1
+--R                                                 |  --
+--R                       3     +-+ 2          +-+  |  16      1  2
+--R                 ((- 2b  + 2\|2 b  + 8b - 8\|2 ) |------  - - b  + 2)
+--R                                                 | 2        2
+--R                                                \|b  - 4
+--R              *
+--R                  +--------------------------------+
+--R                  |          +------+
+--R                  |          |   1
+--R                  |          |  --
+--R                  |   2      |  16      3       +-+
+--R                  |(2b  - 8) |------  - - b + 2\|2
+--R                  |          | 2        2
+--R                  |         \|b  - 4
+--R                  |--------------------------------
+--R                  |              2
+--R                 \|             b  - 4
+--R             + 
+--R                      +-+
+--R                    3\|2
+--R               (b - -----)x
+--R                      2
+--R                                 Type: Union(Expression(AlgebraicNumber),...)
+--E 2370
+
+--S 2371 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       +--------------------------------+
+--R                                       |          +------+
+--R                                       |          |   1
+--R                                       |          |  --
+--R                                       |   2      |  16      3       +-+
+--R                     +---------------+ |(2b  - 8) |------  - - b + 2\|2
+--R            +------+ |   +------+      |          | 2        2
+--R         1  | 2      |   | 2           |         \|b  - 4
+--R         - \|b  - 4 \|- \|b  - 4  + b  |--------------------------------
+--R         2                             |              2
+--R                                      \|             b  - 4
+--R      *
+--R          +-------------+
+--R          | +------+
+--R          | | 2
+--R         \|\|b  - 4  + b
+--R      *
+--R         log
+--R                                              +------+
+--R                                              |   1
+--R                                              |  --
+--R                    3     +-+ 2          +-+  |  16      1  2
+--R                ((2b  - 2\|2 b  - 8b + 8\|2 ) |------  + - b  - 2)
+--R                                              | 2        2
+--R                                             \|b  - 4
+--R             *
+--R                 +--------------------------------+
+--R                 |          +------+
+--R                 |          |   1
+--R                 |          |  --
+--R                 |   2      |  16      3       +-+
+--R                 |(2b  - 8) |------  - - b + 2\|2
+--R                 |          | 2        2
+--R                 |         \|b  - 4
+--R                 |--------------------------------
+--R                 |              2
+--R                \|             b  - 4
+--R            + 
+--R                     +-+
+--R                   3\|2
+--R              (b - -----)x
+--R                     2
+--R     + 
+--R       -
+--R                                          +----------------------------------+
+--R                                          |            +------+
+--R                                          |            |   1
+--R                                          |            |  --
+--R                                          |     2      |  16      3       +-+
+--R                        +---------------+ |(- 2b  + 8) |------  - - b + 2\|2
+--R               +------+ |   +------+      |            | 2        2
+--R            1  | 2      |   | 2           |           \|b  - 4
+--R            - \|b  - 4 \|- \|b  - 4  + b  |----------------------------------
+--R            2                             |               2
+--R                                         \|              b  - 4
+--R         *
+--R             +-------------+
+--R             | +------+
+--R             | | 2
+--R            \|\|b  - 4  + b
+--R         *
+--R            log
+--R                                                 +------+
+--R                                                 |   1
+--R                                                 |  --
+--R                       3     +-+ 2          +-+  |  16      1  2
+--R                   ((2b  - 2\|2 b  - 8b + 8\|2 ) |------  - - b  + 2)
+--R                                                 | 2        2
+--R                                                \|b  - 4
+--R                *
+--R                    +----------------------------------+
+--R                    |            +------+
+--R                    |            |   1
+--R                    |            |  --
+--R                    |     2      |  16      3       +-+
+--R                    |(- 2b  + 8) |------  - - b + 2\|2
+--R                    |            | 2        2
+--R                    |           \|b  - 4
+--R                    |----------------------------------
+--R                    |               2
+--R                   \|              b  - 4
+--R               + 
+--R                        +-+
+--R                      3\|2
+--R                 (b - -----)x
+--R                        2
+--R     + 
+--R                                       +----------------------------------+
+--R                                       |            +------+
+--R                                       |            |   1
+--R                                       |            |  --
+--R                                       |     2      |  16      3       +-+
+--R                     +---------------+ |(- 2b  + 8) |------  - - b + 2\|2
+--R            +------+ |   +------+      |            | 2        2
+--R         1  | 2      |   | 2           |           \|b  - 4
+--R         - \|b  - 4 \|- \|b  - 4  + b  |----------------------------------
+--R         2                             |               2
+--R                                      \|              b  - 4
+--R      *
+--R          +-------------+
+--R          | +------+
+--R          | | 2
+--R         \|\|b  - 4  + b
+--R      *
+--R         log
+--R                                                +------+
+--R                                                |   1
+--R                                                |  --
+--R                      3     +-+ 2          +-+  |  16      1  2
+--R                ((- 2b  + 2\|2 b  + 8b - 8\|2 ) |------  + - b  - 2)
+--R                                                | 2        2
+--R                                               \|b  - 4
+--R             *
+--R                 +----------------------------------+
+--R                 |            +------+
+--R                 |            |   1
+--R                 |            |  --
+--R                 |     2      |  16      3       +-+
+--R                 |(- 2b  + 8) |------  - - b + 2\|2
+--R                 |            | 2        2
+--R                 |           \|b  - 4
+--R                 |----------------------------------
+--R                 |               2
+--R                \|              b  - 4
+--R            + 
+--R                     +-+
+--R                   3\|2
+--R              (b - -----)x
+--R                     2
+--R     + 
+--R       -
+--R                                          +--------------------------------+
+--R                                          |          +------+
+--R                                          |          |   1
+--R                                          |          |  --
+--R                                          |   2      |  16      3       +-+
+--R                        +---------------+ |(2b  - 8) |------  - - b + 2\|2
+--R               +------+ |   +------+      |          | 2        2
+--R            1  | 2      |   | 2           |         \|b  - 4
+--R            - \|b  - 4 \|- \|b  - 4  + b  |--------------------------------
+--R            2                             |              2
+--R                                         \|             b  - 4
+--R         *
+--R             +-------------+
+--R             | +------+
+--R             | | 2
+--R            \|\|b  - 4  + b
+--R         *
+--R            log
+--R                                                   +------+
+--R                                                   |   1
+--R                                                   |  --
+--R                         3     +-+ 2          +-+  |  16      1  2
+--R                   ((- 2b  + 2\|2 b  + 8b - 8\|2 ) |------  - - b  + 2)
+--R                                                   | 2        2
+--R                                                  \|b  - 4
+--R                *
+--R                    +--------------------------------+
+--R                    |          +------+
+--R                    |          |   1
+--R                    |          |  --
+--R                    |   2      |  16      3       +-+
+--R                    |(2b  - 8) |------  - - b + 2\|2
+--R                    |          | 2        2
+--R                    |         \|b  - 4
+--R                    |--------------------------------
+--R                    |              2
+--R                   \|             b  - 4
+--R               + 
+--R                        +-+
+--R                      3\|2
+--R                 (b - -----)x
+--R                        2
+--R     + 
+--R                                       +-------------+
+--R           +-+  +------+    +-+        | +------+                  +-+
+--R          \|2   | 2        \|2         | | 2                      \|2 x
+--R       (- ---- \|b  - 4  + ---- b - 2)\|\|b  - 4  + b atan(------------------)
+--R            2                2                              +---------------+
+--R                                                            |   +------+
+--R                                                            |   | 2
+--R                                                           \|- \|b  - 4  + b
+--R     + 
+--R                                       +---------------+
+--R           +-+  +------+    +-+        |   +------+                 +-+
+--R          \|2   | 2        \|2         |   | 2                     \|2 x
+--R       (- ---- \|b  - 4  - ---- b + 2)\|- \|b  - 4  + b atan(----------------)
+--R            2                2                                +-------------+
+--R                                                              | +------+
+--R                                                              | | 2
+--R                                                             \|\|b  - 4  + b
+--R  /
+--R               +---------------+ +-------------+
+--R      +------+ |   +------+      | +------+
+--R      | 2      |   | 2           | | 2
+--R     \|b  - 4 \|- \|b  - 4  + b \|\|b  - 4  + b
+--R                                            Type: Expression(AlgebraicNumber)
+--E 2371
+
+--S 2372 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                            Type: Expression(AlgebraicNumber)
+--E 2372
+
+)clear all
+
+--S 2373 of 3139
+t0:=(2*a-x^2)/(a^2-a*x^2+x^4)
+--R 
+--R
+--R              2
+--R           - x  + 2a
+--R   (1)  --------------
+--R         4      2    2
+--R        x  - a x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2373
+
+--S 2374 of 3139
+r0:=atanh(x*sqrt(2)/sqrt(a-sqrt(3)*sqrt(-a^2)))*sqrt(a-sqrt(3)*sqrt(-a^2))/_
+   (a*sqrt(2))+atanh(x*sqrt(2)/sqrt(a+sqrt(3)*sqrt(-a^2)))*sqrt(a+sqrt(3)*_
+   sqrt(-a^2))/(a*sqrt(2))
+--R 
+--R
+--R   (2)
+--R        +-----------------+
+--R        |       +----+                     +-+
+--R        |   +-+ |   2                    x\|2
+--R       \|- \|3 \|- a   + a atanh(--------------------)
+--R                                  +-----------------+
+--R                                  |       +----+
+--R                                  |   +-+ |   2
+--R                                 \|- \|3 \|- a   + a
+--R     + 
+--R        +---------------+
+--R        |     +----+                    +-+
+--R        | +-+ |   2                   x\|2
+--R       \|\|3 \|- a   + a atanh(------------------)
+--R                                +---------------+
+--R                                |     +----+
+--R                                | +-+ |   2
+--R                               \|\|3 \|- a   + a
+--R  /
+--R       +-+
+--R     a\|2
+--R                                                    Type: Expression(Integer)
+--E 2374
+
+--S 2375 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          +----+
+--R                          |  3
+--R                  atan(4a |---- )
+--R          +--+            |   2
+--R          | 1            \|16a
+--R          |-- cos(---------------)
+--R         4| 2            2
+--R         \|a
+--R      *
+--R         log
+--R                                   +----+  2                       +----+  2
+--R                                   |  3                            |  3
+--R                           atan(4a |---- )                 atan(4a |---- )
+--R                  +--+2            |   2          +--+2            |   2
+--R               2  | 1             \|16a        2  | 1             \|16a
+--R              a   |--  sin(---------------) + a   |--  cos(---------------)
+--R                 4| 2             2              4| 2             2
+--R                 \|a                             \|a
+--R            + 
+--R                                    +----+
+--R                                    |  3
+--R                            atan(4a |---- )
+--R                    +--+            |   2
+--R                    | 1            \|16a       2
+--R              2a x  |-- cos(--------------- + x
+--R                   4| 2            2
+--R                   \|a
+--R     + 
+--R       -
+--R                             +----+
+--R                             |  3
+--R                     atan(4a |---- )
+--R             +--+            |   2
+--R             | 1            \|16a
+--R             |-- cos(---------------)
+--R            4| 2            2
+--R            \|a
+--R         *
+--R            log
+--R                                      +----+  2                       +----+  2
+--R                                      |  3                            |  3
+--R                              atan(4a |---- )                 atan(4a |---- )
+--R                     +--+2            |   2          +--+2            |   2
+--R                  2  | 1             \|16a        2  | 1             \|16a
+--R                 a   |--  sin(---------------) + a   |--  cos(---------------)
+--R                    4| 2             2              4| 2             2
+--R                    \|a                             \|a
+--R               + 
+--R                                         +----+
+--R                                         |  3
+--R                                 atan(4a |---- )
+--R                         +--+            |   2
+--R                         | 1            \|16a       2
+--R                 - 2a x  |-- cos(--------------- + x
+--R                        4| 2            2
+--R                        \|a
+--R     + 
+--R                                                            +----+
+--R                                                            |  3
+--R                                                    atan(4a |---- )
+--R                          +----+            +--+            |   2
+--R                          |  3              | 1            \|16a
+--R                  atan(4a |---- )        a  |-- sin(---------------)
+--R          +--+            |   2            4| 2            2
+--R          | 1            \|16a             \|a
+--R       2  |-- sin(---------------)atan(------------------------------)
+--R         4| 2            2                                +----+
+--R         \|a                                              |  3
+--R                                                  atan(4a |---- )
+--R                                          +--+            |   2
+--R                                          | 1            \|16a
+--R                                       a  |-- cos(--------------- - x
+--R                                         4| 2            2
+--R                                         \|a
+--R     + 
+--R                                                              +----+
+--R                                                              |  3
+--R                                                      atan(4a |---- )
+--R                            +----+            +--+            |   2
+--R                            |  3              | 1            \|16a
+--R                    atan(4a |---- )        a  |-- sin(---------------)
+--R            +--+            |   2            4| 2            2
+--R            | 1            \|16a             \|a
+--R       - 2  |-- sin(---------------)atan(------------------------------)
+--R           4| 2            2                                +----+
+--R           \|a                                              |  3
+--R                                                    atan(4a |---- )
+--R                                            +--+            |   2
+--R                                            | 1            \|16a
+--R                                         a  |-- cos(--------------- + x
+--R                                           4| 2            2
+--R                                           \|a
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2375
+
+--S 2376 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +----+
+--R                                |  3
+--R                        atan(4a |---- )
+--R                +--+            |   2
+--R           +-+  | 1            \|16a
+--R         a\|2   |-- cos(---------------)
+--R               4| 2            2
+--R               \|a
+--R      *
+--R         log
+--R                                   +----+  2                       +----+  2
+--R                                   |  3                            |  3
+--R                           atan(4a |---- )                 atan(4a |---- )
+--R                  +--+2            |   2          +--+2            |   2
+--R               2  | 1             \|16a        2  | 1             \|16a
+--R              a   |--  sin(---------------) + a   |--  cos(---------------)
+--R                 4| 2             2              4| 2             2
+--R                 \|a                             \|a
+--R            + 
+--R                                    +----+
+--R                                    |  3
+--R                            atan(4a |---- )
+--R                    +--+            |   2
+--R                    | 1            \|16a       2
+--R              2a x  |-- cos(--------------- + x
+--R                   4| 2            2
+--R                   \|a
+--R     + 
+--R       -
+--R                                   +----+
+--R                                   |  3
+--R                           atan(4a |---- )
+--R                   +--+            |   2
+--R              +-+  | 1            \|16a
+--R            a\|2   |-- cos(---------------)
+--R                  4| 2            2
+--R                  \|a
+--R         *
+--R            log
+--R                                      +----+  2                       +----+  2
+--R                                      |  3                            |  3
+--R                              atan(4a |---- )                 atan(4a |---- )
+--R                     +--+2            |   2          +--+2            |   2
+--R                  2  | 1             \|16a        2  | 1             \|16a
+--R                 a   |--  sin(---------------) + a   |--  cos(---------------)
+--R                    4| 2             2              4| 2             2
+--R                    \|a                             \|a
+--R               + 
+--R                                         +----+
+--R                                         |  3
+--R                                 atan(4a |---- )
+--R                         +--+            |   2
+--R                         | 1            \|16a       2
+--R                 - 2a x  |-- cos(--------------- + x
+--R                        4| 2            2
+--R                        \|a
+--R     + 
+--R                                                                 +----+
+--R                                                                 |  3
+--R                                                         atan(4a |---- )
+--R                               +----+            +--+            |   2
+--R                               |  3              | 1            \|16a
+--R                       atan(4a |---- )        a  |-- sin(---------------)
+--R               +--+            |   2            4| 2            2
+--R          +-+  | 1            \|16a             \|a
+--R       2a\|2   |-- sin(---------------)atan(------------------------------)
+--R              4| 2            2                                +----+
+--R              \|a                                              |  3
+--R                                                       atan(4a |---- )
+--R                                               +--+            |   2
+--R                                               | 1            \|16a
+--R                                            a  |-- cos(--------------- - x
+--R                                              4| 2            2
+--R                                              \|a
+--R     + 
+--R                                                                   +----+
+--R                                                                   |  3
+--R                                                           atan(4a |---- )
+--R                                 +----+            +--+            |   2
+--R                                 |  3              | 1            \|16a
+--R                         atan(4a |---- )        a  |-- sin(---------------)
+--R                 +--+            |   2            4| 2            2
+--R            +-+  | 1            \|16a             \|a
+--R       - 2a\|2   |-- sin(---------------)atan(------------------------------)
+--R                4| 2            2                                +----+
+--R                \|a                                              |  3
+--R                                                         atan(4a |---- )
+--R                                                 +--+            |   2
+--R                                                 | 1            \|16a
+--R                                              a  |-- cos(--------------- + x
+--R                                                4| 2            2
+--R                                                \|a
+--R     + 
+--R           +-----------------+
+--R           |       +----+                     +-+
+--R           |   +-+ |   2                    x\|2
+--R       - 2\|- \|3 \|- a   + a atanh(--------------------)
+--R                                     +-----------------+
+--R                                     |       +----+
+--R                                     |   +-+ |   2
+--R                                    \|- \|3 \|- a   + a
+--R     + 
+--R           +---------------+
+--R           |     +----+                    +-+
+--R           | +-+ |   2                   x\|2
+--R       - 2\|\|3 \|- a   + a atanh(------------------)
+--R                                   +---------------+
+--R                                   |     +----+
+--R                                   | +-+ |   2
+--R                                  \|\|3 \|- a   + a
+--R  /
+--R        +-+
+--R     2a\|2
+--R                                                    Type: Expression(Integer)
+--E 2376
+
+--S 2377 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                 +----+  8
+--R                                 |  3
+--R                         atan(4a |---- )
+--R                                 |   2
+--R          3 4    4 2            \|16a
+--R       (2a x  - a x )sin(---------------)
+--R                                2
+--R     + 
+--R                                     +----+  2
+--R                                     |  3
+--R                             atan(4a |---- )
+--R                                     |   2                                +--+2
+--R             3 4     4 2            \|16a           3 6     4 4     5 2   | 1
+--R         ((8a x  - 4a x )cos(---------------)  + (6a x  - 2a x  - 2a x )  |-- )
+--R                                    2                                    4| 2
+--R                                                                         \|a
+--R      *
+--R                     +----+  6
+--R                     |  3
+--R             atan(4a |---- )
+--R                     |   2
+--R                    \|16a
+--R         sin(---------------)
+--R                    2
+--R     + 
+--R                                       +----+  4
+--R                                       |  3
+--R                               atan(4a |---- )
+--R                                       |   2
+--R               3 4     4 2            \|16a
+--R           (12a x  - 6a x )cos(---------------)
+--R                                      2
+--R         + 
+--R                                                     +----+  2
+--R                                                     |  3
+--R                                             atan(4a |---- )
+--R                                    +--+2            |   2
+--R              3 6     4 4     5 2   | 1             \|16a           8     3 4
+--R           (6a x  - 2a x  - 2a x )  |--  cos(---------------) + 6a x  - 6a x
+--R                                   4| 2             2
+--R                                   \|a
+--R      *
+--R                     +----+  4
+--R                     |  3
+--R             atan(4a |---- )
+--R                     |   2
+--R                    \|16a
+--R         sin(---------------)
+--R                    2
+--R     + 
+--R                                      +----+  6
+--R                                      |  3
+--R                              atan(4a |---- )
+--R                                      |   2
+--R              3 4     4 2            \|16a
+--R           (8a x  - 4a x )cos(---------------)
+--R                                     2
+--R         + 
+--R                                                       +----+  4
+--R                                                       |  3
+--R                                               atan(4a |---- )
+--R                                      +--+2            |   2
+--R                3 6     4 4     5 2   | 1             \|16a
+--R           (- 6a x  + 2a x  + 2a x )  |--  cos(---------------)
+--R                                     4| 2             2
+--R                                     \|a
+--R         + 
+--R                                      +----+  2
+--R                                      |  3
+--R                              atan(4a |---- )
+--R                                      |   2                                 +--+2
+--R                8     3 4            \|16a             10     2 8     3 6   | 1
+--R         (- 4a x  + 4a x )cos(---------------)  + (2a x   + 2a x  - 6a x )  |--
+--R                                     2                                     4| 2
+--R                                                                           \|a
+--R      *
+--R                     +----+  2
+--R                     |  3
+--R             atan(4a |---- )
+--R                     |   2
+--R                    \|16a
+--R         sin(---------------)
+--R                    2
+--R     + 
+--R                                 +----+  8
+--R                                 |  3
+--R                         atan(4a |---- )
+--R                                 |   2
+--R          3 4    4 2            \|16a
+--R       (2a x  - a x )cos(---------------)
+--R                                2
+--R     + 
+--R                                                   +----+  6
+--R                                                   |  3
+--R                                           atan(4a |---- )
+--R                                  +--+2            |   2
+--R            3 6     4 4     5 2   | 1             \|16a
+--R       (- 6a x  + 2a x  + 2a x )  |--  cos(---------------)
+--R                                 4| 2             2
+--R                                 \|a
+--R     + 
+--R                                  +----+  4
+--R                                  |  3
+--R                          atan(4a |---- )
+--R                                  |   2
+--R            8     3 4            \|16a
+--R       (6a x  - 6a x )cos(---------------)
+--R                                 2
+--R     + 
+--R                                                    +----+  2
+--R                                                    |  3
+--R                                            atan(4a |---- )
+--R                                   +--+2            |   2
+--R              10     2 8     3 6   | 1             \|16a        10       8
+--R       (- 2a x   - 2a x  + 6a x )  |--  cos(---------------) + x   - 2a x
+--R                                  4| 2             2
+--R                                  \|a
+--R  /
+--R                                     +----+  8
+--R                                     |  3
+--R                             atan(4a |---- )
+--R                                     |   2
+--R         4 4    5 2    6            \|16a
+--R       (a x  - a x  + a )sin(---------------)
+--R                                    2
+--R     + 
+--R                                            +----+  2
+--R                                            |  3
+--R                                    atan(4a |---- )
+--R                                            |   2
+--R              4 4     5 2     6            \|16a
+--R           (4a x  - 4a x  + 4a )cos(---------------)
+--R                                           2
+--R         + 
+--R                                    +--+2
+--R              4 6     5 4     6 2   | 1
+--R           (4a x  - 4a x  + 4a x )  |--
+--R                                   4| 2
+--R                                   \|a
+--R      *
+--R                     +----+  6
+--R                     |  3
+--R             atan(4a |---- )
+--R                     |   2
+--R                    \|16a
+--R         sin(---------------)
+--R                    2
+--R     + 
+--R                                            +----+  4
+--R                                            |  3
+--R                                    atan(4a |---- )
+--R                                            |   2
+--R              4 4     5 2     6            \|16a
+--R           (6a x  - 6a x  + 6a )cos(---------------)
+--R                                           2
+--R         + 
+--R                                                     +----+  2
+--R                                                     |  3
+--R                                             atan(4a |---- )
+--R                                    +--+2            |   2
+--R              4 6     5 4     6 2   | 1             \|16a         2 8     3 6
+--R           (4a x  - 4a x  + 4a x )  |--  cos(---------------) + 6a x  - 6a x
+--R                                   4| 2             2
+--R                                   \|a
+--R         + 
+--R             4 4
+--R           6a x
+--R      *
+--R                     +----+  4
+--R                     |  3
+--R             atan(4a |---- )
+--R                     |   2
+--R                    \|16a
+--R         sin(---------------)
+--R                    2
+--R     + 
+--R                                            +----+  6
+--R                                            |  3
+--R                                    atan(4a |---- )
+--R                                            |   2
+--R              4 4     5 2     6            \|16a
+--R           (4a x  - 4a x  + 4a )cos(---------------)
+--R                                           2
+--R         + 
+--R                                                       +----+  4
+--R                                                       |  3
+--R                                               atan(4a |---- )
+--R                                      +--+2            |   2
+--R                4 6     5 4     6 2   | 1             \|16a
+--R           (- 4a x  + 4a x  - 4a x )  |--  cos(---------------)
+--R                                     4| 2             2
+--R                                     \|a
+--R         + 
+--R                                                +----+  2
+--R                                                |  3
+--R                                        atan(4a |---- )
+--R                                                |   2
+--R                2 8     3 6     4 4            \|16a
+--R           (- 4a x  + 4a x  - 4a x )cos(---------------)
+--R                                               2
+--R         + 
+--R                                     +--+2
+--R              2 10     3 8     4 6   | 1
+--R           (4a x   - 4a x  + 4a x )  |--
+--R                                    4| 2
+--R                                    \|a
+--R      *
+--R                     +----+  2
+--R                     |  3
+--R             atan(4a |---- )
+--R                     |   2
+--R                    \|16a
+--R         sin(---------------)
+--R                    2
+--R     + 
+--R                                     +----+  8
+--R                                     |  3
+--R                             atan(4a |---- )
+--R                                     |   2
+--R         4 4    5 2    6            \|16a
+--R       (a x  - a x  + a )cos(---------------)
+--R                                    2
+--R     + 
+--R                                                   +----+  6
+--R                                                   |  3
+--R                                           atan(4a |---- )
+--R                                  +--+2            |   2
+--R            4 6     5 4     6 2   | 1             \|16a
+--R       (- 4a x  + 4a x  - 4a x )  |--  cos(---------------)
+--R                                 4| 2             2
+--R                                 \|a
+--R     + 
+--R                                          +----+  4
+--R                                          |  3
+--R                                  atan(4a |---- )
+--R                                          |   2
+--R          2 8     3 6     4 4            \|16a
+--R       (6a x  - 6a x  + 6a x )cos(---------------)
+--R                                         2
+--R     + 
+--R                                                  +----+  2
+--R                                                  |  3
+--R                                          atan(4a |---- )
+--R                                 +--+2            |   2
+--R          2 10     3 8     4 6   | 1             \|16a        12      10    2 8
+--R     (- 4a x   + 4a x  - 4a x )  |--  cos(---------------) + x   - a x   + a x
+--R                                4| 2             2
+--R                                \|a
+--R                                                    Type: Expression(Integer)
+--E 2377
+
+)clear all
+
+--S 2378 of 3139
+t0:=(-x^2+2*sqrt(a))/(a+x^4-x^2*sqrt(a))
+--R 
+--R
+--R              +-+    2
+--R          - 2\|a  + x
+--R   (1)  ---------------
+--R         2 +-+    4
+--R        x \|a  - x  - a
+--R                                                    Type: Expression(Integer)
+--E 2378
+
+--S 2379 of 3139
+r0:=atan(x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)-sqrt(a)))*sqrt(sqrt(3)*sqrt(-a)-_
+   sqrt(a))/(sqrt(2)*sqrt(a))+atanh(x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)+_
+   sqrt(a)))*sqrt(sqrt(3)*sqrt(-a)+sqrt(a))/(sqrt(2)*sqrt(a))
+--R 
+--R
+--R   (2)
+--R        +-----------------+                +-+
+--R        | +-+    +-+ +---+               x\|2
+--R       \|\|a  + \|3 \|- a  atanh(--------------------)
+--R                                  +-----------------+
+--R                                  | +-+    +-+ +---+
+--R                                 \|\|a  + \|3 \|- a
+--R     + 
+--R        +-------------------+                +-+
+--R        |   +-+    +-+ +---+               x\|2
+--R       \|- \|a  + \|3 \|- a  atan(----------------------)
+--R                                   +-------------------+
+--R                                   |   +-+    +-+ +---+
+--R                                  \|- \|a  + \|3 \|- a
+--R  /
+--R      +-+ +-+
+--R     \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 2379
+
+--S 2380 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        +-----------------+      +-----------------+
+--R        |   +-----+              |   +-----+
+--R        |   |   3   +-+          |   |   3   +-+
+--R        |4  |- --- \|a + 1       |4  |- --- \|a + 1
+--R        |  \|  16a               |  \|  16a              +-+
+--R        |----------------- log(a |-----------------  + x\|a )
+--R        |        +-+             |        +-+
+--R       \|      2\|a             \|      2\|a
+--R     + 
+--R        +-------------------+      +-------------------+
+--R        |     +-----+              |     +-----+
+--R        |     |   3   +-+          |     |   3   +-+
+--R        |- 4  |- --- \|a + 1       |- 4  |- --- \|a + 1
+--R        |    \|  16a               |    \|  16a              +-+
+--R        |------------------- log(a |-------------------  + x\|a )
+--R        |         +-+              |         +-+
+--R       \|       2\|a              \|       2\|a
+--R     + 
+--R          +-------------------+        +-------------------+
+--R          |     +-----+                |     +-----+
+--R          |     |   3   +-+            |     |   3   +-+
+--R          |- 4  |- --- \|a + 1         |- 4  |- --- \|a + 1
+--R          |    \|  16a                 |    \|  16a              +-+
+--R       -  |------------------- log(- a |-------------------  + x\|a )
+--R          |         +-+                |         +-+
+--R         \|       2\|a                \|       2\|a
+--R     + 
+--R          +-----------------+        +-----------------+
+--R          |   +-----+                |   +-----+
+--R          |   |   3   +-+            |   |   3   +-+
+--R          |4  |- --- \|a + 1         |4  |- --- \|a + 1
+--R          |  \|  16a                 |  \|  16a              +-+
+--R       -  |----------------- log(- a |-----------------  + x\|a )
+--R          |        +-+               |        +-+
+--R         \|      2\|a               \|      2\|a
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2380
+
+--S 2381 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-----------------+      +-----------------+
+--R                |   +-----+              |   +-----+
+--R                |   |   3   +-+          |   |   3   +-+
+--R                |4  |- --- \|a + 1       |4  |- --- \|a + 1
+--R        +-+ +-+ |  \|  16a               |  \|  16a              +-+
+--R       \|2 \|a  |----------------- log(a |-----------------  + x\|a )
+--R                |        +-+             |        +-+
+--R               \|      2\|a             \|      2\|a
+--R     + 
+--R                +-------------------+      +-------------------+
+--R                |     +-----+              |     +-----+
+--R                |     |   3   +-+          |     |   3   +-+
+--R                |- 4  |- --- \|a + 1       |- 4  |- --- \|a + 1
+--R        +-+ +-+ |    \|  16a               |    \|  16a              +-+
+--R       \|2 \|a  |------------------- log(a |-------------------  + x\|a )
+--R                |         +-+              |         +-+
+--R               \|       2\|a              \|       2\|a
+--R     + 
+--R                  +-------------------+        +-------------------+
+--R                  |     +-----+                |     +-----+
+--R                  |     |   3   +-+            |     |   3   +-+
+--R                  |- 4  |- --- \|a + 1         |- 4  |- --- \|a + 1
+--R          +-+ +-+ |    \|  16a                 |    \|  16a              +-+
+--R       - \|2 \|a  |------------------- log(- a |-------------------  + x\|a )
+--R                  |         +-+                |         +-+
+--R                 \|       2\|a                \|       2\|a
+--R     + 
+--R                  +-----------------+        +-----------------+
+--R                  |   +-----+                |   +-----+
+--R                  |   |   3   +-+            |   |   3   +-+
+--R                  |4  |- --- \|a + 1         |4  |- --- \|a + 1
+--R          +-+ +-+ |  \|  16a                 |  \|  16a              +-+
+--R       - \|2 \|a  |----------------- log(- a |-----------------  + x\|a )
+--R                  |        +-+               |        +-+
+--R                 \|      2\|a               \|      2\|a
+--R     + 
+--R           +-----------------+                +-+
+--R           | +-+    +-+ +---+               x\|2
+--R       - 2\|\|a  + \|3 \|- a  atanh(--------------------)
+--R                                     +-----------------+
+--R                                     | +-+    +-+ +---+
+--R                                    \|\|a  + \|3 \|- a
+--R     + 
+--R           +-------------------+                +-+
+--R           |   +-+    +-+ +---+               x\|2
+--R       - 2\|- \|a  + \|3 \|- a  atan(----------------------)
+--R                                      +-------------------+
+--R                                      |   +-+    +-+ +---+
+--R                                     \|- \|a  + \|3 \|- a
+--R  /
+--R       +-+ +-+
+--R     2\|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 2381
+
+--S 2382 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2382
+
+)clear all
+
+--S 2383 of 3139
+t0:=(A+B*x^2)/(a^2-a*x^2+x^4)
+--R 
+--R
+--R              2
+--R           B x  + A
+--R   (1)  --------------
+--R         4      2    2
+--R        x  - a x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2383
+
+--S 2384 of 3139
+r0:=-atanh(x*sqrt(2)/sqrt(a-sqrt(3)*sqrt(-a^2)))*(B*sqrt(3)+(-2*A-a*B)/_
+   sqrt(-a^2))/(sqrt(6)*sqrt(a-sqrt(3)*sqrt(-a^2)))-atanh(x*sqrt(2)/_
+   sqrt(a+sqrt(3)*sqrt(-a^2)))*(B*sqrt(3)+(2*A+a*B)/sqrt(-a^2))/(sqrt(6)*_
+   sqrt(a+sqrt(3)*sqrt(-a^2)))
+--R 
+--R
+--R   (2)
+--R                                   +---------------+
+--R                +----+             |     +----+                     +-+
+--R            +-+ |   2              | +-+ |   2                    x\|2
+--R       (- B\|3 \|- a   + B a + 2A)\|\|3 \|- a   + a atanh(--------------------)
+--R                                                           +-----------------+
+--R                                                           |       +----+
+--R                                                           |   +-+ |   2
+--R                                                          \|- \|3 \|- a   + a
+--R     + 
+--R                                   +-----------------+
+--R                +----+             |       +----+                    +-+
+--R            +-+ |   2              |   +-+ |   2                   x\|2
+--R       (- B\|3 \|- a   - B a - 2A)\|- \|3 \|- a   + a atanh(------------------)
+--R                                                             +---------------+
+--R                                                             |     +----+
+--R                                                             | +-+ |   2
+--R                                                            \|\|3 \|- a   + a
+--R  /
+--R                 +-----------------+ +---------------+
+--R          +----+ |       +----+      |     +----+
+--R      +-+ |   2  |   +-+ |   2       | +-+ |   2
+--R     \|6 \|- a  \|- \|3 \|- a   + a \|\|3 \|- a   + a
+--R                                                    Type: Expression(Integer)
+--E 2384
+
+--S 2385 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +--------------------------------------+
+--R          | 4 4       3 3     2 2 2     3       4
+--R          |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R          |--------------------------------------
+--R         4|                    6
+--R         \|                  9a
+--R      *
+--R                       +-------------------+
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R      *
+--R         log
+--R                                 +--------------------------------------+2
+--R                                 | 4 4       3 3     2 2 2     3       4
+--R                   2 6     2 4   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                (3B a  - 3A a )  |--------------------------------------
+--R                                4|                    6
+--R                                \|                  9a
+--R             *
+--R                              +-------------------+  2
+--R                              | 4 4     2 2 2    4
+--R                            3 |B a  - 2A B a  + A
+--R                         12a  |-------------------
+--R                              |           6
+--R                             \|        48a
+--R                    atan(--------------------------)
+--R                              2 2             2
+--R                             B a  + 4A B a + A
+--R                sin(--------------------------------)
+--R                                    2
+--R            + 
+--R                                   +-------------------+
+--R                                   | 4 4     2 2 2    4
+--R                      6        5   |B a  - 2A B a  + A
+--R                (24B a  + 12A a )x |-------------------
+--R                                   |           6
+--R                                  \|        48a
+--R             *
+--R                 +--------------------------------------+
+--R                 | 4 4       3 3     2 2 2     3       4
+--R                 |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                 |--------------------------------------
+--R                4|                    6
+--R                \|                  9a
+--R             *
+--R                              +-------------------+
+--R                              | 4 4     2 2 2    4
+--R                            3 |B a  - 2A B a  + A
+--R                         12a  |-------------------
+--R                              |           6
+--R                             \|        48a
+--R                    atan(--------------------------)
+--R                              2 2             2
+--R                             B a  + 4A B a + A
+--R                sin(--------------------------------)
+--R                                    2
+--R            + 
+--R                                 +--------------------------------------+2
+--R                                 | 4 4       3 3     2 2 2     3       4
+--R                   2 6     2 4   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                (3B a  - 3A a )  |--------------------------------------
+--R                                4|                    6
+--R                                \|                  9a
+--R             *
+--R                              +-------------------+  2
+--R                              | 4 4     2 2 2    4
+--R                            3 |B a  - 2A B a  + A
+--R                         12a  |-------------------
+--R                              |           6
+--R                             \|        48a
+--R                    atan(--------------------------)
+--R                              2 2             2
+--R                             B a  + 4A B a + A
+--R                cos(--------------------------------)
+--R                                    2
+--R            + 
+--R                                    +--------------------------------------+
+--R                                    | 4 4       3 3     2 2 2     3       4
+--R                     2 4     3 2    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                (3A B a  - 3A a )x  |--------------------------------------
+--R                                   4|                    6
+--R                                   \|                  9a
+--R             *
+--R                              +-------------------+
+--R                              | 4 4     2 2 2    4
+--R                            3 |B a  - 2A B a  + A
+--R                         12a  |-------------------
+--R                              |           6
+--R                             \|        48a
+--R                    atan(--------------------------)
+--R                              2 2             2
+--R                             B a  + 4A B a + A
+--R                cos(--------------------------------)
+--R                                    2
+--R            + 
+--R                4 4      3 3    3       4  2
+--R              (B a  + A B a  - A B a - A )x
+--R     + 
+--R       -
+--R             +--------------------------------------+
+--R             | 4 4       3 3     2 2 2     3       4
+--R             |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R             |--------------------------------------
+--R            4|                    6
+--R            \|                  9a
+--R         *
+--R                          +-------------------+
+--R                          | 4 4     2 2 2    4
+--R                        3 |B a  - 2A B a  + A
+--R                     12a  |-------------------
+--R                          |           6
+--R                         \|        48a
+--R                atan(--------------------------)
+--R                          2 2             2
+--R                         B a  + 4A B a + A
+--R            cos(--------------------------------)
+--R                                2
+--R         *
+--R            log
+--R                                    +--------------------------------------+2
+--R                                    | 4 4       3 3     2 2 2     3       4
+--R                      2 6     2 4   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                   (3B a  - 3A a )  |--------------------------------------
+--R                                   4|                    6
+--R                                   \|                  9a
+--R                *
+--R                                 +-------------------+  2
+--R                                 | 4 4     2 2 2    4
+--R                               3 |B a  - 2A B a  + A
+--R                            12a  |-------------------
+--R                                 |           6
+--R                                \|        48a
+--R                       atan(--------------------------)
+--R                                 2 2             2
+--R                                B a  + 4A B a + A
+--R                   sin(--------------------------------)
+--R                                       2
+--R               + 
+--R                                        +-------------------+
+--R                                        | 4 4     2 2 2    4
+--R                           6        5   |B a  - 2A B a  + A
+--R                   (- 24B a  - 12A a )x |-------------------
+--R                                        |           6
+--R                                       \|        48a
+--R                *
+--R                    +--------------------------------------+
+--R                    | 4 4       3 3     2 2 2     3       4
+--R                    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                    |--------------------------------------
+--R                   4|                    6
+--R                   \|                  9a
+--R                *
+--R                                 +-------------------+
+--R                                 | 4 4     2 2 2    4
+--R                               3 |B a  - 2A B a  + A
+--R                            12a  |-------------------
+--R                                 |           6
+--R                                \|        48a
+--R                       atan(--------------------------)
+--R                                 2 2             2
+--R                                B a  + 4A B a + A
+--R                   sin(--------------------------------)
+--R                                       2
+--R               + 
+--R                                    +--------------------------------------+2
+--R                                    | 4 4       3 3     2 2 2     3       4
+--R                      2 6     2 4   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                   (3B a  - 3A a )  |--------------------------------------
+--R                                   4|                    6
+--R                                   \|                  9a
+--R                *
+--R                                 +-------------------+  2
+--R                                 | 4 4     2 2 2    4
+--R                               3 |B a  - 2A B a  + A
+--R                            12a  |-------------------
+--R                                 |           6
+--R                                \|        48a
+--R                       atan(--------------------------)
+--R                                 2 2             2
+--R                                B a  + 4A B a + A
+--R                   cos(--------------------------------)
+--R                                       2
+--R               + 
+--R                                         +--------------------------------------+
+--R                                         | 4 4       3 3     2 2 2     3       4
+--R                          2 4     3 2    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                   (- 3A B a  + 3A a )x  |--------------------------------------
+--R                                        4|                    6
+--R                                        \|                  9a
+--R                *
+--R                                 +-------------------+
+--R                                 | 4 4     2 2 2    4
+--R                               3 |B a  - 2A B a  + A
+--R                            12a  |-------------------
+--R                                 |           6
+--R                                \|        48a
+--R                       atan(--------------------------)
+--R                                 2 2             2
+--R                                B a  + 4A B a + A
+--R                   cos(--------------------------------)
+--R                                       2
+--R               + 
+--R                   4 4      3 3    3       4  2
+--R                 (B a  + A B a  - A B a - A )x
+--R     + 
+--R            +--------------------------------------+
+--R            | 4 4       3 3     2 2 2     3       4
+--R            |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R         2  |--------------------------------------
+--R           4|                    6
+--R           \|                  9a
+--R      *
+--R                       +-------------------+
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R      *
+--R         atan
+--R                                     +--------------------------------------+
+--R                                     | 4 4       3 3     2 2 2     3       4
+--R                       2 4     3 2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                  (3A B a  - 3A a )  |--------------------------------------
+--R                                    4|                    6
+--R                                    \|                  9a
+--R               *
+--R                                +-------------------+
+--R                                | 4 4     2 2 2    4
+--R                              3 |B a  - 2A B a  + A
+--R                           12a  |-------------------
+--R                                |           6
+--R                               \|        48a
+--R                      atan(--------------------------)
+--R                                2 2             2
+--R                               B a  + 4A B a + A
+--R                  sin(--------------------------------)
+--R                                      2
+--R              + 
+--R                                      +-------------------+
+--R                                      | 4 4     2 2 2    4
+--R                          6        5  |B a  - 2A B a  + A
+--R                  (- 24B a  - 12A a ) |-------------------
+--R                                      |           6
+--R                                     \|        48a
+--R               *
+--R                   +--------------------------------------+
+--R                   | 4 4       3 3     2 2 2     3       4
+--R                   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                   |--------------------------------------
+--R                  4|                    6
+--R                  \|                  9a
+--R               *
+--R                                +-------------------+
+--R                                | 4 4     2 2 2    4
+--R                              3 |B a  - 2A B a  + A
+--R                           12a  |-------------------
+--R                                |           6
+--R                               \|        48a
+--R                      atan(--------------------------)
+--R                                2 2             2
+--R                               B a  + 4A B a + A
+--R                  cos(--------------------------------)
+--R                                      2
+--R           /
+--R                                    +-------------------+
+--R                                    | 4 4     2 2 2    4
+--R                        6        5  |B a  - 2A B a  + A
+--R                  (24B a  + 12A a ) |-------------------
+--R                                    |           6
+--R                                   \|        48a
+--R               *
+--R                   +--------------------------------------+
+--R                   | 4 4       3 3     2 2 2     3       4
+--R                   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                   |--------------------------------------
+--R                  4|                    6
+--R                  \|                  9a
+--R               *
+--R                                +-------------------+
+--R                                | 4 4     2 2 2    4
+--R                              3 |B a  - 2A B a  + A
+--R                           12a  |-------------------
+--R                                |           6
+--R                               \|        48a
+--R                      atan(--------------------------)
+--R                                2 2             2
+--R                               B a  + 4A B a + A
+--R                  sin(--------------------------------)
+--R                                      2
+--R              + 
+--R                                     +--------------------------------------+
+--R                                     | 4 4       3 3     2 2 2     3       4
+--R                       2 4     3 2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                  (3A B a  - 3A a )  |--------------------------------------
+--R                                    4|                    6
+--R                                    \|                  9a
+--R               *
+--R                                +-------------------+
+--R                                | 4 4     2 2 2    4
+--R                              3 |B a  - 2A B a  + A
+--R                           12a  |-------------------
+--R                                |           6
+--R                               \|        48a
+--R                      atan(--------------------------)
+--R                                2 2             2
+--R                               B a  + 4A B a + A
+--R                  cos(--------------------------------)
+--R                                      2
+--R              + 
+--R                     4 4       3 3     3        4
+--R                (- 2B a  - 2A B a  + 2A B a + 2A )x
+--R     + 
+--R       -
+--R               +--------------------------------------+
+--R               | 4 4       3 3     2 2 2     3       4
+--R               |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R            2  |--------------------------------------
+--R              4|                    6
+--R              \|                  9a
+--R         *
+--R                          +-------------------+
+--R                          | 4 4     2 2 2    4
+--R                        3 |B a  - 2A B a  + A
+--R                     12a  |-------------------
+--R                          |           6
+--R                         \|        48a
+--R                atan(--------------------------)
+--R                          2 2             2
+--R                         B a  + 4A B a + A
+--R            sin(--------------------------------)
+--R                                2
+--R         *
+--R            atan
+--R                                        +--------------------------------------+
+--R                                        | 4 4       3 3     2 2 2     3       4
+--R                          2 4     3 2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                     (3A B a  - 3A a )  |--------------------------------------
+--R                                       4|                    6
+--R                                       \|                  9a
+--R                  *
+--R                                   +-------------------+
+--R                                   | 4 4     2 2 2    4
+--R                                 3 |B a  - 2A B a  + A
+--R                              12a  |-------------------
+--R                                   |           6
+--R                                  \|        48a
+--R                         atan(--------------------------)
+--R                                   2 2             2
+--R                                  B a  + 4A B a + A
+--R                     sin(--------------------------------)
+--R                                         2
+--R                 + 
+--R                                         +-------------------+
+--R                                         | 4 4     2 2 2    4
+--R                             6        5  |B a  - 2A B a  + A
+--R                     (- 24B a  - 12A a ) |-------------------
+--R                                         |           6
+--R                                        \|        48a
+--R                  *
+--R                      +--------------------------------------+
+--R                      | 4 4       3 3     2 2 2     3       4
+--R                      |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                      |--------------------------------------
+--R                     4|                    6
+--R                     \|                  9a
+--R                  *
+--R                                   +-------------------+
+--R                                   | 4 4     2 2 2    4
+--R                                 3 |B a  - 2A B a  + A
+--R                              12a  |-------------------
+--R                                   |           6
+--R                                  \|        48a
+--R                         atan(--------------------------)
+--R                                   2 2             2
+--R                                  B a  + 4A B a + A
+--R                     cos(--------------------------------)
+--R                                         2
+--R              /
+--R                                       +-------------------+
+--R                                       | 4 4     2 2 2    4
+--R                           6        5  |B a  - 2A B a  + A
+--R                     (24B a  + 12A a ) |-------------------
+--R                                       |           6
+--R                                      \|        48a
+--R                  *
+--R                      +--------------------------------------+
+--R                      | 4 4       3 3     2 2 2     3       4
+--R                      |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                      |--------------------------------------
+--R                     4|                    6
+--R                     \|                  9a
+--R                  *
+--R                                   +-------------------+
+--R                                   | 4 4     2 2 2    4
+--R                                 3 |B a  - 2A B a  + A
+--R                              12a  |-------------------
+--R                                   |           6
+--R                                  \|        48a
+--R                         atan(--------------------------)
+--R                                   2 2             2
+--R                                  B a  + 4A B a + A
+--R                     sin(--------------------------------)
+--R                                         2
+--R                 + 
+--R                                        +--------------------------------------+
+--R                                        | 4 4       3 3     2 2 2     3       4
+--R                          2 4     3 2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                     (3A B a  - 3A a )  |--------------------------------------
+--R                                       4|                    6
+--R                                       \|                  9a
+--R                  *
+--R                                   +-------------------+
+--R                                   | 4 4     2 2 2    4
+--R                                 3 |B a  - 2A B a  + A
+--R                              12a  |-------------------
+--R                                   |           6
+--R                                  \|        48a
+--R                         atan(--------------------------)
+--R                                   2 2             2
+--R                                  B a  + 4A B a + A
+--R                     cos(--------------------------------)
+--R                                         2
+--R                 + 
+--R                      4 4       3 3     3        4
+--R                   (2B a  + 2A B a  - 2A B a - 2A )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2385
+
+--S 2386 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +--------------------------------------+
+--R              +----+  | 4 4       3 3     2 2 2     3       4
+--R          +-+ |   2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R         \|6 \|- a    |--------------------------------------
+--R                     4|                    6
+--R                     \|                  9a
+--R      *
+--R          +-----------------+ +---------------+
+--R          |       +----+      |     +----+
+--R          |   +-+ |   2       | +-+ |   2
+--R         \|- \|3 \|- a   + a \|\|3 \|- a   + a
+--R      *
+--R                       +-------------------+
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R      *
+--R         log
+--R                                 +--------------------------------------+2
+--R                                 | 4 4       3 3     2 2 2     3       4
+--R                   2 6     2 4   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                (3B a  - 3A a )  |--------------------------------------
+--R                                4|                    6
+--R                                \|                  9a
+--R             *
+--R                              +-------------------+  2
+--R                              | 4 4     2 2 2    4
+--R                            3 |B a  - 2A B a  + A
+--R                         12a  |-------------------
+--R                              |           6
+--R                             \|        48a
+--R                    atan(--------------------------)
+--R                              2 2             2
+--R                             B a  + 4A B a + A
+--R                sin(--------------------------------)
+--R                                    2
+--R            + 
+--R                                   +-------------------+
+--R                                   | 4 4     2 2 2    4
+--R                      6        5   |B a  - 2A B a  + A
+--R                (24B a  + 12A a )x |-------------------
+--R                                   |           6
+--R                                  \|        48a
+--R             *
+--R                 +--------------------------------------+
+--R                 | 4 4       3 3     2 2 2     3       4
+--R                 |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                 |--------------------------------------
+--R                4|                    6
+--R                \|                  9a
+--R             *
+--R                              +-------------------+
+--R                              | 4 4     2 2 2    4
+--R                            3 |B a  - 2A B a  + A
+--R                         12a  |-------------------
+--R                              |           6
+--R                             \|        48a
+--R                    atan(--------------------------)
+--R                              2 2             2
+--R                             B a  + 4A B a + A
+--R                sin(--------------------------------)
+--R                                    2
+--R            + 
+--R                                 +--------------------------------------+2
+--R                                 | 4 4       3 3     2 2 2     3       4
+--R                   2 6     2 4   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                (3B a  - 3A a )  |--------------------------------------
+--R                                4|                    6
+--R                                \|                  9a
+--R             *
+--R                              +-------------------+  2
+--R                              | 4 4     2 2 2    4
+--R                            3 |B a  - 2A B a  + A
+--R                         12a  |-------------------
+--R                              |           6
+--R                             \|        48a
+--R                    atan(--------------------------)
+--R                              2 2             2
+--R                             B a  + 4A B a + A
+--R                cos(--------------------------------)
+--R                                    2
+--R            + 
+--R                                    +--------------------------------------+
+--R                                    | 4 4       3 3     2 2 2     3       4
+--R                     2 4     3 2    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                (3A B a  - 3A a )x  |--------------------------------------
+--R                                   4|                    6
+--R                                   \|                  9a
+--R             *
+--R                              +-------------------+
+--R                              | 4 4     2 2 2    4
+--R                            3 |B a  - 2A B a  + A
+--R                         12a  |-------------------
+--R                              |           6
+--R                             \|        48a
+--R                    atan(--------------------------)
+--R                              2 2             2
+--R                             B a  + 4A B a + A
+--R                cos(--------------------------------)
+--R                                    2
+--R            + 
+--R                4 4      3 3    3       4  2
+--R              (B a  + A B a  - A B a - A )x
+--R     + 
+--R       -
+--R                         +--------------------------------------+
+--R                 +----+  | 4 4       3 3     2 2 2     3       4
+--R             +-+ |   2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R            \|6 \|- a    |--------------------------------------
+--R                        4|                    6
+--R                        \|                  9a
+--R         *
+--R             +-----------------+ +---------------+
+--R             |       +----+      |     +----+
+--R             |   +-+ |   2       | +-+ |   2
+--R            \|- \|3 \|- a   + a \|\|3 \|- a   + a
+--R         *
+--R                          +-------------------+
+--R                          | 4 4     2 2 2    4
+--R                        3 |B a  - 2A B a  + A
+--R                     12a  |-------------------
+--R                          |           6
+--R                         \|        48a
+--R                atan(--------------------------)
+--R                          2 2             2
+--R                         B a  + 4A B a + A
+--R            cos(--------------------------------)
+--R                                2
+--R         *
+--R            log
+--R                                    +--------------------------------------+2
+--R                                    | 4 4       3 3     2 2 2     3       4
+--R                      2 6     2 4   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                   (3B a  - 3A a )  |--------------------------------------
+--R                                   4|                    6
+--R                                   \|                  9a
+--R                *
+--R                                 +-------------------+  2
+--R                                 | 4 4     2 2 2    4
+--R                               3 |B a  - 2A B a  + A
+--R                            12a  |-------------------
+--R                                 |           6
+--R                                \|        48a
+--R                       atan(--------------------------)
+--R                                 2 2             2
+--R                                B a  + 4A B a + A
+--R                   sin(--------------------------------)
+--R                                       2
+--R               + 
+--R                                        +-------------------+
+--R                                        | 4 4     2 2 2    4
+--R                           6        5   |B a  - 2A B a  + A
+--R                   (- 24B a  - 12A a )x |-------------------
+--R                                        |           6
+--R                                       \|        48a
+--R                *
+--R                    +--------------------------------------+
+--R                    | 4 4       3 3     2 2 2     3       4
+--R                    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                    |--------------------------------------
+--R                   4|                    6
+--R                   \|                  9a
+--R                *
+--R                                 +-------------------+
+--R                                 | 4 4     2 2 2    4
+--R                               3 |B a  - 2A B a  + A
+--R                            12a  |-------------------
+--R                                 |           6
+--R                                \|        48a
+--R                       atan(--------------------------)
+--R                                 2 2             2
+--R                                B a  + 4A B a + A
+--R                   sin(--------------------------------)
+--R                                       2
+--R               + 
+--R                                    +--------------------------------------+2
+--R                                    | 4 4       3 3     2 2 2     3       4
+--R                      2 6     2 4   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                   (3B a  - 3A a )  |--------------------------------------
+--R                                   4|                    6
+--R                                   \|                  9a
+--R                *
+--R                                 +-------------------+  2
+--R                                 | 4 4     2 2 2    4
+--R                               3 |B a  - 2A B a  + A
+--R                            12a  |-------------------
+--R                                 |           6
+--R                                \|        48a
+--R                       atan(--------------------------)
+--R                                 2 2             2
+--R                                B a  + 4A B a + A
+--R                   cos(--------------------------------)
+--R                                       2
+--R               + 
+--R                                         +--------------------------------------+
+--R                                         | 4 4       3 3     2 2 2     3       4
+--R                          2 4     3 2    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                   (- 3A B a  + 3A a )x  |--------------------------------------
+--R                                        4|                    6
+--R                                        \|                  9a
+--R                *
+--R                                 +-------------------+
+--R                                 | 4 4     2 2 2    4
+--R                               3 |B a  - 2A B a  + A
+--R                            12a  |-------------------
+--R                                 |           6
+--R                                \|        48a
+--R                       atan(--------------------------)
+--R                                 2 2             2
+--R                                B a  + 4A B a + A
+--R                   cos(--------------------------------)
+--R                                       2
+--R               + 
+--R                   4 4      3 3    3       4  2
+--R                 (B a  + A B a  - A B a - A )x
+--R     + 
+--R                       +--------------------------------------+
+--R               +----+  | 4 4       3 3     2 2 2     3       4
+--R           +-+ |   2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R         2\|6 \|- a    |--------------------------------------
+--R                      4|                    6
+--R                      \|                  9a
+--R      *
+--R          +-----------------+ +---------------+
+--R          |       +----+      |     +----+
+--R          |   +-+ |   2       | +-+ |   2
+--R         \|- \|3 \|- a   + a \|\|3 \|- a   + a
+--R      *
+--R                       +-------------------+
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R      *
+--R         atan
+--R                                     +--------------------------------------+
+--R                                     | 4 4       3 3     2 2 2     3       4
+--R                       2 4     3 2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                  (3A B a  - 3A a )  |--------------------------------------
+--R                                    4|                    6
+--R                                    \|                  9a
+--R               *
+--R                                +-------------------+
+--R                                | 4 4     2 2 2    4
+--R                              3 |B a  - 2A B a  + A
+--R                           12a  |-------------------
+--R                                |           6
+--R                               \|        48a
+--R                      atan(--------------------------)
+--R                                2 2             2
+--R                               B a  + 4A B a + A
+--R                  sin(--------------------------------)
+--R                                      2
+--R              + 
+--R                                      +-------------------+
+--R                                      | 4 4     2 2 2    4
+--R                          6        5  |B a  - 2A B a  + A
+--R                  (- 24B a  - 12A a ) |-------------------
+--R                                      |           6
+--R                                     \|        48a
+--R               *
+--R                   +--------------------------------------+
+--R                   | 4 4       3 3     2 2 2     3       4
+--R                   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                   |--------------------------------------
+--R                  4|                    6
+--R                  \|                  9a
+--R               *
+--R                                +-------------------+
+--R                                | 4 4     2 2 2    4
+--R                              3 |B a  - 2A B a  + A
+--R                           12a  |-------------------
+--R                                |           6
+--R                               \|        48a
+--R                      atan(--------------------------)
+--R                                2 2             2
+--R                               B a  + 4A B a + A
+--R                  cos(--------------------------------)
+--R                                      2
+--R           /
+--R                                    +-------------------+
+--R                                    | 4 4     2 2 2    4
+--R                        6        5  |B a  - 2A B a  + A
+--R                  (24B a  + 12A a ) |-------------------
+--R                                    |           6
+--R                                   \|        48a
+--R               *
+--R                   +--------------------------------------+
+--R                   | 4 4       3 3     2 2 2     3       4
+--R                   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                   |--------------------------------------
+--R                  4|                    6
+--R                  \|                  9a
+--R               *
+--R                                +-------------------+
+--R                                | 4 4     2 2 2    4
+--R                              3 |B a  - 2A B a  + A
+--R                           12a  |-------------------
+--R                                |           6
+--R                               \|        48a
+--R                      atan(--------------------------)
+--R                                2 2             2
+--R                               B a  + 4A B a + A
+--R                  sin(--------------------------------)
+--R                                      2
+--R              + 
+--R                                     +--------------------------------------+
+--R                                     | 4 4       3 3     2 2 2     3       4
+--R                       2 4     3 2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                  (3A B a  - 3A a )  |--------------------------------------
+--R                                    4|                    6
+--R                                    \|                  9a
+--R               *
+--R                                +-------------------+
+--R                                | 4 4     2 2 2    4
+--R                              3 |B a  - 2A B a  + A
+--R                           12a  |-------------------
+--R                                |           6
+--R                               \|        48a
+--R                      atan(--------------------------)
+--R                                2 2             2
+--R                               B a  + 4A B a + A
+--R                  cos(--------------------------------)
+--R                                      2
+--R              + 
+--R                     4 4       3 3     3        4
+--R                (- 2B a  - 2A B a  + 2A B a + 2A )x
+--R     + 
+--R       -
+--R                          +--------------------------------------+
+--R                  +----+  | 4 4       3 3     2 2 2     3       4
+--R              +-+ |   2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R            2\|6 \|- a    |--------------------------------------
+--R                         4|                    6
+--R                         \|                  9a
+--R         *
+--R             +-----------------+ +---------------+
+--R             |       +----+      |     +----+
+--R             |   +-+ |   2       | +-+ |   2
+--R            \|- \|3 \|- a   + a \|\|3 \|- a   + a
+--R         *
+--R                          +-------------------+
+--R                          | 4 4     2 2 2    4
+--R                        3 |B a  - 2A B a  + A
+--R                     12a  |-------------------
+--R                          |           6
+--R                         \|        48a
+--R                atan(--------------------------)
+--R                          2 2             2
+--R                         B a  + 4A B a + A
+--R            sin(--------------------------------)
+--R                                2
+--R         *
+--R            atan
+--R                                        +--------------------------------------+
+--R                                        | 4 4       3 3     2 2 2     3       4
+--R                          2 4     3 2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                     (3A B a  - 3A a )  |--------------------------------------
+--R                                       4|                    6
+--R                                       \|                  9a
+--R                  *
+--R                                   +-------------------+
+--R                                   | 4 4     2 2 2    4
+--R                                 3 |B a  - 2A B a  + A
+--R                              12a  |-------------------
+--R                                   |           6
+--R                                  \|        48a
+--R                         atan(--------------------------)
+--R                                   2 2             2
+--R                                  B a  + 4A B a + A
+--R                     sin(--------------------------------)
+--R                                         2
+--R                 + 
+--R                                         +-------------------+
+--R                                         | 4 4     2 2 2    4
+--R                             6        5  |B a  - 2A B a  + A
+--R                     (- 24B a  - 12A a ) |-------------------
+--R                                         |           6
+--R                                        \|        48a
+--R                  *
+--R                      +--------------------------------------+
+--R                      | 4 4       3 3     2 2 2     3       4
+--R                      |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                      |--------------------------------------
+--R                     4|                    6
+--R                     \|                  9a
+--R                  *
+--R                                   +-------------------+
+--R                                   | 4 4     2 2 2    4
+--R                                 3 |B a  - 2A B a  + A
+--R                              12a  |-------------------
+--R                                   |           6
+--R                                  \|        48a
+--R                         atan(--------------------------)
+--R                                   2 2             2
+--R                                  B a  + 4A B a + A
+--R                     cos(--------------------------------)
+--R                                         2
+--R              /
+--R                                       +-------------------+
+--R                                       | 4 4     2 2 2    4
+--R                           6        5  |B a  - 2A B a  + A
+--R                     (24B a  + 12A a ) |-------------------
+--R                                       |           6
+--R                                      \|        48a
+--R                  *
+--R                      +--------------------------------------+
+--R                      | 4 4       3 3     2 2 2     3       4
+--R                      |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                      |--------------------------------------
+--R                     4|                    6
+--R                     \|                  9a
+--R                  *
+--R                                   +-------------------+
+--R                                   | 4 4     2 2 2    4
+--R                                 3 |B a  - 2A B a  + A
+--R                              12a  |-------------------
+--R                                   |           6
+--R                                  \|        48a
+--R                         atan(--------------------------)
+--R                                   2 2             2
+--R                                  B a  + 4A B a + A
+--R                     sin(--------------------------------)
+--R                                         2
+--R                 + 
+--R                                        +--------------------------------------+
+--R                                        | 4 4       3 3     2 2 2     3       4
+--R                          2 4     3 2   |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R                     (3A B a  - 3A a )  |--------------------------------------
+--R                                       4|                    6
+--R                                       \|                  9a
+--R                  *
+--R                                   +-------------------+
+--R                                   | 4 4     2 2 2    4
+--R                                 3 |B a  - 2A B a  + A
+--R                              12a  |-------------------
+--R                                   |           6
+--R                                  \|        48a
+--R                         atan(--------------------------)
+--R                                   2 2             2
+--R                                  B a  + 4A B a + A
+--R                     cos(--------------------------------)
+--R                                         2
+--R                 + 
+--R                      4 4       3 3     3        4
+--R                   (2B a  + 2A B a  - 2A B a - 2A )x
+--R     + 
+--R                                   +---------------+
+--R               +----+              |     +----+                     +-+
+--R           +-+ |   2               | +-+ |   2                    x\|2
+--R       (2B\|3 \|- a   - 2B a - 4A)\|\|3 \|- a   + a atanh(--------------------)
+--R                                                           +-----------------+
+--R                                                           |       +----+
+--R                                                           |   +-+ |   2
+--R                                                          \|- \|3 \|- a   + a
+--R     + 
+--R                                   +-----------------+
+--R               +----+              |       +----+                    +-+
+--R           +-+ |   2               |   +-+ |   2                   x\|2
+--R       (2B\|3 \|- a   + 2B a + 4A)\|- \|3 \|- a   + a atanh(------------------)
+--R                                                             +---------------+
+--R                                                             |     +----+
+--R                                                             | +-+ |   2
+--R                                                            \|\|3 \|- a   + a
+--R  /
+--R                  +-----------------+ +---------------+
+--R           +----+ |       +----+      |     +----+
+--R       +-+ |   2  |   +-+ |   2       | +-+ |   2
+--R     2\|6 \|- a  \|- \|3 \|- a   + a \|\|3 \|- a   + a
+--R                                                    Type: Expression(Integer)
+--E 2386
+
+--S 2387 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                   7 10       6 9     2 5 8     4 3 6     5 2 5    6   4  2
+--R               (- B a   - 2A B a  - 2A B a  + 2A B a  + 2A B a  + A B a )x
+--R             + 
+--R                    6 10     2 5 9     3 4 8     5 2 6     6   5    7 4
+--R               - A B a   - 2A B a  - 2A B a  + 2A B a  + 2A B a  + A a
+--R          *
+--R              +-+ +-+ +-+
+--R             \|2 \|3 \|6
+--R         + 
+--R                6 8      2 5 7      3 4 6      5 2 4      6   3     7 2  4
+--R           (6A B a  + 12A B a  + 12A B a  - 12A B a  - 12A B a  - 6A a )x
+--R         + 
+--R                  6 9      2 5 8      3 4 7      5 2 5      6   4     7 3  2
+--R           (- 6A B a  - 12A B a  - 12A B a  + 12A B a  + 12A B a  + 6A a )x
+--R         + 
+--R               6 10      2 5 9      3 4 8      5 2 6      6   5     7 4
+--R           6A B a   + 12A B a  + 12A B a  - 12A B a  - 12A B a  - 6A a
+--R      *
+--R                       +-------------------+  8
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                             7 10       6 9     2 5 8     4 3 6     5 2 5
+--R                         - 4B a   - 8A B a  - 8A B a  + 8A B a  + 8A B a
+--R                       + 
+--R                           6   4
+--R                         4A B a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                         6 10     2 5 9     3 4 8     5 2 6     6   5     7 4
+--R                   - 4A B a   - 8A B a  - 8A B a  + 8A B a  + 8A B a  + 4A a
+--R              *
+--R                  +-+ +-+ +-+
+--R                 \|2 \|3 \|6
+--R             + 
+--R                     6 8      2 5 7      3 4 6      5 2 4      6   3      7 2  4
+--R               (24A B a  + 48A B a  + 48A B a  - 48A B a  - 48A B a  - 24A a )x
+--R             + 
+--R                            6 9      2 5 8      3 4 7      5 2 5      6   4
+--R                     - 24A B a  - 48A B a  - 48A B a  + 48A B a  + 48A B a
+--R                   + 
+--R                        7 3
+--R                     24A a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                    6 10      2 5 9      3 4 8      5 2 6      6   5      7 4
+--R               24A B a   + 48A B a  + 48A B a  - 48A B a  - 48A B a  - 24A a
+--R          *
+--R                           +-------------------+  2
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                       5 10        4 9      2 3 8      3 2 7     4   6  4
+--R                   (12B a   + 12A B a  - 18A B a  - 12A B a  + 6A B a )x
+--R                 + 
+--R                         4 10      2 3 9      3 2 8      4   7     5 6  2
+--R                   (12A B a   + 12A B a  - 18A B a  - 12A B a  + 6A a )x
+--R              *
+--R                  +-+ +-+ +-+
+--R                 \|2 \|3 \|6
+--R             + 
+--R                       4 8      2 3 7      3 2 6      4   5      5 4  6
+--R               (- 18A B a  - 18A B a  + 54A B a  + 18A B a  - 36A a )x
+--R             + 
+--R                     4 9      2 3 8      3 2 7      4   6      5 5  4
+--R               (18A B a  + 18A B a  - 54A B a  - 18A B a  + 36A a )x
+--R             + 
+--R                       4 10      2 3 9      3 2 8      4   7      5 6  2
+--R               (- 18A B a   - 18A B a  + 54A B a  + 18A B a  - 36A a )x
+--R          *
+--R              +--------------------------------------+2
+--R              | 4 4       3 3     2 2 2     3       4
+--R              |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |--------------------------------------
+--R             4|                    6
+--R             \|                  9a
+--R      *
+--R                       +-------------------+  6
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                   2 10       2   9  4        2   10       3 9  2  +-+ +-+ +-+
+--R           ((288A B a   + 144A B a )x  + (288A B a   + 144A a )x )\|2 \|3 \|6
+--R         + 
+--R                  3 10         2 9        2   8       3 7  6
+--R           (- 288B a   - 432A B a  - 1296A B a  - 576A a )x
+--R         + 
+--R                3 11         2 10        2   9       3 8  4
+--R           (288B a   + 432A B a   + 1296A B a  + 576A a )x
+--R         + 
+--R                  3 12         2 11        2   10       3 9  2
+--R           (- 288B a   - 432A B a   - 1296A B a   - 576A a )x
+--R      *
+--R          +-------------------+  +--------------------------------------+2
+--R          | 4 4     2 2 2    4   | 4 4       3 3     2 2 2     3       4
+--R          |B a  - 2A B a  + A    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R          |-------------------   |--------------------------------------
+--R          |           6         4|                    6
+--R         \|        48a          \|                  9a
+--R      *
+--R                       +-------------------+
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R      *
+--R                       +-------------------+  5
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                           7 10        6 9      2 5 8      4 3 6      5 2 5
+--R                       - 6B a   - 12A B a  - 12A B a  + 12A B a  + 12A B a
+--R                     + 
+--R                         6   4
+--R                       6A B a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                       6 10      2 5 9      3 4 8      5 2 6      6   5     7 4
+--R                 - 6A B a   - 12A B a  - 12A B a  + 12A B a  + 12A B a  + 6A a
+--R              *
+--R                  +-+ +-+ +-+
+--R                 \|2 \|3 \|6
+--R             + 
+--R                     6 8      2 5 7      3 4 6      5 2 4      6   3      7 2  4
+--R               (36A B a  + 72A B a  + 72A B a  - 72A B a  - 72A B a  - 36A a )x
+--R             + 
+--R                            6 9      2 5 8      3 4 7      5 2 5      6   4
+--R                     - 36A B a  - 72A B a  - 72A B a  + 72A B a  + 72A B a
+--R                   + 
+--R                        7 3
+--R                     36A a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                    6 10      2 5 9      3 4 8      5 2 6      6   5      7 4
+--R               36A B a   + 72A B a  + 72A B a  - 72A B a  - 72A B a  - 36A a
+--R          *
+--R                           +-------------------+  4
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                       5 10        4 9      2 3 8      3 2 7     4   6  4
+--R                   (12B a   + 12A B a  - 18A B a  - 12A B a  + 6A B a )x
+--R                 + 
+--R                         4 10      2 3 9      3 2 8      4   7     5 6  2
+--R                   (12A B a   + 12A B a  - 18A B a  - 12A B a  + 6A a )x
+--R              *
+--R                  +-+ +-+ +-+
+--R                 \|2 \|3 \|6
+--R             + 
+--R                       4 8      2 3 7      3 2 6      4   5      5 4  6
+--R               (- 18A B a  - 18A B a  + 54A B a  + 18A B a  - 36A a )x
+--R             + 
+--R                     4 9      2 3 8      3 2 7      4   6      5 5  4
+--R               (18A B a  + 18A B a  - 54A B a  - 18A B a  + 36A a )x
+--R             + 
+--R                       4 10      2 3 9      3 2 8      4   7      5 6  2
+--R               (- 18A B a   - 18A B a  + 54A B a  + 18A B a  - 36A a )x
+--R          *
+--R              +--------------------------------------+2
+--R              | 4 4       3 3     2 2 2     3       4
+--R              |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |--------------------------------------
+--R             4|                    6
+--R             \|                  9a
+--R          *
+--R                           +-------------------+  2
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                    7 8        6 7      3 4 5     4 3 4     6   2  6
+--R               (- 6B a  - 12A B a  + 12A B a  + 3A B a  + 3A B a )x
+--R             + 
+--R                      6 8      2 5 7      4 3 5     5 2 4     7 2  4
+--R               (- 6A B a  - 12A B a  + 12A B a  + 3A B a  + 3A a )x
+--R          *
+--R              +-+ +-+ +-+
+--R             \|2 \|3 \|6
+--R         + 
+--R                     6 6      2 5 5     3 4 4      4 3 3      5 2 2     6
+--R               - 6A B a  - 12A B a  + 6A B a  + 18A B a  + 12A B a  - 6A B a
+--R             + 
+--R                    7
+--R               - 12A
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                   6 7      2 5 6     3 4 5      4 3 4      5 2 3     6   2
+--R               6A B a  + 12A B a  - 6A B a  - 18A B a  - 12A B a  + 6A B a
+--R             + 
+--R                  7
+--R               12A a
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                     6 8      2 5 7     3 4 6      4 3 5      5 2 4     6   3
+--R               - 6A B a  - 12A B a  + 6A B a  + 18A B a  + 12A B a  - 6A B a
+--R             + 
+--R                    7 2
+--R               - 12A a
+--R          *
+--R              4
+--R             x
+--R      *
+--R                       +-------------------+  4
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                         2 10       2   9  4        2   10       3 9  2  +-+ +-+
+--R                 ((576A B a   + 288A B a )x  + (576A B a   + 288A a )x )\|2 \|3
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      3 10         2 9        2   8        3 7  6
+--R               (- 576B a   - 864A B a  - 2592A B a  - 1152A a )x
+--R             + 
+--R                    3 11         2 10        2   9        3 8  4
+--R               (576B a   + 864A B a   + 2592A B a  + 1152A a )x
+--R             + 
+--R                      3 12         2 11        2   10        3 9  2
+--R               (- 576B a   - 864A B a   - 2592A B a   - 1152A a )x
+--R          *
+--R              +-------------------+  +--------------------------------------+2
+--R              | 4 4     2 2 2    4   | 4 4       3 3     2 2 2     3       4
+--R              |B a  - 2A B a  + A    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |-------------------   |--------------------------------------
+--R              |           6         4|                    6
+--R             \|        48a          \|                  9a
+--R          *
+--R                           +-------------------+  3
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                            4 8       2 3 7      4   5  6
+--R                   (- 192A B a  - 288A B a  + 48A B a )x
+--R                 + 
+--R                          2 3 8       3 2 7      5 5  4
+--R                   (- 192A B a  - 288A B a  + 48A a )x
+--R              *
+--R                  +-+ +-+ +-+
+--R                 \|2 \|3 \|6
+--R             + 
+--R                       5 8         4 7       2 3 6       3 2 5       4   4
+--R                   192B a  + 480A B a  + 192A B a  - 192A B a  - 480A B a
+--R                 + 
+--R                         5 3
+--R                   - 192A a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                         5 9         4 8       2 3 7       3 2 6       4   5
+--R                   - 192B a  - 480A B a  - 192A B a  + 192A B a  + 480A B a
+--R                 + 
+--R                       5 4
+--R                   192A a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                       5 10         4 9       2 3 8       3 2 7       4   6
+--R                   192B a   + 480A B a  + 192A B a  - 192A B a  - 480A B a
+--R                 + 
+--R                         5 5
+--R                   - 192A a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                                                 +-------------------+
+--R                                                 | 4 4     2 2 2    4
+--R                                               3 |B a  - 2A B a  + A
+--R                                            12a  |-------------------
+--R                                                 |           6
+--R                                                \|        48a
+--R              +-------------------+    atan(--------------------------)
+--R              | 4 4     2 2 2    4               2 2             2
+--R              |B a  - 2A B a  + A               B a  + 4A B a + A
+--R              |------------------- cos(--------------------------------)
+--R              |           6                            2
+--R             \|        48a
+--R      *
+--R                       +-------------------+  3
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                             7 10       6 9     2 5 8     4 3 6     5 2 5
+--R                         - 4B a   - 8A B a  - 8A B a  + 8A B a  + 8A B a
+--R                       + 
+--R                           6   4
+--R                         4A B a
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                         6 10     2 5 9     3 4 8     5 2 6     6   5     7 4
+--R                   - 4A B a   - 8A B a  - 8A B a  + 8A B a  + 8A B a  + 4A a
+--R              *
+--R                  +-+ +-+ +-+
+--R                 \|2 \|3 \|6
+--R             + 
+--R                     6 8      2 5 7      3 4 6      5 2 4      6   3      7 2  4
+--R               (24A B a  + 48A B a  + 48A B a  - 48A B a  - 48A B a  - 24A a )x
+--R             + 
+--R                            6 9      2 5 8      3 4 7      5 2 5      6   4
+--R                     - 24A B a  - 48A B a  - 48A B a  + 48A B a  + 48A B a
+--R                   + 
+--R                        7 3
+--R                     24A a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                    6 10      2 5 9      3 4 8      5 2 6      6   5      7 4
+--R               24A B a   + 48A B a  + 48A B a  - 48A B a  - 48A B a  - 24A a
+--R          *
+--R                           +-------------------+  6
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                         5 10        4 9      2 3 8      3 2 7     4   6  4
+--R                   (- 12B a   - 12A B a  + 18A B a  + 12A B a  - 6A B a )x
+--R                 + 
+--R                           4 10      2 3 9      3 2 8      4   7     5 6  2
+--R                   (- 12A B a   - 12A B a  + 18A B a  + 12A B a  - 6A a )x
+--R              *
+--R                  +-+ +-+ +-+
+--R                 \|2 \|3 \|6
+--R             + 
+--R                     4 8      2 3 7      3 2 6      4   5      5 4  6
+--R               (18A B a  + 18A B a  - 54A B a  - 18A B a  + 36A a )x
+--R             + 
+--R                       4 9      2 3 8      3 2 7      4   6      5 5  4
+--R               (- 18A B a  - 18A B a  + 54A B a  + 18A B a  - 36A a )x
+--R             + 
+--R                     4 10      2 3 9      3 2 8      4   7      5 6  2
+--R               (18A B a   + 18A B a  - 54A B a  - 18A B a  + 36A a )x
+--R          *
+--R              +--------------------------------------+2
+--R              | 4 4       3 3     2 2 2     3       4
+--R              |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |--------------------------------------
+--R             4|                    6
+--R             \|                  9a
+--R          *
+--R                           +-------------------+  4
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                         7 8       6 7      2 5 6      3 4 5      4 3 4
+--R                       4B a  + 8A B a  - 64A B a  - 72A B a  + 46A B a
+--R                     + 
+--R                          5 2 3      6   2
+--R                       64A B a  + 14A B a
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                           6 8     2 5 7      3 4 6      4 3 5      5 2 4
+--R                       4A B a  + 8A B a  - 64A B a  - 72A B a  + 46A B a
+--R                     + 
+--R                          6   3      7 2
+--R                       64A B a  + 14A a
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +-+ +-+ +-+
+--R                 \|2 \|3 \|6
+--R             + 
+--R                         6 6       2 5 5       3 4 4       4 3 3       5 2 2
+--R                   132A B a  + 264A B a  + 156A B a  - 108A B a  - 264A B a
+--R                 + 
+--R                         6         7
+--R                   - 156A B a - 24A
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           6 7       2 5 6       3 4 5       4 3 4       5 2 3
+--R                   - 132A B a  - 264A B a  - 156A B a  + 108A B a  + 264A B a
+--R                 + 
+--R                       6   2      7
+--R                   156A B a  + 24A a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         6 8       2 5 7       3 4 6       4 3 5       5 2 4
+--R                   132A B a  + 264A B a  + 156A B a  - 108A B a  - 264A B a
+--R                 + 
+--R                         6   3      7 2
+--R                   - 156A B a  - 24A a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                           +-------------------+  2
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                       5 8        4 7      2 3 6      3 2 5     4   4  8
+--R                   (12B a  + 12A B a  - 18A B a  - 12A B a  + 6A B a )x
+--R                 + 
+--R                         4 8      2 3 7      3 2 6      4   5     5 4  6
+--R                   (12A B a  + 12A B a  - 18A B a  - 12A B a  + 6A a )x
+--R              *
+--R                  +-+ +-+ +-+
+--R                 \|2 \|3 \|6
+--R             + 
+--R                     4 6      2 3 5      4   3      5 2  10
+--R               (18A B a  + 18A B a  - 18A B a  - 18A a )x
+--R             + 
+--R                       4 7      2 3 6      4   4      5 3  8
+--R               (- 18A B a  - 18A B a  + 18A B a  + 18A a )x
+--R             + 
+--R                     4 8      2 3 7      4   5      5 4  6
+--R               (18A B a  + 18A B a  - 18A B a  - 18A a )x
+--R          *
+--R              +--------------------------------------+2
+--R              | 4 4       3 3     2 2 2     3       4
+--R              |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |--------------------------------------
+--R             4|                    6
+--R             \|                  9a
+--R      *
+--R                       +-------------------+  2
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                         2 10       2   9  4        2   10       3 9  2  +-+ +-+
+--R                 ((288A B a   + 144A B a )x  + (288A B a   + 144A a )x )\|2 \|3
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      3 10         2 9        2   8       3 7  6
+--R               (- 288B a   - 432A B a  - 1296A B a  - 576A a )x
+--R             + 
+--R                    3 11         2 10        2   9       3 8  4
+--R               (288B a   + 432A B a   + 1296A B a  + 576A a )x
+--R             + 
+--R                      3 12         2 11        2   10       3 9  2
+--R               (- 288B a   - 432A B a   - 1296A B a   - 576A a )x
+--R          *
+--R              +-------------------+  +--------------------------------------+2
+--R              | 4 4     2 2 2    4   | 4 4       3 3     2 2 2     3       4
+--R              |B a  - 2A B a  + A    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |-------------------   |--------------------------------------
+--R              |           6         4|                    6
+--R             \|        48a          \|                  9a
+--R          *
+--R                           +-------------------+  5
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                          4 8       2 3 7      4   5  6
+--R                   (192A B a  + 288A B a  - 48A B a )x
+--R                 + 
+--R                        2 3 8       3 2 7      5 5  4
+--R                   (192A B a  + 288A B a  - 48A a )x
+--R              *
+--R                  +-+ +-+ +-+
+--R                 \|2 \|3 \|6
+--R             + 
+--R                         5 8         4 7       2 3 6       3 2 5       4   4
+--R                   - 192B a  - 480A B a  - 192A B a  + 192A B a  + 480A B a
+--R                 + 
+--R                       5 3
+--R                   192A a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                       5 9         4 8       2 3 7       3 2 6       4   5
+--R                   192B a  + 480A B a  + 192A B a  - 192A B a  - 480A B a
+--R                 + 
+--R                         5 4
+--R                   - 192A a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         5 10         4 9       2 3 8       3 2 7       4   6
+--R                   - 192B a   - 480A B a  - 192A B a  + 192A B a  + 480A B a
+--R                 + 
+--R                       5 5
+--R                   192A a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                                                 +-------------------+  3
+--R                                                 | 4 4     2 2 2    4
+--R                                               3 |B a  - 2A B a  + A
+--R                                            12a  |-------------------
+--R                                                 |           6
+--R                                                \|        48a
+--R              +-------------------+    atan(--------------------------)
+--R              | 4 4     2 2 2    4               2 2             2
+--R              |B a  - 2A B a  + A               B a  + 4A B a + A
+--R              |------------------- cos(--------------------------------)
+--R              |           6                            2
+--R             \|        48a
+--R         + 
+--R                       2 8       2   7  8        2   8       3 7  6  +-+ +-+ +-+
+--R               ((288A B a  + 144A B a )x  + (288A B a  + 144A a )x )\|2 \|3 \|6
+--R             + 
+--R                      3 8         2 7       2   6       3 5  10
+--R               (- 288B a  - 432A B a  - 432A B a  - 144A a )x
+--R             + 
+--R                    3 9         2 8       2   7       3 6  8
+--R               (288B a  + 432A B a  + 432A B a  + 144A a )x
+--R             + 
+--R                      3 10         2 9       2   8       3 7  6
+--R               (- 288B a   - 432A B a  - 432A B a  - 144A a )x
+--R          *
+--R              +-------------------+  +--------------------------------------+2
+--R              | 4 4     2 2 2    4   | 4 4       3 3     2 2 2     3       4
+--R              |B a  - 2A B a  + A    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |-------------------   |--------------------------------------
+--R              |           6         4|                    6
+--R             \|        48a          \|                  9a
+--R          *
+--R                           +-------------------+
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R      *
+--R                       +-------------------+
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                   7 10       6 9     2 5 8     4 3 6     5 2 5    6   4  2
+--R               (- B a   - 2A B a  - 2A B a  + 2A B a  + 2A B a  + A B a )x
+--R             + 
+--R                    6 10     2 5 9     3 4 8     5 2 6     6   5    7 4
+--R               - A B a   - 2A B a  - 2A B a  + 2A B a  + 2A B a  + A a
+--R          *
+--R              +-+ +-+ +-+
+--R             \|2 \|3 \|6
+--R         + 
+--R                6 8      2 5 7      3 4 6      5 2 4      6   3     7 2  4
+--R           (6A B a  + 12A B a  + 12A B a  - 12A B a  - 12A B a  - 6A a )x
+--R         + 
+--R                  6 9      2 5 8      3 4 7      5 2 5      6   4     7 3  2
+--R           (- 6A B a  - 12A B a  - 12A B a  + 12A B a  + 12A B a  + 6A a )x
+--R         + 
+--R               6 10      2 5 9      3 4 8      5 2 6      6   5     7 4
+--R           6A B a   + 12A B a  + 12A B a  - 12A B a  - 12A B a  - 6A a
+--R      *
+--R                       +-------------------+  8
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R     + 
+--R                     5 10        4 9      2 3 8      3 2 7     4   6  4
+--R               (- 12B a   - 12A B a  + 18A B a  + 12A B a  - 6A B a )x
+--R             + 
+--R                       4 10      2 3 9      3 2 8      4   7     5 6  2
+--R               (- 12A B a   - 12A B a  + 18A B a  + 12A B a  - 6A a )x
+--R          *
+--R              +-+ +-+ +-+
+--R             \|2 \|3 \|6
+--R         + 
+--R                 4 8      2 3 7      3 2 6      4   5      5 4  6
+--R           (18A B a  + 18A B a  - 54A B a  - 18A B a  + 36A a )x
+--R         + 
+--R                   4 9      2 3 8      3 2 7      4   6      5 5  4
+--R           (- 18A B a  - 18A B a  + 54A B a  + 18A B a  - 36A a )x
+--R         + 
+--R                 4 10      2 3 9      3 2 8      4   7      5 6  2
+--R           (18A B a   + 18A B a  - 54A B a  - 18A B a  + 36A a )x
+--R      *
+--R          +--------------------------------------+2
+--R          | 4 4       3 3     2 2 2     3       4
+--R          |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R          |--------------------------------------
+--R         4|                    6
+--R         \|                  9a
+--R      *
+--R                       +-------------------+  6
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R     + 
+--R                    7 8        6 7      3 4 5     4 3 4     6   2  6
+--R               (- 6B a  - 12A B a  + 12A B a  + 3A B a  + 3A B a )x
+--R             + 
+--R                      6 8      2 5 7      4 3 5     5 2 4     7 2  4
+--R               (- 6A B a  - 12A B a  + 12A B a  + 3A B a  + 3A a )x
+--R          *
+--R              +-+ +-+ +-+
+--R             \|2 \|3 \|6
+--R         + 
+--R                     6 6      2 5 5     3 4 4      4 3 3      5 2 2     6
+--R               - 6A B a  - 12A B a  + 6A B a  + 18A B a  + 12A B a  - 6A B a
+--R             + 
+--R                    7
+--R               - 12A
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                   6 7      2 5 6     3 4 5      4 3 4      5 2 3     6   2
+--R               6A B a  + 12A B a  - 6A B a  - 18A B a  - 12A B a  + 6A B a
+--R             + 
+--R                  7
+--R               12A a
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                     6 8      2 5 7     3 4 6      4 3 5      5 2 4     6   3
+--R               - 6A B a  - 12A B a  + 6A B a  + 18A B a  + 12A B a  - 6A B a
+--R             + 
+--R                    7 2
+--R               - 12A a
+--R          *
+--R              4
+--R             x
+--R      *
+--R                       +-------------------+  4
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R     + 
+--R                     5 8        4 7      2 3 6      3 2 5     4   4  8
+--R               (- 12B a  - 12A B a  + 18A B a  + 12A B a  - 6A B a )x
+--R             + 
+--R                       4 8      2 3 7      3 2 6      4   5     5 4  6
+--R               (- 12A B a  - 12A B a  + 18A B a  + 12A B a  - 6A a )x
+--R          *
+--R              +-+ +-+ +-+
+--R             \|2 \|3 \|6
+--R         + 
+--R                   4 6      2 3 5      4   3      5 2  10
+--R           (- 18A B a  - 18A B a  + 18A B a  + 18A a )x
+--R         + 
+--R                 4 7      2 3 6      4   4      5 3  8
+--R           (18A B a  + 18A B a  - 18A B a  - 18A a )x
+--R         + 
+--R                   4 8      2 3 7      4   5      5 4  6
+--R           (- 18A B a  - 18A B a  + 18A B a  + 18A a )x
+--R      *
+--R          +--------------------------------------+2
+--R          | 4 4       3 3     2 2 2     3       4
+--R          |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R          |--------------------------------------
+--R         4|                    6
+--R         \|                  9a
+--R      *
+--R                       +-------------------+  2
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R     + 
+--R               7 6       6 5     2 5 4     4 3 2     5 2     6   10
+--R           (- B a  - 2A B a  - 2A B a  + 2A B a  + 2A B a + A B)x
+--R         + 
+--R                 6 6     2 5 5     3 4 4     5 2 2     6       7  8
+--R           (- A B a  - 2A B a  - 2A B a  + 2A B a  + 2A B a + A )x
+--R      *
+--R          +-+ +-+ +-+
+--R         \|2 \|3 \|6
+--R  /
+--R              6 10        5 9      2 4 8      4 2 6      5   5     6 4  4
+--R           (6B a   + 12A B a  + 12A B a  - 12A B a  - 12A B a  - 6A a )x
+--R         + 
+--R                6 11        5 10      2 4 9      4 2 7      5   6     6 5  2
+--R           (- 6B a   - 12A B a   - 12A B a  + 12A B a  + 12A B a  + 6A a )x
+--R         + 
+--R             6 12        5 11      2 4 10      4 2 8      5   7     6 6
+--R           6B a   + 12A B a   + 12A B a   - 12A B a  - 12A B a  - 6A a
+--R      *
+--R                       +-------------------+  8
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                   6 10        5 9      2 4 8      4 2 6      5   5      6 4  4
+--R               (24B a   + 48A B a  + 48A B a  - 48A B a  - 48A B a  - 24A a )x
+--R             + 
+--R                          6 11        5 10      2 4 9      4 2 7      5   6
+--R                     - 24B a   - 48A B a   - 48A B a  + 48A B a  + 48A B a
+--R                   + 
+--R                        6 5
+--R                     24A a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                  6 12        5 11      2 4 10      4 2 8      5   7      6 6
+--R               24B a   + 48A B a   + 48A B a   - 48A B a  - 48A B a  - 24A a
+--R          *
+--R                           +-------------------+  2
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                     4 10        3 9       2 2 8      3   7      4 6  6
+--R               (- 72B a   - 72A B a  + 108A B a  + 72A B a  - 36A a )x
+--R             + 
+--R                   4 11        3 10       2 2 9      3   8      4 7  4
+--R               (72B a   + 72A B a   - 108A B a  - 72A B a  + 36A a )x
+--R             + 
+--R                     4 12        3 11       2 2 10      3   9      4 8  2
+--R               (- 72B a   - 72A B a   + 108A B a   + 72A B a  - 36A a )x
+--R          *
+--R              +--------------------------------------+2
+--R              | 4 4       3 3     2 2 2     3       4
+--R              |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |--------------------------------------
+--R             4|                    6
+--R             \|                  9a
+--R      *
+--R                       +-------------------+  6
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                       10       2 9  6             11       2 10  4
+--R           (- 1728A B a   - 864A a )x  + (1728A B a   + 864A a  )x
+--R         + 
+--R                       12       2 11  2
+--R           (- 1728A B a   - 864A a  )x
+--R      *
+--R          +-------------------+  +--------------------------------------+2
+--R          | 4 4     2 2 2    4   | 4 4       3 3     2 2 2     3       4
+--R          |B a  - 2A B a  + A    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R          |-------------------   |--------------------------------------
+--R          |           6         4|                    6
+--R         \|        48a          \|                  9a
+--R      *
+--R                       +-------------------+
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R      *
+--R                       +-------------------+  5
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                   6 10        5 9      2 4 8      4 2 6      5   5      6 4  4
+--R               (36B a   + 72A B a  + 72A B a  - 72A B a  - 72A B a  - 36A a )x
+--R             + 
+--R                          6 11        5 10      2 4 9      4 2 7      5   6
+--R                     - 36B a   - 72A B a   - 72A B a  + 72A B a  + 72A B a
+--R                   + 
+--R                        6 5
+--R                     36A a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                  6 12        5 11      2 4 10      4 2 8      5   7      6 6
+--R               36B a   + 72A B a   + 72A B a   - 72A B a  - 72A B a  - 36A a
+--R          *
+--R                           +-------------------+  4
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                     4 10        3 9       2 2 8      3   7      4 6  6
+--R               (- 72B a   - 72A B a  + 108A B a  + 72A B a  - 36A a )x
+--R             + 
+--R                   4 11        3 10       2 2 9      3   8      4 7  4
+--R               (72B a   + 72A B a   - 108A B a  - 72A B a  + 36A a )x
+--R             + 
+--R                     4 12        3 11       2 2 10      3   9      4 8  2
+--R               (- 72B a   - 72A B a   + 108A B a   + 72A B a  - 36A a )x
+--R          *
+--R              +--------------------------------------+2
+--R              | 4 4       3 3     2 2 2     3       4
+--R              |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |--------------------------------------
+--R             4|                    6
+--R             \|                  9a
+--R          *
+--R                           +-------------------+  2
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R               6 8        5 7      3 3 5      4 2 4      6 2  8
+--R           (36B a  + 72A B a  - 72A B a  - 18A B a  - 18A a )x
+--R         + 
+--R                 6 9        5 8      3 3 6      4 2 5      6 3  6
+--R           (- 36B a  - 72A B a  + 72A B a  + 18A B a  + 18A a )x
+--R         + 
+--R               6 10        5 9      3 3 7      4 2 6      6 4  4
+--R           (36B a   + 72A B a  - 72A B a  - 18A B a  - 18A a )x
+--R      *
+--R                       +-------------------+  4
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                           10        2 9  6             11        2 10  4
+--R               (- 3456A B a   - 1728A a )x  + (3456A B a   + 1728A a  )x
+--R             + 
+--R                           12        2 11  2
+--R               (- 3456A B a   - 1728A a  )x
+--R          *
+--R              +-------------------+  +--------------------------------------+2
+--R              | 4 4     2 2 2    4   | 4 4       3 3     2 2 2     3       4
+--R              |B a  - 2A B a  + A    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |-------------------   |--------------------------------------
+--R              |           6         4|                    6
+--R             \|        48a          \|                  9a
+--R          *
+--R                           +-------------------+  3
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                       3 8        2 2 7       4 5  8
+--R               (1152A B a  + 1728A B a  - 288A a )x
+--R             + 
+--R                         3 9        2 2 8       4 6  6
+--R               (- 1152A B a  - 1728A B a  + 288A a )x
+--R             + 
+--R                       3 10        2 2 9       4 7  4
+--R               (1152A B a   + 1728A B a  - 288A a )x
+--R          *
+--R                                                 +-------------------+
+--R                                                 | 4 4     2 2 2    4
+--R                                               3 |B a  - 2A B a  + A
+--R                                            12a  |-------------------
+--R                                                 |           6
+--R                                                \|        48a
+--R              +-------------------+    atan(--------------------------)
+--R              | 4 4     2 2 2    4               2 2             2
+--R              |B a  - 2A B a  + A               B a  + 4A B a + A
+--R              |------------------- cos(--------------------------------)
+--R              |           6                            2
+--R             \|        48a
+--R      *
+--R                       +-------------------+  3
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                   6 10        5 9      2 4 8      4 2 6      5   5      6 4  4
+--R               (24B a   + 48A B a  + 48A B a  - 48A B a  - 48A B a  - 24A a )x
+--R             + 
+--R                          6 11        5 10      2 4 9      4 2 7      5   6
+--R                     - 24B a   - 48A B a   - 48A B a  + 48A B a  + 48A B a
+--R                   + 
+--R                        6 5
+--R                     24A a
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                  6 12        5 11      2 4 10      4 2 8      5   7      6 6
+--R               24B a   + 48A B a   + 48A B a   - 48A B a  - 48A B a  - 24A a
+--R          *
+--R                           +-------------------+  6
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                   4 10        3 9       2 2 8      3   7      4 6  6
+--R               (72B a   + 72A B a  - 108A B a  - 72A B a  + 36A a )x
+--R             + 
+--R                     4 11        3 10       2 2 9      3   8      4 7  4
+--R               (- 72B a   - 72A B a   + 108A B a  + 72A B a  - 36A a )x
+--R             + 
+--R                   4 12        3 11       2 2 10      3   9      4 8  2
+--R               (72B a   + 72A B a   - 108A B a   - 72A B a  + 36A a )x
+--R          *
+--R              +--------------------------------------+2
+--R              | 4 4       3 3     2 2 2     3       4
+--R              |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |--------------------------------------
+--R             4|                    6
+--R             \|                  9a
+--R          *
+--R                           +-------------------+  4
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                        6 8        5 7       2 4 6       3 3 5       4 2 4
+--R                   - 24B a  - 48A B a  + 384A B a  + 432A B a  - 276A B a
+--R                 + 
+--R                         5   3      6 2
+--R                   - 384A B a  - 84A a
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                      6 9        5 8       2 4 7       3 3 6       4 2 5
+--R                   24B a  + 48A B a  - 384A B a  - 432A B a  + 276A B a
+--R                 + 
+--R                       5   4      6 3
+--R                   384A B a  + 84A a
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                        6 10        5 9       2 4 8       3 3 7       4 2 6
+--R                   - 24B a   - 48A B a  + 384A B a  + 432A B a  - 276A B a
+--R                 + 
+--R                         5   5      6 4
+--R                   - 384A B a  - 84A a
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                           +-------------------+  2
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                     4 8        3 7       2 2 6      3   5      4 4  10
+--R               (- 72B a  - 72A B a  + 108A B a  + 72A B a  - 36A a )x
+--R             + 
+--R                   4 9        3 8       2 2 7      3   6      4 5  8
+--R               (72B a  + 72A B a  - 108A B a  - 72A B a  + 36A a )x
+--R             + 
+--R                     4 10        3 9       2 2 8      3   7      4 6  6
+--R               (- 72B a   - 72A B a  + 108A B a  + 72A B a  - 36A a )x
+--R          *
+--R              +--------------------------------------+2
+--R              | 4 4       3 3     2 2 2     3       4
+--R              |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |--------------------------------------
+--R             4|                    6
+--R             \|                  9a
+--R      *
+--R                       +-------------------+  2
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R                           10       2 9  6             11       2 10  4
+--R               (- 1728A B a   - 864A a )x  + (1728A B a   + 864A a  )x
+--R             + 
+--R                           12       2 11  2
+--R               (- 1728A B a   - 864A a  )x
+--R          *
+--R              +-------------------+  +--------------------------------------+2
+--R              | 4 4     2 2 2    4   | 4 4       3 3     2 2 2     3       4
+--R              |B a  - 2A B a  + A    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |-------------------   |--------------------------------------
+--R              |           6         4|                    6
+--R             \|        48a          \|                  9a
+--R          *
+--R                           +-------------------+  5
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R         + 
+--R                         3 8        2 2 7       4 5  8
+--R               (- 1152A B a  - 1728A B a  + 288A a )x
+--R             + 
+--R                       3 9        2 2 8       4 6  6
+--R               (1152A B a  + 1728A B a  - 288A a )x
+--R             + 
+--R                         3 10        2 2 9       4 7  4
+--R               (- 1152A B a   - 1728A B a  + 288A a )x
+--R          *
+--R                                                 +-------------------+  3
+--R                                                 | 4 4     2 2 2    4
+--R                                               3 |B a  - 2A B a  + A
+--R                                            12a  |-------------------
+--R                                                 |           6
+--R                                                \|        48a
+--R              +-------------------+    atan(--------------------------)
+--R              | 4 4     2 2 2    4               2 2             2
+--R              |B a  - 2A B a  + A               B a  + 4A B a + A
+--R              |------------------- cos(--------------------------------)
+--R              |           6                            2
+--R             \|        48a
+--R         + 
+--R                           8       2 7  10             9       2 8  8
+--R               (- 1728A B a  - 864A a )x   + (1728A B a  + 864A a )x
+--R             + 
+--R                           10       2 9  6
+--R               (- 1728A B a   - 864A a )x
+--R          *
+--R              +-------------------+  +--------------------------------------+2
+--R              | 4 4     2 2 2    4   | 4 4       3 3     2 2 2     3       4
+--R              |B a  - 2A B a  + A    |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R              |-------------------   |--------------------------------------
+--R              |           6         4|                    6
+--R             \|        48a          \|                  9a
+--R          *
+--R                           +-------------------+
+--R                           | 4 4     2 2 2    4
+--R                         3 |B a  - 2A B a  + A
+--R                      12a  |-------------------
+--R                           |           6
+--R                          \|        48a
+--R                 atan(--------------------------)
+--R                           2 2             2
+--R                          B a  + 4A B a + A
+--R             cos(--------------------------------)
+--R                                 2
+--R      *
+--R                       +-------------------+
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         sin(--------------------------------)
+--R                             2
+--R     + 
+--R              6 10        5 9      2 4 8      4 2 6      5   5     6 4  4
+--R           (6B a   + 12A B a  + 12A B a  - 12A B a  - 12A B a  - 6A a )x
+--R         + 
+--R                6 11        5 10      2 4 9      4 2 7      5   6     6 5  2
+--R           (- 6B a   - 12A B a   - 12A B a  + 12A B a  + 12A B a  + 6A a )x
+--R         + 
+--R             6 12        5 11      2 4 10      4 2 8      5   7     6 6
+--R           6B a   + 12A B a   + 12A B a   - 12A B a  - 12A B a  - 6A a
+--R      *
+--R                       +-------------------+  8
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R     + 
+--R               4 10        3 9       2 2 8      3   7      4 6  6
+--R           (72B a   + 72A B a  - 108A B a  - 72A B a  + 36A a )x
+--R         + 
+--R                 4 11        3 10       2 2 9      3   8      4 7  4
+--R           (- 72B a   - 72A B a   + 108A B a  + 72A B a  - 36A a )x
+--R         + 
+--R               4 12        3 11       2 2 10      3   9      4 8  2
+--R           (72B a   + 72A B a   - 108A B a   - 72A B a  + 36A a )x
+--R      *
+--R          +--------------------------------------+2
+--R          | 4 4       3 3     2 2 2     3       4
+--R          |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R          |--------------------------------------
+--R         4|                    6
+--R         \|                  9a
+--R      *
+--R                       +-------------------+  6
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R     + 
+--R               6 8        5 7      3 3 5      4 2 4      6 2  8
+--R           (36B a  + 72A B a  - 72A B a  - 18A B a  - 18A a )x
+--R         + 
+--R                 6 9        5 8      3 3 6      4 2 5      6 3  6
+--R           (- 36B a  - 72A B a  + 72A B a  + 18A B a  + 18A a )x
+--R         + 
+--R               6 10        5 9      3 3 7      4 2 6      6 4  4
+--R           (36B a   + 72A B a  - 72A B a  - 18A B a  - 18A a )x
+--R      *
+--R                       +-------------------+  4
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R     + 
+--R               4 8        3 7       2 2 6      3   5      4 4  10
+--R           (72B a  + 72A B a  - 108A B a  - 72A B a  + 36A a )x
+--R         + 
+--R                 4 9        3 8       2 2 7      3   6      4 5  8
+--R           (- 72B a  - 72A B a  + 108A B a  + 72A B a  - 36A a )x
+--R         + 
+--R               4 10        3 9       2 2 8      3   7      4 6  6
+--R           (72B a   + 72A B a  - 108A B a  - 72A B a  + 36A a )x
+--R      *
+--R          +--------------------------------------+2
+--R          | 4 4       3 3     2 2 2     3       4
+--R          |B a  + 2A B a  + 3A B a  + 2A B a + A
+--R          |--------------------------------------
+--R         4|                    6
+--R         \|                  9a
+--R      *
+--R                       +-------------------+  2
+--R                       | 4 4     2 2 2    4
+--R                     3 |B a  - 2A B a  + A
+--R                  12a  |-------------------
+--R                       |           6
+--R                      \|        48a
+--R             atan(--------------------------)
+--R                       2 2             2
+--R                      B a  + 4A B a + A
+--R         cos(--------------------------------)
+--R                             2
+--R     + 
+--R          6 6        5 5      2 4 4      4 2 2      5        6  12
+--R       (6B a  + 12A B a  + 12A B a  - 12A B a  - 12A B a - 6A )x
+--R     + 
+--R            6 7        5 6      2 4 5      4 2 3      5   2     6   10
+--R       (- 6B a  - 12A B a  - 12A B a  + 12A B a  + 12A B a  + 6A a)x
+--R     + 
+--R          6 8        5 7      2 4 6      4 2 4      5   3     6 2  8
+--R       (6B a  + 12A B a  + 12A B a  - 12A B a  - 12A B a  - 6A a )x
+--R                                                    Type: Expression(Integer)
+--E 2387
+
+)clear all
+
+--S 2388 of 3139
+t0:=(A+B*x^2)/(a+x^4-x^2*sqrt(a))
+--R 
+--R
+--R                2
+--R           - B x  - A
+--R   (1)  ---------------
+--R         2 +-+    4
+--R        x \|a  - x  - a
+--R                                                    Type: Expression(Integer)
+--E 2388
+
+--S 2389 of 3139
+r0:=atan(x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)-sqrt(a)))*(B*sqrt(3)+_
+   (-2*A-B*sqrt(a))/sqrt(-a))/(sqrt(6)*sqrt(sqrt(3)*sqrt(-a)-sqrt(a)))-_
+   atanh(x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)+sqrt(a)))*(B*sqrt(3)+_
+   (2*A+B*sqrt(a))/sqrt(-a))/(sqrt(6)*sqrt(sqrt(3)*sqrt(-a)+sqrt(a)))
+--R 
+--R
+--R   (2)
+--R                                      +-------------------+
+--R              +-+     +-+ +---+       |   +-+    +-+ +---+
+--R         (- B\|a  - B\|3 \|- a  - 2A)\|- \|a  + \|3 \|- a
+--R      *
+--R                         +-+
+--R                       x\|2
+--R         atanh(--------------------)
+--R                +-----------------+
+--R                | +-+    +-+ +---+
+--R               \|\|a  + \|3 \|- a
+--R     + 
+--R                                      +-----------------+
+--R              +-+     +-+ +---+       | +-+    +-+ +---+
+--R         (- B\|a  + B\|3 \|- a  - 2A)\|\|a  + \|3 \|- a
+--R      *
+--R                         +-+
+--R                       x\|2
+--R         atan(----------------------)
+--R               +-------------------+
+--R               |   +-+    +-+ +---+
+--R              \|- \|a  + \|3 \|- a
+--R  /
+--R                +-------------------+ +-----------------+
+--R      +-+ +---+ |   +-+    +-+ +---+  | +-+    +-+ +---+
+--R     \|6 \|- a \|- \|a  + \|3 \|- a  \|\|a  + \|3 \|- a
+--R                                                    Type: Expression(Integer)
+--E 2389
+
+--S 2390 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +--------------------------------------------------+
+--R          |     +--------------------+
+--R          |     |   4 2     2 2     4
+--R          |     |- B a  + 2A B a - A           +-+    2     2
+--R          |(12a |--------------------  - 4A B)\|a  - B a - A
+--R          |     |           3
+--R          |    \|        48a
+--R          |--------------------------------------------------
+--R          |                         +-+
+--R         \|                      6a\|a
+--R      *
+--R         log
+--R                             23 14        2 21 13         4 19 12
+--R                          96B  a   + 6576A B  a   + 80616A B  a
+--R                        + 
+--R                                 6 17 11          8 15 10           10 13 9
+--R                          384660A B  a   + 888480A B  a   + 1063608A  B  a
+--R                        + 
+--R                                 12 11 8          14 9 7         16 7 6
+--R                          637752A  B  a  + 147324A  B a  - 12816A  B a
+--R                        + 
+--R                                 18 5 5      20 3 4      22   3
+--R                          - 7752A  B a  + 24A  B a  + 84A  B a
+--R                     *
+--R                         +--------------------+
+--R                         |   4 2     2 2     4
+--R                         |- B a  + 2A B a - A
+--R                         |--------------------
+--R                         |           3
+--R                        \|        48a
+--R                    + 
+--R                           24 13       3 22 12        5 20 11         7 18 10
+--R                      12A B  a   + 744A B  a   + 7851A B  a   + 29472A B  a
+--R                    + 
+--R                            9 16 9        11 14 8         13 12 7
+--R                      42759A B  a  + 6396A  B  a  - 42237A  B  a
+--R                    + 
+--R                              15 10 6        17 8 5        19 6 4       21 4 3
+--R                      - 37788A  B  a  - 8847A  B a  + 1236A  B a  + 429A  B a
+--R                    + 
+--R                           23 2 2     25
+--R                      - 24A  B a  - 3A  a
+--R                 *
+--R                     +-+
+--R                    \|a
+--R                + 
+--R                             22 14         3 20 13          5 18 12
+--R                      1104A B  a   + 26544A B  a   + 194484A B  a
+--R                    + 
+--R                             7 16 11           9 14 10          11 12 9
+--R                      635868A B  a   + 1054824A B  a   + 904488A  B  a
+--R                    + 
+--R                             13 10 8         15 8 7         17 6 6        19 4 5
+--R                      359292A  B  a  + 29412A  B a  - 15624A  B a  - 1992A  B a
+--R                    + 
+--R                          21 2 4      23 3
+--R                      228A  B a  + 12A  a
+--R                 *
+--R                     +--------------------+
+--R                     |   4 2     2 2     4
+--R                     |- B a  + 2A B a - A
+--R                     |--------------------
+--R                     |           3
+--R                    \|        48a
+--R                + 
+--R                      2 23 13        4 21 12         6 19 11         8 17 10
+--R                  132A B  a   + 2808A B  a   + 17067A B  a   + 40437A B  a
+--R                + 
+--R                        10 15 9         12 13 8         14 11 7         16 9 6
+--R                  30990A  B  a  - 21990A  B  a  - 47031A  B  a  - 22341A  B a
+--R                + 
+--R                         18 7 5        20 5 4      22 3 3      24   2
+--R                  - 1206A  B a  + 1086A  B a  + 63A  B a  - 15A  B a
+--R             *
+--R                 +--------------------------------------------------+
+--R                 |     +--------------------+
+--R                 |     |   4 2     2 2     4
+--R                 |     |- B a  + 2A B a - A           +-+    2     2
+--R                 |(12a |--------------------  - 4A B)\|a  - B a - A
+--R                 |     |           3
+--R                 |    \|        48a
+--R                 |--------------------------------------------------
+--R                 |                         +-+
+--R                \|                      6a\|a
+--R            + 
+--R                    26 13       2 24 12        4 22 11         6 20 10
+--R                  8B  a   + 592A B  a   + 7602A B  a   + 36260A B  a
+--R                + 
+--R                        8 18 9         10 16 8         12 14 7         14 12 6
+--R                  75112A B  a  + 53430A  B  a  - 38554A  B  a  - 84704A  B  a
+--R                + 
+--R                          16 10 5        18 8 4        20 6 3       22 4 2
+--R                  - 45984A  B  a  - 5878A  B a  + 1834A  B a  + 312A  B a
+--R                + 
+--R                       24 2      26
+--R                  - 28A  B a - 2A
+--R             *
+--R                  +-+
+--R                x\|a
+--R            + 
+--R                       25 13        3 23 12         5 21 11         7 19 10
+--R                  96A B  a   + 2456A B  a   + 18484A B  a   + 57984A B  a
+--R                + 
+--R                        9 17 9         11 15 8         13 13 7         15 11 6
+--R                  76124A B  a  + 10264A  B  a  - 74172A  B  a  - 71440A  B  a
+--R                + 
+--R                        17 9 5       19 7 4        21 5 3      23 3 2      25
+--R                - 21596A  B a  + 744A  B a  + 1052A  B a  + 16A  B a  - 12A  B a
+--R             *
+--R                x
+--R     + 
+--R       -
+--R             +----------------------------------------------------+
+--R             |       +--------------------+
+--R             |       |   4 2     2 2     4
+--R             |       |- B a  + 2A B a - A           +-+    2     2
+--R             |(- 12a |--------------------  - 4A B)\|a  - B a - A
+--R             |       |           3
+--R             |      \|        48a
+--R             |----------------------------------------------------
+--R             |                          +-+
+--R            \|                       6a\|a
+--R         *
+--R            log
+--R                                23 14        2 21 13         4 19 12
+--R                             96B  a   + 6576A B  a   + 80616A B  a
+--R                           + 
+--R                                    6 17 11          8 15 10           10 13 9
+--R                             384660A B  a   + 888480A B  a   + 1063608A  B  a
+--R                           + 
+--R                                    12 11 8          14 9 7         16 7 6
+--R                             637752A  B  a  + 147324A  B a  - 12816A  B a
+--R                           + 
+--R                                    18 5 5      20 3 4      22   3
+--R                             - 7752A  B a  + 24A  B a  + 84A  B a
+--R                        *
+--R                            +--------------------+
+--R                            |   4 2     2 2     4
+--R                            |- B a  + 2A B a - A
+--R                            |--------------------
+--R                            |           3
+--R                           \|        48a
+--R                       + 
+--R                                24 13       3 22 12        5 20 11
+--R                         - 12A B  a   - 744A B  a   - 7851A B  a
+--R                       + 
+--R                                 7 18 10         9 16 9        11 14 8
+--R                         - 29472A B  a   - 42759A B  a  - 6396A  B  a
+--R                       + 
+--R                               13 12 7         15 10 6        17 8 5
+--R                         42237A  B  a  + 37788A  B  a  + 8847A  B a
+--R                       + 
+--R                                19 6 4       21 4 3      23 2 2     25
+--R                         - 1236A  B a  - 429A  B a  + 24A  B a  + 3A  a
+--R                    *
+--R                        +-+
+--R                       \|a
+--R                   + 
+--R                                22 14         3 20 13          5 18 12
+--R                         1104A B  a   + 26544A B  a   + 194484A B  a
+--R                       + 
+--R                                7 16 11           9 14 10          11 12 9
+--R                         635868A B  a   + 1054824A B  a   + 904488A  B  a
+--R                       + 
+--R                                13 10 8         15 8 7         17 6 6
+--R                         359292A  B  a  + 29412A  B a  - 15624A  B a
+--R                       + 
+--R                                19 4 5       21 2 4      23 3
+--R                         - 1992A  B a  + 228A  B a  + 12A  a
+--R                    *
+--R                        +--------------------+
+--R                        |   4 2     2 2     4
+--R                        |- B a  + 2A B a - A
+--R                        |--------------------
+--R                        |           3
+--R                       \|        48a
+--R                   + 
+--R                           2 23 13        4 21 12         6 19 11
+--R                     - 132A B  a   - 2808A B  a   - 17067A B  a
+--R                   + 
+--R                             8 17 10         10 15 9         12 13 8
+--R                     - 40437A B  a   - 30990A  B  a  + 21990A  B  a
+--R                   + 
+--R                           14 11 7         16 9 6        18 7 5        20 5 4
+--R                     47031A  B  a  + 22341A  B a  + 1206A  B a  - 1086A  B a
+--R                   + 
+--R                          22 3 3      24   2
+--R                     - 63A  B a  + 15A  B a
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |       +--------------------+
+--R                    |       |   4 2     2 2     4
+--R                    |       |- B a  + 2A B a - A           +-+    2     2
+--R                    |(- 12a |--------------------  - 4A B)\|a  - B a - A
+--R                    |       |           3
+--R                    |      \|        48a
+--R                    |----------------------------------------------------
+--R                    |                          +-+
+--R                   \|                       6a\|a
+--R               + 
+--R                       26 13       2 24 12        4 22 11         6 20 10
+--R                     8B  a   + 592A B  a   + 7602A B  a   + 36260A B  a
+--R                   + 
+--R                           8 18 9         10 16 8         12 14 7
+--R                     75112A B  a  + 53430A  B  a  - 38554A  B  a
+--R                   + 
+--R                             14 12 6         16 10 5        18 8 4        20 6 3
+--R                     - 84704A  B  a  - 45984A  B  a  - 5878A  B a  + 1834A  B a
+--R                   + 
+--R                         22 4 2      24 2      26
+--R                     312A  B a  - 28A  B a - 2A
+--R                *
+--R                     +-+
+--R                   x\|a
+--R               + 
+--R                          25 13        3 23 12         5 21 11         7 19 10
+--R                     96A B  a   + 2456A B  a   + 18484A B  a   + 57984A B  a
+--R                   + 
+--R                           9 17 9         11 15 8         13 13 7
+--R                     76124A B  a  + 10264A  B  a  - 74172A  B  a
+--R                   + 
+--R                             15 11 6         17 9 5       19 7 4        21 5 3
+--R                     - 71440A  B  a  - 21596A  B a  + 744A  B a  + 1052A  B a
+--R                   + 
+--R                        23 3 2      25
+--R                     16A  B a  - 12A  B a
+--R                *
+--R                   x
+--R     + 
+--R          +----------------------------------------------------+
+--R          |       +--------------------+
+--R          |       |   4 2     2 2     4
+--R          |       |- B a  + 2A B a - A           +-+    2     2
+--R          |(- 12a |--------------------  - 4A B)\|a  - B a - A
+--R          |       |           3
+--R          |      \|        48a
+--R          |----------------------------------------------------
+--R          |                          +-+
+--R         \|                       6a\|a
+--R      *
+--R         log
+--R                               23 14        2 21 13         4 19 12
+--R                          - 96B  a   - 6576A B  a   - 80616A B  a
+--R                        + 
+--R                                   6 17 11          8 15 10           10 13 9
+--R                          - 384660A B  a   - 888480A B  a   - 1063608A  B  a
+--R                        + 
+--R                                   12 11 8          14 9 7         16 7 6
+--R                          - 637752A  B  a  - 147324A  B a  + 12816A  B a
+--R                        + 
+--R                               18 5 5      20 3 4      22   3
+--R                          7752A  B a  - 24A  B a  - 84A  B a
+--R                     *
+--R                         +--------------------+
+--R                         |   4 2     2 2     4
+--R                         |- B a  + 2A B a - A
+--R                         |--------------------
+--R                         |           3
+--R                        \|        48a
+--R                    + 
+--R                           24 13       3 22 12        5 20 11         7 18 10
+--R                      12A B  a   + 744A B  a   + 7851A B  a   + 29472A B  a
+--R                    + 
+--R                            9 16 9        11 14 8         13 12 7
+--R                      42759A B  a  + 6396A  B  a  - 42237A  B  a
+--R                    + 
+--R                              15 10 6        17 8 5        19 6 4       21 4 3
+--R                      - 37788A  B  a  - 8847A  B a  + 1236A  B a  + 429A  B a
+--R                    + 
+--R                           23 2 2     25
+--R                      - 24A  B a  - 3A  a
+--R                 *
+--R                     +-+
+--R                    \|a
+--R                + 
+--R                               22 14         3 20 13          5 18 12
+--R                      - 1104A B  a   - 26544A B  a   - 194484A B  a
+--R                    + 
+--R                               7 16 11           9 14 10          11 12 9
+--R                      - 635868A B  a   - 1054824A B  a   - 904488A  B  a
+--R                    + 
+--R                               13 10 8         15 8 7         17 6 6
+--R                      - 359292A  B  a  - 29412A  B a  + 15624A  B a
+--R                    + 
+--R                           19 4 5       21 2 4      23 3
+--R                      1992A  B a  - 228A  B a  - 12A  a
+--R                 *
+--R                     +--------------------+
+--R                     |   4 2     2 2     4
+--R                     |- B a  + 2A B a - A
+--R                     |--------------------
+--R                     |           3
+--R                    \|        48a
+--R                + 
+--R                      2 23 13        4 21 12         6 19 11         8 17 10
+--R                  132A B  a   + 2808A B  a   + 17067A B  a   + 40437A B  a
+--R                + 
+--R                        10 15 9         12 13 8         14 11 7         16 9 6
+--R                  30990A  B  a  - 21990A  B  a  - 47031A  B  a  - 22341A  B a
+--R                + 
+--R                         18 7 5        20 5 4      22 3 3      24   2
+--R                  - 1206A  B a  + 1086A  B a  + 63A  B a  - 15A  B a
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |       +--------------------+
+--R                 |       |   4 2     2 2     4
+--R                 |       |- B a  + 2A B a - A           +-+    2     2
+--R                 |(- 12a |--------------------  - 4A B)\|a  - B a - A
+--R                 |       |           3
+--R                 |      \|        48a
+--R                 |----------------------------------------------------
+--R                 |                          +-+
+--R                \|                       6a\|a
+--R            + 
+--R                    26 13       2 24 12        4 22 11         6 20 10
+--R                  8B  a   + 592A B  a   + 7602A B  a   + 36260A B  a
+--R                + 
+--R                        8 18 9         10 16 8         12 14 7         14 12 6
+--R                  75112A B  a  + 53430A  B  a  - 38554A  B  a  - 84704A  B  a
+--R                + 
+--R                          16 10 5        18 8 4        20 6 3       22 4 2
+--R                  - 45984A  B  a  - 5878A  B a  + 1834A  B a  + 312A  B a
+--R                + 
+--R                       24 2      26
+--R                  - 28A  B a - 2A
+--R             *
+--R                  +-+
+--R                x\|a
+--R            + 
+--R                       25 13        3 23 12         5 21 11         7 19 10
+--R                  96A B  a   + 2456A B  a   + 18484A B  a   + 57984A B  a
+--R                + 
+--R                        9 17 9         11 15 8         13 13 7         15 11 6
+--R                  76124A B  a  + 10264A  B  a  - 74172A  B  a  - 71440A  B  a
+--R                + 
+--R                        17 9 5       19 7 4        21 5 3      23 3 2      25
+--R                - 21596A  B a  + 744A  B a  + 1052A  B a  + 16A  B a  - 12A  B a
+--R             *
+--R                x
+--R     + 
+--R       -
+--R             +--------------------------------------------------+
+--R             |     +--------------------+
+--R             |     |   4 2     2 2     4
+--R             |     |- B a  + 2A B a - A           +-+    2     2
+--R             |(12a |--------------------  - 4A B)\|a  - B a - A
+--R             |     |           3
+--R             |    \|        48a
+--R             |--------------------------------------------------
+--R             |                         +-+
+--R            \|                      6a\|a
+--R         *
+--R            log
+--R                                  23 14        2 21 13         4 19 12
+--R                             - 96B  a   - 6576A B  a   - 80616A B  a
+--R                           + 
+--R                                      6 17 11          8 15 10           10 13 9
+--R                             - 384660A B  a   - 888480A B  a   - 1063608A  B  a
+--R                           + 
+--R                                      12 11 8          14 9 7         16 7 6
+--R                             - 637752A  B  a  - 147324A  B a  + 12816A  B a
+--R                           + 
+--R                                  18 5 5      20 3 4      22   3
+--R                             7752A  B a  - 24A  B a  - 84A  B a
+--R                        *
+--R                            +--------------------+
+--R                            |   4 2     2 2     4
+--R                            |- B a  + 2A B a - A
+--R                            |--------------------
+--R                            |           3
+--R                           \|        48a
+--R                       + 
+--R                                24 13       3 22 12        5 20 11
+--R                         - 12A B  a   - 744A B  a   - 7851A B  a
+--R                       + 
+--R                                 7 18 10         9 16 9        11 14 8
+--R                         - 29472A B  a   - 42759A B  a  - 6396A  B  a
+--R                       + 
+--R                               13 12 7         15 10 6        17 8 5
+--R                         42237A  B  a  + 37788A  B  a  + 8847A  B a
+--R                       + 
+--R                                19 6 4       21 4 3      23 2 2     25
+--R                         - 1236A  B a  - 429A  B a  + 24A  B a  + 3A  a
+--R                    *
+--R                        +-+
+--R                       \|a
+--R                   + 
+--R                                  22 14         3 20 13          5 18 12
+--R                         - 1104A B  a   - 26544A B  a   - 194484A B  a
+--R                       + 
+--R                                  7 16 11           9 14 10          11 12 9
+--R                         - 635868A B  a   - 1054824A B  a   - 904488A  B  a
+--R                       + 
+--R                                  13 10 8         15 8 7         17 6 6
+--R                         - 359292A  B  a  - 29412A  B a  + 15624A  B a
+--R                       + 
+--R                              19 4 5       21 2 4      23 3
+--R                         1992A  B a  - 228A  B a  - 12A  a
+--R                    *
+--R                        +--------------------+
+--R                        |   4 2     2 2     4
+--R                        |- B a  + 2A B a - A
+--R                        |--------------------
+--R                        |           3
+--R                       \|        48a
+--R                   + 
+--R                           2 23 13        4 21 12         6 19 11
+--R                     - 132A B  a   - 2808A B  a   - 17067A B  a
+--R                   + 
+--R                             8 17 10         10 15 9         12 13 8
+--R                     - 40437A B  a   - 30990A  B  a  + 21990A  B  a
+--R                   + 
+--R                           14 11 7         16 9 6        18 7 5        20 5 4
+--R                     47031A  B  a  + 22341A  B a  + 1206A  B a  - 1086A  B a
+--R                   + 
+--R                          22 3 3      24   2
+--R                     - 63A  B a  + 15A  B a
+--R                *
+--R                    +--------------------------------------------------+
+--R                    |     +--------------------+
+--R                    |     |   4 2     2 2     4
+--R                    |     |- B a  + 2A B a - A           +-+    2     2
+--R                    |(12a |--------------------  - 4A B)\|a  - B a - A
+--R                    |     |           3
+--R                    |    \|        48a
+--R                    |--------------------------------------------------
+--R                    |                         +-+
+--R                   \|                      6a\|a
+--R               + 
+--R                       26 13       2 24 12        4 22 11         6 20 10
+--R                     8B  a   + 592A B  a   + 7602A B  a   + 36260A B  a
+--R                   + 
+--R                           8 18 9         10 16 8         12 14 7
+--R                     75112A B  a  + 53430A  B  a  - 38554A  B  a
+--R                   + 
+--R                             14 12 6         16 10 5        18 8 4        20 6 3
+--R                     - 84704A  B  a  - 45984A  B  a  - 5878A  B a  + 1834A  B a
+--R                   + 
+--R                         22 4 2      24 2      26
+--R                     312A  B a  - 28A  B a - 2A
+--R                *
+--R                     +-+
+--R                   x\|a
+--R               + 
+--R                          25 13        3 23 12         5 21 11         7 19 10
+--R                     96A B  a   + 2456A B  a   + 18484A B  a   + 57984A B  a
+--R                   + 
+--R                           9 17 9         11 15 8         13 13 7
+--R                     76124A B  a  + 10264A  B  a  - 74172A  B  a
+--R                   + 
+--R                             15 11 6         17 9 5       19 7 4        21 5 3
+--R                     - 71440A  B  a  - 21596A  B a  + 744A  B a  + 1052A  B a
+--R                   + 
+--R                        23 3 2      25
+--R                     16A  B a  - 12A  B a
+--R                *
+--R                   x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2390
+
+--S 2391 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    +-------------------+
+--R          +-+ +---+ |   +-+    +-+ +---+
+--R         \|6 \|- a \|- \|a  + \|3 \|- a
+--R      *
+--R          +--------------------------------------------------+
+--R          |     +--------------------+
+--R          |     |   4 2     2 2     4
+--R          |     |- B a  + 2A B a - A           +-+    2     2
+--R          |(12a |--------------------  - 4A B)\|a  - B a - A
+--R          |     |           3
+--R          |    \|        48a
+--R          |--------------------------------------------------
+--R          |                         +-+
+--R         \|                      6a\|a
+--R      *
+--R          +-----------------+
+--R          | +-+    +-+ +---+
+--R         \|\|a  + \|3 \|- a
+--R      *
+--R         log
+--R                             23 14        2 21 13         4 19 12
+--R                          96B  a   + 6576A B  a   + 80616A B  a
+--R                        + 
+--R                                 6 17 11          8 15 10           10 13 9
+--R                          384660A B  a   + 888480A B  a   + 1063608A  B  a
+--R                        + 
+--R                                 12 11 8          14 9 7         16 7 6
+--R                          637752A  B  a  + 147324A  B a  - 12816A  B a
+--R                        + 
+--R                                 18 5 5      20 3 4      22   3
+--R                          - 7752A  B a  + 24A  B a  + 84A  B a
+--R                     *
+--R                         +--------------------+
+--R                         |   4 2     2 2     4
+--R                         |- B a  + 2A B a - A
+--R                         |--------------------
+--R                         |           3
+--R                        \|        48a
+--R                    + 
+--R                           24 13       3 22 12        5 20 11         7 18 10
+--R                      12A B  a   + 744A B  a   + 7851A B  a   + 29472A B  a
+--R                    + 
+--R                            9 16 9        11 14 8         13 12 7
+--R                      42759A B  a  + 6396A  B  a  - 42237A  B  a
+--R                    + 
+--R                              15 10 6        17 8 5        19 6 4       21 4 3
+--R                      - 37788A  B  a  - 8847A  B a  + 1236A  B a  + 429A  B a
+--R                    + 
+--R                           23 2 2     25
+--R                      - 24A  B a  - 3A  a
+--R                 *
+--R                     +-+
+--R                    \|a
+--R                + 
+--R                             22 14         3 20 13          5 18 12
+--R                      1104A B  a   + 26544A B  a   + 194484A B  a
+--R                    + 
+--R                             7 16 11           9 14 10          11 12 9
+--R                      635868A B  a   + 1054824A B  a   + 904488A  B  a
+--R                    + 
+--R                             13 10 8         15 8 7         17 6 6        19 4 5
+--R                      359292A  B  a  + 29412A  B a  - 15624A  B a  - 1992A  B a
+--R                    + 
+--R                          21 2 4      23 3
+--R                      228A  B a  + 12A  a
+--R                 *
+--R                     +--------------------+
+--R                     |   4 2     2 2     4
+--R                     |- B a  + 2A B a - A
+--R                     |--------------------
+--R                     |           3
+--R                    \|        48a
+--R                + 
+--R                      2 23 13        4 21 12         6 19 11         8 17 10
+--R                  132A B  a   + 2808A B  a   + 17067A B  a   + 40437A B  a
+--R                + 
+--R                        10 15 9         12 13 8         14 11 7         16 9 6
+--R                  30990A  B  a  - 21990A  B  a  - 47031A  B  a  - 22341A  B a
+--R                + 
+--R                         18 7 5        20 5 4      22 3 3      24   2
+--R                  - 1206A  B a  + 1086A  B a  + 63A  B a  - 15A  B a
+--R             *
+--R                 +--------------------------------------------------+
+--R                 |     +--------------------+
+--R                 |     |   4 2     2 2     4
+--R                 |     |- B a  + 2A B a - A           +-+    2     2
+--R                 |(12a |--------------------  - 4A B)\|a  - B a - A
+--R                 |     |           3
+--R                 |    \|        48a
+--R                 |--------------------------------------------------
+--R                 |                         +-+
+--R                \|                      6a\|a
+--R            + 
+--R                    26 13       2 24 12        4 22 11         6 20 10
+--R                  8B  a   + 592A B  a   + 7602A B  a   + 36260A B  a
+--R                + 
+--R                        8 18 9         10 16 8         12 14 7         14 12 6
+--R                  75112A B  a  + 53430A  B  a  - 38554A  B  a  - 84704A  B  a
+--R                + 
+--R                          16 10 5        18 8 4        20 6 3       22 4 2
+--R                  - 45984A  B  a  - 5878A  B a  + 1834A  B a  + 312A  B a
+--R                + 
+--R                       24 2      26
+--R                  - 28A  B a - 2A
+--R             *
+--R                  +-+
+--R                x\|a
+--R            + 
+--R                       25 13        3 23 12         5 21 11         7 19 10
+--R                  96A B  a   + 2456A B  a   + 18484A B  a   + 57984A B  a
+--R                + 
+--R                        9 17 9         11 15 8         13 13 7         15 11 6
+--R                  76124A B  a  + 10264A  B  a  - 74172A  B  a  - 71440A  B  a
+--R                + 
+--R                        17 9 5       19 7 4        21 5 3      23 3 2      25
+--R                - 21596A  B a  + 744A  B a  + 1052A  B a  + 16A  B a  - 12A  B a
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                       +-------------------+
+--R             +-+ +---+ |   +-+    +-+ +---+
+--R            \|6 \|- a \|- \|a  + \|3 \|- a
+--R         *
+--R             +----------------------------------------------------+
+--R             |       +--------------------+
+--R             |       |   4 2     2 2     4
+--R             |       |- B a  + 2A B a - A           +-+    2     2
+--R             |(- 12a |--------------------  - 4A B)\|a  - B a - A
+--R             |       |           3
+--R             |      \|        48a
+--R             |----------------------------------------------------
+--R             |                          +-+
+--R            \|                       6a\|a
+--R         *
+--R             +-----------------+
+--R             | +-+    +-+ +---+
+--R            \|\|a  + \|3 \|- a
+--R         *
+--R            log
+--R                                23 14        2 21 13         4 19 12
+--R                             96B  a   + 6576A B  a   + 80616A B  a
+--R                           + 
+--R                                    6 17 11          8 15 10           10 13 9
+--R                             384660A B  a   + 888480A B  a   + 1063608A  B  a
+--R                           + 
+--R                                    12 11 8          14 9 7         16 7 6
+--R                             637752A  B  a  + 147324A  B a  - 12816A  B a
+--R                           + 
+--R                                    18 5 5      20 3 4      22   3
+--R                             - 7752A  B a  + 24A  B a  + 84A  B a
+--R                        *
+--R                            +--------------------+
+--R                            |   4 2     2 2     4
+--R                            |- B a  + 2A B a - A
+--R                            |--------------------
+--R                            |           3
+--R                           \|        48a
+--R                       + 
+--R                                24 13       3 22 12        5 20 11
+--R                         - 12A B  a   - 744A B  a   - 7851A B  a
+--R                       + 
+--R                                 7 18 10         9 16 9        11 14 8
+--R                         - 29472A B  a   - 42759A B  a  - 6396A  B  a
+--R                       + 
+--R                               13 12 7         15 10 6        17 8 5
+--R                         42237A  B  a  + 37788A  B  a  + 8847A  B a
+--R                       + 
+--R                                19 6 4       21 4 3      23 2 2     25
+--R                         - 1236A  B a  - 429A  B a  + 24A  B a  + 3A  a
+--R                    *
+--R                        +-+
+--R                       \|a
+--R                   + 
+--R                                22 14         3 20 13          5 18 12
+--R                         1104A B  a   + 26544A B  a   + 194484A B  a
+--R                       + 
+--R                                7 16 11           9 14 10          11 12 9
+--R                         635868A B  a   + 1054824A B  a   + 904488A  B  a
+--R                       + 
+--R                                13 10 8         15 8 7         17 6 6
+--R                         359292A  B  a  + 29412A  B a  - 15624A  B a
+--R                       + 
+--R                                19 4 5       21 2 4      23 3
+--R                         - 1992A  B a  + 228A  B a  + 12A  a
+--R                    *
+--R                        +--------------------+
+--R                        |   4 2     2 2     4
+--R                        |- B a  + 2A B a - A
+--R                        |--------------------
+--R                        |           3
+--R                       \|        48a
+--R                   + 
+--R                           2 23 13        4 21 12         6 19 11
+--R                     - 132A B  a   - 2808A B  a   - 17067A B  a
+--R                   + 
+--R                             8 17 10         10 15 9         12 13 8
+--R                     - 40437A B  a   - 30990A  B  a  + 21990A  B  a
+--R                   + 
+--R                           14 11 7         16 9 6        18 7 5        20 5 4
+--R                     47031A  B  a  + 22341A  B a  + 1206A  B a  - 1086A  B a
+--R                   + 
+--R                          22 3 3      24   2
+--R                     - 63A  B a  + 15A  B a
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |       +--------------------+
+--R                    |       |   4 2     2 2     4
+--R                    |       |- B a  + 2A B a - A           +-+    2     2
+--R                    |(- 12a |--------------------  - 4A B)\|a  - B a - A
+--R                    |       |           3
+--R                    |      \|        48a
+--R                    |----------------------------------------------------
+--R                    |                          +-+
+--R                   \|                       6a\|a
+--R               + 
+--R                       26 13       2 24 12        4 22 11         6 20 10
+--R                     8B  a   + 592A B  a   + 7602A B  a   + 36260A B  a
+--R                   + 
+--R                           8 18 9         10 16 8         12 14 7
+--R                     75112A B  a  + 53430A  B  a  - 38554A  B  a
+--R                   + 
+--R                             14 12 6         16 10 5        18 8 4        20 6 3
+--R                     - 84704A  B  a  - 45984A  B  a  - 5878A  B a  + 1834A  B a
+--R                   + 
+--R                         22 4 2      24 2      26
+--R                     312A  B a  - 28A  B a - 2A
+--R                *
+--R                     +-+
+--R                   x\|a
+--R               + 
+--R                          25 13        3 23 12         5 21 11         7 19 10
+--R                     96A B  a   + 2456A B  a   + 18484A B  a   + 57984A B  a
+--R                   + 
+--R                           9 17 9         11 15 8         13 13 7
+--R                     76124A B  a  + 10264A  B  a  - 74172A  B  a
+--R                   + 
+--R                             15 11 6         17 9 5       19 7 4        21 5 3
+--R                     - 71440A  B  a  - 21596A  B a  + 744A  B a  + 1052A  B a
+--R                   + 
+--R                        23 3 2      25
+--R                     16A  B a  - 12A  B a
+--R                *
+--R                   x
+--R     + 
+--R                    +-------------------+
+--R          +-+ +---+ |   +-+    +-+ +---+
+--R         \|6 \|- a \|- \|a  + \|3 \|- a
+--R      *
+--R          +----------------------------------------------------+
+--R          |       +--------------------+
+--R          |       |   4 2     2 2     4
+--R          |       |- B a  + 2A B a - A           +-+    2     2
+--R          |(- 12a |--------------------  - 4A B)\|a  - B a - A
+--R          |       |           3
+--R          |      \|        48a
+--R          |----------------------------------------------------
+--R          |                          +-+
+--R         \|                       6a\|a
+--R      *
+--R          +-----------------+
+--R          | +-+    +-+ +---+
+--R         \|\|a  + \|3 \|- a
+--R      *
+--R         log
+--R                               23 14        2 21 13         4 19 12
+--R                          - 96B  a   - 6576A B  a   - 80616A B  a
+--R                        + 
+--R                                   6 17 11          8 15 10           10 13 9
+--R                          - 384660A B  a   - 888480A B  a   - 1063608A  B  a
+--R                        + 
+--R                                   12 11 8          14 9 7         16 7 6
+--R                          - 637752A  B  a  - 147324A  B a  + 12816A  B a
+--R                        + 
+--R                               18 5 5      20 3 4      22   3
+--R                          7752A  B a  - 24A  B a  - 84A  B a
+--R                     *
+--R                         +--------------------+
+--R                         |   4 2     2 2     4
+--R                         |- B a  + 2A B a - A
+--R                         |--------------------
+--R                         |           3
+--R                        \|        48a
+--R                    + 
+--R                           24 13       3 22 12        5 20 11         7 18 10
+--R                      12A B  a   + 744A B  a   + 7851A B  a   + 29472A B  a
+--R                    + 
+--R                            9 16 9        11 14 8         13 12 7
+--R                      42759A B  a  + 6396A  B  a  - 42237A  B  a
+--R                    + 
+--R                              15 10 6        17 8 5        19 6 4       21 4 3
+--R                      - 37788A  B  a  - 8847A  B a  + 1236A  B a  + 429A  B a
+--R                    + 
+--R                           23 2 2     25
+--R                      - 24A  B a  - 3A  a
+--R                 *
+--R                     +-+
+--R                    \|a
+--R                + 
+--R                               22 14         3 20 13          5 18 12
+--R                      - 1104A B  a   - 26544A B  a   - 194484A B  a
+--R                    + 
+--R                               7 16 11           9 14 10          11 12 9
+--R                      - 635868A B  a   - 1054824A B  a   - 904488A  B  a
+--R                    + 
+--R                               13 10 8         15 8 7         17 6 6
+--R                      - 359292A  B  a  - 29412A  B a  + 15624A  B a
+--R                    + 
+--R                           19 4 5       21 2 4      23 3
+--R                      1992A  B a  - 228A  B a  - 12A  a
+--R                 *
+--R                     +--------------------+
+--R                     |   4 2     2 2     4
+--R                     |- B a  + 2A B a - A
+--R                     |--------------------
+--R                     |           3
+--R                    \|        48a
+--R                + 
+--R                      2 23 13        4 21 12         6 19 11         8 17 10
+--R                  132A B  a   + 2808A B  a   + 17067A B  a   + 40437A B  a
+--R                + 
+--R                        10 15 9         12 13 8         14 11 7         16 9 6
+--R                  30990A  B  a  - 21990A  B  a  - 47031A  B  a  - 22341A  B a
+--R                + 
+--R                         18 7 5        20 5 4      22 3 3      24   2
+--R                  - 1206A  B a  + 1086A  B a  + 63A  B a  - 15A  B a
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |       +--------------------+
+--R                 |       |   4 2     2 2     4
+--R                 |       |- B a  + 2A B a - A           +-+    2     2
+--R                 |(- 12a |--------------------  - 4A B)\|a  - B a - A
+--R                 |       |           3
+--R                 |      \|        48a
+--R                 |----------------------------------------------------
+--R                 |                          +-+
+--R                \|                       6a\|a
+--R            + 
+--R                    26 13       2 24 12        4 22 11         6 20 10
+--R                  8B  a   + 592A B  a   + 7602A B  a   + 36260A B  a
+--R                + 
+--R                        8 18 9         10 16 8         12 14 7         14 12 6
+--R                  75112A B  a  + 53430A  B  a  - 38554A  B  a  - 84704A  B  a
+--R                + 
+--R                          16 10 5        18 8 4        20 6 3       22 4 2
+--R                  - 45984A  B  a  - 5878A  B a  + 1834A  B a  + 312A  B a
+--R                + 
+--R                       24 2      26
+--R                  - 28A  B a - 2A
+--R             *
+--R                  +-+
+--R                x\|a
+--R            + 
+--R                       25 13        3 23 12         5 21 11         7 19 10
+--R                  96A B  a   + 2456A B  a   + 18484A B  a   + 57984A B  a
+--R                + 
+--R                        9 17 9         11 15 8         13 13 7         15 11 6
+--R                  76124A B  a  + 10264A  B  a  - 74172A  B  a  - 71440A  B  a
+--R                + 
+--R                        17 9 5       19 7 4        21 5 3      23 3 2      25
+--R                - 21596A  B a  + 744A  B a  + 1052A  B a  + 16A  B a  - 12A  B a
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                       +-------------------+
+--R             +-+ +---+ |   +-+    +-+ +---+
+--R            \|6 \|- a \|- \|a  + \|3 \|- a
+--R         *
+--R             +--------------------------------------------------+
+--R             |     +--------------------+
+--R             |     |   4 2     2 2     4
+--R             |     |- B a  + 2A B a - A           +-+    2     2
+--R             |(12a |--------------------  - 4A B)\|a  - B a - A
+--R             |     |           3
+--R             |    \|        48a
+--R             |--------------------------------------------------
+--R             |                         +-+
+--R            \|                      6a\|a
+--R         *
+--R             +-----------------+
+--R             | +-+    +-+ +---+
+--R            \|\|a  + \|3 \|- a
+--R         *
+--R            log
+--R                                  23 14        2 21 13         4 19 12
+--R                             - 96B  a   - 6576A B  a   - 80616A B  a
+--R                           + 
+--R                                      6 17 11          8 15 10           10 13 9
+--R                             - 384660A B  a   - 888480A B  a   - 1063608A  B  a
+--R                           + 
+--R                                      12 11 8          14 9 7         16 7 6
+--R                             - 637752A  B  a  - 147324A  B a  + 12816A  B a
+--R                           + 
+--R                                  18 5 5      20 3 4      22   3
+--R                             7752A  B a  - 24A  B a  - 84A  B a
+--R                        *
+--R                            +--------------------+
+--R                            |   4 2     2 2     4
+--R                            |- B a  + 2A B a - A
+--R                            |--------------------
+--R                            |           3
+--R                           \|        48a
+--R                       + 
+--R                                24 13       3 22 12        5 20 11
+--R                         - 12A B  a   - 744A B  a   - 7851A B  a
+--R                       + 
+--R                                 7 18 10         9 16 9        11 14 8
+--R                         - 29472A B  a   - 42759A B  a  - 6396A  B  a
+--R                       + 
+--R                               13 12 7         15 10 6        17 8 5
+--R                         42237A  B  a  + 37788A  B  a  + 8847A  B a
+--R                       + 
+--R                                19 6 4       21 4 3      23 2 2     25
+--R                         - 1236A  B a  - 429A  B a  + 24A  B a  + 3A  a
+--R                    *
+--R                        +-+
+--R                       \|a
+--R                   + 
+--R                                  22 14         3 20 13          5 18 12
+--R                         - 1104A B  a   - 26544A B  a   - 194484A B  a
+--R                       + 
+--R                                  7 16 11           9 14 10          11 12 9
+--R                         - 635868A B  a   - 1054824A B  a   - 904488A  B  a
+--R                       + 
+--R                                  13 10 8         15 8 7         17 6 6
+--R                         - 359292A  B  a  - 29412A  B a  + 15624A  B a
+--R                       + 
+--R                              19 4 5       21 2 4      23 3
+--R                         1992A  B a  - 228A  B a  - 12A  a
+--R                    *
+--R                        +--------------------+
+--R                        |   4 2     2 2     4
+--R                        |- B a  + 2A B a - A
+--R                        |--------------------
+--R                        |           3
+--R                       \|        48a
+--R                   + 
+--R                           2 23 13        4 21 12         6 19 11
+--R                     - 132A B  a   - 2808A B  a   - 17067A B  a
+--R                   + 
+--R                             8 17 10         10 15 9         12 13 8
+--R                     - 40437A B  a   - 30990A  B  a  + 21990A  B  a
+--R                   + 
+--R                           14 11 7         16 9 6        18 7 5        20 5 4
+--R                     47031A  B  a  + 22341A  B a  + 1206A  B a  - 1086A  B a
+--R                   + 
+--R                          22 3 3      24   2
+--R                     - 63A  B a  + 15A  B a
+--R                *
+--R                    +--------------------------------------------------+
+--R                    |     +--------------------+
+--R                    |     |   4 2     2 2     4
+--R                    |     |- B a  + 2A B a - A           +-+    2     2
+--R                    |(12a |--------------------  - 4A B)\|a  - B a - A
+--R                    |     |           3
+--R                    |    \|        48a
+--R                    |--------------------------------------------------
+--R                    |                         +-+
+--R                   \|                      6a\|a
+--R               + 
+--R                       26 13       2 24 12        4 22 11         6 20 10
+--R                     8B  a   + 592A B  a   + 7602A B  a   + 36260A B  a
+--R                   + 
+--R                           8 18 9         10 16 8         12 14 7
+--R                     75112A B  a  + 53430A  B  a  - 38554A  B  a
+--R                   + 
+--R                             14 12 6         16 10 5        18 8 4        20 6 3
+--R                     - 84704A  B  a  - 45984A  B  a  - 5878A  B a  + 1834A  B a
+--R                   + 
+--R                         22 4 2      24 2      26
+--R                     312A  B a  - 28A  B a - 2A
+--R                *
+--R                     +-+
+--R                   x\|a
+--R               + 
+--R                          25 13        3 23 12         5 21 11         7 19 10
+--R                     96A B  a   + 2456A B  a   + 18484A B  a   + 57984A B  a
+--R                   + 
+--R                           9 17 9         11 15 8         13 13 7
+--R                     76124A B  a  + 10264A  B  a  - 74172A  B  a
+--R                   + 
+--R                             15 11 6         17 9 5       19 7 4        21 5 3
+--R                     - 71440A  B  a  - 21596A  B a  + 744A  B a  + 1052A  B a
+--R                   + 
+--R                        23 3 2      25
+--R                     16A  B a  - 12A  B a
+--R                *
+--R                   x
+--R     + 
+--R                                      +-------------------+
+--R             +-+      +-+ +---+       |   +-+    +-+ +---+
+--R         (2B\|a  + 2B\|3 \|- a  + 4A)\|- \|a  + \|3 \|- a
+--R      *
+--R                         +-+
+--R                       x\|2
+--R         atanh(--------------------)
+--R                +-----------------+
+--R                | +-+    +-+ +---+
+--R               \|\|a  + \|3 \|- a
+--R     + 
+--R                                      +-----------------+
+--R             +-+      +-+ +---+       | +-+    +-+ +---+
+--R         (2B\|a  - 2B\|3 \|- a  + 4A)\|\|a  + \|3 \|- a
+--R      *
+--R                         +-+
+--R                       x\|2
+--R         atan(----------------------)
+--R               +-------------------+
+--R               |   +-+    +-+ +---+
+--R              \|- \|a  + \|3 \|- a
+--R  /
+--R                 +-------------------+ +-----------------+
+--R       +-+ +---+ |   +-+    +-+ +---+  | +-+    +-+ +---+
+--R     2\|6 \|- a \|- \|a  + \|3 \|- a  \|\|a  + \|3 \|- a
+--R                                                    Type: Expression(Integer)
+--E 2391
+
+--S 2392 of 3139
+--d0:=D(m0,x)
+--E 2392
+
+)clear all
+
+--S 2393 of 3139
+t0:=(A+B*x^2)/(a+c*x^4-x^2*sqrt(a*c))
+--R 
+--R
+--R                  2
+--R             - B x  - A
+--R   (1)  -------------------
+--R         2 +---+      4
+--R        x \|a c  - c x  - a
+--R                                                    Type: Expression(Integer)
+--E 2393
+
+--S 2394 of 3139
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(sqrt(3)*sqrt(-a)*sqrt(c)-sqrt(a*c)))*_
+   (B*sqrt(3)+a*(2*A*c+B*sqrt(a*c))/((-a)^(3/2)*sqrt(c)))/(sqrt(6)*sqrt(c)*_
+   sqrt(sqrt(3)*sqrt(-a)*sqrt(c)-sqrt(a*c)))-atanh(x*sqrt(2)*sqrt(c)/_
+   sqrt(sqrt(3)*sqrt(-a)*sqrt(c)+sqrt(a*c)))*(B*sqrt(3)+(2*A*c+_
+   B*sqrt(a*c))/(sqrt(-a)*sqrt(c)))/(sqrt(6)*sqrt(c)*sqrt(sqrt(3)*_
+   sqrt(-a)*sqrt(c)+sqrt(a*c)))
+--R 
+--R
+--R   (2)
+--R                                              +-------------------------+
+--R              +---+     +-+ +---+ +-+         |   +---+    +-+ +---+ +-+
+--R         (- B\|a c  - B\|3 \|- a \|c  - 2A c)\|- \|a c  + \|3 \|- a \|c
+--R      *
+--R                          +-+ +-+
+--R                        x\|2 \|c
+--R         atanh(--------------------------)
+--R                +-----------------------+
+--R                | +---+    +-+ +---+ +-+
+--R               \|\|a c  + \|3 \|- a \|c
+--R     + 
+--R                                              +-----------------------+
+--R              +---+     +-+ +---+ +-+         | +---+    +-+ +---+ +-+
+--R         (- B\|a c  + B\|3 \|- a \|c  - 2A c)\|\|a c  + \|3 \|- a \|c
+--R      *
+--R                          +-+ +-+
+--R                        x\|2 \|c
+--R         atan(----------------------------)
+--R               +-------------------------+
+--R               |   +---+    +-+ +---+ +-+
+--R              \|- \|a c  + \|3 \|- a \|c
+--R  /
+--R                 +-------------------------+ +-----------------------+
+--R       +-+ +---+ |   +---+    +-+ +---+ +-+  | +---+    +-+ +---+ +-+
+--R     c\|6 \|- a \|- \|a c  + \|3 \|- a \|c  \|\|a c  + \|3 \|- a \|c
+--R                                                    Type: Expression(Integer)
+--E 2394
+
+--S 2395 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +-----------------------------------------------------------+
+--R             |       +------------------------+
+--R             |       |   4 2     2 2       4 2
+--R             |       |- A c  + 2A B a c - B a           +---+    2     2
+--R             |(12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R             |       |            3 3
+--R             |      \|         48a c
+--R             |-----------------------------------------------------------
+--R             |                              +---+
+--R            \|                         6a c\|a c
+--R         *
+--R            log
+--R                                22   3 13      20 3 4 12        18 5 5 11
+--R                             84A  B a c   + 24A  B a c   - 7752A  B a c
+--R                           + 
+--R                                     16 7 6 10          14 9 7 9
+--R                             - 12816A  B a c   + 147324A  B a c
+--R                           + 
+--R                                    12 11 8 8           10 13 9 7
+--R                             637752A  B  a c  + 1063608A  B  a c
+--R                           + 
+--R                                    8 15 10 6          6 17 11 5
+--R                             888480A B  a  c  + 384660A B  a  c
+--R                           + 
+--R                                   4 19 12 4        2 21 13 3      23 14 2
+--R                             80616A B  a  c  + 6576A B  a  c  + 96B  a  c
+--R                        *
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                            |- A c  + 2A B a c - B a
+--R                            |------------------------
+--R                            |            3 3
+--R                           \|         48a c
+--R                       + 
+--R                             25   13      23 2 2 12       21 4 3 11
+--R                         - 3A  a c   - 24A  B a c   + 429A  B a c
+--R                       + 
+--R                              19 6 4 10        17 8 5 9         15 10 6 8
+--R                         1236A  B a c   - 8847A  B a c  - 37788A  B  a c
+--R                       + 
+--R                                 13 12 7 7        11 14 8 6         9 16 9 5
+--R                         - 42237A  B  a c  + 6396A  B  a c  + 42759A B  a c
+--R                       + 
+--R                               7 18 10 4        5 20 11 3       3 22 12 2
+--R                         29472A B  a  c  + 7851A B  a  c  + 744A B  a  c
+--R                       + 
+--R                              24 13
+--R                         12A B  a  c
+--R                    *
+--R                        +---+
+--R                       \|a c
+--R                   + 
+--R                            23 3 14       21 2 4 13        19 4 5 12
+--R                         12A  a c   + 228A  B a c   - 1992A  B a c
+--R                       + 
+--R                                 17 6 6 11         15 8 7 10          13 10 8 9
+--R                         - 15624A  B a c   + 29412A  B a c   + 359292A  B  a c
+--R                       + 
+--R                                11 12 9 8           9 14 10 7          7 16 11 6
+--R                         904488A  B  a c  + 1054824A B  a  c  + 635868A B  a  c
+--R                       + 
+--R                                5 18 12 5         3 20 13 4          22 14 3
+--R                         194484A B  a  c  + 26544A B  a  c  + 1104A B  a  c
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |            3 3
+--R                       \|         48a c
+--R                   + 
+--R                          24   2 13      22 3 3 12        20 5 4 11
+--R                     - 15A  B a c   + 63A  B a c   + 1086A  B a c
+--R                   + 
+--R                            18 7 5 10         16 9 6 9         14 11 7 8
+--R                     - 1206A  B a c   - 22341A  B a c  - 47031A  B  a c
+--R                   + 
+--R                             12 13 8 7         10 15 9 6         8 17 10 5
+--R                     - 21990A  B  a c  + 30990A  B  a c  + 40437A B  a  c
+--R                   + 
+--R                           6 19 11 4        4 21 12 3       2 23 13 2
+--R                     17067A B  a  c  + 2808A B  a  c  + 132A B  a  c
+--R                *
+--R                  +-----------------------------------------------------------+
+--R                  |       +------------------------+
+--R                  |       |   4 2     2 2       4 2
+--R                  |       |- A c  + 2A B a c - B a           +---+    2     2
+--R                  |(12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R                  |       |            3 3
+--R                  |      \|         48a c
+--R                  |-----------------------------------------------------------
+--R                  |                              +---+
+--R                 \|                         6a c\|a c
+--R               + 
+--R                       26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                     2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                   + 
+--R                          18 8 4 9         16 10 5 8         14 12 6 7
+--R                     5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                   + 
+--R                           12 14 7 6         10 16 8 5         8 18 9 4
+--R                     38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                   + 
+--R                           6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                   - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R                *
+--R                     +---+
+--R                   x\|a c
+--R               + 
+--R                        25     13      23 3 2 12        21 5 3 11
+--R                     12A  B a c   - 16A  B a c   - 1052A  B a c
+--R                   + 
+--R                           19 7 4 10         17 9 5 9         15 11 6 8
+--R                     - 744A  B a c   + 21596A  B a c  + 71440A  B  a c
+--R                   + 
+--R                           13 13 7 7         11 15 8 6         9 17 9 5
+--R                     74172A  B  a c  - 10264A  B  a c  - 76124A B  a c
+--R                   + 
+--R                             7 19 10 4         5 21 11 3        3 23 12 2
+--R                     - 57984A B  a  c  - 18484A B  a  c  - 2456A B  a  c
+--R                   + 
+--R                            25 13
+--R                     - 96A B  a  c
+--R                *
+--R                   x
+--R     + 
+--R          +-------------------------------------------------------------+
+--R          |         +------------------------+
+--R          |         |   4 2     2 2       4 2
+--R          |         |- A c  + 2A B a c - B a           +---+    2     2
+--R          |(- 12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R          |         |            3 3
+--R          |        \|         48a c
+--R          |-------------------------------------------------------------
+--R          |                               +---+
+--R         \|                          6a c\|a c
+--R      *
+--R         log
+--R                             22   3 13      20 3 4 12        18 5 5 11
+--R                          84A  B a c   + 24A  B a c   - 7752A  B a c
+--R                        + 
+--R                                  16 7 6 10          14 9 7 9          12 11 8 8
+--R                          - 12816A  B a c   + 147324A  B a c  + 637752A  B  a c
+--R                        + 
+--R                                  10 13 9 7          8 15 10 6
+--R                          1063608A  B  a c  + 888480A B  a  c
+--R                        + 
+--R                                 6 17 11 5         4 19 12 4        2 21 13 3
+--R                          384660A B  a  c  + 80616A B  a  c  + 6576A B  a  c
+--R                        + 
+--R                             23 14 2
+--R                          96B  a  c
+--R                     *
+--R                         +------------------------+
+--R                         |   4 2     2 2       4 2
+--R                         |- A c  + 2A B a c - B a
+--R                         |------------------------
+--R                         |            3 3
+--R                        \|         48a c
+--R                    + 
+--R                        25   13      23 2 2 12       21 4 3 11        19 6 4 10
+--R                      3A  a c   + 24A  B a c   - 429A  B a c   - 1236A  B a c
+--R                    + 
+--R                           17 8 5 9         15 10 6 8         13 12 7 7
+--R                      8847A  B a c  + 37788A  B  a c  + 42237A  B  a c
+--R                    + 
+--R                             11 14 8 6         9 16 9 5         7 18 10 4
+--R                      - 6396A  B  a c  - 42759A B  a c  - 29472A B  a  c
+--R                    + 
+--R                             5 20 11 3       3 22 12 2        24 13
+--R                      - 7851A B  a  c  - 744A B  a  c  - 12A B  a  c
+--R                 *
+--R                     +---+
+--R                    \|a c
+--R                + 
+--R                         23 3 14       21 2 4 13        19 4 5 12
+--R                      12A  a c   + 228A  B a c   - 1992A  B a c
+--R                    + 
+--R                              17 6 6 11         15 8 7 10          13 10 8 9
+--R                      - 15624A  B a c   + 29412A  B a c   + 359292A  B  a c
+--R                    + 
+--R                             11 12 9 8           9 14 10 7          7 16 11 6
+--R                      904488A  B  a c  + 1054824A B  a  c  + 635868A B  a  c
+--R                    + 
+--R                             5 18 12 5         3 20 13 4          22 14 3
+--R                      194484A B  a  c  + 26544A B  a  c  + 1104A B  a  c
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |            3 3
+--R                    \|         48a c
+--R                + 
+--R                     24   2 13      22 3 3 12        20 5 4 11        18 7 5 10
+--R                  15A  B a c   - 63A  B a c   - 1086A  B a c   + 1206A  B a c
+--R                + 
+--R                        16 9 6 9         14 11 7 8         12 13 8 7
+--R                  22341A  B a c  + 47031A  B  a c  + 21990A  B  a c
+--R                + 
+--R                          10 15 9 6         8 17 10 5         6 19 11 4
+--R                  - 30990A  B  a c  - 40437A B  a  c  - 17067A B  a  c
+--R                + 
+--R                         4 21 12 3       2 23 13 2
+--R                  - 2808A B  a  c  - 132A B  a  c
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |         +------------------------+
+--R               |         |   4 2     2 2       4 2
+--R               |         |- A c  + 2A B a c - B a           +---+    2     2
+--R               |(- 12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R               |         |            3 3
+--R               |        \|         48a c
+--R               |-------------------------------------------------------------
+--R               |                               +---+
+--R              \|                          6a c\|a c
+--R            + 
+--R                    26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                  2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                + 
+--R                       18 8 4 9         16 10 5 8         14 12 6 7
+--R                  5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                + 
+--R                        12 14 7 6         10 16 8 5         8 18 9 4
+--R                  38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                + 
+--R                          6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                  - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R             *
+--R                  +---+
+--R                x\|a c
+--R            + 
+--R                     25     13      23 3 2 12        21 5 3 11       19 7 4 10
+--R                  12A  B a c   - 16A  B a c   - 1052A  B a c   - 744A  B a c
+--R                + 
+--R                        17 9 5 9         15 11 6 8         13 13 7 7
+--R                  21596A  B a c  + 71440A  B  a c  + 74172A  B  a c
+--R                + 
+--R                          11 15 8 6         9 17 9 5         7 19 10 4
+--R                  - 10264A  B  a c  - 76124A B  a c  - 57984A B  a  c
+--R                + 
+--R                          5 21 11 3        3 23 12 2        25 13
+--R                  - 18484A B  a  c  - 2456A B  a  c  - 96A B  a  c
+--R             *
+--R                x
+--R     + 
+--R       -
+--R             +-------------------------------------------------------------+
+--R             |         +------------------------+
+--R             |         |   4 2     2 2       4 2
+--R             |         |- A c  + 2A B a c - B a           +---+    2     2
+--R             |(- 12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R             |         |            3 3
+--R             |        \|         48a c
+--R             |-------------------------------------------------------------
+--R             |                               +---+
+--R            \|                          6a c\|a c
+--R         *
+--R            log
+--R                                  22   3 13      20 3 4 12        18 5 5 11
+--R                             - 84A  B a c   - 24A  B a c   + 7752A  B a c
+--R                           + 
+--R                                   16 7 6 10          14 9 7 9
+--R                             12816A  B a c   - 147324A  B a c
+--R                           + 
+--R                                      12 11 8 8           10 13 9 7
+--R                             - 637752A  B  a c  - 1063608A  B  a c
+--R                           + 
+--R                                      8 15 10 6          6 17 11 5
+--R                             - 888480A B  a  c  - 384660A B  a  c
+--R                           + 
+--R                                     4 19 12 4        2 21 13 3      23 14 2
+--R                             - 80616A B  a  c  - 6576A B  a  c  - 96B  a  c
+--R                        *
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                            |- A c  + 2A B a c - B a
+--R                            |------------------------
+--R                            |            3 3
+--R                           \|         48a c
+--R                       + 
+--R                             25   13      23 2 2 12       21 4 3 11
+--R                         - 3A  a c   - 24A  B a c   + 429A  B a c
+--R                       + 
+--R                              19 6 4 10        17 8 5 9         15 10 6 8
+--R                         1236A  B a c   - 8847A  B a c  - 37788A  B  a c
+--R                       + 
+--R                                 13 12 7 7        11 14 8 6         9 16 9 5
+--R                         - 42237A  B  a c  + 6396A  B  a c  + 42759A B  a c
+--R                       + 
+--R                               7 18 10 4        5 20 11 3       3 22 12 2
+--R                         29472A B  a  c  + 7851A B  a  c  + 744A B  a  c
+--R                       + 
+--R                              24 13
+--R                         12A B  a  c
+--R                    *
+--R                        +---+
+--R                       \|a c
+--R                   + 
+--R                              23 3 14       21 2 4 13        19 4 5 12
+--R                         - 12A  a c   - 228A  B a c   + 1992A  B a c
+--R                       + 
+--R                               17 6 6 11         15 8 7 10          13 10 8 9
+--R                         15624A  B a c   - 29412A  B a c   - 359292A  B  a c
+--R                       + 
+--R                                  11 12 9 8           9 14 10 7
+--R                         - 904488A  B  a c  - 1054824A B  a  c
+--R                       + 
+--R                                  7 16 11 6          5 18 12 5         3 20 13 4
+--R                         - 635868A B  a  c  - 194484A B  a  c  - 26544A B  a  c
+--R                       + 
+--R                                  22 14 3
+--R                         - 1104A B  a  c
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |            3 3
+--R                       \|         48a c
+--R                   + 
+--R                          24   2 13      22 3 3 12        20 5 4 11
+--R                     - 15A  B a c   + 63A  B a c   + 1086A  B a c
+--R                   + 
+--R                            18 7 5 10         16 9 6 9         14 11 7 8
+--R                     - 1206A  B a c   - 22341A  B a c  - 47031A  B  a c
+--R                   + 
+--R                             12 13 8 7         10 15 9 6         8 17 10 5
+--R                     - 21990A  B  a c  + 30990A  B  a c  + 40437A B  a  c
+--R                   + 
+--R                           6 19 11 4        4 21 12 3       2 23 13 2
+--R                     17067A B  a  c  + 2808A B  a  c  + 132A B  a  c
+--R                *
+--R                   ROOT
+--R                                   +------------------------+
+--R                                   |   4 2     2 2       4 2
+--R                                   |- A c  + 2A B a c - B a           +---+
+--R                          (- 12a c |------------------------  - 4A B)\|a c
+--R                                   |            3 3
+--R                                  \|         48a c
+--R                        + 
+--R                             2     2
+--R                          - A c - B a
+--R                     /
+--R                             +---+
+--R                        6a c\|a c
+--R               + 
+--R                       26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                     2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                   + 
+--R                          18 8 4 9         16 10 5 8         14 12 6 7
+--R                     5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                   + 
+--R                           12 14 7 6         10 16 8 5         8 18 9 4
+--R                     38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                   + 
+--R                           6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                   - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R                *
+--R                     +---+
+--R                   x\|a c
+--R               + 
+--R                        25     13      23 3 2 12        21 5 3 11
+--R                     12A  B a c   - 16A  B a c   - 1052A  B a c
+--R                   + 
+--R                           19 7 4 10         17 9 5 9         15 11 6 8
+--R                     - 744A  B a c   + 21596A  B a c  + 71440A  B  a c
+--R                   + 
+--R                           13 13 7 7         11 15 8 6         9 17 9 5
+--R                     74172A  B  a c  - 10264A  B  a c  - 76124A B  a c
+--R                   + 
+--R                             7 19 10 4         5 21 11 3        3 23 12 2
+--R                     - 57984A B  a  c  - 18484A B  a  c  - 2456A B  a  c
+--R                   + 
+--R                            25 13
+--R                     - 96A B  a  c
+--R                *
+--R                   x
+--R     + 
+--R          +-----------------------------------------------------------+
+--R          |       +------------------------+
+--R          |       |   4 2     2 2       4 2
+--R          |       |- A c  + 2A B a c - B a           +---+    2     2
+--R          |(12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R          |       |            3 3
+--R          |      \|         48a c
+--R          |-----------------------------------------------------------
+--R          |                              +---+
+--R         \|                         6a c\|a c
+--R      *
+--R         log
+--R                               22   3 13      20 3 4 12        18 5 5 11
+--R                          - 84A  B a c   - 24A  B a c   + 7752A  B a c
+--R                        + 
+--R                                16 7 6 10          14 9 7 9          12 11 8 8
+--R                          12816A  B a c   - 147324A  B a c  - 637752A  B  a c
+--R                        + 
+--R                                    10 13 9 7          8 15 10 6
+--R                          - 1063608A  B  a c  - 888480A B  a  c
+--R                        + 
+--R                                   6 17 11 5         4 19 12 4        2 21 13 3
+--R                          - 384660A B  a  c  - 80616A B  a  c  - 6576A B  a  c
+--R                        + 
+--R                               23 14 2
+--R                          - 96B  a  c
+--R                     *
+--R                         +------------------------+
+--R                         |   4 2     2 2       4 2
+--R                         |- A c  + 2A B a c - B a
+--R                         |------------------------
+--R                         |            3 3
+--R                        \|         48a c
+--R                    + 
+--R                        25   13      23 2 2 12       21 4 3 11        19 6 4 10
+--R                      3A  a c   + 24A  B a c   - 429A  B a c   - 1236A  B a c
+--R                    + 
+--R                           17 8 5 9         15 10 6 8         13 12 7 7
+--R                      8847A  B a c  + 37788A  B  a c  + 42237A  B  a c
+--R                    + 
+--R                             11 14 8 6         9 16 9 5         7 18 10 4
+--R                      - 6396A  B  a c  - 42759A B  a c  - 29472A B  a  c
+--R                    + 
+--R                             5 20 11 3       3 22 12 2        24 13
+--R                      - 7851A B  a  c  - 744A B  a  c  - 12A B  a  c
+--R                 *
+--R                     +---+
+--R                    \|a c
+--R                + 
+--R                           23 3 14       21 2 4 13        19 4 5 12
+--R                      - 12A  a c   - 228A  B a c   + 1992A  B a c
+--R                    + 
+--R                            17 6 6 11         15 8 7 10          13 10 8 9
+--R                      15624A  B a c   - 29412A  B a c   - 359292A  B  a c
+--R                    + 
+--R                               11 12 9 8           9 14 10 7          7 16 11 6
+--R                      - 904488A  B  a c  - 1054824A B  a  c  - 635868A B  a  c
+--R                    + 
+--R                               5 18 12 5         3 20 13 4          22 14 3
+--R                      - 194484A B  a  c  - 26544A B  a  c  - 1104A B  a  c
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |            3 3
+--R                    \|         48a c
+--R                + 
+--R                     24   2 13      22 3 3 12        20 5 4 11        18 7 5 10
+--R                  15A  B a c   - 63A  B a c   - 1086A  B a c   + 1206A  B a c
+--R                + 
+--R                        16 9 6 9         14 11 7 8         12 13 8 7
+--R                  22341A  B a c  + 47031A  B  a c  + 21990A  B  a c
+--R                + 
+--R                          10 15 9 6         8 17 10 5         6 19 11 4
+--R                  - 30990A  B  a c  - 40437A B  a  c  - 17067A B  a  c
+--R                + 
+--R                         4 21 12 3       2 23 13 2
+--R                  - 2808A B  a  c  - 132A B  a  c
+--R             *
+--R                 +-----------------------------------------------------------+
+--R                 |       +------------------------+
+--R                 |       |   4 2     2 2       4 2
+--R                 |       |- A c  + 2A B a c - B a           +---+    2     2
+--R                 |(12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R                 |       |            3 3
+--R                 |      \|         48a c
+--R                 |-----------------------------------------------------------
+--R                 |                              +---+
+--R                \|                         6a c\|a c
+--R            + 
+--R                    26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                  2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                + 
+--R                       18 8 4 9         16 10 5 8         14 12 6 7
+--R                  5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                + 
+--R                        12 14 7 6         10 16 8 5         8 18 9 4
+--R                  38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                + 
+--R                          6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                  - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R             *
+--R                  +---+
+--R                x\|a c
+--R            + 
+--R                     25     13      23 3 2 12        21 5 3 11       19 7 4 10
+--R                  12A  B a c   - 16A  B a c   - 1052A  B a c   - 744A  B a c
+--R                + 
+--R                        17 9 5 9         15 11 6 8         13 13 7 7
+--R                  21596A  B a c  + 71440A  B  a c  + 74172A  B  a c
+--R                + 
+--R                          11 15 8 6         9 17 9 5         7 19 10 4
+--R                  - 10264A  B  a c  - 76124A B  a c  - 57984A B  a  c
+--R                + 
+--R                          5 21 11 3        3 23 12 2        25 13
+--R                  - 18484A B  a  c  - 2456A B  a  c  - 96A B  a  c
+--R             *
+--R                x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2395
+
+--S 2396 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        +-------------------------+
+--R              +-+ +---+ |   +---+    +-+ +---+ +-+
+--R            c\|6 \|- a \|- \|a c  + \|3 \|- a \|c
+--R         *
+--R             +-----------------------------------------------------------+
+--R             |       +------------------------+
+--R             |       |   4 2     2 2       4 2
+--R             |       |- A c  + 2A B a c - B a           +---+    2     2
+--R             |(12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R             |       |            3 3
+--R             |      \|         48a c
+--R             |-----------------------------------------------------------
+--R             |                              +---+
+--R            \|                         6a c\|a c
+--R         *
+--R             +-----------------------+
+--R             | +---+    +-+ +---+ +-+
+--R            \|\|a c  + \|3 \|- a \|c
+--R         *
+--R            log
+--R                                22   3 13      20 3 4 12        18 5 5 11
+--R                             84A  B a c   + 24A  B a c   - 7752A  B a c
+--R                           + 
+--R                                     16 7 6 10          14 9 7 9
+--R                             - 12816A  B a c   + 147324A  B a c
+--R                           + 
+--R                                    12 11 8 8           10 13 9 7
+--R                             637752A  B  a c  + 1063608A  B  a c
+--R                           + 
+--R                                    8 15 10 6          6 17 11 5
+--R                             888480A B  a  c  + 384660A B  a  c
+--R                           + 
+--R                                   4 19 12 4        2 21 13 3      23 14 2
+--R                             80616A B  a  c  + 6576A B  a  c  + 96B  a  c
+--R                        *
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                            |- A c  + 2A B a c - B a
+--R                            |------------------------
+--R                            |            3 3
+--R                           \|         48a c
+--R                       + 
+--R                             25   13      23 2 2 12       21 4 3 11
+--R                         - 3A  a c   - 24A  B a c   + 429A  B a c
+--R                       + 
+--R                              19 6 4 10        17 8 5 9         15 10 6 8
+--R                         1236A  B a c   - 8847A  B a c  - 37788A  B  a c
+--R                       + 
+--R                                 13 12 7 7        11 14 8 6         9 16 9 5
+--R                         - 42237A  B  a c  + 6396A  B  a c  + 42759A B  a c
+--R                       + 
+--R                               7 18 10 4        5 20 11 3       3 22 12 2
+--R                         29472A B  a  c  + 7851A B  a  c  + 744A B  a  c
+--R                       + 
+--R                              24 13
+--R                         12A B  a  c
+--R                    *
+--R                        +---+
+--R                       \|a c
+--R                   + 
+--R                            23 3 14       21 2 4 13        19 4 5 12
+--R                         12A  a c   + 228A  B a c   - 1992A  B a c
+--R                       + 
+--R                                 17 6 6 11         15 8 7 10          13 10 8 9
+--R                         - 15624A  B a c   + 29412A  B a c   + 359292A  B  a c
+--R                       + 
+--R                                11 12 9 8           9 14 10 7          7 16 11 6
+--R                         904488A  B  a c  + 1054824A B  a  c  + 635868A B  a  c
+--R                       + 
+--R                                5 18 12 5         3 20 13 4          22 14 3
+--R                         194484A B  a  c  + 26544A B  a  c  + 1104A B  a  c
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |            3 3
+--R                       \|         48a c
+--R                   + 
+--R                          24   2 13      22 3 3 12        20 5 4 11
+--R                     - 15A  B a c   + 63A  B a c   + 1086A  B a c
+--R                   + 
+--R                            18 7 5 10         16 9 6 9         14 11 7 8
+--R                     - 1206A  B a c   - 22341A  B a c  - 47031A  B  a c
+--R                   + 
+--R                             12 13 8 7         10 15 9 6         8 17 10 5
+--R                     - 21990A  B  a c  + 30990A  B  a c  + 40437A B  a  c
+--R                   + 
+--R                           6 19 11 4        4 21 12 3       2 23 13 2
+--R                     17067A B  a  c  + 2808A B  a  c  + 132A B  a  c
+--R                *
+--R                  +-----------------------------------------------------------+
+--R                  |       +------------------------+
+--R                  |       |   4 2     2 2       4 2
+--R                  |       |- A c  + 2A B a c - B a           +---+    2     2
+--R                  |(12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R                  |       |            3 3
+--R                  |      \|         48a c
+--R                  |-----------------------------------------------------------
+--R                  |                              +---+
+--R                 \|                         6a c\|a c
+--R               + 
+--R                       26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                     2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                   + 
+--R                          18 8 4 9         16 10 5 8         14 12 6 7
+--R                     5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                   + 
+--R                           12 14 7 6         10 16 8 5         8 18 9 4
+--R                     38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                   + 
+--R                           6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                   - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R                *
+--R                     +---+
+--R                   x\|a c
+--R               + 
+--R                        25     13      23 3 2 12        21 5 3 11
+--R                     12A  B a c   - 16A  B a c   - 1052A  B a c
+--R                   + 
+--R                           19 7 4 10         17 9 5 9         15 11 6 8
+--R                     - 744A  B a c   + 21596A  B a c  + 71440A  B  a c
+--R                   + 
+--R                           13 13 7 7         11 15 8 6         9 17 9 5
+--R                     74172A  B  a c  - 10264A  B  a c  - 76124A B  a c
+--R                   + 
+--R                             7 19 10 4         5 21 11 3        3 23 12 2
+--R                     - 57984A B  a  c  - 18484A B  a  c  - 2456A B  a  c
+--R                   + 
+--R                            25 13
+--R                     - 96A B  a  c
+--R                *
+--R                   x
+--R     + 
+--R                     +-------------------------+
+--R           +-+ +---+ |   +---+    +-+ +---+ +-+
+--R         c\|6 \|- a \|- \|a c  + \|3 \|- a \|c
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |         +------------------------+
+--R          |         |   4 2     2 2       4 2
+--R          |         |- A c  + 2A B a c - B a           +---+    2     2
+--R          |(- 12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R          |         |            3 3
+--R          |        \|         48a c
+--R          |-------------------------------------------------------------
+--R          |                               +---+
+--R         \|                          6a c\|a c
+--R      *
+--R          +-----------------------+
+--R          | +---+    +-+ +---+ +-+
+--R         \|\|a c  + \|3 \|- a \|c
+--R      *
+--R         log
+--R                             22   3 13      20 3 4 12        18 5 5 11
+--R                          84A  B a c   + 24A  B a c   - 7752A  B a c
+--R                        + 
+--R                                  16 7 6 10          14 9 7 9          12 11 8 8
+--R                          - 12816A  B a c   + 147324A  B a c  + 637752A  B  a c
+--R                        + 
+--R                                  10 13 9 7          8 15 10 6
+--R                          1063608A  B  a c  + 888480A B  a  c
+--R                        + 
+--R                                 6 17 11 5         4 19 12 4        2 21 13 3
+--R                          384660A B  a  c  + 80616A B  a  c  + 6576A B  a  c
+--R                        + 
+--R                             23 14 2
+--R                          96B  a  c
+--R                     *
+--R                         +------------------------+
+--R                         |   4 2     2 2       4 2
+--R                         |- A c  + 2A B a c - B a
+--R                         |------------------------
+--R                         |            3 3
+--R                        \|         48a c
+--R                    + 
+--R                        25   13      23 2 2 12       21 4 3 11        19 6 4 10
+--R                      3A  a c   + 24A  B a c   - 429A  B a c   - 1236A  B a c
+--R                    + 
+--R                           17 8 5 9         15 10 6 8         13 12 7 7
+--R                      8847A  B a c  + 37788A  B  a c  + 42237A  B  a c
+--R                    + 
+--R                             11 14 8 6         9 16 9 5         7 18 10 4
+--R                      - 6396A  B  a c  - 42759A B  a c  - 29472A B  a  c
+--R                    + 
+--R                             5 20 11 3       3 22 12 2        24 13
+--R                      - 7851A B  a  c  - 744A B  a  c  - 12A B  a  c
+--R                 *
+--R                     +---+
+--R                    \|a c
+--R                + 
+--R                         23 3 14       21 2 4 13        19 4 5 12
+--R                      12A  a c   + 228A  B a c   - 1992A  B a c
+--R                    + 
+--R                              17 6 6 11         15 8 7 10          13 10 8 9
+--R                      - 15624A  B a c   + 29412A  B a c   + 359292A  B  a c
+--R                    + 
+--R                             11 12 9 8           9 14 10 7          7 16 11 6
+--R                      904488A  B  a c  + 1054824A B  a  c  + 635868A B  a  c
+--R                    + 
+--R                             5 18 12 5         3 20 13 4          22 14 3
+--R                      194484A B  a  c  + 26544A B  a  c  + 1104A B  a  c
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |            3 3
+--R                    \|         48a c
+--R                + 
+--R                     24   2 13      22 3 3 12        20 5 4 11        18 7 5 10
+--R                  15A  B a c   - 63A  B a c   - 1086A  B a c   + 1206A  B a c
+--R                + 
+--R                        16 9 6 9         14 11 7 8         12 13 8 7
+--R                  22341A  B a c  + 47031A  B  a c  + 21990A  B  a c
+--R                + 
+--R                          10 15 9 6         8 17 10 5         6 19 11 4
+--R                  - 30990A  B  a c  - 40437A B  a  c  - 17067A B  a  c
+--R                + 
+--R                         4 21 12 3       2 23 13 2
+--R                  - 2808A B  a  c  - 132A B  a  c
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |         +------------------------+
+--R               |         |   4 2     2 2       4 2
+--R               |         |- A c  + 2A B a c - B a           +---+    2     2
+--R               |(- 12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R               |         |            3 3
+--R               |        \|         48a c
+--R               |-------------------------------------------------------------
+--R               |                               +---+
+--R              \|                          6a c\|a c
+--R            + 
+--R                    26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                  2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                + 
+--R                       18 8 4 9         16 10 5 8         14 12 6 7
+--R                  5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                + 
+--R                        12 14 7 6         10 16 8 5         8 18 9 4
+--R                  38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                + 
+--R                          6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                  - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R             *
+--R                  +---+
+--R                x\|a c
+--R            + 
+--R                     25     13      23 3 2 12        21 5 3 11       19 7 4 10
+--R                  12A  B a c   - 16A  B a c   - 1052A  B a c   - 744A  B a c
+--R                + 
+--R                        17 9 5 9         15 11 6 8         13 13 7 7
+--R                  21596A  B a c  + 71440A  B  a c  + 74172A  B  a c
+--R                + 
+--R                          11 15 8 6         9 17 9 5         7 19 10 4
+--R                  - 10264A  B  a c  - 76124A B  a c  - 57984A B  a  c
+--R                + 
+--R                          5 21 11 3        3 23 12 2        25 13
+--R                  - 18484A B  a  c  - 2456A B  a  c  - 96A B  a  c
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                        +-------------------------+
+--R              +-+ +---+ |   +---+    +-+ +---+ +-+
+--R            c\|6 \|- a \|- \|a c  + \|3 \|- a \|c
+--R         *
+--R             +-------------------------------------------------------------+
+--R             |         +------------------------+
+--R             |         |   4 2     2 2       4 2
+--R             |         |- A c  + 2A B a c - B a           +---+    2     2
+--R             |(- 12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R             |         |            3 3
+--R             |        \|         48a c
+--R             |-------------------------------------------------------------
+--R             |                               +---+
+--R            \|                          6a c\|a c
+--R         *
+--R             +-----------------------+
+--R             | +---+    +-+ +---+ +-+
+--R            \|\|a c  + \|3 \|- a \|c
+--R         *
+--R            log
+--R                                  22   3 13      20 3 4 12        18 5 5 11
+--R                             - 84A  B a c   - 24A  B a c   + 7752A  B a c
+--R                           + 
+--R                                   16 7 6 10          14 9 7 9
+--R                             12816A  B a c   - 147324A  B a c
+--R                           + 
+--R                                      12 11 8 8           10 13 9 7
+--R                             - 637752A  B  a c  - 1063608A  B  a c
+--R                           + 
+--R                                      8 15 10 6          6 17 11 5
+--R                             - 888480A B  a  c  - 384660A B  a  c
+--R                           + 
+--R                                     4 19 12 4        2 21 13 3      23 14 2
+--R                             - 80616A B  a  c  - 6576A B  a  c  - 96B  a  c
+--R                        *
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                            |- A c  + 2A B a c - B a
+--R                            |------------------------
+--R                            |            3 3
+--R                           \|         48a c
+--R                       + 
+--R                             25   13      23 2 2 12       21 4 3 11
+--R                         - 3A  a c   - 24A  B a c   + 429A  B a c
+--R                       + 
+--R                              19 6 4 10        17 8 5 9         15 10 6 8
+--R                         1236A  B a c   - 8847A  B a c  - 37788A  B  a c
+--R                       + 
+--R                                 13 12 7 7        11 14 8 6         9 16 9 5
+--R                         - 42237A  B  a c  + 6396A  B  a c  + 42759A B  a c
+--R                       + 
+--R                               7 18 10 4        5 20 11 3       3 22 12 2
+--R                         29472A B  a  c  + 7851A B  a  c  + 744A B  a  c
+--R                       + 
+--R                              24 13
+--R                         12A B  a  c
+--R                    *
+--R                        +---+
+--R                       \|a c
+--R                   + 
+--R                              23 3 14       21 2 4 13        19 4 5 12
+--R                         - 12A  a c   - 228A  B a c   + 1992A  B a c
+--R                       + 
+--R                               17 6 6 11         15 8 7 10          13 10 8 9
+--R                         15624A  B a c   - 29412A  B a c   - 359292A  B  a c
+--R                       + 
+--R                                  11 12 9 8           9 14 10 7
+--R                         - 904488A  B  a c  - 1054824A B  a  c
+--R                       + 
+--R                                  7 16 11 6          5 18 12 5         3 20 13 4
+--R                         - 635868A B  a  c  - 194484A B  a  c  - 26544A B  a  c
+--R                       + 
+--R                                  22 14 3
+--R                         - 1104A B  a  c
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |            3 3
+--R                       \|         48a c
+--R                   + 
+--R                          24   2 13      22 3 3 12        20 5 4 11
+--R                     - 15A  B a c   + 63A  B a c   + 1086A  B a c
+--R                   + 
+--R                            18 7 5 10         16 9 6 9         14 11 7 8
+--R                     - 1206A  B a c   - 22341A  B a c  - 47031A  B  a c
+--R                   + 
+--R                             12 13 8 7         10 15 9 6         8 17 10 5
+--R                     - 21990A  B  a c  + 30990A  B  a c  + 40437A B  a  c
+--R                   + 
+--R                           6 19 11 4        4 21 12 3       2 23 13 2
+--R                     17067A B  a  c  + 2808A B  a  c  + 132A B  a  c
+--R                *
+--R                   ROOT
+--R                                   +------------------------+
+--R                                   |   4 2     2 2       4 2
+--R                                   |- A c  + 2A B a c - B a           +---+
+--R                          (- 12a c |------------------------  - 4A B)\|a c
+--R                                   |            3 3
+--R                                  \|         48a c
+--R                        + 
+--R                             2     2
+--R                          - A c - B a
+--R                     /
+--R                             +---+
+--R                        6a c\|a c
+--R               + 
+--R                       26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                     2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                   + 
+--R                          18 8 4 9         16 10 5 8         14 12 6 7
+--R                     5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                   + 
+--R                           12 14 7 6         10 16 8 5         8 18 9 4
+--R                     38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                   + 
+--R                           6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                   - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R                *
+--R                     +---+
+--R                   x\|a c
+--R               + 
+--R                        25     13      23 3 2 12        21 5 3 11
+--R                     12A  B a c   - 16A  B a c   - 1052A  B a c
+--R                   + 
+--R                           19 7 4 10         17 9 5 9         15 11 6 8
+--R                     - 744A  B a c   + 21596A  B a c  + 71440A  B  a c
+--R                   + 
+--R                           13 13 7 7         11 15 8 6         9 17 9 5
+--R                     74172A  B  a c  - 10264A  B  a c  - 76124A B  a c
+--R                   + 
+--R                             7 19 10 4         5 21 11 3        3 23 12 2
+--R                     - 57984A B  a  c  - 18484A B  a  c  - 2456A B  a  c
+--R                   + 
+--R                            25 13
+--R                     - 96A B  a  c
+--R                *
+--R                   x
+--R     + 
+--R                     +-------------------------+
+--R           +-+ +---+ |   +---+    +-+ +---+ +-+
+--R         c\|6 \|- a \|- \|a c  + \|3 \|- a \|c
+--R      *
+--R          +-----------------------------------------------------------+
+--R          |       +------------------------+
+--R          |       |   4 2     2 2       4 2
+--R          |       |- A c  + 2A B a c - B a           +---+    2     2
+--R          |(12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R          |       |            3 3
+--R          |      \|         48a c
+--R          |-----------------------------------------------------------
+--R          |                              +---+
+--R         \|                         6a c\|a c
+--R      *
+--R          +-----------------------+
+--R          | +---+    +-+ +---+ +-+
+--R         \|\|a c  + \|3 \|- a \|c
+--R      *
+--R         log
+--R                               22   3 13      20 3 4 12        18 5 5 11
+--R                          - 84A  B a c   - 24A  B a c   + 7752A  B a c
+--R                        + 
+--R                                16 7 6 10          14 9 7 9          12 11 8 8
+--R                          12816A  B a c   - 147324A  B a c  - 637752A  B  a c
+--R                        + 
+--R                                    10 13 9 7          8 15 10 6
+--R                          - 1063608A  B  a c  - 888480A B  a  c
+--R                        + 
+--R                                   6 17 11 5         4 19 12 4        2 21 13 3
+--R                          - 384660A B  a  c  - 80616A B  a  c  - 6576A B  a  c
+--R                        + 
+--R                               23 14 2
+--R                          - 96B  a  c
+--R                     *
+--R                         +------------------------+
+--R                         |   4 2     2 2       4 2
+--R                         |- A c  + 2A B a c - B a
+--R                         |------------------------
+--R                         |            3 3
+--R                        \|         48a c
+--R                    + 
+--R                        25   13      23 2 2 12       21 4 3 11        19 6 4 10
+--R                      3A  a c   + 24A  B a c   - 429A  B a c   - 1236A  B a c
+--R                    + 
+--R                           17 8 5 9         15 10 6 8         13 12 7 7
+--R                      8847A  B a c  + 37788A  B  a c  + 42237A  B  a c
+--R                    + 
+--R                             11 14 8 6         9 16 9 5         7 18 10 4
+--R                      - 6396A  B  a c  - 42759A B  a c  - 29472A B  a  c
+--R                    + 
+--R                             5 20 11 3       3 22 12 2        24 13
+--R                      - 7851A B  a  c  - 744A B  a  c  - 12A B  a  c
+--R                 *
+--R                     +---+
+--R                    \|a c
+--R                + 
+--R                           23 3 14       21 2 4 13        19 4 5 12
+--R                      - 12A  a c   - 228A  B a c   + 1992A  B a c
+--R                    + 
+--R                            17 6 6 11         15 8 7 10          13 10 8 9
+--R                      15624A  B a c   - 29412A  B a c   - 359292A  B  a c
+--R                    + 
+--R                               11 12 9 8           9 14 10 7          7 16 11 6
+--R                      - 904488A  B  a c  - 1054824A B  a  c  - 635868A B  a  c
+--R                    + 
+--R                               5 18 12 5         3 20 13 4          22 14 3
+--R                      - 194484A B  a  c  - 26544A B  a  c  - 1104A B  a  c
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |            3 3
+--R                    \|         48a c
+--R                + 
+--R                     24   2 13      22 3 3 12        20 5 4 11        18 7 5 10
+--R                  15A  B a c   - 63A  B a c   - 1086A  B a c   + 1206A  B a c
+--R                + 
+--R                        16 9 6 9         14 11 7 8         12 13 8 7
+--R                  22341A  B a c  + 47031A  B  a c  + 21990A  B  a c
+--R                + 
+--R                          10 15 9 6         8 17 10 5         6 19 11 4
+--R                  - 30990A  B  a c  - 40437A B  a  c  - 17067A B  a  c
+--R                + 
+--R                         4 21 12 3       2 23 13 2
+--R                  - 2808A B  a  c  - 132A B  a  c
+--R             *
+--R                 +-----------------------------------------------------------+
+--R                 |       +------------------------+
+--R                 |       |   4 2     2 2       4 2
+--R                 |       |- A c  + 2A B a c - B a           +---+    2     2
+--R                 |(12a c |------------------------  - 4A B)\|a c  - A c - B a
+--R                 |       |            3 3
+--R                 |      \|         48a c
+--R                 |-----------------------------------------------------------
+--R                 |                              +---+
+--R                \|                         6a c\|a c
+--R            + 
+--R                    26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                  2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                + 
+--R                       18 8 4 9         16 10 5 8         14 12 6 7
+--R                  5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                + 
+--R                        12 14 7 6         10 16 8 5         8 18 9 4
+--R                  38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                + 
+--R                          6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                  - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R             *
+--R                  +---+
+--R                x\|a c
+--R            + 
+--R                     25     13      23 3 2 12        21 5 3 11       19 7 4 10
+--R                  12A  B a c   - 16A  B a c   - 1052A  B a c   - 744A  B a c
+--R                + 
+--R                        17 9 5 9         15 11 6 8         13 13 7 7
+--R                  21596A  B a c  + 71440A  B  a c  + 74172A  B  a c
+--R                + 
+--R                          11 15 8 6         9 17 9 5         7 19 10 4
+--R                  - 10264A  B  a c  - 76124A B  a c  - 57984A B  a  c
+--R                + 
+--R                          5 21 11 3        3 23 12 2        25 13
+--R                  - 18484A B  a  c  - 2456A B  a  c  - 96A B  a  c
+--R             *
+--R                x
+--R     + 
+--R                                              +-------------------------+
+--R             +---+      +-+ +---+ +-+         |   +---+    +-+ +---+ +-+
+--R         (2B\|a c  + 2B\|3 \|- a \|c  + 4A c)\|- \|a c  + \|3 \|- a \|c
+--R      *
+--R                          +-+ +-+
+--R                        x\|2 \|c
+--R         atanh(--------------------------)
+--R                +-----------------------+
+--R                | +---+    +-+ +---+ +-+
+--R               \|\|a c  + \|3 \|- a \|c
+--R     + 
+--R                                              +-----------------------+
+--R             +---+      +-+ +---+ +-+         | +---+    +-+ +---+ +-+
+--R         (2B\|a c  - 2B\|3 \|- a \|c  + 4A c)\|\|a c  + \|3 \|- a \|c
+--R      *
+--R                          +-+ +-+
+--R                        x\|2 \|c
+--R         atan(----------------------------)
+--R               +-------------------------+
+--R               |   +---+    +-+ +---+ +-+
+--R              \|- \|a c  + \|3 \|- a \|c
+--R  /
+--R                  +-------------------------+ +-----------------------+
+--R        +-+ +---+ |   +---+    +-+ +---+ +-+  | +---+    +-+ +---+ +-+
+--R     2c\|6 \|- a \|- \|a c  + \|3 \|- a \|c  \|\|a c  + \|3 \|- a \|c
+--R                                                    Type: Expression(Integer)
+--E 2396
+
+--S 2397 of 3139
+--d0:=D(m0,x)
+--E 2397
+
+)clear all
+
+--S 2398 of 3139
+t0:=(A+B*x^2)/(a+c*x^4-x^2*sqrt(a)*sqrt(c))
+--R 
+--R
+--R                   2
+--R              - B x  - A
+--R   (1)  ---------------------
+--R         2 +-+ +-+      4
+--R        x \|a \|c  - c x  - a
+--R                                                    Type: Expression(Integer)
+--E 2398
+
+--S 2399 of 3139
+r0:=atan(c^(1/4)*x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)-sqrt(a)))*(B*sqrt(3)+_
+   (-B*sqrt(a)-2*A*sqrt(c))/sqrt(-a))/(c^(3/4)*sqrt(6)*sqrt(sqrt(3)*_
+   sqrt(-a)-sqrt(a)))-atanh(c^(1/4)*x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)+_
+   sqrt(a)))*(B*sqrt(3)+(B*sqrt(a)+2*A*sqrt(c))/sqrt(-a))/(c^(3/4)*_
+   sqrt(6)*sqrt(sqrt(3)*sqrt(-a)+sqrt(a)))
+--R 
+--R
+--R   (2)
+--R                                          +-------------------+
+--R               +-+     +-+     +-+ +---+  |   +-+    +-+ +---+
+--R         (- 2A\|c  - B\|a  - B\|3 \|- a )\|- \|a  + \|3 \|- a
+--R      *
+--R                       +-+4+-+
+--R                     x\|2 \|c
+--R         atanh(--------------------)
+--R                +-----------------+
+--R                | +-+    +-+ +---+
+--R               \|\|a  + \|3 \|- a
+--R     + 
+--R                                          +-----------------+
+--R               +-+     +-+     +-+ +---+  | +-+    +-+ +---+
+--R         (- 2A\|c  - B\|a  + B\|3 \|- a )\|\|a  + \|3 \|- a
+--R      *
+--R                       +-+4+-+
+--R                     x\|2 \|c
+--R         atan(----------------------)
+--R               +-------------------+
+--R               |   +-+    +-+ +---+
+--R              \|- \|a  + \|3 \|- a
+--R  /
+--R                     +-------------------+ +-----------------+
+--R      +-+ +---+4+-+3 |   +-+    +-+ +---+  | +-+    +-+ +---+
+--R     \|6 \|- a \|c  \|- \|a  + \|3 \|- a  \|\|a  + \|3 \|- a
+--R                                                    Type: Expression(Integer)
+--E 2399
+
+--S 2400 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +-------------------------------------------------------------+
+--R             |       +------------------------+
+--R             |       |   4 2     2 2       4 2
+--R             |       |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R             |(12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R             |       |            3 3
+--R             |      \|         48a c
+--R             |-------------------------------------------------------------
+--R             |                              +-+ +-+
+--R            \|                         6a c\|a \|c
+--R         *
+--R            log
+--R                                22   3 13      20 3 4 12        18 5 5 11
+--R                             84A  B a c   + 24A  B a c   - 7752A  B a c
+--R                           + 
+--R                                     16 7 6 10          14 9 7 9
+--R                             - 12816A  B a c   + 147324A  B a c
+--R                           + 
+--R                                    12 11 8 8           10 13 9 7
+--R                             637752A  B  a c  + 1063608A  B  a c
+--R                           + 
+--R                                    8 15 10 6          6 17 11 5
+--R                             888480A B  a  c  + 384660A B  a  c
+--R                           + 
+--R                                   4 19 12 4        2 21 13 3      23 14 2
+--R                             80616A B  a  c  + 6576A B  a  c  + 96B  a  c
+--R                        *
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                            |- A c  + 2A B a c - B a
+--R                            |------------------------
+--R                            |            3 3
+--R                           \|         48a c
+--R                       + 
+--R                             25   13      23 2 2 12       21 4 3 11
+--R                         - 3A  a c   - 24A  B a c   + 429A  B a c
+--R                       + 
+--R                              19 6 4 10        17 8 5 9         15 10 6 8
+--R                         1236A  B a c   - 8847A  B a c  - 37788A  B  a c
+--R                       + 
+--R                                 13 12 7 7        11 14 8 6         9 16 9 5
+--R                         - 42237A  B  a c  + 6396A  B  a c  + 42759A B  a c
+--R                       + 
+--R                               7 18 10 4        5 20 11 3       3 22 12 2
+--R                         29472A B  a  c  + 7851A B  a  c  + 744A B  a  c
+--R                       + 
+--R                              24 13
+--R                         12A B  a  c
+--R                    *
+--R                        +-+ +-+
+--R                       \|a \|c
+--R                   + 
+--R                            23 3 14       21 2 4 13        19 4 5 12
+--R                         12A  a c   + 228A  B a c   - 1992A  B a c
+--R                       + 
+--R                                 17 6 6 11         15 8 7 10          13 10 8 9
+--R                         - 15624A  B a c   + 29412A  B a c   + 359292A  B  a c
+--R                       + 
+--R                                11 12 9 8           9 14 10 7          7 16 11 6
+--R                         904488A  B  a c  + 1054824A B  a  c  + 635868A B  a  c
+--R                       + 
+--R                                5 18 12 5         3 20 13 4          22 14 3
+--R                         194484A B  a  c  + 26544A B  a  c  + 1104A B  a  c
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |            3 3
+--R                       \|         48a c
+--R                   + 
+--R                          24   2 13      22 3 3 12        20 5 4 11
+--R                     - 15A  B a c   + 63A  B a c   + 1086A  B a c
+--R                   + 
+--R                            18 7 5 10         16 9 6 9         14 11 7 8
+--R                     - 1206A  B a c   - 22341A  B a c  - 47031A  B  a c
+--R                   + 
+--R                             12 13 8 7         10 15 9 6         8 17 10 5
+--R                     - 21990A  B  a c  + 30990A  B  a c  + 40437A B  a  c
+--R                   + 
+--R                           6 19 11 4        4 21 12 3       2 23 13 2
+--R                     17067A B  a  c  + 2808A B  a  c  + 132A B  a  c
+--R                *
+--R                   ROOT
+--R                                 +------------------------+
+--R                                 |   4 2     2 2       4 2
+--R                                 |- A c  + 2A B a c - B a           +-+ +-+
+--R                          (12a c |------------------------  - 4A B)\|a \|c
+--R                                 |            3 3
+--R                                \|         48a c
+--R                        + 
+--R                             2     2
+--R                          - A c - B a
+--R                     /
+--R                             +-+ +-+
+--R                        6a c\|a \|c
+--R               + 
+--R                       26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                     2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                   + 
+--R                          18 8 4 9         16 10 5 8         14 12 6 7
+--R                     5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                   + 
+--R                           12 14 7 6         10 16 8 5         8 18 9 4
+--R                     38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                   + 
+--R                           6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                   - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R                *
+--R                     +-+ +-+
+--R                   x\|a \|c
+--R               + 
+--R                        25     13      23 3 2 12        21 5 3 11
+--R                     12A  B a c   - 16A  B a c   - 1052A  B a c
+--R                   + 
+--R                           19 7 4 10         17 9 5 9         15 11 6 8
+--R                     - 744A  B a c   + 21596A  B a c  + 71440A  B  a c
+--R                   + 
+--R                           13 13 7 7         11 15 8 6         9 17 9 5
+--R                     74172A  B  a c  - 10264A  B  a c  - 76124A B  a c
+--R                   + 
+--R                             7 19 10 4         5 21 11 3        3 23 12 2
+--R                     - 57984A B  a  c  - 18484A B  a  c  - 2456A B  a  c
+--R                   + 
+--R                            25 13
+--R                     - 96A B  a  c
+--R                *
+--R                   x
+--R     + 
+--R          +---------------------------------------------------------------+
+--R          |         +------------------------+
+--R          |         |   4 2     2 2       4 2
+--R          |         |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R          |(- 12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R          |         |            3 3
+--R          |        \|         48a c
+--R          |---------------------------------------------------------------
+--R          |                               +-+ +-+
+--R         \|                          6a c\|a \|c
+--R      *
+--R         log
+--R                             22   3 13      20 3 4 12        18 5 5 11
+--R                          84A  B a c   + 24A  B a c   - 7752A  B a c
+--R                        + 
+--R                                  16 7 6 10          14 9 7 9          12 11 8 8
+--R                          - 12816A  B a c   + 147324A  B a c  + 637752A  B  a c
+--R                        + 
+--R                                  10 13 9 7          8 15 10 6
+--R                          1063608A  B  a c  + 888480A B  a  c
+--R                        + 
+--R                                 6 17 11 5         4 19 12 4        2 21 13 3
+--R                          384660A B  a  c  + 80616A B  a  c  + 6576A B  a  c
+--R                        + 
+--R                             23 14 2
+--R                          96B  a  c
+--R                     *
+--R                         +------------------------+
+--R                         |   4 2     2 2       4 2
+--R                         |- A c  + 2A B a c - B a
+--R                         |------------------------
+--R                         |            3 3
+--R                        \|         48a c
+--R                    + 
+--R                        25   13      23 2 2 12       21 4 3 11        19 6 4 10
+--R                      3A  a c   + 24A  B a c   - 429A  B a c   - 1236A  B a c
+--R                    + 
+--R                           17 8 5 9         15 10 6 8         13 12 7 7
+--R                      8847A  B a c  + 37788A  B  a c  + 42237A  B  a c
+--R                    + 
+--R                             11 14 8 6         9 16 9 5         7 18 10 4
+--R                      - 6396A  B  a c  - 42759A B  a c  - 29472A B  a  c
+--R                    + 
+--R                             5 20 11 3       3 22 12 2        24 13
+--R                      - 7851A B  a  c  - 744A B  a  c  - 12A B  a  c
+--R                 *
+--R                     +-+ +-+
+--R                    \|a \|c
+--R                + 
+--R                         23 3 14       21 2 4 13        19 4 5 12
+--R                      12A  a c   + 228A  B a c   - 1992A  B a c
+--R                    + 
+--R                              17 6 6 11         15 8 7 10          13 10 8 9
+--R                      - 15624A  B a c   + 29412A  B a c   + 359292A  B  a c
+--R                    + 
+--R                             11 12 9 8           9 14 10 7          7 16 11 6
+--R                      904488A  B  a c  + 1054824A B  a  c  + 635868A B  a  c
+--R                    + 
+--R                             5 18 12 5         3 20 13 4          22 14 3
+--R                      194484A B  a  c  + 26544A B  a  c  + 1104A B  a  c
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |            3 3
+--R                    \|         48a c
+--R                + 
+--R                     24   2 13      22 3 3 12        20 5 4 11        18 7 5 10
+--R                  15A  B a c   - 63A  B a c   - 1086A  B a c   + 1206A  B a c
+--R                + 
+--R                        16 9 6 9         14 11 7 8         12 13 8 7
+--R                  22341A  B a c  + 47031A  B  a c  + 21990A  B  a c
+--R                + 
+--R                          10 15 9 6         8 17 10 5         6 19 11 4
+--R                  - 30990A  B  a c  - 40437A B  a  c  - 17067A B  a  c
+--R                + 
+--R                         4 21 12 3       2 23 13 2
+--R                  - 2808A B  a  c  - 132A B  a  c
+--R             *
+--R               +---------------------------------------------------------------+
+--R               |         +------------------------+
+--R               |         |   4 2     2 2       4 2
+--R               |         |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R               |(- 12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R               |         |            3 3
+--R               |        \|         48a c
+--R               |---------------------------------------------------------------
+--R               |                               +-+ +-+
+--R              \|                          6a c\|a \|c
+--R            + 
+--R                    26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                  2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                + 
+--R                       18 8 4 9         16 10 5 8         14 12 6 7
+--R                  5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                + 
+--R                        12 14 7 6         10 16 8 5         8 18 9 4
+--R                  38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                + 
+--R                          6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                  - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R             *
+--R                  +-+ +-+
+--R                x\|a \|c
+--R            + 
+--R                     25     13      23 3 2 12        21 5 3 11       19 7 4 10
+--R                  12A  B a c   - 16A  B a c   - 1052A  B a c   - 744A  B a c
+--R                + 
+--R                        17 9 5 9         15 11 6 8         13 13 7 7
+--R                  21596A  B a c  + 71440A  B  a c  + 74172A  B  a c
+--R                + 
+--R                          11 15 8 6         9 17 9 5         7 19 10 4
+--R                  - 10264A  B  a c  - 76124A B  a c  - 57984A B  a  c
+--R                + 
+--R                          5 21 11 3        3 23 12 2        25 13
+--R                  - 18484A B  a  c  - 2456A B  a  c  - 96A B  a  c
+--R             *
+--R                x
+--R     + 
+--R       -
+--R             +---------------------------------------------------------------+
+--R             |         +------------------------+
+--R             |         |   4 2     2 2       4 2
+--R             |         |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R             |(- 12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R             |         |            3 3
+--R             |        \|         48a c
+--R             |---------------------------------------------------------------
+--R             |                               +-+ +-+
+--R            \|                          6a c\|a \|c
+--R         *
+--R            log
+--R                                  22   3 13      20 3 4 12        18 5 5 11
+--R                             - 84A  B a c   - 24A  B a c   + 7752A  B a c
+--R                           + 
+--R                                   16 7 6 10          14 9 7 9
+--R                             12816A  B a c   - 147324A  B a c
+--R                           + 
+--R                                      12 11 8 8           10 13 9 7
+--R                             - 637752A  B  a c  - 1063608A  B  a c
+--R                           + 
+--R                                      8 15 10 6          6 17 11 5
+--R                             - 888480A B  a  c  - 384660A B  a  c
+--R                           + 
+--R                                     4 19 12 4        2 21 13 3      23 14 2
+--R                             - 80616A B  a  c  - 6576A B  a  c  - 96B  a  c
+--R                        *
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                            |- A c  + 2A B a c - B a
+--R                            |------------------------
+--R                            |            3 3
+--R                           \|         48a c
+--R                       + 
+--R                             25   13      23 2 2 12       21 4 3 11
+--R                         - 3A  a c   - 24A  B a c   + 429A  B a c
+--R                       + 
+--R                              19 6 4 10        17 8 5 9         15 10 6 8
+--R                         1236A  B a c   - 8847A  B a c  - 37788A  B  a c
+--R                       + 
+--R                                 13 12 7 7        11 14 8 6         9 16 9 5
+--R                         - 42237A  B  a c  + 6396A  B  a c  + 42759A B  a c
+--R                       + 
+--R                               7 18 10 4        5 20 11 3       3 22 12 2
+--R                         29472A B  a  c  + 7851A B  a  c  + 744A B  a  c
+--R                       + 
+--R                              24 13
+--R                         12A B  a  c
+--R                    *
+--R                        +-+ +-+
+--R                       \|a \|c
+--R                   + 
+--R                              23 3 14       21 2 4 13        19 4 5 12
+--R                         - 12A  a c   - 228A  B a c   + 1992A  B a c
+--R                       + 
+--R                               17 6 6 11         15 8 7 10          13 10 8 9
+--R                         15624A  B a c   - 29412A  B a c   - 359292A  B  a c
+--R                       + 
+--R                                  11 12 9 8           9 14 10 7
+--R                         - 904488A  B  a c  - 1054824A B  a  c
+--R                       + 
+--R                                  7 16 11 6          5 18 12 5         3 20 13 4
+--R                         - 635868A B  a  c  - 194484A B  a  c  - 26544A B  a  c
+--R                       + 
+--R                                  22 14 3
+--R                         - 1104A B  a  c
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |            3 3
+--R                       \|         48a c
+--R                   + 
+--R                          24   2 13      22 3 3 12        20 5 4 11
+--R                     - 15A  B a c   + 63A  B a c   + 1086A  B a c
+--R                   + 
+--R                            18 7 5 10         16 9 6 9         14 11 7 8
+--R                     - 1206A  B a c   - 22341A  B a c  - 47031A  B  a c
+--R                   + 
+--R                             12 13 8 7         10 15 9 6         8 17 10 5
+--R                     - 21990A  B  a c  + 30990A  B  a c  + 40437A B  a  c
+--R                   + 
+--R                           6 19 11 4        4 21 12 3       2 23 13 2
+--R                     17067A B  a  c  + 2808A B  a  c  + 132A B  a  c
+--R                *
+--R                   ROOT
+--R                                   +------------------------+
+--R                                   |   4 2     2 2       4 2
+--R                                   |- A c  + 2A B a c - B a           +-+ +-+
+--R                          (- 12a c |------------------------  - 4A B)\|a \|c
+--R                                   |            3 3
+--R                                  \|         48a c
+--R                        + 
+--R                             2     2
+--R                          - A c - B a
+--R                     /
+--R                             +-+ +-+
+--R                        6a c\|a \|c
+--R               + 
+--R                       26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                     2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                   + 
+--R                          18 8 4 9         16 10 5 8         14 12 6 7
+--R                     5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                   + 
+--R                           12 14 7 6         10 16 8 5         8 18 9 4
+--R                     38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                   + 
+--R                           6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                   - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R                *
+--R                     +-+ +-+
+--R                   x\|a \|c
+--R               + 
+--R                        25     13      23 3 2 12        21 5 3 11
+--R                     12A  B a c   - 16A  B a c   - 1052A  B a c
+--R                   + 
+--R                           19 7 4 10         17 9 5 9         15 11 6 8
+--R                     - 744A  B a c   + 21596A  B a c  + 71440A  B  a c
+--R                   + 
+--R                           13 13 7 7         11 15 8 6         9 17 9 5
+--R                     74172A  B  a c  - 10264A  B  a c  - 76124A B  a c
+--R                   + 
+--R                             7 19 10 4         5 21 11 3        3 23 12 2
+--R                     - 57984A B  a  c  - 18484A B  a  c  - 2456A B  a  c
+--R                   + 
+--R                            25 13
+--R                     - 96A B  a  c
+--R                *
+--R                   x
+--R     + 
+--R          +-------------------------------------------------------------+
+--R          |       +------------------------+
+--R          |       |   4 2     2 2       4 2
+--R          |       |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R          |(12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R          |       |            3 3
+--R          |      \|         48a c
+--R          |-------------------------------------------------------------
+--R          |                              +-+ +-+
+--R         \|                         6a c\|a \|c
+--R      *
+--R         log
+--R                               22   3 13      20 3 4 12        18 5 5 11
+--R                          - 84A  B a c   - 24A  B a c   + 7752A  B a c
+--R                        + 
+--R                                16 7 6 10          14 9 7 9          12 11 8 8
+--R                          12816A  B a c   - 147324A  B a c  - 637752A  B  a c
+--R                        + 
+--R                                    10 13 9 7          8 15 10 6
+--R                          - 1063608A  B  a c  - 888480A B  a  c
+--R                        + 
+--R                                   6 17 11 5         4 19 12 4        2 21 13 3
+--R                          - 384660A B  a  c  - 80616A B  a  c  - 6576A B  a  c
+--R                        + 
+--R                               23 14 2
+--R                          - 96B  a  c
+--R                     *
+--R                         +------------------------+
+--R                         |   4 2     2 2       4 2
+--R                         |- A c  + 2A B a c - B a
+--R                         |------------------------
+--R                         |            3 3
+--R                        \|         48a c
+--R                    + 
+--R                        25   13      23 2 2 12       21 4 3 11        19 6 4 10
+--R                      3A  a c   + 24A  B a c   - 429A  B a c   - 1236A  B a c
+--R                    + 
+--R                           17 8 5 9         15 10 6 8         13 12 7 7
+--R                      8847A  B a c  + 37788A  B  a c  + 42237A  B  a c
+--R                    + 
+--R                             11 14 8 6         9 16 9 5         7 18 10 4
+--R                      - 6396A  B  a c  - 42759A B  a c  - 29472A B  a  c
+--R                    + 
+--R                             5 20 11 3       3 22 12 2        24 13
+--R                      - 7851A B  a  c  - 744A B  a  c  - 12A B  a  c
+--R                 *
+--R                     +-+ +-+
+--R                    \|a \|c
+--R                + 
+--R                           23 3 14       21 2 4 13        19 4 5 12
+--R                      - 12A  a c   - 228A  B a c   + 1992A  B a c
+--R                    + 
+--R                            17 6 6 11         15 8 7 10          13 10 8 9
+--R                      15624A  B a c   - 29412A  B a c   - 359292A  B  a c
+--R                    + 
+--R                               11 12 9 8           9 14 10 7          7 16 11 6
+--R                      - 904488A  B  a c  - 1054824A B  a  c  - 635868A B  a  c
+--R                    + 
+--R                               5 18 12 5         3 20 13 4          22 14 3
+--R                      - 194484A B  a  c  - 26544A B  a  c  - 1104A B  a  c
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |            3 3
+--R                    \|         48a c
+--R                + 
+--R                     24   2 13      22 3 3 12        20 5 4 11        18 7 5 10
+--R                  15A  B a c   - 63A  B a c   - 1086A  B a c   + 1206A  B a c
+--R                + 
+--R                        16 9 6 9         14 11 7 8         12 13 8 7
+--R                  22341A  B a c  + 47031A  B  a c  + 21990A  B  a c
+--R                + 
+--R                          10 15 9 6         8 17 10 5         6 19 11 4
+--R                  - 30990A  B  a c  - 40437A B  a  c  - 17067A B  a  c
+--R                + 
+--R                         4 21 12 3       2 23 13 2
+--R                  - 2808A B  a  c  - 132A B  a  c
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |       +------------------------+
+--R               |       |   4 2     2 2       4 2
+--R               |       |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R               |(12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R               |       |            3 3
+--R               |      \|         48a c
+--R               |-------------------------------------------------------------
+--R               |                              +-+ +-+
+--R              \|                         6a c\|a \|c
+--R            + 
+--R                    26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                  2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                + 
+--R                       18 8 4 9         16 10 5 8         14 12 6 7
+--R                  5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                + 
+--R                        12 14 7 6         10 16 8 5         8 18 9 4
+--R                  38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                + 
+--R                          6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                  - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R             *
+--R                  +-+ +-+
+--R                x\|a \|c
+--R            + 
+--R                     25     13      23 3 2 12        21 5 3 11       19 7 4 10
+--R                  12A  B a c   - 16A  B a c   - 1052A  B a c   - 744A  B a c
+--R                + 
+--R                        17 9 5 9         15 11 6 8         13 13 7 7
+--R                  21596A  B a c  + 71440A  B  a c  + 74172A  B  a c
+--R                + 
+--R                          11 15 8 6         9 17 9 5         7 19 10 4
+--R                  - 10264A  B  a c  - 76124A B  a c  - 57984A B  a  c
+--R                + 
+--R                          5 21 11 3        3 23 12 2        25 13
+--R                  - 18484A B  a  c  - 2456A B  a  c  - 96A B  a  c
+--R             *
+--R                x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2400
+
+--S 2401 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                            +-------------------+
+--R             +-+ +---+4+-+3 |   +-+    +-+ +---+
+--R            \|6 \|- a \|c  \|- \|a  + \|3 \|- a
+--R         *
+--R             +-------------------------------------------------------------+
+--R             |       +------------------------+
+--R             |       |   4 2     2 2       4 2
+--R             |       |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R             |(12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R             |       |            3 3
+--R             |      \|         48a c
+--R             |-------------------------------------------------------------
+--R             |                              +-+ +-+
+--R            \|                         6a c\|a \|c
+--R         *
+--R             +-----------------+
+--R             | +-+    +-+ +---+
+--R            \|\|a  + \|3 \|- a
+--R         *
+--R            log
+--R                                22   3 13      20 3 4 12        18 5 5 11
+--R                             84A  B a c   + 24A  B a c   - 7752A  B a c
+--R                           + 
+--R                                     16 7 6 10          14 9 7 9
+--R                             - 12816A  B a c   + 147324A  B a c
+--R                           + 
+--R                                    12 11 8 8           10 13 9 7
+--R                             637752A  B  a c  + 1063608A  B  a c
+--R                           + 
+--R                                    8 15 10 6          6 17 11 5
+--R                             888480A B  a  c  + 384660A B  a  c
+--R                           + 
+--R                                   4 19 12 4        2 21 13 3      23 14 2
+--R                             80616A B  a  c  + 6576A B  a  c  + 96B  a  c
+--R                        *
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                            |- A c  + 2A B a c - B a
+--R                            |------------------------
+--R                            |            3 3
+--R                           \|         48a c
+--R                       + 
+--R                             25   13      23 2 2 12       21 4 3 11
+--R                         - 3A  a c   - 24A  B a c   + 429A  B a c
+--R                       + 
+--R                              19 6 4 10        17 8 5 9         15 10 6 8
+--R                         1236A  B a c   - 8847A  B a c  - 37788A  B  a c
+--R                       + 
+--R                                 13 12 7 7        11 14 8 6         9 16 9 5
+--R                         - 42237A  B  a c  + 6396A  B  a c  + 42759A B  a c
+--R                       + 
+--R                               7 18 10 4        5 20 11 3       3 22 12 2
+--R                         29472A B  a  c  + 7851A B  a  c  + 744A B  a  c
+--R                       + 
+--R                              24 13
+--R                         12A B  a  c
+--R                    *
+--R                        +-+ +-+
+--R                       \|a \|c
+--R                   + 
+--R                            23 3 14       21 2 4 13        19 4 5 12
+--R                         12A  a c   + 228A  B a c   - 1992A  B a c
+--R                       + 
+--R                                 17 6 6 11         15 8 7 10          13 10 8 9
+--R                         - 15624A  B a c   + 29412A  B a c   + 359292A  B  a c
+--R                       + 
+--R                                11 12 9 8           9 14 10 7          7 16 11 6
+--R                         904488A  B  a c  + 1054824A B  a  c  + 635868A B  a  c
+--R                       + 
+--R                                5 18 12 5         3 20 13 4          22 14 3
+--R                         194484A B  a  c  + 26544A B  a  c  + 1104A B  a  c
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |            3 3
+--R                       \|         48a c
+--R                   + 
+--R                          24   2 13      22 3 3 12        20 5 4 11
+--R                     - 15A  B a c   + 63A  B a c   + 1086A  B a c
+--R                   + 
+--R                            18 7 5 10         16 9 6 9         14 11 7 8
+--R                     - 1206A  B a c   - 22341A  B a c  - 47031A  B  a c
+--R                   + 
+--R                             12 13 8 7         10 15 9 6         8 17 10 5
+--R                     - 21990A  B  a c  + 30990A  B  a c  + 40437A B  a  c
+--R                   + 
+--R                           6 19 11 4        4 21 12 3       2 23 13 2
+--R                     17067A B  a  c  + 2808A B  a  c  + 132A B  a  c
+--R                *
+--R                   ROOT
+--R                                 +------------------------+
+--R                                 |   4 2     2 2       4 2
+--R                                 |- A c  + 2A B a c - B a           +-+ +-+
+--R                          (12a c |------------------------  - 4A B)\|a \|c
+--R                                 |            3 3
+--R                                \|         48a c
+--R                        + 
+--R                             2     2
+--R                          - A c - B a
+--R                     /
+--R                             +-+ +-+
+--R                        6a c\|a \|c
+--R               + 
+--R                       26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                     2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                   + 
+--R                          18 8 4 9         16 10 5 8         14 12 6 7
+--R                     5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                   + 
+--R                           12 14 7 6         10 16 8 5         8 18 9 4
+--R                     38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                   + 
+--R                           6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                   - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R                *
+--R                     +-+ +-+
+--R                   x\|a \|c
+--R               + 
+--R                        25     13      23 3 2 12        21 5 3 11
+--R                     12A  B a c   - 16A  B a c   - 1052A  B a c
+--R                   + 
+--R                           19 7 4 10         17 9 5 9         15 11 6 8
+--R                     - 744A  B a c   + 21596A  B a c  + 71440A  B  a c
+--R                   + 
+--R                           13 13 7 7         11 15 8 6         9 17 9 5
+--R                     74172A  B  a c  - 10264A  B  a c  - 76124A B  a c
+--R                   + 
+--R                             7 19 10 4         5 21 11 3        3 23 12 2
+--R                     - 57984A B  a  c  - 18484A B  a  c  - 2456A B  a  c
+--R                   + 
+--R                            25 13
+--R                     - 96A B  a  c
+--R                *
+--R                   x
+--R     + 
+--R                         +-------------------+
+--R          +-+ +---+4+-+3 |   +-+    +-+ +---+
+--R         \|6 \|- a \|c  \|- \|a  + \|3 \|- a
+--R      *
+--R          +---------------------------------------------------------------+
+--R          |         +------------------------+
+--R          |         |   4 2     2 2       4 2
+--R          |         |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R          |(- 12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R          |         |            3 3
+--R          |        \|         48a c
+--R          |---------------------------------------------------------------
+--R          |                               +-+ +-+
+--R         \|                          6a c\|a \|c
+--R      *
+--R          +-----------------+
+--R          | +-+    +-+ +---+
+--R         \|\|a  + \|3 \|- a
+--R      *
+--R         log
+--R                             22   3 13      20 3 4 12        18 5 5 11
+--R                          84A  B a c   + 24A  B a c   - 7752A  B a c
+--R                        + 
+--R                                  16 7 6 10          14 9 7 9          12 11 8 8
+--R                          - 12816A  B a c   + 147324A  B a c  + 637752A  B  a c
+--R                        + 
+--R                                  10 13 9 7          8 15 10 6
+--R                          1063608A  B  a c  + 888480A B  a  c
+--R                        + 
+--R                                 6 17 11 5         4 19 12 4        2 21 13 3
+--R                          384660A B  a  c  + 80616A B  a  c  + 6576A B  a  c
+--R                        + 
+--R                             23 14 2
+--R                          96B  a  c
+--R                     *
+--R                         +------------------------+
+--R                         |   4 2     2 2       4 2
+--R                         |- A c  + 2A B a c - B a
+--R                         |------------------------
+--R                         |            3 3
+--R                        \|         48a c
+--R                    + 
+--R                        25   13      23 2 2 12       21 4 3 11        19 6 4 10
+--R                      3A  a c   + 24A  B a c   - 429A  B a c   - 1236A  B a c
+--R                    + 
+--R                           17 8 5 9         15 10 6 8         13 12 7 7
+--R                      8847A  B a c  + 37788A  B  a c  + 42237A  B  a c
+--R                    + 
+--R                             11 14 8 6         9 16 9 5         7 18 10 4
+--R                      - 6396A  B  a c  - 42759A B  a c  - 29472A B  a  c
+--R                    + 
+--R                             5 20 11 3       3 22 12 2        24 13
+--R                      - 7851A B  a  c  - 744A B  a  c  - 12A B  a  c
+--R                 *
+--R                     +-+ +-+
+--R                    \|a \|c
+--R                + 
+--R                         23 3 14       21 2 4 13        19 4 5 12
+--R                      12A  a c   + 228A  B a c   - 1992A  B a c
+--R                    + 
+--R                              17 6 6 11         15 8 7 10          13 10 8 9
+--R                      - 15624A  B a c   + 29412A  B a c   + 359292A  B  a c
+--R                    + 
+--R                             11 12 9 8           9 14 10 7          7 16 11 6
+--R                      904488A  B  a c  + 1054824A B  a  c  + 635868A B  a  c
+--R                    + 
+--R                             5 18 12 5         3 20 13 4          22 14 3
+--R                      194484A B  a  c  + 26544A B  a  c  + 1104A B  a  c
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |            3 3
+--R                    \|         48a c
+--R                + 
+--R                     24   2 13      22 3 3 12        20 5 4 11        18 7 5 10
+--R                  15A  B a c   - 63A  B a c   - 1086A  B a c   + 1206A  B a c
+--R                + 
+--R                        16 9 6 9         14 11 7 8         12 13 8 7
+--R                  22341A  B a c  + 47031A  B  a c  + 21990A  B  a c
+--R                + 
+--R                          10 15 9 6         8 17 10 5         6 19 11 4
+--R                  - 30990A  B  a c  - 40437A B  a  c  - 17067A B  a  c
+--R                + 
+--R                         4 21 12 3       2 23 13 2
+--R                  - 2808A B  a  c  - 132A B  a  c
+--R             *
+--R               +---------------------------------------------------------------+
+--R               |         +------------------------+
+--R               |         |   4 2     2 2       4 2
+--R               |         |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R               |(- 12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R               |         |            3 3
+--R               |        \|         48a c
+--R               |---------------------------------------------------------------
+--R               |                               +-+ +-+
+--R              \|                          6a c\|a \|c
+--R            + 
+--R                    26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                  2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                + 
+--R                       18 8 4 9         16 10 5 8         14 12 6 7
+--R                  5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                + 
+--R                        12 14 7 6         10 16 8 5         8 18 9 4
+--R                  38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                + 
+--R                          6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                  - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R             *
+--R                  +-+ +-+
+--R                x\|a \|c
+--R            + 
+--R                     25     13      23 3 2 12        21 5 3 11       19 7 4 10
+--R                  12A  B a c   - 16A  B a c   - 1052A  B a c   - 744A  B a c
+--R                + 
+--R                        17 9 5 9         15 11 6 8         13 13 7 7
+--R                  21596A  B a c  + 71440A  B  a c  + 74172A  B  a c
+--R                + 
+--R                          11 15 8 6         9 17 9 5         7 19 10 4
+--R                  - 10264A  B  a c  - 76124A B  a c  - 57984A B  a  c
+--R                + 
+--R                          5 21 11 3        3 23 12 2        25 13
+--R                  - 18484A B  a  c  - 2456A B  a  c  - 96A B  a  c
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                            +-------------------+
+--R             +-+ +---+4+-+3 |   +-+    +-+ +---+
+--R            \|6 \|- a \|c  \|- \|a  + \|3 \|- a
+--R         *
+--R             +---------------------------------------------------------------+
+--R             |         +------------------------+
+--R             |         |   4 2     2 2       4 2
+--R             |         |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R             |(- 12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R             |         |            3 3
+--R             |        \|         48a c
+--R             |---------------------------------------------------------------
+--R             |                               +-+ +-+
+--R            \|                          6a c\|a \|c
+--R         *
+--R             +-----------------+
+--R             | +-+    +-+ +---+
+--R            \|\|a  + \|3 \|- a
+--R         *
+--R            log
+--R                                  22   3 13      20 3 4 12        18 5 5 11
+--R                             - 84A  B a c   - 24A  B a c   + 7752A  B a c
+--R                           + 
+--R                                   16 7 6 10          14 9 7 9
+--R                             12816A  B a c   - 147324A  B a c
+--R                           + 
+--R                                      12 11 8 8           10 13 9 7
+--R                             - 637752A  B  a c  - 1063608A  B  a c
+--R                           + 
+--R                                      8 15 10 6          6 17 11 5
+--R                             - 888480A B  a  c  - 384660A B  a  c
+--R                           + 
+--R                                     4 19 12 4        2 21 13 3      23 14 2
+--R                             - 80616A B  a  c  - 6576A B  a  c  - 96B  a  c
+--R                        *
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                            |- A c  + 2A B a c - B a
+--R                            |------------------------
+--R                            |            3 3
+--R                           \|         48a c
+--R                       + 
+--R                             25   13      23 2 2 12       21 4 3 11
+--R                         - 3A  a c   - 24A  B a c   + 429A  B a c
+--R                       + 
+--R                              19 6 4 10        17 8 5 9         15 10 6 8
+--R                         1236A  B a c   - 8847A  B a c  - 37788A  B  a c
+--R                       + 
+--R                                 13 12 7 7        11 14 8 6         9 16 9 5
+--R                         - 42237A  B  a c  + 6396A  B  a c  + 42759A B  a c
+--R                       + 
+--R                               7 18 10 4        5 20 11 3       3 22 12 2
+--R                         29472A B  a  c  + 7851A B  a  c  + 744A B  a  c
+--R                       + 
+--R                              24 13
+--R                         12A B  a  c
+--R                    *
+--R                        +-+ +-+
+--R                       \|a \|c
+--R                   + 
+--R                              23 3 14       21 2 4 13        19 4 5 12
+--R                         - 12A  a c   - 228A  B a c   + 1992A  B a c
+--R                       + 
+--R                               17 6 6 11         15 8 7 10          13 10 8 9
+--R                         15624A  B a c   - 29412A  B a c   - 359292A  B  a c
+--R                       + 
+--R                                  11 12 9 8           9 14 10 7
+--R                         - 904488A  B  a c  - 1054824A B  a  c
+--R                       + 
+--R                                  7 16 11 6          5 18 12 5         3 20 13 4
+--R                         - 635868A B  a  c  - 194484A B  a  c  - 26544A B  a  c
+--R                       + 
+--R                                  22 14 3
+--R                         - 1104A B  a  c
+--R                    *
+--R                        +------------------------+
+--R                        |   4 2     2 2       4 2
+--R                        |- A c  + 2A B a c - B a
+--R                        |------------------------
+--R                        |            3 3
+--R                       \|         48a c
+--R                   + 
+--R                          24   2 13      22 3 3 12        20 5 4 11
+--R                     - 15A  B a c   + 63A  B a c   + 1086A  B a c
+--R                   + 
+--R                            18 7 5 10         16 9 6 9         14 11 7 8
+--R                     - 1206A  B a c   - 22341A  B a c  - 47031A  B  a c
+--R                   + 
+--R                             12 13 8 7         10 15 9 6         8 17 10 5
+--R                     - 21990A  B  a c  + 30990A  B  a c  + 40437A B  a  c
+--R                   + 
+--R                           6 19 11 4        4 21 12 3       2 23 13 2
+--R                     17067A B  a  c  + 2808A B  a  c  + 132A B  a  c
+--R                *
+--R                   ROOT
+--R                                   +------------------------+
+--R                                   |   4 2     2 2       4 2
+--R                                   |- A c  + 2A B a c - B a           +-+ +-+
+--R                          (- 12a c |------------------------  - 4A B)\|a \|c
+--R                                   |            3 3
+--R                                  \|         48a c
+--R                        + 
+--R                             2     2
+--R                          - A c - B a
+--R                     /
+--R                             +-+ +-+
+--R                        6a c\|a \|c
+--R               + 
+--R                       26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                     2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                   + 
+--R                          18 8 4 9         16 10 5 8         14 12 6 7
+--R                     5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                   + 
+--R                           12 14 7 6         10 16 8 5         8 18 9 4
+--R                     38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                   + 
+--R                           6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                   - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R                *
+--R                     +-+ +-+
+--R                   x\|a \|c
+--R               + 
+--R                        25     13      23 3 2 12        21 5 3 11
+--R                     12A  B a c   - 16A  B a c   - 1052A  B a c
+--R                   + 
+--R                           19 7 4 10         17 9 5 9         15 11 6 8
+--R                     - 744A  B a c   + 21596A  B a c  + 71440A  B  a c
+--R                   + 
+--R                           13 13 7 7         11 15 8 6         9 17 9 5
+--R                     74172A  B  a c  - 10264A  B  a c  - 76124A B  a c
+--R                   + 
+--R                             7 19 10 4         5 21 11 3        3 23 12 2
+--R                     - 57984A B  a  c  - 18484A B  a  c  - 2456A B  a  c
+--R                   + 
+--R                            25 13
+--R                     - 96A B  a  c
+--R                *
+--R                   x
+--R     + 
+--R                         +-------------------+
+--R          +-+ +---+4+-+3 |   +-+    +-+ +---+
+--R         \|6 \|- a \|c  \|- \|a  + \|3 \|- a
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |       +------------------------+
+--R          |       |   4 2     2 2       4 2
+--R          |       |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R          |(12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R          |       |            3 3
+--R          |      \|         48a c
+--R          |-------------------------------------------------------------
+--R          |                              +-+ +-+
+--R         \|                         6a c\|a \|c
+--R      *
+--R          +-----------------+
+--R          | +-+    +-+ +---+
+--R         \|\|a  + \|3 \|- a
+--R      *
+--R         log
+--R                               22   3 13      20 3 4 12        18 5 5 11
+--R                          - 84A  B a c   - 24A  B a c   + 7752A  B a c
+--R                        + 
+--R                                16 7 6 10          14 9 7 9          12 11 8 8
+--R                          12816A  B a c   - 147324A  B a c  - 637752A  B  a c
+--R                        + 
+--R                                    10 13 9 7          8 15 10 6
+--R                          - 1063608A  B  a c  - 888480A B  a  c
+--R                        + 
+--R                                   6 17 11 5         4 19 12 4        2 21 13 3
+--R                          - 384660A B  a  c  - 80616A B  a  c  - 6576A B  a  c
+--R                        + 
+--R                               23 14 2
+--R                          - 96B  a  c
+--R                     *
+--R                         +------------------------+
+--R                         |   4 2     2 2       4 2
+--R                         |- A c  + 2A B a c - B a
+--R                         |------------------------
+--R                         |            3 3
+--R                        \|         48a c
+--R                    + 
+--R                        25   13      23 2 2 12       21 4 3 11        19 6 4 10
+--R                      3A  a c   + 24A  B a c   - 429A  B a c   - 1236A  B a c
+--R                    + 
+--R                           17 8 5 9         15 10 6 8         13 12 7 7
+--R                      8847A  B a c  + 37788A  B  a c  + 42237A  B  a c
+--R                    + 
+--R                             11 14 8 6         9 16 9 5         7 18 10 4
+--R                      - 6396A  B  a c  - 42759A B  a c  - 29472A B  a  c
+--R                    + 
+--R                             5 20 11 3       3 22 12 2        24 13
+--R                      - 7851A B  a  c  - 744A B  a  c  - 12A B  a  c
+--R                 *
+--R                     +-+ +-+
+--R                    \|a \|c
+--R                + 
+--R                           23 3 14       21 2 4 13        19 4 5 12
+--R                      - 12A  a c   - 228A  B a c   + 1992A  B a c
+--R                    + 
+--R                            17 6 6 11         15 8 7 10          13 10 8 9
+--R                      15624A  B a c   - 29412A  B a c   - 359292A  B  a c
+--R                    + 
+--R                               11 12 9 8           9 14 10 7          7 16 11 6
+--R                      - 904488A  B  a c  - 1054824A B  a  c  - 635868A B  a  c
+--R                    + 
+--R                               5 18 12 5         3 20 13 4          22 14 3
+--R                      - 194484A B  a  c  - 26544A B  a  c  - 1104A B  a  c
+--R                 *
+--R                     +------------------------+
+--R                     |   4 2     2 2       4 2
+--R                     |- A c  + 2A B a c - B a
+--R                     |------------------------
+--R                     |            3 3
+--R                    \|         48a c
+--R                + 
+--R                     24   2 13      22 3 3 12        20 5 4 11        18 7 5 10
+--R                  15A  B a c   - 63A  B a c   - 1086A  B a c   + 1206A  B a c
+--R                + 
+--R                        16 9 6 9         14 11 7 8         12 13 8 7
+--R                  22341A  B a c  + 47031A  B  a c  + 21990A  B  a c
+--R                + 
+--R                          10 15 9 6         8 17 10 5         6 19 11 4
+--R                  - 30990A  B  a c  - 40437A B  a  c  - 17067A B  a  c
+--R                + 
+--R                         4 21 12 3       2 23 13 2
+--R                  - 2808A B  a  c  - 132A B  a  c
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |       +------------------------+
+--R               |       |   4 2     2 2       4 2
+--R               |       |- A c  + 2A B a c - B a           +-+ +-+    2     2
+--R               |(12a c |------------------------  - 4A B)\|a \|c  - A c - B a
+--R               |       |            3 3
+--R               |      \|         48a c
+--R               |-------------------------------------------------------------
+--R               |                              +-+ +-+
+--R              \|                         6a c\|a \|c
+--R            + 
+--R                    26 13      24 2   12       22 4 2 11        20 6 3 10
+--R                  2A  c   + 28A  B a c   - 312A  B a c   - 1834A  B a c
+--R                + 
+--R                       18 8 4 9         16 10 5 8         14 12 6 7
+--R                  5878A  B a c  + 45984A  B  a c  + 84704A  B  a c
+--R                + 
+--R                        12 14 7 6         10 16 8 5         8 18 9 4
+--R                  38554A  B  a c  - 53430A  B  a c  - 75112A B  a c
+--R                + 
+--R                          6 20 10 3        4 22 11 2       2 24 12      26 13
+--R                  - 36260A B  a  c  - 7602A B  a  c  - 592A B  a  c - 8B  a
+--R             *
+--R                  +-+ +-+
+--R                x\|a \|c
+--R            + 
+--R                     25     13      23 3 2 12        21 5 3 11       19 7 4 10
+--R                  12A  B a c   - 16A  B a c   - 1052A  B a c   - 744A  B a c
+--R                + 
+--R                        17 9 5 9         15 11 6 8         13 13 7 7
+--R                  21596A  B a c  + 71440A  B  a c  + 74172A  B  a c
+--R                + 
+--R                          11 15 8 6         9 17 9 5         7 19 10 4
+--R                  - 10264A  B  a c  - 76124A B  a c  - 57984A B  a  c
+--R                + 
+--R                          5 21 11 3        3 23 12 2        25 13
+--R                  - 18484A B  a  c  - 2456A B  a  c  - 96A B  a  c
+--R             *
+--R                x
+--R     + 
+--R                                          +-------------------+
+--R             +-+      +-+      +-+ +---+  |   +-+    +-+ +---+
+--R         (4A\|c  + 2B\|a  + 2B\|3 \|- a )\|- \|a  + \|3 \|- a
+--R      *
+--R                       +-+4+-+
+--R                     x\|2 \|c
+--R         atanh(--------------------)
+--R                +-----------------+
+--R                | +-+    +-+ +---+
+--R               \|\|a  + \|3 \|- a
+--R     + 
+--R                                          +-----------------+
+--R             +-+      +-+      +-+ +---+  | +-+    +-+ +---+
+--R         (4A\|c  + 2B\|a  - 2B\|3 \|- a )\|\|a  + \|3 \|- a
+--R      *
+--R                       +-+4+-+
+--R                     x\|2 \|c
+--R         atan(----------------------)
+--R               +-------------------+
+--R               |   +-+    +-+ +---+
+--R              \|- \|a  + \|3 \|- a
+--R  /
+--R                      +-------------------+ +-----------------+
+--R       +-+ +---+4+-+3 |   +-+    +-+ +---+  | +-+    +-+ +---+
+--R     2\|6 \|- a \|c  \|- \|a  + \|3 \|- a  \|\|a  + \|3 \|- a
+--R                                                    Type: Expression(Integer)
+--E 2401
+
+--S 2402 of 3139
+--d0:=D(m0,x)
+--E 2402
+
+)clear all
+
+--S 2403 of 3139
+t0:=x*(-7+4*x^2)/(4-5*x^2+x^4)
+--R 
+--R
+--R            3
+--R          4x  - 7x
+--R   (1)  ------------
+--R         4     2
+--R        x  - 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2403
+
+--S 2404 of 3139
+r0:=1/2*log(1-x^2)+3/2*log(4-x^2)
+--R 
+--R
+--R                2               2
+--R        3log(- x  + 4) + log(- x  + 1)
+--R   (2)  ------------------------------
+--R                       2
+--R                                                    Type: Expression(Integer)
+--E 2404
+
+--S 2405 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2              2
+--R        log(x  - 1) + 3log(x  - 4)
+--R   (3)  --------------------------
+--R                     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2405
+
+--S 2406 of 3139
+m0:=a0-r0
+--R 
+--R
+--R             2              2                2               2
+--R        log(x  - 1) + 3log(x  - 4) - 3log(- x  + 4) - log(- x  + 1)
+--R   (4)  -----------------------------------------------------------
+--R                                     2
+--R                                                    Type: Expression(Integer)
+--E 2406
+
+--S 2407 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2407
+
+)clear all
+
+--S 2408 of 3139
+t0:=(-7*x+4*x^3)/(4-5*x^2+x^4)
+--R 
+--R
+--R            3
+--R          4x  - 7x
+--R   (1)  ------------
+--R         4     2
+--R        x  - 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2408
+
+--S 2409 of 3139
+r0:=1/2*log(1-x^2)+3/2*log(4-x^2)
+--R 
+--R
+--R                2               2
+--R        3log(- x  + 4) + log(- x  + 1)
+--R   (2)  ------------------------------
+--R                       2
+--R                                                    Type: Expression(Integer)
+--E 2409
+
+--S 2410 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2              2
+--R        log(x  - 1) + 3log(x  - 4)
+--R   (3)  --------------------------
+--R                     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2410
+
+--S 2411 of 3139
+m0:=a0-r0
+--R 
+--R
+--R             2              2                2               2
+--R        log(x  - 1) + 3log(x  - 4) - 3log(- x  + 4) - log(- x  + 1)
+--R   (4)  -----------------------------------------------------------
+--R                                     2
+--R                                                    Type: Expression(Integer)
+--E 2411
+
+--S 2412 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2412
+
+)clear all
+
+--S 2413 of 3139
+t0:=x*(2+x^2)/(1+x^2+x^4)
+--R 
+--R
+--R           3
+--R          x  + 2x
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2413
+
+--S 2414 of 3139
+r0:=1/4*log(1+x^2+x^4)+1/2*atan((1+2*x^2)/sqrt(3))*sqrt(3)
+--R 
+--R
+--R                                        2      +-+
+--R             4    2          +-+     (2x  + 1)\|3
+--R        log(x  + x  + 1) + 2\|3 atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             4
+--R                                                    Type: Expression(Integer)
+--E 2414
+
+--S 2415 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        +-+
+--R             4    2          +-+       \|3
+--R        log(x  + x  + 1) - 2\|3 atan(-------)
+--R                                       2
+--R                                     2x  + 1
+--R   (3)  -------------------------------------
+--R                          4
+--R                                         Type: Union(Expression(Integer),...)
+--E 2415
+
+--S 2416 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                      2      +-+                +-+
+--R           +-+     (2x  + 1)\|3      +-+       \|3
+--R        - \|3 atan(-------------) - \|3 atan(-------)
+--R                         3                     2
+--R                                             2x  + 1
+--R   (4)  ---------------------------------------------
+--R                              2
+--R                                                    Type: Expression(Integer)
+--E 2416
+
+--S 2417 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2417
+
+)clear all
+
+--S 2418 of 3139
+t0:=(2*x+x^3)/(1+x^2+x^4)
+--R 
+--R
+--R           3
+--R          x  + 2x
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2418
+
+--S 2419 of 3139
+r0:=1/4*log(1+x^2+x^4)+1/2*atan((1+2*x^2)/sqrt(3))*sqrt(3)
+--R 
+--R
+--R                                        2      +-+
+--R             4    2          +-+     (2x  + 1)\|3
+--R        log(x  + x  + 1) + 2\|3 atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             4
+--R                                                    Type: Expression(Integer)
+--E 2419
+
+--S 2420 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        +-+
+--R             4    2          +-+       \|3
+--R        log(x  + x  + 1) - 2\|3 atan(-------)
+--R                                       2
+--R                                     2x  + 1
+--R   (3)  -------------------------------------
+--R                          4
+--R                                         Type: Union(Expression(Integer),...)
+--E 2420
+
+--S 2421 of 3139
+m0:=a0-r0
+--R 
+--R
+--R                      2      +-+                +-+
+--R           +-+     (2x  + 1)\|3      +-+       \|3
+--R        - \|3 atan(-------------) - \|3 atan(-------)
+--R                         3                     2
+--R                                             2x  + 1
+--R   (4)  ---------------------------------------------
+--R                              2
+--R                                                    Type: Expression(Integer)
+--E 2421
+
+--S 2422 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2422
+
+)clear all
+
+--S 2423 of 3139
+t0:=(11*x+2*x^3)/(3+2*x^2+x^4)^2
+--R 
+--R
+--R                   3
+--R                 2x  + 11x
+--R   (1)  --------------------------
+--R         8     6      4      2
+--R        x  + 4x  + 10x  + 12x  + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2423
+
+--S 2424 of 3139
+r0:=1/8*(5+9*x^2)/(3+2*x^2+x^4)+9/8*atan((1+x^2)/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                2      +-+
+--R           4      2           (x  + 1)\|2        2      +-+
+--R        (9x  + 18x  + 27)atan(------------) + (9x  + 5)\|2
+--R                                    2
+--R   (2)  ---------------------------------------------------
+--R                          4      2       +-+
+--R                       (8x  + 16x  + 24)\|2
+--R                                                    Type: Expression(Integer)
+--E 2424
+
+--S 2425 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                2      +-+
+--R           4      2           (x  + 1)\|2        2      +-+
+--R        (9x  + 18x  + 27)atan(------------) + (9x  + 5)\|2
+--R                                    2
+--R   (3)  ---------------------------------------------------
+--R                          4      2       +-+
+--R                       (8x  + 16x  + 24)\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2425
+
+--S 2426 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2426
+
+--S 2427 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2427
+
+)clear all
+
+--S 2428 of 3139
+t0:=x^3*(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                                          +---------------+
+--R              9               7               5        3  |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + (A b + B a)x  + A a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2428
+
+--S 2429 of 3139
+r0:=1/384*(7*b^2*B-12*A*b*c-4*a*B*c)*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^3-_
+   1/120*(7*b*B-2*A*c)*(a+b*x^2+c*x^4)^(5/2)/c^2+1/12*(A+B*x^2)*(a+b*x^2+_
+   c*x^4)^(5/2)/c+1/2048*(b^2-4*a*c)^2*(7*b^2*B-12*A*b*c-4*a*B*c)*_
+   atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(9/2)-_
+   1/1024*(b^2-4*a*c)*(7*b^2*B-12*A*b*c-4*a*B*c)*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^4
+--R 
+--R
+--R   (2)
+--R                     2          3  3             3          2 2  2
+--R           (- 2880A a b - 960B a )c  + (1440A a b  + 2160B a b )c
+--R         + 
+--R                    5           4           6
+--R           (- 180A b  - 900B a b )c + 105B b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                  5 10           5            4  8
+--R           2560B c x   + (3072A c  + 3328B b c )x
+--R         + 
+--R                                4        2 3  6
+--R           ((4224A b + 4480B a)c  + 96B b c )x
+--R         + 
+--R                     4          2             3         3 2  4
+--R           (6144A a c  + (192A b  + 576B a b)c  - 112B b c )x
+--R         + 
+--R                               2  3            3           2  2         4   2
+--R           ((1344A a b + 960B a )c  + (- 240A b  - 864B a b )c  + 140B b c)x
+--R         + 
+--R                  2 3               2          2   2          4            3
+--R           3072A a c  + (- 2400A a b  - 2592B a b)c  + (360A b  + 1520B a b )c
+--R         + 
+--R                   5
+--R           - 210B b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R           4 +-+
+--R     30720c \|c
+--R                                                    Type: Expression(Integer)
+--E 2429
+
+--S 2430 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               4 2            5   5
+--R                     (552960A a b  + 184320B a b)c
+--R                   + 
+--R                               3 4            4 3  4
+--R                     (184320A a b  - 261120B a b )c
+--R                   + 
+--R                                 2 6            3 5  3
+--R                     (- 161280A a b  - 161280B a b )c
+--R                   + 
+--R                                8           2 7  2           10            9
+--R                     (11520A a b  + 97920B a b )c  + (2160A b   - 6000B a b )c
+--R                   + 
+--R                              11
+--R                     - 1260B b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                                5             6  5
+--R                     (1105920A a b + 368640B a )c
+--R                   + 
+--R                                4 3            5 2  4
+--R                     (3317760A a b  + 460800B a b )c
+--R                   + 
+--R                                  3 5             4 4  3
+--R                     (- 1059840A a b  - 2288640B a b )c
+--R                   + 
+--R                                 2 7            3 6  2
+--R                     (- 161280A a b  + 564480B a b )c
+--R                   + 
+--R                                9            2 8               10
+--R                     (50400A a b  + 110880B a b )c - 29400B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                                5 2             6   4
+--R                     (8847360A a b  + 2949120B a b)c
+--R                   + 
+--R                               4 4             5 3  3
+--R                     (737280A a b  - 4915200B a b )c
+--R                   + 
+--R                                  3 6             4 5  2
+--R                     (- 2027520A a b  - 1105920B a b )c
+--R                   + 
+--R                               2 8             3 7              2 9
+--R                     (322560A a b  + 1290240B a b )c - 188160B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                                6              7  4              5 3 3
+--R                     (5898240A a b + 1966080B a )c  + 10321920A a b c
+--R                   + 
+--R                                  4 5             5 4  2
+--R                     (- 6266880A a b  - 8110080B a b )c
+--R                   + 
+--R                               3 7             4 6              3 8
+--R                     (829440A a b  + 3932160B a b )c - 483840B a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                                 6 2             7   3
+--R                     (14745600A a b  + 4915200B a b)c
+--R                   + 
+--R                                  5 4              6 3  2
+--R                     (- 7372800A a b  - 11059200B a b )c
+--R                   + 
+--R                               4 6             5 5              4 7
+--R                     (921600A a b  + 4608000B a b )c - 537600B a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                            7              8  3
+--R                 (5898240A a b + 1966080B a )c
+--R               + 
+--R                              6 3             7 2  2
+--R                 (- 2949120A a b  - 4423680B a b )c
+--R               + 
+--R                           5 5             6 4              5 6
+--R                 (368640A a b  + 1843200B a b )c - 215040B a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                             5            6  6
+--R                 (- 184320A a b - 61440B a )c
+--R               + 
+--R                             4 3           5 2  5
+--R                 (- 599040A a b  - 92160B a b )c
+--R               + 
+--R                           3 5            4 4  4            2 7           3 6  3
+--R                 (161280A a b  + 403200B a b )c  + (40320A a b  - 80640B a b )c
+--R               + 
+--R                             9           2 8  2            11            10
+--R                 (- 9360A a b  - 26640B a b )c  + (- 180A b   + 5400B a b  )c
+--R               + 
+--R                       12
+--R                 105B b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                              5 2             6   5
+--R                 (- 3317760A a b  - 1105920B a b)c
+--R               + 
+--R                              4 4             5 3  4
+--R                 (- 1105920A a b  + 1566720B a b )c
+--R               + 
+--R                           3 6            4 5  3
+--R                 (967680A a b  + 967680B a b )c
+--R               + 
+--R                            2 8            3 7  2
+--R                 (- 69120A a b  - 587520B a b )c
+--R               + 
+--R                              10           2 9              11
+--R                 (- 12960A a b   + 36000B a b )c + 7560B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                              6              7  5
+--R                 (- 3317760A a b - 1105920B a )c
+--R               + 
+--R                              5 3             6 2  4
+--R                 (- 9953280A a b  - 1382400B a b )c
+--R               + 
+--R                            4 5             5 4  3
+--R                 (3179520A a b  + 6865920B a b )c
+--R               + 
+--R                           3 7             4 6  2
+--R                 (483840A a b  - 1693440B a b )c
+--R               + 
+--R                             2 9            3 8             2 10
+--R                 (- 151200A a b  - 332640B a b )c + 88200B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                               6 2             7   4
+--R                 (- 17694720A a b  - 5898240B a b)c
+--R               + 
+--R                              5 4             6 3  3
+--R                 (- 1474560A a b  + 9830400B a b )c
+--R               + 
+--R                            4 6             5 5  2
+--R                 (4055040A a b  + 2211840B a b )c
+--R               + 
+--R                             3 8             4 7              3 9
+--R                 (- 645120A a b  - 2580480B a b )c + 376320B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                              7              8  4              6 3 3
+--R                 (- 8847360A a b - 2949120B a )c  - 15482880A a b c
+--R               + 
+--R                            5 5              6 4  2
+--R                 (9400320A a b  + 12165120B a b )c
+--R               + 
+--R                              4 7             5 6              4 8
+--R                 (- 1244160A a b  - 5898240B a b )c + 725760B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                               7 2             8   3
+--R                 (- 17694720A a b  - 5898240B a b)c
+--R               + 
+--R                            6 4              7 3  2
+--R                 (8847360A a b  + 13271040B a b )c
+--R               + 
+--R                              5 6             6 5              5 7
+--R                 (- 1105920A a b  - 5529600B a b )c + 645120B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                          8              9  3
+--R             (- 5898240A a b - 1966080B a )c
+--R           + 
+--R                        7 3             8 2  2
+--R             (2949120A a b  + 4423680B a b )c
+--R           + 
+--R                         6 5             7 4              6 6
+--R             (- 368640A a b  - 1843200B a b )c + 215040B a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                         3 8            2 2 7              4 6          6 5  22
+--R             (- 163840B a c  - 614400B a b c  - 153600B a b c  - 2560B b c )x
+--R           + 
+--R                            3 8               2 2             3   7
+--R                 - 196608A a c  + (- 737280A a b  - 3162112B a b)c
+--R               + 
+--R                               4             2 3  6
+--R                 (- 184320A a b  - 3256320B a b )c
+--R               + 
+--R                           6              5  5          7 4
+--R                 (- 3072A b  - 384000B a b )c  - 3328B b c
+--R            *
+--R                20
+--R               x
+--R           + 
+--R                              3              4  7
+--R                 (- 3809280A a b - 3235840B a )c
+--R               + 
+--R                              2 3              3 2  6
+--R                 (- 3962880A a b  - 15237120B a b )c
+--R               + 
+--R                               5             2 4  5
+--R                 (- 474624A a b  - 5637120B a b )c
+--R               + 
+--R                           7              6  4        8 3
+--R                 (- 4224A b  - 249856B a b )c  - 96B b c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                             4 7                 3 2              4   6
+--R                 - 3932160A a c  + (- 18739200A a b  - 24760320B a b)c
+--R               + 
+--R                              2 4              3 3  5
+--R                 (- 7050240A a b  - 27136000B a b )c
+--R               + 
+--R                               6             2 5  4            8           7  3
+--R                 (- 321792A a b  - 3217920B a b )c  + (- 192A b  - 768B a b )c
+--R               + 
+--R                       9 2
+--R                 112B b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                               4               5  6
+--R                 (- 30904320A a b - 13086720B a )c
+--R               + 
+--R                               3 3              4 2  5
+--R                 (- 34467840A a b  - 57154560B a b )c
+--R               + 
+--R                              2 5              3 4  4
+--R                 (- 4197888A a b  - 16360960B a b )c
+--R               + 
+--R                            7          2 6  3          9           8  2
+--R                 (- 768A a b  + 2688B a b )c  + (240A b  + 528B a b )c
+--R               + 
+--R                         10
+--R                 - 140B b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                              5 6                 4 2              5   5
+--R                 - 16711680A a c  + (- 74311680A a b  - 55080960B a b)c
+--R               + 
+--R                               3 4              4 3  4
+--R                 (- 21719040A a b  - 41244160B a b )c
+--R               + 
+--R                          2 6           3 5  3               8           2 7  2
+--R                 (26880A a b  + 26880B a b )c  + (- 1920A a b  - 16320B a b )c
+--R               + 
+--R                          10            9           11
+--R                 (- 360A b   + 1000B a b )c + 210B b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                               5               6  5
+--R                 (- 74096640A a b - 20111360B a )c
+--R               + 
+--R                               4 3              5 2  4
+--R                 (- 57692160A a b  - 55633920B a b )c
+--R               + 
+--R                           3 5             4 4  3
+--R                 (540672A a b  + 1090560B a b )c
+--R               + 
+--R                          2 7            3 6  2                9           2 8
+--R                 (57600A a b  - 296192B a b )c  + (- 21600A a b  - 40800B a b )c
+--R               + 
+--R                           10
+--R                 12600B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                              6 5                 5 2              6   4
+--R                 - 27525120A a c  + (- 83681280A a b  - 40017920B a b)c
+--R               + 
+--R                             4 4             5 3  3
+--R                 (- 215040A a b  + 3440640B a b )c
+--R               + 
+--R                            3 6            4 5  2
+--R                 (1236480A a b  + 537600B a b )c
+--R               + 
+--R                             2 8            3 7              2 9
+--R                 (- 201600A a b  - 788480B a b )c + 117600B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                               6               7  4
+--R                 (- 59965440A a b - 12124160B a )c
+--R               + 
+--R                              5 3            6 2  3
+--R                 (- 7864320A a b  + 245760B a b )c
+--R               + 
+--R                            4 5             5 4  2
+--R                 (4853760A a b  + 6205440B a b )c
+--R               + 
+--R                             3 7             4 6              3 8
+--R                 (- 645120A a b  - 3046400B a b )c + 376320B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                              7 4                 6 2             7   3
+--R                 - 15728640A a c  + (- 13271040A a b  - 4423680B a b)c
+--R               + 
+--R                            5 4             6 3  2
+--R                 (6635520A a b  + 9953280B a b )c
+--R               + 
+--R                             4 6             5 5              4 7
+--R                 (- 829440A a b  - 4147200B a b )c + 483840B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                              7              8  3
+--R                 (- 5898240A a b - 1966080B a )c
+--R               + 
+--R                            6 3             7 2  2
+--R                 (2949120A a b  + 4423680B a b )c
+--R               + 
+--R                             5 5             6 4              5 6
+--R                 (- 368640A a b  - 1843200B a b )c + 215040B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                       2   8              3 7           5 6  24
+--R             (491520B a b c  + 409600B a b c  + 30720B b c )x
+--R           + 
+--R                           2             3  8               3             2 2  7
+--R                 (589824A a b + 983040B a )c  + (491520A a b  + 4571136B a b )c
+--R               + 
+--R                          5               4  6           6 5
+--R                 (36864A b  + 1658880B a b )c  + 70656B b c
+--R            *
+--R                22
+--R               x
+--R           + 
+--R                           3 8              2 2              3   7
+--R                 1179648A a c  + (5529600A a b  + 11476992B a b)c
+--R               + 
+--R                              4              2 3  6
+--R                 (2027520A a b  + 14284800B a b )c
+--R               + 
+--R                          6               5  5           7 4
+--R                 (87552A b  + 2280960B a b )c  + 41088B b c
+--R            *
+--R                20
+--R               x
+--R           + 
+--R                             3              4  7
+--R                 (14008320A a b + 7946240B a )c
+--R               + 
+--R                             2 3              3 2  6
+--R                 (17633280A a b  + 42270720B a b )c
+--R               + 
+--R                              5              2 4  5
+--R                 (2860032A a b  + 18462720B a b )c
+--R               + 
+--R                          7               6  4         8 3
+--R                 (52992A b  + 1056768B a b )c  - 192B b c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                           4 7               3 2              4   6
+--R                 9830400A a c  + (52899840A a b  + 51056640B a b)c
+--R               + 
+--R                             2 4              3 3  5
+--R                 (23454720A a b  + 62361600B a b )c
+--R               + 
+--R                              6             2 5  4            8            7  3
+--R                 (1369344A a b  + 8501760B a b )c  + (- 576A b  - 2304B a b )c
+--R               + 
+--R                       9 2
+--R                 336B b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                             4               5  6
+--R                 (65249280A a b + 21749760B a )c
+--R               + 
+--R                             3 3               4 2  5
+--R                 (80732160A a b  + 102389760B a b )c
+--R               + 
+--R                             2 5              3 4  4
+--R                 (11123712A a b  + 31964160B a b )c
+--R               + 
+--R                             7           2 6  3           9            8  2
+--R                 (- 4608A a b  + 16128B a b )c  + (1440A b  + 3168B a b )c
+--R               + 
+--R                         10
+--R                 - 840B b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                            5 6                4 2              5   5
+--R                 28508160A a c  + (137164800A a b  + 81930240B a b)c
+--R               + 
+--R                             3 4              4 3  4
+--R                 (43223040A a b  + 64094720B a b )c
+--R               + 
+--R                             2 6            3 5  3
+--R                 (- 412416A a b  - 341760B a b )c
+--R               + 
+--R                            8            2 7  2           10             9
+--R                 (40320A a b  + 254016B a b )c  + (3960A b   - 22200B a b )c
+--R               + 
+--R                          11
+--R                 - 2310B b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                              5               6  5
+--R                 (113172480A a b + 25927680B a )c
+--R               + 
+--R                             4 3              5 2  4
+--R                 (95109120A a b  + 73820160B a b )c
+--R               + 
+--R                              3 5             4 4  3
+--R                 (- 2184192A a b  - 4254720B a b )c
+--R               + 
+--R                             2 7             3 6  2
+--R                 (- 184320A a b  + 1212672B a b )c
+--R               + 
+--R                            9            2 8               10
+--R                 (79200A a b  + 133920B a b )c - 46200B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            6 5                5 2              6   4
+--R                 35389440A a c  + (116858880A a b  + 47800320B a b)c
+--R               + 
+--R                           4 4             5 3  3
+--R                 (276480A a b  - 7864320B a b )c
+--R               + 
+--R                              3 6             4 5  2
+--R                 (- 2695680A a b  - 1059840B a b )c
+--R               + 
+--R                           2 8             3 7              2 9
+--R                 (443520A a b  + 1720320B a b )c - 258720B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             6               7  4
+--R                 (70778880A a b + 13107200B a )c
+--R               + 
+--R                             5 3            6 2  3
+--R                 (12288000A a b  - 491520B a b )c
+--R               + 
+--R                              4 5             5 4  2
+--R                 (- 7618560A a b  - 9707520B a b )c
+--R               + 
+--R                            3 7             4 6              3 8
+--R                 (1013760A a b  + 4782080B a b )c - 591360B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            7 4               6 2             7   3
+--R                 15728640A a c  + (16220160A a b  + 5406720B a b)c
+--R               + 
+--R                              5 4              6 3  2
+--R                 (- 8110080A a b  - 12165120B a b )c
+--R               + 
+--R                            4 6             5 5              4 7
+--R                 (1013760A a b  + 5068800B a b )c - 591360B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            7              8  3
+--R                 (5898240A a b + 1966080B a )c
+--R               + 
+--R                              6 3             7 2  2
+--R                 (- 2949120A a b  - 4423680B a b )c
+--R               + 
+--R                           5 5             6 4              5 6
+--R                 (368640A a b  + 1843200B a b )c - 215040B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                      2   6             3 5          5 4  10
+--R             (5898240a b c  + 4915200a b c  + 368640b c )x
+--R           + 
+--R                       3 6            2 2 5             4 4  8
+--R             (11796480a c  + 41287680a b c  + 8601600a b c )x
+--R           + 
+--R                       3   5            2 3 4  6
+--R             (94371840a b c  + 55050240a b c )x
+--R           + 
+--R                     4 5             3 2 4  4             4   4 2            5 4
+--R           (62914560a c  + 141557760a b c )x  + 157286400a b c x  + 62914560a c
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                        3 7           2 2 6             4 5         6 4  12
+--R             (- 1966080a c  - 7372800a b c  - 1843200a b c  - 30720b c )x
+--R           + 
+--R                         3   6            2 3 5             5 4  10
+--R             (- 35389440a b c  - 29491200a b c  - 2211840a b c )x
+--R           + 
+--R                         4 6             3 2 5            2 4 4  8
+--R             (- 35389440a c  - 123863040a b c  - 25804800a b c )x
+--R           + 
+--R                          4   5             3 3 4  6
+--R             (- 188743680a b c  - 110100480a b c )x
+--R           + 
+--R                         5 5             4 2 4  4             5   4 2
+--R             (- 94371840a c  - 212336640a b c )x  - 188743680a b c x
+--R           + 
+--R                        6 4
+--R             - 62914560a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                                 4 2            5   5
+--R                     (- 552960A a b  - 184320B a b)c
+--R                   + 
+--R                                 3 4            4 3  4
+--R                     (- 184320A a b  + 261120B a b )c
+--R                   + 
+--R                               2 6            3 5  3
+--R                     (161280A a b  + 161280B a b )c
+--R                   + 
+--R                                  8           2 7  2
+--R                     (- 11520A a b  - 97920B a b )c
+--R                   + 
+--R                               10            9            11
+--R                     (- 2160A b   + 6000B a b )c + 1260B b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                                  5             6  5
+--R                     (- 1105920A a b - 368640B a )c
+--R                   + 
+--R                                  4 3            5 2  4
+--R                     (- 3317760A a b  - 460800B a b )c
+--R                   + 
+--R                                3 5             4 4  3
+--R                     (1059840A a b  + 2288640B a b )c
+--R                   + 
+--R                               2 7            3 6  2
+--R                     (161280A a b  - 564480B a b )c
+--R                   + 
+--R                                  9            2 8               10
+--R                     (- 50400A a b  - 110880B a b )c + 29400B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                                  5 2             6   4
+--R                     (- 8847360A a b  - 2949120B a b)c
+--R                   + 
+--R                                 4 4             5 3  3
+--R                     (- 737280A a b  + 4915200B a b )c
+--R                   + 
+--R                                3 6             4 5  2
+--R                     (2027520A a b  + 1105920B a b )c
+--R                   + 
+--R                                 2 8             3 7              2 9
+--R                     (- 322560A a b  - 1290240B a b )c + 188160B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                                  6              7  4              5 3 3
+--R                     (- 5898240A a b - 1966080B a )c  - 10321920A a b c
+--R                   + 
+--R                                4 5             5 4  2
+--R                     (6266880A a b  + 8110080B a b )c
+--R                   + 
+--R                                 3 7             4 6              3 8
+--R                     (- 829440A a b  - 3932160B a b )c + 483840B a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                                   6 2             7   3
+--R                     (- 14745600A a b  - 4915200B a b)c
+--R                   + 
+--R                                5 4              6 3  2
+--R                     (7372800A a b  + 11059200B a b )c
+--R                   + 
+--R                                 4 6             5 5              4 7
+--R                     (- 921600A a b  - 4608000B a b )c + 537600B a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                              7              8  3
+--R                 (- 5898240A a b - 1966080B a )c
+--R               + 
+--R                            6 3             7 2  2
+--R                 (2949120A a b  + 4423680B a b )c
+--R               + 
+--R                             5 5             6 4              5 6
+--R                 (- 368640A a b  - 1843200B a b )c + 215040B a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                           5            6  6             4 3           5 2  5
+--R                 (184320A a b + 61440B a )c  + (599040A a b  + 92160B a b )c
+--R               + 
+--R                             3 5            4 4  4
+--R                 (- 161280A a b  - 403200B a b )c
+--R               + 
+--R                            2 7           3 6  3             9           2 8  2
+--R                 (- 40320A a b  + 80640B a b )c  + (9360A a b  + 26640B a b )c
+--R               + 
+--R                        11            10           12
+--R                 (180A b   - 5400B a b  )c - 105B b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            5 2             6   5
+--R                 (3317760A a b  + 1105920B a b)c
+--R               + 
+--R                            4 4             5 3  4
+--R                 (1105920A a b  - 1566720B a b )c
+--R               + 
+--R                             3 6            4 5  3
+--R                 (- 967680A a b  - 967680B a b )c
+--R               + 
+--R                          2 8            3 7  2              10           2 9
+--R                 (69120A a b  + 587520B a b )c  + (12960A a b   - 36000B a b )c
+--R               + 
+--R                            11
+--R                 - 7560B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            6              7  5
+--R                 (3317760A a b + 1105920B a )c
+--R               + 
+--R                            5 3             6 2  4
+--R                 (9953280A a b  + 1382400B a b )c
+--R               + 
+--R                              4 5             5 4  3
+--R                 (- 3179520A a b  - 6865920B a b )c
+--R               + 
+--R                             3 7             4 6  2
+--R                 (- 483840A a b  + 1693440B a b )c
+--R               + 
+--R                           2 9            3 8             2 10
+--R                 (151200A a b  + 332640B a b )c - 88200B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             6 2             7   4
+--R                 (17694720A a b  + 5898240B a b)c
+--R               + 
+--R                            5 4             6 3  3
+--R                 (1474560A a b  - 9830400B a b )c
+--R               + 
+--R                              4 6             5 5  2
+--R                 (- 4055040A a b  - 2211840B a b )c
+--R               + 
+--R                           3 8             4 7              3 9
+--R                 (645120A a b  + 2580480B a b )c - 376320B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            7              8  4              6 3 3
+--R                 (8847360A a b + 2949120B a )c  + 15482880A a b c
+--R               + 
+--R                              5 5              6 4  2
+--R                 (- 9400320A a b  - 12165120B a b )c
+--R               + 
+--R                            4 7             5 6              4 8
+--R                 (1244160A a b  + 5898240B a b )c - 725760B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                             7 2             8   3
+--R                 (17694720A a b  + 5898240B a b)c
+--R               + 
+--R                              6 4              7 3  2
+--R                 (- 8847360A a b  - 13271040B a b )c
+--R               + 
+--R                            5 6             6 5              5 7
+--R                 (1105920A a b  + 5529600B a b )c - 645120B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        8              9  3
+--R             (5898240A a b + 1966080B a )c
+--R           + 
+--R                          7 3             8 2  2
+--R             (- 2949120A a b  - 4423680B a b )c
+--R           + 
+--R                       6 5             7 4              6 6
+--R             (368640A a b  + 1843200B a b )c - 215040B a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                        3 8            2 2 7             4 6          6 5  22
+--R             (- 81920B a c  - 307200B a b c  - 76800B a b c  - 1280B b c )x
+--R           + 
+--R                           3 8               2 2             3   7
+--R                 - 98304A a c  + (- 368640A a b  - 1581056B a b)c
+--R               + 
+--R                              4             2 3  6
+--R                 (- 92160A a b  - 1628160B a b )c
+--R               + 
+--R                           6              5  5          7 4
+--R                 (- 1536A b  - 192000B a b )c  - 1664B b c
+--R            *
+--R                20
+--R               x
+--R           + 
+--R                              3              4  7
+--R                 (- 1904640A a b - 1617920B a )c
+--R               + 
+--R                              2 3             3 2  6
+--R                 (- 1981440A a b  - 7618560B a b )c
+--R               + 
+--R                               5             2 4  5
+--R                 (- 237312A a b  - 2818560B a b )c
+--R               + 
+--R                           7              6  4        8 3
+--R                 (- 2112A b  - 124928B a b )c  - 48B b c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                             4 7                3 2              4   6
+--R                 - 1966080A a c  + (- 9369600A a b  - 12380160B a b)c
+--R               + 
+--R                              2 4              3 3  5
+--R                 (- 3525120A a b  - 13568000B a b )c
+--R               + 
+--R                               6             2 5  4           8           7  3
+--R                 (- 160896A a b  - 1608960B a b )c  + (- 96A b  - 384B a b )c
+--R               + 
+--R                      9 2
+--R                 56B b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                               4              5  6
+--R                 (- 15452160A a b - 6543360B a )c
+--R               + 
+--R                               3 3              4 2  5
+--R                 (- 17233920A a b  - 28577280B a b )c
+--R               + 
+--R                              2 5             3 4  4
+--R                 (- 2098944A a b  - 8180480B a b )c
+--R               + 
+--R                          7          2 6  3          9           8  2        10
+--R               (- 384A a b  + 1344B a b )c  + (120A b  + 264B a b )c  - 70B b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                             5 6                 4 2              5   5
+--R                 - 8355840A a c  + (- 37155840A a b  - 27540480B a b)c
+--R               + 
+--R                               3 4              4 3  4
+--R                 (- 10859520A a b  - 20622080B a b )c
+--R               + 
+--R                          2 6           3 5  3              8          2 7  2
+--R                 (13440A a b  + 13440B a b )c  + (- 960A a b  - 8160B a b )c
+--R               + 
+--R                          10           9           11
+--R                 (- 180A b   + 500B a b )c + 105B b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                               5               6  5
+--R                 (- 37048320A a b - 10055680B a )c
+--R               + 
+--R                               4 3              5 2  4
+--R                 (- 28846080A a b  - 27816960B a b )c
+--R               + 
+--R                           3 5            4 4  3
+--R                 (270336A a b  + 545280B a b )c
+--R               + 
+--R                          2 7            3 6  2                9           2 8
+--R                 (28800A a b  - 148096B a b )c  + (- 10800A a b  - 20400B a b )c
+--R               + 
+--R                          10
+--R                 6300B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                              6 5                 5 2              6   4
+--R                 - 13762560A a c  + (- 41840640A a b  - 20008960B a b)c
+--R               + 
+--R                             4 4             5 3  3
+--R                 (- 107520A a b  + 1720320B a b )c
+--R               + 
+--R                           3 6            4 5  2
+--R                 (618240A a b  + 268800B a b )c
+--R               + 
+--R                             2 8            3 7             2 9
+--R                 (- 100800A a b  - 394240B a b )c + 58800B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                               6              7  4
+--R                 (- 29982720A a b - 6062080B a )c
+--R               + 
+--R                              5 3            6 2  3
+--R                 (- 3932160A a b  + 122880B a b )c
+--R               + 
+--R                            4 5             5 4  2
+--R                 (2426880A a b  + 3102720B a b )c
+--R               + 
+--R                             3 7             4 6              3 8
+--R                 (- 322560A a b  - 1523200B a b )c + 188160B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                             7 4                6 2             7   3
+--R                 - 7864320A a c  + (- 6635520A a b  - 2211840B a b)c
+--R               + 
+--R                            5 4             6 3  2
+--R                 (3317760A a b  + 4976640B a b )c
+--R               + 
+--R                             4 6             5 5              4 7
+--R                 (- 414720A a b  - 2073600B a b )c + 241920B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                              7             8  3
+--R                 (- 2949120A a b - 983040B a )c
+--R               + 
+--R                            6 3             7 2  2
+--R                 (1474560A a b  + 2211840B a b )c
+--R               + 
+--R                             5 5            6 4              5 6
+--R                 (- 184320A a b  - 921600B a b )c + 107520B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                       2   8              3 7           5 6  24
+--R             (245760B a b c  + 204800B a b c  + 15360B b c )x
+--R           + 
+--R                           2             3  8               3             2 2  7
+--R                 (294912A a b + 491520B a )c  + (245760A a b  + 2285568B a b )c
+--R               + 
+--R                          5              4  6           6 5
+--R                 (18432A b  + 829440B a b )c  + 35328B b c
+--R            *
+--R                22
+--R               x
+--R           + 
+--R                          3 8              2 2             3   7
+--R                 589824A a c  + (2764800A a b  + 5738496B a b)c
+--R               + 
+--R                              4             2 3  6
+--R                 (1013760A a b  + 7142400B a b )c
+--R               + 
+--R                          6               5  5           7 4
+--R                 (43776A b  + 1140480B a b )c  + 20544B b c
+--R            *
+--R                20
+--R               x
+--R           + 
+--R                            3              4  7
+--R                 (7004160A a b + 3973120B a )c
+--R               + 
+--R                            2 3              3 2  6
+--R                 (8816640A a b  + 21135360B a b )c
+--R               + 
+--R                              5             2 4  5
+--R                 (1430016A a b  + 9231360B a b )c
+--R               + 
+--R                          7              6  4        8 3
+--R                 (26496A b  + 528384B a b )c  - 96B b c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                           4 7               3 2              4   6
+--R                 4915200A a c  + (26449920A a b  + 25528320B a b)c
+--R               + 
+--R                             2 4              3 3  5
+--R                 (11727360A a b  + 31180800B a b )c
+--R               + 
+--R                             6             2 5  4            8            7  3
+--R                 (684672A a b  + 4250880B a b )c  + (- 288A b  - 1152B a b )c
+--R               + 
+--R                       9 2
+--R                 168B b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                             4               5  6
+--R                 (32624640A a b + 10874880B a )c
+--R               + 
+--R                             3 3              4 2  5
+--R                 (40366080A a b  + 51194880B a b )c
+--R               + 
+--R                            2 5              3 4  4
+--R                 (5561856A a b  + 15982080B a b )c
+--R               + 
+--R                             7          2 6  3          9            8  2
+--R                 (- 2304A a b  + 8064B a b )c  + (720A b  + 1584B a b )c
+--R               + 
+--R                         10
+--R                 - 420B b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                            5 6               4 2              5   5
+--R                 14254080A a c  + (68582400A a b  + 40965120B a b)c
+--R               + 
+--R                             3 4              4 3  4
+--R                 (21611520A a b  + 32047360B a b )c
+--R               + 
+--R                             2 6            3 5  3
+--R                 (- 206208A a b  - 170880B a b )c
+--R               + 
+--R                            8            2 7  2           10             9
+--R                 (20160A a b  + 127008B a b )c  + (1980A b   - 11100B a b )c
+--R               + 
+--R                          11
+--R                 - 1155B b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                             5               6  5
+--R                 (56586240A a b + 12963840B a )c
+--R               + 
+--R                             4 3              5 2  4
+--R                 (47554560A a b  + 36910080B a b )c
+--R               + 
+--R                              3 5             4 4  3
+--R                 (- 1092096A a b  - 2127360B a b )c
+--R               + 
+--R                            2 7            3 6  2              9           2 8
+--R                 (- 92160A a b  + 606336B a b )c  + (39600A a b  + 66960B a b )c
+--R               + 
+--R                             10
+--R                 - 23100B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            6 5               5 2              6   4
+--R                 17694720A a c  + (58429440A a b  + 23900160B a b)c
+--R               + 
+--R                           4 4             5 3  3
+--R                 (138240A a b  - 3932160B a b )c
+--R               + 
+--R                              3 6            4 5  2
+--R                 (- 1347840A a b  - 529920B a b )c
+--R               + 
+--R                           2 8            3 7              2 9
+--R                 (221760A a b  + 860160B a b )c - 129360B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             6              7  4
+--R                 (35389440A a b + 6553600B a )c
+--R               + 
+--R                            5 3            6 2  3
+--R                 (6144000A a b  - 245760B a b )c
+--R               + 
+--R                              4 5             5 4  2
+--R                 (- 3809280A a b  - 4853760B a b )c
+--R               + 
+--R                           3 7             4 6              3 8
+--R                 (506880A a b  + 2391040B a b )c - 295680B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                           7 4              6 2             7   3
+--R                 7864320A a c  + (8110080A a b  + 2703360B a b)c
+--R               + 
+--R                              5 4             6 3  2
+--R                 (- 4055040A a b  - 6082560B a b )c
+--R               + 
+--R                           4 6             5 5              4 7
+--R                 (506880A a b  + 2534400B a b )c - 295680B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            7             8  3
+--R                 (2949120A a b + 983040B a )c
+--R               + 
+--R                              6 3             7 2  2
+--R                 (- 1474560A a b  - 2211840B a b )c
+--R               + 
+--R                           5 5            6 4              5 6
+--R                 (184320A a b  + 921600B a b )c - 107520B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                      2   6             3 5          5 4  10
+--R             (2949120a b c  + 2457600a b c  + 184320b c )x
+--R           + 
+--R                      3 6            2 2 5             4 4  8
+--R             (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R           + 
+--R                       3   5            2 3 4  6
+--R             (47185920a b c  + 27525120a b c )x
+--R           + 
+--R                     4 5            3 2 4  4            4   4 2            5 4
+--R           (31457280a c  + 70778880a b c )x  + 78643200a b c x  + 31457280a c
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                       3 7           2 2 6            4 5         6 4  12
+--R             (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R           + 
+--R                         3   6            2 3 5             5 4  10
+--R             (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R           + 
+--R                         4 6            3 2 5            2 4 4  8
+--R             (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R           + 
+--R                         4   5            3 3 4  6
+--R             (- 94371840a b c  - 55050240a b c )x
+--R           + 
+--R                         5 5             4 2 4  4            5   4 2
+--R             (- 47185920a c  - 106168320a b c )x  - 94371840a b c x
+--R           + 
+--R                        6 4
+--R             - 31457280a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2430
+
+--S 2431 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             4 2            5   5
+--R                   (552960A a b  + 184320B a b)c
+--R                 + 
+--R                             3 4            4 3  4
+--R                   (184320A a b  - 261120B a b )c
+--R                 + 
+--R                               2 6            3 5  3
+--R                   (- 161280A a b  - 161280B a b )c
+--R                 + 
+--R                              8           2 7  2           10            9
+--R                   (11520A a b  + 97920B a b )c  + (2160A b   - 6000B a b )c
+--R                 + 
+--R                            11
+--R                   - 1260B b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              5             6  5
+--R                   (1105920A a b + 368640B a )c
+--R                 + 
+--R                              4 3            5 2  4
+--R                   (3317760A a b  + 460800B a b )c
+--R                 + 
+--R                                3 5             4 4  3
+--R                   (- 1059840A a b  - 2288640B a b )c
+--R                 + 
+--R                               2 7            3 6  2
+--R                   (- 161280A a b  + 564480B a b )c
+--R                 + 
+--R                              9            2 8               10
+--R                   (50400A a b  + 110880B a b )c - 29400B a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              5 2             6   4
+--R                   (8847360A a b  + 2949120B a b)c
+--R                 + 
+--R                             4 4             5 3  3
+--R                   (737280A a b  - 4915200B a b )c
+--R                 + 
+--R                                3 6             4 5  2
+--R                   (- 2027520A a b  - 1105920B a b )c
+--R                 + 
+--R                             2 8             3 7              2 9
+--R                   (322560A a b  + 1290240B a b )c - 188160B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              6              7  4              5 3 3
+--R                   (5898240A a b + 1966080B a )c  + 10321920A a b c
+--R                 + 
+--R                                4 5             5 4  2
+--R                   (- 6266880A a b  - 8110080B a b )c
+--R                 + 
+--R                             3 7             4 6              3 8
+--R                   (829440A a b  + 3932160B a b )c - 483840B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               6 2             7   3
+--R                   (14745600A a b  + 4915200B a b)c
+--R                 + 
+--R                                5 4              6 3  2
+--R                   (- 7372800A a b  - 11059200B a b )c
+--R                 + 
+--R                             4 6             5 5              4 7
+--R                   (921600A a b  + 4608000B a b )c - 537600B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          7              8  3
+--R               (5898240A a b + 1966080B a )c
+--R             + 
+--R                            6 3             7 2  2
+--R               (- 2949120A a b  - 4423680B a b )c
+--R             + 
+--R                         5 5             6 4              5 6
+--R               (368640A a b  + 1843200B a b )c - 215040B a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                           5            6  6               4 3           5 2  5
+--R               (- 184320A a b - 61440B a )c  + (- 599040A a b  - 92160B a b )c
+--R             + 
+--R                         3 5            4 4  4            2 7           3 6  3
+--R               (161280A a b  + 403200B a b )c  + (40320A a b  - 80640B a b )c
+--R             + 
+--R                           9           2 8  2            11            10
+--R               (- 9360A a b  - 26640B a b )c  + (- 180A b   + 5400B a b  )c
+--R             + 
+--R                     12
+--R               105B b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                            5 2             6   5
+--R               (- 3317760A a b  - 1105920B a b)c
+--R             + 
+--R                            4 4             5 3  4
+--R               (- 1105920A a b  + 1566720B a b )c
+--R             + 
+--R                         3 6            4 5  3
+--R               (967680A a b  + 967680B a b )c
+--R             + 
+--R                          2 8            3 7  2
+--R               (- 69120A a b  - 587520B a b )c
+--R             + 
+--R                            10           2 9              11
+--R               (- 12960A a b   + 36000B a b )c + 7560B a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                            6              7  5
+--R               (- 3317760A a b - 1105920B a )c
+--R             + 
+--R                            5 3             6 2  4
+--R               (- 9953280A a b  - 1382400B a b )c
+--R             + 
+--R                          4 5             5 4  3
+--R               (3179520A a b  + 6865920B a b )c
+--R             + 
+--R                         3 7             4 6  2
+--R               (483840A a b  - 1693440B a b )c
+--R             + 
+--R                           2 9            3 8             2 10
+--R               (- 151200A a b  - 332640B a b )c + 88200B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                             6 2             7   4
+--R               (- 17694720A a b  - 5898240B a b)c
+--R             + 
+--R                            5 4             6 3  3
+--R               (- 1474560A a b  + 9830400B a b )c
+--R             + 
+--R                          4 6             5 5  2
+--R               (4055040A a b  + 2211840B a b )c
+--R             + 
+--R                           3 8             4 7              3 9
+--R               (- 645120A a b  - 2580480B a b )c + 376320B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                            7              8  4              6 3 3
+--R               (- 8847360A a b - 2949120B a )c  - 15482880A a b c
+--R             + 
+--R                          5 5              6 4  2
+--R               (9400320A a b  + 12165120B a b )c
+--R             + 
+--R                            4 7             5 6              4 8
+--R               (- 1244160A a b  - 5898240B a b )c + 725760B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                             7 2             8   3
+--R               (- 17694720A a b  - 5898240B a b)c
+--R             + 
+--R                          6 4              7 3  2
+--R               (8847360A a b  + 13271040B a b )c
+--R             + 
+--R                            5 6             6 5              5 7
+--R               (- 1105920A a b  - 5529600B a b )c + 645120B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        8              9  3              7 3             8 2  2
+--R           (- 5898240A a b - 1966080B a )c  + (2949120A a b  + 4423680B a b )c
+--R         + 
+--R                       6 5             7 4              6 6
+--R           (- 368640A a b  - 1843200B a b )c + 215040B a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                             4 2            5   5
+--R                   (552960A a b  + 184320B a b)c
+--R                 + 
+--R                             3 4            4 3  4
+--R                   (184320A a b  - 261120B a b )c
+--R                 + 
+--R                               2 6            3 5  3
+--R                   (- 161280A a b  - 161280B a b )c
+--R                 + 
+--R                              8           2 7  2           10            9
+--R                   (11520A a b  + 97920B a b )c  + (2160A b   - 6000B a b )c
+--R                 + 
+--R                            11
+--R                   - 1260B b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              5             6  5
+--R                   (1105920A a b + 368640B a )c
+--R                 + 
+--R                              4 3            5 2  4
+--R                   (3317760A a b  + 460800B a b )c
+--R                 + 
+--R                                3 5             4 4  3
+--R                   (- 1059840A a b  - 2288640B a b )c
+--R                 + 
+--R                               2 7            3 6  2
+--R                   (- 161280A a b  + 564480B a b )c
+--R                 + 
+--R                              9            2 8               10
+--R                   (50400A a b  + 110880B a b )c - 29400B a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              5 2             6   4
+--R                   (8847360A a b  + 2949120B a b)c
+--R                 + 
+--R                             4 4             5 3  3
+--R                   (737280A a b  - 4915200B a b )c
+--R                 + 
+--R                                3 6             4 5  2
+--R                   (- 2027520A a b  - 1105920B a b )c
+--R                 + 
+--R                             2 8             3 7              2 9
+--R                   (322560A a b  + 1290240B a b )c - 188160B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              6              7  4              5 3 3
+--R                   (5898240A a b + 1966080B a )c  + 10321920A a b c
+--R                 + 
+--R                                4 5             5 4  2
+--R                   (- 6266880A a b  - 8110080B a b )c
+--R                 + 
+--R                             3 7             4 6              3 8
+--R                   (829440A a b  + 3932160B a b )c - 483840B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               6 2             7   3
+--R                   (14745600A a b  + 4915200B a b)c
+--R                 + 
+--R                                5 4              6 3  2
+--R                   (- 7372800A a b  - 11059200B a b )c
+--R                 + 
+--R                             4 6             5 5              4 7
+--R                   (921600A a b  + 4608000B a b )c - 537600B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          7              8  3
+--R               (5898240A a b + 1966080B a )c
+--R             + 
+--R                            6 3             7 2  2
+--R               (- 2949120A a b  - 4423680B a b )c
+--R             + 
+--R                         5 5             6 4              5 6
+--R               (368640A a b  + 1843200B a b )c - 215040B a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                           5            6  6               4 3           5 2  5
+--R               (- 184320A a b - 61440B a )c  + (- 599040A a b  - 92160B a b )c
+--R             + 
+--R                         3 5            4 4  4            2 7           3 6  3
+--R               (161280A a b  + 403200B a b )c  + (40320A a b  - 80640B a b )c
+--R             + 
+--R                           9           2 8  2            11            10
+--R               (- 9360A a b  - 26640B a b )c  + (- 180A b   + 5400B a b  )c
+--R             + 
+--R                     12
+--R               105B b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                            5 2             6   5
+--R               (- 3317760A a b  - 1105920B a b)c
+--R             + 
+--R                            4 4             5 3  4
+--R               (- 1105920A a b  + 1566720B a b )c
+--R             + 
+--R                         3 6            4 5  3
+--R               (967680A a b  + 967680B a b )c
+--R             + 
+--R                          2 8            3 7  2
+--R               (- 69120A a b  - 587520B a b )c
+--R             + 
+--R                            10           2 9              11
+--R               (- 12960A a b   + 36000B a b )c + 7560B a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                            6              7  5
+--R               (- 3317760A a b - 1105920B a )c
+--R             + 
+--R                            5 3             6 2  4
+--R               (- 9953280A a b  - 1382400B a b )c
+--R             + 
+--R                          4 5             5 4  3
+--R               (3179520A a b  + 6865920B a b )c
+--R             + 
+--R                         3 7             4 6  2
+--R               (483840A a b  - 1693440B a b )c
+--R             + 
+--R                           2 9            3 8             2 10
+--R               (- 151200A a b  - 332640B a b )c + 88200B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                             6 2             7   4
+--R               (- 17694720A a b  - 5898240B a b)c
+--R             + 
+--R                            5 4             6 3  3
+--R               (- 1474560A a b  + 9830400B a b )c
+--R             + 
+--R                          4 6             5 5  2
+--R               (4055040A a b  + 2211840B a b )c
+--R             + 
+--R                           3 8             4 7              3 9
+--R               (- 645120A a b  - 2580480B a b )c + 376320B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                            7              8  4              6 3 3
+--R               (- 8847360A a b - 2949120B a )c  - 15482880A a b c
+--R             + 
+--R                          5 5              6 4  2
+--R               (9400320A a b  + 12165120B a b )c
+--R             + 
+--R                            4 7             5 6              4 8
+--R               (- 1244160A a b  - 5898240B a b )c + 725760B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                             7 2             8   3
+--R               (- 17694720A a b  - 5898240B a b)c
+--R             + 
+--R                          6 4              7 3  2
+--R               (8847360A a b  + 13271040B a b )c
+--R             + 
+--R                            5 6             6 5              5 7
+--R               (- 1105920A a b  - 5529600B a b )c + 645120B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        8              9  3              7 3             8 2  2
+--R           (- 5898240A a b - 1966080B a )c  + (2949120A a b  + 4423680B a b )c
+--R         + 
+--R                       6 5             7 4              6 6
+--R           (- 368640A a b  - 1843200B a b )c + 215040B a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                        5   5            4 3            5 2  4
+--R               589824A a b c  + (30720A a b  - 497664B a b )c
+--R             + 
+--R                           3 5            4 4  3
+--R               (- 278016A a b  - 122880B a b )c
+--R             + 
+--R                        2 7            3 6  2             9           2 8
+--R               (28800A a b  + 171776B a b )c  + (4320A a b  - 15360B a b )c
+--R             + 
+--R                          10
+--R               - 2520B a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         6 5              5 2            6   4
+--R               1179648A a c  + (3207168A a b  - 995328B a b)c
+--R             + 
+--R                            4 4             5 3  3
+--R               (- 2227200A a b  - 2899968B a b )c
+--R             + 
+--R                           3 6             4 5  2
+--R               (- 188160A a b  + 1236480B a b )c
+--R             + 
+--R                         2 8            3 7             2 9
+--R               (100800A a b  + 143360B a b )c - 58800B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         6   4                5 3             6 2  3
+--R               9437184A a b c  + (- 1867776A a b  - 7962624B a b )c
+--R             + 
+--R                            4 5           5 4  2
+--R               (- 3194880A a b  + 24576B a b )c
+--R             + 
+--R                         3 7             4 6              3 8
+--R               (645120A a b  + 2078720B a b )c - 376320B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         7 4              6 2             7   3
+--R               6291456A a c  + (9240576A a b  - 5308416B a b)c
+--R             + 
+--R                             5 4             6 3  2
+--R               (- 10321920A a b  - 8830976B a b )c
+--R             + 
+--R                          4 6             5 5              4 7
+--R               (1658880A a b  + 6574080B a b )c - 967680B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          7   3                 6 3              7 2  2
+--R               15728640A a b c  + (- 12288000A a b  - 13271040B a b )c
+--R             + 
+--R                          5 5             6 4               5 6
+--R               (1843200A a b  + 7782400B a b )c - 1075200B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     8 3                7 2             8   2
+--R           6291456A a c  + (- 4915200A a b  - 5308416B a b)c
+--R         + 
+--R                     6 4             7 3              6 5
+--R           (737280A a b  + 3112960B a b )c - 430080B a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                          5 6               4 2            5   5
+--R               - 196608A a c  + (- 583680A a b  + 165888B a b)c
+--R             + 
+--R                         3 4            4 3  4            2 6            3 5  3
+--R               (368640A a b  + 524800B a b )c  + (54528A a b  - 195840B a b )c
+--R             + 
+--R                            8           2 7  2            10             9
+--R               (- 19200A a b  - 38208B a b )c  + (- 360A b   + 11080B a b )c
+--R             + 
+--R                     11
+--R               210B b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           5   5               4 3             5 2  4
+--R               - 3538944A a b c  + (- 184320A a b  + 2985984B a b )c
+--R             + 
+--R                          3 5            4 4  3
+--R               (1668096A a b  + 737280B a b )c
+--R             + 
+--R                           2 7             3 6  2
+--R               (- 172800A a b  - 1030656B a b )c
+--R             + 
+--R                            9           2 8               10
+--R               (- 25920A a b  + 92160B a b )c + 15120B a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                           6 5                5 2             6   4
+--R               - 3538944A a c  + (- 9621504A a b  + 2985984B a b)c
+--R             + 
+--R                          4 4             5 3  3
+--R               (6681600A a b  + 8699904B a b )c
+--R             + 
+--R                         3 6             4 5  2
+--R               (564480A a b  - 3709440B a b )c
+--R             + 
+--R                           2 8            3 7              2 9
+--R               (- 302400A a b  - 430080B a b )c + 176400B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                            6   4              5 3              6 2  3
+--R               - 18874368A a b c  + (3735552A a b  + 15925248B a b )c
+--R             + 
+--R                          4 5           5 4  2
+--R               (6389760A a b  - 49152B a b )c
+--R             + 
+--R                            3 7             4 6              3 8
+--R               (- 1290240A a b  - 4157440B a b )c + 752640B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           7 4                 6 2             7   3
+--R               - 9437184A a c  + (- 13860864A a b  + 7962624B a b)c
+--R             + 
+--R                           5 4              6 3  2
+--R               (15482880A a b  + 13246464B a b )c
+--R             + 
+--R                            4 6             5 5               4 7
+--R               (- 2488320A a b  - 9861120B a b )c + 1451520B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                            7   3               6 3              7 2  2
+--R               - 18874368A a b c  + (14745600A a b  + 15925248B a b )c
+--R             + 
+--R                            5 5             6 4               5 6
+--R               (- 2211840A a b  - 9338880B a b )c + 1290240B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       8 3              7 2             8   2
+--R           - 6291456A a c  + (4915200A a b  + 5308416B a b)c
+--R         + 
+--R                       6 4             7 3              6 5
+--R           (- 737280A a b  - 3112960B a b )c + 430080B a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                    2   6             3 5          5 4  10
+--R           (5898240a b c  + 4915200a b c  + 368640b c )x
+--R         + 
+--R                     3 6            2 2 5             4 4  8
+--R           (11796480a c  + 41287680a b c  + 8601600a b c )x
+--R         + 
+--R                     3   5            2 3 4  6
+--R           (94371840a b c  + 55050240a b c )x
+--R         + 
+--R                   4 5             3 2 4  4             4   4 2            5 4
+--R         (62914560a c  + 141557760a b c )x  + 157286400a b c x  + 62914560a c
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                      3 7           2 2 6             4 5         6 4  12
+--R           (- 1966080a c  - 7372800a b c  - 1843200a b c  - 30720b c )x
+--R         + 
+--R                       3   6            2 3 5             5 4  10
+--R           (- 35389440a b c  - 29491200a b c  - 2211840a b c )x
+--R         + 
+--R                       4 6             3 2 5            2 4 4  8
+--R           (- 35389440a c  - 123863040a b c  - 25804800a b c )x
+--R         + 
+--R                        4   5             3 3 4  6
+--R           (- 188743680a b c  - 110100480a b c )x
+--R         + 
+--R                     5 5             4 2 4  4             5   4 2            6 4
+--R         (- 94371840a c  - 212336640a b c )x  - 188743680a b c x  - 62914560a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 2431
+
+--S 2432 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2432
+
+--S 2433 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             4 2            5   5
+--R                   (552960A a b  + 184320B a b)c
+--R                 + 
+--R                             3 4            4 3  4
+--R                   (184320A a b  - 261120B a b )c
+--R                 + 
+--R                               2 6            3 5  3
+--R                   (- 161280A a b  - 161280B a b )c
+--R                 + 
+--R                              8           2 7  2           10            9
+--R                   (11520A a b  + 97920B a b )c  + (2160A b   - 6000B a b )c
+--R                 + 
+--R                            11
+--R                   - 1260B b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              5             6  5
+--R                   (1105920A a b + 368640B a )c
+--R                 + 
+--R                              4 3            5 2  4
+--R                   (3317760A a b  + 460800B a b )c
+--R                 + 
+--R                                3 5             4 4  3
+--R                   (- 1059840A a b  - 2288640B a b )c
+--R                 + 
+--R                               2 7            3 6  2
+--R                   (- 161280A a b  + 564480B a b )c
+--R                 + 
+--R                              9            2 8               10
+--R                   (50400A a b  + 110880B a b )c - 29400B a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              5 2             6   4
+--R                   (8847360A a b  + 2949120B a b)c
+--R                 + 
+--R                             4 4             5 3  3
+--R                   (737280A a b  - 4915200B a b )c
+--R                 + 
+--R                                3 6             4 5  2
+--R                   (- 2027520A a b  - 1105920B a b )c
+--R                 + 
+--R                             2 8             3 7              2 9
+--R                   (322560A a b  + 1290240B a b )c - 188160B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              6              7  4              5 3 3
+--R                   (5898240A a b + 1966080B a )c  + 10321920A a b c
+--R                 + 
+--R                                4 5             5 4  2
+--R                   (- 6266880A a b  - 8110080B a b )c
+--R                 + 
+--R                             3 7             4 6              3 8
+--R                   (829440A a b  + 3932160B a b )c - 483840B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               6 2             7   3
+--R                   (14745600A a b  + 4915200B a b)c
+--R                 + 
+--R                                5 4              6 3  2
+--R                   (- 7372800A a b  - 11059200B a b )c
+--R                 + 
+--R                             4 6             5 5              4 7
+--R                   (921600A a b  + 4608000B a b )c - 537600B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          7              8  3
+--R               (5898240A a b + 1966080B a )c
+--R             + 
+--R                            6 3             7 2  2
+--R               (- 2949120A a b  - 4423680B a b )c
+--R             + 
+--R                         5 5             6 4              5 6
+--R               (368640A a b  + 1843200B a b )c - 215040B a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                               5            6  6
+--R                   (- 184320A a b - 61440B a )c
+--R                 + 
+--R                               4 3           5 2  5
+--R                   (- 599040A a b  - 92160B a b )c
+--R                 + 
+--R                             3 5            4 4  4
+--R                   (161280A a b  + 403200B a b )c
+--R                 + 
+--R                            2 7           3 6  3
+--R                   (40320A a b  - 80640B a b )c
+--R                 + 
+--R                               9           2 8  2            11            10
+--R                   (- 9360A a b  - 26640B a b )c  + (- 180A b   + 5400B a b  )c
+--R                 + 
+--R                         12
+--R                   105B b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                5 2             6   5
+--R                   (- 3317760A a b  - 1105920B a b)c
+--R                 + 
+--R                                4 4             5 3  4
+--R                   (- 1105920A a b  + 1566720B a b )c
+--R                 + 
+--R                             3 6            4 5  3
+--R                   (967680A a b  + 967680B a b )c
+--R                 + 
+--R                              2 8            3 7  2
+--R                   (- 69120A a b  - 587520B a b )c
+--R                 + 
+--R                                10           2 9              11
+--R                   (- 12960A a b   + 36000B a b )c + 7560B a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                                6              7  5
+--R                   (- 3317760A a b - 1105920B a )c
+--R                 + 
+--R                                5 3             6 2  4
+--R                   (- 9953280A a b  - 1382400B a b )c
+--R                 + 
+--R                              4 5             5 4  3
+--R                   (3179520A a b  + 6865920B a b )c
+--R                 + 
+--R                             3 7             4 6  2
+--R                   (483840A a b  - 1693440B a b )c
+--R                 + 
+--R                               2 9            3 8             2 10
+--R                   (- 151200A a b  - 332640B a b )c + 88200B a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                 6 2             7   4
+--R                   (- 17694720A a b  - 5898240B a b)c
+--R                 + 
+--R                                5 4             6 3  3
+--R                   (- 1474560A a b  + 9830400B a b )c
+--R                 + 
+--R                              4 6             5 5  2
+--R                   (4055040A a b  + 2211840B a b )c
+--R                 + 
+--R                               3 8             4 7              3 9
+--R                   (- 645120A a b  - 2580480B a b )c + 376320B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                                7              8  4              6 3 3
+--R                   (- 8847360A a b - 2949120B a )c  - 15482880A a b c
+--R                 + 
+--R                              5 5              6 4  2
+--R                   (9400320A a b  + 12165120B a b )c
+--R                 + 
+--R                                4 7             5 6              4 8
+--R                   (- 1244160A a b  - 5898240B a b )c + 725760B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                 7 2             8   3
+--R                   (- 17694720A a b  - 5898240B a b)c
+--R                 + 
+--R                              6 4              7 3  2
+--R                   (8847360A a b  + 13271040B a b )c
+--R                 + 
+--R                                5 6             6 5              5 7
+--R                   (- 1105920A a b  - 5529600B a b )c + 645120B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                            8              9  3
+--R               (- 5898240A a b - 1966080B a )c
+--R             + 
+--R                          7 3             8 2  2
+--R               (2949120A a b  + 4423680B a b )c
+--R             + 
+--R                           6 5             7 4              6 6
+--R               (- 368640A a b  - 1843200B a b )c + 215040B a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                                4 2            5   5
+--R                   (- 1105920A a b  - 368640B a b)c
+--R                 + 
+--R                               3 4            4 3  4
+--R                   (- 368640A a b  + 522240B a b )c
+--R                 + 
+--R                             2 6            3 5  3
+--R                   (322560A a b  + 322560B a b )c
+--R                 + 
+--R                                8            2 7  2
+--R                   (- 23040A a b  - 195840B a b )c
+--R                 + 
+--R                             10             9            11
+--R                   (- 4320A b   + 12000B a b )c + 2520B b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                                5             6  5
+--R                   (- 2211840A a b - 737280B a )c
+--R                 + 
+--R                                4 3            5 2  4
+--R                   (- 6635520A a b  - 921600B a b )c
+--R                 + 
+--R                              3 5             4 4  3
+--R                   (2119680A a b  + 4577280B a b )c
+--R                 + 
+--R                             2 7             3 6  2
+--R                   (322560A a b  - 1128960B a b )c
+--R                 + 
+--R                                 9            2 8               10
+--R                   (- 100800A a b  - 221760B a b )c + 58800B a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                 5 2             6   4
+--R                   (- 17694720A a b  - 5898240B a b)c
+--R                 + 
+--R                                4 4             5 3  3
+--R                   (- 1474560A a b  + 9830400B a b )c
+--R                 + 
+--R                              3 6             4 5  2
+--R                   (4055040A a b  + 2211840B a b )c
+--R                 + 
+--R                               2 8             3 7              2 9
+--R                   (- 645120A a b  - 2580480B a b )c + 376320B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                                 6              7  4              5 3 3
+--R                   (- 11796480A a b - 3932160B a )c  - 20643840A a b c
+--R                 + 
+--R                               4 5              5 4  2
+--R                   (12533760A a b  + 16220160B a b )c
+--R                 + 
+--R                                3 7             4 6              3 8
+--R                   (- 1658880A a b  - 7864320B a b )c + 967680B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                                 6 2             7   3
+--R                   (- 29491200A a b  - 9830400B a b)c
+--R                 + 
+--R                               5 4              6 3  2
+--R                   (14745600A a b  + 22118400B a b )c
+--R                 + 
+--R                                4 6             5 5               4 7
+--R                   (- 1843200A a b  - 9216000B a b )c + 1075200B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                             7              8  3
+--R               (- 11796480A a b - 3932160B a )c
+--R             + 
+--R                          6 3             7 2  2
+--R               (5898240A a b  + 8847360B a b )c
+--R             + 
+--R                           5 5             6 4              5 6
+--R               (- 737280A a b  - 3686400B a b )c + 430080B a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                             5             6  6
+--R                   (368640A a b + 122880B a )c
+--R                 + 
+--R                              4 3            5 2  5
+--R                   (1198080A a b  + 184320B a b )c
+--R                 + 
+--R                               3 5            4 4  4
+--R                   (- 322560A a b  - 806400B a b )c
+--R                 + 
+--R                              2 7            3 6  3
+--R                   (- 80640A a b  + 161280B a b )c
+--R                 + 
+--R                              9           2 8  2          11             10
+--R                   (18720A a b  + 53280B a b )c  + (360A b   - 10800B a b  )c
+--R                 + 
+--R                           12
+--R                   - 210B b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                              5 2             6   5
+--R                   (6635520A a b  + 2211840B a b)c
+--R                 + 
+--R                              4 4             5 3  4
+--R                   (2211840A a b  - 3133440B a b )c
+--R                 + 
+--R                                3 6             4 5  3
+--R                   (- 1935360A a b  - 1935360B a b )c
+--R                 + 
+--R                             2 8             3 7  2
+--R                   (138240A a b  + 1175040B a b )c
+--R                 + 
+--R                              10           2 9               11
+--R                   (25920A a b   - 72000B a b )c - 15120B a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              6              7  5
+--R                   (6635520A a b + 2211840B a )c
+--R                 + 
+--R                               5 3             6 2  4
+--R                   (19906560A a b  + 2764800B a b )c
+--R                 + 
+--R                                4 5              5 4  3
+--R                   (- 6359040A a b  - 13731840B a b )c
+--R                 + 
+--R                               3 7             4 6  2
+--R                   (- 967680A a b  + 3386880B a b )c
+--R                 + 
+--R                             2 9            3 8              2 10
+--R                   (302400A a b  + 665280B a b )c - 176400B a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               6 2              7   4
+--R                   (35389440A a b  + 11796480B a b)c
+--R                 + 
+--R                              5 4              6 3  3
+--R                   (2949120A a b  - 19660800B a b )c
+--R                 + 
+--R                                4 6             5 5  2
+--R                   (- 8110080A a b  - 4423680B a b )c
+--R                 + 
+--R                              3 8             4 7              3 9
+--R                   (1290240A a b  + 5160960B a b )c - 752640B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                               7              8  4              6 3 3
+--R                   (17694720A a b + 5898240B a )c  + 30965760A a b c
+--R                 + 
+--R                                 5 5              6 4  2
+--R                   (- 18800640A a b  - 24330240B a b )c
+--R                 + 
+--R                              4 7              5 6               4 8
+--R                   (2488320A a b  + 11796480B a b )c - 1451520B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               7 2              8   3
+--R                   (35389440A a b  + 11796480B a b)c
+--R                 + 
+--R                                 6 4              7 3  2
+--R                   (- 17694720A a b  - 26542080B a b )c
+--R                 + 
+--R                              5 6              6 5               5 7
+--R                   (2211840A a b  + 11059200B a b )c - 1290240B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           8              9  3
+--R               (11796480A a b + 3932160B a )c
+--R             + 
+--R                            7 3             8 2  2
+--R               (- 5898240A a b  - 8847360B a b )c
+--R             + 
+--R                         6 5             7 4              6 6
+--R               (737280A a b  + 3686400B a b )c - 430080B a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                        5   5            4 3            5 2  4
+--R               589824A a b c  + (30720A a b  - 497664B a b )c
+--R             + 
+--R                           3 5            4 4  3
+--R               (- 278016A a b  - 122880B a b )c
+--R             + 
+--R                        2 7            3 6  2             9           2 8
+--R               (28800A a b  + 171776B a b )c  + (4320A a b  - 15360B a b )c
+--R             + 
+--R                          10
+--R               - 2520B a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         6 5              5 2            6   4
+--R               1179648A a c  + (3207168A a b  - 995328B a b)c
+--R             + 
+--R                            4 4             5 3  3
+--R               (- 2227200A a b  - 2899968B a b )c
+--R             + 
+--R                           3 6             4 5  2
+--R               (- 188160A a b  + 1236480B a b )c
+--R             + 
+--R                         2 8            3 7             2 9
+--R               (100800A a b  + 143360B a b )c - 58800B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         6   4                5 3             6 2  3
+--R               9437184A a b c  + (- 1867776A a b  - 7962624B a b )c
+--R             + 
+--R                            4 5           5 4  2
+--R               (- 3194880A a b  + 24576B a b )c
+--R             + 
+--R                         3 7             4 6              3 8
+--R               (645120A a b  + 2078720B a b )c - 376320B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         7 4              6 2             7   3
+--R               6291456A a c  + (9240576A a b  - 5308416B a b)c
+--R             + 
+--R                             5 4             6 3  2
+--R               (- 10321920A a b  - 8830976B a b )c
+--R             + 
+--R                          4 6             5 5              4 7
+--R               (1658880A a b  + 6574080B a b )c - 967680B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          7   3                 6 3              7 2  2
+--R               15728640A a b c  + (- 12288000A a b  - 13271040B a b )c
+--R             + 
+--R                          5 5             6 4               5 6
+--R               (1843200A a b  + 7782400B a b )c - 1075200B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     8 3                7 2             8   2
+--R           6291456A a c  + (- 4915200A a b  - 5308416B a b)c
+--R         + 
+--R                     6 4             7 3              6 5
+--R           (737280A a b  + 3112960B a b )c - 430080B a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                          5 6               4 2            5   5
+--R               - 196608A a c  + (- 583680A a b  + 165888B a b)c
+--R             + 
+--R                         3 4            4 3  4            2 6            3 5  3
+--R               (368640A a b  + 524800B a b )c  + (54528A a b  - 195840B a b )c
+--R             + 
+--R                            8           2 7  2            10             9
+--R               (- 19200A a b  - 38208B a b )c  + (- 360A b   + 11080B a b )c
+--R             + 
+--R                     11
+--R               210B b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           5   5               4 3             5 2  4
+--R               - 3538944A a b c  + (- 184320A a b  + 2985984B a b )c
+--R             + 
+--R                          3 5            4 4  3
+--R               (1668096A a b  + 737280B a b )c
+--R             + 
+--R                           2 7             3 6  2
+--R               (- 172800A a b  - 1030656B a b )c
+--R             + 
+--R                            9           2 8               10
+--R               (- 25920A a b  + 92160B a b )c + 15120B a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                           6 5                5 2             6   4
+--R               - 3538944A a c  + (- 9621504A a b  + 2985984B a b)c
+--R             + 
+--R                          4 4             5 3  3
+--R               (6681600A a b  + 8699904B a b )c
+--R             + 
+--R                         3 6             4 5  2
+--R               (564480A a b  - 3709440B a b )c
+--R             + 
+--R                           2 8            3 7              2 9
+--R               (- 302400A a b  - 430080B a b )c + 176400B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                            6   4              5 3              6 2  3
+--R               - 18874368A a b c  + (3735552A a b  + 15925248B a b )c
+--R             + 
+--R                          4 5           5 4  2
+--R               (6389760A a b  - 49152B a b )c
+--R             + 
+--R                            3 7             4 6              3 8
+--R               (- 1290240A a b  - 4157440B a b )c + 752640B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           7 4                 6 2             7   3
+--R               - 9437184A a c  + (- 13860864A a b  + 7962624B a b)c
+--R             + 
+--R                           5 4              6 3  2
+--R               (15482880A a b  + 13246464B a b )c
+--R             + 
+--R                            4 6             5 5               4 7
+--R               (- 2488320A a b  - 9861120B a b )c + 1451520B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                            7   3               6 3              7 2  2
+--R               - 18874368A a b c  + (14745600A a b  + 15925248B a b )c
+--R             + 
+--R                            5 5             6 4               5 6
+--R               (- 2211840A a b  - 9338880B a b )c + 1290240B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       8 3              7 2             8   2
+--R           - 6291456A a c  + (4915200A a b  + 5308416B a b)c
+--R         + 
+--R                       6 4             7 3              6 5
+--R           (- 737280A a b  - 3112960B a b )c + 430080B a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                    2   6             3 5          5 4  10
+--R           (5898240a b c  + 4915200a b c  + 368640b c )x
+--R         + 
+--R                     3 6            2 2 5             4 4  8
+--R           (11796480a c  + 41287680a b c  + 8601600a b c )x
+--R         + 
+--R                     3   5            2 3 4  6
+--R           (94371840a b c  + 55050240a b c )x
+--R         + 
+--R                   4 5             3 2 4  4             4   4 2            5 4
+--R         (62914560a c  + 141557760a b c )x  + 157286400a b c x  + 62914560a c
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                      3 7           2 2 6             4 5         6 4  12
+--R           (- 1966080a c  - 7372800a b c  - 1843200a b c  - 30720b c )x
+--R         + 
+--R                       3   6            2 3 5             5 4  10
+--R           (- 35389440a b c  - 29491200a b c  - 2211840a b c )x
+--R         + 
+--R                       4 6             3 2 5            2 4 4  8
+--R           (- 35389440a c  - 123863040a b c  - 25804800a b c )x
+--R         + 
+--R                        4   5             3 3 4  6
+--R           (- 188743680a b c  - 110100480a b c )x
+--R         + 
+--R                     5 5             4 2 4  4             5   4 2            6 4
+--R         (- 94371840a c  - 212336640a b c )x  - 188743680a b c x  - 62914560a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 2433
+
+--S 2434 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2434
+
+)clear all
+
+--S 2435 of 3139
+t0:=x*(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                                         +---------------+
+--R              7               5               3          |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + (A b + B a)x  + A a x)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2435
+
+--S 2436 of 3139
+r0:=-1/32*(b*B-2*A*c)*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^2+_
+   1/10*B*(a+b*x^2+c*x^4)^(5/2)/c-3/512*(b^2-4*a*c)^2*(b*B-2*A*c)*_
+   atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(7/2)+_
+   3/256*(b^2-4*a*c)*(b*B-2*A*c)*(b+2*c*x^2)*sqrt(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R                   2 3              2         2   2         4           3
+--R             480A a c  + (- 240A a b  - 240B a b)c  + (30A b  + 120B a b )c
+--R           + 
+--R                    5
+--R             - 15B b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                 4 8          4           3  6
+--R           256B c x  + (320A c  + 352B b c )x
+--R         + 
+--R                              3        2 2  4
+--R           ((480A b + 512B a)c  + 16B b c )x
+--R         + 
+--R                    3         2             2        3   2
+--R           (800A a c  + (40A b  + 112B a b)c  - 20B b c)x
+--R         + 
+--R                             2  2           3           2          4
+--R           (400A a b + 256B a )c  + (- 60A b  - 200B a b )c + 30B b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R          3 +-+
+--R     2560c \|c
+--R                                                    Type: Expression(Integer)
+--E 2436
+
+--S 2437 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               4 5              3 2          4   4
+--R                     - 15360A a c  + (- 30720A a b  + 7680B a b)c
+--R                   + 
+--R                              2 4           3 3  3          2 5 2         8
+--R                     (13440A a b  + 15360B a b )c  - 6720B a b c  - 300A b c
+--R                   + 
+--R                           9
+--R                     150B b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                                4   4            3 3           4 2  3
+--R                     - 184320A a b c  + (15360A a b  + 92160B a b )c
+--R                   + 
+--R                              2 5          3 4  2
+--R                     (26880A a b  - 7680B a b )c
+--R                   + 
+--R                                 7           2 6              8
+--R                     (- 4800A a b  - 13440B a b )c + 2400B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                                5 4               4 2           5   3
+--R                     - 184320A a c  + (- 230400A a b  + 92160B a b)c
+--R                   + 
+--R                               3 4            4 3  2
+--R                     (149760A a b  + 115200B a b )c
+--R                   + 
+--R                                2 6           3 5             2 7
+--R                     (- 20160A a b  - 74880B a b )c + 10080B a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                                5   3             4 3            5 2  2
+--R                     - 491520A a b c  + (245760A a b  + 245760B a b )c
+--R                   + 
+--R                                3 5            4 4             3 6
+--R                     (- 30720A a b  - 122880B a b )c + 15360B a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                            6 3             5 2            6   2
+--R                 - 245760A a c  + (122880A a b  + 122880B a b)c
+--R               + 
+--R                            4 4           5 3            4 5
+--R                 (- 15360A a b  - 61440B a b )c + 7680B a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                         4   5           4 2 4          2 5 3
+--R                 38400A a b c  - 19200B a b c  - 6720A a b c
+--R               + 
+--R                          7          2 6  2         9           8          10
+--R                 (960A a b  + 3360B a b )c  + (30A b  - 480B a b )c - 15B b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                         5 5             4 2           5   4
+--R                 76800A a c  + (153600A a b  - 38400B a b)c
+--R               + 
+--R                            3 4           4 3  3           3 5 2            8
+--R                 (- 67200A a b  - 76800B a b )c  + 33600B a b c  + 1500A a b c
+--R               + 
+--R                           9
+--R                 - 750B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          5   4              4 3            5 2  3
+--R                 460800A a b c  + (- 38400A a b  - 230400B a b )c
+--R               + 
+--R                            3 5           4 4  2            2 7           3 6
+--R                 (- 67200A a b  + 19200B a b )c  + (12000A a b  + 33600B a b )c
+--R               + 
+--R                          2 8
+--R                 - 6000B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          6 4             5 2            6   3
+--R                 307200A a c  + (384000A a b  - 153600B a b)c
+--R               + 
+--R                             4 4            5 3  2
+--R                 (- 249600A a b  - 192000B a b )c
+--R               + 
+--R                          3 6            4 5             3 7
+--R                 (33600A a b  + 124800B a b )c - 16800B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          6   3               5 3            6 2  2
+--R                 614400A a b c  + (- 307200A a b  - 307200B a b )c
+--R               + 
+--R                          4 5            5 4             4 6
+--R                 (38400A a b  + 153600B a b )c - 19200B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      7 3               6 2            7   2
+--R             245760A a c  + (- 122880A a b  - 122880B a b)c
+--R           + 
+--R                      5 4           6 3            5 5
+--R             (15360A a b  + 61440B a b )c - 7680B a b
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                        2   6             3 5         5 4  18
+--R             (- 20480B a b c  - 10240B a b c  - 256B b c )x
+--R           + 
+--R                            2            3  6                3            2 2  5
+--R                 (- 25600A a b - 40960B a )c  + (- 12800A a b  - 130560B a b )c
+--R               + 
+--R                          5             4  4         6 3
+--R                 (- 320A b  - 26880B a b )c  - 352B b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                           3 6               2 2            3   5
+--R                 - 51200A a c  + (- 166400A a b  - 343040B a b)c
+--R               + 
+--R                              4            2 3  4            6             5  3
+--R                 (- 35200A a b  - 264960B a b )c  + (- 480A b  - 18752B a b )c
+--R               + 
+--R                        7 2
+--R                 - 16B b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                             3             4  5
+--R                 (- 448000A a b - 245760B a )c
+--R               + 
+--R                             2 3            3 2  4
+--R                 (- 355200A a b  - 840960B a b )c
+--R               + 
+--R                              5            2 4  3           7           6  2
+--R                 (- 26400A a b  - 175680B a b )c  + (- 40A b  - 112B a b )c
+--R               + 
+--R                      8
+--R                 20B b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            4 5                3 2             4   4
+--R                 - 332800A a c  + (- 1177600A a b  - 1082880B a b)c
+--R               + 
+--R                             2 4            3 3  3          2 5 2        8
+--R                 (- 259200A a b  - 650240B a b )c  + 1344B a b c  + 60A b c
+--R               + 
+--R                        9
+--R                 - 30B b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                              4             5  4
+--R                 (- 1536000A a b - 491520B a )c
+--R               + 
+--R                              3 3             4 2  3
+--R                 (- 1016320A a b  - 1198080B a b )c
+--R               + 
+--R                            2 5          3 4  2             7          2 6
+--R                 (- 12800A a b  + 6400B a b )c  + (2400A a b  + 6400B a b )c
+--R               + 
+--R                            8
+--R                 - 1200B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            5 4                4 2             5   3
+--R                 - 675840A a c  + (- 1766400A a b  - 1054720B a b)c
+--R               + 
+--R                             3 4           4 3  2            2 6           3 5
+--R                 (- 106240A a b  - 79360B a b )c  + (14400A a b  + 53120B a b )c
+--R               + 
+--R                          2 7
+--R                 - 7200B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                              5             6  3
+--R                 (- 1372160A a b - 327680B a )c
+--R               + 
+--R                             4 3            5 2  2
+--R                 (- 215040A a b  - 215040B a b )c
+--R               + 
+--R                          3 5            4 4             3 6
+--R                 (26880A a b  + 107520B a b )c - 13440B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            6 3               5 2            6   2
+--R                 - 409600A a c  + (- 122880A a b  - 122880B a b)c
+--R               + 
+--R                          4 4           5 3            4 5
+--R                 (15360A a b  + 61440B a b )c - 7680B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                     2 7             2 6          4 5  20
+--R             (8192B a c  + 20480B a b c  + 2560B b c )x
+--R           + 
+--R                         2 7              2            2   6
+--R                 10240A a c  + (25600A a b  + 117760B a b)c
+--R               + 
+--R                         4             3  5          5 4
+--R                 (3200A b  + 89600B a b )c  + 6080B b c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                           2             3  6               3            2 2  5
+--R                 (148480A a b + 122880B a )c  + (115200A a b  + 478720B a b )c
+--R               + 
+--R                         5              4  4          6 3
+--R                 (8000A b  + 134400B a b )c  + 3680B b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                          3 6             2 2            3   5
+--R                 158720A a c  + (628480A a b  + 821760B a b)c
+--R               + 
+--R                             4            2 3  4           6             5  3
+--R                 (180800A a b  + 750720B a b )c  + (5200A b  + 68320B a b )c
+--R               + 
+--R                        7 2
+--R                 - 40B b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                            3             4  5
+--R                 (1118720A a b + 450560B a )c
+--R               + 
+--R                            2 3             3 2  4
+--R                 (1050240A a b  + 1713920B a b )c
+--R               + 
+--R                            5            2 4  3            7           6  2
+--R                 (98400A a b  + 404160B a b )c  + (- 200A b  - 560B a b )c
+--R               + 
+--R                       8
+--R                 100B b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          4 5              3 2             4   4
+--R                 619520A a c  + (2462720A a b  + 1758720B a b)c
+--R               + 
+--R                           2 4             3 3  3
+--R                 (640640A a b  + 1154560B a b )c
+--R               + 
+--R                             6           2 5  2            8           7
+--R                 (- 1600A a b  - 17984B a b )c  + (- 540A b  + 800B a b )c
+--R               + 
+--R                       9
+--R                 270B b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            4             5  4
+--R                 (2457600A a b + 655360B a )c
+--R               + 
+--R                            3 3             4 2  3
+--R                 (1830400A a b  + 1761280B a b )c
+--R               + 
+--R                          2 5           3 4  2               7           2 6
+--R                 (37120A a b  - 24320B a b )c  + (- 7200A a b  - 18560B a b )c
+--R               + 
+--R                          8
+--R                 3600B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          5 4              4 2             5   3
+--R                 880640A a c  + (2462720A a b  + 1280000B a b)c
+--R               + 
+--R                           3 4            4 3  2
+--R                 (190720A a b  + 140800B a b )c
+--R               + 
+--R                            2 6           3 5             2 7
+--R                 (- 25920A a b  - 95360B a b )c + 12960B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            5             6  3             4 3            5 2  2
+--R                 (1576960A a b + 327680B a )c  + (276480A a b  + 276480B a b )c
+--R               + 
+--R                            3 5            4 4             3 6
+--R                 (- 34560A a b  - 138240B a b )c + 17280B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          6 3             5 2            6   2
+--R                 409600A a c  + (122880A a b  + 122880B a b)c
+--R               + 
+--R                            4 4           5 3            4 5
+--R                 (- 15360A a b  - 61440B a b )c + 7680B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                    2 5            2 4         4 3  8
+--R             (81920a c  + 204800a b c  + 25600b c )x
+--R           + 
+--R                     2   4            3 3  6           3 4           2 2 3  4
+--R             (983040a b c  + 409600a b c )x  + (983040a c  + 1720320a b c )x
+--R           + 
+--R                     3   3 2           4 3
+--R             2621440a b c x  + 1310720a c
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                       2   5            3 4        5 3  10
+--R             (- 204800a b c  - 102400a b c  - 2560b c )x
+--R           + 
+--R                       3 5           2 2 4            4 3  8
+--R             (- 409600a c  - 1024000a b c  - 128000a b c )x
+--R           + 
+--R                        3   4           2 3 3  6
+--R             (- 2457600a b c  - 1024000a b c )x
+--R           + 
+--R                        4 4           3 2 3  4           4   3 2           5 3
+--R             (- 1638400a c  - 2867200a b c )x  - 3276800a b c x  - 1310720a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                             4 5            3 2          4   4
+--R                     15360A a c  + (30720A a b  - 7680B a b)c
+--R                   + 
+--R                                2 4           3 3  3          2 5 2         8
+--R                     (- 13440A a b  - 15360B a b )c  + 6720B a b c  + 300A b c
+--R                   + 
+--R                             9
+--R                     - 150B b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                              4   4              3 3           4 2  3
+--R                     184320A a b c  + (- 15360A a b  - 92160B a b )c
+--R                   + 
+--R                                2 5          3 4  2
+--R                     (- 26880A a b  + 7680B a b )c
+--R                   + 
+--R                               7           2 6              8
+--R                     (4800A a b  + 13440B a b )c - 2400B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                              5 4             4 2           5   3
+--R                     184320A a c  + (230400A a b  - 92160B a b)c
+--R                   + 
+--R                                 3 4            4 3  2
+--R                     (- 149760A a b  - 115200B a b )c
+--R                   + 
+--R                              2 6           3 5             2 7
+--R                     (20160A a b  + 74880B a b )c - 10080B a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                              5   3               4 3            5 2  2
+--R                     491520A a b c  + (- 245760A a b  - 245760B a b )c
+--R                   + 
+--R                              3 5            4 4             3 6
+--R                     (30720A a b  + 122880B a b )c - 15360B a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                          6 3               5 2            6   2
+--R                 245760A a c  + (- 122880A a b  - 122880B a b)c
+--R               + 
+--R                          4 4           5 3            4 5
+--R                 (15360A a b  + 61440B a b )c - 7680B a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                           4   5           4 2 4          2 5 3
+--R                 - 38400A a b c  + 19200B a b c  + 6720A a b c
+--R               + 
+--R                          7          2 6  2           9           8          10
+--R               (- 960A a b  - 3360B a b )c  + (- 30A b  + 480B a b )c + 15B b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           5 5               4 2           5   4
+--R                 - 76800A a c  + (- 153600A a b  + 38400B a b)c
+--R               + 
+--R                          3 4           4 3  3           3 5 2            8
+--R                 (67200A a b  + 76800B a b )c  - 33600B a b c  - 1500A a b c
+--R               + 
+--R                         9
+--R                 750B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            5   4            4 3            5 2  3
+--R                 - 460800A a b c  + (38400A a b  + 230400B a b )c
+--R               + 
+--R                          3 5           4 4  2              2 7           3 6
+--R                 (67200A a b  - 19200B a b )c  + (- 12000A a b  - 33600B a b )c
+--R               + 
+--R                        2 8
+--R                 6000B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            6 4               5 2            6   3
+--R                 - 307200A a c  + (- 384000A a b  + 153600B a b)c
+--R               + 
+--R                           4 4            5 3  2
+--R                 (249600A a b  + 192000B a b )c
+--R               + 
+--R                            3 6            4 5             3 7
+--R                 (- 33600A a b  - 124800B a b )c + 16800B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            6   3             5 3            6 2  2
+--R                 - 614400A a b c  + (307200A a b  + 307200B a b )c
+--R               + 
+--R                            4 5            5 4             4 6
+--R                 (- 38400A a b  - 153600B a b )c + 19200B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        7 3             6 2            7   2
+--R             - 245760A a c  + (122880A a b  + 122880B a b)c
+--R           + 
+--R                        5 4           6 3            5 5
+--R             (- 15360A a b  - 61440B a b )c + 7680B a b
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                        2   6            3 5         5 4  18
+--R             (- 10240B a b c  - 5120B a b c  - 128B b c )x
+--R           + 
+--R                            2            3  6               3           2 2  5
+--R                 (- 12800A a b - 20480B a )c  + (- 6400A a b  - 65280B a b )c
+--R               + 
+--R                          5             4  4         6 3
+--R                 (- 160A b  - 13440B a b )c  - 176B b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                           3 6              2 2            3   5
+--R                 - 25600A a c  + (- 83200A a b  - 171520B a b)c
+--R               + 
+--R                              4            2 3  4            6            5  3
+--R                 (- 17600A a b  - 132480B a b )c  + (- 240A b  - 9376B a b )c
+--R               + 
+--R                       7 2
+--R                 - 8B b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                             3             4  5
+--R                 (- 224000A a b - 122880B a )c
+--R               + 
+--R                             2 3            3 2  4
+--R                 (- 177600A a b  - 420480B a b )c
+--R               + 
+--R                              5           2 4  3           7          6  2
+--R                 (- 13200A a b  - 87840B a b )c  + (- 20A b  - 56B a b )c
+--R               + 
+--R                      8
+--R                 10B b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            4 5               3 2            4   4
+--R                 - 166400A a c  + (- 588800A a b  - 541440B a b)c
+--R               + 
+--R                             2 4            3 3  3         2 5 2        8
+--R                 (- 129600A a b  - 325120B a b )c  + 672B a b c  + 30A b c
+--R               + 
+--R                        9
+--R                 - 15B b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                             4             5  4
+--R                 (- 768000A a b - 245760B a )c
+--R               + 
+--R                             3 3            4 2  3
+--R                 (- 508160A a b  - 599040B a b )c
+--R               + 
+--R                           2 5          3 4  2             7          2 6
+--R                 (- 6400A a b  + 3200B a b )c  + (1200A a b  + 3200B a b )c
+--R               + 
+--R                           8
+--R                 - 600B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            5 4               4 2            5   3
+--R                 - 337920A a c  + (- 883200A a b  - 527360B a b)c
+--R               + 
+--R                            3 4           4 3  2           2 6           3 5
+--R                 (- 53120A a b  - 39680B a b )c  + (7200A a b  + 26560B a b )c
+--R               + 
+--R                          2 7
+--R                 - 3600B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                             5             6  3
+--R                 (- 686080A a b - 163840B a )c
+--R               + 
+--R                             4 3            5 2  2
+--R                 (- 107520A a b  - 107520B a b )c
+--R               + 
+--R                          3 5           4 4            3 6
+--R                 (13440A a b  + 53760B a b )c - 6720B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            6 3              5 2           6   2
+--R                 - 204800A a c  + (- 61440A a b  - 61440B a b)c
+--R               + 
+--R                         4 4           5 3            4 5
+--R                 (7680A a b  + 30720B a b )c - 3840B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                     2 7             2 6          4 5  20
+--R             (4096B a c  + 10240B a b c  + 1280B b c )x
+--R           + 
+--R                        2 7              2           2   6
+--R                 5120A a c  + (12800A a b  + 58880B a b)c
+--R               + 
+--R                         4             3  5          5 4
+--R                 (1600A b  + 44800B a b )c  + 3040B b c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                          2            3  6              3            2 2  5
+--R                 (74240A a b + 61440B a )c  + (57600A a b  + 239360B a b )c
+--R               + 
+--R                         5             4  4          6 3
+--R                 (4000A b  + 67200B a b )c  + 1840B b c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                         3 6             2 2            3   5
+--R                 79360A a c  + (314240A a b  + 410880B a b)c
+--R               + 
+--R                            4            2 3  4           6             5  3
+--R                 (90400A a b  + 375360B a b )c  + (2600A b  + 34160B a b )c
+--R               + 
+--R                        7 2
+--R                 - 20B b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                           3             4  5             2 3            3 2  4
+--R                 (559360A a b + 225280B a )c  + (525120A a b  + 856960B a b )c
+--R               + 
+--R                            5            2 4  3            7           6  2
+--R                 (49200A a b  + 202080B a b )c  + (- 100A b  - 280B a b )c
+--R               + 
+--R                      8
+--R                 50B b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          4 5              3 2            4   4
+--R                 309760A a c  + (1231360A a b  + 879360B a b)c
+--R               + 
+--R                           2 4            3 3  3              6          2 5  2
+--R                 (320320A a b  + 577280B a b )c  + (- 800A a b  - 8992B a b )c
+--R               + 
+--R                          8           7           9
+--R                 (- 270A b  + 400B a b )c + 135B b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            4             5  4             3 3            4 2  3
+--R                 (1228800A a b + 327680B a )c  + (915200A a b  + 880640B a b )c
+--R               + 
+--R                          2 5           3 4  2               7          2 6
+--R                 (18560A a b  - 12160B a b )c  + (- 3600A a b  - 9280B a b )c
+--R               + 
+--R                          8
+--R                 1800B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          5 4              4 2            5   3
+--R                 440320A a c  + (1231360A a b  + 640000B a b)c
+--R               + 
+--R                          3 4           4 3  2              2 6           3 5
+--R                 (95360A a b  + 70400B a b )c  + (- 12960A a b  - 47680B a b )c
+--R               + 
+--R                        2 7
+--R                 6480B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                           5             6  3             4 3            5 2  2
+--R                 (788480A a b + 163840B a )c  + (138240A a b  + 138240B a b )c
+--R               + 
+--R                            3 5           4 4            3 6
+--R                 (- 17280A a b  - 69120B a b )c + 8640B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          6 3            5 2           6   2
+--R                 204800A a c  + (61440A a b  + 61440B a b)c
+--R               + 
+--R                           4 4           5 3            4 5
+--R                 (- 7680A a b  - 30720B a b )c + 3840B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                    2 5            2 4         4 3  8
+--R             (40960a c  + 102400a b c  + 12800b c )x
+--R           + 
+--R                     2   4            3 3  6           3 4          2 2 3  4
+--R             (491520a b c  + 204800a b c )x  + (491520a c  + 860160a b c )x
+--R           + 
+--R                     3   3 2          4 3
+--R             1310720a b c x  + 655360a c
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                       2   5           3 4        5 3  10
+--R             (- 102400a b c  - 51200a b c  - 1280b c )x
+--R           + 
+--R                       3 5          2 2 4           4 3  8
+--R             (- 204800a c  - 512000a b c  - 64000a b c )x
+--R           + 
+--R                        3   4          2 3 3  6
+--R             (- 1228800a b c  - 512000a b c )x
+--R           + 
+--R                       4 4           3 2 3  4           4   3 2          5 3
+--R             (- 819200a c  - 1433600a b c )x  - 1638400a b c x  - 655360a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2437
+
+--S 2438 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             4 5              3 2          4   4
+--R                   - 15360A a c  + (- 30720A a b  + 7680B a b)c
+--R                 + 
+--R                            2 4           3 3  3          2 5 2         8
+--R                   (13440A a b  + 15360B a b )c  - 6720B a b c  - 300A b c
+--R                 + 
+--R                         9
+--R                   150B b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              4   4            3 3           4 2  3
+--R                   - 184320A a b c  + (15360A a b  + 92160B a b )c
+--R                 + 
+--R                            2 5          3 4  2               7           2 6
+--R                   (26880A a b  - 7680B a b )c  + (- 4800A a b  - 13440B a b )c
+--R                 + 
+--R                            8
+--R                   2400B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              5 4               4 2           5   3
+--R                   - 184320A a c  + (- 230400A a b  + 92160B a b)c
+--R                 + 
+--R                             3 4            4 3  2
+--R                   (149760A a b  + 115200B a b )c
+--R                 + 
+--R                              2 6           3 5             2 7
+--R                   (- 20160A a b  - 74880B a b )c + 10080B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              5   3             4 3            5 2  2
+--R                   - 491520A a b c  + (245760A a b  + 245760B a b )c
+--R                 + 
+--R                              3 5            4 4             3 6
+--R                   (- 30720A a b  - 122880B a b )c + 15360B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          6 3             5 2            6   2
+--R               - 245760A a c  + (122880A a b  + 122880B a b)c
+--R             + 
+--R                          4 4           5 3            4 5
+--R               (- 15360A a b  - 61440B a b )c + 7680B a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                       4   5           4 2 4          2 5 3
+--R               38400A a b c  - 19200B a b c  - 6720A a b c
+--R             + 
+--R                        7          2 6  2         9           8          10
+--R               (960A a b  + 3360B a b )c  + (30A b  - 480B a b )c - 15B b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                       5 5             4 2           5   4
+--R               76800A a c  + (153600A a b  - 38400B a b)c
+--R             + 
+--R                          3 4           4 3  3           3 5 2            8
+--R               (- 67200A a b  - 76800B a b )c  + 33600B a b c  + 1500A a b c
+--R             + 
+--R                         9
+--R               - 750B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                        5   4              4 3            5 2  3
+--R               460800A a b c  + (- 38400A a b  - 230400B a b )c
+--R             + 
+--R                          3 5           4 4  2            2 7           3 6
+--R               (- 67200A a b  + 19200B a b )c  + (12000A a b  + 33600B a b )c
+--R             + 
+--R                        2 8
+--R               - 6000B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        6 4             5 2            6   3
+--R               307200A a c  + (384000A a b  - 153600B a b)c
+--R             + 
+--R                           4 4            5 3  2            3 6            4 5
+--R               (- 249600A a b  - 192000B a b )c  + (33600A a b  + 124800B a b )c
+--R             + 
+--R                         3 7
+--R               - 16800B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        6   3               5 3            6 2  2
+--R               614400A a b c  + (- 307200A a b  - 307200B a b )c
+--R             + 
+--R                        4 5            5 4             4 6
+--R               (38400A a b  + 153600B a b )c - 19200B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    7 3               6 2            7   2
+--R           245760A a c  + (- 122880A a b  - 122880B a b)c
+--R         + 
+--R                    5 4           6 3            5 5
+--R           (15360A a b  + 61440B a b )c - 7680B a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                             4 5              3 2          4   4
+--R                   - 15360A a c  + (- 30720A a b  + 7680B a b)c
+--R                 + 
+--R                            2 4           3 3  3          2 5 2         8
+--R                   (13440A a b  + 15360B a b )c  - 6720B a b c  - 300A b c
+--R                 + 
+--R                         9
+--R                   150B b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              4   4            3 3           4 2  3
+--R                   - 184320A a b c  + (15360A a b  + 92160B a b )c
+--R                 + 
+--R                            2 5          3 4  2               7           2 6
+--R                   (26880A a b  - 7680B a b )c  + (- 4800A a b  - 13440B a b )c
+--R                 + 
+--R                            8
+--R                   2400B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              5 4               4 2           5   3
+--R                   - 184320A a c  + (- 230400A a b  + 92160B a b)c
+--R                 + 
+--R                             3 4            4 3  2
+--R                   (149760A a b  + 115200B a b )c
+--R                 + 
+--R                              2 6           3 5             2 7
+--R                   (- 20160A a b  - 74880B a b )c + 10080B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              5   3             4 3            5 2  2
+--R                   - 491520A a b c  + (245760A a b  + 245760B a b )c
+--R                 + 
+--R                              3 5            4 4             3 6
+--R                   (- 30720A a b  - 122880B a b )c + 15360B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          6 3             5 2            6   2
+--R               - 245760A a c  + (122880A a b  + 122880B a b)c
+--R             + 
+--R                          4 4           5 3            4 5
+--R               (- 15360A a b  - 61440B a b )c + 7680B a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                       4   5           4 2 4          2 5 3
+--R               38400A a b c  - 19200B a b c  - 6720A a b c
+--R             + 
+--R                        7          2 6  2         9           8          10
+--R               (960A a b  + 3360B a b )c  + (30A b  - 480B a b )c - 15B b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                       5 5             4 2           5   4
+--R               76800A a c  + (153600A a b  - 38400B a b)c
+--R             + 
+--R                          3 4           4 3  3           3 5 2            8
+--R               (- 67200A a b  - 76800B a b )c  + 33600B a b c  + 1500A a b c
+--R             + 
+--R                         9
+--R               - 750B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                        5   4              4 3            5 2  3
+--R               460800A a b c  + (- 38400A a b  - 230400B a b )c
+--R             + 
+--R                          3 5           4 4  2            2 7           3 6
+--R               (- 67200A a b  + 19200B a b )c  + (12000A a b  + 33600B a b )c
+--R             + 
+--R                        2 8
+--R               - 6000B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        6 4             5 2            6   3
+--R               307200A a c  + (384000A a b  - 153600B a b)c
+--R             + 
+--R                           4 4            5 3  2            3 6            4 5
+--R               (- 249600A a b  - 192000B a b )c  + (33600A a b  + 124800B a b )c
+--R             + 
+--R                         3 7
+--R               - 16800B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        6   3               5 3            6 2  2
+--R               614400A a b c  + (- 307200A a b  - 307200B a b )c
+--R             + 
+--R                        4 5            5 4             4 6
+--R               (38400A a b  + 153600B a b )c - 19200B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    7 3               6 2            7   2
+--R           245760A a c  + (- 122880A a b  - 122880B a b)c
+--R         + 
+--R                    5 4           6 3            5 5
+--R           (15360A a b  + 61440B a b )c - 7680B a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                        4           5  4            3 3           4 2  3
+--R               (12800A a b + 8192B a )c  + (30080A a b  + 14080B a b )c
+--R             + 
+--R                        2 5           3 4  2              7         2 6
+--R               (- 800A a b  - 12480B a b )c  + (- 600A a b  + 400B a b )c
+--R             + 
+--R                       8
+--R               300B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         4 2           5   3            3 4           4 3  2
+--R               (153600A a b  + 98304B a b)c  + (40960A a b  - 35840B a b )c
+--R             + 
+--R                         2 6           3 5            2 7
+--R               (- 9600A a b  - 20480B a b )c + 4800B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         5            6  3             4 3           5 2  2
+--R               (153600A a b + 98304B a )c  + (245760A a b  + 95232B a b )c
+--R             + 
+--R                          3 5            4 4             3 6
+--R               (- 40320A a b  - 122880B a b )c + 20160B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                         5 2            6   2              4 4            5 3
+--R               (409600A a b  + 262144B a b)c  + (- 61440A a b  - 204800B a b )c
+--R             + 
+--R                       4 5
+--R               30720B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     6             7  2              5 3            6 2
+--R           (204800A a b + 131072B a )c  + (- 30720A a b  - 102400B a b )c
+--R         + 
+--R                   5 4
+--R           15360B a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                          3 2           4   4              2 4          3 3  3
+--R               (- 32000A a b  - 20480B a b)c  + (- 11200A a b  + 5760B a b )c
+--R             + 
+--R                         6          2 5  2         8            7          9
+--R               (2000A a b  + 5344B a b )c  + (60A b  - 1000B a b )c - 30B b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          4            5  4               3 3           4 2  3
+--R               (- 64000A a b - 40960B a )c  + (- 150400A a b  - 70400B a b )c
+--R             + 
+--R                       2 5           3 4  2             7          2 6
+--R               (4000A a b  + 62400B a b )c  + (3000A a b  - 2000B a b )c
+--R             + 
+--R                          8
+--R               - 1500B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                           4 2            5   3
+--R               (- 384000A a b  - 245760B a b)c
+--R             + 
+--R                           3 4           4 3  2            2 6           3 5
+--R               (- 102400A a b  + 89600B a b )c  + (24000A a b  + 51200B a b )c
+--R             + 
+--R                         2 7
+--R               - 12000B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           5             6  3
+--R               (- 256000A a b - 163840B a )c
+--R             + 
+--R                           4 3            5 2  2            3 5            4 4
+--R               (- 409600A a b  - 158720B a b )c  + (67200A a b  + 204800B a b )c
+--R             + 
+--R                         3 6
+--R               - 33600B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                           5 2            6   2            4 4            5 3
+--R               (- 512000A a b  - 327680B a b)c  + (76800A a b  + 256000B a b )c
+--R             + 
+--R                         4 5
+--R               - 38400B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       6             7  2            5 3            6 2
+--R           (- 204800A a b - 131072B a )c  + (30720A a b  + 102400B a b )c
+--R         + 
+--R                     5 4
+--R           - 15360B a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                  2 5            2 4         4 3  8
+--R           (81920a c  + 204800a b c  + 25600b c )x
+--R         + 
+--R                   2   4            3 3  6           3 4           2 2 3  4
+--R           (983040a b c  + 409600a b c )x  + (983040a c  + 1720320a b c )x
+--R         + 
+--R                   3   3 2           4 3
+--R           2621440a b c x  + 1310720a c
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                     2   5            3 4        5 3  10
+--R           (- 204800a b c  - 102400a b c  - 2560b c )x
+--R         + 
+--R                     3 5           2 2 4            4 3  8
+--R           (- 409600a c  - 1024000a b c  - 128000a b c )x
+--R         + 
+--R                      3   4           2 3 3  6
+--R           (- 2457600a b c  - 1024000a b c )x
+--R         + 
+--R                      4 4           3 2 3  4           4   3 2           5 3
+--R           (- 1638400a c  - 2867200a b c )x  - 3276800a b c x  - 1310720a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 2438
+
+--S 2439 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2439
+
+--S 2440 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             4 5              3 2          4   4
+--R                   - 15360A a c  + (- 30720A a b  + 7680B a b)c
+--R                 + 
+--R                            2 4           3 3  3          2 5 2         8
+--R                   (13440A a b  + 15360B a b )c  - 6720B a b c  - 300A b c
+--R                 + 
+--R                         9
+--R                   150B b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              4   4            3 3           4 2  3
+--R                   - 184320A a b c  + (15360A a b  + 92160B a b )c
+--R                 + 
+--R                            2 5          3 4  2               7           2 6
+--R                   (26880A a b  - 7680B a b )c  + (- 4800A a b  - 13440B a b )c
+--R                 + 
+--R                            8
+--R                   2400B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              5 4               4 2           5   3
+--R                   - 184320A a c  + (- 230400A a b  + 92160B a b)c
+--R                 + 
+--R                             3 4            4 3  2
+--R                   (149760A a b  + 115200B a b )c
+--R                 + 
+--R                              2 6           3 5             2 7
+--R                   (- 20160A a b  - 74880B a b )c + 10080B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              5   3             4 3            5 2  2
+--R                   - 491520A a b c  + (245760A a b  + 245760B a b )c
+--R                 + 
+--R                              3 5            4 4             3 6
+--R                   (- 30720A a b  - 122880B a b )c + 15360B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          6 3             5 2            6   2
+--R               - 245760A a c  + (122880A a b  + 122880B a b)c
+--R             + 
+--R                          4 4           5 3            4 5
+--R               (- 15360A a b  - 61440B a b )c + 7680B a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                           4   5           4 2 4          2 5 3
+--R                   38400A a b c  - 19200B a b c  - 6720A a b c
+--R                 + 
+--R                            7          2 6  2         9           8          10
+--R                   (960A a b  + 3360B a b )c  + (30A b  - 480B a b )c - 15B b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                           5 5             4 2           5   4
+--R                   76800A a c  + (153600A a b  - 38400B a b)c
+--R                 + 
+--R                              3 4           4 3  3           3 5 2            8
+--R                   (- 67200A a b  - 76800B a b )c  + 33600B a b c  + 1500A a b c
+--R                 + 
+--R                             9
+--R                   - 750B a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            5   4              4 3            5 2  3
+--R                   460800A a b c  + (- 38400A a b  - 230400B a b )c
+--R                 + 
+--R                              3 5           4 4  2
+--R                   (- 67200A a b  + 19200B a b )c
+--R                 + 
+--R                            2 7           3 6            2 8
+--R                   (12000A a b  + 33600B a b )c - 6000B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            6 4             5 2            6   3
+--R                   307200A a c  + (384000A a b  - 153600B a b)c
+--R                 + 
+--R                               4 4            5 3  2
+--R                   (- 249600A a b  - 192000B a b )c
+--R                 + 
+--R                            3 6            4 5             3 7
+--R                   (33600A a b  + 124800B a b )c - 16800B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            6   3               5 3            6 2  2
+--R                   614400A a b c  + (- 307200A a b  - 307200B a b )c
+--R                 + 
+--R                            4 5            5 4             4 6
+--R                   (38400A a b  + 153600B a b )c - 19200B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        7 3               6 2            7   2
+--R               245760A a c  + (- 122880A a b  - 122880B a b)c
+--R             + 
+--R                        5 4           6 3            5 5
+--R               (15360A a b  + 61440B a b )c - 7680B a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                           4 5            3 2           4   4
+--R                   30720A a c  + (61440A a b  - 15360B a b)c
+--R                 + 
+--R                              2 4           3 3  3           2 5 2         8
+--R                   (- 26880A a b  - 30720B a b )c  + 13440B a b c  + 600A b c
+--R                 + 
+--R                           9
+--R                   - 300B b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            4   4              3 3            4 2  3
+--R                   368640A a b c  + (- 30720A a b  - 184320B a b )c
+--R                 + 
+--R                              2 5           3 4  2             7           2 6
+--R                   (- 53760A a b  + 15360B a b )c  + (9600A a b  + 26880B a b )c
+--R                 + 
+--R                              8
+--R                   - 4800B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            5 4             4 2            5   3
+--R                   368640A a c  + (460800A a b  - 184320B a b)c
+--R                 + 
+--R                               3 4            4 3  2
+--R                   (- 299520A a b  - 230400B a b )c
+--R                 + 
+--R                            2 6            3 5             2 7
+--R                   (40320A a b  + 149760B a b )c - 20160B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            5   3               4 3            5 2  2
+--R                   983040A a b c  + (- 491520A a b  - 491520B a b )c
+--R                 + 
+--R                            3 5            4 4             3 6
+--R                   (61440A a b  + 245760B a b )c - 30720B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        6 3               5 2            6   2
+--R               491520A a c  + (- 245760A a b  - 245760B a b)c
+--R             + 
+--R                        4 4            5 3             4 5
+--R               (30720A a b  + 122880B a b )c - 15360B a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                             4   5           4 2 4           2 5 3
+--R                   - 76800A a b c  + 38400B a b c  + 13440A a b c
+--R                 + 
+--R                               7          2 6  2           9           8
+--R                   (- 1920A a b  - 6720B a b )c  + (- 60A b  + 960B a b )c
+--R                 + 
+--R                        10
+--R                   30B b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              5 5               4 2           5   4
+--R                   - 153600A a c  + (- 307200A a b  + 76800B a b)c
+--R                 + 
+--R                             3 4            4 3  3           3 5 2            8
+--R                   (134400A a b  + 153600B a b )c  - 67200B a b c  - 3000A a b c
+--R                 + 
+--R                            9
+--R                   1500B a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              5   4            4 3            5 2  3
+--R                   - 921600A a b c  + (76800A a b  + 460800B a b )c
+--R                 + 
+--R                             3 5           4 4  2
+--R                   (134400A a b  - 38400B a b )c
+--R                 + 
+--R                              2 7           3 6             2 8
+--R                   (- 24000A a b  - 67200B a b )c + 12000B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              6 4               5 2            6   3
+--R                   - 614400A a c  + (- 768000A a b  + 307200B a b)c
+--R                 + 
+--R                             4 4            5 3  2
+--R                   (499200A a b  + 384000B a b )c
+--R                 + 
+--R                              3 6            4 5             3 7
+--R                   (- 67200A a b  - 249600B a b )c + 33600B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               6   3             5 3            6 2  2
+--R                   - 1228800A a b c  + (614400A a b  + 614400B a b )c
+--R                 + 
+--R                              4 5            5 4             4 6
+--R                   (- 76800A a b  - 307200B a b )c + 38400B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          7 3             6 2            7   2
+--R               - 491520A a c  + (245760A a b  + 245760B a b)c
+--R             + 
+--R                          5 4            6 3             5 5
+--R               (- 30720A a b  - 122880B a b )c + 15360B a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                        4           5  4            3 3           4 2  3
+--R               (12800A a b + 8192B a )c  + (30080A a b  + 14080B a b )c
+--R             + 
+--R                        2 5           3 4  2              7         2 6
+--R               (- 800A a b  - 12480B a b )c  + (- 600A a b  + 400B a b )c
+--R             + 
+--R                       8
+--R               300B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         4 2           5   3            3 4           4 3  2
+--R               (153600A a b  + 98304B a b)c  + (40960A a b  - 35840B a b )c
+--R             + 
+--R                         2 6           3 5            2 7
+--R               (- 9600A a b  - 20480B a b )c + 4800B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         5            6  3             4 3           5 2  2
+--R               (153600A a b + 98304B a )c  + (245760A a b  + 95232B a b )c
+--R             + 
+--R                          3 5            4 4             3 6
+--R               (- 40320A a b  - 122880B a b )c + 20160B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                         5 2            6   2              4 4            5 3
+--R               (409600A a b  + 262144B a b)c  + (- 61440A a b  - 204800B a b )c
+--R             + 
+--R                       4 5
+--R               30720B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     6             7  2              5 3            6 2
+--R           (204800A a b + 131072B a )c  + (- 30720A a b  - 102400B a b )c
+--R         + 
+--R                   5 4
+--R           15360B a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                          3 2           4   4              2 4          3 3  3
+--R               (- 32000A a b  - 20480B a b)c  + (- 11200A a b  + 5760B a b )c
+--R             + 
+--R                         6          2 5  2         8            7          9
+--R               (2000A a b  + 5344B a b )c  + (60A b  - 1000B a b )c - 30B b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          4            5  4               3 3           4 2  3
+--R               (- 64000A a b - 40960B a )c  + (- 150400A a b  - 70400B a b )c
+--R             + 
+--R                       2 5           3 4  2             7          2 6
+--R               (4000A a b  + 62400B a b )c  + (3000A a b  - 2000B a b )c
+--R             + 
+--R                          8
+--R               - 1500B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                           4 2            5   3
+--R               (- 384000A a b  - 245760B a b)c
+--R             + 
+--R                           3 4           4 3  2            2 6           3 5
+--R               (- 102400A a b  + 89600B a b )c  + (24000A a b  + 51200B a b )c
+--R             + 
+--R                         2 7
+--R               - 12000B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           5             6  3
+--R               (- 256000A a b - 163840B a )c
+--R             + 
+--R                           4 3            5 2  2            3 5            4 4
+--R               (- 409600A a b  - 158720B a b )c  + (67200A a b  + 204800B a b )c
+--R             + 
+--R                         3 6
+--R               - 33600B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                           5 2            6   2            4 4            5 3
+--R               (- 512000A a b  - 327680B a b)c  + (76800A a b  + 256000B a b )c
+--R             + 
+--R                         4 5
+--R               - 38400B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       6             7  2            5 3            6 2
+--R           (- 204800A a b - 131072B a )c  + (30720A a b  + 102400B a b )c
+--R         + 
+--R                     5 4
+--R           - 15360B a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                  2 5            2 4         4 3  8
+--R           (81920a c  + 204800a b c  + 25600b c )x
+--R         + 
+--R                   2   4            3 3  6           3 4           2 2 3  4
+--R           (983040a b c  + 409600a b c )x  + (983040a c  + 1720320a b c )x
+--R         + 
+--R                   3   3 2           4 3
+--R           2621440a b c x  + 1310720a c
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                     2   5            3 4        5 3  10
+--R           (- 204800a b c  - 102400a b c  - 2560b c )x
+--R         + 
+--R                     3 5           2 2 4            4 3  8
+--R           (- 409600a c  - 1024000a b c  - 128000a b c )x
+--R         + 
+--R                      3   4           2 3 3  6
+--R           (- 2457600a b c  - 1024000a b c )x
+--R         + 
+--R                      4 4           3 2 3  4           4   3 2           5 3
+--R           (- 1638400a c  - 2867200a b c )x  - 3276800a b c x  - 1310720a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 2440
+
+--S 2441 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2441
+
+)clear all
+
+--S 2442 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        x
+--R                                                    Type: Expression(Integer)
+--E 2442
+
+--S 2443 of 3139
+r0:=1/48*(3*b*B+8*A*c+6*B*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c-1/2*a^(3/2)*A*_
+   atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))+1/256*(64*a*A*b*_
+   c^2+(b^2-4*a*c)*(3*b^2*B-8*A*b*c-12*a*B*c))*atanh(1/2*(b+2*c*x^2)/_
+   (sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(5/2)-1/128*(3*b^3*B-8*A*b^2*c-_
+   12*a*b*B*c-64*a*A*c^2+2*c*(3*b^2*B-8*A*b*c-12*a*B*c)*x^2)*sqrt(a+_
+   b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                                          2
+--R                 2 +-+ +-+             b x  + 2a
+--R       - 384A a c \|a \|c atanh(-----------------------)
+--R                                      +---------------+
+--R                                  +-+ |   4      2
+--R                                2\|a \|c x  + b x  + a
+--R     + 
+--R                            2  2           3          2         4
+--R         ((288A a b + 144B a )c  + (- 24A b  - 72B a b )c + 9B b )
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                3 6          3           2  4
+--R           96B c x  + (128A c  + 144B b c )x
+--R         + 
+--R                              2        2   2           2         2
+--R           ((224A b + 240B a)c  + 12B b c)x  + 512A a c  + (48A b  + 120B a b)c
+--R         + 
+--R                  3
+--R           - 18B b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R         2 +-+
+--R     768c \|c
+--R                                                    Type: Expression(Integer)
+--E 2443
+
+--S 2444 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          3   3          2 3 2  6
+--R                 (12288A a b c  + 3072A a b c )x
+--R               + 
+--R                        4 3           3 2 2  4           4   2 2           5 2
+--R               (24576A a c  + 30720A a b c )x  + 73728A a b c x  + 49152A a c
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|c \|c x  + b x  + a
+--R           + 
+--R                           3 4          2 2 3           4 2  8
+--R                 (- 6144A a c  - 9216A a b c  - 384A a b c )x
+--R               + 
+--R                            3   3           2 3 2  6
+--R                 (- 49152A a b c  - 12288A a b c )x
+--R               + 
+--R                          4 3           3 2 2  4           4   2 2           5 2
+--R               (- 49152A a c  - 61440A a b c )x  - 98304A a b c x  - 49152A a c
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                             2 2          3   3             4          2 3  2
+--R                     (9216A a b  + 4608B a b)c  + (1536A a b  - 1152B a b )c
+--R                   + 
+--R                              6           5          7
+--R                     (- 192A b  - 288B a b )c + 72B b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                              3           4  3            2 3          3 2  2
+--R                     (18432A a b + 9216B a )c  + (21504A a b  + 6912B a b )c
+--R                   + 
+--R                                 5          2 4             6
+--R                     (- 1920A a b  - 5184B a b )c + 720B a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                              3 2           4   2
+--R                     (55296A a b  + 27648B a b)c
+--R                   + 
+--R                               2 4           3 3            2 5
+--R                     (- 4608A a b  - 13824B a b )c + 1728B a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                          4            5  2             3 3          4 2
+--R                 (36864A a b + 18432B a )c  + (- 3072A a b  - 9216B a b )c
+--R               + 
+--R                        3 4
+--R                 1152B a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                           3           4  4             2 3          3 2  3
+--R                 (- 4608A a b - 2304B a )c  + (- 6528A a b  - 2304B a b )c
+--R               + 
+--R                          5          2 4  2         7           6         8
+--R                 (288A a b  + 1440B a b )c  + (24A b  - 144B a b )c - 9B b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            3 2           4   3             2 4          3 3  2
+--R                 (- 36864A a b  - 18432B a b)c  + (- 6144A a b  + 4608B a b )c
+--R               + 
+--R                          6          2 5             7
+--R                 (768A a b  + 1152B a b )c - 288B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            4            5  3              3 3           4 2  2
+--R                 (- 36864A a b - 18432B a )c  + (- 43008A a b  - 13824B a b )c
+--R               + 
+--R                         2 5           3 4            2 6
+--R                 (3840A a b  + 10368B a b )c - 1440B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            4 2           5   2           3 4           4 3
+--R                 (- 73728A a b  - 36864B a b)c  + (6144A a b  + 18432B a b )c
+--R               + 
+--R                          3 5
+--R                 - 2304B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        5            6  2           4 3          5 2
+--R             (- 36864A a b - 18432B a )c  + (3072A a b  + 9216B a b )c
+--R           + 
+--R                      4 4
+--R             - 1152B a b
+--R        *
+--R           log
+--R                            4         2     2  +-+            4         2  +-+
+--R                    ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                           6              2  4         2     2  +-+ +-+
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c
+--R                + 
+--R                      2 6           4     2   2
+--R                  4a c x  + 6a b c x  + 8a c x
+--R             /
+--R                                  +---------------+
+--R                         2     2  |   4      2
+--R                  (4a b x  + 8a )\|c x  + b x  + a
+--R                + 
+--R                              2  4         2     2  +-+
+--R                  ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R       + 
+--R                       2 5            2 4        4 3  14
+--R             (- 1536B a c  - 2304B a b c  - 96B b c )x
+--R           + 
+--R                          2 5               2           2   4
+--R                 - 2048A a c  + (- 3072A a b  - 14592B a b)c
+--R               + 
+--R                          4            3  3         5 2
+--R                 (- 128A b  - 6528B a b )c  - 144B b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            2            3  4               3           2 2  3
+--R                 (- 19968A a b - 16128B a )c  + (- 9472A a b  - 39744B a b )c
+--R               + 
+--R                          5            4  2        6
+--R                 (- 224A b  - 5136B a b )c  - 12B b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           3 4              2 2           3   3
+--R                 - 24576A a c  + (- 62208A a b  - 75648B a b)c
+--R               + 
+--R                           4           2 3  2           6          5          7
+--R               (- 8832A a b  - 34848B a b )c  + (- 48A b  - 72B a b )c + 18B b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             3            4  3              2 3           3 2  2
+--R                 (- 110592A a b - 43008B a )c  + (- 52736A a b  - 88320B a b )c
+--R               + 
+--R                             5          2 4             6
+--R                 (- 1152A a b  - 3072B a b )c + 432B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                           4 3               3 2           4   2
+--R                 - 49152A a c  + (- 101376A a b  - 87552B a b)c
+--R               + 
+--R                           2 4           3 3            2 5
+--R                 (- 3840A a b  - 11520B a b )c + 1440B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            4            5  2             3 3          4 2
+--R                 (- 61440A a b - 30720B a )c  + (- 3072A a b  - 9216B a b )c
+--R               + 
+--R                        3 4
+--R                 1152B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                         5         3 4  16
+--R             (3072B a b c  + 768B b c )x
+--R           + 
+--R                                     2  5           3             2  4
+--R                 (4096A a b + 6144B a )c  + (1024A b  + 15360B a b )c
+--R               + 
+--R                        4 3
+--R                 1920B b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                        2 5              2           2   4
+--R                 8192A a c  + (21504A a b  + 44544B a b)c
+--R               + 
+--R                         4             3  3          5 2
+--R                 (2816A b  + 26880B a b )c  + 1248B b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          2            3  4              3           2 2  3
+--R                 (67584A a b + 33792B a )c  + (41984A a b  + 99072B a b )c
+--R               + 
+--R                         5             4  2        6
+--R                 (2176A b  + 16320B a b )c  - 48B b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                         3 4             2 2            3   3
+--R                 49152A a c  + (146688A a b  + 133248B a b)c
+--R               + 
+--R                          4           2 3  2          6           5           7
+--R               (27520A a b  + 73440B a b )c  + (336A b  + 312B a b )c - 126B b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                           3            4  3            2 3            3 2  2
+--R                 (165888A a b + 58368B a )c  + (97280A a b  + 132864B a b )c
+--R               + 
+--R                           5          2 4              6
+--R                 (2688A a b  + 7104B a b )c - 1008B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                         4 3             3 2            4   2
+--R                 49152A a c  + (132096A a b  + 102912B a b)c
+--R               + 
+--R                         2 4           3 3            2 5
+--R                 (5376A a b  + 16128B a b )c - 2016B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          4            5  2           3 3          4 2
+--R                 (61440A a b + 30720B a )c  + (3072A a b  + 9216B a b )c
+--R               + 
+--R                          3 4
+--R                 - 1152B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                        3        3 2  6          2 3           2 2  4
+--R             (24576a b c  + 6144b c )x  + (49152a c  + 61440a b c )x
+--R           + 
+--R                    2   2 2         3 2
+--R             147456a b c x  + 98304a c
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                      2 4           2 3       4 2  8
+--R             (- 12288a c  - 18432a b c  - 768b c )x
+--R           + 
+--R                      2   3           3 2  6            3 3          2 2 2  4
+--R             (- 98304a b c  - 24576a b c )x  + (- 98304a c  - 122880a b c )x
+--R           + 
+--R                      3   2 2         4 2
+--R             - 196608a b c x  - 98304a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                         3   3          2 3 2  6
+--R                 (6144A a b c  + 1536A a b c )x
+--R               + 
+--R                        4 3           3 2 2  4           4   2 2           5 2
+--R               (12288A a c  + 15360A a b c )x  + 36864A a b c x  + 24576A a c
+--R            *
+--R                      +---------------+
+--R                +---+ |   4      2
+--R               \|- c \|c x  + b x  + a
+--R           + 
+--R                           3 4          2 2 3           4 2  8
+--R                 (- 3072A a c  - 4608A a b c  - 192A a b c )x
+--R               + 
+--R                            3   3          2 3 2  6
+--R                 (- 24576A a b c  - 6144A a b c )x
+--R               + 
+--R                          4 3           3 2 2  4           4   2 2           5 2
+--R               (- 24576A a c  - 30720A a b c )x  - 49152A a b c x  - 24576A a c
+--R            *
+--R                +---+ +-+
+--R               \|- c \|a
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                             2 2          3   3             4          2 3  2
+--R                     (9216A a b  + 4608B a b)c  + (1536A a b  - 1152B a b )c
+--R                   + 
+--R                              6           5          7
+--R                     (- 192A b  - 288B a b )c + 72B b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                              3           4  3            2 3          3 2  2
+--R                     (18432A a b + 9216B a )c  + (21504A a b  + 6912B a b )c
+--R                   + 
+--R                                 5          2 4             6
+--R                     (- 1920A a b  - 5184B a b )c + 720B a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                              3 2           4   2
+--R                     (55296A a b  + 27648B a b)c
+--R                   + 
+--R                               2 4           3 3            2 5
+--R                     (- 4608A a b  - 13824B a b )c + 1728B a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                          4            5  2             3 3          4 2
+--R                 (36864A a b + 18432B a )c  + (- 3072A a b  - 9216B a b )c
+--R               + 
+--R                        3 4
+--R                 1152B a b
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                           3           4  4             2 3          3 2  3
+--R                 (- 4608A a b - 2304B a )c  + (- 6528A a b  - 2304B a b )c
+--R               + 
+--R                          5          2 4  2         7           6         8
+--R                 (288A a b  + 1440B a b )c  + (24A b  - 144B a b )c - 9B b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            3 2           4   3             2 4          3 3  2
+--R                 (- 36864A a b  - 18432B a b)c  + (- 6144A a b  + 4608B a b )c
+--R               + 
+--R                          6          2 5             7
+--R                 (768A a b  + 1152B a b )c - 288B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            4            5  3              3 3           4 2  2
+--R                 (- 36864A a b - 18432B a )c  + (- 43008A a b  - 13824B a b )c
+--R               + 
+--R                         2 5           3 4            2 6
+--R                 (3840A a b  + 10368B a b )c - 1440B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            4 2           5   2           3 4           4 3
+--R                 (- 73728A a b  - 36864B a b)c  + (6144A a b  + 18432B a b )c
+--R               + 
+--R                          3 5
+--R                 - 2304B a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        5            6  2           4 3          5 2
+--R             (- 36864A a b - 18432B a )c  + (3072A a b  + 9216B a b )c
+--R           + 
+--R                      4 4
+--R             - 1152B a b
+--R        *
+--R                           +---------------+
+--R                 +---+ +-+ |   4      2          +---+
+--R                \|- c \|a \|c x  + b x  + a  - a\|- c
+--R           atan(--------------------------------------)
+--R                                  2 +-+
+--R                               c x \|a
+--R       + 
+--R                      2 5            2 4        4 3  14
+--R             (- 768B a c  - 1152B a b c  - 48B b c )x
+--R           + 
+--R                          2 5               2          2   4
+--R                 - 1024A a c  + (- 1536A a b  - 7296B a b)c
+--R               + 
+--R                         4            3  3        5 2
+--R                 (- 64A b  - 3264B a b )c  - 72B b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           2           3  4               3           2 2  3
+--R                 (- 9984A a b - 8064B a )c  + (- 4736A a b  - 19872B a b )c
+--R               + 
+--R                          5            4  2       6
+--R                 (- 112A b  - 2568B a b )c  - 6B b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           3 4              2 2           3   3
+--R                 - 12288A a c  + (- 31104A a b  - 37824B a b)c
+--R               + 
+--R                           4           2 3  2           6          5         7
+--R               (- 4416A a b  - 17424B a b )c  + (- 24A b  - 36B a b )c + 9B b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            3            4  3              2 3           3 2  2
+--R                 (- 55296A a b - 21504B a )c  + (- 26368A a b  - 44160B a b )c
+--R               + 
+--R                            5          2 4             6
+--R                 (- 576A a b  - 1536B a b )c + 216B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                           4 3              3 2           4   2
+--R                 - 24576A a c  + (- 50688A a b  - 43776B a b)c
+--R               + 
+--R                           2 4          3 3           2 5
+--R                 (- 1920A a b  - 5760B a b )c + 720B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            4            5  2             3 3          4 2
+--R                 (- 30720A a b - 15360B a )c  + (- 1536A a b  - 4608B a b )c
+--R               + 
+--R                       3 4
+--R                 576B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                         5         3 4  16
+--R             (1536B a b c  + 384B b c )x
+--R           + 
+--R                                    2  5          3            2  4         4 3
+--R               ((2048A a b + 3072B a )c  + (512A b  + 7680B a b )c  + 960B b c )
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                        2 5              2           2   4
+--R                 4096A a c  + (10752A a b  + 22272B a b)c
+--R               + 
+--R                         4             3  3         5 2
+--R                 (1408A b  + 13440B a b )c  + 624B b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          2            3  4              3           2 2  3
+--R                 (33792A a b + 16896B a )c  + (20992A a b  + 49536B a b )c
+--R               + 
+--R                         5            4  2        6
+--R                 (1088A b  + 8160B a b )c  - 24B b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                         3 4            2 2           3   3
+--R                 24576A a c  + (73344A a b  + 66624B a b)c
+--R               + 
+--R                          4           2 3  2          6           5          7
+--R               (13760A a b  + 36720B a b )c  + (168A b  + 156B a b )c - 63B b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          3            4  3            2 3           3 2  2
+--R                 (82944A a b + 29184B a )c  + (48640A a b  + 66432B a b )c
+--R               + 
+--R                           5          2 4             6
+--R                 (1344A a b  + 3552B a b )c - 504B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                         4 3            3 2           4   2
+--R                 24576A a c  + (66048A a b  + 51456B a b)c
+--R               + 
+--R                         2 4          3 3            2 5
+--R                 (2688A a b  + 8064B a b )c - 1008B a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          4            5  2           3 3          4 2
+--R                 (30720A a b + 15360B a )c  + (1536A a b  + 4608B a b )c
+--R               + 
+--R                         3 4
+--R                 - 576B a b
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                        3        3 2  6          2 3           2 2  4
+--R             (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R           + 
+--R                   2   2 2         3 2
+--R             73728a b c x  + 49152a c
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                     2 4          2 3       4 2  8
+--R             (- 6144a c  - 9216a b c  - 384b c )x
+--R           + 
+--R                      2   3           3 2  6            3 3         2 2 2  4
+--R             (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R           + 
+--R                     3   2 2         4 2
+--R             - 98304a b c x  - 49152a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2444
+
+--S 2445 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        3   3          2 3 2  6
+--R               (12288A a b c  + 3072A a b c )x
+--R             + 
+--R                        4 3           3 2 2  4           4   2 2           5 2
+--R               (24576A a c  + 30720A a b c )x  + 73728A a b c x  + 49152A a c
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|c \|c x  + b x  + a
+--R         + 
+--R                         3 4          2 2 3           4 2  8
+--R               (- 6144A a c  - 9216A a b c  - 384A a b c )x
+--R             + 
+--R                          3   3           2 3 2  6
+--R               (- 49152A a b c  - 12288A a b c )x
+--R             + 
+--R                        4 3           3 2 2  4           4   2 2           5 2
+--R             (- 49152A a c  - 61440A a b c )x  - 98304A a b c x  - 49152A a c
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                           2 2          3   3             4          2 3  2
+--R                   (9216A a b  + 4608B a b)c  + (1536A a b  - 1152B a b )c
+--R                 + 
+--R                            6           5          7
+--R                   (- 192A b  - 288B a b )c + 72B b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            3           4  3            2 3          3 2  2
+--R                   (18432A a b + 9216B a )c  + (21504A a b  + 6912B a b )c
+--R                 + 
+--R                               5          2 4             6
+--R                   (- 1920A a b  - 5184B a b )c + 720B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            3 2           4   2             2 4           3 3
+--R                   (55296A a b  + 27648B a b)c  + (- 4608A a b  - 13824B a b )c
+--R                 + 
+--R                          2 5
+--R                   1728B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        4            5  2             3 3          4 2
+--R               (36864A a b + 18432B a )c  + (- 3072A a b  - 9216B a b )c
+--R             + 
+--R                      3 4
+--R               1152B a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                         3           4  4             2 3          3 2  3
+--R               (- 4608A a b - 2304B a )c  + (- 6528A a b  - 2304B a b )c
+--R             + 
+--R                        5          2 4  2         7           6         8
+--R               (288A a b  + 1440B a b )c  + (24A b  - 144B a b )c - 9B b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                          3 2           4   3             2 4          3 3  2
+--R               (- 36864A a b  - 18432B a b)c  + (- 6144A a b  + 4608B a b )c
+--R             + 
+--R                        6          2 5             7
+--R               (768A a b  + 1152B a b )c - 288B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          4            5  3              3 3           4 2  2
+--R               (- 36864A a b - 18432B a )c  + (- 43008A a b  - 13824B a b )c
+--R             + 
+--R                       2 5           3 4            2 6
+--R               (3840A a b  + 10368B a b )c - 1440B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          4 2           5   2           3 4           4 3
+--R               (- 73728A a b  - 36864B a b)c  + (6144A a b  + 18432B a b )c
+--R             + 
+--R                        3 5
+--R               - 2304B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    5            6  2           4 3          5 2            4 4
+--R         (- 36864A a b - 18432B a )c  + (3072A a b  + 9216B a b )c - 1152B a b
+--R      *
+--R         log
+--R                          4         2     2  +-+            4         2  +-+
+--R                  ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R               *
+--R                   +---------------+
+--R                   |   4      2
+--R                  \|c x  + b x  + a
+--R              + 
+--R                         6              2  4         2     2  +-+ +-+       2 6
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c  + 4a c x
+--R              + 
+--R                        4     2   2
+--R                6a b c x  + 8a c x
+--R           /
+--R                                +---------------+
+--R                       2     2  |   4      2
+--R                (4a b x  + 8a )\|c x  + b x  + a
+--R              + 
+--R                            2  4         2     2  +-+
+--R                ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R     + 
+--R                        3   3          2 3 2  6
+--R               (12288A a b c  + 3072A a b c )x
+--R             + 
+--R                        4 3           3 2 2  4           4   2 2           5 2
+--R               (24576A a c  + 30720A a b c )x  + 73728A a b c x  + 49152A a c
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|c \|c x  + b x  + a
+--R         + 
+--R                         3 4          2 2 3           4 2  8
+--R               (- 6144A a c  - 9216A a b c  - 384A a b c )x
+--R             + 
+--R                          3   3           2 3 2  6
+--R               (- 49152A a b c  - 12288A a b c )x
+--R             + 
+--R                        4 3           3 2 2  4           4   2 2           5 2
+--R             (- 49152A a c  - 61440A a b c )x  - 98304A a b c x  - 49152A a c
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                             2 2          3   3               4          2 3  2
+--R                   (- 9216A a b  - 4608B a b)c  + (- 1536A a b  + 1152B a b )c
+--R                 + 
+--R                          6           5          7
+--R                   (192A b  + 288B a b )c - 72B b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              3           4  3              2 3          3 2  2
+--R                   (- 18432A a b - 9216B a )c  + (- 21504A a b  - 6912B a b )c
+--R                 + 
+--R                             5          2 4             6
+--R                   (1920A a b  + 5184B a b )c - 720B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              3 2           4   2           2 4           3 3
+--R                   (- 55296A a b  - 27648B a b)c  + (4608A a b  + 13824B a b )c
+--R                 + 
+--R                            2 5
+--R                   - 1728B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          4            5  2           3 3          4 2
+--R               (- 36864A a b - 18432B a )c  + (3072A a b  + 9216B a b )c
+--R             + 
+--R                        3 4
+--R               - 1152B a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                       3           4  4           2 3          3 2  3
+--R               (4608A a b + 2304B a )c  + (6528A a b  + 2304B a b )c
+--R             + 
+--R                          5          2 4  2           7           6         8
+--R               (- 288A a b  - 1440B a b )c  + (- 24A b  + 144B a b )c + 9B b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                        3 2           4   3           2 4          3 3  2
+--R               (36864A a b  + 18432B a b)c  + (6144A a b  - 4608B a b )c
+--R             + 
+--R                          6          2 5             7
+--R               (- 768A a b  - 1152B a b )c + 288B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        4            5  3            3 3           4 2  2
+--R               (36864A a b + 18432B a )c  + (43008A a b  + 13824B a b )c
+--R             + 
+--R                         2 5           3 4            2 6
+--R               (- 3840A a b  - 10368B a b )c + 1440B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        4 2           5   2             3 4           4 3
+--R               (73728A a b  + 36864B a b)c  + (- 6144A a b  - 18432B a b )c
+--R             + 
+--R                      3 5
+--R               2304B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                  5            6  2             4 3          5 2            4 4
+--R         (36864A a b + 18432B a )c  + (- 3072A a b  - 9216B a b )c + 1152B a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                       3   3           2 3          3 2  2
+--R               16384A a b c  + (5632A a b  + 3840B a b )c
+--R             + 
+--R                        5         2 4             6
+--R               (384A a b  + 384B a b )c - 144B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                       4 3            3 2          4   2
+--R               32768A a c  + (44032A a b  + 7680B a b)c
+--R             + 
+--R                       2 4          3 3            2 5
+--R               (3840A a b  + 8448B a b )c - 1440B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    4   2           3 3           4 2            3 4  2
+--R           (98304A a b c  + (9216A a b  + 23040B a b )c - 3456B a b )x
+--R         + 
+--R                   5 2           4 2           5             4 3
+--R           65536A a c  + (6144A a b  + 15360B a b)c - 2304B a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                        3 4              2 2          3   3
+--R               - 8192A a c  + (- 13056A a b  - 1920B a b)c
+--R             + 
+--R                           4          2 3  2           6           5          7
+--R               (- 1664A a b  - 2592B a b )c  + (- 48A b  + 312B a b )c + 18B b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         3   3              2 3           3 2  2
+--R               - 65536A a b c  + (- 22528A a b  - 15360B a b )c
+--R             + 
+--R                           5          2 4             6
+--R               (- 1536A a b  - 1536B a b )c + 576B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         4 3              3 2           4   2
+--R               - 65536A a c  + (- 88064A a b  - 15360B a b)c
+--R             + 
+--R                         2 4           3 3            2 5
+--R               (- 7680A a b  - 16896B a b )c + 2880B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       4   2              3 3           4 2            3 4  2
+--R           (- 131072A a b c  + (- 12288A a b  - 30720B a b )c + 4608B a b )x
+--R         + 
+--R                     5 2             4 2           5             4 3
+--R           - 65536A a c  + (- 6144A a b  - 15360B a b)c + 2304B a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                      3        3 2  6          2 3           2 2  4
+--R           (24576a b c  + 6144b c )x  + (49152a c  + 61440a b c )x
+--R         + 
+--R                  2   2 2         3 2
+--R           147456a b c x  + 98304a c
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                    2 4           2 3       4 2  8
+--R           (- 12288a c  - 18432a b c  - 768b c )x
+--R         + 
+--R                    2   3           3 2  6            3 3          2 2 2  4
+--R           (- 98304a b c  - 24576a b c )x  + (- 98304a c  - 122880a b c )x
+--R         + 
+--R                    3   2 2         4 2
+--R           - 196608a b c x  - 98304a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 2445
+
+--S 2446 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2446
+
+--S 2447 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        3   3          2 3 2  6
+--R               (12288A a b c  + 3072A a b c )x
+--R             + 
+--R                        4 3           3 2 2  4           4   2 2           5 2
+--R               (24576A a c  + 30720A a b c )x  + 73728A a b c x  + 49152A a c
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|c \|c x  + b x  + a
+--R         + 
+--R                         3 4          2 2 3           4 2  8
+--R               (- 6144A a c  - 9216A a b c  - 384A a b c )x
+--R             + 
+--R                          3   3           2 3 2  6
+--R               (- 49152A a b c  - 12288A a b c )x
+--R             + 
+--R                        4 3           3 2 2  4           4   2 2           5 2
+--R             (- 49152A a c  - 61440A a b c )x  - 98304A a b c x  - 49152A a c
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                        3   3          2 3 2  6
+--R               (12288A a b c  + 3072A a b c )x
+--R             + 
+--R                        4 3           3 2 2  4           4   2 2           5 2
+--R               (24576A a c  + 30720A a b c )x  + 73728A a b c x  + 49152A a c
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|c \|c x  + b x  + a
+--R         + 
+--R                         3 4          2 2 3           4 2  8
+--R               (- 6144A a c  - 9216A a b c  - 384A a b c )x
+--R             + 
+--R                          3   3           2 3 2  6
+--R               (- 49152A a b c  - 12288A a b c )x
+--R             + 
+--R                        4 3           3 2 2  4           4   2 2           5 2
+--R             (- 49152A a c  - 61440A a b c )x  - 98304A a b c x  - 49152A a c
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                             2 2          3   3               4          2 3  2
+--R                   (- 9216A a b  - 4608B a b)c  + (- 1536A a b  + 1152B a b )c
+--R                 + 
+--R                          6           5          7
+--R                   (192A b  + 288B a b )c - 72B b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              3           4  3              2 3          3 2  2
+--R                   (- 18432A a b - 9216B a )c  + (- 21504A a b  - 6912B a b )c
+--R                 + 
+--R                             5          2 4             6
+--R                   (1920A a b  + 5184B a b )c - 720B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              3 2           4   2           2 4           3 3
+--R                   (- 55296A a b  - 27648B a b)c  + (4608A a b  + 13824B a b )c
+--R                 + 
+--R                            2 5
+--R                   - 1728B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          4            5  2           3 3          4 2
+--R               (- 36864A a b - 18432B a )c  + (3072A a b  + 9216B a b )c
+--R             + 
+--R                        3 4
+--R               - 1152B a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                           3           4  4           2 3          3 2  3
+--R                   (4608A a b + 2304B a )c  + (6528A a b  + 2304B a b )c
+--R                 + 
+--R                            5          2 4  2           7           6         8
+--R                 (- 288A a b  - 1440B a b )c  + (- 24A b  + 144B a b )c + 9B b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            3 2           4   3           2 4          3 3  2
+--R                   (36864A a b  + 18432B a b)c  + (6144A a b  - 4608B a b )c
+--R                 + 
+--R                              6          2 5             7
+--R                   (- 768A a b  - 1152B a b )c + 288B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            4            5  3            3 3           4 2  2
+--R                   (36864A a b + 18432B a )c  + (43008A a b  + 13824B a b )c
+--R                 + 
+--R                             2 5           3 4            2 6
+--R                   (- 3840A a b  - 10368B a b )c + 1440B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            4 2           5   2             3 4           4 3
+--R                   (73728A a b  + 36864B a b)c  + (- 6144A a b  - 18432B a b )c
+--R                 + 
+--R                          3 5
+--R                   2304B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        5            6  2             4 3          5 2
+--R               (36864A a b + 18432B a )c  + (- 3072A a b  - 9216B a b )c
+--R             + 
+--R                      4 4
+--R               1152B a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                            2 2          3   3             4          2 3  2
+--R                   (18432A a b  + 9216B a b)c  + (3072A a b  - 2304B a b )c
+--R                 + 
+--R                            6           5           7
+--R                   (- 384A b  - 576B a b )c + 144B b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            3            4  3            2 3           3 2  2
+--R                   (36864A a b + 18432B a )c  + (43008A a b  + 13824B a b )c
+--R                 + 
+--R                               5           2 4              6
+--R                   (- 3840A a b  - 10368B a b )c + 1440B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             3 2           4   2             2 4           3 3
+--R                   (110592A a b  + 55296B a b)c  + (- 9216A a b  - 27648B a b )c
+--R                 + 
+--R                          2 5
+--R                   3456B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        4            5  2             3 3           4 2
+--R               (73728A a b + 36864B a )c  + (- 6144A a b  - 18432B a b )c
+--R             + 
+--R                      3 4
+--R               2304B a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                             3           4  4              2 3          3 2  3
+--R                   (- 9216A a b - 4608B a )c  + (- 13056A a b  - 4608B a b )c
+--R                 + 
+--R                            5          2 4  2         7           6          8
+--R                   (576A a b  + 2880B a b )c  + (48A b  - 288B a b )c - 18B b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              3 2           4   3
+--R                   (- 73728A a b  - 36864B a b)c
+--R                 + 
+--R                              2 4          3 3  2             6          2 5
+--R                   (- 12288A a b  + 9216B a b )c  + (1536A a b  + 2304B a b )c
+--R                 + 
+--R                             7
+--R                   - 576B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              4            5  3
+--R                   (- 73728A a b - 36864B a )c
+--R                 + 
+--R                              3 3           4 2  2           2 5           3 4
+--R                   (- 86016A a b  - 27648B a b )c  + (7680A a b  + 20736B a b )c
+--R                 + 
+--R                            2 6
+--R                   - 2880B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               4 2           5   2
+--R                   (- 147456A a b  - 73728B a b)c
+--R                 + 
+--R                            3 4           4 3            3 5
+--R                   (12288A a b  + 36864B a b )c - 4608B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          5            6  2           4 3           5 2
+--R               (- 73728A a b - 36864B a )c  + (6144A a b  + 18432B a b )c
+--R             + 
+--R                        4 4
+--R               - 2304B a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                         +---------------+
+--R               +---+ +-+ |   4      2          +---+
+--R              \|- c \|a \|c x  + b x  + a  - a\|- c
+--R         atan(--------------------------------------)
+--R                                2 +-+
+--R                             c x \|a
+--R     + 
+--R                       3   3           2 3          3 2  2
+--R               16384A a b c  + (5632A a b  + 3840B a b )c
+--R             + 
+--R                        5         2 4             6
+--R               (384A a b  + 384B a b )c - 144B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                       4 3            3 2          4   2
+--R               32768A a c  + (44032A a b  + 7680B a b)c
+--R             + 
+--R                       2 4          3 3            2 5
+--R               (3840A a b  + 8448B a b )c - 1440B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    4   2           3 3           4 2            3 4  2
+--R           (98304A a b c  + (9216A a b  + 23040B a b )c - 3456B a b )x
+--R         + 
+--R                   5 2           4 2           5             4 3
+--R           65536A a c  + (6144A a b  + 15360B a b)c - 2304B a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                        3 4              2 2          3   3
+--R               - 8192A a c  + (- 13056A a b  - 1920B a b)c
+--R             + 
+--R                           4          2 3  2           6           5          7
+--R               (- 1664A a b  - 2592B a b )c  + (- 48A b  + 312B a b )c + 18B b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         3   3              2 3           3 2  2
+--R               - 65536A a b c  + (- 22528A a b  - 15360B a b )c
+--R             + 
+--R                           5          2 4             6
+--R               (- 1536A a b  - 1536B a b )c + 576B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         4 3              3 2           4   2
+--R               - 65536A a c  + (- 88064A a b  - 15360B a b)c
+--R             + 
+--R                         2 4           3 3            2 5
+--R               (- 7680A a b  - 16896B a b )c + 2880B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       4   2              3 3           4 2            3 4  2
+--R           (- 131072A a b c  + (- 12288A a b  - 30720B a b )c + 4608B a b )x
+--R         + 
+--R                     5 2             4 2           5             4 3
+--R           - 65536A a c  + (- 6144A a b  - 15360B a b)c + 2304B a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                      3        3 2  6          2 3           2 2  4
+--R           (24576a b c  + 6144b c )x  + (49152a c  + 61440a b c )x
+--R         + 
+--R                  2   2 2         3 2
+--R           147456a b c x  + 98304a c
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                    2 4           2 3       4 2  8
+--R           (- 12288a c  - 18432a b c  - 768b c )x
+--R         + 
+--R                    2   3           3 2  6            3 3          2 2 2  4
+--R           (- 98304a b c  - 24576a b c )x  + (- 98304a c  - 122880a b c )x
+--R         + 
+--R                    3   2 2         4 2
+--R           - 196608a b c x  - 98304a c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 2447
+
+--S 2448 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2448
+
+)clear all
+
+--S 2449 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^3
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        3
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 2449
+
+--S 2450 of 3139
+r0:=-1/6*(3*A-B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^2-1/32*(b^3*B-6*A*b^2*c-_
+   12*a*b*B*c-24*a*A*c^2)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+_
+   c*x^4)))/c^(3/2)-1/4*(3*A*b+2*a*B)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*_
+   sqrt(a+b*x^2+c*x^4)))*sqrt(a)+1/16*(b^2*B+18*A*b*c+8*a*B*c+2*c*(b*B+_
+   6*A*c)*x^2)*sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                                    2
+--R                           2 +-+ +-+             b x  + 2a
+--R       (- 72A b - 48B a)c x \|a \|c atanh(-----------------------)
+--R                                                +---------------+
+--R                                            +-+ |   4      2
+--R                                          2\|a \|c x  + b x  + a
+--R     + 
+--R                                                                  2
+--R               2         2                   3  2             2c x  + b
+--R       (72A a c  + (18A b  + 36B a b)c - 3B b )x atanh(-----------------------)
+--R                                                             +---------------+
+--R                                                         +-+ |   4      2
+--R                                                       2\|c \|c x  + b x  + a
+--R     + 
+--R                2 6         2            4                           2  2
+--R           16B c x  + (24A c  + 28B b c)x  + ((60A b + 64B a)c + 6B b )x
+--R         + 
+--R           - 48A a c
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R          2 +-+
+--R     96c x \|c
+--R                                                    Type: Expression(Integer)
+--E 2450
+
+--S 2451 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          2 2          3   2            4         2 3    8
+--R                 ((2304A a b  + 1536B a b)c  + (576A a b  + 384B a b )c)x
+--R               + 
+--R                          3           4  2           2 3          3 2    6
+--R                 ((4608A a b + 3072B a )c  + (5760A a b  + 3840B a b )c)x
+--R               + 
+--R                          3 2          4     4           4           5    2
+--R                 (13824A a b  + 9216B a b)c x  + (9216A a b + 6144B a )c x
+--R            *
+--R                        +---------------+
+--R                +-+ +-+ |   4      2
+--R               \|a \|c \|c x  + b x  + a
+--R           + 
+--R                               3          4  3             2 3          3 2  2
+--R                     (- 1152A a b - 768B a )c  + (- 1728A a b  - 1152B a b )c
+--R                   + 
+--R                               5        2 4
+--R                     (- 72A a b  - 48B a b )c
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                            3 2          4   2             2 4          3 3    8
+--R                 ((- 9216A a b  - 6144B a b)c  + (- 2304A a b  - 1536B a b )c)x
+--R               + 
+--R                            4           5  2              3 3          4 2    6
+--R                 ((- 9216A a b - 6144B a )c  + (- 11520A a b  - 7680B a b )c)x
+--R               + 
+--R                          4 2           5     4             5           6    2
+--R               (- 18432A a b  - 12288B a b)c x  + (- 9216A a b - 6144B a )c x
+--R            *
+--R                +-+
+--R               \|c
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                            3   3           2 3          3 2  2
+--R                     2304A a b c  + (1152A a b  + 1152B a b )c
+--R                   + 
+--R                              5         2 4            6
+--R                     (144A a b  + 192B a b )c - 24B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                            4 3           3 2          4   2
+--R                     4608A a c  + (6912A a b  + 2304B a b)c
+--R                   + 
+--R                             2 4          3 3           2 5
+--R                     (1440A a b  + 2688B a b )c - 240B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                          4   2           3 3          4 2           3 4  4
+--R                 (13824A a b c  + (3456A a b  + 6912B a b )c - 576B a b )x
+--R               + 
+--R                         5 2           4 2          5            4 3  2
+--R                 (9216A a c  + (2304A a b  + 4608B a b)c - 384B a b )x
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                              3 4             2 2         3   3
+--R                     - 1152A a c  + (- 2016A a b  - 576B a b)c
+--R                   + 
+--R                              4         2 3  2           6          5         7
+--R                   (- 504A a b  - 816B a b )c  + (- 18A b  + 36B a b )c + 3B b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              3   3             2 3          3 2  2
+--R                     - 9216A a b c  + (- 4608A a b  - 4608B a b )c
+--R                   + 
+--R                                5         2 4            6
+--R                     (- 576A a b  - 768B a b )c + 96B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                              4 3              3 2          4   2
+--R                     - 9216A a c  + (- 13824A a b  - 4608B a b)c
+--R                   + 
+--R                               2 4          3 3           2 5
+--R                     (- 2880A a b  - 5376B a b )c + 480B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                            4   2             3 3          4 2           3 4  4
+--R                 (- 18432A a b c  + (- 4608A a b  - 9216B a b )c + 768B a b )x
+--R               + 
+--R                           5 2             4 2          5            4 3  2
+--R                 (- 9216A a c  + (- 2304A a b  - 4608B a b)c + 384B a b )x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R           log
+--R                            4         2     2  +-+            4         2  +-+
+--R                    ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                           6              2  4         2     2  +-+ +-+
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c
+--R                + 
+--R                      2 6           4     2   2
+--R                  4a c x  + 6a b c x  + 8a c x
+--R             /
+--R                                  +---------------+
+--R                         2     2  |   4      2
+--R                  (4a b x  + 8a )\|c x  + b x  + a
+--R                + 
+--R                              2  4         2     2  +-+
+--R                  ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R       + 
+--R                      2 4           2 3        4 2  14
+--R             (- 256B a c  - 384B a b c  - 16B b c )x
+--R           + 
+--R                         2 4              2          2   3
+--R                 - 384A a c  + (- 576A a b  - 2496B a b)c
+--R               + 
+--R                         4            3  2        5
+--R                 (- 24A b  - 1184B a b )c  - 28B b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           2           3  3               3          2 2  2
+--R                 (- 4032A a b - 3072B a )c  + (- 2208A a b  - 7776B a b )c
+--R               + 
+--R                         5            4         6
+--R                 (- 60A b  - 1104B a b )c - 6B b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          3 3             2 2           3   2
+--R                 - 2304A a c  + (- 8832A a b  - 13824B a b)c
+--R               + 
+--R                             4          2 3             5
+--R                 (- 1488A a b  - 6592B a b )c - 144B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                           3           4  2             2 3           3 2
+--R                 (- 4608A a b - 6144B a )c  + (- 4224A a b  - 12672B a b )c
+--R               + 
+--R                         2 4
+--R                 - 480B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                     4 2           3 2          4            3 3  4
+--R             (3072A a c  + (1536A a b  - 7680B a b)c - 384B a b )x
+--R           + 
+--R                     4     2          5
+--R             10752A a b c x  + 6144A a c
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                    2   4           3 3  16
+--R             (512B a b c  + 128B a b c )x
+--R           + 
+--R                        2           3  4            3          2 2  3
+--R                 (768A a b + 1024B a )c  + (192A a b  + 2688B a b )c
+--R               + 
+--R                         4 2
+--R                 352B a b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                        3 4           2 2          3   3
+--R                 1536A a c  + (4608A a b  + 8448B a b)c
+--R               + 
+--R                          4          2 3  2           5
+--R                 (672A a b  + 5248B a b )c  + 272B a b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                         3           4  3           2 3           3 2  2
+--R                 (8448A a b + 6144B a )c  + (7296A a b  + 18336B a b )c
+--R               + 
+--R                          5          2 4            6
+--R                 (432A a b  + 3440B a b )c + 42B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                        4 3            3 2           4   2
+--R                 1536A a c  + (12288A a b  + 20736B a b)c
+--R               + 
+--R                         2 4           3 3           2 5
+--R                 (3360A a b  + 12160B a b )c + 336B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          4           5  2           3 3           4 2
+--R                 (- 768A a b + 6144B a )c  + (4416A a b  + 16512B a b )c
+--R               + 
+--R                       3 4
+--R                 672B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                       5 2             4 2          5            4 3  4
+--R             (- 6144A a c  + (- 6144A a b  + 7680B a b)c + 384B a b )x
+--R           + 
+--R                       5     2          6
+--R             - 13824A a b c x  - 6144A a c
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                   2   2         3   8         3 2        2 2   6
+--R             (3072a b c  + 768a b c)x  + (6144a c  + 7680a b c)x
+--R           + 
+--R                   3     4         4   2
+--R             18432a b c x  + 12288a c x
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                     2 3          2 2      4   10
+--R             (- 1536a c  - 2304a b c  - 96b c)x
+--R           + 
+--R                      2   2          3   8            3 2         2 2   6
+--R             (- 12288a b c  - 3072a b c)x  + (- 12288a c  - 15360a b c)x
+--R           + 
+--R                     3     4         4   2
+--R             - 24576a b c x  - 12288a c x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R     ,
+--R
+--R                          2 2         3   2            4         2 3    8
+--R                 ((1152A a b  + 768B a b)c  + (288A a b  + 192B a b )c)x
+--R               + 
+--R                          3           4  2           2 3          3 2    6
+--R                 ((2304A a b + 1536B a )c  + (2880A a b  + 1920B a b )c)x
+--R               + 
+--R                         3 2          4     4           4           5    2
+--R                 (6912A a b  + 4608B a b)c x  + (4608A a b + 3072B a )c x
+--R            *
+--R                          +---------------+
+--R                +---+ +-+ |   4      2
+--R               \|- c \|a \|c x  + b x  + a
+--R           + 
+--R                              3          4  3            2 3         3 2  2
+--R                     (- 576A a b - 384B a )c  + (- 864A a b  - 576B a b )c
+--R                   + 
+--R                               5        2 4
+--R                     (- 36A a b  - 24B a b )c
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                            3 2          4   2             2 4         3 3    8
+--R                 ((- 4608A a b  - 3072B a b)c  + (- 1152A a b  - 768B a b )c)x
+--R               + 
+--R                            4           5  2             3 3          4 2    6
+--R                 ((- 4608A a b - 3072B a )c  + (- 5760A a b  - 3840B a b )c)x
+--R               + 
+--R                           4 2          5     4             5           6    2
+--R                 (- 9216A a b  - 6144B a b)c x  + (- 4608A a b - 3072B a )c x
+--R            *
+--R                +---+
+--R               \|- c
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                            3   3           2 3          3 2  2
+--R                     2304A a b c  + (1152A a b  + 1152B a b )c
+--R                   + 
+--R                              5         2 4            6
+--R                     (144A a b  + 192B a b )c - 24B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                            4 3           3 2          4   2
+--R                     4608A a c  + (6912A a b  + 2304B a b)c
+--R                   + 
+--R                             2 4          3 3           2 5
+--R                     (1440A a b  + 2688B a b )c - 240B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                          4   2           3 3          4 2           3 4  4
+--R                 (13824A a b c  + (3456A a b  + 6912B a b )c - 576B a b )x
+--R               + 
+--R                         5 2           4 2          5            4 3  2
+--R                 (9216A a c  + (2304A a b  + 4608B a b)c - 384B a b )x
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                              3 4             2 2         3   3
+--R                     - 1152A a c  + (- 2016A a b  - 576B a b)c
+--R                   + 
+--R                              4         2 3  2           6          5         7
+--R                   (- 504A a b  - 816B a b )c  + (- 18A b  + 36B a b )c + 3B b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              3   3             2 3          3 2  2
+--R                     - 9216A a b c  + (- 4608A a b  - 4608B a b )c
+--R                   + 
+--R                                5         2 4            6
+--R                     (- 576A a b  - 768B a b )c + 96B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                              4 3              3 2          4   2
+--R                     - 9216A a c  + (- 13824A a b  - 4608B a b)c
+--R                   + 
+--R                               2 4          3 3           2 5
+--R                     (- 2880A a b  - 5376B a b )c + 480B a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                            4   2             3 3          4 2           3 4  4
+--R                 (- 18432A a b c  + (- 4608A a b  - 9216B a b )c + 768B a b )x
+--R               + 
+--R                           5 2             4 2          5            4 3  2
+--R                 (- 9216A a c  + (- 2304A a b  - 4608B a b)c + 384B a b )x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                           +---------------+
+--R                 +---+ +-+ |   4      2          +---+
+--R                \|- c \|a \|c x  + b x  + a  - a\|- c
+--R           atan(--------------------------------------)
+--R                                  2 +-+
+--R                               c x \|a
+--R       + 
+--R                      2 4           2 3       4 2  14
+--R             (- 128B a c  - 192B a b c  - 8B b c )x
+--R           + 
+--R                         2 4              2          2   3
+--R                 - 192A a c  + (- 288A a b  - 1248B a b)c
+--R               + 
+--R                         4           3  2        5
+--R                 (- 12A b  - 592B a b )c  - 14B b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           2           3  3               3          2 2  2
+--R                 (- 2016A a b - 1536B a )c  + (- 1104A a b  - 3888B a b )c
+--R               + 
+--R                         5           4         6
+--R                 (- 30A b  - 552B a b )c - 3B b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          3 3             2 2          3   2
+--R                 - 1152A a c  + (- 4416A a b  - 6912B a b)c
+--R               + 
+--R                            4          2 3            5
+--R                 (- 744A a b  - 3296B a b )c - 72B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                           3           4  2             2 3          3 2
+--R                 (- 2304A a b - 3072B a )c  + (- 2112A a b  - 6336B a b )c
+--R               + 
+--R                         2 4
+--R                 - 240B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                     4 2          3 2          4            3 3  4
+--R             (1536A a c  + (768A a b  - 3840B a b)c - 192B a b )x
+--R           + 
+--R                    4     2          5
+--R             5376A a b c x  + 3072A a c
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                    2   4          3 3  16
+--R             (256B a b c  + 64B a b c )x
+--R           + 
+--R                          2          3  4           3          2 2  3
+--R                   (384A a b + 512B a )c  + (96A a b  + 1344B a b )c
+--R                 + 
+--R                           4 2
+--R                   176B a b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                       3 4           2 2          3   3
+--R                 768A a c  + (2304A a b  + 4224B a b)c
+--R               + 
+--R                          4          2 3  2           5
+--R                 (336A a b  + 2624B a b )c  + 136B a b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                         3           4  3           2 3          3 2  2
+--R                 (4224A a b + 3072B a )c  + (3648A a b  + 9168B a b )c
+--R               + 
+--R                          5          2 4            6
+--R                 (216A a b  + 1720B a b )c + 21B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                       4 3           3 2           4   2
+--R                 768A a c  + (6144A a b  + 10368B a b)c
+--R               + 
+--R                         2 4          3 3           2 5
+--R                 (1680A a b  + 6080B a b )c + 168B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          4           5  2           3 3          4 2
+--R                 (- 384A a b + 3072B a )c  + (2208A a b  + 8256B a b )c
+--R               + 
+--R                       3 4
+--R                 336B a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                       5 2             4 2          5            4 3  4
+--R             (- 3072A a c  + (- 3072A a b  + 3840B a b)c + 192B a b )x
+--R           + 
+--R                      5     2          6
+--R             - 6912A a b c x  - 3072A a c
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                   2   2         3   8         3 2        2 2   6        3     4
+--R             (1536a b c  + 384a b c)x  + (3072a c  + 3840a b c)x  + 9216a b c x
+--R           + 
+--R                  4   2
+--R             6144a c x
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                    2 3          2 2      4   10           2   2          3   8
+--R             (- 768a c  - 1152a b c  - 48b c)x   + (- 6144a b c  - 1536a b c)x
+--R           + 
+--R                     3 2        2 2   6         3     4        4   2
+--R             (- 6144a c  - 7680a b c)x  - 12288a b c x  - 6144a c x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2451
+
+--S 2452 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        2 2          3   2            4         2 3    6
+--R               ((2304A a b  + 1536B a b)c  + (576A a b  + 384B a b )c)x
+--R             + 
+--R                        3           4  2           2 3          3 2    4
+--R               ((4608A a b + 3072B a )c  + (5760A a b  + 3840B a b )c)x
+--R             + 
+--R                        3 2          4     2           4           5
+--R               (13824A a b  + 9216B a b)c x  + (9216A a b + 6144B a )c
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                             3          4  3             2 3          3 2  2
+--R                   (- 1152A a b - 768B a )c  + (- 1728A a b  - 1152B a b )c
+--R                 + 
+--R                             5        2 4
+--R                   (- 72A a b  - 48B a b )c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          3 2          4   2             2 4          3 3    6
+--R               ((- 9216A a b  - 6144B a b)c  + (- 2304A a b  - 1536B a b )c)x
+--R             + 
+--R                          4           5  2              3 3          4 2    4
+--R               ((- 9216A a b - 6144B a )c  + (- 11520A a b  - 7680B a b )c)x
+--R             + 
+--R                          4 2           5     2             5           6
+--R               (- 18432A a b  - 12288B a b)c x  + (- 9216A a b - 6144B a )c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                          3   3           2 3          3 2  2
+--R                   2304A a b c  + (1152A a b  + 1152B a b )c
+--R                 + 
+--R                            5         2 4            6
+--R                   (144A a b  + 192B a b )c - 24B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          4 3           3 2          4   2
+--R                   4608A a c  + (6912A a b  + 2304B a b)c
+--R                 + 
+--R                           2 4          3 3           2 5
+--R                   (1440A a b  + 2688B a b )c - 240B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        4   2           3 3          4 2           3 4  2
+--R               (13824A a b c  + (3456A a b  + 6912B a b )c - 576B a b )x
+--R             + 
+--R                      5 2           4 2          5            4 3
+--R               9216A a c  + (2304A a b  + 4608B a b)c - 384B a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                            3 4             2 2         3   3
+--R                   - 1152A a c  + (- 2016A a b  - 576B a b)c
+--R                 + 
+--R                              4         2 3  2           6          5         7
+--R                   (- 504A a b  - 816B a b )c  + (- 18A b  + 36B a b )c + 3B b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            3   3             2 3          3 2  2
+--R                   - 9216A a b c  + (- 4608A a b  - 4608B a b )c
+--R                 + 
+--R                              5         2 4            6
+--R                   (- 576A a b  - 768B a b )c + 96B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            4 3              3 2          4   2
+--R                   - 9216A a c  + (- 13824A a b  - 4608B a b)c
+--R                 + 
+--R                             2 4          3 3           2 5
+--R                   (- 2880A a b  - 5376B a b )c + 480B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          4   2             3 3          4 2           3 4  2
+--R               (- 18432A a b c  + (- 4608A a b  - 9216B a b )c + 768B a b )x
+--R             + 
+--R                        5 2             4 2          5            4 3
+--R               - 9216A a c  + (- 2304A a b  - 4608B a b)c + 384B a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         log
+--R                          4         2     2  +-+            4         2  +-+
+--R                  ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R               *
+--R                   +---------------+
+--R                   |   4      2
+--R                  \|c x  + b x  + a
+--R              + 
+--R                         6              2  4         2     2  +-+ +-+       2 6
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c  + 4a c x
+--R              + 
+--R                        4     2   2
+--R                6a b c x  + 8a c x
+--R           /
+--R                                +---------------+
+--R                       2     2  |   4      2
+--R                (4a b x  + 8a )\|c x  + b x  + a
+--R              + 
+--R                            2  4         2     2  +-+
+--R                ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R     + 
+--R                        2 2          3   2            4         2 3    6
+--R               ((2304A a b  + 1536B a b)c  + (576A a b  + 384B a b )c)x
+--R             + 
+--R                        3           4  2           2 3          3 2    4
+--R               ((4608A a b + 3072B a )c  + (5760A a b  + 3840B a b )c)x
+--R             + 
+--R                        3 2          4     2           4           5
+--R               (13824A a b  + 9216B a b)c x  + (9216A a b + 6144B a )c
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                             3          4  3             2 3          3 2  2
+--R                   (- 1152A a b - 768B a )c  + (- 1728A a b  - 1152B a b )c
+--R                 + 
+--R                             5        2 4
+--R                   (- 72A a b  - 48B a b )c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          3 2          4   2             2 4          3 3    6
+--R               ((- 9216A a b  - 6144B a b)c  + (- 2304A a b  - 1536B a b )c)x
+--R             + 
+--R                          4           5  2              3 3          4 2    4
+--R               ((- 9216A a b - 6144B a )c  + (- 11520A a b  - 7680B a b )c)x
+--R             + 
+--R                          4 2           5     2             5           6
+--R               (- 18432A a b  - 12288B a b)c x  + (- 9216A a b - 6144B a )c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                            3   3             2 3          3 2  2
+--R                   - 2304A a b c  + (- 1152A a b  - 1152B a b )c
+--R                 + 
+--R                              5         2 4            6
+--R                   (- 144A a b  - 192B a b )c + 24B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            4 3             3 2          4   2
+--R                   - 4608A a c  + (- 6912A a b  - 2304B a b)c
+--R                 + 
+--R                             2 4          3 3           2 5
+--R                   (- 1440A a b  - 2688B a b )c + 240B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          4   2             3 3          4 2           3 4  2
+--R               (- 13824A a b c  + (- 3456A a b  - 6912B a b )c + 576B a b )x
+--R             + 
+--R                        5 2             4 2          5            4 3
+--R               - 9216A a c  + (- 2304A a b  - 4608B a b)c + 384B a b
+--R          *
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R         + 
+--R                          3 4           2 2         3   3
+--R                   1152A a c  + (2016A a b  + 576B a b)c
+--R                 + 
+--R                            4         2 3  2         6          5         7
+--R                   (504A a b  + 816B a b )c  + (18A b  - 36B a b )c - 3B b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          3   3           2 3          3 2  2
+--R                   9216A a b c  + (4608A a b  + 4608B a b )c
+--R                 + 
+--R                            5         2 4            6
+--R                   (576A a b  + 768B a b )c - 96B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          4 3            3 2          4   2
+--R                   9216A a c  + (13824A a b  + 4608B a b)c
+--R                 + 
+--R                           2 4          3 3           2 5
+--R                   (2880A a b  + 5376B a b )c - 480B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        4   2           3 3          4 2           3 4  2
+--R               (18432A a b c  + (4608A a b  + 9216B a b )c - 768B a b )x
+--R             + 
+--R                      5 2           4 2          5            4 3
+--R               9216A a c  + (2304A a b  + 4608B a b)c - 384B a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                    2 2          3   2            4         2 3            5  6
+--R           ((1536A a b  + 2048B a b)c  + (384A a b  + 704B a b )c + 48B a b )x
+--R         + 
+--R                    3           4  2           2 3          3 2           2 4  4
+--R           ((3072A a b + 4096B a )c  + (3840A a b  + 5504B a b )c + 480B a b )x
+--R         + 
+--R                    3 2           4             3 3  2           4           5
+--R           ((9216A a b  + 12288B a b)c + 1152B a b )x  + (6144A a b + 8192B a )c
+--R         + 
+--R                 4 2
+--R           768B a b
+--R      *
+--R                  +---------------+
+--R          +-+ +-+ |   4      2
+--R         \|a \|c \|c x  + b x  + a
+--R     + 
+--R                        3           4  3             2 3          3 2  2
+--R               (- 768A a b - 1024B a )c  + (- 1152A a b  - 1632B a b )c
+--R             + 
+--R                         5         2 4           6
+--R               (- 48A a b  - 208B a b )c - 6B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         3 2          4   2             2 4          3 3
+--R               (- 6144A a b  - 8192B a b)c  + (- 1536A a b  - 2816B a b )c
+--R             + 
+--R                       2 5
+--R               - 192B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         4           5  2             3 3           4 2
+--R               (- 6144A a b - 8192B a )c  + (- 7680A a b  - 11008B a b )c
+--R             + 
+--R                       3 4
+--R               - 960B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       4 2           5             4 3  2
+--R           ((- 12288A a b  - 16384B a b)c - 1536B a b )x
+--R         + 
+--R                     5           6           5 2
+--R           (- 6144A a b - 8192B a )c - 768B a b
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                 2   2         3   6         3 2        2 2   4         3     2
+--R           (3072a b c  + 768a b c)x  + (6144a c  + 7680a b c)x  + 18432a b c x
+--R         + 
+--R                 4
+--R           12288a c
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                   2 3          2 2      4   8            2   2          3   6
+--R           (- 1536a c  - 2304a b c  - 96b c)x  + (- 12288a b c  - 3072a b c)x
+--R         + 
+--R                    3 2         2 2   4         3     2         4
+--R           (- 12288a c  - 15360a b c)x  - 24576a b c x  - 12288a c
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 2452
+
+--S 2453 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2453
+
+--S 2454 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        2 2          3   2            4         2 3    6
+--R               ((2304A a b  + 1536B a b)c  + (576A a b  + 384B a b )c)x
+--R             + 
+--R                        3           4  2           2 3          3 2    4
+--R               ((4608A a b + 3072B a )c  + (5760A a b  + 3840B a b )c)x
+--R             + 
+--R                        3 2          4     2           4           5
+--R               (13824A a b  + 9216B a b)c x  + (9216A a b + 6144B a )c
+--R          *
+--R                            +---------------+
+--R              +---+ +-+ +-+ |   4      2
+--R             \|- c \|a \|c \|c x  + b x  + a
+--R         + 
+--R                             3          4  3             2 3          3 2  2
+--R                   (- 1152A a b - 768B a )c  + (- 1728A a b  - 1152B a b )c
+--R                 + 
+--R                             5        2 4
+--R                   (- 72A a b  - 48B a b )c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          3 2          4   2             2 4          3 3    6
+--R               ((- 9216A a b  - 6144B a b)c  + (- 2304A a b  - 1536B a b )c)x
+--R             + 
+--R                          4           5  2              3 3          4 2    4
+--R               ((- 9216A a b - 6144B a )c  + (- 11520A a b  - 7680B a b )c)x
+--R             + 
+--R                          4 2           5     2             5           6
+--R               (- 18432A a b  - 12288B a b)c x  + (- 9216A a b - 6144B a )c
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                        2 2          3   2            4         2 3    6
+--R               ((2304A a b  + 1536B a b)c  + (576A a b  + 384B a b )c)x
+--R             + 
+--R                        3           4  2           2 3          3 2    4
+--R               ((4608A a b + 3072B a )c  + (5760A a b  + 3840B a b )c)x
+--R             + 
+--R                        3 2          4     2           4           5
+--R               (13824A a b  + 9216B a b)c x  + (9216A a b + 6144B a )c
+--R          *
+--R                            +---------------+
+--R              +---+ +-+ +-+ |   4      2
+--R             \|- c \|a \|c \|c x  + b x  + a
+--R         + 
+--R                             3          4  3             2 3          3 2  2
+--R                   (- 1152A a b - 768B a )c  + (- 1728A a b  - 1152B a b )c
+--R                 + 
+--R                             5        2 4
+--R                   (- 72A a b  - 48B a b )c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          3 2          4   2             2 4          3 3    6
+--R               ((- 9216A a b  - 6144B a b)c  + (- 2304A a b  - 1536B a b )c)x
+--R             + 
+--R                          4           5  2              3 3          4 2    4
+--R               ((- 9216A a b - 6144B a )c  + (- 11520A a b  - 7680B a b )c)x
+--R             + 
+--R                          4 2           5     2             5           6
+--R               (- 18432A a b  - 12288B a b)c x  + (- 9216A a b - 6144B a )c
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                            3   3             2 3          3 2  2
+--R                   - 2304A a b c  + (- 1152A a b  - 1152B a b )c
+--R                 + 
+--R                              5         2 4            6
+--R                   (- 144A a b  - 192B a b )c + 24B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            4 3             3 2          4   2
+--R                   - 4608A a c  + (- 6912A a b  - 2304B a b)c
+--R                 + 
+--R                             2 4          3 3           2 5
+--R                   (- 1440A a b  - 2688B a b )c + 240B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          4   2             3 3          4 2           3 4  2
+--R               (- 13824A a b c  + (- 3456A a b  - 6912B a b )c + 576B a b )x
+--R             + 
+--R                        5 2             4 2          5            4 3
+--R               - 9216A a c  + (- 2304A a b  - 4608B a b)c + 384B a b
+--R          *
+--R                    +---------------+
+--R              +---+ |   4      2
+--R             \|- c \|c x  + b x  + a
+--R         + 
+--R                          3 4           2 2         3   3
+--R                   1152A a c  + (2016A a b  + 576B a b)c
+--R                 + 
+--R                            4         2 3  2         6          5         7
+--R                   (504A a b  + 816B a b )c  + (18A b  - 36B a b )c - 3B b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          3   3           2 3          3 2  2
+--R                   9216A a b c  + (4608A a b  + 4608B a b )c
+--R                 + 
+--R                            5         2 4            6
+--R                   (576A a b  + 768B a b )c - 96B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          4 3            3 2          4   2
+--R                   9216A a c  + (13824A a b  + 4608B a b)c
+--R                 + 
+--R                           2 4          3 3           2 5
+--R                   (2880A a b  + 5376B a b )c - 480B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        4   2           3 3          4 2           3 4  2
+--R               (18432A a b c  + (4608A a b  + 9216B a b )c - 768B a b )x
+--R             + 
+--R                      5 2           4 2          5            4 3
+--R               9216A a c  + (2304A a b  + 4608B a b)c - 384B a b
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                          3   3           2 3          3 2  2
+--R                   4608A a b c  + (2304A a b  + 2304B a b )c
+--R                 + 
+--R                            5         2 4            6
+--R                   (288A a b  + 384B a b )c - 48B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          4 3            3 2          4   2
+--R                   9216A a c  + (13824A a b  + 4608B a b)c
+--R                 + 
+--R                           2 4          3 3           2 5
+--R                   (2880A a b  + 5376B a b )c - 480B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        4   2           3 3           4 2            3 4  2
+--R               (27648A a b c  + (6912A a b  + 13824B a b )c - 1152B a b )x
+--R             + 
+--R                       5 2           4 2          5            4 3
+--R               18432A a c  + (4608A a b  + 9216B a b)c - 768B a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|c \|c x  + b x  + a
+--R         + 
+--R                            3 4             2 2          3   3
+--R                   - 2304A a c  + (- 4032A a b  - 1152B a b)c
+--R                 + 
+--R                             4          2 3  2           6          5         7
+--R                 (- 1008A a b  - 1632B a b )c  + (- 36A b  + 72B a b )c + 6B b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             3   3             2 3          3 2  2
+--R                   - 18432A a b c  + (- 9216A a b  - 9216B a b )c
+--R                 + 
+--R                               5          2 4             6
+--R                   (- 1152A a b  - 1536B a b )c + 192B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             4 3              3 2          4   2
+--R                   - 18432A a c  + (- 27648A a b  - 9216B a b)c
+--R                 + 
+--R                             2 4           3 3           2 5
+--R                   (- 5760A a b  - 10752B a b )c + 960B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          4   2             3 3           4 2            3 4  2
+--R               (- 36864A a b c  + (- 9216A a b  - 18432B a b )c + 1536B a b )x
+--R             + 
+--R                         5 2             4 2          5            4 3
+--R               - 18432A a c  + (- 4608A a b  - 9216B a b)c + 768B a b
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                         +---------------+
+--R               +---+ +-+ |   4      2          +---+
+--R              \|- c \|a \|c x  + b x  + a  - a\|- c
+--R         atan(--------------------------------------)
+--R                                2 +-+
+--R                             c x \|a
+--R     + 
+--R                    2 2          3   2            4         2 3            5  6
+--R           ((1536A a b  + 2048B a b)c  + (384A a b  + 704B a b )c + 48B a b )x
+--R         + 
+--R                    3           4  2           2 3          3 2           2 4  4
+--R           ((3072A a b + 4096B a )c  + (3840A a b  + 5504B a b )c + 480B a b )x
+--R         + 
+--R                    3 2           4             3 3  2           4           5
+--R           ((9216A a b  + 12288B a b)c + 1152B a b )x  + (6144A a b + 8192B a )c
+--R         + 
+--R                 4 2
+--R           768B a b
+--R      *
+--R                        +---------------+
+--R          +---+ +-+ +-+ |   4      2
+--R         \|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                        3           4  3             2 3          3 2  2
+--R               (- 768A a b - 1024B a )c  + (- 1152A a b  - 1632B a b )c
+--R             + 
+--R                         5         2 4           6
+--R               (- 48A a b  - 208B a b )c - 6B a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         3 2          4   2             2 4          3 3
+--R               (- 6144A a b  - 8192B a b)c  + (- 1536A a b  - 2816B a b )c
+--R             + 
+--R                       2 5
+--R               - 192B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         4           5  2             3 3           4 2
+--R               (- 6144A a b - 8192B a )c  + (- 7680A a b  - 11008B a b )c
+--R             + 
+--R                       3 4
+--R               - 960B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       4 2           5             4 3  2
+--R           ((- 12288A a b  - 16384B a b)c - 1536B a b )x
+--R         + 
+--R                     5           6           5 2
+--R           (- 6144A a b - 8192B a )c - 768B a b
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                 2   2         3   6         3 2        2 2   4         3     2
+--R           (3072a b c  + 768a b c)x  + (6144a c  + 7680a b c)x  + 18432a b c x
+--R         + 
+--R                 4
+--R           12288a c
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                   2 3          2 2      4   8            2   2          3   6
+--R           (- 1536a c  - 2304a b c  - 96b c)x  + (- 12288a b c  - 3072a b c)x
+--R         + 
+--R                    3 2         2 2   4         3     2         4
+--R           (- 12288a c  - 15360a b c)x  - 24576a b c x  - 12288a c
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 2454
+
+--S 2455 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2455
+
+)clear all
+
+--S 2456 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^5
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        5
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 2456
+
+--S 2457 of 3139
+r0:=-1/4*(A-B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^4-3/16*(4*a*b*B+A*(b^2+4*a*c))*_
+   atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)+_
+   3/16*(b^2*B+4*A*b*c+4*a*B*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/sqrt(c)-3/8*(A*b+2*a*B-(b*B+2*A*c)*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                                                          2
+--R                        2            4 +-+             b x  + 2a
+--R       (- 12A a c - 3A b  - 12B a b)x \|c atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|a \|c x  + b x  + a
+--R     + 
+--R                                                        2
+--R                               2  4 +-+             2c x  + b
+--R       ((12A b + 12B a)c + 3B b )x \|a atanh(-----------------------)
+--R                                                   +---------------+
+--R                                               +-+ |   4      2
+--R                                             2\|c \|c x  + b x  + a
+--R     + 
+--R                6                  4                    2         +-+ +-+
+--R         (4B c x  + (8A c + 10B b)x  + (- 10A b - 8B a)x  - 4A a)\|a \|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R  /
+--R        4 +-+ +-+
+--R     16x \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 2457
+
+--S 2458 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            3   2          2 3          3 2            5
+--R                     1536A a b c  + (768A a b  + 1536B a b )c + 96A a b
+--R                   + 
+--R                           2 4
+--R                     384B a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                            4 2           3 2          4            2 4
+--R                     3072A a c  + (4608A a b  + 3072B a b)c + 960A a b
+--R                   + 
+--R                            3 3
+--R                     3840B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                         4             3 3          4 2  6
+--R                 (9216A a b c + 2304A a b  + 9216B a b )x
+--R               + 
+--R                         5           4 2          5   4
+--R                 (6144A a c + 1536A a b  + 6144B a b)x
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|c \|c x  + b x  + a
+--R           + 
+--R                             3 3             2 2         3   2
+--R                     - 768A a c  + (- 1344A a b  - 768B a b)c
+--R                   + 
+--R                                4          2 3          6          5
+--R                     (- 336A a b  - 1152B a b )c - 12A b  - 48B a b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                              3   2             2 3          3 2             5
+--R                     - 6144A a b c  + (- 3072A a b  - 6144B a b )c - 384A a b
+--R                   + 
+--R                              2 4
+--R                     - 1536B a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              4 2             3 2          4             2 4
+--R                     - 6144A a c  + (- 9216A a b  - 6144B a b)c - 1920A a b
+--R                   + 
+--R                              3 3
+--R                     - 7680B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                            4             3 3           4 2  6
+--R                 (- 12288A a b c - 3072A a b  - 12288B a b )x
+--R               + 
+--R                           5           4 2          5   4
+--R                 (- 6144A a c - 1536A a b  - 6144B a b)x
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                             2 2          3   2            4         2 3
+--R                     (1536A a b  + 1536B a b)c  + (384A a b  + 768B a b )c
+--R                   + 
+--R                            5
+--R                     96B a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                             3           4  2           2 3          3 2
+--R                     (3072A a b + 3072B a )c  + (3840A a b  + 4608B a b )c
+--R                   + 
+--R                           2 4
+--R                     960B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                          3 2          4             3 3  6
+--R                 ((9216A a b  + 9216B a b)c + 2304B a b )x
+--R               + 
+--R                          4           5            4 2  4
+--R                 ((6144A a b + 6144B a )c + 1536B a b )x
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                          3          4  3             2 3          3 2  2
+--R                 (- 768A a b - 768B a )c  + (- 1152A a b  - 1344B a b )c
+--R               + 
+--R                           5         2 4            6
+--R                 (- 48A a b  - 336B a b )c - 12B a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           3 2          4   2             2 4          3 3
+--R                 (- 6144A a b  - 6144B a b)c  + (- 1536A a b  - 3072B a b )c
+--R               + 
+--R                         2 5
+--R                 - 384B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           4           5  2             3 3          4 2
+--R                 (- 6144A a b - 6144B a )c  + (- 7680A a b  - 9216B a b )c
+--R               + 
+--R                          3 4
+--R                 - 1920B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                         4 2           5             4 3  6
+--R             ((- 12288A a b  - 12288B a b)c - 3072B a b )x
+--R           + 
+--R                        5           6            5 2  4
+--R             ((- 6144A a b - 6144B a )c - 1536B a b )x
+--R        *
+--R           log
+--R                            4         2     2  +-+            4         2  +-+
+--R                    ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                           6              2  4         2     2  +-+ +-+
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c
+--R                + 
+--R                      2 6           4     2   2
+--R                  4a c x  + 6a b c x  + 8a c x
+--R             /
+--R                                  +---------------+
+--R                         2     2  |   4      2
+--R                  (4a b x  + 8a )\|c x  + b x  + a
+--R                + 
+--R                              2  4         2     2  +-+
+--R                  ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R       + 
+--R                      3 3         2 2 2          4   14
+--R             (- 256B a c  - 384B a b c  - 16B a b c)x
+--R           + 
+--R                         3 3            2 2          3   2
+--R                 - 512A a c  + (- 768A a b  - 2688B a b)c
+--R               + 
+--R                           4          2 3            5
+--R                 (- 32A a b  - 1472B a b )c - 40B a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           3           4  2           2 3          3 2
+--R                 (- 2432A a b - 1536B a )c  + (- 96A a b  - 5888B a b )c
+--R               + 
+--R                          5         2 4
+--R                 - 32A a b  - 992B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            4 2           3 2          4            2 4
+--R                   - 1792A a c  + (2368A a b  - 3072B a b)c + 576A a b
+--R                 + 
+--R                            3 3
+--R                   - 2816B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                      4           5            3 3          4 2  6
+--R             ((5120A a b + 2048B a )c + 5184A a b  + 1024B a b )x
+--R           + 
+--R                     5            4 2          5   4           5           6  2
+--R             (2048A a c + 11648A a b  + 7168B a b)x  + (9216A a b + 4096B a )x
+--R           + 
+--R                    6
+--R             2048A a
+--R        *
+--R                +---------------+
+--R            +-+ |   4      2
+--R           \|c \|c x  + b x  + a
+--R       + 
+--R                    2   3           3 2  16
+--R             (512B a b c  + 128B a b c )x
+--R           + 
+--R                         2           3  3            3          2 2  2
+--R                 (1024A a b + 1024B a )c  + (256A a b  + 3072B a b )c
+--R               + 
+--R                         4
+--R                 448B a b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                        3 3           2 2          3   2
+--R                 1536A a c  + (1680A a b  + 5632B a b)c
+--R               + 
+--R                          4          2 3         6           5
+--R                 (120A a b  + 4864B a b )c + 9A b  + 288B a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                         3           4  2             2 3          3 2
+--R                 (2048A a b + 1024B a )c  + (- 1664A a b  + 8192B a b )c
+--R               + 
+--R                          5          2 4
+--R                 - 32A a b  + 2240B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          4 2             3 2         4             2 4
+--R                   1024A a c  + (- 8576A a b  - 512B a b)c - 2208A a b
+--R                 + 
+--R                          3 3
+--R                   2944B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                         4           5            3 3          4 2  6
+--R             ((- 10240A a b - 4096B a )c - 9984A a b  - 4096B a b )x
+--R           + 
+--R                       5            4 2          5   4
+--R             (- 3072A a c - 16000A a b  - 9216B a b)x
+--R           + 
+--R                        5           6  2          6
+--R             (- 10240A a b - 4096B a )x  - 2048A a
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                   2            3  10         3         2 2  8         3   6
+--R             (2048a b c + 512a b )x   + (4096a c + 5120a b )x  + 12288a b x
+--R           + 
+--R                  4 4
+--R             8192a x
+--R        *
+--R                    +---------------+
+--R            +-+ +-+ |   4      2
+--R           \|a \|c \|c x  + b x  + a
+--R       + 
+--R                     3 2        2 2         4  12           3           2 3  10
+--R             (- 1024a c  - 1536a b c - 64a b )x   + (- 8192a b c - 2048a b )x
+--R           + 
+--R                     4          3 2  8         4   6        5 4
+--R             (- 8192a c - 10240a b )x  - 16384a b x  - 8192a x
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                            3   2          2 3          3 2            5
+--R                     1536A a b c  + (768A a b  + 1536B a b )c + 96A a b
+--R                   + 
+--R                           2 4
+--R                     384B a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                            4 2           3 2          4            2 4
+--R                     3072A a c  + (4608A a b  + 3072B a b)c + 960A a b
+--R                   + 
+--R                            3 3
+--R                     3840B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                         4             3 3          4 2  6
+--R                 (9216A a b c + 2304A a b  + 9216B a b )x
+--R               + 
+--R                         5           4 2          5   4
+--R                 (6144A a c + 1536A a b  + 6144B a b)x
+--R            *
+--R                      +---------------+
+--R                +---+ |   4      2
+--R               \|- c \|c x  + b x  + a
+--R           + 
+--R                             3 3             2 2         3   2
+--R                     - 768A a c  + (- 1344A a b  - 768B a b)c
+--R                   + 
+--R                                4          2 3          6          5
+--R                     (- 336A a b  - 1152B a b )c - 12A b  - 48B a b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                              3   2             2 3          3 2             5
+--R                     - 6144A a b c  + (- 3072A a b  - 6144B a b )c - 384A a b
+--R                   + 
+--R                              2 4
+--R                     - 1536B a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              4 2             3 2          4             2 4
+--R                     - 6144A a c  + (- 9216A a b  - 6144B a b)c - 1920A a b
+--R                   + 
+--R                              3 3
+--R                     - 7680B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                            4             3 3           4 2  6
+--R                 (- 12288A a b c - 3072A a b  - 12288B a b )x
+--R               + 
+--R                           5           4 2          5   4
+--R                 (- 6144A a c - 1536A a b  - 6144B a b)x
+--R            *
+--R                +---+ +-+
+--R               \|- c \|a
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                             2 2          3   2            4          2 3
+--R                     (3072A a b  + 3072B a b)c  + (768A a b  + 1536B a b )c
+--R                   + 
+--R                             5
+--R                     192B a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                             3           4  2           2 3          3 2
+--R                     (6144A a b + 6144B a )c  + (7680A a b  + 9216B a b )c
+--R                   + 
+--R                            2 4
+--R                     1920B a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                           3 2           4             3 3  6
+--R                 ((18432A a b  + 18432B a b)c + 4608B a b )x
+--R               + 
+--R                           4            5            4 2  4
+--R                 ((12288A a b + 12288B a )c + 3072B a b )x
+--R            *
+--R                    +---------------+
+--R                +-+ |   4      2
+--R               \|a \|c x  + b x  + a
+--R           + 
+--R                           3           4  3             2 3          3 2  2
+--R                 (- 1536A a b - 1536B a )c  + (- 2304A a b  - 2688B a b )c
+--R               + 
+--R                           5         2 4            6
+--R                 (- 96A a b  - 672B a b )c - 24B a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            3 2           4   2             2 4          3 3
+--R                 (- 12288A a b  - 12288B a b)c  + (- 3072A a b  - 6144B a b )c
+--R               + 
+--R                         2 5
+--R                 - 768B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            4            5  2              3 3           4 2
+--R                 (- 12288A a b - 12288B a )c  + (- 15360A a b  - 18432B a b )c
+--R               + 
+--R                          3 4
+--R                 - 3840B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                         4 2           5             4 3  6
+--R             ((- 24576A a b  - 24576B a b)c - 6144B a b )x
+--R           + 
+--R                         5            6            5 2  4
+--R             ((- 12288A a b - 12288B a )c - 3072B a b )x
+--R        *
+--R                           +---------------+
+--R                 +---+ +-+ |   4      2          +---+
+--R                \|- c \|a \|c x  + b x  + a  - a\|- c
+--R           atan(--------------------------------------)
+--R                                  2 +-+
+--R                               c x \|a
+--R       + 
+--R                      3 3         2 2 2          4   14
+--R             (- 256B a c  - 384B a b c  - 16B a b c)x
+--R           + 
+--R                         3 3            2 2          3   2
+--R                 - 512A a c  + (- 768A a b  - 2688B a b)c
+--R               + 
+--R                           4          2 3            5
+--R                 (- 32A a b  - 1472B a b )c - 40B a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           3           4  2           2 3          3 2
+--R                 (- 2432A a b - 1536B a )c  + (- 96A a b  - 5888B a b )c
+--R               + 
+--R                          5         2 4
+--R                 - 32A a b  - 992B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            4 2           3 2          4            2 4
+--R                   - 1792A a c  + (2368A a b  - 3072B a b)c + 576A a b
+--R                 + 
+--R                            3 3
+--R                   - 2816B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                      4           5            3 3          4 2  6
+--R             ((5120A a b + 2048B a )c + 5184A a b  + 1024B a b )x
+--R           + 
+--R                     5            4 2          5   4           5           6  2
+--R             (2048A a c + 11648A a b  + 7168B a b)x  + (9216A a b + 4096B a )x
+--R           + 
+--R                    6
+--R             2048A a
+--R        *
+--R                  +---------------+
+--R            +---+ |   4      2
+--R           \|- c \|c x  + b x  + a
+--R       + 
+--R                    2   3           3 2  16
+--R             (512B a b c  + 128B a b c )x
+--R           + 
+--R                         2           3  3            3          2 2  2
+--R                 (1024A a b + 1024B a )c  + (256A a b  + 3072B a b )c
+--R               + 
+--R                         4
+--R                 448B a b c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                        3 3           2 2          3   2
+--R                 1536A a c  + (1680A a b  + 5632B a b)c
+--R               + 
+--R                          4          2 3         6           5
+--R                 (120A a b  + 4864B a b )c + 9A b  + 288B a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                         3           4  2             2 3          3 2
+--R                 (2048A a b + 1024B a )c  + (- 1664A a b  + 8192B a b )c
+--R               + 
+--R                          5          2 4
+--R                 - 32A a b  + 2240B a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          4 2             3 2         4             2 4
+--R                   1024A a c  + (- 8576A a b  - 512B a b)c - 2208A a b
+--R                 + 
+--R                          3 3
+--R                   2944B a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                         4           5            3 3          4 2  6
+--R             ((- 10240A a b - 4096B a )c - 9984A a b  - 4096B a b )x
+--R           + 
+--R                       5            4 2          5   4
+--R             (- 3072A a c - 16000A a b  - 9216B a b)x
+--R           + 
+--R                        5           6  2          6
+--R             (- 10240A a b - 4096B a )x  - 2048A a
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                   2            3  10         3         2 2  8         3   6
+--R             (2048a b c + 512a b )x   + (4096a c + 5120a b )x  + 12288a b x
+--R           + 
+--R                  4 4
+--R             8192a x
+--R        *
+--R                      +---------------+
+--R            +---+ +-+ |   4      2
+--R           \|- c \|a \|c x  + b x  + a
+--R       + 
+--R                     3 2        2 2         4  12           3           2 3  10
+--R             (- 1024a c  - 1536a b c - 64a b )x   + (- 8192a b c - 2048a b )x
+--R           + 
+--R                     4          3 2  8         4   6        5 4
+--R             (- 8192a c - 10240a b )x  - 16384a b x  - 8192a x
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2458
+
+--S 2459 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                 +---------------+
+--R                                             +-+ |   4      2           2
+--R                       2            +-+    2\|a \|c x  + b x  + a  - b x  - 2a
+--R       (48A a c + 12A b  + 48B a b)\|c log(-----------------------------------)
+--R                                                           2 +-+
+--R                                                         2x \|a
+--R     + 
+--R                                  2  +-+
+--R         ((48A b + 48B a)c + 12B b )\|a
+--R      *
+--R         log
+--R                          4         2     2  +-+            4         2  +-+
+--R                  ((4a c x  + 4a b x  + 8a )\|c  + (- 2b c x  - 8a c x )\|a )
+--R               *
+--R                   +---------------+
+--R                   |   4      2
+--R                  \|c x  + b x  + a
+--R              + 
+--R                         6              2  4         2     2  +-+ +-+       2 6
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x  - 8a )\|a \|c  + 4a c x
+--R              + 
+--R                        4     2   2
+--R                6a b c x  + 8a c x
+--R           /
+--R                                +---------------+
+--R                       2     2  |   4      2
+--R                (4a b x  + 8a )\|c x  + b x  + a
+--R              + 
+--R                            2  4         2     2  +-+
+--R                ((- 4a c - b )x  - 8a b x  - 8a )\|a
+--R     + 
+--R                                                       2
+--R                       2            +-+             b x  + 2a
+--R       (48A a c + 12A b  + 48B a b)\|c atanh(-----------------------)
+--R                                                   +---------------+
+--R                                               +-+ |   4      2
+--R                                             2\|a \|c x  + b x  + a
+--R     + 
+--R                                                         2
+--R                                  2  +-+             2c x  + b
+--R       ((- 48A b - 48B a)c - 12B b )\|a atanh(-----------------------)
+--R                                                    +---------------+
+--R                                                +-+ |   4      2
+--R                                              2\|c \|c x  + b x  + a
+--R     + 
+--R                      2            +-+
+--R       (32A a c - 9A b  + 32B a b)\|c
+--R  /
+--R        +-+ +-+
+--R     64\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 2459
+
+--S 2460 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2460
+
+--S 2461 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         2            +---+ +-+
+--R         (48A a c + 12A b  + 48B a b)\|- c \|c
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                                                             2
+--R                       2            +---+ +-+             b x  + 2a
+--R       (48A a c + 12A b  + 48B a b)\|- c \|c atanh(-----------------------)
+--R                                                         +---------------+
+--R                                                     +-+ |   4      2
+--R                                                   2\|a \|c x  + b x  + a
+--R     + 
+--R                                                               2
+--R                                  2  +---+ +-+             2c x  + b
+--R       ((- 48A b - 48B a)c - 12B b )\|- c \|a atanh(-----------------------)
+--R                                                          +---------------+
+--R                                                      +-+ |   4      2
+--R                                                    2\|c \|c x  + b x  + a
+--R     + 
+--R                                  2  +-+ +-+
+--R         ((96A b + 96B a)c + 24B b )\|a \|c
+--R      *
+--R                         +---------------+
+--R               +---+ +-+ |   4      2          +---+
+--R              \|- c \|a \|c x  + b x  + a  - a\|- c
+--R         atan(--------------------------------------)
+--R                                2 +-+
+--R                             c x \|a
+--R     + 
+--R                      2            +---+ +-+
+--R       (32A a c - 9A b  + 32B a b)\|- c \|c
+--R  /
+--R        +---+ +-+ +-+
+--R     64\|- c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 2461
+
+--S 2462 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2462
+
+)clear all
+
+--S 2463 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2463
+
+--S 2464 of 3139
+--r0:=1/63*x*(3*(b*B+3*A*c)+7*B*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c-_
+---  1/315*x*(4*b^3*B-9*A*b^2*c-9*a*b*B*c-90*a*A*c^2+3*c*(4*b^2*B-_
+---  9*A*b*c-14*a*B*c)*x^2)*sqrt(a+b*x^2+c*x^4)/c^2+1/630*(8*b^4*B-_
+---  18*A*b^3*c-57*a*b^2*B*c+144*a*A*b*c^2+84*a^2*B*c^2)*_
+---  elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*_
+---  sqrt(a+b*x^2+c*x^4))-1/630*elliptic_f(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*(8*b^4*B-18*A*b^3*c-_
+---  57*a*b^2*B*c+144*a*A*b*c^2+84*a^2*B*c^2-2*a*c*(4*b^3*B-9*A*b^2*c-_
+---  24*a*b*B*c+180*a*A*c^2)/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 2464
+
+--S 2465 of 3139
+--a0:=integrate(t0,x)
+--E 2465
+
+--S 2466 of 3139
+--m0:=a0-r0
+--E 2466
+
+--S 2467 of 3139
+--d0:=D(m0,x)
+--E 2467
+
+)clear all
+
+--S 2468 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^2
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        2
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 2468
+
+--S 2469 of 3139
+--r0:=-1/7*(7*A-B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x+1/35*x*(b^2*B+49*A*b*c+_
+---  10*a*B*c+3*c*(b*B+14*A*c)*x^2)*sqrt(a+b*x^2+c*x^4)/c-1/70*(2*b^3*B-_
+---  7*A*b^2*c-16*a*b*B*c-84*a*A*c^2)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/_
+---  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+---  (b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+---  (c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))+1/70*elliptic_f(asin(x*_
+---  sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*(2*b^3*B-7*A*b^2*c-16*a*b*B*c-_
+---  84*a*A*c^2-2*a*c*(b^2*B-56*A*b*c-20*a*B*c)/(b+sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 2469
+
+--S 2470 of 3139
+--a0:=integrate(t0,x)
+--E 2470
+
+--S 2471 of 3139
+--m0:=a0-r0
+--E 2471
+
+--S 2472 of 3139
+--d0:=D(m0,x)
+--E 2472
+
+)clear all
+
+--S 2473 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^4
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        4
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 2473
+
+--S 2474 of 3139
+--r0:=-1/15*(5*A-3*B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^3-1/15*(3*(5*A*b+6*a*B)-_
+---  (3*b*B+10*A*c)*x^2)*sqrt(a+b*x^2+c*x^4)/x+1/30*(3*b^2*B+40*A*b*c+_
+---  36*a*B*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+_
+---  c*x^4))-1/30*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-_
+---  4*a*c))*(3*b^2*B+40*A*b*c+36*a*B*c-2*c*(24*a*b*B+5*A*(3*b^2+4*a*c))/_
+---  (b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+---  (c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 2474
+
+--S 2475 of 3139
+--a0:=integrate(t0,x)
+--E 2475
+
+--S 2476 of 3139
+--m0:=a0-r0
+--E 2476
+
+--S 2477 of 3139
+--d0:=D(m0,x)
+--E 2477
+
+)clear all
+
+--S 2478 of 3139
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^6
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        6
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 2478
+
+--S 2479 of 3139
+--r0:=-1/15*(3*A-5*B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^5-1/15*(40*a*b*B+3*A*_
+---  (b^2+12*a*c))*sqrt(a+b*x^2+c*x^4)/(a*x)-1/15*(3*A*b+10*a*B-3*(5*b*B+_
+---  6*A*c)*x^2)*sqrt(a+b*x^2+c*x^4)/x^3+1/30*(40*a*b*B+3*A*(b^2+12*a*c))*_
+---  elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*_
+---  sqrt(a+b*x^2+c*x^4))-1/30*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+---  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+---  (b+sqrt(b^2-4*a*c))*(40*a*b*B+3*A*(b^2+12*a*c)-2*a*(15*b^2*B+_
+---  24*A*b*c+20*a*B*c)/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 2479
+
+--S 2480 of 3139
+--a0:=integrate(t0,x)
+--E 2480
+
+--S 2481 of 3139
+--m0:=a0-r0
+--E 2481
+
+--S 2482 of 3139
+--d0:=D(m0,x)
+--E 2482
+
+)clear all
+
+--S 2483 of 3139
+t0:=x^5*(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                       7      5
+--R                    B x  + A x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2483
+
+--S 2484 of 3139
+r0:=-1/4*(3*b*B-2*A*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/_
+   c^(5/2)-x^4*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+_
+   c*x^4))+1/2*(3*b^2*B-4*A*b*c-4*a*B*c)*sqrt(a+b*x^2+c*x^4)/(c^2*_
+   (b^2-4*a*c))+(A*b-2*a*B-(b*B-2*A*c)*x^2)*sqrt(a+b*x^2+c*x^4)/(c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                                  +---------------+
+--R                2          2                   3  |   4      2
+--R         (8A a c  + (- 2A b  - 12B a b)c + 3B b )\|c x  + b x  + a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                  2       2   4            2        2                   3  2
+--R           (8B a c  - 2B b c)x  + (- 8A a c  + (4A b  + 20B a b)c - 6B b )x
+--R         + 
+--R                          2           2
+--R           (4A a b + 16B a )c - 6B a b
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                          +---------------+
+--R           3     2 2  +-+ |   4      2
+--R     (16a c  - 4b c )\|c \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2484
+
+--S 2485 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        2        2                   3  4
+--R                 (8A a c  + (2A b  - 12B a b)c - 3B b )x
+--R               + 
+--R                                     2  2        2         2
+--R                 (16A a b c - 24B a b )x  + 16A a c - 24B a b
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                          2        2   6
+--R                 (- 8A b c  + 12B b c)x
+--R               + 
+--R                           2          2                    3  4
+--R                 (- 16A a c  + (- 8A b  + 24B a b)c + 12B b )x
+--R               + 
+--R                                       2  2        2         2
+--R                 (- 24A a b c + 36B a b )x  - 16A a c + 24B a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                      6                   2  4                       2  +-+ +-+
+--R           (- 8B b c x  + (12A b c - 18B b )x  + (16A a c - 24B a b)x )\|a \|c
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                    2       2   8            2          2                   3  6
+--R             (8B a c  + 2B b c)x  + (- 8A a c  + (- 4A b  + 20B a b)c + 6B b )x
+--R           + 
+--R                                   2  4           2         2   2
+--R             (- 20A a b c + 30B a b )x  + (- 16A a c + 24B a b)x
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                                                        +---------------+
+--R                3     2 2  4          2 2      2 2  +-+ |   4      2
+--R         ((16a c  + 4b c )x  + 32a b c x  + 32a c )\|c \|c x  + b x  + a
+--R       + 
+--R                 3 6           3      2 2  4          2 2      2 2  +-+ +-+
+--R         (- 16b c x  + (- 32a c  - 16b c )x  - 48a b c x  - 32a c )\|a \|c
+--R     ,
+--R
+--R                        2        2                   3  4
+--R                 (8A a c  + (2A b  - 12B a b)c - 3B b )x
+--R               + 
+--R                                     2  2        2         2
+--R                 (16A a b c - 24B a b )x  + 16A a c - 24B a b
+--R            *
+--R                +---------------+
+--R                |   4      2
+--R               \|c x  + b x  + a
+--R           + 
+--R                          2        2   6
+--R                 (- 8A b c  + 12B b c)x
+--R               + 
+--R                           2          2                    3  4
+--R                 (- 16A a c  + (- 8A b  + 24B a b)c + 12B b )x
+--R               + 
+--R                                       2  2        2         2
+--R                 (- 24A a b c + 36B a b )x  - 16A a c + 24B a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                      6                 2  4                      2  +---+ +-+
+--R           (- 4B b c x  + (6A b c - 9B b )x  + (8A a c - 12B a b)x )\|- c \|a
+--R        *
+--R            +---------------+
+--R            |   4      2
+--R           \|c x  + b x  + a
+--R       + 
+--R                    2      2   8            2          2                   3  6
+--R             (4B a c  + B b c)x  + (- 4A a c  + (- 2A b  + 10B a b)c + 3B b )x
+--R           + 
+--R                                   2  4          2         2   2
+--R             (- 10A a b c + 15B a b )x  + (- 8A a c + 12B a b)x
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                                                         +---------------+
+--R               3     2 2  4          2 2      2 2  +---+ |   4      2
+--R         ((8a c  + 2b c )x  + 16a b c x  + 16a c )\|- c \|c x  + b x  + a
+--R       + 
+--R                3 6           3     2 2  4          2 2      2 2  +---+ +-+
+--R         (- 8b c x  + (- 16a c  - 8b c )x  - 24a b c x  - 16a c )\|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2485
+
+--S 2486 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         2          3          2          4  2        2 2
+--R               (32A a b c  + (- 8A b  - 48B a b )c + 12B b )x  + 64A a c
+--R             + 
+--R                         2        2             3
+--R               (- 16A a b  - 96B a b)c + 24B a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                   2 3        2   2       4        5  4
+--R           (- 32A a c  + 48B a b c  + 2A b c - 3B b )x
+--R         + 
+--R                   2   2           3        2 2            4  2        3 2
+--R           (- 64A a b c  + (16A a b  + 96B a b )c - 24B a b )x  - 64A a c
+--R         + 
+--R                 2 2        3           2 3
+--R           (16A a b  + 96B a b)c - 24B a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                           2        3          2          4  2        2 2
+--R               (- 32A a b c  + (8A b  + 48B a b )c - 12B b )x  - 64A a c
+--R             + 
+--R                       2        2             3
+--R               (16A a b  + 96B a b)c - 24B a b
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                 2 3        2   2       4        5  4
+--R           (32A a c  - 48B a b c  - 2A b c + 3B b )x
+--R         + 
+--R                 2   2             3        2 2            4  2        3 2
+--R           (64A a b c  + (- 16A a b  - 96B a b )c + 24B a b )x  + 64A a c
+--R         + 
+--R                   2 2        3           2 3
+--R           (- 16A a b  - 96B a b)c + 24B a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                      2        2             3  2         2          3
+--R             ((16A a b  + 64B a b)c - 24B a b )x  + (32A a b + 128B a )c
+--R           + 
+--R                    2 2
+--R             - 48B a b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R     + 
+--R                              2  2          3         2         4  4
+--R           ((- 16A a b - 64B a )c  + (- 4A b  + 8B a b )c + 6B b )x
+--R         + 
+--R                      2         2             3  2           2          3
+--R           ((- 32A a b  - 128B a b)c + 48B a b )x  + (- 32A a b - 128B a )c
+--R         + 
+--R                2 2
+--R           48B a b
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                                                            +---------------+
+--R                3      3 2  2       2 3        2 2  +-+ +-+ |   4      2
+--R       ((64a b c  - 16b c )x  + 128a c  - 32a b c )\|a \|c \|c x  + b x  + a
+--R     + 
+--R                   2 4     4 2  4          2   3        3 2  2       3 3
+--R             (- 64a c  + 4b c )x  + (- 128a b c  + 32a b c )x  - 128a c
+--R           + 
+--R                2 2 2
+--R             32a b c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 2486
+
+--S 2487 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2487
+
+--S 2488 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                           2        3          2          4  2        2 2
+--R               (- 32A a b c  + (8A b  + 48B a b )c - 12B b )x  - 64A a c
+--R             + 
+--R                       2        2             3
+--R               (16A a b  + 96B a b)c - 24B a b
+--R          *
+--R                        +---------------+
+--R              +---+ +-+ |   4      2
+--R             \|- c \|a \|c x  + b x  + a
+--R         + 
+--R                     2 3        2   2       4        5  4
+--R               (32A a c  - 48B a b c  - 2A b c + 3B b )x
+--R             + 
+--R                     2   2             3        2 2            4  2        3 2
+--R               (64A a b c  + (- 16A a b  - 96B a b )c + 24B a b )x  + 64A a c
+--R             + 
+--R                       2 2        3           2 3
+--R               (- 16A a b  - 96B a b)c + 24B a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                         2           3          2          4  2         2 2
+--R               (64A a b c  + (- 16A b  - 96B a b )c + 24B b )x  + 128A a c
+--R             + 
+--R                         2         2             3
+--R               (- 32A a b  - 192B a b)c + 48B a b
+--R          *
+--R                      +---------------+
+--R              +-+ +-+ |   4      2
+--R             \|a \|c \|c x  + b x  + a
+--R         + 
+--R                       2 3        2   2       4        5  4
+--R               (- 64A a c  + 96B a b c  + 4A b c - 6B b )x
+--R             + 
+--R                        2   2           3         2 2            4  2
+--R               (- 128A a b c  + (32A a b  + 192B a b )c - 48B a b )x
+--R             + 
+--R                       3 2         2 2         3           2 3
+--R               - 128A a c  + (32A a b  + 192B a b)c - 48B a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                      2        2             3  2         2          3
+--R             ((16A a b  + 64B a b)c - 24B a b )x  + (32A a b + 128B a )c
+--R           + 
+--R                    2 2
+--R             - 48B a b
+--R      *
+--R                    +---------------+
+--R          +---+ +-+ |   4      2
+--R         \|- c \|c \|c x  + b x  + a
+--R     + 
+--R                              2  2          3         2         4  4
+--R           ((- 16A a b - 64B a )c  + (- 4A b  + 8B a b )c + 6B b )x
+--R         + 
+--R                      2         2             3  2           2          3
+--R           ((- 32A a b  - 128B a b)c + 48B a b )x  + (- 32A a b - 128B a )c
+--R         + 
+--R                2 2
+--R           48B a b
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                  3      3 2  2       2 3        2 2  +---+ +-+ +-+
+--R         ((64a b c  - 16b c )x  + 128a c  - 32a b c )\|- c \|a \|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R     + 
+--R                   2 4     4 2  4          2   3        3 2  2       3 3
+--R             (- 64a c  + 4b c )x  + (- 128a b c  + 32a b c )x  - 128a c
+--R           + 
+--R                2 2 2
+--R             32a b c
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 2488
+
+--S 2489 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2489
+
+)clear all
+
+--S 2490 of 3139
+t0:=x^3*(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                       5      3
+--R                    B x  + A x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2490
+
+--S 2491 of 3139
+r0:=1/2*B*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(3/2)+_
+   (2*a+b*x^2)*(A+B*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-b*B*sqrt(a+_
+   b*x^2+c*x^4)/(c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                       +---------------+                 2
+--R                    2  |   4      2                  2c x  + b
+--R       (4B a c - B b )\|c x  + b x  + a atanh(-----------------------)
+--R                                                    +---------------+
+--R                                                +-+ |   4      2
+--R                                              2\|c \|c x  + b x  + a
+--R     + 
+--R                                2  2                    +-+
+--R       (((- 2A b - 4B a)c + 2B b )x  - 4A a c + 2B a b)\|c
+--R  /
+--R                        +---------------+
+--R          2     2   +-+ |   4      2
+--R     (8a c  - 2b c)\|c \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2491
+
+--S 2492 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               +---------------+
+--R                     2         |   4      2
+--R               (B b x  + 2B a)\|c x  + b x  + a
+--R             + 
+--R                        4         2         +-+
+--R               (- 2B c x  - 2B b x  - 2B a)\|a
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                       +---------------+
+--R             2 +-+ +-+ |   4      2                       4         2  +-+
+--R         2B x \|a \|c \|c x  + b x  + a  + ((2A c - 2B b)x  - 2B a x )\|c
+--R    /
+--R                              +---------------+
+--R                2         +-+ |   4      2
+--R         (2b c x  + 4a c)\|c \|c x  + b x  + a
+--R       + 
+--R              2 4         2         +-+ +-+
+--R         (- 4c x  - 4b c x  - 4a c)\|a \|c
+--R     ,
+--R
+--R                               +---------------+
+--R                     2         |   4      2
+--R               (B b x  + 2B a)\|c x  + b x  + a
+--R             + 
+--R                        4         2         +-+
+--R               (- 2B c x  - 2B b x  - 2B a)\|a
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                        +---------------+
+--R            2 +---+ +-+ |   4      2                     4        2  +---+
+--R         B x \|- c \|a \|c x  + b x  + a  + ((A c - B b)x  - B a x )\|- c
+--R    /
+--R                               +---------------+
+--R               2         +---+ |   4      2
+--R         (b c x  + 2a c)\|- c \|c x  + b x  + a
+--R       + 
+--R              2 4         2         +---+ +-+
+--R         (- 2c x  - 2b c x  - 2a c)\|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2492
+
+--S 2493 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                +---------------+
+--R                         2  +-+ |   4      2                         3  2
+--R           (8B a c - 2B b )\|a \|c x  + b x  + a  + (- 4B a b c + B b )x
+--R         + 
+--R                 2          2
+--R           - 8B a c + 2B a b
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                                  +---------------+
+--R                           2  +-+ |   4      2                       3  2
+--R           (- 8B a c + 2B b )\|a \|c x  + b x  + a  + (4B a b c - B b )x
+--R         + 
+--R               2          2
+--R           8B a c - 2B a b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                               +---------------+
+--R                           +-+ |   4      2
+--R       (- 8A a c + 4B a b)\|c \|c x  + b x  + a
+--R     + 
+--R                      2  2                    +-+ +-+
+--R       ((4A b c - 2B b )x  + 8A a c - 4B a b)\|a \|c
+--R  /
+--R                               +---------------+
+--R             2     2   +-+ +-+ |   4      2
+--R       (16a c  - 4b c)\|a \|c \|c x  + b x  + a
+--R     + 
+--R                 2     3   2      2 2       2   +-+
+--R       ((- 8a b c  + 2b c)x  - 16a c  + 4a b c)\|c
+--R                                                    Type: Expression(Integer)
+--E 2493
+
+--S 2494 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2494
+
+--S 2495 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                        +---------------+
+--R                           2  +---+ +-+ |   4      2
+--R           (- 8B a c + 2B b )\|- c \|a \|c x  + b x  + a
+--R         + 
+--R                           3  2       2          2  +---+
+--R           ((4B a b c - B b )x  + 8B a c - 2B a b )\|- c
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                                     +---------------+
+--R                          2  +-+ +-+ |   4      2
+--R           (16B a c - 4B b )\|a \|c \|c x  + b x  + a
+--R         + 
+--R                              3  2        2          2  +-+
+--R           ((- 8B a b c + 2B b )x  - 16B a c + 4B a b )\|c
+--R      *
+--R                     +---------------+
+--R               +---+ |   4      2         +---+ +-+
+--R              \|- c \|c x  + b x  + a  - \|- c \|a
+--R         atan(-------------------------------------)
+--R                                  2
+--R                               c x
+--R     + 
+--R                                     +---------------+
+--R                           +---+ +-+ |   4      2
+--R       (- 8A a c + 4B a b)\|- c \|c \|c x  + b x  + a
+--R     + 
+--R                      2  2                    +---+ +-+ +-+
+--R       ((4A b c - 2B b )x  + 8A a c - 4B a b)\|- c \|a \|c
+--R  /
+--R                                     +---------------+
+--R             2     2   +---+ +-+ +-+ |   4      2
+--R       (16a c  - 4b c)\|- c \|a \|c \|c x  + b x  + a
+--R     + 
+--R                 2     3   2      2 2       2   +---+ +-+
+--R       ((- 8a b c  + 2b c)x  - 16a c  + 4a b c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 2495
+
+--S 2496 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2496
+
+)clear all
+
+--S 2497 of 3139
+t0:=x*(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                        3
+--R                     B x  + A x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2497
+
+--S 2498 of 3139
+r0:=(-A*b+2*a*B+(b*B-2*A*c)*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                      2
+--R         (2A c - B b)x  + A b - 2B a
+--R   (2)  -----------------------------
+--R                    +---------------+
+--R                 2  |   4      2
+--R        (4a c - b )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2498
+
+--S 2499 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       +---------------+
+--R                     2 |   4      2            4      2  +-+
+--R                - A x \|c x  + b x  + a  + (B x  + A x )\|a
+--R   (3)  -----------------------------------------------------------
+--R                        +---------------+
+--R            2       +-+ |   4      2              4         2     2
+--R        (b x  + 2a)\|a \|c x  + b x  + a  - 2a c x  - 2a b x  - 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 2499
+
+--S 2500 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +---------------+
+--R                 +-+ |   4      2              2           2                2
+--R   (2A b - 4B a)\|a \|c x  + b x  + a  + (- A b  + 2B a b)x  - 2A a b + 4B a
+--R   --------------------------------------------------------------------------
+--R                   +---------------+
+--R       2        2  |   4      2                      3  2     2        2  +-+
+--R    (8a c - 2a b )\|c x  + b x  + a  + ((- 4a b c + b )x  - 8a c + 2a b )\|a
+--R                                                    Type: Expression(Integer)
+--E 2500
+
+--S 2501 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2501
+
+)clear all
+
+--S 2502 of 3139
+t0:=(A+B*x^2)/(x*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                          2
+--R                       B x  + A
+--R   (1)  -------------------------------------
+--R                            +---------------+
+--R            5      3        |   4      2
+--R        (c x  + b x  + a x)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2502
+
+--S 2503 of 3139
+r0:=-1/2*A*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(3/2)+_
+   (-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                         +---------------+                2
+--R                      2  |   4      2                  b x  + 2a
+--R       (- 4A a c + A b )\|c x  + b x  + a atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|a \|c x  + b x  + a
+--R     + 
+--R                          2                2           +-+
+--R       ((- 2A b + 4B a)c x  + 4A a c - 2A b  + 2B a b)\|a
+--R  /
+--R                        +---------------+
+--R        2        2  +-+ |   4      2
+--R     (8a c - 2a b )\|a \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2503
+
+--S 2504 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          +---------------+
+--R                2         |   4      2                 4         2         +-+
+--R         ((A b x  + 2A a)\|c x  + b x  + a  + (- 2A c x  - 2A b x  - 2A a)\|a )
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                       +---------------+
+--R                     2 |   4      2                 4                   2  +-+
+--R       (2A b - 2B a)x \|c x  + b x  + a  + (- 2A c x  + (- 2A b + 2B a)x )\|a
+--R  /
+--R                         +---------------+
+--R            2     2  +-+ |   4      2          2   4     2   2     3
+--R     (2a b x  + 4a )\|a \|c x  + b x  + a  - 4a c x  - 4a b x  - 4a
+--R                                         Type: Union(Expression(Integer),...)
+--E 2504
+
+--S 2505 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              +---------------+
+--R                2          2  |   4      2
+--R           (8A a c - 2A a b )\|c x  + b x  + a
+--R         + 
+--R                             3  2       2          2  +-+
+--R           ((- 4A a b c + A b )x  - 8A a c + 2A a b )\|a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                              +---------------+
+--R                2          2  |   4      2
+--R           (8A a c - 2A a b )\|c x  + b x  + a
+--R         + 
+--R                             3  2       2          2  +-+
+--R           ((- 4A a b c + A b )x  - 8A a c + 2A a b )\|a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                                   +---------------+
+--R            2          2       2   |   4      2
+--R       (8A a c - 4A a b  + 4B a b)\|c x  + b x  + a
+--R     + 
+--R                          3         2  2       2          2       2   +-+
+--R       ((- 4A a b c + 2A b  - 2B a b )x  - 8A a c + 4A a b  - 4B a b)\|a
+--R  /
+--R                           +---------------+
+--R           3      2 2  +-+ |   4      2             3        2 3  2      4
+--R       (16a c - 4a b )\|a \|c x  + b x  + a  + (- 8a b c + 2a b )x  - 16a c
+--R     + 
+--R         3 2
+--R       4a b
+--R                                                    Type: Expression(Integer)
+--E 2505
+
+--S 2506 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2506
+
+)clear all
+
+--S 2507 of 3139
+t0:=(A+B*x^2)/(x^3*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                          2
+--R                       B x  + A
+--R   (1)  --------------------------------------
+--R                             +---------------+
+--R            7      5      3  |   4      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2507
+
+--S 2508 of 3139
+r0:=1/4*(3*A*b-2*a*B)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/_
+   a^(5/2)+(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*x^2*_
+   sqrt(a+b*x^2+c*x^4))-1/2*(3*A*b^2-2*a*b*B-8*a*A*c)*_
+   sqrt(a+b*x^2+c*x^4)/(a^2*(b^2-4*a*c)*x^2)
+--R 
+--R
+--R   (2)
+--R                                                  +---------------+
+--R                         2         3         2  2 |   4      2
+--R         ((12A a b - 8B a )c - 3A b  + 2B a b )x \|c x  + b x  + a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                     2        2             4
+--R           (- 16A a c  + (6A b  - 4B a b)c)x
+--R         + 
+--R                             2         3         2  2       2          2
+--R           ((- 20A a b + 8B a )c + 6A b  - 4B a b )x  - 8A a c + 2A a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                           +---------------+
+--R         3      2 2  2 +-+ |   4      2
+--R     (16a c - 4a b )x \|a \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2508
+
+--S 2509 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                  2         3         2  6
+--R               ((- 24A a b + 16B a )c - 6A b  + 4B a b )x
+--R             + 
+--R                         2        2   4           2         3  2
+--R               (- 48A a b  + 32B a b)x  + (- 48A a b + 32B a )x
+--R          *
+--R                  +---------------+
+--R              +-+ |   4      2
+--R             \|a \|c x  + b x  + a
+--R         + 
+--R                   2        2     8
+--R           (24A a b  - 16B a b)c x
+--R         + 
+--R                  2         3            3        2 2  6
+--R           ((48A a b - 32B a )c + 24A a b  - 16B a b )x
+--R         + 
+--R                 2 2        3   4         3         4  2
+--R           (72A a b  - 48B a b)x  + (48A a b - 32B a )x
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                           2         3         2  6
+--R           ((4A a b + 16B a )c - 9A b  + 8B a b )x
+--R         + 
+--R                 2           2        2   4        2   2        3
+--R           (64A a c - 24A a b  + 32B a b)x  + 40A a b x  + 32A a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R     + 
+--R               2 2           2        2     8
+--R       (- 32A a c  + (24A a b  - 24B a b)c)x
+--R     + 
+--R                2         3            3        2 2  6
+--R       ((- 48A a b - 16B a )c + 24A a b  - 24B a b )x
+--R     + 
+--R               3        2 2        3   4        3   2        4
+--R       (- 80A a c + 8A a b  - 32B a b)x  - 56A a b x  - 32A a
+--R  /
+--R                                               +---------------+
+--R            4      3 2  6      4   4      5 2  |   4      2
+--R       ((32a c + 8a b )x  + 64a b x  + 64a x )\|c x  + b x  + a
+--R     + 
+--R             3     8         4       3 2  6      4   4      5 2  +-+
+--R       (- 32a b c x  + (- 64a c - 32a b )x  - 96a b x  - 64a x )\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 2509
+
+--S 2510 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            2         3         2
+--R         ((- 24A a b + 16B a )c + 6A b  - 4B a b )
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                                                                2
+--R                          2         3         2              b x  + 2a
+--R       ((- 24A a b + 16B a )c + 6A b  - 4B a b )atanh(-----------------------)
+--R                                                            +---------------+
+--R                                                        +-+ |   4      2
+--R                                                      2\|a \|c x  + b x  + a
+--R     + 
+--R                         2         3         2
+--R       (- 28A a b + 16B a )c + 9A b  - 8B a b
+--R  /
+--R         3      2 2  +-+
+--R     (32a c - 8a b )\|a
+--R                                                    Type: Expression(Integer)
+--E 2510
+
+--S 2511 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2511
+
+)clear all
+
+--S 2512 of 3139
+t0:=x^4*(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                       6      4
+--R                    B x  + A x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2512
+
+--S 2513 of 3139
+--r0:=-x^3*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-_
+---  (b*B-2*A*c)*x*sqrt(a+b*x^2+c*x^4)/(c*(b^2-4*a*c))+1/2*(2*b^2*B-_
+---  A*b*c-6*a*B*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*(b^2-4*a*c)*sqrt(2)*_
+---  sqrt(a+b*x^2+c*x^4))-1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+---  sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+_
+---  sqrt(b^2-4*a*c))*(2*b^2*B-A*b*c-6*a*B*c-2*a*c*(b*B-2*A*c)/(b+_
+---  sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*(b^2-_
+---  4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 2513
+
+--S 2514 of 3139
+--a0:=integrate(t0,x)
+--E 2514
+
+--S 2515 of 3139
+--m0:=a0-r0
+--E 2515
+
+--S 2516 of 3139
+--d0:=D(m0,x)
+--E 2516
+
+)clear all
+
+--S 2517 of 3139
+t0:=x^2*(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                       4      2
+--R                    B x  + A x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2517
+
+--S 2518 of 3139
+--r0:=-x*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-_
+---  1/2*(b*B-2*A*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+_
+---  2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*_
+---  sqrt(a+b*x^2+c*x^4))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+---  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+---  (b^2*B-4*a*B*c+(b*B-2*A*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 2518
+
+--S 2519 of 3139
+--a0:=integrate(t0,x)
+--E 2519
+
+--S 2520 of 3139
+--m0:=a0-r0
+--E 2520
+
+--S 2521 of 3139
+--d0:=D(m0,x)
+--E 2521
+
+)clear all
+
+--S 2522 of 3139
+t0:=(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                         2
+--R                      B x  + A
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2522
+
+--S 2523 of 3139
+--r0:=-x*(a*b*B-A*(b^2-2*a*c)-(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+---  sqrt(a+b*x^2+c*x^4))-1/2*(A*b-2*a*B)*elliptic_e(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-_
+---  4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-_
+---  4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))-1/2*elliptic_f(asin(x*_
+---  sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(2*a*B*sqrt(b^2-4*a*c)-A*(b^2-4*a*c+b*sqrt(b^2-_
+---  4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*_
+---  sqrt(a+b*x^2+c*x^4))
+--E 2523
+
+--S 2524 of 3139
+--a0:=integrate(t0,x)
+--E 2524
+
+--S 2525 of 3139
+--m0:=a0-r0
+--E 2525
+
+--S 2526 of 3139
+--d0:=D(m0,x)
+--E 2526
+
+)clear all
+
+--S 2527 of 3139
+t0:=(A+B*x^2)/(x^2*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                          2
+--R                       B x  + A
+--R   (1)  --------------------------------------
+--R                             +---------------+
+--R            6      4      2  |   4      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2527
+
+--S 2528 of 3139
+--r0:=(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*x*_
+---  sqrt(a+b*x^2+c*x^4))-(2*A*b^2-a*b*B-6*a*A*c)*sqrt(a+b*x^2+c*x^4)/_
+---  (a^2*(b^2-4*a*c)*x)+1/2*(2*A*b^2-a*b*B-6*a*A*c)*elliptic_e(asin(x*_
+---  sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-_
+---  4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+---  (a^2*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))-_
+---  1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  (2*A*b^2-a*b*B-6*a*A*c-2*a*(A*b-2*a*B)*c/(b+sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*(b^2-4*a*c)*sqrt(2)*_
+---  sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 2528
+
+--S 2529 of 3139
+--a0:=integrate(t0,x)
+--E 2529
+
+--S 2530 of 3139
+--m0:=a0-r0
+--E 2530
+
+--S 2531 of 3139
+--d0:=D(m0,x)
+--E 2531
+
+)clear all
+
+--S 2532 of 3139
+t0:=(3-x^2)/sqrt(3+x^2-x^4)
+--R 
+--R
+--R               2
+--R            - x  + 3
+--R   (1)  ----------------
+--R         +-------------+
+--R         |   4    2
+--R        \|- x  + x  + 3
+--R                                                    Type: Expression(Integer)
+--E 2532
+
+--S 2533 of 3139
+--r0:=-elliptic_e(asin(x*sqrt(2/(1+sqrt(13)))),1/6*(-7-sqrt(13)))*_
+---  sqrt(1/2*(-1+sqrt(13)))+elliptic_f(asin(x*sqrt(2/(1+sqrt(13)))),_
+---  1/6*(-7-sqrt(13)))*sqrt(7+2*sqrt(13))
+--E 2533
+
+--S 2534 of 3139
+--a0:=integrate(t0,x)
+--E 2534
+
+--S 2535 of 3139
+--m0:=a0-r0
+--E 2535
+
+--S 2536 of 3139
+--d0:=D(m0,x)
+--E 2536
+
+)clear all
+
+--S 2537 of 3139
+t0:=(3-x^2)/sqrt(3+2*x^2-x^4)
+--R 
+--R
+--R                2
+--R             - x  + 3
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   4     2
+--R        \|- x  + 2x  + 3
+--R                                                    Type: Expression(Integer)
+--E 2537
+
+--S 2538 of 3139
+--r0:=-%i*elliptic_e(%i*asinh(x),-1/3)*sqrt(3)
+--E 2538
+
+--S 2539 of 3139
+--a0:=integrate(t0,x)
+--E 2539
+
+--S 2540 of 3139
+--m0:=a0-r0
+--E 2540
+
+--S 2541 of 3139
+--d0:=D(m0,x)
+--E 2541
+
+)clear all
+
+--S 2542 of 3139
+t0:=(3-x^2)/sqrt(3+3*x^2-x^4)
+--R 
+--R
+--R                2
+--R             - x  + 3
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   4     2
+--R        \|- x  + 3x  + 3
+--R                                                    Type: Expression(Integer)
+--E 2542
+
+--S 2543 of 3139
+--r0:=-elliptic_e(asin(x*sqrt(2/(3+sqrt(21)))),1/2*(-5-sqrt(21)))*_
+---  sqrt(1/2*(-3+sqrt(21)))+elliptic_f(asin(x*sqrt(2/(3+sqrt(21)))),_
+---  1/2*(-5-sqrt(21)))*sqrt(9+2*sqrt(21))
+--E 2543
+
+--S 2544 of 3139
+--a0:=integrate(t0,x)
+--E 2544
+
+--S 2545 of 3139
+--m0:=a0-r0
+--E 2545
+
+--S 2546 of 3139
+--d0:=D(m0,x)
+--E 2546
+
+)clear all
+
+--S 2547 of 3139
+t0:=(3-x^2)/sqrt(3-x^2-x^4)
+--R 
+--R
+--R               2
+--R            - x  + 3
+--R   (1)  ----------------
+--R         +-------------+
+--R         |   4    2
+--R        \|- x  - x  + 3
+--R                                                    Type: Expression(Integer)
+--E 2547
+
+--S 2548 of 3139
+--r0:=-elliptic_e(asin(x*sqrt(2/(-1+sqrt(13)))),1/6*(-7+sqrt(13)))*_
+---  sqrt(1/2*(1+sqrt(13)))+elliptic_f(asin(x*sqrt(2/(-1+sqrt(13)))),_
+---  1/6*(-7+sqrt(13)))*sqrt(5+2*sqrt(13))
+--E 2548
+
+--S 2549 of 3139
+--a0:=integrate(t0,x)
+--E 2549
+
+--S 2550 of 3139
+--m0:=a0-r0
+--E 2550
+
+--S 2551 of 3139
+--d0:=D(m0,x)
+--E 2551
+
+)clear all
+
+--S 2552 of 3139
+t0:=(3-x^2)/sqrt(3-2*x^2-x^4)
+--R 
+--R
+--R                2
+--R             - x  + 3
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   4     2
+--R        \|- x  - 2x  + 3
+--R                                                    Type: Expression(Integer)
+--E 2552
+
+--S 2553 of 3139
+--r0:=-elliptic_e(asin(x),-1/3)*sqrt(3)+2*elliptic_f(asin(x),-1/3)*sqrt(3)
+--E 2553
+
+--S 2554 of 3139
+--a0:=integrate(t0,x)
+--E 2554
+
+--S 2555 of 3139
+--m0:=a0-r0
+--E 2555
+
+--S 2556 of 3139
+--d0:=D(m0,x)
+--E 2556
+
+)clear all
+
+--S 2557 of 3139
+t0:=(3-x^2)/sqrt(3-3*x^2-x^4)
+--R 
+--R
+--R                2
+--R             - x  + 3
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   4     2
+--R        \|- x  - 3x  + 3
+--R                                                    Type: Expression(Integer)
+--E 2557
+
+--S 2558 of 3139
+--r0:=-elliptic_e(asin(x*sqrt(2/(-3+sqrt(21)))),1/2*(-5+sqrt(21)))*_
+---  sqrt(1/2*(3+sqrt(21)))+elliptic_f(asin(x*sqrt(2/(-3+sqrt(21)))),_
+---  1/2*(-5+sqrt(21)))*sqrt(3+2*sqrt(21))
+--E 2558
+
+--S 2559 of 3139
+--a0:=integrate(t0,x)
+--E 2559
+
+--S 2560 of 3139
+--m0:=a0-r0
+--E 2560
+
+--S 2561 of 3139
+--d0:=D(m0,x)
+--E 2561
+
+)clear all
+
+--S 2562 of 3139
+t0:=(b+2*c*x^2-sqrt(b^2-4*a*c))/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +-----------+
+--R           |          2        2
+--R        - \|- 4a c + b   + 2c x  + b
+--R   (1)  ----------------------------
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2562
+
+--S 2563 of 3139
+--r0:=elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),_
+---  (b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*(b-sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(-c)*sqrt(a+b*x^2+c*x^4))
+--E 2563
+
+--S 2564 of 3139
+--a0:=integrate(t0,x)
+--E 2564
+
+--S 2565 of 3139
+--m0:=a0-r0
+--E 2565
+
+--S 2566 of 3139
+--d0:=D(m0,x)
+--E 2566
+
+)clear all
+
+--S 2567 of 3139
+t0:=x^2*sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R           +--------+ +-------------------+
+--R         2 |   2      | 2 4         2    2
+--R   (1)  x \|d x  + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2567
+
+--S 2568 of 3139
+r0:=1/6*b*x^3*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))+_
+   1/16*c^2*(b*c-2*a*d)*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d^(5/2)*(a+b*x^2))-1/16*c*(b*c-2*a*d)*x*sqrt(c+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^2*(a+b*x^2))-1/8*(b*c-2*a*d)*x^3*_
+   sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                          +-------------------+           +-+
+--R              2        3  | 2 4         2    2          x\|d
+--R       (- 6a c d + 3b c )\|b x  + 2a b x  + a  atanh(-----------)
+--R                                                      +--------+
+--R                                                      |   2
+--R                                                     \|d x  + c
+--R     + 
+--R                                                                 +--------+
+--R              2 5         2           3                 2    +-+ |   2
+--R         (8b d x  + (12a d  + 2b c d)x  + (6a c d - 3b c )x)\|d \|d x  + c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R  /
+--R           2 2        2  +-+
+--R     (48b d x  + 48a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 2568
+
+--S 2569 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       2 3        3 2  4          3 2        4   2         4
+--R                 (36a c d  - 18b c d )x  + (192a c d  - 96b c d)x  + 192a c d
+--R               + 
+--R                        5
+--R                 - 96b c
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|c \|d x  + c
+--R           + 
+--R                    2 4       3 3  6            3 3        4 2  4
+--R             (- 6a c d  + 3b c d )x  + (- 108a c d  + 54b c d )x
+--R           + 
+--R                      4 2         5   2         5         6
+--R             (- 288a c d  + 144b c d)x  - 192a c d + 96b c
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|c \|d  + d x)\|d x  + c  + (- d x  - c)\|d  - d x\|c
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|c \|d x  + c  - c
+--R       + 
+--R                   5 11           5           4  9              4         2 3  7
+--R             - 8b d x   + (- 12a d  - 146b c d )x  + (- 222a c d  - 417b c d )x
+--R           + 
+--R                      2 3         3 2  5            3 2        4   3
+--R             (- 684a c d  - 298b c d )x  + (- 672a c d  + 80b c d)x
+--R           + 
+--R                      4         5
+--R             (- 192a c d + 96b c )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|d \|d x  + c
+--R       + 
+--R                  5 11         5           4  9            4         2 3  7
+--R             48b d x   + (72a d  + 316b c d )x  + (492a c d  + 570b c d )x
+--R           + 
+--R                    2 3         3 2  5          3 2         4   3
+--R             (996a c d  + 270b c d )x  + (768a c d  - 128b c d)x
+--R           + 
+--R                    4         5
+--R             (192a c d - 96b c )x
+--R        *
+--R            +-+ +-+
+--R           \|c \|d
+--R    /
+--R                                                   +--------+
+--R              4 4          3 2        2 2  +-+ +-+ |   2
+--R         (288d x  + 1536c d x  + 1536c d )\|c \|d \|d x  + c
+--R       + 
+--R               5 6         4 4        2 3 2        3 2  +-+
+--R         (- 48d x  - 864c d x  - 2304c d x  - 1536c d )\|d
+--R     ,
+--R
+--R                         2 3        3 2  4            3 2         4   2
+--R                 (- 72a c d  + 36b c d )x  + (- 384a c d  + 192b c d)x
+--R               + 
+--R                         4          5
+--R                 - 384a c d + 192b c
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|c \|d x  + c
+--R           + 
+--R                   2 4       3 3  6          3 3         4 2  4
+--R             (12a c d  - 6b c d )x  + (216a c d  - 108b c d )x
+--R           + 
+--R                    4 2         5   2         5          6
+--R             (576a c d  - 288b c d)x  + 384a c d - 192b c
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- d \|d x  + c  - \|- d \|c
+--R           atan(------------------------------)
+--R                              d x
+--R       + 
+--R                   5 11           5           4  9              4         2 3  7
+--R             - 8b d x   + (- 12a d  - 146b c d )x  + (- 222a c d  - 417b c d )x
+--R           + 
+--R                      2 3         3 2  5            3 2        4   3
+--R             (- 684a c d  - 298b c d )x  + (- 672a c d  + 80b c d)x
+--R           + 
+--R                      4         5
+--R             (- 192a c d + 96b c )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- d \|d x  + c
+--R       + 
+--R                  5 11         5           4  9            4         2 3  7
+--R             48b d x   + (72a d  + 316b c d )x  + (492a c d  + 570b c d )x
+--R           + 
+--R                    2 3         3 2  5          3 2         4   3
+--R             (996a c d  + 270b c d )x  + (768a c d  - 128b c d)x
+--R           + 
+--R                    4         5
+--R             (192a c d - 96b c )x
+--R        *
+--R            +---+ +-+
+--R           \|- d \|c
+--R    /
+--R                                                     +--------+
+--R              4 4          3 2        2 2  +---+ +-+ |   2
+--R         (288d x  + 1536c d x  + 1536c d )\|- d \|c \|d x  + c
+--R       + 
+--R               5 6         4 4        2 3 2        3 2  +---+
+--R         (- 48d x  - 864c d x  - 2304c d x  - 1536c d )\|- d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2569
+
+--S 2570 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       2 3      2 3 2  6       2 2 3           3 2      2 4   4
+--R               (36a b c d  - 18b c d )x  + (36a c d  + 174a b c d  - 96b c d)x
+--R             + 
+--R                    2 3 2          4       2 5  2       2 4           5
+--R               (192a c d  + 96a b c d - 96b c )x  + 192a c d - 96a b c
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|d x  + c
+--R         + 
+--R                    2 4     2 3 3  8        2 2 4           3 3      2 4 2  6
+--R           (- 6a b c d  + 3b c d )x  + (- 6a c d  - 105a b c d  + 54b c d )x
+--R         + 
+--R                  2 3 3           4 2       2 5   4
+--R           (- 108a c d  - 234a b c d  + 144b c d)x
+--R         + 
+--R                  2 4 2          5       2 6  2       2 5           6
+--R           (- 288a c d  - 48a b c d + 96b c )x  - 192a c d + 96a b c
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|c \|d  + d x)\|d x  + c  + (- d x  - c)\|d  - d x\|c
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|c \|d x  + c  - c
+--R     + 
+--R                     2 3        3 2  4          3 2        4   2         4
+--R               (36a c d  - 18b c d )x  + (192a c d  - 96b c d)x  + 192a c d
+--R             + 
+--R                      5
+--R               - 96b c
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|d x  + c
+--R         + 
+--R                  2 4       3 3  6            3 3        4 2  4
+--R           (- 6a c d  + 3b c d )x  + (- 108a c d  + 54b c d )x
+--R         + 
+--R                    4 2         5   2         5         6
+--R           (- 288a c d  + 144b c d)x  - 192a c d + 96b c
+--R      *
+--R          +-------------------+           +-+
+--R          | 2 4         2    2          x\|d
+--R         \|b x  + 2a b x  + a  atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|d x  + c
+--R     + 
+--R                   5 11         5           4  9            4         2 3  7
+--R               8b d x   + (12a d  + 146b c d )x  + (222a c d  + 417b c d )x
+--R             + 
+--R                      2 3         3 2  5          3 2        4   3
+--R               (684a c d  + 298b c d )x  + (672a c d  - 80b c d)x
+--R             + 
+--R                      4         5
+--R               (192a c d - 96b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|d \|d x  + c
+--R         + 
+--R                      5 11           5           4  9
+--R               - 48b d x   + (- 72a d  - 316b c d )x
+--R             + 
+--R                          4         2 3  7            2 3         3 2  5
+--R               (- 492a c d  - 570b c d )x  + (- 996a c d  - 270b c d )x
+--R             + 
+--R                        3 2         4   3            4         5
+--R               (- 768a c d  + 128b c d)x  + (- 192a c d + 96b c )x
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               2 5 13             5       2   4  11
+--R           - 8b d x   + (- 20a b d  - 146b c d )x
+--R         + 
+--R                 2 5             4       2 2 3  9
+--R           (- 12a d  - 368a b c d  - 417b c d )x
+--R         + 
+--R                  2   4            2 3       2 3 2  7
+--R           (- 222a c d  - 1101a b c d  - 298b c d )x
+--R         + 
+--R                  2 2 3           3 2      2 4   5
+--R           (- 684a c d  - 970a b c d  + 80b c d)x
+--R         + 
+--R                  2 3 2           4       2 5  3          2 4           5
+--R           (- 672a c d  - 112a b c d + 96b c )x  + (- 192a c d + 96a b c )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|d \|d x  + c
+--R     + 
+--R              2 5 13            5       2   4  11
+--R           48b d x   + (120a b d  + 316b c d )x
+--R         + 
+--R               2 5             4       2 2 3  9
+--R           (72a d  + 808a b c d  + 570b c d )x
+--R         + 
+--R                2   4            2 3       2 3 2  7
+--R           (492a c d  + 1566a b c d  + 270b c d )x
+--R         + 
+--R                2 2 3            3 2       2 4   5
+--R           (996a c d  + 1038a b c d  - 128b c d)x
+--R         + 
+--R                2 3 2          4       2 5  3        2 4           5
+--R           (768a c d  + 64a b c d - 96b c )x  + (192a c d - 96a b c )x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R  /
+--R                 4 6          4            3  4             3          2 2  2
+--R           288b d x  + (288a d  + 1536b c d )x  + (1536a c d  + 1536b c d )x
+--R         + 
+--R                  2 2
+--R           1536a c d
+--R      *
+--R                  +--------+
+--R          +-+ +-+ |   2
+--R         \|c \|d \|d x  + c
+--R     + 
+--R                  5 8           5           4  6              4          2 3  4
+--R           - 48b d x  + (- 48a d  - 864b c d )x  + (- 864a c d  - 2304b c d )x
+--R         + 
+--R                     2 3          3 2  2          3 2
+--R           (- 2304a c d  - 1536b c d )x  - 1536a c d
+--R      *
+--R          +-+
+--R         \|d
+--R                                                    Type: Expression(Integer)
+--E 2570
+
+--S 2571 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        8 20         8           7  18
+--R                   - b d x   + (- a d  - 113b c d )x
+--R                 + 
+--R                              7          2 6  16
+--R                   (- 113a c d  - 2128b c d )x
+--R                 + 
+--R                             2 6           3 5  14
+--R                   (- 2128a c d  - 15456b c d )x
+--R                 + 
+--R                              3 5           4 4  12
+--R                   (- 15456a c d  - 55680b c d )x
+--R                 + 
+--R                              4 4            5 3  10
+--R                   (- 55680a c d  - 109824b c d )x
+--R                 + 
+--R                               5 3            6 2  8
+--R                   (- 109824a c d  - 120832b c d )x
+--R                 + 
+--R                               6 2           7   6
+--R                   (- 120832a c d  - 69632b c d)x
+--R                 + 
+--R                              7            8  4           8 2
+--R                   (- 69632a c d - 16384b c )x  - 16384a c x
+--R              *
+--R                  +-+
+--R                 \|d
+--R             + 
+--R                          8 19           8           7  17
+--R                   - 15b d x   + (- 15a d  - 560b c d )x
+--R                 + 
+--R                              7          2 6  15
+--R                   (- 560a c d  - 6048b c d )x
+--R                 + 
+--R                             2 6           3 5  13
+--R                   (- 6048a c d  - 28800b c d )x
+--R                 + 
+--R                              3 5           4 4  11
+--R                   (- 28800a c d  - 70400b c d )x
+--R                 + 
+--R                              4 4           5 3  9
+--R                   (- 70400a c d  - 92160b c d )x
+--R                 + 
+--R                              5 3           6 2  7
+--R                   (- 92160a c d  - 61440b c d )x
+--R                 + 
+--R                              6 2           7   5           7   3
+--R                   (- 61440a c d  - 16384b c d)x  - 16384a c d x
+--R              *
+--R                  +-+
+--R                 \|c
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|d x  + c
+--R         + 
+--R                    8 20         8           7  18            7          2 6  16
+--R               15b d x   + (15a d  + 575b c d )x   + (575a c d  + 6608b c d )x
+--R             + 
+--R                       2 6           3 5  14            3 5           4 4  12
+--R               (6608a c d  + 34848b c d )x   + (34848a c d  + 99200b c d )x
+--R             + 
+--R                        4 4            5 3  10             5 3            6 2  8
+--R               (99200a c d  + 162560b c d )x   + (162560a c d  + 153600b c d )x
+--R             + 
+--R                         6 2           7   6            7            8  4
+--R               (153600a c d  + 77824b c d)x  + (77824a c d + 16384b c )x
+--R             + 
+--R                       8 2
+--R               16384a c x
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R              9 21       9           8  19            8          2 7  17
+--R           b d x   + (a d  + 113b c d )x   + (113a c d  + 2128b c d )x
+--R         + 
+--R                   2 7           3 6  15            3 6           4 5  13
+--R           (2128a c d  + 15456b c d )x   + (15456a c d  + 55680b c d )x
+--R         + 
+--R                    4 5            5 4  11             5 4            6 3  9
+--R           (55680a c d  + 109824b c d )x   + (109824a c d  + 120832b c d )x
+--R         + 
+--R                     6 3           7 2  7            7 2           8   5
+--R           (120832a c d  + 69632b c d )x  + (69632a c d  + 16384b c d)x
+--R         + 
+--R                   8   3
+--R           16384a c d x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                2 8 22          8       2   7  20
+--R               b d x   + (2a b d  + 113b c d )x
+--R             + 
+--R                 2 8             7        2 2 6  18
+--R               (a d  + 226a b c d  + 2128b c d )x
+--R             + 
+--R                    2   7            2 6         2 3 5  16
+--R               (113a c d  + 4256a b c d  + 15456b c d )x
+--R             + 
+--R                     2 2 6             3 5         2 4 4  14
+--R               (2128a c d  + 30912a b c d  + 55680b c d )x
+--R             + 
+--R                      2 3 5              4 4          2 5 3  12
+--R               (15456a c d  + 111360a b c d  + 109824b c d )x
+--R             + 
+--R                      2 4 4              5 3          2 6 2  10
+--R               (55680a c d  + 219648a b c d  + 120832b c d )x
+--R             + 
+--R                       2 5 3              6 2         2 7   8
+--R               (109824a c d  + 241664a b c d  + 69632b c d)x
+--R             + 
+--R                       2 6 2              7          2 8  6
+--R               (120832a c d  + 139264a b c d + 16384b c )x
+--R             + 
+--R                      2 7              8  4         2 8 2
+--R               (69632a c d + 32768a b c )x  + 16384a c x
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                  2 8 21           8       2   7  19
+--R               15b d x   + (30a b d  + 560b c d )x
+--R             + 
+--R                   2 8              7        2 2 6  17
+--R               (15a d  + 1120a b c d  + 6048b c d )x
+--R             + 
+--R                    2   7             2 6         2 3 5  15
+--R               (560a c d  + 12096a b c d  + 28800b c d )x
+--R             + 
+--R                     2 2 6             3 5         2 4 4  13
+--R               (6048a c d  + 57600a b c d  + 70400b c d )x
+--R             + 
+--R                      2 3 5              4 4         2 5 3  11
+--R               (28800a c d  + 140800a b c d  + 92160b c d )x
+--R             + 
+--R                      2 4 4              5 3         2 6 2  9
+--R               (70400a c d  + 184320a b c d  + 61440b c d )x
+--R             + 
+--R                      2 5 3              6 2         2 7   7
+--R               (92160a c d  + 122880a b c d  + 16384b c d)x
+--R             + 
+--R                      2 6 2             7   5         2 7   3
+--R               (61440a c d  + 32768a b c d)x  + 16384a c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                2 8 22             8       2   7  20
+--R           - 15b d x   + (- 30a b d  - 575b c d )x
+--R         + 
+--R                 2 8              7        2 2 6  18
+--R           (- 15a d  - 1150a b c d  - 6608b c d )x
+--R         + 
+--R                  2   7             2 6         2 3 5  16
+--R           (- 575a c d  - 13216a b c d  - 34848b c d )x
+--R         + 
+--R                   2 2 6             3 5         2 4 4  14
+--R           (- 6608a c d  - 69696a b c d  - 99200b c d )x
+--R         + 
+--R                    2 3 5              4 4          2 5 3  12
+--R           (- 34848a c d  - 198400a b c d  - 162560b c d )x
+--R         + 
+--R                    2 4 4              5 3          2 6 2  10
+--R           (- 99200a c d  - 325120a b c d  - 153600b c d )x
+--R         + 
+--R                     2 5 3              6 2         2 7   8
+--R           (- 162560a c d  - 307200a b c d  - 77824b c d)x
+--R         + 
+--R                     2 6 2              7          2 8  6
+--R           (- 153600a c d  - 155648a b c d - 16384b c )x
+--R         + 
+--R                    2 7              8  4         2 8 2
+--R           (- 77824a c d - 32768a b c )x  - 16384a c x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R     + 
+--R          2 9 23            9       2   8  21
+--R       - b d x   + (- 2a b d  - 113b c d )x
+--R     + 
+--R           2 9             8        2 2 7  19
+--R       (- a d  - 226a b c d  - 2128b c d )x
+--R     + 
+--R              2   8            2 7         2 3 6  17
+--R       (- 113a c d  - 4256a b c d  - 15456b c d )x
+--R     + 
+--R               2 2 7             3 6         2 4 5  15
+--R       (- 2128a c d  - 30912a b c d  - 55680b c d )x
+--R     + 
+--R                2 3 6              4 5          2 5 4  13
+--R       (- 15456a c d  - 111360a b c d  - 109824b c d )x
+--R     + 
+--R                2 4 5              5 4          2 6 3  11
+--R       (- 55680a c d  - 219648a b c d  - 120832b c d )x
+--R     + 
+--R                 2 5 4              6 3         2 7 2  9
+--R       (- 109824a c d  - 241664a b c d  - 69632b c d )x
+--R     + 
+--R                 2 6 3              7 2         2 8   7
+--R       (- 120832a c d  - 139264a b c d  - 16384b c d)x
+--R     + 
+--R                2 7 2             8   5         2 8   3
+--R       (- 69632a c d  - 32768a b c d)x  - 16384a c d x
+--R  /
+--R                    7 14         6 12        2 5 10         3 4 8         4 3 6
+--R                 15d x   + 560c d x   + 6048c d x   + 28800c d x  + 70400c d x
+--R               + 
+--R                       5 2 4         6   2         7
+--R                 92160c d x  + 61440c d x  + 16384c
+--R            *
+--R                +-+ +-+
+--R               \|c \|d
+--R           + 
+--R              8 15         7 13        2 6 11         3 5 9         4 4 7
+--R             d x   + 112c d x   + 2016c d x   + 13440c d x  + 42240c d x
+--R           + 
+--R                   5 3 5         6 2 3         7
+--R             67584c d x  + 53248c d x  + 16384c d x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|d x  + c
+--R       + 
+--R                8 16         7 14        2 6 12         3 5 10         4 4 8
+--R             - d x   - 113c d x   - 2128c d x   - 15456c d x   - 55680c d x
+--R           + 
+--R                      5 3 6          6 2 4         7   2         8
+--R             - 109824c d x  - 120832c d x  - 69632c d x  - 16384c
+--R        *
+--R            +-+
+--R           \|d
+--R       + 
+--R                  8 15         7 13        2 6 11         3 5 9         4 4 7
+--R             - 15d x   - 560c d x   - 6048c d x   - 28800c d x  - 70400c d x
+--R           + 
+--R                     5 3 5         6 2 3         7
+--R             - 92160c d x  - 61440c d x  - 16384c d x
+--R        *
+--R            +-+
+--R           \|c
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2571
+
+--S 2572 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     2 3        3 2  4          3 2        4   2         4
+--R               (36a c d  - 18b c d )x  + (192a c d  - 96b c d)x  + 192a c d
+--R             + 
+--R                      5
+--R               - 96b c
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- d \|c \|d x  + c
+--R         + 
+--R                      2 4       3 3  6            3 3        4 2  4
+--R               (- 6a c d  + 3b c d )x  + (- 108a c d  + 54b c d )x
+--R             + 
+--R                        4 2         5   2         5         6
+--R               (- 288a c d  + 144b c d)x  - 192a c d + 96b c
+--R          *
+--R              +---+
+--R             \|- d
+--R      *
+--R          +-------------------+           +-+
+--R          | 2 4         2    2          x\|d
+--R         \|b x  + 2a b x  + a  atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|d x  + c
+--R     + 
+--R                         2 3      2 3 2  6
+--R               (- 72a b c d  + 36b c d )x
+--R             + 
+--R                     2 2 3           3 2       2 4   4
+--R               (- 72a c d  - 348a b c d  + 192b c d)x
+--R             + 
+--R                      2 3 2           4        2 5  2       2 4            5
+--R               (- 384a c d  - 192a b c d + 192b c )x  - 384a c d + 192a b c
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|c \|d \|d x  + c
+--R         + 
+--R                       2 4     2 3 3  8       2 2 4           3 3       2 4 2  6
+--R               (12a b c d  - 6b c d )x  + (12a c d  + 210a b c d  - 108b c d )x
+--R             + 
+--R                    2 3 3           4 2       2 5   4
+--R               (216a c d  + 468a b c d  - 288b c d)x
+--R             + 
+--R                    2 4 2          5        2 6  2       2 5            6
+--R               (576a c d  + 96a b c d - 192b c )x  + 384a c d - 192a b c
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- d \|d x  + c  - \|- d \|c
+--R         atan(------------------------------)
+--R                            d x
+--R     + 
+--R                   5 11         5           4  9            4         2 3  7
+--R               8b d x   + (12a d  + 146b c d )x  + (222a c d  + 417b c d )x
+--R             + 
+--R                      2 3         3 2  5          3 2        4   3
+--R               (684a c d  + 298b c d )x  + (672a c d  - 80b c d)x
+--R             + 
+--R                      4         5
+--R               (192a c d - 96b c )x
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- d \|d \|d x  + c
+--R         + 
+--R                      5 11           5           4  9
+--R               - 48b d x   + (- 72a d  - 316b c d )x
+--R             + 
+--R                          4         2 3  7            2 3         3 2  5
+--R               (- 492a c d  - 570b c d )x  + (- 996a c d  - 270b c d )x
+--R             + 
+--R                        3 2         4   3            4         5
+--R               (- 768a c d  + 128b c d)x  + (- 192a c d + 96b c )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- d \|c \|d
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               2 5 13             5       2   4  11
+--R           - 8b d x   + (- 20a b d  - 146b c d )x
+--R         + 
+--R                 2 5             4       2 2 3  9
+--R           (- 12a d  - 368a b c d  - 417b c d )x
+--R         + 
+--R                  2   4            2 3       2 3 2  7
+--R           (- 222a c d  - 1101a b c d  - 298b c d )x
+--R         + 
+--R                  2 2 3           3 2      2 4   5
+--R           (- 684a c d  - 970a b c d  + 80b c d)x
+--R         + 
+--R                  2 3 2           4       2 5  3          2 4           5
+--R           (- 672a c d  - 112a b c d + 96b c )x  + (- 192a c d + 96a b c )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- d \|d \|d x  + c
+--R     + 
+--R              2 5 13            5       2   4  11
+--R           48b d x   + (120a b d  + 316b c d )x
+--R         + 
+--R               2 5             4       2 2 3  9
+--R           (72a d  + 808a b c d  + 570b c d )x
+--R         + 
+--R                2   4            2 3       2 3 2  7
+--R           (492a c d  + 1566a b c d  + 270b c d )x
+--R         + 
+--R                2 2 3            3 2       2 4   5
+--R           (996a c d  + 1038a b c d  - 128b c d)x
+--R         + 
+--R                2 3 2          4       2 5  3        2 4           5
+--R           (768a c d  + 64a b c d - 96b c )x  + (192a c d - 96a b c )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- d \|c \|d
+--R  /
+--R                 4 6          4            3  4             3          2 2  2
+--R           288b d x  + (288a d  + 1536b c d )x  + (1536a c d  + 1536b c d )x
+--R         + 
+--R                  2 2
+--R           1536a c d
+--R      *
+--R                        +--------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- d \|c \|d \|d x  + c
+--R     + 
+--R                  5 8           5           4  6              4          2 3  4
+--R           - 48b d x  + (- 48a d  - 864b c d )x  + (- 864a c d  - 2304b c d )x
+--R         + 
+--R                     2 3          3 2  2          3 2
+--R           (- 2304a c d  - 1536b c d )x  - 1536a c d
+--R      *
+--R          +---+ +-+
+--R         \|- d \|d
+--R                                                    Type: Expression(Integer)
+--E 2572
+
+--S 2573 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                         +-------------------+
+--R             6               4        2  | 2 4         2    2     2   8
+--R       (b d x  + (a d + b c)x  + a c x )\|b x  + 2a b x  + a   - b d x
+--R     + 
+--R                    2   6       2            4    2   2
+--R       (- 2a b d - b c)x  + (- a d - 2a b c)x  - a c x
+--R  /
+--R      +--------+ +-------------------+
+--R      |   2      | 2 4         2    2
+--R     \|d x  + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2573
+
+)clear all
+
+--S 2574 of 3139
+t0:=x*sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          +--------+ +-------------------+
+--R          |   2      | 2 4         2    2
+--R   (1)  x\|d x  + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2574
+
+--S 2575 of 3139
+r0:=1/5*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/d-2/15*(b*c-a*d)*_
+   (c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                                      +--------+
+--R            2 4        2          2                2  |   2
+--R       (3b d x  + (5a d  + b c d)x  + 5a c d - 2b c )\|d x  + c
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          2 2        2
+--R     15b d x  + 15a d
+--R                                                    Type: Expression(Integer)
+--E 2575
+
+--S 2576 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    2 8             2        2   6            2         3  4
+--R           - 15b c d x  + (- 25a c d  - 65b c d)x  + (- 120a c d - 60b c )x
+--R         + 
+--R                   3 2
+--R           - 120a c x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R               3 10        3          2  8           2        2   6
+--R           3b d x   + (5a d  + 40b c d )x  + (70a c d  + 95b c d)x
+--R         + 
+--R                  2         3  4         3 2
+--R           (180a c d + 60b c )x  + 120a c x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                      +--------+
+--R         2 4           2       2  +-+ |   2             2 4       2   2       3
+--R     (15d x  + 180c d x  + 240c )\|c \|d x  + c  - 75c d x  - 300c d x  - 240c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2576
+
+--S 2577 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      4 8           4        2 3  6          2 3        3 2  4
+--R               15b c d x  + (25a c d  + 65b c d )x  + (125a c d  + 58b c d )x
+--R             + 
+--R                      3 2        4   2        4         5
+--R               (180a c d  - 24b c d)x  + 80a c d - 32b c
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|d x  + c
+--R         + 
+--R                     5 10          5          4  8             4        2 3  6
+--R               - 3b d x   + (- 5a d  - 40b c d )x  + (- 70a c d  - 95b c d )x
+--R             + 
+--R                        2 3        3 2  4            3 2        4   2        4
+--R               (- 205a c d  - 50b c d )x  + (- 220a c d  + 40b c d)x  - 80a c d
+--R             + 
+--R                    5
+--R               32b c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                2   4 10               4      2 2 3  8
+--R           - 15b c d x   + (- 40a b c d  - 65b c d )x
+--R         + 
+--R                 2   4           2 3      2 3 2  6
+--R           (- 25a c d  - 185a b c d  - 60b c d )x
+--R         + 
+--R                  2 2 3           3 2  4       2 3 2 2
+--R           (- 120a c d  - 180a b c d )x  - 120a c d x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R             2 5 12          5      2   4  10
+--R           3b d x   + (8a b d  + 40b c d )x
+--R         + 
+--R              2 5             4      2 2 3  8
+--R           (5a d  + 110a b c d  + 95b c d )x
+--R         + 
+--R               2   4           2 3      2 3 2  6        2 2 3           3 2  4
+--R           (70a c d  + 275a b c d  + 60b c d )x  + (180a c d  + 180a b c d )x
+--R         + 
+--R               2 3 2 2
+--R           120a c d x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                4 6         4           3  4            3         2 2  2
+--R           15b d x  + (15a d  + 180b c d )x  + (180a c d  + 240b c d )x
+--R         + 
+--R                 2 2
+--R           240a c d
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|d x  + c
+--R     + 
+--R                4 6             4         2 3  4            2 3         3 2  2
+--R       - 75b c d x  + (- 75a c d  - 300b c d )x  + (- 300a c d  - 240b c d )x
+--R     + 
+--R               3 2
+--R       - 240a c d
+--R                                                    Type: Expression(Integer)
+--E 2577
+
+--S 2578 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                        +-------------------+
+--R             5               3          | 2 4         2    2     2   7
+--R       (b d x  + (a d + b c)x  + a c x)\|b x  + 2a b x  + a   - b d x
+--R     + 
+--R                    2   5       2            3    2
+--R       (- 2a b d - b c)x  + (- a d - 2a b c)x  - a c x
+--R  /
+--R      +--------+ +-------------------+
+--R      |   2      | 2 4         2    2
+--R     \|d x  + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2578
+
+)clear all
+
+--S 2579 of 3139
+t0:=sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         +--------+ +-------------------+
+--R         |   2      | 2 4         2    2
+--R   (1)  \|d x  + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2579
+
+--S 2580 of 3139
+r0:=1/4*b*x*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))-_
+   1/8*c*(b*c-4*a*d)*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d^(3/2)*(a+b*x^2))-1/8*(b*c-4*a*d)*x*sqrt(c+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                       +-------------------+           +-+
+--R                    2  | 2 4         2    2          x\|d
+--R       (4a c d - b c )\|b x  + 2a b x  + a  atanh(-----------)
+--R                                                   +--------+
+--R                                                   |   2
+--R                                                  \|d x  + c
+--R     + 
+--R                                     +--------+ +-------------------+
+--R              3                  +-+ |   2      | 2 4         2    2
+--R       (2b d x  + (4a d + b c)x)\|d \|d x  + c \|b x  + 2a b x  + a
+--R  /
+--R            2         +-+
+--R     (8b d x  + 8a d)\|d
+--R                                                    Type: Expression(Integer)
+--E 2580
+
+--S 2581 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                           +--------+
+--R                      2       2   2        2        3  +-+ |   2
+--R             ((16a c d  - 4b c d)x  + 32a c d - 8b c )\|c \|d x  + c
+--R           + 
+--R                      3      2 2  4           2 2       3   2        3        4
+--R             (- 4a c d  + b c d )x  + (- 32a c d  + 8b c d)x  - 32a c d + 8b c
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|c \|d  - d x)\|d x  + c  + (- d x  - c)\|d  + d x\|c
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|c \|d x  + c  - c
+--R       + 
+--R                   3 7          3          2  5             2        2   3
+--R             - 2b d x  + (- 4a d  - 17b c d )x  + (- 32a c d  - 24b c d)x
+--R           + 
+--R                     2        3
+--R             (- 32a c d - 8b c )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|d \|d x  + c
+--R       + 
+--R                 3 7         3          2  5           2        2   3
+--R             8b d x  + (16a d  + 28b c d )x  + (48a c d  + 28b c d)x
+--R           + 
+--R                   2        3
+--R             (32a c d + 8b c )x
+--R        *
+--R            +-+ +-+
+--R           \|c \|d
+--R    /
+--R                                +--------+
+--R           2 2          +-+ +-+ |   2             3 4        2 2      2   +-+
+--R       (32d x  + 64c d)\|c \|d \|d x  + c  + (- 8d x  - 64c d x  - 64c d)\|d
+--R     ,
+--R
+--R                                                            +--------+
+--R                      2       2   2        2         3  +-+ |   2
+--R             ((32a c d  - 8b c d)x  + 64a c d - 16b c )\|c \|d x  + c
+--R           + 
+--R                    3       2 2  4           2 2        3   2        3         4
+--R           (- 8a c d  + 2b c d )x  + (- 64a c d  + 16b c d)x  - 64a c d + 16b c
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- d \|d x  + c  - \|- d \|c
+--R           atan(------------------------------)
+--R                              d x
+--R       + 
+--R                   3 7          3          2  5             2        2   3
+--R             - 2b d x  + (- 4a d  - 17b c d )x  + (- 32a c d  - 24b c d)x
+--R           + 
+--R                     2        3
+--R             (- 32a c d - 8b c )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- d \|d x  + c
+--R       + 
+--R                 3 7         3          2  5           2        2   3
+--R             8b d x  + (16a d  + 28b c d )x  + (48a c d  + 28b c d)x
+--R           + 
+--R                   2        3
+--R             (32a c d + 8b c )x
+--R        *
+--R            +---+ +-+
+--R           \|- d \|c
+--R    /
+--R                                    +--------+
+--R             2 2          +---+ +-+ |   2
+--R         (32d x  + 64c d)\|- d \|c \|d x  + c
+--R       + 
+--R              3 4        2 2      2   +---+
+--R         (- 8d x  - 64c d x  - 64c d)\|- d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2581
+
+--S 2582 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         2     2 2   4       2   2          2      2 3  2
+--R               (16a b c d  - 4b c d)x  + (16a c d  + 28a b c d - 8b c )x
+--R             + 
+--R                  2 2          3
+--R               32a c d - 8a b c
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|d x  + c
+--R         + 
+--R                      3    2 2 2  6        2   3          2 2     2 3   4
+--R           (- 4a b c d  + b c d )x  + (- 4a c d  - 31a b c d  + 8b c d)x
+--R         + 
+--R                 2 2 2          3      2 4  2      2 3          4
+--R           (- 32a c d  - 24a b c d + 8b c )x  - 32a c d + 8a b c
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|c \|d  - d x)\|d x  + c  + (- d x  - c)\|d  + d x\|c
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|c \|d x  + c  - c
+--R     + 
+--R                                                           +--------+
+--R                      2       2   2        2        3  +-+ |   2
+--R           ((- 16a c d  + 4b c d)x  - 32a c d + 8b c )\|c \|d x  + c
+--R         + 
+--R                  3      2 2  4         2 2       3   2        3        4
+--R           (4a c d  - b c d )x  + (32a c d  - 8b c d)x  + 32a c d - 8b c
+--R      *
+--R          +-------------------+           +-+
+--R          | 2 4         2    2          x\|d
+--R         \|b x  + 2a b x  + a  atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|d x  + c
+--R     + 
+--R                   3 7        3          2  5           2        2   3
+--R               2b d x  + (4a d  + 17b c d )x  + (32a c d  + 24b c d)x
+--R             + 
+--R                     2        3
+--R               (32a c d + 8b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|d \|d x  + c
+--R         + 
+--R                     3 7           3          2  5             2        2   3
+--R               - 8b d x  + (- 16a d  - 28b c d )x  + (- 48a c d  - 28b c d)x
+--R             + 
+--R                       2        3
+--R               (- 32a c d - 8b c )x
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               2 3 9            3      2   2  7
+--R           - 2b d x  + (- 6a b d  - 17b c d )x
+--R         + 
+--R                2 3            2      2 2   5
+--R           (- 4a d  - 49a b c d  - 24b c d)x
+--R         + 
+--R                 2   2          2      2 3  3         2 2          3
+--R           (- 32a c d  - 56a b c d - 8b c )x  + (- 32a c d - 8a b c )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|d \|d x  + c
+--R     + 
+--R             2 3 9           3      2   2  7       2 3            2      2 2   5
+--R           8b d x  + (24a b d  + 28b c d )x  + (16a d  + 76a b c d  + 28b c d)x
+--R         + 
+--R               2   2          2      2 3  3       2 2          3
+--R           (48a c d  + 60a b c d + 8b c )x  + (32a c d + 8a b c )x
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R  /
+--R                                                           +--------+
+--R             2 4         2            2            +-+ +-+ |   2
+--R       (32b d x  + (32a d  + 64b c d)x  + 64a c d)\|c \|d \|d x  + c
+--R     + 
+--R                   3 6          3          2  4             2        2   2
+--R             - 8b d x  + (- 8a d  - 64b c d )x  + (- 64a c d  - 64b c d)x
+--R           + 
+--R                    2
+--R             - 64a c d
+--R      *
+--R          +-+
+--R         \|d
+--R                                                    Type: Expression(Integer)
+--E 2582
+
+--S 2583 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        6 14         6          5  12
+--R                   - b d x   + (- a d  - 61b c d )x
+--R                 + 
+--R                             5         2 4  10            2 4          3 3  8
+--R                   (- 61a c d  - 620b c d )x   + (- 620a c d  - 2352b c d )x
+--R                 + 
+--R                             3 3          4 2  6             4 2          5   4
+--R                   (- 2352a c d  - 4096b c d )x  + (- 4096a c d  - 3328b c d)x
+--R                 + 
+--R                             5           6  2          6
+--R                   (- 3328a c d - 1024b c )x  - 1024a c
+--R              *
+--R                  +-+
+--R                 \|d
+--R             + 
+--R                        6 13         6           5  11
+--R                   11b d x   + (11a d  + 220b c d )x
+--R                 + 
+--R                            5          2 4  9           2 4          3 3  7
+--R                   (220a c d  + 1232b c d )x  + (1232a c d  + 2816b c d )x
+--R                 + 
+--R                           3 3          4 2  5           4 2          5   3
+--R                   (2816a c d  + 2816b c d )x  + (2816a c d  + 1024b c d)x
+--R                 + 
+--R                          5
+--R                   1024a c d x
+--R              *
+--R                  +-+
+--R                 \|c
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|d x  + c
+--R         + 
+--R                    6 14         6           5  12            5          2 4  10
+--R               11b d x   + (11a d  + 231b c d )x   + (231a c d  + 1452b c d )x
+--R             + 
+--R                       2 4          3 3  8           3 3          4 2  6
+--R               (1452a c d  + 4048b c d )x  + (4048a c d  + 5632b c d )x
+--R             + 
+--R                       4 2          5   4           5           6  2          6
+--R               (5632a c d  + 3840b c d)x  + (3840a c d + 1024b c )x  + 1024a c
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R                7 15         7          6  13             6         2 5  11
+--R           - b d x   + (- a d  - 61b c d )x   + (- 61a c d  - 620b c d )x
+--R         + 
+--R                    2 5          3 4  9             3 4          4 3  7
+--R           (- 620a c d  - 2352b c d )x  + (- 2352a c d  - 4096b c d )x
+--R         + 
+--R                     4 3          5 2  5             5 2          6   3
+--R           (- 4096a c d  - 3328b c d )x  + (- 3328a c d  - 1024b c d)x
+--R         + 
+--R                    6
+--R           - 1024a c d x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                2 6 16          6      2   5  14
+--R               b d x   + (2a b d  + 61b c d )x
+--R             + 
+--R                 2 6             5       2 2 4  12
+--R               (a d  + 122a b c d  + 620b c d )x
+--R             + 
+--R                   2   5            2 4        2 3 3  10
+--R               (61a c d  + 1240a b c d  + 2352b c d )x
+--R             + 
+--R                    2 2 4            3 3        2 4 2  8
+--R               (620a c d  + 4704a b c d  + 4096b c d )x
+--R             + 
+--R                     2 3 3            4 2        2 5   6
+--R               (2352a c d  + 8192a b c d  + 3328b c d)x
+--R             + 
+--R                     2 4 2            5         2 6  4
+--R               (4096a c d  + 6656a b c d + 1024b c )x
+--R             + 
+--R                     2 5             6  2        2 6
+--R               (3328a c d + 2048a b c )x  + 1024a c
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                    2 6 15             6       2   5  13
+--R               - 11b d x   + (- 22a b d  - 220b c d )x
+--R             + 
+--R                     2 6             5        2 2 4  11
+--R               (- 11a d  - 440a b c d  - 1232b c d )x
+--R             + 
+--R                      2   5            2 4        2 3 3  9
+--R               (- 220a c d  - 2464a b c d  - 2816b c d )x
+--R             + 
+--R                       2 2 4            3 3        2 4 2  7
+--R               (- 1232a c d  - 5632a b c d  - 2816b c d )x
+--R             + 
+--R                       2 3 3            4 2        2 5   5
+--R               (- 2816a c d  - 5632a b c d  - 1024b c d)x
+--R             + 
+--R                       2 4 2            5   3        2 5
+--R               (- 2816a c d  - 2048a b c d)x  - 1024a c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R                2 6 16             6       2   5  14
+--R           - 11b d x   + (- 22a b d  - 231b c d )x
+--R         + 
+--R                 2 6             5        2 2 4  12
+--R           (- 11a d  - 462a b c d  - 1452b c d )x
+--R         + 
+--R                  2   5            2 4        2 3 3  10
+--R           (- 231a c d  - 2904a b c d  - 4048b c d )x
+--R         + 
+--R                   2 2 4            3 3        2 4 2  8
+--R           (- 1452a c d  - 8096a b c d  - 5632b c d )x
+--R         + 
+--R                   2 3 3             4 2        2 5   6
+--R           (- 4048a c d  - 11264a b c d  - 3840b c d)x
+--R         + 
+--R                   2 4 2            5         2 6  4
+--R           (- 5632a c d  - 7680a b c d - 1024b c )x
+--R         + 
+--R                   2 5             6  2        2 6
+--R           (- 3840a c d - 2048a b c )x  - 1024a c
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R     + 
+--R        2 7 17          7      2   6  15     2 7             6       2 2 5  13
+--R       b d x   + (2a b d  + 61b c d )x   + (a d  + 122a b c d  + 620b c d )x
+--R     + 
+--R           2   6            2 5        2 3 4  11
+--R       (61a c d  + 1240a b c d  + 2352b c d )x
+--R     + 
+--R            2 2 5            3 4        2 4 3  9
+--R       (620a c d  + 4704a b c d  + 4096b c d )x
+--R     + 
+--R             2 3 4            4 3        2 5 2  7
+--R       (2352a c d  + 8192a b c d  + 3328b c d )x
+--R     + 
+--R             2 4 3            5 2        2 6   5         2 5 2            6   3
+--R       (4096a c d  + 6656a b c d  + 1024b c d)x  + (3328a c d  + 2048a b c d)x
+--R     + 
+--R            2 6
+--R       1024a c d x
+--R  /
+--R                    5 10         4 8        2 3 6        3 2 4        4   2
+--R                 11d x   + 220c d x  + 1232c d x  + 2816c d x  + 2816c d x
+--R               + 
+--R                      5
+--R                 1024c
+--R            *
+--R                +-+ +-+
+--R               \|c \|d
+--R           + 
+--R              6 11        5 9       2 4 7        3 3 5        4 2 3        5
+--R           - d x   - 60c d x  - 560c d x  - 1792c d x  - 2304c d x  - 1024c d x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|d x  + c
+--R       + 
+--R                6 12        5 10       2 4 8        3 3 6        4 2 4
+--R             - d x   - 61c d x   - 620c d x  - 2352c d x  - 4096c d x
+--R           + 
+--R                    5   2        6
+--R             - 3328c d x  - 1024c
+--R        *
+--R            +-+
+--R           \|d
+--R       + 
+--R                6 11         5 9        2 4 7        3 3 5        4 2 3
+--R             11d x   + 220c d x  + 1232c d x  + 2816c d x  + 2816c d x
+--R           + 
+--R                  5
+--R             1024c d x
+--R        *
+--R            +-+
+--R           \|c
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2583
+
+--S 2584 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                 +--------+
+--R                      2       2   2        2        3  +---+ +-+ |   2
+--R           ((- 16a c d  + 4b c d)x  - 32a c d + 8b c )\|- d \|c \|d x  + c
+--R         + 
+--R                 3      2 2  4         2 2       3   2        3        4  +---+
+--R         ((4a c d  - b c d )x  + (32a c d  - 8b c d)x  + 32a c d - 8b c )\|- d
+--R      *
+--R          +-------------------+           +-+
+--R          | 2 4         2    2          x\|d
+--R         \|b x  + 2a b x  + a  atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|d x  + c
+--R     + 
+--R                         2     2 2   4       2   2          2       2 3  2
+--R               (32a b c d  - 8b c d)x  + (32a c d  + 56a b c d - 16b c )x
+--R             + 
+--R                  2 2           3
+--R               64a c d - 16a b c
+--R          *
+--R                      +--------+
+--R              +-+ +-+ |   2
+--R             \|c \|d \|d x  + c
+--R         + 
+--R                          3     2 2 2  6        2   3          2 2      2 3   4
+--R               (- 8a b c d  + 2b c d )x  + (- 8a c d  - 62a b c d  + 16b c d)x
+--R             + 
+--R                     2 2 2          3       2 4  2      2 3           4
+--R               (- 64a c d  - 48a b c d + 16b c )x  - 64a c d + 16a b c
+--R          *
+--R              +-+
+--R             \|d
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- d \|d x  + c  - \|- d \|c
+--R         atan(------------------------------)
+--R                            d x
+--R     + 
+--R                   3 7        3          2  5           2        2   3
+--R               2b d x  + (4a d  + 17b c d )x  + (32a c d  + 24b c d)x
+--R             + 
+--R                     2        3
+--R               (32a c d + 8b c )x
+--R          *
+--R                        +--------+
+--R              +---+ +-+ |   2
+--R             \|- d \|d \|d x  + c
+--R         + 
+--R                     3 7           3          2  5             2        2   3
+--R               - 8b d x  + (- 16a d  - 28b c d )x  + (- 48a c d  - 28b c d)x
+--R             + 
+--R                       2        3
+--R               (- 32a c d - 8b c )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- d \|c \|d
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               2 3 9            3      2   2  7
+--R           - 2b d x  + (- 6a b d  - 17b c d )x
+--R         + 
+--R                2 3            2      2 2   5
+--R           (- 4a d  - 49a b c d  - 24b c d)x
+--R         + 
+--R                 2   2          2      2 3  3         2 2          3
+--R           (- 32a c d  - 56a b c d - 8b c )x  + (- 32a c d - 8a b c )x
+--R      *
+--R                    +--------+
+--R          +---+ +-+ |   2
+--R         \|- d \|d \|d x  + c
+--R     + 
+--R             2 3 9           3      2   2  7       2 3            2      2 2   5
+--R           8b d x  + (24a b d  + 28b c d )x  + (16a d  + 76a b c d  + 28b c d)x
+--R         + 
+--R               2   2          2      2 3  3       2 2          3
+--R           (48a c d  + 60a b c d + 8b c )x  + (32a c d + 8a b c )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- d \|c \|d
+--R  /
+--R                                                                 +--------+
+--R             2 4         2            2            +---+ +-+ +-+ |   2
+--R       (32b d x  + (32a d  + 64b c d)x  + 64a c d)\|- d \|c \|d \|d x  + c
+--R     + 
+--R                   3 6          3          2  4             2        2   2
+--R             - 8b d x  + (- 8a d  - 64b c d )x  + (- 64a c d  - 64b c d)x
+--R           + 
+--R                    2
+--R             - 64a c d
+--R      *
+--R          +---+ +-+
+--R         \|- d \|d
+--R                                                    Type: Expression(Integer)
+--E 2584
+
+--S 2585 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                      +-------------------+
+--R             4               2        | 2 4         2    2     2   6
+--R       (b d x  + (a d + b c)x  + a c)\|b x  + 2a b x  + a   - b d x
+--R     + 
+--R                    2   4       2            2    2
+--R       (- 2a b d - b c)x  + (- a d - 2a b c)x  - a c
+--R  /
+--R      +--------+ +-------------------+
+--R      |   2      | 2 4         2    2
+--R     \|d x  + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2585
+
+)clear all
+
+--S 2586 of 3139
+t0:=sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x
+--R 
+--R
+--R         +--------+ +-------------------+
+--R         |   2      | 2 4         2    2
+--R        \|d x  + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 2586
+
+--S 2587 of 3139
+r0:=1/3*b*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))-_
+   a*atanh(sqrt(c+d*x^2)/sqrt(c))*sqrt(c)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)+a*sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R                                              +--------+
+--R                  +-------------------+       |   2
+--R              +-+ | 2 4         2    2       \|d x  + c
+--R       - 3a d\|c \|b x  + 2a b x  + a  atanh(-----------)
+--R                                                  +-+
+--R                                                 \|c
+--R     + 
+--R                             +--------+ +-------------------+
+--R             2               |   2      | 2 4         2    2
+--R       (b d x  + 3a d + b c)\|d x  + c \|b x  + 2a b x  + a
+--R  /
+--R           2
+--R     3b d x  + 3a d
+--R                                                    Type: Expression(Integer)
+--E 2587
+
+--S 2588 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                               +--------+
+--R                   2        2  |   2                   2        2  +-+
+--R         ((3a c d x  + 12a c )\|d x  + c  + (- 9a c d x  - 12a c )\|c )
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|d x  + c  - \|c
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                            +--------+
+--R                  4                   2  2  |   2
+--R       (- 3b c d x  + (- 6a c d - 6b c )x )\|d x  + c
+--R     + 
+--R           2 6        2           4                 2  2  +-+
+--R       (b d x  + (3a d  + 6b c d)x  + (6a c d + 6b c )x )\|c
+--R  /
+--R                       +--------+
+--R          2        +-+ |   2              2      2
+--R     (3d x  + 12c)\|c \|d x  + c  - 9c d x  - 12c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2588
+
+--S 2589 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                             +--------+
+--R                    2 4      2   2          2   2      2 2   |   2
+--R           (3a b c d x  + (3a c d  + 12a b c d)x  + 12a c d)\|d x  + c
+--R         + 
+--R                      2 4        2   2          2   2      2 2   +-+
+--R           (- 9a b c d x  + (- 9a c d  - 12a b c d)x  - 12a c d)\|c
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|d x  + c  - \|c
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                +--------+
+--R                 2 2        2   |   2                 2 2        2   +-+
+--R         ((3a c d x  + 12a c d)\|d x  + c  + (- 9a c d x  - 12a c d)\|c )
+--R      *
+--R                                      +--------+
+--R          +-------------------+       |   2
+--R          | 2 4         2    2       \|d x  + c
+--R         \|b x  + 2a b x  + a  atanh(-----------)
+--R                                          +-+
+--R                                         \|c
+--R     + 
+--R                                                                +--------+
+--R                  2 4          2       2   2        2        3  |   2
+--R           (3b c d x  + (9a c d  + 7b c d)x  + 12a c d + 4b c )\|d x  + c
+--R         + 
+--R                    3 6          3         2  4             2       2   2
+--R               - b d x  + (- 3a d  - 6b c d )x  + (- 15a c d  - 9b c d)x
+--R             + 
+--R                      2        3
+--R               - 12a c d - 4b c
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              2   2 6              2     2 2   4        2   2         2   2
+--R         (- 3b c d x  + (- 9a b c d  - 6b c d)x  + (- 6a c d  - 6a b c d)x )
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R            2 3 8          3     2   2  6      2 3            2     2 2   4
+--R           b d x  + (4a b d  + 6b c d )x  + (3a d  + 12a b c d  + 6b c d)x
+--R         + 
+--R              2   2         2   2
+--R           (6a c d  + 6a b c d)x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                                     +--------+
+--R            2 4        2            2            +-+ |   2              2 4
+--R       (3b d x  + (3a d  + 12b c d)x  + 12a c d)\|c \|d x  + c  - 9b c d x
+--R     + 
+--R                2        2   2        2
+--R       (- 9a c d  - 12b c d)x  - 12a c d
+--R                                                    Type: Expression(Integer)
+--E 2589
+
+--S 2590 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     3 8          3          2  6             2         2   4
+--R               - 7b d x  + (- 7a d  - 56b c d )x  + (- 56a c d  - 112b c d)x
+--R             + 
+--R                        2         3  2        3
+--R               (- 112a c d - 64b c )x  - 64a c
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|d x  + c
+--R         + 
+--R              4 10       4          3  8           3         2 2  6
+--R           b d x   + (a d  + 25b c d )x  + (25a c d  + 104b c d )x
+--R         + 
+--R                  2 2         3   4          3         4  2        4
+--R           (104a c d  + 144b c d)x  + (144a c d + 64b c )x  + 64a c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             2 3 10           3      2   2  8
+--R           7b d x   + (14a b d  + 56b c d )x
+--R         + 
+--R              2 3             2       2 2   6
+--R           (7a d  + 112a b c d  + 112b c d)x
+--R         + 
+--R             2   2           2       2 3  4        2 2            3  2      2 3
+--R         (56a c d  + 224a b c d + 64b c )x  + (112a c d + 128a b c )x  + 64a c
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|d x  + c
+--R     + 
+--R          2 4 12            4      2   3  10
+--R       - b d x   + (- 2a b d  - 25b c d )x
+--R     + 
+--R           2 4            3       2 2 2  8
+--R       (- a d  - 50a b c d  - 104b c d )x
+--R     + 
+--R             2   3           2 2       2 3   6
+--R       (- 25a c d  - 208a b c d  - 144b c d)x
+--R     + 
+--R            2 2 2           3       2 4  4          2 3            4  2      2 4
+--R     (- 104a c d  - 288a b c d - 64b c )x  + (- 144a c d - 128a b c )x  - 64a c
+--R  /
+--R                                              +--------+
+--R           3 7        2 5      2   3      3   |   2
+--R         (d x  + 24c d x  + 80c d x  + 64c x)\|d x  + c
+--R       + 
+--R              3 7        2 5       2   3      3   +-+
+--R         (- 7d x  - 56c d x  - 112c d x  - 64c x)\|c
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2590
+
+)clear all
+
+--S 2591 of 3139
+t0:=sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^2
+--R 
+--R
+--R         +--------+ +-------------------+
+--R         |   2      | 2 4         2    2
+--R        \|d x  + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------
+--R                         2
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 2591
+
+--S 2592 of 3139
+r0:=-a*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*x*(a+b*x^2))+_
+   1/2*(b*c+2*a*d)*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/((a+b*x^2)*sqrt(d))+1/2*(b*c+2*a*d)*x*sqrt(c+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                     +-------------------+           +-+
+--R                     | 2 4         2    2          x\|d
+--R       (2a d + b c)x\|b x  + 2a b x  + a  atanh(-----------)
+--R                                                 +--------+
+--R                                                 |   2
+--R                                                \|d x  + c
+--R     + 
+--R                       +--------+ +-------------------+
+--R           2       +-+ |   2      | 2 4         2    2
+--R       (b x  - 2a)\|d \|d x  + c \|b x  + 2a b x  + a
+--R  /
+--R          3         +-+
+--R     (2b x  + 2a x)\|d
+--R                                                    Type: Expression(Integer)
+--E 2592
+
+--S 2593 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                     +--------+
+--R                   2          3                 2    |   2
+--R             ((2a d  + b c d)x  + (8a c d + 4b c )x)\|d x  + c
+--R           + 
+--R                     2           3                   2    +-+
+--R             ((- 6a d  - 3b c d)x  + (- 8a c d - 4b c )x)\|c
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|c \|d  - d x)\|d x  + c  + (- d x  - c)\|d  + d x\|c
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|c \|d x  + c  - c
+--R       + 
+--R                                                      +--------+
+--R                  4                 2         +-+ +-+ |   2
+--R         (- 3b d x  + (6a d - 4b c)x  + 8a c)\|c \|d \|d x  + c
+--R       + 
+--R             2 6          2           4                    2  2       2  +-+
+--R         (b d x  + (- 2a d  + 5b c d)x  + (- 10a c d + 4b c )x  - 8a c )\|d
+--R    /
+--R                          +--------+
+--R            3         +-+ |   2               3         +-+ +-+
+--R       (2d x  + 8c x)\|d \|d x  + c  + (- 6d x  - 8c x)\|c \|d
+--R     ,
+--R
+--R                                                       +--------+
+--R                   2           3                  2    |   2
+--R             ((4a d  + 2b c d)x  + (16a c d + 8b c )x)\|d x  + c
+--R           + 
+--R                      2           3                    2    +-+
+--R             ((- 12a d  - 6b c d)x  + (- 16a c d - 8b c )x)\|c
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- d \|d x  + c  - \|- d \|c
+--R           atan(------------------------------)
+--R                              d x
+--R       + 
+--R                                                        +--------+
+--R                  4                 2         +---+ +-+ |   2
+--R         (- 3b d x  + (6a d - 4b c)x  + 8a c)\|- d \|c \|d x  + c
+--R       + 
+--R             2 6          2           4                    2  2       2  +---+
+--R         (b d x  + (- 2a d  + 5b c d)x  + (- 10a c d + 4b c )x  - 8a c )\|- d
+--R    /
+--R                            +--------+
+--R            3         +---+ |   2               3         +---+ +-+
+--R       (2d x  + 8c x)\|- d \|d x  + c  + (- 6d x  - 8c x)\|- d \|c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2593
+
+--S 2594 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2    2     5      2 2                2 2  3
+--R               (2a b d  + b c d)x  + (2a d  + 9a b c d + 4b c )x
+--R             + 
+--R                  2            2
+--R               (8a c d + 4a b c )x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|d x  + c
+--R         + 
+--R                        2     2     5        2 2                 2 2  3
+--R               (- 6a b d  - 3b c d)x  + (- 6a d  - 11a b c d - 4b c )x
+--R             + 
+--R                    2            2
+--R               (- 8a c d - 4a b c )x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|c \|d  - d x)\|d x  + c  + (- d x  - c)\|d  + d x\|c
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|c \|d x  + c  - c
+--R     + 
+--R                                                       +--------+
+--R                   2          3                   2    |   2
+--R           ((- 2a d  - b c d)x  + (- 8a c d - 4b c )x)\|d x  + c
+--R         + 
+--R                 2           3                 2    +-+
+--R           ((6a d  + 3b c d)x  + (8a c d + 4b c )x)\|c
+--R      *
+--R          +-------------------+           +-+
+--R          | 2 4         2    2          x\|d
+--R         \|b x  + 2a b x  + a  atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|d x  + c
+--R     + 
+--R                                                        +--------+
+--R                  4                   2         +-+ +-+ |   2
+--R           (3b d x  + (- 6a d + 4b c)x  - 8a c)\|c \|d \|d x  + c
+--R         + 
+--R                 2 6        2           4                  2  2       2  +-+
+--R           (- b d x  + (2a d  - 5b c d)x  + (10a c d - 4b c )x  + 8a c )\|d
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              2   6               2   4      2            2     2   +-+ +-+
+--R         (- 3b d x  + (3a b d - 4b c)x  + (6a d + 4a b c)x  + 8a c)\|c \|d
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R            2 2 8           2     2     6        2 2                2 2  4
+--R           b d x  + (- a b d  + 5b c d)x  + (- 2a d  - 5a b c d + 4b c )x
+--R         + 
+--R                 2            2  2     2 2
+--R           (- 10a c d - 4a b c )x  - 8a c
+--R      *
+--R          +-+
+--R         \|d
+--R  /
+--R                                                +--------+
+--R              5                 3           +-+ |   2
+--R       (2b d x  + (2a d + 8b c)x  + 8a c x)\|d \|d x  + c
+--R     + 
+--R                5                   3           +-+ +-+
+--R       (- 6b d x  + (- 6a d - 8b c)x  - 8a c x)\|c \|d
+--R                                                    Type: Expression(Integer)
+--E 2594
+
+--S 2595 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        5 12         5          4  10
+--R                   - b d x   + (- a d  - 41b c d )x
+--R                 + 
+--R                             4         2 3  8            2 3         3 2  6
+--R                   (- 41a c d  - 280b c d )x  + (- 280a c d  - 688b c d )x
+--R                 + 
+--R                          3 2         4   4            4          5  2         5
+--R                 (- 688a c d  - 704b c d)x  + (- 704a c d - 256b c )x  - 256a c
+--R              *
+--R                  +-+
+--R                 \|d
+--R             + 
+--R                       5 11        5           4  9            4         2 3  7
+--R                   9b d x   + (9a d  + 120b c d )x  + (120a c d  + 432b c d )x
+--R                 + 
+--R                          2 3         3 2  5          3 2         4   3
+--R                   (432a c d  + 576b c d )x  + (576a c d  + 256b c d)x
+--R                 + 
+--R                         4
+--R                   256a c d x
+--R              *
+--R                  +-+
+--R                 \|c
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|d x  + c
+--R         + 
+--R                   5 12        5           4  10            4         2 3  8
+--R               9b d x   + (9a d  + 129b c d )x   + (129a c d  + 552b c d )x
+--R             + 
+--R                      2 3          3 2  6           3 2         4   4
+--R               (552a c d  + 1008b c d )x  + (1008a c d  + 832b c d)x
+--R             + 
+--R                      4          5  2         5
+--R               (832a c d + 256b c )x  + 256a c
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R         + 
+--R                6 13         6          5  11             5         2 4  9
+--R           - b d x   + (- a d  - 41b c d )x   + (- 41a c d  - 280b c d )x
+--R         + 
+--R                    2 4         3 3  7            3 3         4 2  5
+--R           (- 280a c d  - 688b c d )x  + (- 688a c d  - 704b c d )x
+--R         + 
+--R                    4 2         5   3         5
+--R           (- 704a c d  - 256b c d)x  - 256a c d x
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                2 5 14          5      2   4  12
+--R               b d x   + (2a b d  + 41b c d )x
+--R             + 
+--R                 2 5            4       2 2 3  10
+--R               (a d  + 82a b c d  + 280b c d )x
+--R             + 
+--R                   2   4           2 3       2 3 2  8
+--R               (41a c d  + 560a b c d  + 688b c d )x
+--R             + 
+--R                    2 2 3            3 2       2 4   6
+--R               (280a c d  + 1376a b c d  + 704b c d)x
+--R             + 
+--R                    2 3 2            4        2 5  4        2 4            5  2
+--R               (688a c d  + 1408a b c d + 256b c )x  + (704a c d + 512a b c )x
+--R             + 
+--R                   2 5
+--R               256a c
+--R          *
+--R              +-+
+--R             \|d
+--R         + 
+--R                   2 5 13             5       2   4  11
+--R               - 9b d x   + (- 18a b d  - 120b c d )x
+--R             + 
+--R                    2 5             4       2 2 3  9
+--R               (- 9a d  - 240a b c d  - 432b c d )x
+--R             + 
+--R                      2   4           2 3       2 3 2  7
+--R               (- 120a c d  - 864a b c d  - 576b c d )x
+--R             + 
+--R                      2 2 3            3 2       2 4   5
+--R               (- 432a c d  - 1152a b c d  - 256b c d)x
+--R             + 
+--R                      2 3 2           4   3       2 4
+--R               (- 576a c d  - 512a b c d)x  - 256a c d x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|d x  + c
+--R     + 
+--R               2 5 14             5       2   4  12
+--R           - 9b d x   + (- 18a b d  - 129b c d )x
+--R         + 
+--R                2 5             4       2 2 3  10
+--R           (- 9a d  - 258a b c d  - 552b c d )x
+--R         + 
+--R                  2   4            2 3        2 3 2  8
+--R           (- 129a c d  - 1104a b c d  - 1008b c d )x
+--R         + 
+--R                  2 2 3            3 2       2 4   6
+--R           (- 552a c d  - 2016a b c d  - 832b c d)x
+--R         + 
+--R                   2 3 2            4        2 5  4          2 4            5  2
+--R           (- 1008a c d  - 1664a b c d - 256b c )x  + (- 832a c d - 512a b c )x
+--R         + 
+--R                 2 5
+--R           - 256a c
+--R      *
+--R          +-+ +-+
+--R         \|c \|d
+--R     + 
+--R        2 6 15          6      2   5  13     2 6            5       2 2 4  11
+--R       b d x   + (2a b d  + 41b c d )x   + (a d  + 82a b c d  + 280b c d )x
+--R     + 
+--R           2   5           2 4       2 3 3  9
+--R       (41a c d  + 560a b c d  + 688b c d )x
+--R     + 
+--R            2 2 4            3 3       2 4 2  7
+--R       (280a c d  + 1376a b c d  + 704b c d )x
+--R     + 
+--R            2 3 3            4 2       2 5   5        2 4 2           5   3
+--R       (688a c d  + 1408a b c d  + 256b c d)x  + (704a c d  + 512a b c d)x
+--R     + 
+--R           2 5
+--R       256a c d x
+--R  /
+--R                4 10         3 8       2 2 6       3   4       4 2  +-+ +-+
+--R             (9d x   + 120c d x  + 432c d x  + 576c d x  + 256c x )\|c \|d
+--R           + 
+--R                5 11        4 9       2 3 7       3 2 5       4   3
+--R             - d x   - 40c d x  - 240c d x  - 448c d x  - 256c d x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|d x  + c
+--R       + 
+--R             5 12        4 10       2 3 8       3 2 6       4   4       5 2  +-+
+--R         (- d x   - 41c d x   - 280c d x  - 688c d x  - 704c d x  - 256c x )\|d
+--R       + 
+--R            5 11         4 9       2 3 7       3 2 5       4   3  +-+
+--R         (9d x   + 120c d x  + 432c d x  + 576c d x  + 256c d x )\|c
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2595
+
+--S 2596 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                             +--------+
+--R                   2          3                   2    +---+ |   2
+--R           ((- 2a d  - b c d)x  + (- 8a c d - 4b c )x)\|- d \|d x  + c
+--R         + 
+--R                 2           3                 2    +---+ +-+
+--R           ((6a d  + 3b c d)x  + (8a c d + 4b c )x)\|- d \|c
+--R      *
+--R          +-------------------+           +-+
+--R          | 2 4         2    2          x\|d
+--R         \|b x  + 2a b x  + a  atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|d x  + c
+--R     + 
+--R                      2     2     5      2 2                 2 2  3
+--R               (4a b d  + 2b c d)x  + (4a d  + 18a b c d + 8b c )x
+--R             + 
+--R                   2            2
+--R               (16a c d + 8a b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|d \|d x  + c
+--R         + 
+--R                         2     2     5         2 2                 2 2  3
+--R               (- 12a b d  - 6b c d)x  + (- 12a d  - 22a b c d - 8b c )x
+--R             + 
+--R                     2            2
+--R               (- 16a c d - 8a b c )x
+--R          *
+--R              +-+ +-+
+--R             \|c \|d
+--R      *
+--R                     +--------+
+--R               +---+ |   2         +---+ +-+
+--R              \|- d \|d x  + c  - \|- d \|c
+--R         atan(------------------------------)
+--R                            d x
+--R     + 
+--R                                                              +--------+
+--R                  4                   2         +---+ +-+ +-+ |   2
+--R           (3b d x  + (- 6a d + 4b c)x  - 8a c)\|- d \|c \|d \|d x  + c
+--R         + 
+--R               2 6        2           4                  2  2       2  +---+ +-+
+--R         (- b d x  + (2a d  - 5b c d)x  + (10a c d - 4b c )x  + 8a c )\|- d \|d
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              2   6               2   4      2            2     2   +---+ +-+
+--R         (- 3b d x  + (3a b d - 4b c)x  + (6a d + 4a b c)x  + 8a c)\|- d \|c
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|d \|d x  + c
+--R     + 
+--R            2 2 8           2     2     6        2 2                2 2  4
+--R           b d x  + (- a b d  + 5b c d)x  + (- 2a d  - 5a b c d + 4b c )x
+--R         + 
+--R                 2            2  2     2 2
+--R           (- 10a c d - 4a b c )x  - 8a c
+--R      *
+--R          +---+ +-+
+--R         \|- d \|d
+--R  /
+--R                                                      +--------+
+--R              5                 3           +---+ +-+ |   2
+--R       (2b d x  + (2a d + 8b c)x  + 8a c x)\|- d \|d \|d x  + c
+--R     + 
+--R                5                   3           +---+ +-+ +-+
+--R       (- 6b d x  + (- 6a d - 8b c)x  - 8a c x)\|- d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 2596
+
+--S 2597 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                      +-------------------+
+--R             4               2        | 2 4         2    2     2   6
+--R       (b d x  + (a d + b c)x  + a c)\|b x  + 2a b x  + a   - b d x
+--R     + 
+--R                    2   4       2            2    2
+--R       (- 2a b d - b c)x  + (- a d - 2a b c)x  - a c
+--R  /
+--R        +--------+ +-------------------+
+--R      2 |   2      | 2 4         2    2
+--R     x \|d x  + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2597
+
+)clear all
+
+--S 2598 of 3139
+t0:=sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3
+--R 
+--R
+--R         +--------+ +-------------------+
+--R         |   2      | 2 4         2    2
+--R        \|d x  + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------
+--R                         3
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 2598
+
+--S 2599 of 3139
+r0:=-1/2*a*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*x^2*(a+b*x^2))-_
+   1/2*(2*b*c+a*d)*atanh(sqrt(c+d*x^2)/sqrt(c))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/((a+b*x^2)*sqrt(c))+1/2*(2*b*c+a*d)*sqrt(c+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                                    +--------+
+--R                        +-------------------+       |   2
+--R                      2 | 2 4         2    2       \|d x  + c
+--R       (- a d - 2b c)x \|b x  + 2a b x  + a  atanh(-----------)
+--R                                                        +-+
+--R                                                       \|c
+--R     + 
+--R                       +--------+ +-------------------+
+--R            2      +-+ |   2      | 2 4         2    2
+--R       (2b x  - a)\|c \|d x  + c \|b x  + 2a b x  + a
+--R  /
+--R          4       2  +-+
+--R     (2b x  + 2a x )\|c
+--R                                                    Type: Expression(Integer)
+--E 2599
+
+--S 2600 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                    +--------+
+--R                2           4                 2  2  |   2
+--R           ((a d  + 2b c d)x  + (4a c d + 8b c )x )\|d x  + c
+--R         + 
+--R                   2           4                   2  2  +-+
+--R           ((- 3a d  - 6b c d)x  + (- 4a c d - 8b c )x )\|c
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|d x  + c  - \|c
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                         +--------+
+--R                  4           2       2  |   2
+--R       (- 4b c d x  + 3a c d x  + 4a c )\|d x  + c
+--R     + 
+--R            2 6         2           4           2       2  +-+
+--R       (2b d x  + (- a d  + 4b c d)x  - 5a c d x  - 4a c )\|c
+--R  /
+--R                         +--------+
+--R          4       2  +-+ |   2              4     2 2
+--R     (2d x  + 8c x )\|c \|d x  + c  - 6c d x  - 8c x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2600
+
+--S 2601 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     2     2     6     2 2                2 2  4
+--R               (a b d  + 2b c d)x  + (a d  + 6a b c d + 8b c )x
+--R             + 
+--R                  2            2  2
+--R               (4a c d + 8a b c )x
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|d x  + c
+--R         + 
+--R                      2     2 2   6        2   2          2      2 3  4
+--R           (- 3a b c d  - 6b c d)x  + (- 3a c d  - 10a b c d - 8b c )x
+--R         + 
+--R                2 2          3  2
+--R           (- 4a c d - 8a b c )x
+--R      *
+--R              +--------+
+--R              |   2         +-+
+--R             \|d x  + c  - \|c
+--R         log(------------------)
+--R                      x
+--R     + 
+--R                                                        +--------+
+--R                2           4                 2  2  +-+ |   2
+--R           ((a d  + 2b c d)x  + (4a c d + 8b c )x )\|c \|d x  + c
+--R         + 
+--R                    2       2   4          2        3  2
+--R           (- 3a c d  - 6b c d)x  + (- 4a c d - 8b c )x
+--R      *
+--R                                      +--------+
+--R          +-------------------+       |   2
+--R          | 2 4         2    2       \|d x  + c
+--R         \|b x  + 2a b x  + a  atanh(-----------)
+--R                                          +-+
+--R                                         \|c
+--R     + 
+--R                                                          +--------+
+--R                    4                   2  2       2  +-+ |   2              2 6
+--R           (6b c d x  + (- 3a c d + 8b c )x  - 4a c )\|c \|d x  + c  - 2b c d x
+--R         + 
+--R                 2        2   4        2        3  2       3
+--R           (a c d  - 10b c d)x  + (5a c d - 8b c )x  + 4a c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                                                                     +--------+
+--R            2     6            4      2            2  2     2 2  +-+ |   2
+--R       (- 4b c d x  - a b c d x  + (3a c d + 4a b c )x  + 4a c )\|c \|d x  + c
+--R     + 
+--R         2   2 8           2     2 2   6       2   2        2   4
+--R       2b c d x  + (a b c d  + 4b c d)x  + (- a c d  - a b c d)x
+--R     + 
+--R            2 2          3  2     2 3
+--R       (- 5a c d - 4a b c )x  - 4a c
+--R  /
+--R                                                  +--------+
+--R                6                 2  4       2 2  |   2
+--R       (2b c d x  + (2a c d + 8b c )x  + 8a c x )\|d x  + c
+--R     + 
+--R                  6                   2  4       2 2  +-+
+--R       (- 6b c d x  + (- 6a c d - 8b c )x  - 8a c x )\|c
+--R                                                    Type: Expression(Integer)
+--E 2601
+
+--S 2602 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     3 8          3          2  6             2         2   4
+--R               - 7b d x  + (- 7a d  - 56b c d )x  + (- 56a c d  - 112b c d)x
+--R             + 
+--R                        2         3  2        3
+--R               (- 112a c d - 64b c )x  - 64a c
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|c \|d x  + c
+--R         + 
+--R              4 10       4          3  8           3         2 2  6
+--R           b d x   + (a d  + 25b c d )x  + (25a c d  + 104b c d )x
+--R         + 
+--R                  2 2         3   4          3         4  2        4
+--R           (104a c d  + 144b c d)x  + (144a c d + 64b c )x  + 64a c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             2 3 10           3      2   2  8
+--R           7b d x   + (14a b d  + 56b c d )x
+--R         + 
+--R              2 3             2       2 2   6
+--R           (7a d  + 112a b c d  + 112b c d)x
+--R         + 
+--R             2   2           2       2 3  4        2 2            3  2      2 3
+--R         (56a c d  + 224a b c d + 64b c )x  + (112a c d + 128a b c )x  + 64a c
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|d x  + c
+--R     + 
+--R          2 4 12            4      2   3  10
+--R       - b d x   + (- 2a b d  - 25b c d )x
+--R     + 
+--R           2 4            3       2 2 2  8
+--R       (- a d  - 50a b c d  - 104b c d )x
+--R     + 
+--R             2   3           2 2       2 3   6
+--R       (- 25a c d  - 208a b c d  - 144b c d)x
+--R     + 
+--R            2 2 2           3       2 4  4          2 3            4  2      2 4
+--R     (- 104a c d  - 288a b c d - 64b c )x  + (- 144a c d - 128a b c )x  - 64a c
+--R  /
+--R                                               +--------+
+--R           3 9        2 7      2   5      3 3  |   2
+--R         (d x  + 24c d x  + 80c d x  + 64c x )\|d x  + c
+--R       + 
+--R              3 9        2 7       2   5      3 3  +-+
+--R         (- 7d x  - 56c d x  - 112c d x  - 64c x )\|c
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2602
+
+)clear all
+
+--S 2603 of 3139
+t0:=(d+e*x^2)^4/(-d^2+e^2*x^4)
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        e x  + 3d e x  + 3d e x  + d
+--R   (1)  -----------------------------
+--R                      2
+--R                   e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2603
+
+--S 2604 of 3139
+r0:=7*d^2*x+4/3*d*e*x^3+1/5*e^2*x^5-8*d^(5/2)*atanh(x*sqrt(e)/sqrt(d))/sqrt(e)
+--R 
+--R
+--R                           +-+
+--R              2 +-+      x\|e        2 5          3       2   +-+
+--R        - 120d \|d atanh(-----) + (3e x  + 20d e x  + 105d x)\|e
+--R                           +-+
+--R                          \|d
+--R   (2)  ---------------------------------------------------------
+--R                                     +-+
+--R                                  15\|e
+--R                                                    Type: Expression(Integer)
+--E 2604
+
+--S 2605 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       +-+
+--R                       |d       2
+--R         +-+    - 2e x |-  + e x  + d
+--R       2 |d           \|e                  2 5          3       2
+--R    60d  |- log(---------------------) + 3e x  + 20d e x  + 105d x
+--R        \|e               2
+--R                       e x  - d
+--R   [--------------------------------------------------------------,
+--R                                  15
+--R                     +---+
+--R                     |  d
+--R          +---+      |- -
+--R        2 |  d      \|  e       2 5          3       2
+--R    120d  |- - atan(------) + 3e x  + 20d e x  + 105d x
+--R         \|  e         x
+--R    ---------------------------------------------------]
+--R                             15
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2605
+
+--S 2606 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R                              +-+
+--R                              |d       2
+--R            +-+        - 2e x |-  + e x  + d                   +-+
+--R          2 |d  +-+          \|e                  2 +-+      x\|e
+--R        4d  |- \|e log(---------------------) + 8d \|d atanh(-----)
+--R           \|e                   2                             +-+
+--R                              e x  - d                        \|d
+--R   (4)  -----------------------------------------------------------
+--R                                     +-+
+--R                                    \|e
+--R                                                    Type: Expression(Integer)
+--E 2606
+
+--S 2607 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2607
+
+--S 2608 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                 +---+
+--R                                                 |  d
+--R                       +-+        +---+          |- -
+--R          2 +-+      x\|e       2 |  d  +-+     \|  e
+--R        8d \|d atanh(-----) + 8d  |- - \|e atan(------)
+--R                       +-+       \|  e             x
+--R                      \|d
+--R   (6)  -----------------------------------------------
+--R                               +-+
+--R                              \|e
+--R                                                    Type: Expression(Integer)
+--E 2608
+
+--S 2609 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2609
+
+)clear all
+
+--S 2610 of 3139
+t0:=(d+e*x^2)^3/(-d^2+e^2*x^4)
+--R 
+--R
+--R         2 4         2    2
+--R        e x  + 2d e x  + d
+--R   (1)  -------------------
+--R                 2
+--R              e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2610
+
+--S 2611 of 3139
+r0:=3*d*x+1/3*e*x^3-4*d^(3/2)*atanh(x*sqrt(e)/sqrt(d))/sqrt(e)
+--R 
+--R
+--R                         +-+
+--R              +-+      x\|e         3         +-+
+--R        - 12d\|d atanh(-----) + (e x  + 9d x)\|e
+--R                         +-+
+--R                        \|d
+--R   (2)  -----------------------------------------
+--R                            +-+
+--R                          3\|e
+--R                                                    Type: Expression(Integer)
+--E 2611
+
+--S 2612 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +-+
+--R                     |d       2
+--R       +-+    - 2e x |-  + e x  + d
+--R       |d           \|e                   3
+--R    6d |- log(---------------------) + e x  + 9d x
+--R      \|e               2
+--R                     e x  - d
+--R   [----------------------------------------------,
+--R                           3
+--R                   +---+
+--R                   |  d
+--R        +---+      |- -
+--R        |  d      \|  e        3
+--R    12d |- - atan(------) + e x  + 9d x
+--R       \|  e         x
+--R    -----------------------------------]
+--R                     3
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2612
+
+--S 2613 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R                             +-+
+--R                             |d       2
+--R           +-+        - 2e x |-  + e x  + d                  +-+
+--R           |d  +-+          \|e                   +-+      x\|e
+--R        2d |- \|e log(---------------------) + 4d\|d atanh(-----)
+--R          \|e                   2                            +-+
+--R                             e x  - d                       \|d
+--R   (4)  ---------------------------------------------------------
+--R                                    +-+
+--R                                   \|e
+--R                                                    Type: Expression(Integer)
+--E 2613
+
+--S 2614 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2614
+
+--S 2615 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                               +---+
+--R                                               |  d
+--R                      +-+       +---+          |- -
+--R           +-+      x\|e        |  d  +-+     \|  e
+--R        4d\|d atanh(-----) + 4d |- - \|e atan(------)
+--R                      +-+      \|  e             x
+--R                     \|d
+--R   (6)  ---------------------------------------------
+--R                              +-+
+--R                             \|e
+--R                                                    Type: Expression(Integer)
+--E 2615
+
+--S 2616 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2616
+
+)clear all
+
+--S 2617 of 3139
+t0:=(d+e*x^2)^2/(-d^2+e^2*x^4)
+--R 
+--R
+--R           2
+--R        e x  + d
+--R   (1)  --------
+--R           2
+--R        e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2617
+
+--S 2618 of 3139
+r0:=x-2*atanh(x*sqrt(e)/sqrt(d))*sqrt(d)/sqrt(e)
+--R 
+--R
+--R                       +-+
+--R            +-+      x\|e       +-+
+--R        - 2\|d atanh(-----) + x\|e
+--R                       +-+
+--R                      \|d
+--R   (2)  ---------------------------
+--R                     +-+
+--R                    \|e
+--R                                                    Type: Expression(Integer)
+--E 2618
+
+--S 2619 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        +-+                               +---+
+--R                        |d       2                        |  d
+--R          +-+    - 2e x |-  + e x  + d         +---+      |- -
+--R          |d           \|e                     |  d      \|  e
+--R   (3)  [ |- log(---------------------) + x,2  |- - atan(------ + x]
+--R         \|e               2                  \|  e         x
+--R                        e x  - d
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2619
+
+--S 2620 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R                           +-+
+--R                           |d       2
+--R         +-+        - 2e x |-  + e x  + d                 +-+
+--R         |d  +-+          \|e                  +-+      x\|e
+--R         |- \|e log(---------------------) + 2\|d atanh(-----)
+--R        \|e                   2                           +-+
+--R                           e x  - d                      \|d
+--R   (4)  ------------------------------------------------------
+--R                                  +-+
+--R                                 \|e
+--R                                                    Type: Expression(Integer)
+--E 2620
+
+--S 2621 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2621
+
+--S 2622 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                                              +---+
+--R                                              |  d
+--R                     +-+       +---+          |- -
+--R          +-+      x\|e        |  d  +-+     \|  e
+--R        2\|d atanh(-----) + 2  |- - \|e atan(------)
+--R                     +-+      \|  e             x
+--R                    \|d
+--R   (6)  -------------------------------------------
+--R                             +-+
+--R                            \|e
+--R                                                    Type: Expression(Integer)
+--E 2622
+
+--S 2623 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2623
+
+)clear all
+
+--S 2624 of 3139
+t0:=(d+e*x^2)/(-d^2+e^2*x^4)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R           2
+--R        e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2624
+
+--S 2625 of 3139
+r0:=-atanh(x*sqrt(e)/sqrt(d))/(sqrt(d)*sqrt(e))
+--R 
+--R
+--R                  +-+
+--R                x\|e
+--R          atanh(-----)
+--R                  +-+
+--R                 \|d
+--R   (2)  - ------------
+--R             +-+ +-+
+--R            \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2625
+
+--S 2626 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 2      +---+
+--R             (e x  + d)\|d e  - 2d e x           +-----+
+--R         log(-------------------------)        x\|- d e
+--R                         2                atan(---------)
+--R                      e x  - d                     d
+--R   (3)  [------------------------------,- ---------------]
+--R                       +---+                   +-----+
+--R                     2\|d e                   \|- d e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2626
+
+--S 2627 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R                        2      +---+                            +-+
+--R         +-+ +-+    (e x  + d)\|d e  - 2d e x      +---+      x\|e
+--R        \|d \|e log(-------------------------) + 2\|d e atanh(-----)
+--R                                2                               +-+
+--R                             e x  - d                          \|d
+--R   (4)  ------------------------------------------------------------
+--R                                 +-+ +-+ +---+
+--R                               2\|d \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 2627
+
+--S 2628 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2628
+
+--S 2629 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +-+                   +-----+
+--R         +-----+      x\|e      +-+ +-+     x\|- d e
+--R        \|- d e atanh(-----) - \|d \|e atan(---------)
+--R                        +-+                     d
+--R                       \|d
+--R   (6)  ----------------------------------------------
+--R                        +-----+ +-+ +-+
+--R                       \|- d e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2629
+
+--S 2630 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2630
+
+)clear all
+
+--S 2631 of 3139
+t0:=1/((d+e*x^2)*(-d^2+e^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R         3 6      2 4    2   2    3
+--R        e x  + d e x  - d e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2631
+
+--S 2632 of 3139
+r0:=-1/4*x/(d^2*(d+e*x^2))-1/2*atan(x*sqrt(e)/sqrt(d))/(d^(5/2)*sqrt(e))-_
+   1/4*atanh(x*sqrt(e)/sqrt(d))/(d^(5/2)*sqrt(e))
+--R 
+--R
+--R                            +-+                         +-+
+--R              2           x\|e            2           x\|e       +-+ +-+
+--R        (- e x  - d)atanh(-----) + (- 2e x  - 2d)atan(-----) - x\|d \|e
+--R                            +-+                         +-+
+--R                           \|d                         \|d
+--R   (2)  ----------------------------------------------------------------
+--R                                2   2     3  +-+ +-+
+--R                             (4d e x  + 4d )\|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2632
+
+--S 2633 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                           2      +---+                                  +---+
+--R             2         (e x  + d)\|d e  - 2d e x           2           x\|d e
+--R         (e x  + d)log(-------------------------) + (- 4e x  - 4d)atan(-------)
+--R                                   2                                      d
+--R                                e x  - d
+--R       + 
+--R              +---+
+--R         - 2x\|d e
+--R    /
+--R          2   2     3  +---+
+--R       (8d e x  + 8d )\|d e
+--R     ,
+--R
+--R                           2      +-----+
+--R             2         (e x  - d)\|- d e  - 2d e x
+--R         (e x  + d)log(---------------------------)
+--R                                    2
+--R                                 e x  + d
+--R       + 
+--R                            +-----+
+--R               2          x\|- d e       +-----+
+--R         (- e x  - d)atan(---------) - x\|- d e
+--R                              d
+--R    /
+--R          2   2     3  +-----+
+--R       (4d e x  + 4d )\|- d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2633
+
+--S 2634 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       2      +---+                            +-+
+--R        +-+ +-+    (e x  + d)\|d e  - 2d e x      +---+      x\|e
+--R       \|d \|e log(-------------------------) + 2\|d e atanh(-----)
+--R                               2                               +-+
+--R                            e x  - d                          \|d
+--R     + 
+--R                         +---+                  +-+
+--R           +-+ +-+     x\|d e       +---+     x\|e
+--R       - 4\|d \|e atan(-------) + 4\|d e atan(-----)
+--R                          d                     +-+
+--R                                               \|d
+--R  /
+--R       2 +-+ +-+ +---+
+--R     8d \|d \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 2634
+
+--S 2635 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2635
+
+--S 2636 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       2      +-----+                             +-+
+--R        +-+ +-+    (e x  - d)\|- d e  - 2d e x     +-----+      x\|e
+--R       \|d \|e log(---------------------------) + \|- d e atanh(-----)
+--R                                2                                 +-+
+--R                             e x  + d                            \|d
+--R     + 
+--R                       +-+                   +-----+
+--R         +-----+     x\|e      +-+ +-+     x\|- d e
+--R       2\|- d e atan(-----) - \|d \|e atan(---------)
+--R                       +-+                     d
+--R                      \|d
+--R  /
+--R       2 +-----+ +-+ +-+
+--R     4d \|- d e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2636
+
+--S 2637 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2637
+
+)clear all
+
+--S 2638 of 3139
+t0:=1/((d+e*x^2)^2*(-d^2+e^2*x^4))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R         4 8       3 6     3   2    4
+--R        e x  + 2d e x  - 2d e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2638
+
+--S 2639 of 3139
+r0:=-1/8*x/(d^2*(d+e*x^2)^2)-5/16*x/(d^3*(d+e*x^2))-7/16*atan(x*sqrt(e)/_
+   sqrt(d))/(d^(7/2)*sqrt(e))-1/8*atanh(x*sqrt(e)/sqrt(d))/(d^(7/2)*sqrt(e))
+--R 
+--R
+--R   (2)
+--R                                        +-+
+--R            2 4         2     2       x\|e
+--R       (- 2e x  - 4d e x  - 2d )atanh(-----)
+--R                                        +-+
+--R                                       \|d
+--R     + 
+--R                                        +-+
+--R            2 4          2     2      x\|e            3         +-+ +-+
+--R       (- 7e x  - 14d e x  - 7d )atan(-----) + (- 5e x  - 7d x)\|d \|e
+--R                                        +-+
+--R                                       \|d
+--R  /
+--R         3 2 4      4   2      5  +-+ +-+
+--R     (16d e x  + 32d e x  + 16d )\|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2639
+
+--S 2640 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                      2      +---+
+--R           2 4         2    2     (e x  + d)\|d e  - 2d e x
+--R         (e x  + 2d e x  + d )log(-------------------------)
+--R                                              2
+--R                                           e x  - d
+--R       + 
+--R                                          +---+
+--R              2 4          2     2      x\|d e            3         +---+
+--R         (- 7e x  - 14d e x  - 7d )atan(-------) + (- 5e x  - 7d x)\|d e
+--R                                           d
+--R    /
+--R           3 2 4      4   2      5  +---+
+--R       (16d e x  + 32d e x  + 16d )\|d e
+--R     ,
+--R
+--R                                         2      +-----+
+--R            2 4          2     2     (e x  - d)\|- d e  - 2d e x
+--R         (7e x  + 14d e x  + 7d )log(---------------------------)
+--R                                                  2
+--R                                               e x  + d
+--R       + 
+--R                                         +-----+
+--R              2 4         2     2      x\|- d e             3          +-----+
+--R         (- 4e x  - 8d e x  - 4d )atan(---------) + (- 10e x  - 14d x)\|- d e
+--R                                           d
+--R    /
+--R           3 2 4      4   2      5  +-----+
+--R       (32d e x  + 64d e x  + 32d )\|- d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2640
+
+--S 2641 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       2      +---+                            +-+
+--R        +-+ +-+    (e x  + d)\|d e  - 2d e x      +---+      x\|e
+--R       \|d \|e log(-------------------------) + 2\|d e atanh(-----)
+--R                               2                               +-+
+--R                            e x  - d                          \|d
+--R     + 
+--R                         +---+                  +-+
+--R           +-+ +-+     x\|d e       +---+     x\|e
+--R       - 7\|d \|e atan(-------) + 7\|d e atan(-----)
+--R                          d                     +-+
+--R                                               \|d
+--R  /
+--R        3 +-+ +-+ +---+
+--R     16d \|d \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 2641
+
+--S 2642 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2642
+
+--S 2643 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        2      +-----+                              +-+
+--R         +-+ +-+    (e x  - d)\|- d e  - 2d e x      +-----+      x\|e
+--R       7\|d \|e log(---------------------------) + 4\|- d e atanh(-----)
+--R                                 2                                  +-+
+--R                              e x  + d                             \|d
+--R     + 
+--R                        +-+                    +-----+
+--R          +-----+     x\|e       +-+ +-+     x\|- d e
+--R       14\|- d e atan(-----) - 4\|d \|e atan(---------)
+--R                        +-+                      d
+--R                       \|d
+--R  /
+--R        3 +-----+ +-+ +-+
+--R     32d \|- d e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2643
+
+--S 2644 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2644
+
+)clear all
+
+--S 2645 of 3139
+t0:=(d+e*x^2)^(3/2)/(-d^2+e^2*x^4)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|e x  + d
+--R   (1)  -----------
+--R             2
+--R          e x  - d
+--R                                                    Type: Expression(Integer)
+--E 2645
+
+--S 2646 of 3139
+r0:=atanh(x*sqrt(e)/sqrt(d+e*x^2))/sqrt(e)-atanh(x*sqrt(2)*sqrt(e)/_
+   sqrt(d+e*x^2))*sqrt(2)/sqrt(e)
+--R 
+--R
+--R                       +-+ +-+                +-+
+--R           +-+       x\|2 \|e               x\|e
+--R        - \|2 atanh(-----------) + atanh(-----------)
+--R                     +--------+           +--------+
+--R                     |   2                |   2
+--R                    \|e x  + d           \|e x  + d
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                             \|e
+--R                                                    Type: Expression(Integer)
+--E 2646
+
+--S 2647 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               +--------+
+--R                +-+ +-+        |   2              2      +-+       +-+
+--R              (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R         2log(--------------------------------------------------------)
+--R                                      +--------+
+--R                                  +-+ |   2
+--R                                 \|d \|e x  + d  - d
+--R       + 
+--R            +-+
+--R            |2  +-+
+--R            |- \|e
+--R           \|e
+--R        *
+--R           log
+--R                                                           +-+  +--------+
+--R                          2       +-+        2 3           |2   |   2
+--R                  ((- 6e x  - 2d)\|d  + (- 2e x  - 4d e x) |- )\|e x  + d
+--R                                                          \|e
+--R                + 
+--R                                   +-+
+--R                     2 3           |2  +-+     2 4         2     2
+--R                  (4e x  + 4d e x) |- \|d  + 3e x  + 7d e x  + 2d
+--R                                  \|e
+--R             /
+--R                                 +--------+
+--R                     2       +-+ |   2         2 4        2     2
+--R                (2e x  - 2d)\|d \|e x  + d  - e x  - d e x  + 2d
+--R    /
+--R         +-+
+--R       2\|e
+--R     ,
+--R
+--R                      +--------+
+--R                +---+ |   2         +---+ +-+
+--R               \|- e \|e x  + d  - \|- e \|d
+--R         2atan(------------------------------)
+--R                             e x
+--R       + 
+--R                                        +--------+
+--R                  +---+          2      |   2              2      +-+
+--R            +---+ |  2      (2e x  - d)\|e x  + d  + (- e x  + d)\|d
+--R         - \|- e  |- - atan(-----------------------------------------)
+--R                 \|  e                           +---+
+--R                                             2 3 |  2
+--R                                            e x  |- -
+--R                                                \|  e
+--R       + 
+--R                +---+         +-+
+--R          +---+ |  2         \|d
+--R         \|- e  |- - atan(---------)
+--R               \|  e          +---+
+--R                              |  2
+--R                          e x |- -
+--R                             \|  e
+--R    /
+--R        +---+
+--R       \|- e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2647
+
+--S 2648 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             +--------+
+--R              +-+ +-+        |   2              2      +-+       +-+
+--R            (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R       2log(--------------------------------------------------------)
+--R                                    +--------+
+--R                                +-+ |   2
+--R                               \|d \|e x  + d  - d
+--R     + 
+--R          +-+
+--R          |2  +-+
+--R          |- \|e
+--R         \|e
+--R      *
+--R         log
+--R                                                         +-+  +--------+
+--R                        2       +-+        2 3           |2   |   2
+--R                ((- 6e x  - 2d)\|d  + (- 2e x  - 4d e x) |- )\|e x  + d
+--R                                                        \|e
+--R              + 
+--R                                 +-+
+--R                   2 3           |2  +-+     2 4         2     2
+--R                (4e x  + 4d e x) |- \|d  + 3e x  + 7d e x  + 2d
+--R                                \|e
+--R           /
+--R                               +--------+
+--R                   2       +-+ |   2         2 4        2     2
+--R              (2e x  - 2d)\|d \|e x  + d  - e x  - d e x  + 2d
+--R     + 
+--R                     +-+ +-+                 +-+
+--R         +-+       x\|2 \|e                x\|e
+--R       2\|2 atanh(-----------) - 2atanh(-----------)
+--R                   +--------+            +--------+
+--R                   |   2                 |   2
+--R                  \|e x  + d            \|e x  + d
+--R  /
+--R       +-+
+--R     2\|e
+--R                                                    Type: Expression(Integer)
+--E 2648
+
+--S 2649 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2649
+
+--S 2650 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          +-+ +-+                      +-+
+--R        +-+ +---+       x\|2 \|e       +---+         x\|e
+--R       \|2 \|- e atanh(-----------) - \|- e atanh(-----------)
+--R                        +--------+                 +--------+
+--R                        |   2                      |   2
+--R                       \|e x  + d                 \|e x  + d
+--R     + 
+--R                        +--------+
+--R                  +---+ |   2         +---+ +-+
+--R         +-+     \|- e \|e x  + d  - \|- e \|d
+--R       2\|e atan(------------------------------)
+--R                               e x
+--R     + 
+--R                                          +--------+
+--R                +---+              2      |   2              2      +-+
+--R          +---+ |  2  +-+     (2e x  - d)\|e x  + d  + (- e x  + d)\|d
+--R       - \|- e  |- - \|e atan(-----------------------------------------)
+--R               \|  e                               +---+
+--R                                               2 3 |  2
+--R                                              e x  |- -
+--R                                                  \|  e
+--R     + 
+--R              +---+             +-+
+--R        +---+ |  2  +-+        \|d
+--R       \|- e  |- - \|e atan(---------)
+--R             \|  e              +---+
+--R                                |  2
+--R                            e x |- -
+--R                               \|  e
+--R  /
+--R      +---+ +-+
+--R     \|- e \|e
+--R                                                    Type: Expression(Integer)
+--E 2650
+
+--S 2651 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2651
+
+)clear all
+
+--S 2652 of 3139
+t0:=(d+e*x^2)^(1/2)/(-d^2+e^2*x^4)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|e x  + d
+--R   (1)  -----------
+--R          2 4    2
+--R         e x  - d
+--R                                                    Type: Expression(Integer)
+--E 2652
+
+--S 2653 of 3139
+r0:=-atanh(x*sqrt(2)*sqrt(e)/sqrt(d+e*x^2))/(d*sqrt(2)*sqrt(e))
+--R 
+--R
+--R                   +-+ +-+
+--R                 x\|2 \|e
+--R          atanh(-----------)
+--R                 +--------+
+--R                 |   2
+--R                \|e x  + d
+--R   (2)  - ------------------
+--R                 +-+ +-+
+--R               d\|2 \|e
+--R                                                    Type: Expression(Integer)
+--E 2653
+
+--S 2654 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                                         +--------+
+--R                      2       +-+ +--+     2 3           |   2
+--R              ((- 6e x  - 2d)\|d \|2e  - 4e x  - 8d e x)\|e x  + d
+--R            + 
+--R                 2 4         2     2  +--+      2 3           +-+
+--R              (3e x  + 7d e x  + 2d )\|2e  + (8e x  + 8d e x)\|d
+--R         /
+--R                             +--------+
+--R                 2       +-+ |   2         2 4        2     2
+--R            (2e x  - 2d)\|d \|e x  + d  - e x  - d e x  + 2d
+--R    /
+--R          +--+
+--R       2d\|2e
+--R     ,
+--R                     +--------+
+--R              2      |   2              2      +-+          +----+ +-+
+--R         (2e x  - d)\|e x  + d  + (- e x  + d)\|d          \|- 2e \|d
+--R    atan(-----------------------------------------) + atan(-----------)
+--R                           3 +----+                            2e x
+--R                        e x \|- 2e
+--R    -------------------------------------------------------------------]
+--R                                    +----+
+--R                                  d\|- 2e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2654
+
+--S 2655 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|2 \|e
+--R      *
+--R         log
+--R                                                           +--------+
+--R                        2       +-+ +--+     2 3           |   2
+--R                ((- 6e x  - 2d)\|d \|2e  - 4e x  - 8d e x)\|e x  + d
+--R              + 
+--R                   2 4         2     2  +--+      2 3           +-+
+--R                (3e x  + 7d e x  + 2d )\|2e  + (8e x  + 8d e x)\|d
+--R           /
+--R                               +--------+
+--R                   2       +-+ |   2         2 4        2     2
+--R              (2e x  - 2d)\|d \|e x  + d  - e x  - d e x  + 2d
+--R     + 
+--R                      +-+ +-+
+--R         +--+       x\|2 \|e
+--R       2\|2e atanh(-----------)
+--R                    +--------+
+--R                    |   2
+--R                   \|e x  + d
+--R  /
+--R        +-+ +-+ +--+
+--R     2d\|2 \|e \|2e
+--R                                                    Type: Expression(Integer)
+--E 2655
+
+--S 2656 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2656
+
+--S 2657 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +-+ +-+
+--R        +----+       x\|2 \|e
+--R       \|- 2e atanh(-----------)
+--R                     +--------+
+--R                     |   2
+--R                    \|e x  + d
+--R     + 
+--R                                +--------+
+--R                         2      |   2              2      +-+
+--R        +-+ +-+     (2e x  - d)\|e x  + d  + (- e x  + d)\|d
+--R       \|2 \|e atan(-----------------------------------------)
+--R                                      3 +----+
+--R                                   e x \|- 2e
+--R     + 
+--R                     +----+ +-+
+--R        +-+ +-+     \|- 2e \|d
+--R       \|2 \|e atan(-----------)
+--R                        2e x
+--R  /
+--R       +-+ +----+ +-+
+--R     d\|2 \|- 2e \|e
+--R                                                    Type: Expression(Integer)
+--E 2657
+
+--S 2658 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2658
+
+)clear all
+
+--S 2659 of 3139
+t0:=1/((d+e*x^2)^(1/2)*(-d^2+e^2*x^4))
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R                    +--------+
+--R          2 4    2  |   2
+--R        (e x  - d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2659
+
+--S 2660 of 3139
+r0:=-1/2*atanh(x*sqrt(2)*sqrt(e)/sqrt(d+e*x^2))/(d^2*sqrt(2)*sqrt(e))-_
+   1/2*x/(d^2*sqrt(d+e*x^2))
+--R 
+--R
+--R           +--------+         +-+ +-+
+--R           |   2            x\|2 \|e        +-+ +-+
+--R        - \|e x  + d atanh(-----------) - x\|2 \|e
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R   (2)  -------------------------------------------
+--R                               +--------+
+--R                     2 +-+ +-+ |   2
+--R                   2d \|2 \|e \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2660
+
+--S 2661 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 +--------+
+--R             +-+ |   2           2
+--R           (\|d \|e x  + d  - e x  - d)
+--R        *
+--R           log
+--R                                                             +--------+
+--R                          2       +-+ +--+     2 3           |   2
+--R                  ((- 6e x  - 2d)\|d \|2e  - 4e x  - 8d e x)\|e x  + d
+--R                + 
+--R                     2 4         2     2  +--+      2 3           +-+
+--R                  (3e x  + 7d e x  + 2d )\|2e  + (8e x  + 8d e x)\|d
+--R             /
+--R                                 +--------+
+--R                     2       +-+ |   2         2 4        2     2
+--R                (2e x  - 2d)\|d \|e x  + d  - e x  - d e x  + 2d
+--R       + 
+--R                 +--------+
+--R            +--+ |   2           +-+ +--+
+--R         2x\|2e \|e x  + d  - 2x\|d \|2e
+--R    /
+--R                    +--------+
+--R         2 +-+ +--+ |   2             2   2     3  +--+
+--R       4d \|d \|2e \|e x  + d  + (- 4d e x  - 4d )\|2e
+--R     ,
+--R
+--R                 +--------+
+--R             +-+ |   2           2
+--R           (\|d \|e x  + d  - e x  - d)
+--R        *
+--R                            +--------+
+--R                     2      |   2              2      +-+
+--R                (2e x  - d)\|e x  + d  + (- e x  + d)\|d
+--R           atan(-----------------------------------------)
+--R                                  3 +----+
+--R                               e x \|- 2e
+--R       + 
+--R               +--------+                  +----+ +-+             +--------+
+--R           +-+ |   2           2          \|- 2e \|d       +----+ |   2
+--R         (\|d \|e x  + d  - e x  - d)atan(-----------) + x\|- 2e \|e x  + d
+--R                                              2e x
+--R       + 
+--R             +----+ +-+
+--R         - x\|- 2e \|d
+--R    /
+--R                      +--------+
+--R         2 +----+ +-+ |   2             2   2     3  +----+
+--R       2d \|- 2e \|d \|e x  + d  + (- 2d e x  - 2d )\|- 2e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2661
+
+--S 2662 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|2 \|e
+--R      *
+--R         log
+--R                                                           +--------+
+--R                        2       +-+ +--+     2 3           |   2
+--R                ((- 6e x  - 2d)\|d \|2e  - 4e x  - 8d e x)\|e x  + d
+--R              + 
+--R                   2 4         2     2  +--+      2 3           +-+
+--R                (3e x  + 7d e x  + 2d )\|2e  + (8e x  + 8d e x)\|d
+--R           /
+--R                               +--------+
+--R                   2       +-+ |   2         2 4        2     2
+--R              (2e x  - 2d)\|d \|e x  + d  - e x  - d e x  + 2d
+--R     + 
+--R                      +-+ +-+
+--R         +--+       x\|2 \|e
+--R       2\|2e atanh(-----------)
+--R                    +--------+
+--R                    |   2
+--R                   \|e x  + d
+--R  /
+--R       2 +-+ +-+ +--+
+--R     4d \|2 \|e \|2e
+--R                                                    Type: Expression(Integer)
+--E 2662
+
+--S 2663 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2663
+
+--S 2664 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +-+ +-+
+--R        +----+       x\|2 \|e
+--R       \|- 2e atanh(-----------)
+--R                     +--------+
+--R                     |   2
+--R                    \|e x  + d
+--R     + 
+--R                                +--------+
+--R                         2      |   2              2      +-+
+--R        +-+ +-+     (2e x  - d)\|e x  + d  + (- e x  + d)\|d
+--R       \|2 \|e atan(-----------------------------------------)
+--R                                      3 +----+
+--R                                   e x \|- 2e
+--R     + 
+--R                     +----+ +-+
+--R        +-+ +-+     \|- 2e \|d
+--R       \|2 \|e atan(-----------)
+--R                        2e x
+--R  /
+--R       2 +-+ +----+ +-+
+--R     2d \|2 \|- 2e \|e
+--R                                                    Type: Expression(Integer)
+--E 2664
+
+--S 2665 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2665
+
+)clear all
+
+--S 2666 of 3139
+t0:=1/((d+e*x^2)^(3/2)*(-d^2+e^2*x^4))
+--R 
+--R
+--R                            1
+--R   (1)  ----------------------------------------
+--R                                      +--------+
+--R          3 6      2 4    2   2    3  |   2
+--R        (e x  + d e x  - d e x  - d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2666
+
+--S 2667 of 3139
+r0:=-1/6*x/(d^2*(d+e*x^2)^(3/2))-1/4*atanh(x*sqrt(2)*sqrt(e)/sqrt(d+e*x^2))/_
+   (d^3*sqrt(2)*sqrt(e))-7/12*x/(d^3*sqrt(d+e*x^2))
+--R 
+--R
+--R                       +--------+         +-+ +-+
+--R               2       |   2            x\|2 \|e             3         +-+ +-+
+--R        (- 3e x  - 3d)\|e x  + d atanh(-----------) + (- 7e x  - 9d x)\|2 \|e
+--R                                        +--------+
+--R                                        |   2
+--R                                       \|e x  + d
+--R   (2)  ----------------------------------------------------------------------
+--R                                                   +--------+
+--R                             3   2      4  +-+ +-+ |   2
+--R                         (12d e x  + 12d )\|2 \|e \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2667
+
+--S 2668 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                           +--------+
+--R                2 4          2      2  +-+ |   2          3 6        2 4
+--R             (9e x  + 21d e x  + 12d )\|d \|e x  + d  - 3e x  - 18d e x
+--R           + 
+--R                  2   2      3
+--R             - 27d e x  - 12d
+--R        *
+--R           log
+--R                                                             +--------+
+--R                          2       +-+ +--+     2 3           |   2
+--R                  ((- 6e x  - 2d)\|d \|2e  - 4e x  - 8d e x)\|e x  + d
+--R                + 
+--R                     2 4         2     2  +--+      2 3           +-+
+--R                  (3e x  + 7d e x  + 2d )\|2e  + (8e x  + 8d e x)\|d
+--R             /
+--R                                 +--------+
+--R                     2       +-+ |   2         2 4        2     2
+--R                (2e x  - 2d)\|d \|e x  + d  - e x  - d e x  + 2d
+--R       + 
+--R                                          +--------+
+--R             2 5          3      2   +--+ |   2
+--R         (14e x  + 74d e x  + 72d x)\|2e \|e x  + d
+--R       + 
+--R               2 5           3      2   +-+ +--+
+--R         (- 42e x  - 110d e x  - 72d x)\|d \|2e
+--R    /
+--R                                                +--------+
+--R             3 2 4       4   2      5  +-+ +--+ |   2
+--R         (72d e x  + 168d e x  + 96d )\|d \|2e \|e x  + d
+--R       + 
+--R               3 3 6       4 2 4       5   2      6  +--+
+--R         (- 24d e x  - 144d e x  - 216d e x  - 96d )\|2e
+--R     ,
+--R
+--R                                           +--------+
+--R                2 4          2      2  +-+ |   2          3 6        2 4
+--R             (9e x  + 21d e x  + 12d )\|d \|e x  + d  - 3e x  - 18d e x
+--R           + 
+--R                  2   2      3
+--R             - 27d e x  - 12d
+--R        *
+--R                            +--------+
+--R                     2      |   2              2      +-+
+--R                (2e x  - d)\|e x  + d  + (- e x  + d)\|d
+--R           atan(-----------------------------------------)
+--R                                  3 +----+
+--R                               e x \|- 2e
+--R       + 
+--R                                           +--------+
+--R                2 4          2      2  +-+ |   2          3 6        2 4
+--R             (9e x  + 21d e x  + 12d )\|d \|e x  + d  - 3e x  - 18d e x
+--R           + 
+--R                  2   2      3
+--R             - 27d e x  - 12d
+--R        *
+--R                 +----+ +-+
+--R                \|- 2e \|d
+--R           atan(-----------)
+--R                    2e x
+--R       + 
+--R                                           +--------+
+--R            2 5          3      2   +----+ |   2
+--R         (7e x  + 37d e x  + 36d x)\|- 2e \|e x  + d
+--R       + 
+--R               2 5          3      2   +----+ +-+
+--R         (- 21e x  - 55d e x  - 36d x)\|- 2e \|d
+--R    /
+--R                                                 +--------+
+--R             3 2 4      4   2      5  +----+ +-+ |   2
+--R         (36d e x  + 84d e x  + 48d )\|- 2e \|d \|e x  + d
+--R       + 
+--R               3 3 6      4 2 4       5   2      6  +----+
+--R         (- 12d e x  - 72d e x  - 108d e x  - 48d )\|- 2e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2668
+
+--S 2669 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|2 \|e
+--R      *
+--R         log
+--R                                                           +--------+
+--R                        2       +-+ +--+     2 3           |   2
+--R                ((- 6e x  - 2d)\|d \|2e  - 4e x  - 8d e x)\|e x  + d
+--R              + 
+--R                   2 4         2     2  +--+      2 3           +-+
+--R                (3e x  + 7d e x  + 2d )\|2e  + (8e x  + 8d e x)\|d
+--R           /
+--R                               +--------+
+--R                   2       +-+ |   2         2 4        2     2
+--R              (2e x  - 2d)\|d \|e x  + d  - e x  - d e x  + 2d
+--R     + 
+--R                      +-+ +-+
+--R         +--+       x\|2 \|e
+--R       2\|2e atanh(-----------)
+--R                    +--------+
+--R                    |   2
+--R                   \|e x  + d
+--R  /
+--R       3 +-+ +-+ +--+
+--R     8d \|2 \|e \|2e
+--R                                                    Type: Expression(Integer)
+--E 2669
+
+--S 2670 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2670
+
+--S 2671 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +-+ +-+
+--R        +----+       x\|2 \|e
+--R       \|- 2e atanh(-----------)
+--R                     +--------+
+--R                     |   2
+--R                    \|e x  + d
+--R     + 
+--R                                +--------+
+--R                         2      |   2              2      +-+
+--R        +-+ +-+     (2e x  - d)\|e x  + d  + (- e x  + d)\|d
+--R       \|2 \|e atan(-----------------------------------------)
+--R                                      3 +----+
+--R                                   e x \|- 2e
+--R     + 
+--R                     +----+ +-+
+--R        +-+ +-+     \|- 2e \|d
+--R       \|2 \|e atan(-----------)
+--R                        2e x
+--R  /
+--R       3 +-+ +----+ +-+
+--R     4d \|2 \|- 2e \|e
+--R                                                    Type: Expression(Integer)
+--E 2671
+
+--S 2672 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2672
+
+)clear all
+
+--S 2673 of 3139
+t0:=(d+e*x^2)^4/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        e x  + 3d e x  + 3d e x  + d
+--R   (1)  -----------------------------
+--R                   2
+--R              c e x  + b e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2673
+
+--S 2674 of 3139
+r0:=(7*c^2*d^2-5*b*c*d*e+b^2*e^2)*x/c^3+1/3*e*(4*c*d-b*e)*x^3/c^2+_
+   1/5*e^2*x^5/c-(2*c*d-b*e)^3*atanh(x*sqrt(c)*sqrt(e)/sqrt(c*d-b*e))/_
+   (c^(7/2)*sqrt(e)*sqrt(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                                                              +-+ +-+
+--R           3 3      2     2         2 2        3 3          x\|c \|e
+--R       (15b e  - 90b c d e  + 180b c d e - 120c d )atanh(--------------)
+--R                                                          +-----------+
+--R                                                         \|- b e + c d
+--R     + 
+--R            2 2 5            2      2     3       2 2                   2 2
+--R         (3c e x  + (- 5b c e  + 20c d e)x  + (15b e  - 75b c d e + 105c d )x)
+--R      *
+--R          +-----------+ +-+ +-+
+--R         \|- b e + c d \|c \|e
+--R  /
+--R        3 +-----------+ +-+ +-+
+--R     15c \|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 2674
+
+--S 2675 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               3 3      2     2         2 2        3 3
+--R           (15b e  - 90b c d e  + 180b c d e - 120c d )
+--R        *
+--R                                    +----------------+
+--R                     2              |       2    2                2     2
+--R               (c e x  - b e + c d)\|- b c e  + c d e  + (- 2b c e  + 2c d e)x
+--R           log(---------------------------------------------------------------)
+--R                                           2
+--R                                      c e x  + b e - c d
+--R       + 
+--R                 2 2 5             2      2     3
+--R               6c e x  + (- 10b c e  + 40c d e)x
+--R             + 
+--R                   2 2                    2 2
+--R               (30b e  - 150b c d e + 210c d )x
+--R        *
+--R            +----------------+
+--R            |       2    2
+--R           \|- b c e  + c d e
+--R    /
+--R            +----------------+
+--R          3 |       2    2
+--R       30c \|- b c e  + c d e
+--R     ,
+--R
+--R                                                              +--------------+
+--R                                                              |     2    2
+--R               3 3      2     2         2 2        3 3      x\|b c e  - c d e
+--R         (- 15b e  + 90b c d e  - 180b c d e + 120c d )atan(------------------)
+--R                                                                 b e - c d
+--R       + 
+--R              2 2 5            2      2     3       2 2                   2 2
+--R           (3c e x  + (- 5b c e  + 20c d e)x  + (15b e  - 75b c d e + 105c d )x)
+--R        *
+--R            +--------------+
+--R            |     2    2
+--R           \|b c e  - c d e
+--R    /
+--R            +--------------+
+--R          3 |     2    2
+--R       15c \|b c e  - c d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2675
+
+--S 2676 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           3 3     2     2        2 2      3 3  +-----------+ +-+ +-+
+--R         (b e  - 6b c d e  + 12b c d e - 8c d )\|- b e + c d \|c \|e
+--R      *
+--R                                  +----------------+
+--R                   2              |       2    2                2     2
+--R             (c e x  - b e + c d)\|- b c e  + c d e  + (- 2b c e  + 2c d e)x
+--R         log(---------------------------------------------------------------)
+--R                                         2
+--R                                    c e x  + b e - c d
+--R     + 
+--R                                                     +----------------+
+--R              3 3      2     2        2 2       3 3  |       2    2
+--R         (- 2b e  + 12b c d e  - 24b c d e + 16c d )\|- b c e  + c d e
+--R      *
+--R                    +-+ +-+
+--R                  x\|c \|e
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R  /
+--R         +----------------+
+--R       3 |       2    2     +-----------+ +-+ +-+
+--R     2c \|- b c e  + c d e \|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 2676
+
+--S 2677 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2677
+
+--S 2678 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                  +--------------+
+--R             3 3     2     2        2 2      3 3  |     2    2
+--R         (- b e  + 6b c d e  - 12b c d e + 8c d )\|b c e  - c d e
+--R      *
+--R                    +-+ +-+
+--R                  x\|c \|e
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R             3 3     2     2        2 2      3 3  +-----------+ +-+ +-+
+--R         (- b e  + 6b c d e  - 12b c d e + 8c d )\|- b e + c d \|c \|e
+--R      *
+--R                +--------------+
+--R                |     2    2
+--R              x\|b c e  - c d e
+--R         atan(------------------)
+--R                   b e - c d
+--R  /
+--R                              +--------------+
+--R      3 +-----------+ +-+ +-+ |     2    2
+--R     c \|- b e + c d \|c \|e \|b c e  - c d e
+--R                                                    Type: Expression(Integer)
+--E 2678
+
+--S 2679 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2679
+
+)clear all
+
+--S 2680 of 3139
+t0:=(d+e*x^2)^3/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R         2 4         2    2
+--R        e x  + 2d e x  + d
+--R   (1)  -------------------
+--R              2
+--R         c e x  + b e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2680
+
+--S 2681 of 3139
+r0:=(3*c*d-b*e)*x/c^2+1/3*e*x^3/c-(2*c*d-b*e)^2*atanh(x*sqrt(c)*sqrt(e)/_
+   sqrt(c*d-b*e))/(c^(5/2)*sqrt(e)*sqrt(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                                                +-+ +-+
+--R            2 2                  2 2          x\|c \|e
+--R       (- 3b e  + 12b c d e - 12c d )atanh(--------------)
+--R                                            +-----------+
+--R                                           \|- b e + c d
+--R     + 
+--R             3                     +-----------+ +-+ +-+
+--R       (c e x  + (- 3b e + 9c d)x)\|- b e + c d \|c \|e
+--R  /
+--R       2 +-----------+ +-+ +-+
+--R     3c \|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 2681
+
+--S 2682 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              2 2                  2 2
+--R           (3b e  - 12b c d e + 12c d )
+--R        *
+--R                                    +----------------+
+--R                     2              |       2    2              2     2
+--R               (c e x  - b e + c d)\|- b c e  + c d e  + (2b c e  - 2c d e)x
+--R           log(-------------------------------------------------------------)
+--R                                          2
+--R                                     c e x  + b e - c d
+--R       + 
+--R                                       +----------------+
+--R                3                      |       2    2
+--R         (2c e x  + (- 6b e + 18c d)x)\|- b c e  + c d e
+--R    /
+--R           +----------------+
+--R         2 |       2    2
+--R       6c \|- b c e  + c d e
+--R     ,
+--R
+--R                                            +--------------+
+--R                                            |     2    2
+--R            2 2                  2 2      x\|b c e  - c d e
+--R         (3b e  - 12b c d e + 12c d )atan(------------------)
+--R                                               b e - c d
+--R       + 
+--R                                     +--------------+
+--R               3                     |     2    2
+--R         (c e x  + (- 3b e + 9c d)x)\|b c e  - c d e
+--R    /
+--R           +--------------+
+--R         2 |     2    2
+--R       3c \|b c e  - c d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2682
+
+--S 2683 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           2 2                2 2  +-----------+ +-+ +-+
+--R         (b e  - 4b c d e + 4c d )\|- b e + c d \|c \|e
+--R      *
+--R                                  +----------------+
+--R                   2              |       2    2              2     2
+--R             (c e x  - b e + c d)\|- b c e  + c d e  + (2b c e  - 2c d e)x
+--R         log(-------------------------------------------------------------)
+--R                                        2
+--R                                   c e x  + b e - c d
+--R     + 
+--R                                  +----------------+           +-+ +-+
+--R          2 2                2 2  |       2    2             x\|c \|e
+--R       (2b e  - 8b c d e + 8c d )\|- b c e  + c d e atanh(--------------)
+--R                                                           +-----------+
+--R                                                          \|- b e + c d
+--R  /
+--R         +----------------+
+--R       2 |       2    2     +-----------+ +-+ +-+
+--R     2c \|- b c e  + c d e \|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 2683
+
+--S 2684 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2684
+
+--S 2685 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                 +--------------+           +-+ +-+
+--R         2 2                2 2  |     2    2             x\|c \|e
+--R       (b e  - 4b c d e + 4c d )\|b c e  - c d e atanh(--------------)
+--R                                                        +-----------+
+--R                                                       \|- b e + c d
+--R     + 
+--R                                                             +--------------+
+--R                                                             |     2    2
+--R         2 2                2 2  +-----------+ +-+ +-+     x\|b c e  - c d e
+--R       (b e  - 4b c d e + 4c d )\|- b e + c d \|c \|e atan(------------------)
+--R                                                                b e - c d
+--R  /
+--R                              +--------------+
+--R      2 +-----------+ +-+ +-+ |     2    2
+--R     c \|- b e + c d \|c \|e \|b c e  - c d e
+--R                                                    Type: Expression(Integer)
+--E 2685
+
+--S 2686 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2686
+
+)clear all
+
+--S 2687 of 3139
+t0:=(d+e*x^2)^2/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R                2
+--R             e x  + d
+--R   (1)  ------------------
+--R             2
+--R        c e x  + b e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2687
+
+--S 2688 of 3139
+r0:=x/c-(2*c*d-b*e)*atanh(x*sqrt(c)*sqrt(e)/sqrt(c*d-b*e))/(c^(3/2)*sqrt(e)*_
+   sqrt(c*d-b*e))
+--R 
+--R
+--R                               +-+ +-+
+--R                             x\|c \|e         +-----------+ +-+ +-+
+--R        (b e - 2c d)atanh(--------------) + x\|- b e + c d \|c \|e
+--R                           +-----------+
+--R                          \|- b e + c d
+--R   (2)  -----------------------------------------------------------
+--R                            +-----------+ +-+ +-+
+--R                          c\|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 2688
+
+--S 2689 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           (b e - 2c d)
+--R        *
+--R                                    +----------------+
+--R                     2              |       2    2                2     2
+--R               (c e x  - b e + c d)\|- b c e  + c d e  + (- 2b c e  + 2c d e)x
+--R           log(---------------------------------------------------------------)
+--R                                           2
+--R                                      c e x  + b e - c d
+--R       + 
+--R            +----------------+
+--R            |       2    2
+--R         2x\|- b c e  + c d e
+--R    /
+--R          +----------------+
+--R          |       2    2
+--R       2c\|- b c e  + c d e
+--R     ,
+--R                         +--------------+
+--R                         |     2    2          +--------------+
+--R                       x\|b c e  - c d e       |     2    2
+--R    (- b e + 2c d)atan(------------------) + x\|b c e  - c d e
+--R                            b e - c d
+--R    -----------------------------------------------------------]
+--R                           +--------------+
+--R                           |     2    2
+--R                         c\|b c e  - c d e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2689
+
+--S 2690 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      +-----------+ +-+ +-+
+--R         (b e - 2c d)\|- b e + c d \|c \|e
+--R      *
+--R                                  +----------------+
+--R                   2              |       2    2                2     2
+--R             (c e x  - b e + c d)\|- b c e  + c d e  + (- 2b c e  + 2c d e)x
+--R         log(---------------------------------------------------------------)
+--R                                         2
+--R                                    c e x  + b e - c d
+--R     + 
+--R                       +----------------+           +-+ +-+
+--R                       |       2    2             x\|c \|e
+--R       (- 2b e + 4c d)\|- b c e  + c d e atanh(--------------)
+--R                                                +-----------+
+--R                                               \|- b e + c d
+--R  /
+--R        +----------------+
+--R        |       2    2     +-----------+ +-+ +-+
+--R     2c\|- b c e  + c d e \|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 2690
+
+--S 2691 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2691
+
+--S 2692 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      +--------------+           +-+ +-+
+--R                      |     2    2             x\|c \|e
+--R       (- b e + 2c d)\|b c e  - c d e atanh(--------------)
+--R                                             +-----------+
+--R                                            \|- b e + c d
+--R     + 
+--R                                                  +--------------+
+--R                                                  |     2    2
+--R                      +-----------+ +-+ +-+     x\|b c e  - c d e
+--R       (- b e + 2c d)\|- b e + c d \|c \|e atan(------------------)
+--R                                                     b e - c d
+--R  /
+--R                             +--------------+
+--R       +-----------+ +-+ +-+ |     2    2
+--R     c\|- b e + c d \|c \|e \|b c e  - c d e
+--R                                                    Type: Expression(Integer)
+--E 2692
+
+--S 2693 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2693
+
+)clear all
+
+--S 2694 of 3139
+t0:=(d+e*x^2)/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R             2
+--R        c e x  + b e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2694
+
+--S 2695 of 3139
+r0:=-atanh(x*sqrt(c)*sqrt(e)/sqrt(c*d-b*e))/(sqrt(c)*sqrt(e)*sqrt(c*d-b*e))
+--R 
+--R
+--R                      +-+ +-+
+--R                    x\|c \|e
+--R           atanh(--------------)
+--R                  +-----------+
+--R                 \|- b e + c d
+--R   (2)  - ----------------------
+--R           +-----------+ +-+ +-+
+--R          \|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 2695
+
+--S 2696 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                             +----------------+
+--R              2              |       2    2              2     2
+--R        (c e x  - b e + c d)\|- b c e  + c d e  + (2b c e  - 2c d e)x
+--R    log(-------------------------------------------------------------)
+--R                                   2
+--R                              c e x  + b e - c d
+--R   [------------------------------------------------------------------,
+--R                             +----------------+
+--R                             |       2    2
+--R                           2\|- b c e  + c d e
+--R           +--------------+
+--R           |     2    2
+--R         x\|b c e  - c d e
+--R    atan(------------------)
+--R              b e - c d
+--R    ------------------------]
+--R         +--------------+
+--R         |     2    2
+--R        \|b c e  - c d e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2696
+
+--S 2697 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-----------+ +-+ +-+
+--R         \|- b e + c d \|c \|e
+--R      *
+--R                                  +----------------+
+--R                   2              |       2    2              2     2
+--R             (c e x  - b e + c d)\|- b c e  + c d e  + (2b c e  - 2c d e)x
+--R         log(-------------------------------------------------------------)
+--R                                        2
+--R                                   c e x  + b e - c d
+--R     + 
+--R         +----------------+           +-+ +-+
+--R         |       2    2             x\|c \|e
+--R       2\|- b c e  + c d e atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- b e + c d
+--R  /
+--R       +----------------+
+--R       |       2    2     +-----------+ +-+ +-+
+--R     2\|- b c e  + c d e \|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 2697
+
+--S 2698 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2698
+
+--S 2699 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        +--------------+           +-+ +-+
+--R        |     2    2             x\|c \|e
+--R       \|b c e  - c d e atanh(--------------)
+--R                               +-----------+
+--R                              \|- b e + c d
+--R     + 
+--R                                    +--------------+
+--R                                    |     2    2
+--R        +-----------+ +-+ +-+     x\|b c e  - c d e
+--R       \|- b e + c d \|c \|e atan(------------------)
+--R                                       b e - c d
+--R  /
+--R                            +--------------+
+--R      +-----------+ +-+ +-+ |     2    2
+--R     \|- b e + c d \|c \|e \|b c e  - c d e
+--R                                                    Type: Expression(Integer)
+--E 2699
+
+--S 2700 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2700
+
+)clear all
+
+--S 2701 of 3139
+t0:=1/((d+e*x^2)*(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4))
+--R 
+--R
+--R                                       1
+--R   (1)  ---------------------------------------------------------------
+--R           3 6       3        2  4          2      2   2      2       3
+--R        c e x  + (b e  + c d e )x  + (2b d e  - c d e)x  + b d e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2701
+
+--S 2702 of 3139
+r0:=-1/2*x/(d*(2*c*d-b*e)*(d+e*x^2))-1/2*(4*c*d-b*e)*atan(x*sqrt(e)/_
+   sqrt(d))/(d^(3/2)*(2*c*d-b*e)^2*sqrt(e))-c^(3/2)*atanh(x*sqrt(c)*_
+   sqrt(e)/sqrt(c*d-b*e))/((2*c*d-b*e)^2*sqrt(e)*sqrt(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                                               +-+ +-+
+--R                  2       2  +-+ +-+         x\|c \|e
+--R       (- 2c d e x  - 2c d )\|c \|d atanh(--------------)
+--R                                           +-----------+
+--R                                          \|- b e + c d
+--R     + 
+--R                                                               +-+
+--R            2           2               2  +-----------+     x\|e
+--R       ((b e  - 4c d e)x  + b d e - 4c d )\|- b e + c d atan(-----)
+--R                                                               +-+
+--R                                                              \|d
+--R     + 
+--R                     +-----------+ +-+ +-+
+--R       (b e - 2c d)x\|- b e + c d \|d \|e
+--R  /
+--R           2   3         2 2     2 3   2     2 2 2         3      2 4
+--R       ((2b d e  - 8b c d e  + 8c d e)x  + 2b d e  - 8b c d e + 8c d )
+--R    *
+--R        +-----------+ +-+ +-+
+--R       \|- b e + c d \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2702
+
+--S 2703 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                       +--------------+
+--R                    2       2  +-----+ |        c
+--R           (2c d e x  + 2c d )\|- d e  |- ------------
+--R                                       |     2
+--R                                      \|  b e  - c d e
+--R        *
+--R                                 +--------------+
+--R                    2            |        c              2
+--R               (2b e  - 2c d e)x |- ------------  + c e x  - b e + c d
+--R                                 |     2
+--R                                \|  b e  - c d e
+--R           log(-------------------------------------------------------)
+--R                                       2
+--R                                  c e x  + b e - c d
+--R       + 
+--R                                                    2      +-----+
+--R              2           2               2     (e x  - d)\|- d e  + 2d e x
+--R         ((b e  - 4c d e)x  + b d e - 4c d )log(---------------------------)
+--R                                                             2
+--R                                                          e x  + d
+--R       + 
+--R                        +-----+
+--R         (2b e - 4c d)x\|- d e
+--R    /
+--R             2   3          2 2      2 3   2     2 2 2          3       2 4
+--R         ((4b d e  - 16b c d e  + 16c d e)x  + 4b d e  - 16b c d e + 16c d )
+--R      *
+--R          +-----+
+--R         \|- d e
+--R     ,
+--R
+--R                             +--------------+
+--R                   2      2  |        c       +---+
+--R           (c d e x  + c d ) |- ------------ \|d e
+--R                             |     2
+--R                            \|  b e  - c d e
+--R        *
+--R                                 +--------------+
+--R                    2            |        c              2
+--R               (2b e  - 2c d e)x |- ------------  + c e x  - b e + c d
+--R                                 |     2
+--R                                \|  b e  - c d e
+--R           log(-------------------------------------------------------)
+--R                                       2
+--R                                  c e x  + b e - c d
+--R       + 
+--R                                                   +---+
+--R              2           2               2      x\|d e                   +---+
+--R         ((b e  - 4c d e)x  + b d e - 4c d )atan(-------) + (b e - 2c d)x\|d e
+--R                                                    d
+--R    /
+--R           2   3         2 2     2 3   2     2 2 2         3      2 4  +---+
+--R       ((2b d e  - 8b c d e  + 8c d e)x  + 2b d e  - 8b c d e + 8c d )\|d e
+--R     ,
+--R
+--R                                                    2      +-----+
+--R              2           2               2     (e x  - d)\|- d e  + 2d e x
+--R         ((b e  - 4c d e)x  + b d e - 4c d )log(---------------------------)
+--R                                                             2
+--R                                                          e x  + d
+--R       + 
+--R                                         +------------+
+--R                      2       2  +-----+ |      c
+--R           (- 4c d e x  - 4c d )\|- d e  |------------
+--R                                         |   2
+--R                                        \|b e  - c d e
+--R        *
+--R                            +------------+
+--R                            |      c
+--R                (b e - c d) |------------
+--R                            |   2
+--R                           \|b e  - c d e
+--R           atan(--------------------------)
+--R                            c x
+--R       + 
+--R                        +-----+
+--R         (2b e - 4c d)x\|- d e
+--R    /
+--R             2   3          2 2      2 3   2     2 2 2          3       2 4
+--R         ((4b d e  - 16b c d e  + 16c d e)x  + 4b d e  - 16b c d e + 16c d )
+--R      *
+--R          +-----+
+--R         \|- d e
+--R     ,
+--R
+--R                                                   +---+
+--R              2           2               2      x\|d e
+--R         ((b e  - 4c d e)x  + b d e - 4c d )atan(-------)
+--R                                                    d
+--R       + 
+--R                                 +------------+
+--R                      2       2  |      c       +---+
+--R           (- 2c d e x  - 2c d ) |------------ \|d e
+--R                                 |   2
+--R                                \|b e  - c d e
+--R        *
+--R                            +------------+
+--R                            |      c
+--R                (b e - c d) |------------
+--R                            |   2
+--R                           \|b e  - c d e
+--R           atan(--------------------------)
+--R                            c x
+--R       + 
+--R                       +---+
+--R         (b e - 2c d)x\|d e
+--R    /
+--R           2   3         2 2     2 3   2     2 2 2         3      2 4  +---+
+--R       ((2b d e  - 8b c d e  + 8c d e)x  + 2b d e  - 8b c d e + 8c d )\|d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2703
+
+--S 2704 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                    +--------------+
+--R              +-----+ +-----------+ |        c       +-+ +-+
+--R         2c d\|- d e \|- b e + c d  |- ------------ \|d \|e
+--R                                    |     2
+--R                                   \|  b e  - c d e
+--R      *
+--R                               +--------------+
+--R                  2            |        c              2
+--R             (2b e  - 2c d e)x |- ------------  + c e x  - b e + c d
+--R                               |     2
+--R                              \|  b e  - c d e
+--R         log(-------------------------------------------------------)
+--R                                     2
+--R                                c e x  + b e - c d
+--R     + 
+--R                                                 2      +-----+
+--R                    +-----------+ +-+ +-+    (e x  - d)\|- d e  + 2d e x
+--R       (b e - 4c d)\|- b e + c d \|d \|e log(---------------------------)
+--R                                                          2
+--R                                                       e x  + d
+--R     + 
+--R                                      +-+ +-+
+--R            +-----+ +-+ +-+         x\|c \|e
+--R       4c d\|- d e \|c \|d atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- b e + c d
+--R     + 
+--R                                                   +-+
+--R                       +-----+ +-----------+     x\|e
+--R       (- 2b e + 8c d)\|- d e \|- b e + c d atan(-----)
+--R                                                   +-+
+--R                                                  \|d
+--R  /
+--R        2   2          2       2 3  +-----+ +-----------+ +-+ +-+
+--R     (4b d e  - 16b c d e + 16c d )\|- d e \|- b e + c d \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2704
+
+--S 2705 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2705
+
+--S 2706 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                           +--------------+
+--R             +-----------+ |        c       +-+ +-+ +---+
+--R         c d\|- b e + c d  |- ------------ \|d \|e \|d e
+--R                           |     2
+--R                          \|  b e  - c d e
+--R      *
+--R                               +--------------+
+--R                  2            |        c              2
+--R             (2b e  - 2c d e)x |- ------------  + c e x  - b e + c d
+--R                               |     2
+--R                              \|  b e  - c d e
+--R         log(-------------------------------------------------------)
+--R                                     2
+--R                                c e x  + b e - c d
+--R     + 
+--R                                    +-+ +-+
+--R            +-+ +-+ +---+         x\|c \|e
+--R       2c d\|c \|d \|d e atanh(--------------)
+--R                                +-----------+
+--R                               \|- b e + c d
+--R     + 
+--R                                                +---+
+--R                    +-----------+ +-+ +-+     x\|d e
+--R       (b e - 4c d)\|- b e + c d \|d \|e atan(-------)
+--R                                                 d
+--R     + 
+--R                                                +-+
+--R                      +-----------+ +---+     x\|e
+--R       (- b e + 4c d)\|- b e + c d \|d e atan(-----)
+--R                                                +-+
+--R                                               \|d
+--R  /
+--R        2   2         2      2 3  +-----------+ +-+ +-+ +---+
+--R     (2b d e  - 8b c d e + 8c d )\|- b e + c d \|d \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 2706
+
+--S 2707 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2707
+
+)clear all
+
+--S 2708 of 3139
+t0:=1/((d+e*x^2)^2*(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4))
+--R 
+--R
+--R   (1)
+--R                                         1
+--R   -----------------------------------------------------------------------------
+--R      4 8       4         3  6         3 4        2 2       3   2      3       4
+--R   c e x  + (b e  + 2c d e )x  + 3b d e x  + (3b d e  - 2c d e)x  + b d e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2708
+
+--S 2709 of 3139
+r0:=-1/4*x/(d*(2*c*d-b*e)*(d+e*x^2)^2)-1/8*(10*c*d-3*b*e)*x/(d^2*_
+   (2*c*d-b*e)^2*(d+e*x^2))-1/8*(28*c^2*d^2-16*b*c*d*e+3*b^2*e^2)*_
+   atan(x*sqrt(e)/sqrt(d))/(d^(5/2)*(2*c*d-b*e)^3*sqrt(e))-c^(5/2)*_
+   atanh(x*sqrt(c)*sqrt(e)/sqrt(c*d-b*e))/((2*c*d-b*e)^3*sqrt(e)*sqrt(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                                                          +-+ +-+
+--R          2 2 2 4      2 3   2     2 4  +-+ +-+         x\|c \|e
+--R       (8c d e x  + 16c d e x  + 8c d )\|c \|d atanh(--------------)
+--R                                                      +-----------+
+--R                                                     \|- b e + c d
+--R     + 
+--R              2 4            3      2 2 2  4
+--R           (3b e  - 16b c d e  + 28c d e )x
+--R         + 
+--R              2   3          2 2      2 3   2     2 2 2          3       2 4
+--R           (6b d e  - 32b c d e  + 56c d e)x  + 3b d e  - 16b c d e + 28c d
+--R      *
+--R                              +-+
+--R          +-----------+     x\|e
+--R         \|- b e + c d atan(-----)
+--R                              +-+
+--R                             \|d
+--R     + 
+--R             2 3            2      2 2   3      2   2          2       2 3
+--R         ((3b e  - 16b c d e  + 20c d e)x  + (5b d e  - 24b c d e + 28c d )x)
+--R      *
+--R          +-----------+ +-+ +-+
+--R         \|- b e + c d \|d \|e
+--R  /
+--R            3 2 5      2   3 4        2 4 3      3 5 2  4
+--R         (8b d e  - 48b c d e  + 96b c d e  - 64c d e )x
+--R       + 
+--R             3 3 4      2   4 3         2 5 2       3 6   2     3 4 3
+--R         (16b d e  - 96b c d e  + 192b c d e  - 128c d e)x  + 8b d e
+--R       + 
+--R              2   5 2        2 6       3 7
+--R         - 48b c d e  + 96b c d e - 64c d
+--R    *
+--R        +-----------+ +-+ +-+
+--R       \|- b e + c d \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2709
+
+--S 2710 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 4            3      2 2 2  4
+--R             (3b e  - 16b c d e  + 28c d e )x
+--R           + 
+--R                2   3          2 2      2 3   2     2 2 2          3       2 4
+--R             (6b d e  - 32b c d e  + 56c d e)x  + 3b d e  - 16b c d e + 28c d
+--R        *
+--R                   2      +-----+
+--R               (e x  - d)\|- d e  + 2d e x
+--R           log(---------------------------)
+--R                            2
+--R                         e x  + d
+--R       + 
+--R                                                    +--------------+
+--R              2 2 2 4      2 3   2     2 4  +-----+ |        c
+--R           (8c d e x  + 16c d e x  + 8c d )\|- d e  |- ------------
+--R                                                    |     2
+--R                                                   \|  b e  - c d e
+--R        *
+--R                                   +--------------+
+--R                      2            |        c              2
+--R               (- 2b e  + 2c d e)x |- ------------  + c e x  - b e + c d
+--R                                   |     2
+--R                                  \|  b e  - c d e
+--R           log(---------------------------------------------------------)
+--R                                        2
+--R                                   c e x  + b e - c d
+--R       + 
+--R               2 3            2      2 2   3       2   2          2       2 3
+--R           ((6b e  - 32b c d e  + 40c d e)x  + (10b d e  - 48b c d e + 56c d )x)
+--R        *
+--R            +-----+
+--R           \|- d e
+--R    /
+--R               3 2 5      2   3 4         2 4 3       3 5 2  4
+--R           (16b d e  - 96b c d e  + 192b c d e  - 128c d e )x
+--R         + 
+--R               3 3 4       2   4 3         2 5 2       3 6   2      3 4 3
+--R           (32b d e  - 192b c d e  + 384b c d e  - 256c d e)x  + 16b d e
+--R         + 
+--R                2   5 2         2 6        3 7
+--R           - 96b c d e  + 192b c d e - 128c d
+--R      *
+--R          +-----+
+--R         \|- d e
+--R     ,
+--R
+--R                                           +--------------+
+--R              2 2 2 4     2 3   2     2 4  |        c       +---+
+--R           (4c d e x  + 8c d e x  + 4c d ) |- ------------ \|d e
+--R                                           |     2
+--R                                          \|  b e  - c d e
+--R        *
+--R                                   +--------------+
+--R                      2            |        c              2
+--R               (- 2b e  + 2c d e)x |- ------------  + c e x  - b e + c d
+--R                                   |     2
+--R                                  \|  b e  - c d e
+--R           log(---------------------------------------------------------)
+--R                                        2
+--R                                   c e x  + b e - c d
+--R       + 
+--R                2 4            3      2 2 2  4
+--R             (3b e  - 16b c d e  + 28c d e )x
+--R           + 
+--R                2   3          2 2      2 3   2     2 2 2          3       2 4
+--R             (6b d e  - 32b c d e  + 56c d e)x  + 3b d e  - 16b c d e + 28c d
+--R        *
+--R                  +---+
+--R                x\|d e
+--R           atan(-------)
+--R                   d
+--R       + 
+--R               2 3            2      2 2   3      2   2          2       2 3
+--R           ((3b e  - 16b c d e  + 20c d e)x  + (5b d e  - 24b c d e + 28c d )x)
+--R        *
+--R            +---+
+--R           \|d e
+--R    /
+--R              3 2 5      2   3 4        2 4 3      3 5 2  4
+--R           (8b d e  - 48b c d e  + 96b c d e  - 64c d e )x
+--R         + 
+--R               3 3 4      2   4 3         2 5 2       3 6   2     3 4 3
+--R           (16b d e  - 96b c d e  + 192b c d e  - 128c d e)x  + 8b d e
+--R         + 
+--R                2   5 2        2 6       3 7
+--R           - 48b c d e  + 96b c d e - 64c d
+--R      *
+--R          +---+
+--R         \|d e
+--R     ,
+--R
+--R                2 4            3      2 2 2  4
+--R             (3b e  - 16b c d e  + 28c d e )x
+--R           + 
+--R                2   3          2 2      2 3   2     2 2 2          3       2 4
+--R             (6b d e  - 32b c d e  + 56c d e)x  + 3b d e  - 16b c d e + 28c d
+--R        *
+--R                   2      +-----+
+--R               (e x  - d)\|- d e  + 2d e x
+--R           log(---------------------------)
+--R                            2
+--R                         e x  + d
+--R       + 
+--R                                                      +------------+
+--R               2 2 2 4      2 3   2      2 4  +-----+ |      c
+--R           (16c d e x  + 32c d e x  + 16c d )\|- d e  |------------
+--R                                                      |   2
+--R                                                     \|b e  - c d e
+--R        *
+--R                            +------------+
+--R                            |      c
+--R                (b e - c d) |------------
+--R                            |   2
+--R                           \|b e  - c d e
+--R           atan(--------------------------)
+--R                            c x
+--R       + 
+--R               2 3            2      2 2   3       2   2          2       2 3
+--R           ((6b e  - 32b c d e  + 40c d e)x  + (10b d e  - 48b c d e + 56c d )x)
+--R        *
+--R            +-----+
+--R           \|- d e
+--R    /
+--R               3 2 5      2   3 4         2 4 3       3 5 2  4
+--R           (16b d e  - 96b c d e  + 192b c d e  - 128c d e )x
+--R         + 
+--R               3 3 4       2   4 3         2 5 2       3 6   2      3 4 3
+--R           (32b d e  - 192b c d e  + 384b c d e  - 256c d e)x  + 16b d e
+--R         + 
+--R                2   5 2         2 6        3 7
+--R           - 96b c d e  + 192b c d e - 128c d
+--R      *
+--R          +-----+
+--R         \|- d e
+--R     ,
+--R
+--R                2 4            3      2 2 2  4
+--R             (3b e  - 16b c d e  + 28c d e )x
+--R           + 
+--R                2   3          2 2      2 3   2     2 2 2          3       2 4
+--R             (6b d e  - 32b c d e  + 56c d e)x  + 3b d e  - 16b c d e + 28c d
+--R        *
+--R                  +---+
+--R                x\|d e
+--R           atan(-------)
+--R                   d
+--R       + 
+--R                                            +------------+
+--R              2 2 2 4      2 3   2     2 4  |      c       +---+
+--R           (8c d e x  + 16c d e x  + 8c d ) |------------ \|d e
+--R                                            |   2
+--R                                           \|b e  - c d e
+--R        *
+--R                            +------------+
+--R                            |      c
+--R                (b e - c d) |------------
+--R                            |   2
+--R                           \|b e  - c d e
+--R           atan(--------------------------)
+--R                            c x
+--R       + 
+--R               2 3            2      2 2   3      2   2          2       2 3
+--R           ((3b e  - 16b c d e  + 20c d e)x  + (5b d e  - 24b c d e + 28c d )x)
+--R        *
+--R            +---+
+--R           \|d e
+--R    /
+--R              3 2 5      2   3 4        2 4 3      3 5 2  4
+--R           (8b d e  - 48b c d e  + 96b c d e  - 64c d e )x
+--R         + 
+--R               3 3 4      2   4 3         2 5 2       3 6   2     3 4 3
+--R           (16b d e  - 96b c d e  + 192b c d e  - 128c d e)x  + 8b d e
+--R         + 
+--R                2   5 2        2 6       3 7
+--R           - 48b c d e  + 96b c d e - 64c d
+--R      *
+--R          +---+
+--R         \|d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2710
+
+--S 2711 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2                  2 2  +-----------+ +-+ +-+
+--R         (3b e  - 16b c d e + 28c d )\|- b e + c d \|d \|e
+--R      *
+--R                 2      +-----+
+--R             (e x  - d)\|- d e  + 2d e x
+--R         log(---------------------------)
+--R                          2
+--R                       e x  + d
+--R     + 
+--R                                     +--------------+
+--R           2 2 +-----+ +-----------+ |        c       +-+ +-+
+--R         8c d \|- d e \|- b e + c d  |- ------------ \|d \|e
+--R                                     |     2
+--R                                    \|  b e  - c d e
+--R      *
+--R                                 +--------------+
+--R                    2            |        c              2
+--R             (- 2b e  + 2c d e)x |- ------------  + c e x  - b e + c d
+--R                                 |     2
+--R                                \|  b e  - c d e
+--R         log(---------------------------------------------------------)
+--R                                      2
+--R                                 c e x  + b e - c d
+--R     + 
+--R                                          +-+ +-+
+--R            2 2 +-----+ +-+ +-+         x\|c \|e
+--R       - 16c d \|- d e \|c \|d atanh(--------------)
+--R                                      +-----------+
+--R                                     \|- b e + c d
+--R     + 
+--R                                                                  +-+
+--R            2 2                  2 2  +-----+ +-----------+     x\|e
+--R       (- 6b e  + 32b c d e - 56c d )\|- d e \|- b e + c d atan(-----)
+--R                                                                  +-+
+--R                                                                 \|d
+--R  /
+--R           3 2 3      2   3 2         2 4        3 5  +-----+ +-----------+ +-+
+--R       (16b d e  - 96b c d e  + 192b c d e - 128c d )\|- d e \|- b e + c d \|d
+--R    *
+--R        +-+
+--R       \|e
+--R                                                    Type: Expression(Integer)
+--E 2711
+
+--S 2712 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2712
+
+--S 2713 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             +--------------+
+--R           2 2 +-----------+ |        c       +-+ +-+ +---+
+--R         4c d \|- b e + c d  |- ------------ \|d \|e \|d e
+--R                             |     2
+--R                            \|  b e  - c d e
+--R      *
+--R                                 +--------------+
+--R                    2            |        c              2
+--R             (- 2b e  + 2c d e)x |- ------------  + c e x  - b e + c d
+--R                                 |     2
+--R                                \|  b e  - c d e
+--R         log(---------------------------------------------------------)
+--R                                      2
+--R                                 c e x  + b e - c d
+--R     + 
+--R                                       +-+ +-+
+--R           2 2 +-+ +-+ +---+         x\|c \|e
+--R       - 8c d \|c \|d \|d e atanh(--------------)
+--R                                   +-----------+
+--R                                  \|- b e + c d
+--R     + 
+--R                                                                +---+
+--R          2 2                  2 2  +-----------+ +-+ +-+     x\|d e
+--R       (3b e  - 16b c d e + 28c d )\|- b e + c d \|d \|e atan(-------)
+--R                                                                 d
+--R     + 
+--R                                                                +-+
+--R            2 2                  2 2  +-----------+ +---+     x\|e
+--R       (- 3b e  + 16b c d e - 28c d )\|- b e + c d \|d e atan(-----)
+--R                                                                +-+
+--R                                                               \|d
+--R  /
+--R        3 2 3      2   3 2        2 4       3 5  +-----------+ +-+ +-+ +---+
+--R     (8b d e  - 48b c d e  + 96b c d e - 64c d )\|- b e + c d \|d \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 2713
+
+--S 2714 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2714
+
+)clear all
+
+--S 2715 of 3139
+t0:=(d+e*x^2)^(5/2)/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R               2
+--R          c e x  + b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2715
+
+--S 2716 of 3139
+r0:=1/2*(5*c*d-2*b*e)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/(c^2*sqrt(e))+_
+   (2*c*d-b*e)^(3/2)*atan(x*sqrt(e)*sqrt(2*c*d-b*e)/(sqrt(-c*d+b*e)*_
+   sqrt(d+e*x^2)))/(c^2*sqrt(e)*sqrt(-c*d+b*e))+1/2*x*sqrt(d+e*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                             +-+
+--R                       +---------+         x\|e
+--R       (- 2b e + 5c d)\|b e - c d atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|e x  + d
+--R     + 
+--R                                              +------------+ +-+
+--R                       +------------+       x\|- b e + 2c d \|e
+--R       (- 2b e + 4c d)\|- b e + 2c d atan(-----------------------)
+--R                                                       +--------+
+--R                                           +---------+ |   2
+--R                                          \|b e - c d \|e x  + d
+--R     + 
+--R                           +--------+
+--R           +-+ +---------+ |   2
+--R       c x\|e \|b e - c d \|e x  + d
+--R  /
+--R       2 +-+ +---------+
+--R     2c \|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2716
+
+--S 2717 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                +--------+
+--R                            +-+ |   2               2           2
+--R             (4b e - 10c d)\|d \|e x  + d  + (- 2b e  + 5c d e)x  - 4b d e
+--R           + 
+--R                  2
+--R             10c d
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|d \|e  + e x)\|e x  + d  + (- e x  - d)\|e  - e x\|d
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|d \|e x  + d  - d
+--R       + 
+--R                           +------------+         +--------+
+--R                           | b e - 2c d   +-+ +-+ |   2
+--R             (2b e - 4c d) |------------ \|d \|e \|e x  + d
+--R                           |   2
+--R                          \|b e  - c d e
+--R           + 
+--R                                                    +------------+
+--R                    2           2                2  | b e - 2c d   +-+
+--R             ((- b e  + 2c d e)x  - 2b d e + 4c d ) |------------ \|e
+--R                                                    |   2
+--R                                                   \|b e  - c d e
+--R        *
+--R           log
+--R                            2           2                2  +-+
+--R                      ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                    + 
+--R                                3         2  3            2       2
+--R                        ((- 2b e  + 2c d e )x  + (- 4b d e  + 4c d e)x)
+--R                     *
+--R                         +------------+
+--R                         | b e - 2c d
+--R                         |------------
+--R                         |   2
+--R                        \|b e  - c d e
+--R                 *
+--R                     +--------+
+--R                     |   2
+--R                    \|e x  + d
+--R                + 
+--R                                                              +------------+
+--R                        3         2  3          2       2     | b e - 2c d   +-+
+--R                  ((4b e  - 4c d e )x  + (4b d e  - 4c d e)x) |------------ \|d
+--R                                                              |   2
+--R                                                             \|b e  - c d e
+--R                + 
+--R                       3         2  4            2       2   2       2        3
+--R                (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e + 2c d
+--R             /
+--R                                              +--------+
+--R                         2                +-+ |   2           2 4
+--R                  (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R                + 
+--R                        2          2                2
+--R                  (- b e  - c d e)x  - 2b d e + 2c d
+--R       + 
+--R                                 +--------+
+--R                 3           +-+ |   2               3           +-+ +-+
+--R         (- c e x  - 2c d x)\|e \|e x  + d  + (2c e x  + 2c d x)\|d \|e
+--R    /
+--R                   +--------+
+--R         2 +-+ +-+ |   2             2   2     2   +-+
+--R       4c \|d \|e \|e x  + d  + (- 2c e x  - 4c d)\|e
+--R     ,
+--R
+--R                                +--------+
+--R                            +-+ |   2               2           2
+--R             (4b e - 10c d)\|d \|e x  + d  + (- 2b e  + 5c d e)x  - 4b d e
+--R           + 
+--R                  2
+--R             10c d
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|d \|e  + e x)\|e x  + d  + (- e x  - d)\|e  - e x\|d
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|d \|e x  + d  - d
+--R       + 
+--R                           +------------+         +--------+
+--R                           |- b e + 2c d  +-+ +-+ |   2
+--R             (4b e - 8c d) |------------ \|d \|e \|e x  + d
+--R                           |   2
+--R                          \|b e  - c d e
+--R           + 
+--R                                                     +------------+
+--R                     2           2                2  |- b e + 2c d  +-+
+--R             ((- 2b e  + 4c d e)x  - 4b d e + 8c d ) |------------ \|e
+--R                                                     |   2
+--R                                                    \|b e  - c d e
+--R        *
+--R           atan
+--R                                                     +--------+
+--R                       2           2              2  |   2
+--R                  ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R                + 
+--R                          2              2  +-+
+--R                  (c d e x  + b d e - c d )\|d
+--R             /
+--R                                  +------------+
+--R                    3        2  3 |- b e + 2c d
+--R                (b e  - c d e )x  |------------
+--R                                  |   2
+--R                                 \|b e  - c d e
+--R       + 
+--R                             +------------+         +--------+
+--R                             |- b e + 2c d  +-+ +-+ |   2
+--R             (- 4b e + 8c d) |------------ \|d \|e \|e x  + d
+--R                             |   2
+--R                            \|b e  - c d e
+--R           + 
+--R                                                   +------------+
+--R                   2           2                2  |- b e + 2c d  +-+
+--R             ((2b e  - 4c d e)x  + 4b d e - 8c d ) |------------ \|e
+--R                                                   |   2
+--R                                                  \|b e  - c d e
+--R        *
+--R                        +-+
+--R                       \|d
+--R           atan(------------------)
+--R                    +------------+
+--R                    |- b e + 2c d
+--R                e x |------------
+--R                    |   2
+--R                   \|b e  - c d e
+--R       + 
+--R                                 +--------+
+--R                 3           +-+ |   2               3           +-+ +-+
+--R         (- c e x  - 2c d x)\|e \|e x  + d  + (2c e x  + 2c d x)\|d \|e
+--R    /
+--R                   +--------+
+--R         2 +-+ +-+ |   2             2   2     2   +-+
+--R       4c \|d \|e \|e x  + d  + (- 2c e x  - 4c d)\|e
+--R     ,
+--R
+--R                                 +------------+     +--------+
+--R                           +---+ | b e - 2c d   +-+ |   2
+--R             (2b e - 4c d)\|- e  |------------ \|d \|e x  + d
+--R                                 |   2
+--R                                \|b e  - c d e
+--R           + 
+--R                                                          +------------+
+--R                    2           2                2  +---+ | b e - 2c d
+--R             ((- b e  + 2c d e)x  - 2b d e + 4c d )\|- e  |------------
+--R                                                          |   2
+--R                                                         \|b e  - c d e
+--R        *
+--R           log
+--R                            2           2                2  +-+
+--R                      ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                    + 
+--R                                3         2  3            2       2
+--R                        ((- 2b e  + 2c d e )x  + (- 4b d e  + 4c d e)x)
+--R                     *
+--R                         +------------+
+--R                         | b e - 2c d
+--R                         |------------
+--R                         |   2
+--R                        \|b e  - c d e
+--R                 *
+--R                     +--------+
+--R                     |   2
+--R                    \|e x  + d
+--R                + 
+--R                                                              +------------+
+--R                        3         2  3          2       2     | b e - 2c d   +-+
+--R                  ((4b e  - 4c d e )x  + (4b d e  - 4c d e)x) |------------ \|d
+--R                                                              |   2
+--R                                                             \|b e  - c d e
+--R                + 
+--R                       3         2  4            2       2   2       2        3
+--R                (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e + 2c d
+--R             /
+--R                                              +--------+
+--R                         2                +-+ |   2           2 4
+--R                  (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R                + 
+--R                        2          2                2
+--R                  (- b e  - c d e)x  - 2b d e + 2c d
+--R       + 
+--R                                  +--------+
+--R                              +-+ |   2             2            2
+--R             (- 8b e + 20c d)\|d \|e x  + d  + (4b e  - 10c d e)x  + 8b d e
+--R           + 
+--R                    2
+--R             - 20c d
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- e \|e x  + d  - \|- e \|d
+--R           atan(------------------------------)
+--R                              e x
+--R       + 
+--R                                   +--------+
+--R                 3           +---+ |   2               3           +---+ +-+
+--R         (- c e x  - 2c d x)\|- e \|e x  + d  + (2c e x  + 2c d x)\|- e \|d
+--R    /
+--R                     +--------+
+--R         2 +---+ +-+ |   2             2   2     2   +---+
+--R       4c \|- e \|d \|e x  + d  + (- 2c e x  - 4c d)\|- e
+--R     ,
+--R
+--R                                  +--------+
+--R                              +-+ |   2             2            2
+--R             (- 8b e + 20c d)\|d \|e x  + d  + (4b e  - 10c d e)x  + 8b d e
+--R           + 
+--R                    2
+--R             - 20c d
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- e \|e x  + d  - \|- e \|d
+--R           atan(------------------------------)
+--R                              e x
+--R       + 
+--R                                 +------------+     +--------+
+--R                           +---+ |- b e + 2c d  +-+ |   2
+--R             (4b e - 8c d)\|- e  |------------ \|d \|e x  + d
+--R                                 |   2
+--R                                \|b e  - c d e
+--R           + 
+--R                                                           +------------+
+--R                     2           2                2  +---+ |- b e + 2c d
+--R             ((- 2b e  + 4c d e)x  - 4b d e + 8c d )\|- e  |------------
+--R                                                           |   2
+--R                                                          \|b e  - c d e
+--R        *
+--R           atan
+--R                                                     +--------+
+--R                       2           2              2  |   2
+--R                  ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R                + 
+--R                          2              2  +-+
+--R                  (c d e x  + b d e - c d )\|d
+--R             /
+--R                                  +------------+
+--R                    3        2  3 |- b e + 2c d
+--R                (b e  - c d e )x  |------------
+--R                                  |   2
+--R                                 \|b e  - c d e
+--R       + 
+--R                                   +------------+     +--------+
+--R                             +---+ |- b e + 2c d  +-+ |   2
+--R             (- 4b e + 8c d)\|- e  |------------ \|d \|e x  + d
+--R                                   |   2
+--R                                  \|b e  - c d e
+--R           + 
+--R                                                         +------------+
+--R                   2           2                2  +---+ |- b e + 2c d
+--R             ((2b e  - 4c d e)x  + 4b d e - 8c d )\|- e  |------------
+--R                                                         |   2
+--R                                                        \|b e  - c d e
+--R        *
+--R                        +-+
+--R                       \|d
+--R           atan(------------------)
+--R                    +------------+
+--R                    |- b e + 2c d
+--R                e x |------------
+--R                    |   2
+--R                   \|b e  - c d e
+--R       + 
+--R                                   +--------+
+--R                 3           +---+ |   2               3           +---+ +-+
+--R         (- c e x  - 2c d x)\|- e \|e x  + d  + (2c e x  + 2c d x)\|- e \|d
+--R    /
+--R                     +--------+
+--R         2 +---+ +-+ |   2             2   2     2   +---+
+--R       4c \|- e \|d \|e x  + d  + (- 2c e x  - 4c d)\|- e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2717
+
+--S 2718 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       +---------+
+--R         (2b e - 5c d)\|b e - c d
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|d \|e  + e x)\|e x  + d  + (- e x  - d)\|e  - e x\|d
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R     + 
+--R                      +------------+
+--R                      | b e - 2c d   +-+ +---------+
+--R         (b e - 2c d) |------------ \|e \|b e - c d
+--R                      |   2
+--R                     \|b e  - c d e
+--R      *
+--R         log
+--R                          2           2                2  +-+
+--R                    ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                  + 
+--R                                                                  +------------+
+--R                          3         2  3            2       2     | b e - 2c d
+--R                  ((- 2b e  + 2c d e )x  + (- 4b d e  + 4c d e)x) |------------
+--R                                                                  |   2
+--R                                                                 \|b e  - c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                                                            +------------+
+--R                      3         2  3          2       2     | b e - 2c d   +-+
+--R                ((4b e  - 4c d e )x  + (4b d e  - 4c d e)x) |------------ \|d
+--R                                                            |   2
+--R                                                           \|b e  - c d e
+--R              + 
+--R                       3         2  4            2       2   2       2        3
+--R                (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e + 2c d
+--R           /
+--R                                            +--------+
+--R                       2                +-+ |   2           2 4
+--R                (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R              + 
+--R                      2          2                2
+--R                (- b e  - c d e)x  - 2b d e + 2c d
+--R     + 
+--R                                           +-+
+--R                     +---------+         x\|e
+--R       (2b e - 5c d)\|b e - c d atanh(-----------)
+--R                                       +--------+
+--R                                       |   2
+--R                                      \|e x  + d
+--R     + 
+--R                                            +------------+ +-+
+--R                     +------------+       x\|- b e + 2c d \|e
+--R       (2b e - 4c d)\|- b e + 2c d atan(-----------------------)
+--R                                                     +--------+
+--R                                         +---------+ |   2
+--R                                        \|b e - c d \|e x  + d
+--R  /
+--R       2 +-+ +---------+
+--R     2c \|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2718
+
+--S 2719 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2719
+
+--S 2720 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+
+--R         (2b e - 5c d)\|b e - c d
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|d \|e  + e x)\|e x  + d  + (- e x  - d)\|e  - e x\|d
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R     + 
+--R                                           +-+
+--R                     +---------+         x\|e
+--R       (2b e - 5c d)\|b e - c d atanh(-----------)
+--R                                       +--------+
+--R                                       |   2
+--R                                      \|e x  + d
+--R     + 
+--R                       +------------+
+--R                       |- b e + 2c d  +-+ +---------+
+--R         (2b e - 4c d) |------------ \|e \|b e - c d
+--R                       |   2
+--R                      \|b e  - c d e
+--R      *
+--R         atan
+--R                                                   +--------+
+--R                     2           2              2  |   2
+--R                ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R              + 
+--R                        2              2  +-+
+--R                (c d e x  + b d e - c d )\|d
+--R           /
+--R                                +------------+
+--R                  3        2  3 |- b e + 2c d
+--R              (b e  - c d e )x  |------------
+--R                                |   2
+--R                               \|b e  - c d e
+--R     + 
+--R                       +------------+                             +-+
+--R                       |- b e + 2c d  +-+ +---------+            \|d
+--R       (- 2b e + 4c d) |------------ \|e \|b e - c d atan(------------------)
+--R                       |   2                                  +------------+
+--R                      \|b e  - c d e                          |- b e + 2c d
+--R                                                          e x |------------
+--R                                                              |   2
+--R                                                             \|b e  - c d e
+--R     + 
+--R                                            +------------+ +-+
+--R                     +------------+       x\|- b e + 2c d \|e
+--R       (2b e - 4c d)\|- b e + 2c d atan(-----------------------)
+--R                                                     +--------+
+--R                                         +---------+ |   2
+--R                                        \|b e - c d \|e x  + d
+--R  /
+--R       2 +-+ +---------+
+--R     2c \|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2720
+
+--S 2721 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2721
+
+)clear all
+
+--S 2722 of 3139
+t0:=(d+e*x^2)^(3/2)/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|e x  + d
+--R   (1)  ------------------
+--R             2
+--R        c e x  + b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2722
+
+--S 2723 of 3139
+r0:=atanh(x*sqrt(e)/sqrt(d+e*x^2))/(c*sqrt(e))+atan(x*sqrt(e)*_
+   sqrt(2*c*d-b*e)/(sqrt(-c*d+b*e)*sqrt(d+e*x^2)))*sqrt(2*c*d-b*e)/_
+   (c*sqrt(e)*sqrt(-c*d+b*e))
+--R 
+--R
+--R   (2)
+--R                          +-+                               +------------+ +-+
+--R    +---------+         x\|e         +------------+       x\|- b e + 2c d \|e
+--R   \|b e - c d atanh(-----------) + \|- b e + 2c d atan(-----------------------)
+--R                      +--------+                                     +--------+
+--R                      |   2                              +---------+ |   2
+--R                     \|e x  + d                         \|b e - c d \|e x  + d
+--R   -----------------------------------------------------------------------------
+--R                                   +-+ +---------+
+--R                                 c\|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2723
+
+--S 2724 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               +--------+
+--R                +-+ +-+        |   2              2      +-+       +-+
+--R              (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R         2log(--------------------------------------------------------)
+--R                                      +--------+
+--R                                  +-+ |   2
+--R                                 \|d \|e x  + d  - d
+--R       + 
+--R            +------------+
+--R            | b e - 2c d   +-+
+--R            |------------ \|e
+--R            |   2
+--R           \|b e  - c d e
+--R        *
+--R           log
+--R                            2           2                2  +-+
+--R                      ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                    + 
+--R                                                                +------------+
+--R                          3         2  3          2       2     | b e - 2c d
+--R                    ((2b e  - 2c d e )x  + (4b d e  - 4c d e)x) |------------
+--R                                                                |   2
+--R                                                               \|b e  - c d e
+--R                 *
+--R                     +--------+
+--R                     |   2
+--R                    \|e x  + d
+--R                + 
+--R                            3         2  3            2       2
+--R                    ((- 4b e  + 4c d e )x  + (- 4b d e  + 4c d e)x)
+--R                 *
+--R                     +------------+
+--R                     | b e - 2c d   +-+
+--R                     |------------ \|d
+--R                     |   2
+--R                    \|b e  - c d e
+--R                + 
+--R                       3         2  4            2       2   2       2        3
+--R                (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e + 2c d
+--R             /
+--R                                              +--------+
+--R                         2                +-+ |   2           2 4
+--R                  (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R                + 
+--R                        2          2                2
+--R                  (- b e  - c d e)x  - 2b d e + 2c d
+--R    /
+--R          +-+
+--R       2c\|e
+--R     ,
+--R
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R       + 
+--R         -
+--R               +------------+
+--R               |- b e + 2c d  +-+
+--R               |------------ \|e
+--R               |   2
+--R              \|b e  - c d e
+--R           *
+--R              atan
+--R                                                        +--------+
+--R                          2           2              2  |   2
+--R                     ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R                   + 
+--R                             2              2  +-+
+--R                     (c d e x  + b d e - c d )\|d
+--R                /
+--R                                     +------------+
+--R                       3        2  3 |- b e + 2c d
+--R                   (b e  - c d e )x  |------------
+--R                                     |   2
+--R                                    \|b e  - c d e
+--R       + 
+--R          +------------+                 +-+
+--R          |- b e + 2c d  +-+            \|d
+--R          |------------ \|e atan(------------------)
+--R          |   2                      +------------+
+--R         \|b e  - c d e              |- b e + 2c d
+--R                                 e x |------------
+--R                                     |   2
+--R                                    \|b e  - c d e
+--R    /
+--R         +-+
+--R       c\|e
+--R     ,
+--R
+--R                  +------------+
+--R            +---+ | b e - 2c d
+--R           \|- e  |------------
+--R                  |   2
+--R                 \|b e  - c d e
+--R        *
+--R           log
+--R                            2           2                2  +-+
+--R                      ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                    + 
+--R                                                                +------------+
+--R                          3         2  3          2       2     | b e - 2c d
+--R                    ((2b e  - 2c d e )x  + (4b d e  - 4c d e)x) |------------
+--R                                                                |   2
+--R                                                               \|b e  - c d e
+--R                 *
+--R                     +--------+
+--R                     |   2
+--R                    \|e x  + d
+--R                + 
+--R                            3         2  3            2       2
+--R                    ((- 4b e  + 4c d e )x  + (- 4b d e  + 4c d e)x)
+--R                 *
+--R                     +------------+
+--R                     | b e - 2c d   +-+
+--R                     |------------ \|d
+--R                     |   2
+--R                    \|b e  - c d e
+--R                + 
+--R                       3         2  4            2       2   2       2        3
+--R                (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e + 2c d
+--R             /
+--R                                              +--------+
+--R                         2                +-+ |   2           2 4
+--R                  (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R                + 
+--R                        2          2                2
+--R                  (- b e  - c d e)x  - 2b d e + 2c d
+--R       + 
+--R                      +--------+
+--R                +---+ |   2         +---+ +-+
+--R               \|- e \|e x  + d  - \|- e \|d
+--R         4atan(------------------------------)
+--R                             e x
+--R    /
+--R          +---+
+--R       2c\|- e
+--R     ,
+--R
+--R                      +--------+
+--R                +---+ |   2         +---+ +-+
+--R               \|- e \|e x  + d  - \|- e \|d
+--R         2atan(------------------------------)
+--R                             e x
+--R       + 
+--R         -
+--R                     +------------+
+--R               +---+ |- b e + 2c d
+--R              \|- e  |------------
+--R                     |   2
+--R                    \|b e  - c d e
+--R           *
+--R              atan
+--R                                                        +--------+
+--R                          2           2              2  |   2
+--R                     ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R                   + 
+--R                             2              2  +-+
+--R                     (c d e x  + b d e - c d )\|d
+--R                /
+--R                                     +------------+
+--R                       3        2  3 |- b e + 2c d
+--R                   (b e  - c d e )x  |------------
+--R                                     |   2
+--R                                    \|b e  - c d e
+--R       + 
+--R                +------------+             +-+
+--R          +---+ |- b e + 2c d             \|d
+--R         \|- e  |------------ atan(------------------)
+--R                |   2                  +------------+
+--R               \|b e  - c d e          |- b e + 2c d
+--R                                   e x |------------
+--R                                       |   2
+--R                                      \|b e  - c d e
+--R    /
+--R         +---+
+--R       c\|- e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2724
+
+--S 2725 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           +---------+
+--R         2\|b e - c d
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R     + 
+--R          +------------+
+--R          | b e - 2c d   +-+ +---------+
+--R          |------------ \|e \|b e - c d
+--R          |   2
+--R         \|b e  - c d e
+--R      *
+--R         log
+--R                          2           2                2  +-+
+--R                    ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                  + 
+--R                                                                +------------+
+--R                          3         2  3          2       2     | b e - 2c d
+--R                    ((2b e  - 2c d e )x  + (4b d e  - 4c d e)x) |------------
+--R                                                                |   2
+--R                                                               \|b e  - c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                                                                  +------------+
+--R                          3         2  3            2       2     | b e - 2c d
+--R                  ((- 4b e  + 4c d e )x  + (- 4b d e  + 4c d e)x) |------------
+--R                                                                  |   2
+--R                                                                 \|b e  - c d e
+--R               *
+--R                   +-+
+--R                  \|d
+--R              + 
+--R                       3         2  4            2       2   2       2        3
+--R                (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e + 2c d
+--R           /
+--R                                            +--------+
+--R                       2                +-+ |   2           2 4
+--R                (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R              + 
+--R                      2          2                2
+--R                (- b e  - c d e)x  - 2b d e + 2c d
+--R     + 
+--R                                 +-+
+--R           +---------+         x\|e
+--R       - 2\|b e - c d atanh(-----------)
+--R                             +--------+
+--R                             |   2
+--R                            \|e x  + d
+--R     + 
+--R                                  +------------+ +-+
+--R           +------------+       x\|- b e + 2c d \|e
+--R       - 2\|- b e + 2c d atan(-----------------------)
+--R                                           +--------+
+--R                               +---------+ |   2
+--R                              \|b e - c d \|e x  + d
+--R  /
+--R        +-+ +---------+
+--R     2c\|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2725
+
+--S 2726 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2726
+
+--S 2727 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                        +--------+
+--R                         +-+ +-+        |   2              2      +-+       +-+
+--R        +---------+    (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R       \|b e - c d log(--------------------------------------------------------)
+--R                                               +--------+
+--R                                           +-+ |   2
+--R                                          \|d \|e x  + d  - d
+--R     + 
+--R                                +-+
+--R          +---------+         x\|e
+--R       - \|b e - c d atanh(-----------)
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R     + 
+--R       -
+--R             +------------+
+--R             |- b e + 2c d  +-+ +---------+
+--R             |------------ \|e \|b e - c d
+--R             |   2
+--R            \|b e  - c d e
+--R         *
+--R            atan
+--R                                                      +--------+
+--R                        2           2              2  |   2
+--R                   ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R                 + 
+--R                           2              2  +-+
+--R                   (c d e x  + b d e - c d )\|d
+--R              /
+--R                                   +------------+
+--R                     3        2  3 |- b e + 2c d
+--R                 (b e  - c d e )x  |------------
+--R                                   |   2
+--R                                  \|b e  - c d e
+--R     + 
+--R        +------------+                             +-+
+--R        |- b e + 2c d  +-+ +---------+            \|d
+--R        |------------ \|e \|b e - c d atan(------------------)
+--R        |   2                                  +------------+
+--R       \|b e  - c d e                          |- b e + 2c d
+--R                                           e x |------------
+--R                                               |   2
+--R                                              \|b e  - c d e
+--R     + 
+--R                                 +------------+ +-+
+--R          +------------+       x\|- b e + 2c d \|e
+--R       - \|- b e + 2c d atan(-----------------------)
+--R                                          +--------+
+--R                              +---------+ |   2
+--R                             \|b e - c d \|e x  + d
+--R  /
+--R       +-+ +---------+
+--R     c\|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2727
+
+--S 2728 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2728
+
+)clear all
+
+--S 2729 of 3139
+t0:=(d+e*x^2)^(1/2)/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R   (1)  ------------------------------
+--R           2 4      2 2              2
+--R        c e x  + b e x  + b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 2729
+
+--S 2730 of 3139
+r0:=atan(x*sqrt(e)*sqrt(2*c*d-b*e)/(sqrt(-c*d+b*e)*sqrt(d+e*x^2)))/_
+   (sqrt(e)*sqrt(2*c*d-b*e)*sqrt(-c*d+b*e))
+--R 
+--R
+--R                  +------------+ +-+
+--R                x\|- b e + 2c d \|e
+--R         atan(-----------------------)
+--R                           +--------+
+--R               +---------+ |   2
+--R              \|b e - c d \|e x  + d
+--R   (2)  -------------------------------
+--R         +------------+ +-+ +---------+
+--R        \|- b e + 2c d \|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2730
+
+--S 2731 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                          2           2                2  +-+
+--R                    ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                 *
+--R                     +-------------------------+
+--R                     | 2 3           2     2 2
+--R                    \|b e  - 3b c d e  + 2c d e
+--R                + 
+--R                       2 4           3     2 2 2  3
+--R                  (- 2b e  + 6b c d e  - 4c d e )x
+--R                + 
+--R                       2   3          2 2     2 3
+--R                  (- 4b d e  + 12b c d e  - 8c d e)x
+--R             *
+--R                 +--------+
+--R                 |   2
+--R                \|e x  + d
+--R            + 
+--R                           3         2  4            2       2   2       2
+--R                    (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e
+--R                  + 
+--R                        3
+--R                    2c d
+--R             *
+--R                 +-------------------------+
+--R                 | 2 3           2     2 2
+--R                \|b e  - 3b c d e  + 2c d e
+--R            + 
+--R                     2 4            3     2 2 2  3
+--R                  (4b e  - 12b c d e  + 8c d e )x
+--R                + 
+--R                     2   3          2 2     2 3
+--R                  (4b d e  - 12b c d e  + 8c d e)x
+--R             *
+--R                 +-+
+--R                \|d
+--R         /
+--R                                          +--------+
+--R                     2                +-+ |   2           2 4
+--R              (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R            + 
+--R                    2          2                2
+--R              (- b e  - c d e)x  - 2b d e + 2c d
+--R    /
+--R         +-------------------------+
+--R         | 2 3           2     2 2
+--R       2\|b e  - 3b c d e  + 2c d e
+--R     ,
+--R
+--R         -
+--R            atan
+--R                                                      +--------+
+--R                        2           2              2  |   2
+--R                   ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R                 + 
+--R                           2              2  +-+
+--R                   (c d e x  + b d e - c d )\|d
+--R              /
+--R                      +---------------------------+
+--R                    3 |   2 3           2     2 2
+--R                 e x \|- b e  + 3b c d e  - 2c d e
+--R       + 
+--R                 +---------------------------+
+--R                 |   2 3           2     2 2   +-+
+--R                \|- b e  + 3b c d e  - 2c d e \|d
+--R         - atan(----------------------------------)
+--R                             2
+--R                         (b e  - 2c d e)x
+--R    /
+--R        +---------------------------+
+--R        |   2 3           2     2 2
+--R       \|- b e  + 3b c d e  - 2c d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2731
+
+--S 2732 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +------------+ +-+ +---------+
+--R         \|- b e + 2c d \|e \|b e - c d
+--R      *
+--R         log
+--R                            2           2                2  +-+
+--R                      ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                   *
+--R                       +-------------------------+
+--R                       | 2 3           2     2 2
+--R                      \|b e  - 3b c d e  + 2c d e
+--R                  + 
+--R                         2 4           3     2 2 2  3
+--R                    (- 2b e  + 6b c d e  - 4c d e )x
+--R                  + 
+--R                         2   3          2 2     2 3
+--R                    (- 4b d e  + 12b c d e  - 8c d e)x
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                           3         2  4            2       2   2       2
+--R                    (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e
+--R                  + 
+--R                        3
+--R                    2c d
+--R               *
+--R                   +-------------------------+
+--R                   | 2 3           2     2 2
+--R                  \|b e  - 3b c d e  + 2c d e
+--R              + 
+--R                       2 4            3     2 2 2  3
+--R                    (4b e  - 12b c d e  + 8c d e )x
+--R                  + 
+--R                       2   3          2 2     2 3
+--R                    (4b d e  - 12b c d e  + 8c d e)x
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R                                            +--------+
+--R                       2                +-+ |   2           2 4
+--R                (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R              + 
+--R                      2          2                2
+--R                (- b e  - c d e)x  - 2b d e + 2c d
+--R     + 
+--R           +-------------------------+         +------------+ +-+
+--R           | 2 3           2     2 2         x\|- b e + 2c d \|e
+--R       - 2\|b e  - 3b c d e  + 2c d e atan(-----------------------)
+--R                                                        +--------+
+--R                                            +---------+ |   2
+--R                                           \|b e - c d \|e x  + d
+--R  /
+--R                                      +-------------------------+
+--R       +------------+ +-+ +---------+ | 2 3           2     2 2
+--R     2\|- b e + 2c d \|e \|b e - c d \|b e  - 3b c d e  + 2c d e
+--R                                                    Type: Expression(Integer)
+--E 2732
+
+--S 2733 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2733
+
+--S 2734 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       -
+--R             +------------+ +-+ +---------+
+--R            \|- b e + 2c d \|e \|b e - c d
+--R         *
+--R            atan
+--R                                                      +--------+
+--R                        2           2              2  |   2
+--R                   ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R                 + 
+--R                           2              2  +-+
+--R                   (c d e x  + b d e - c d )\|d
+--R              /
+--R                      +---------------------------+
+--R                    3 |   2 3           2     2 2
+--R                 e x \|- b e  + 3b c d e  - 2c d e
+--R     + 
+--R                                              +---------------------------+
+--R                                              |   2 3           2     2 2   +-+
+--R          +------------+ +-+ +---------+     \|- b e  + 3b c d e  - 2c d e \|d
+--R       - \|- b e + 2c d \|e \|b e - c d atan(----------------------------------)
+--R                                                          2
+--R                                                      (b e  - 2c d e)x
+--R     + 
+--R          +---------------------------+         +------------+ +-+
+--R          |   2 3           2     2 2         x\|- b e + 2c d \|e
+--R       - \|- b e  + 3b c d e  - 2c d e atan(-----------------------)
+--R                                                         +--------+
+--R                                             +---------+ |   2
+--R                                            \|b e - c d \|e x  + d
+--R  /
+--R      +---------------------------+
+--R      |   2 3           2     2 2   +------------+ +-+ +---------+
+--R     \|- b e  + 3b c d e  - 2c d e \|- b e + 2c d \|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2734
+
+--S 2735 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2735
+
+)clear all
+
+--S 2736 of 3139
+t0:=1/((d+e*x^2)^(1/2)*(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4))
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R                                         +--------+
+--R            2 4      2 2              2  |   2
+--R        (c e x  + b e x  + b d e - c d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2736
+
+--S 2737 of 3139
+r0:=c*atan(x*sqrt(e)*sqrt(2*c*d-b*e)/(sqrt(-c*d+b*e)*sqrt(d+e*x^2)))/_
+   ((2*c*d-b*e)^(3/2)*sqrt(e)*sqrt(-c*d+b*e))-x/(d*(2*c*d-b*e)*sqrt(d+e*x^2))
+--R 
+--R
+--R   (2)
+--R             +--------+         +------------+ +-+
+--R             |   2            x\|- b e + 2c d \|e
+--R       - c d\|e x  + d atan(-----------------------)
+--R                                         +--------+
+--R                             +---------+ |   2
+--R                            \|b e - c d \|e x  + d
+--R     + 
+--R         +------------+ +-+ +---------+
+--R       x\|- b e + 2c d \|e \|b e - c d
+--R  /
+--R                                                    +--------+
+--R                  2  +------------+ +-+ +---------+ |   2
+--R     (b d e - 2c d )\|- b e + 2c d \|e \|b e - c d \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2737
+
+--S 2738 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    +--------+
+--R                +-+ |   2               2      2
+--R           (c d\|d \|e x  + d  - c d e x  - c d )
+--R        *
+--R           log
+--R                              2           2                2  +-+
+--R                        ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                     *
+--R                         +-------------------------+
+--R                         | 2 3           2     2 2
+--R                        \|b e  - 3b c d e  + 2c d e
+--R                    + 
+--R                         2 4           3     2 2 2  3
+--R                      (2b e  - 6b c d e  + 4c d e )x
+--R                    + 
+--R                         2   3          2 2     2 3
+--R                      (4b d e  - 12b c d e  + 8c d e)x
+--R                 *
+--R                     +--------+
+--R                     |   2
+--R                    \|e x  + d
+--R                + 
+--R                             3         2  4            2       2   2       2
+--R                      (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e
+--R                    + 
+--R                          3
+--R                      2c d
+--R                 *
+--R                     +-------------------------+
+--R                     | 2 3           2     2 2
+--R                    \|b e  - 3b c d e  + 2c d e
+--R                + 
+--R                           2 4            3     2 2 2  3
+--R                      (- 4b e  + 12b c d e  - 8c d e )x
+--R                    + 
+--R                           2   3          2 2     2 3
+--R                      (- 4b d e  + 12b c d e  - 8c d e)x
+--R                 *
+--R                     +-+
+--R                    \|d
+--R             /
+--R                                              +--------+
+--R                         2                +-+ |   2           2 4
+--R                  (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R                + 
+--R                        2          2                2
+--R                  (- b e  - c d e)x  - 2b d e + 2c d
+--R       + 
+--R              +-------------------------+ +--------+
+--R              | 2 3           2     2 2   |   2
+--R         - 2x\|b e  - 3b c d e  + 2c d e \|e x  + d
+--R       + 
+--R                +-------------------------+
+--R            +-+ | 2 3           2     2 2
+--R         2x\|d \|b e  - 3b c d e  + 2c d e
+--R    /
+--R                              +-------------------------+ +--------+
+--R                       2  +-+ | 2 3           2     2 2   |   2
+--R         (2b d e - 4c d )\|d \|b e  - 3b c d e  + 2c d e \|e x  + d
+--R       + 
+--R                                                   +-------------------------+
+--R                   2       2   2       2        3  | 2 3           2     2 2
+--R         ((- 2b d e  + 4c d e)x  - 2b d e + 4c d )\|b e  - 3b c d e  + 2c d e
+--R     ,
+--R
+--R                    +--------+
+--R                +-+ |   2               2      2
+--R           (c d\|d \|e x  + d  - c d e x  - c d )
+--R        *
+--R           atan
+--R                                                     +--------+
+--R                       2           2              2  |   2
+--R                  ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R                + 
+--R                          2              2  +-+
+--R                  (c d e x  + b d e - c d )\|d
+--R             /
+--R                     +---------------------------+
+--R                   3 |   2 3           2     2 2
+--R                e x \|- b e  + 3b c d e  - 2c d e
+--R       + 
+--R                    +--------+
+--R                +-+ |   2               2      2
+--R           (c d\|d \|e x  + d  - c d e x  - c d )
+--R        *
+--R                 +---------------------------+
+--R                 |   2 3           2     2 2   +-+
+--R                \|- b e  + 3b c d e  - 2c d e \|d
+--R           atan(----------------------------------)
+--R                             2
+--R                         (b e  - 2c d e)x
+--R       + 
+--R             +---------------------------+ +--------+
+--R             |   2 3           2     2 2   |   2
+--R         - x\|- b e  + 3b c d e  - 2c d e \|e x  + d
+--R       + 
+--R           +---------------------------+
+--R           |   2 3           2     2 2   +-+
+--R         x\|- b e  + 3b c d e  - 2c d e \|d
+--R    /
+--R                         +---------------------------+     +--------+
+--R                      2  |   2 3           2     2 2   +-+ |   2
+--R         (b d e - 2c d )\|- b e  + 3b c d e  - 2c d e \|d \|e x  + d
+--R       + 
+--R                                                 +---------------------------+
+--R                  2       2   2      2        3  |   2 3           2     2 2
+--R         ((- b d e  + 2c d e)x  - b d e + 2c d )\|- b e  + 3b c d e  - 2c d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2738
+
+--S 2739 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           +------------+ +-+ +---------+
+--R         c\|- b e + 2c d \|e \|b e - c d
+--R      *
+--R         log
+--R                            2           2                2  +-+
+--R                      ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                   *
+--R                       +-------------------------+
+--R                       | 2 3           2     2 2
+--R                      \|b e  - 3b c d e  + 2c d e
+--R                  + 
+--R                       2 4           3     2 2 2  3
+--R                    (2b e  - 6b c d e  + 4c d e )x
+--R                  + 
+--R                       2   3          2 2     2 3
+--R                    (4b d e  - 12b c d e  + 8c d e)x
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                           3         2  4            2       2   2       2
+--R                    (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e
+--R                  + 
+--R                        3
+--R                    2c d
+--R               *
+--R                   +-------------------------+
+--R                   | 2 3           2     2 2
+--R                  \|b e  - 3b c d e  + 2c d e
+--R              + 
+--R                         2 4            3     2 2 2  3
+--R                    (- 4b e  + 12b c d e  - 8c d e )x
+--R                  + 
+--R                         2   3          2 2     2 3
+--R                    (- 4b d e  + 12b c d e  - 8c d e)x
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R                                            +--------+
+--R                       2                +-+ |   2           2 4
+--R                (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R              + 
+--R                      2          2                2
+--R                (- b e  - c d e)x  - 2b d e + 2c d
+--R     + 
+--R          +-------------------------+         +------------+ +-+
+--R          | 2 3           2     2 2         x\|- b e + 2c d \|e
+--R       2c\|b e  - 3b c d e  + 2c d e atan(-----------------------)
+--R                                                       +--------+
+--R                                           +---------+ |   2
+--R                                          \|b e - c d \|e x  + d
+--R  /
+--R                                                  +-------------------------+
+--R                   +------------+ +-+ +---------+ | 2 3           2     2 2
+--R     (2b e - 4c d)\|- b e + 2c d \|e \|b e - c d \|b e  - 3b c d e  + 2c d e
+--R                                                    Type: Expression(Integer)
+--E 2739
+
+--S 2740 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2740
+
+--S 2741 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +------------+ +-+ +---------+
+--R         c\|- b e + 2c d \|e \|b e - c d
+--R      *
+--R         atan
+--R                                                   +--------+
+--R                     2           2              2  |   2
+--R                ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R              + 
+--R                        2              2  +-+
+--R                (c d e x  + b d e - c d )\|d
+--R           /
+--R                   +---------------------------+
+--R                 3 |   2 3           2     2 2
+--R              e x \|- b e  + 3b c d e  - 2c d e
+--R     + 
+--R                                             +---------------------------+
+--R                                             |   2 3           2     2 2   +-+
+--R         +------------+ +-+ +---------+     \|- b e  + 3b c d e  - 2c d e \|d
+--R       c\|- b e + 2c d \|e \|b e - c d atan(----------------------------------)
+--R                                                         2
+--R                                                     (b e  - 2c d e)x
+--R     + 
+--R         +---------------------------+         +------------+ +-+
+--R         |   2 3           2     2 2         x\|- b e + 2c d \|e
+--R       c\|- b e  + 3b c d e  - 2c d e atan(-----------------------)
+--R                                                        +--------+
+--R                                            +---------+ |   2
+--R                                           \|b e - c d \|e x  + d
+--R  /
+--R                  +---------------------------+
+--R                  |   2 3           2     2 2   +------------+ +-+ +---------+
+--R     (b e - 2c d)\|- b e  + 3b c d e  - 2c d e \|- b e + 2c d \|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2741
+
+--S 2742 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2742
+
+)clear all
+
+--S 2743 of 3139
+t0:=1/((d+e*x^2)^(3/2)*(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4))
+--R 
+--R
+--R   (1)
+--R                                         1
+--R   ----------------------------------------------------------------------------
+--R                                                                     +--------+
+--R       3 6       3        2  4          2      2   2      2       3  |   2
+--R   (c e x  + (b e  + c d e )x  + (2b d e  - c d e)x  + b d e - c d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2743
+
+--S 2744 of 3139
+r0:=-1/3*x/(d*(2*c*d-b*e)*(d+e*x^2)^(3/2))+c^2*atan(x*sqrt(e)*_
+   sqrt(2*c*d-b*e)/(sqrt(-c*d+b*e)*sqrt(d+e*x^2)))/((2*c*d-b*e)^(5/2)*_
+   sqrt(e)*sqrt(-c*d+b*e))-1/3*(7*c*d-2*b*e)*x/(d^2*(2*c*d-b*e)^2*_
+   sqrt(d+e*x^2))
+--R 
+--R
+--R   (2)
+--R                           +--------+         +------------+ +-+
+--R          2 2   2     2 3  |   2            x\|- b e + 2c d \|e
+--R       (3c d e x  + 3c d )\|e x  + d atan(-----------------------)
+--R                                                       +--------+
+--R                                           +---------+ |   2
+--R                                          \|b e - c d \|e x  + d
+--R     + 
+--R             2           3                 2    +------------+ +-+ +---------+
+--R       ((2b e  - 7c d e)x  + (3b d e - 9c d )x)\|- b e + 2c d \|e \|b e - c d
+--R  /
+--R           2 2 3          3 2      2 4   2     2 3 2          4       2 5
+--R       ((3b d e  - 12b c d e  + 12c d e)x  + 3b d e  - 12b c d e + 12c d )
+--R    *
+--R                                       +--------+
+--R        +------------+ +-+ +---------+ |   2
+--R       \|- b e + 2c d \|e \|b e - c d \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2744
+
+--S 2745 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                   +--------+
+--R                2 2 2 4      2 3   2      2 4  +-+ |   2          2 2 3 6
+--R             (9c d e x  + 21c d e x  + 12c d )\|d \|e x  + d  - 3c d e x
+--R           + 
+--R                  2 3 2 4      2 4   2      2 5
+--R             - 18c d e x  - 27c d e x  - 12c d
+--R        *
+--R           log
+--R                              2           2                2  +-+
+--R                        ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                     *
+--R                         +-------------------------+
+--R                         | 2 3           2     2 2
+--R                        \|b e  - 3b c d e  + 2c d e
+--R                    + 
+--R                           2 4           3     2 2 2  3
+--R                      (- 2b e  + 6b c d e  - 4c d e )x
+--R                    + 
+--R                           2   3          2 2     2 3
+--R                      (- 4b d e  + 12b c d e  - 8c d e)x
+--R                 *
+--R                     +--------+
+--R                     |   2
+--R                    \|e x  + d
+--R                + 
+--R                             3         2  4            2       2   2       2
+--R                      (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e
+--R                    + 
+--R                          3
+--R                      2c d
+--R                 *
+--R                     +-------------------------+
+--R                     | 2 3           2     2 2
+--R                    \|b e  - 3b c d e  + 2c d e
+--R                + 
+--R                         2 4            3     2 2 2  3
+--R                      (4b e  - 12b c d e  + 8c d e )x
+--R                    + 
+--R                         2   3          2 2     2 3
+--R                      (4b d e  - 12b c d e  + 8c d e)x
+--R                 *
+--R                     +-+
+--R                    \|d
+--R             /
+--R                                              +--------+
+--R                         2                +-+ |   2           2 4
+--R                  (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R                + 
+--R                        2          2                2
+--R                  (- b e  - c d e)x  - 2b d e + 2c d
+--R       + 
+--R                    3          2  5             2        2   3
+--R             (- 4b e  + 14c d e )x  + (- 22b d e  + 74c d e)x
+--R           + 
+--R                     2         3
+--R             (- 24b d e + 72c d )x
+--R        *
+--R            +-------------------------+ +--------+
+--R            | 2 3           2     2 2   |   2
+--R           \|b e  - 3b c d e  + 2c d e \|e x  + d
+--R       + 
+--R                     3          2  5           2         2   3
+--R               (12b e  - 42c d e )x  + (34b d e  - 110c d e)x
+--R             + 
+--R                     2         3
+--R               (24b d e - 72c d )x
+--R        *
+--R                +-------------------------+
+--R            +-+ | 2 3           2     2 2
+--R           \|d \|b e  - 3b c d e  + 2c d e
+--R    /
+--R                 2 2 4          3 3      2 4 2  4
+--R             (18b d e  - 72b c d e  + 72c d e )x
+--R           + 
+--R               2 3 3           4 2       2 5   2      2 4 2          5       2 6
+--R           (42b d e  - 168b c d e  + 168c d e)x  + 24b d e  - 96b c d e + 96c d
+--R        *
+--R                +-------------------------+ +--------+
+--R            +-+ | 2 3           2     2 2   |   2
+--R           \|d \|b e  - 3b c d e  + 2c d e \|e x  + d
+--R       + 
+--R                  2 2 5          3 4      2 4 3  6
+--R             (- 6b d e  + 24b c d e  - 24c d e )x
+--R           + 
+--R                   2 3 4           4 3       2 5 2  4
+--R             (- 36b d e  + 144b c d e  - 144c d e )x
+--R           + 
+--R                   2 4 3           5 2       2 6   2      2 5 2          6
+--R             (- 54b d e  + 216b c d e  - 216c d e)x  - 24b d e  + 96b c d e
+--R           + 
+--R                  2 7
+--R             - 96c d
+--R        *
+--R            +-------------------------+
+--R            | 2 3           2     2 2
+--R           \|b e  - 3b c d e  + 2c d e
+--R     ,
+--R
+--R                                                     +--------+
+--R                  2 2 2 4      2 3   2      2 4  +-+ |   2          2 2 3 6
+--R             (- 9c d e x  - 21c d e x  - 12c d )\|d \|e x  + d  + 3c d e x
+--R           + 
+--R                2 3 2 4      2 4   2      2 5
+--R             18c d e x  + 27c d e x  + 12c d
+--R        *
+--R           atan
+--R                                                     +--------+
+--R                       2           2              2  |   2
+--R                  ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R                + 
+--R                          2              2  +-+
+--R                  (c d e x  + b d e - c d )\|d
+--R             /
+--R                     +---------------------------+
+--R                   3 |   2 3           2     2 2
+--R                e x \|- b e  + 3b c d e  - 2c d e
+--R       + 
+--R                                                     +--------+
+--R                  2 2 2 4      2 3   2      2 4  +-+ |   2          2 2 3 6
+--R             (- 9c d e x  - 21c d e x  - 12c d )\|d \|e x  + d  + 3c d e x
+--R           + 
+--R                2 3 2 4      2 4   2      2 5
+--R             18c d e x  + 27c d e x  + 12c d
+--R        *
+--R                 +---------------------------+
+--R                 |   2 3           2     2 2   +-+
+--R                \|- b e  + 3b c d e  - 2c d e \|d
+--R           atan(----------------------------------)
+--R                             2
+--R                         (b e  - 2c d e)x
+--R       + 
+--R                    3         2  5             2        2   3
+--R             (- 2b e  + 7c d e )x  + (- 11b d e  + 37c d e)x
+--R           + 
+--R                     2         3
+--R             (- 12b d e + 36c d )x
+--R        *
+--R            +---------------------------+ +--------+
+--R            |   2 3           2     2 2   |   2
+--R           \|- b e  + 3b c d e  - 2c d e \|e x  + d
+--R       + 
+--R                 3          2  5           2        2   3         2         3
+--R           ((6b e  - 21c d e )x  + (17b d e  - 55c d e)x  + (12b d e - 36c d )x)
+--R        *
+--R            +---------------------------+
+--R            |   2 3           2     2 2   +-+
+--R           \|- b e  + 3b c d e  - 2c d e \|d
+--R    /
+--R                2 2 4          3 3      2 4 2  4
+--R             (9b d e  - 36b c d e  + 36c d e )x
+--R           + 
+--R               2 3 3          4 2      2 5   2      2 4 2          5       2 6
+--R           (21b d e  - 84b c d e  + 84c d e)x  + 12b d e  - 48b c d e + 48c d
+--R        *
+--R            +---------------------------+     +--------+
+--R            |   2 3           2     2 2   +-+ |   2
+--R           \|- b e  + 3b c d e  - 2c d e \|d \|e x  + d
+--R       + 
+--R                  2 2 5          3 4      2 4 3  6
+--R             (- 3b d e  + 12b c d e  - 12c d e )x
+--R           + 
+--R                   2 3 4          4 3      2 5 2  4
+--R             (- 18b d e  + 72b c d e  - 72c d e )x
+--R           + 
+--R                   2 4 3           5 2       2 6   2      2 5 2          6
+--R             (- 27b d e  + 108b c d e  - 108c d e)x  - 12b d e  + 48b c d e
+--R           + 
+--R                  2 7
+--R             - 48c d
+--R        *
+--R            +---------------------------+
+--R            |   2 3           2     2 2
+--R           \|- b e  + 3b c d e  - 2c d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2745
+
+--S 2746 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          2 +------------+ +-+ +---------+
+--R         c \|- b e + 2c d \|e \|b e - c d
+--R      *
+--R         log
+--R                            2           2                2  +-+
+--R                      ((4b e  - 6c d e)x  + 2b d e - 2c d )\|d
+--R                   *
+--R                       +-------------------------+
+--R                       | 2 3           2     2 2
+--R                      \|b e  - 3b c d e  + 2c d e
+--R                  + 
+--R                         2 4           3     2 2 2  3
+--R                    (- 2b e  + 6b c d e  - 4c d e )x
+--R                  + 
+--R                         2   3          2 2     2 3
+--R                    (- 4b d e  + 12b c d e  - 8c d e)x
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                           3         2  4            2       2   2       2
+--R                    (- 2b e  + 3c d e )x  + (- 5b d e  + 7c d e)x  - 2b d e
+--R                  + 
+--R                        3
+--R                    2c d
+--R               *
+--R                   +-------------------------+
+--R                   | 2 3           2     2 2
+--R                  \|b e  - 3b c d e  + 2c d e
+--R              + 
+--R                       2 4            3     2 2 2  3
+--R                    (4b e  - 12b c d e  + 8c d e )x
+--R                  + 
+--R                       2   3          2 2     2 3
+--R                    (4b d e  - 12b c d e  + 8c d e)x
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R                                            +--------+
+--R                       2                +-+ |   2           2 4
+--R                (2c e x  + 2b e - 2c d)\|d \|e x  + d  - c e x
+--R              + 
+--R                      2          2                2
+--R                (- b e  - c d e)x  - 2b d e + 2c d
+--R     + 
+--R             +-------------------------+         +------------+ +-+
+--R           2 | 2 3           2     2 2         x\|- b e + 2c d \|e
+--R       - 2c \|b e  - 3b c d e  + 2c d e atan(-----------------------)
+--R                                                          +--------+
+--R                                              +---------+ |   2
+--R                                             \|b e - c d \|e x  + d
+--R  /
+--R          2 2                2 2  +------------+ +-+ +---------+
+--R       (2b e  - 8b c d e + 8c d )\|- b e + 2c d \|e \|b e - c d
+--R    *
+--R        +-------------------------+
+--R        | 2 3           2     2 2
+--R       \|b e  - 3b c d e  + 2c d e
+--R                                                    Type: Expression(Integer)
+--E 2746
+
+--S 2747 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2747
+
+--S 2748 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       -
+--R             2 +------------+ +-+ +---------+
+--R            c \|- b e + 2c d \|e \|b e - c d
+--R         *
+--R            atan
+--R                                                      +--------+
+--R                        2           2              2  |   2
+--R                   ((b e  - 2c d e)x  - b d e + c d )\|e x  + d
+--R                 + 
+--R                           2              2  +-+
+--R                   (c d e x  + b d e - c d )\|d
+--R              /
+--R                      +---------------------------+
+--R                    3 |   2 3           2     2 2
+--R                 e x \|- b e  + 3b c d e  - 2c d e
+--R     + 
+--R       -
+--R             2 +------------+ +-+ +---------+
+--R            c \|- b e + 2c d \|e \|b e - c d
+--R         *
+--R                  +---------------------------+
+--R                  |   2 3           2     2 2   +-+
+--R                 \|- b e  + 3b c d e  - 2c d e \|d
+--R            atan(----------------------------------)
+--R                              2
+--R                          (b e  - 2c d e)x
+--R     + 
+--R            +---------------------------+         +------------+ +-+
+--R          2 |   2 3           2     2 2         x\|- b e + 2c d \|e
+--R       - c \|- b e  + 3b c d e  - 2c d e atan(-----------------------)
+--R                                                           +--------+
+--R                                               +---------+ |   2
+--R                                              \|b e - c d \|e x  + d
+--R  /
+--R                                 +---------------------------+
+--R         2 2                2 2  |   2 3           2     2 2   +------------+
+--R       (b e  - 4b c d e + 4c d )\|- b e  + 3b c d e  - 2c d e \|- b e + 2c d
+--R    *
+--R        +-+ +---------+
+--R       \|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 2748
+
+--S 2749 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2749
+
+)clear all
+
+--S 2750 of 3139
+t0:=(d+e*x^2)^4*(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (1)
+--R        4 12       4         3  10       4         3       2 2  8
+--R     c e x   + (b e  + 4c d e )x   + (a e  + 4b d e  + 6c d e )x
+--R   + 
+--R            3       2 2       3   6        2 2       3       4  4
+--R     (4a d e  + 6b d e  + 4c d e)x  + (6a d e  + 4b d e + c d )x
+--R   + 
+--R          3       4  2      4
+--R     (4a d e + b d )x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 2750
+
+--S 2751 of 3139
+r0:=a*d^4*x+1/3*d^3*(b*d+4*a*e)*x^3+1/5*d^2*(c*d^2+4*b*d*e+6*a*e^2)*x^5+_
+   2/7*d*e*(2*c*d^2+e*(3*b*d+2*a*e))*x^7+1/9*e^2*(6*c*d^2+e*(4*b*d+a*e))*x^9+_
+   1/11*e^3*(4*c*d+b*e)*x^11+1/13*c*e^4*x^13
+--R 
+--R
+--R   (2)
+--R      1    4 13     1    4    4      3  11    1    4   4      3   2    2 2  9
+--R     -- c e x   + (-- b e  + -- c d e )x   + (- a e  + - b d e  + - c d e )x
+--R     13            11        11               9        9          3
+--R   + 
+--R      4      3   6    2 2   4    3   7    6    2 2   4    3    1    4  5
+--R     (- a d e  + - b d e  + - c d e)x  + (- a d e  + - b d e + - c d )x
+--R      7          7          7             5          5         5
+--R   + 
+--R      4    3    1    4  3      4
+--R     (- a d e + - b d )x  + a d x
+--R      3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2751
+
+--S 2752 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    4 13     1    4    4      3  11    1    4   4      3   2    2 2  9
+--R     -- c e x   + (-- b e  + -- c d e )x   + (- a e  + - b d e  + - c d e )x
+--R     13            11        11               9        9          3
+--R   + 
+--R      4      3   6    2 2   4    3   7    6    2 2   4    3    1    4  5
+--R     (- a d e  + - b d e  + - c d e)x  + (- a d e  + - b d e + - c d )x
+--R      7          7          7             5          5         5
+--R   + 
+--R      4    3    1    4  3      4
+--R     (- a d e + - b d )x  + a d x
+--R      3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2752
+
+--S 2753 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2753
+
+--S 2754 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2754
+
+)clear all
+
+--S 2755 of 3139
+t0:=(d+e*x^2)^3*(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (1)
+--R        3 10       3         2  8       3         2       2   6
+--R     c e x   + (b e  + 3c d e )x  + (a e  + 3b d e  + 3c d e)x
+--R   + 
+--R            2       2       3  4        2       3  2      3
+--R     (3a d e  + 3b d e + c d )x  + (3a d e + b d )x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 2755
+
+--S 2756 of 3139
+r0:=a*d^3*x+1/3*d^2*(b*d+3*a*e)*x^3+1/5*d*(c*d^2+3*e*(b*d+a*e))*x^5+_
+   1/7*e*(3*c*d^2+e*(3*b*d+a*e))*x^7+1/9*e^2*(3*c*d+b*e)*x^9+1/11*c*e^3*x^11
+--R 
+--R
+--R   (2)
+--R      1    3 11    1    3   1      2  9    1    3   3      2   3    2   7
+--R     -- c e x   + (- b e  + - c d e )x  + (- a e  + - b d e  + - c d e)x
+--R     11            9        3              7        7          7
+--R   + 
+--R      3      2   3    2    1    3  5       2    1    3  3      3
+--R     (- a d e  + - b d e + - c d )x  + (a d e + - b d )x  + a d x
+--R      5          5         5                    3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2756
+
+--S 2757 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    3 11    1    3   1      2  9    1    3   3      2   3    2   7
+--R     -- c e x   + (- b e  + - c d e )x  + (- a e  + - b d e  + - c d e)x
+--R     11            9        3              7        7          7
+--R   + 
+--R      3      2   3    2    1    3  5       2    1    3  3      3
+--R     (- a d e  + - b d e + - c d )x  + (a d e + - b d )x  + a d x
+--R      5          5         5                    3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2757
+
+--S 2758 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2758
+
+--S 2759 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2759
+
+)clear all
+
+--S 2760 of 3139
+t0:=(d+e*x^2)^2*(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (1)
+--R        2 8       2           6       2               2  4                2  2
+--R     c e x  + (b e  + 2c d e)x  + (a e  + 2b d e + c d )x  + (2a d e + b d )x
+--R   + 
+--R        2
+--R     a d
+--R                                                    Type: Polynomial(Integer)
+--E 2760
+
+--S 2761 of 3139
+r0:=a*d^2*x+1/3*d*(b*d+2*a*e)*x^3+1/5*(c*d^2+e*(2*b*d+a*e))*x^5+_
+   1/7*e*(2*c*d+b*e)*x^7+1/9*c*e^2*x^9
+--R 
+--R
+--R   (2)
+--R     1    2 9    1    2   2        7    1    2   2         1    2  5
+--R     - c e x  + (- b e  + - c d e)x  + (- a e  + - b d e + - c d )x
+--R     9           7        7             5        5         5
+--R   + 
+--R      2         1    2  3      2
+--R     (- a d e + - b d )x  + a d x
+--R      3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2761
+
+--S 2762 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    2 9    1    2   2        7    1    2   2         1    2  5
+--R     - c e x  + (- b e  + - c d e)x  + (- a e  + - b d e + - c d )x
+--R     9           7        7             5        5         5
+--R   + 
+--R      2         1    2  3      2
+--R     (- a d e + - b d )x  + a d x
+--R      3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2762
+
+--S 2763 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2763
+
+--S 2764 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2764
+
+)clear all
+
+--S 2765 of 3139
+t0:=(d+e*x^2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R             6               4               2
+--R   (1)  c e x  + (b e + c d)x  + (a e + b d)x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 2765
+
+--S 2766 of 3139
+r0:=a*d*x+1/3*(b*d+a*e)*x^3+1/5*(c*d+b*e)*x^5+1/7*c*e*x^7
+--R 
+--R
+--R        1      7    1       1      5    1       1      3
+--R   (2)  - c e x  + (- b e + - c d)x  + (- a e + - b d)x  + a d x
+--R        7           5       5           3       3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2766
+
+--S 2767 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1      7    1       1      5    1       1      3
+--R   (3)  - c e x  + (- b e + - c d)x  + (- a e + - b d)x  + a d x
+--R        7           5       5           3       3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2767
+
+--S 2768 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2768
+
+--S 2769 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2769
+
+)clear all
+
+--S 2770 of 3139
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R               2
+--R            e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2770
+
+--S 2771 of 3139
+r0:=-(c*d-b*e)*x/e^2+1/3*c*x^3/e+(c*d^2-b*d*e+a*e^2)*atan(x*sqrt(e)/_
+   sqrt(d))/(e^(5/2)*sqrt(d))
+--R 
+--R
+--R   (2)
+--R                                  +-+
+--R        2                2      x\|e           3                   +-+ +-+
+--R   (3a e  - 3b d e + 3c d )atan(-----) + (c e x  + (3b e - 3c d)x)\|d \|e
+--R                                  +-+
+--R                                 \|d
+--R   -----------------------------------------------------------------------
+--R                                   2 +-+ +-+
+--R                                 3e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2771
+
+--S 2772 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                         2      +-----+
+--R              2                2     (e x  - d)\|- d e  + 2d e x
+--R         (3a e  - 3b d e + 3c d )log(---------------------------)
+--R                                                  2
+--R                                               e x  + d
+--R       + 
+--R                3                   +-----+
+--R         (2c e x  + (6b e - 6c d)x)\|- d e
+--R    /
+--R         2 +-----+
+--R       6e \|- d e
+--R     ,
+--R                                   +---+
+--R         2                2      x\|d e           3                   +---+
+--R    (3a e  - 3b d e + 3c d )atan(-------) + (c e x  + (3b e - 3c d)x)\|d e
+--R                                    d
+--R    -----------------------------------------------------------------------]
+--R                                     2 +---+
+--R                                   3e \|d e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2772
+
+--S 2773 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                            2      +-----+
+--R           2              2  +-+ +-+    (e x  - d)\|- d e  + 2d e x
+--R       (a e  - b d e + c d )\|d \|e log(---------------------------)
+--R                                                     2
+--R                                                  e x  + d
+--R     + 
+--R                                                +-+
+--R              2                2  +-----+     x\|e
+--R       (- 2a e  + 2b d e - 2c d )\|- d e atan(-----)
+--R                                                +-+
+--R                                               \|d
+--R  /
+--R       2 +-----+ +-+ +-+
+--R     2e \|- d e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2773
+
+--S 2774 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2774
+
+--S 2775 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                           +---+
+--R           2              2  +-+ +-+     x\|d e
+--R       (a e  - b d e + c d )\|d \|e atan(-------)
+--R                                            d
+--R     + 
+--R                                           +-+
+--R             2              2  +---+     x\|e
+--R       (- a e  + b d e - c d )\|d e atan(-----)
+--R                                           +-+
+--R                                          \|d
+--R  /
+--R      2 +-+ +-+ +---+
+--R     e \|d \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 2775
+
+--S 2776 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2776
+
+)clear all
+
+--S 2777 of 3139
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^2
+--R 
+--R
+--R             4      2
+--R          c x  + b x  + a
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        e x  + 2d e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2777
+
+--S 2778 of 3139
+r0:=c*x/e^2+1/2*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2))-_
+   1/2*(3*c*d^2-e*(b*d+a*e))*atan(x*sqrt(e)/sqrt(d))/(d^(3/2)*e^(5/2))
+--R 
+--R
+--R   (2)
+--R                                                                   +-+
+--R            3        2       2   2        2      2        3      x\|e
+--R       ((a e  + b d e  - 3c d e)x  + a d e  + b d e - 3c d )atan(-----)
+--R                                                                   +-+
+--R                                                                  \|d
+--R     + 
+--R                3       2               2    +-+ +-+
+--R       (2c d e x  + (a e  - b d e + 3c d )x)\|d \|e
+--R  /
+--R          3 2     2 2  +-+ +-+
+--R     (2d e x  + 2d e )\|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2778
+
+--S 2779 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                3        2       2   2        2      2        3
+--R           ((a e  + b d e  - 3c d e)x  + a d e  + b d e - 3c d )
+--R        *
+--R                   2      +-----+
+--R               (e x  - d)\|- d e  + 2d e x
+--R           log(---------------------------)
+--R                            2
+--R                         e x  + d
+--R       + 
+--R                  3        2                2    +-----+
+--R         (4c d e x  + (2a e  - 2b d e + 6c d )x)\|- d e
+--R    /
+--R            3 2     2 2  +-----+
+--R       (4d e x  + 4d e )\|- d e
+--R     ,
+--R
+--R                                                                     +---+
+--R              3        2       2   2        2      2        3      x\|d e
+--R         ((a e  + b d e  - 3c d e)x  + a d e  + b d e - 3c d )atan(-------)
+--R                                                                      d
+--R       + 
+--R                  3       2               2    +---+
+--R         (2c d e x  + (a e  - b d e + 3c d )x)\|d e
+--R    /
+--R            3 2     2 2  +---+
+--R       (2d e x  + 2d e )\|d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2779
+
+--S 2780 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                             2      +-----+
+--R           2               2  +-+ +-+    (e x  - d)\|- d e  + 2d e x
+--R       (a e  + b d e - 3c d )\|d \|e log(---------------------------)
+--R                                                      2
+--R                                                   e x  + d
+--R     + 
+--R                                                +-+
+--R              2                2  +-----+     x\|e
+--R       (- 2a e  - 2b d e + 6c d )\|- d e atan(-----)
+--R                                                +-+
+--R                                               \|d
+--R  /
+--R         2 +-----+ +-+ +-+
+--R     4d e \|- d e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2780
+
+--S 2781 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2781
+
+--S 2782 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                            +---+
+--R           2               2  +-+ +-+     x\|d e
+--R       (a e  + b d e - 3c d )\|d \|e atan(-------)
+--R                                             d
+--R     + 
+--R                                            +-+
+--R             2               2  +---+     x\|e
+--R       (- a e  - b d e + 3c d )\|d e atan(-----)
+--R                                            +-+
+--R                                           \|d
+--R  /
+--R         2 +-+ +-+ +---+
+--R     2d e \|d \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 2782
+
+--S 2783 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2783
+
+)clear all
+
+--S 2784 of 3139
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^3
+--R 
+--R
+--R                  4      2
+--R               c x  + b x  + a
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        e x  + 3d e x  + 3d e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2784
+
+--S 2785 of 3139
+r0:=1/4*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^2)-1/8*(5*c*d^2-_
+   e*(b*d+3*a*e))*x/(d^2*e^2*(d+e*x^2))+1/8*(3*c*d^2+e*(b*d+3*a*e))*_
+   atan(x*sqrt(e)/sqrt(d))/(d^(5/2)*e^(5/2))
+--R 
+--R
+--R   (2)
+--R                4        3       2 2  4          3       2 2       3   2
+--R           (3a e  + b d e  + 3c d e )x  + (6a d e  + 2b d e  + 6c d e)x
+--R         + 
+--R               2 2      3        4
+--R           3a d e  + b d e + 3c d
+--R      *
+--R                +-+
+--R              x\|e
+--R         atan(-----)
+--R                +-+
+--R               \|d
+--R     + 
+--R             3        2       2   3          2      2        3    +-+ +-+
+--R       ((3a e  + b d e  - 5c d e)x  + (5a d e  - b d e - 3c d )x)\|d \|e
+--R  /
+--R        2 4 4      3 3 2     4 2  +-+ +-+
+--R     (8d e x  + 16d e x  + 8d e )\|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2785
+
+--S 2786 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  4        3       2 2  4          3       2 2       3   2
+--R             (3a e  + b d e  + 3c d e )x  + (6a d e  + 2b d e  + 6c d e)x
+--R           + 
+--R                 2 2      3        4
+--R             3a d e  + b d e + 3c d
+--R        *
+--R                   2      +-----+
+--R               (e x  - d)\|- d e  + 2d e x
+--R           log(---------------------------)
+--R                            2
+--R                         e x  + d
+--R       + 
+--R               3         2        2   3           2       2        3    +-----+
+--R         ((6a e  + 2b d e  - 10c d e)x  + (10a d e  - 2b d e - 6c d )x)\|- d e
+--R    /
+--R           2 4 4      3 3 2      4 2  +-----+
+--R       (16d e x  + 32d e x  + 16d e )\|- d e
+--R     ,
+--R
+--R                  4        3       2 2  4          3       2 2       3   2
+--R             (3a e  + b d e  + 3c d e )x  + (6a d e  + 2b d e  + 6c d e)x
+--R           + 
+--R                 2 2      3        4
+--R             3a d e  + b d e + 3c d
+--R        *
+--R                  +---+
+--R                x\|d e
+--R           atan(-------)
+--R                   d
+--R       + 
+--R               3        2       2   3          2      2        3    +---+
+--R         ((3a e  + b d e  - 5c d e)x  + (5a d e  - b d e - 3c d )x)\|d e
+--R    /
+--R          2 4 4      3 3 2     4 2  +---+
+--R       (8d e x  + 16d e x  + 8d e )\|d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2786
+
+--S 2787 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                              2      +-----+
+--R            2               2  +-+ +-+    (e x  - d)\|- d e  + 2d e x
+--R       (3a e  + b d e + 3c d )\|d \|e log(---------------------------)
+--R                                                       2
+--R                                                    e x  + d
+--R     + 
+--R                                                +-+
+--R              2                2  +-----+     x\|e
+--R       (- 6a e  - 2b d e - 6c d )\|- d e atan(-----)
+--R                                                +-+
+--R                                               \|d
+--R  /
+--R        2 2 +-----+ +-+ +-+
+--R     16d e \|- d e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2787
+
+--S 2788 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2788
+
+--S 2789 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                             +---+
+--R            2               2  +-+ +-+     x\|d e
+--R       (3a e  + b d e + 3c d )\|d \|e atan(-------)
+--R                                              d
+--R     + 
+--R                                             +-+
+--R              2               2  +---+     x\|e
+--R       (- 3a e  - b d e - 3c d )\|d e atan(-----)
+--R                                             +-+
+--R                                            \|d
+--R  /
+--R       2 2 +-+ +-+ +---+
+--R     8d e \|d \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 2789
+
+--S 2790 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2790
+
+)clear all
+
+--S 2791 of 3139
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^4
+--R 
+--R
+--R                       4      2
+--R                    c x  + b x  + a
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        e x  + 4d e x  + 6d e x  + 4d e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2791
+
+--S 2792 of 3139
+r0:=1/6*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^3)-1/24*(7*c*d^2-_
+   e*(b*d+5*a*e))*x/(d^2*e^2*(d+e*x^2)^2)+1/16*(c*d^2+e*(b*d+5*a*e))*_
+   x/(d^3*e^2*(d+e*x^2))+1/16*(c*d^2+e*(b*d+5*a*e))*atan(x*sqrt(e)/_
+   sqrt(d))/(d^(7/2)*e^(5/2))
+--R 
+--R
+--R   (2)
+--R                 5         4       2 3  6           4       2 3       3 2  4
+--R           (15a e  + 3b d e  + 3c d e )x  + (45a d e  + 9b d e  + 9c d e )x
+--R         + 
+--R                 2 3       3 2       4   2        3 2       4        5
+--R           (45a d e  + 9b d e  + 9c d e)x  + 15a d e  + 3b d e + 3c d
+--R      *
+--R                +-+
+--R              x\|e
+--R         atan(-----)
+--R                +-+
+--R               \|d
+--R     + 
+--R                 4         3       2 2  5           3       2 2       3   3
+--R           (15a e  + 3b d e  + 3c d e )x  + (40a d e  + 8b d e  - 8c d e)x
+--R         + 
+--R                 2 2       3        4
+--R           (33a d e  - 3b d e - 3c d )x
+--R      *
+--R          +-+ +-+
+--R         \|d \|e
+--R  /
+--R         3 5 6       4 4 4       5 3 2      6 2  +-+ +-+
+--R     (48d e x  + 144d e x  + 144d e x  + 48d e )\|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2792
+
+--S 2793 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   5         4       2 3  6           4       2 3       3 2  4
+--R             (15a e  + 3b d e  + 3c d e )x  + (45a d e  + 9b d e  + 9c d e )x
+--R           + 
+--R                   2 3       3 2       4   2        3 2       4        5
+--R             (45a d e  + 9b d e  + 9c d e)x  + 15a d e  + 3b d e + 3c d
+--R        *
+--R                   2      +-----+
+--R               (e x  - d)\|- d e  + 2d e x
+--R           log(---------------------------)
+--R                            2
+--R                         e x  + d
+--R       + 
+--R                   4         3       2 2  5           3        2 2        3   3
+--R             (30a e  + 6b d e  + 6c d e )x  + (80a d e  + 16b d e  - 16c d e)x
+--R           + 
+--R                   2 2       3        4
+--R             (66a d e  - 6b d e - 6c d )x
+--R        *
+--R            +-----+
+--R           \|- d e
+--R    /
+--R           3 5 6       4 4 4       5 3 2      6 2  +-----+
+--R       (96d e x  + 288d e x  + 288d e x  + 96d e )\|- d e
+--R     ,
+--R
+--R                   5         4       2 3  6           4       2 3       3 2  4
+--R             (15a e  + 3b d e  + 3c d e )x  + (45a d e  + 9b d e  + 9c d e )x
+--R           + 
+--R                   2 3       3 2       4   2        3 2       4        5
+--R             (45a d e  + 9b d e  + 9c d e)x  + 15a d e  + 3b d e + 3c d
+--R        *
+--R                  +---+
+--R                x\|d e
+--R           atan(-------)
+--R                   d
+--R       + 
+--R                   4         3       2 2  5           3       2 2       3   3
+--R             (15a e  + 3b d e  + 3c d e )x  + (40a d e  + 8b d e  - 8c d e)x
+--R           + 
+--R                   2 2       3        4
+--R             (33a d e  - 3b d e - 3c d )x
+--R        *
+--R            +---+
+--R           \|d e
+--R    /
+--R           3 5 6       4 4 4       5 3 2      6 2  +---+
+--R       (48d e x  + 144d e x  + 144d e x  + 48d e )\|d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2793
+
+--S 2794 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                             2      +-----+
+--R            2              2  +-+ +-+    (e x  - d)\|- d e  + 2d e x
+--R       (5a e  + b d e + c d )\|d \|e log(---------------------------)
+--R                                                      2
+--R                                                   e x  + d
+--R     + 
+--R                                                 +-+
+--R               2                2  +-----+     x\|e
+--R       (- 10a e  - 2b d e - 2c d )\|- d e atan(-----)
+--R                                                 +-+
+--R                                                \|d
+--R  /
+--R        3 2 +-----+ +-+ +-+
+--R     32d e \|- d e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2794
+
+--S 2795 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2795
+
+--S 2796 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                            +---+
+--R            2              2  +-+ +-+     x\|d e
+--R       (5a e  + b d e + c d )\|d \|e atan(-------)
+--R                                             d
+--R     + 
+--R                                            +-+
+--R              2              2  +---+     x\|e
+--R       (- 5a e  - b d e - c d )\|d e atan(-----)
+--R                                            +-+
+--R                                           \|d
+--R  /
+--R        3 2 +-+ +-+ +---+
+--R     16d e \|d \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 2796
+
+--S 2797 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2797
+
+)clear all
+
+--S 2798 of 3139
+t0:=(d+e*x^2)^4/(a+b*x^2+c*x^4)
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        e x  + 4d e x  + 6d e x  + 4d e x  + d
+--R   (1)  ---------------------------------------
+--R                       4      2
+--R                    c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2798
+
+--S 2799 of 3139
+r0:=e^2*(6*c^2*d^2+b^2*e^2-c*e*(4*b*d+a*e))*x/c^3+1/3*e^3*(4*c*d-b*e)*_
+   x^3/c^2+1/5*e^4*x^5/c+atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (e*(2*c*d-b*e)*(2*c^2*d^2+b^2*e^2-2*c*e*(b*d+a*e))+(2*c^4*d^4+b^4*e^4-_
+   4*b^2*c*e^3*(b*d+a*e)-4*c^3*d^2*e*(b*d+3*a*e)+2*c^2*e^2*(3*b^2*d^2+_
+   6*a*b*d*e+a^2*e^2))/sqrt(b^2-4*a*c))/(c^(7/2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (e*(2*c*d-b*e)*(2*c^2*d^2+b^2*e^2-2*c*e*(b*d+a*e))+(-2*c^4*d^4-_
+   b^4*e^4+4*b^2*c*e^3*(b*d+a*e)+4*c^3*d^2*e*(b*d+3*a*e)-2*c^2*e^2*_
+   (3*b^2*d^2+6*a*b*d*e+a^2*e^2))/sqrt(b^2-4*a*c))/(c^(7/2)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                               3  4           2      2     3        2 2 2
+--R                 (30a b c - 15b )e  + (- 60a c  + 60b c)d e  - 90b c d e
+--R               + 
+--R                    3 3
+--R                 60c d e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 2        2       4  4            2      3     3
+--R           (30a c  - 60a b c + 15b )e  + (180a b c  - 60b c)d e
+--R         + 
+--R                    3      2 2  2 2        3 3       4 4
+--R           (- 180a c  + 90b c )d e  - 60b c d e + 30c d
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                               3  4           2      2     3        2 2 2
+--R                 (30a b c - 15b )e  + (- 60a c  + 60b c)d e  - 90b c d e
+--R               + 
+--R                    3 3
+--R                 60c d e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 2        2       4  4              2      3     3
+--R           (- 30a c  + 60a b c - 15b )e  + (- 180a b c  + 60b c)d e
+--R         + 
+--R                  3      2 2  2 2        3 3       4 4
+--R           (180a c  - 90b c )d e  + 60b c d e - 30c d
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R             2 4 5            4      2   3  3
+--R           3c e x  + (- 5b c e  + 20c d e )x
+--R         + 
+--R                          2  4            3      2 2 2
+--R           ((- 15a c + 15b )e  - 60b c d e  + 90c d e )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R        3 +-+ |          2  +-+ |   |          2       | |          2
+--R     15c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2799
+
+--S 2800 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R               3
+--R            15c
+--R         *
+--R            ROOT
+--R                         2 8       2 7
+--R                     (16a c  - 4a b c )
+--R                  *
+--R                     ROOT
+--R                                   8 6      7 2 5      6 4 4      5 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     4 8 2      3 10     2 12
+--R                                - 37a b c  + 10a b  c - a b
+--R                           *
+--R                               16
+--R                              e
+--R                          + 
+--R                                     7   6       6 3 5       5 5 4       4 7 3
+--R                                - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                              + 
+--R                                      3 9 2      2 11
+--R                                - 144a b c  + 16a b  c
+--R                           *
+--R                                 15
+--R                              d e
+--R                          + 
+--R                                   7 7        6 2 6        5 4 5        4 6 4
+--R                                56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                              + 
+--R                                    3 8 3       2 10 2
+--R                                960a b c  - 120a b  c
+--R                           *
+--R                               2 14
+--R                              d e
+--R                          + 
+--R                                     6   7        5 3 6        4 5 5
+--R                                1568a b c  - 7280a b c  + 8960a b c
+--R                              + 
+--R                                       3 7 4       2 9 3
+--R                                - 3920a b c  + 560a b c
+--R                           *
+--R                               3 13
+--R                              d e
+--R                          + 
+--R                                      6 8         5 2 7         4 4 6
+--R                                - 924a c  + 11060a b c  - 20020a b c
+--R                              + 
+--R                                      3 6 5        2 8 4
+--R                                10920a b c  - 1820a b c
+--R                           *
+--R                               4 12
+--R                              d e
+--R                          + 
+--R                                       5   8         4 3 7         3 5 6
+--R                                - 9744a b c  + 30464a b c  - 21840a b c
+--R                              + 
+--R                                     2 7 5
+--R                                4368a b c
+--R                           *
+--R                               5 11
+--R                              d e
+--R                          + 
+--R                                       5 9         4 2 8         3 4 7
+--R                                  3976a c  - 31248a b c  + 32088a b c
+--R                                + 
+--R                                         2 6 6
+--R                                  - 8008a b c
+--R                           *
+--R                               6 10
+--R                              d e
+--R                          + 
+--R                                   4   9         3 3 8         2 5 7  7 9
+--R                            (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                          + 
+--R                                         4 10         3 2 9         2 4 8
+--R                                  - 6470a c   + 27060a b c  - 12750a b c
+--R                                + 
+--R                                      6 7
+--R                                  2a b c
+--R                           *
+--R                               8 8
+--R                              d e
+--R                          + 
+--R                                     3   10         2 3 9        5 8  9 7
+--R                            (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                          + 
+--R                                  3 11        2 2 10        4 9  10 6
+--R                            (3976a c   - 7224a b c   + 56a b c )d  e
+--R                          + 
+--R                                  2   11         3 10  11 5
+--R                            (3360a b c   - 112a b c  )d  e
+--R                          + 
+--R                                   2 12         2 11  12 4           12 13 3
+--R                            (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                          + 
+--R                                 13 14 2    14 16
+--R                            56a c  d  e  - c  d
+--R                       /
+--R                             3 15      2 2 14
+--R                          64a c   - 16a b c
+--R                 + 
+--R                        4   3      3 3 2     2 5       7  8
+--R                   (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                 + 
+--R                       4 4      3 2 3      2 4 2       6     7
+--R                   (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                 + 
+--R                        3   4       2 3 3        5 2  2 6
+--R                   (140a b c  - 140a b c  + 28a b c )d e
+--R                 + 
+--R                          3 5       2 2 4        4 3  3 5
+--R                   (- 112a c  + 224a b c  - 56a b c )d e
+--R                 + 
+--R                          2   5        3 4  4 4        2 6        2 5  5 3
+--R                   (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R                 + 
+--R                          6 6 2        7 7       7 8
+--R                   28a b c d e  - 16a c d e + b c d
+--R              /
+--R                   2 8       2 7
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                             4   9      3 3 8     2 5 7  4
+--R                         (48a b c  - 28a b c  + 4a b c )e
+--R                       + 
+--R                                4 10      3 2 9      2 4 8    3
+--R                         (- 128a c   + 96a b c  - 16a b c )d e
+--R                       + 
+--R                               3   10      2 3 9  2 2
+--R                         (- 96a b c   + 24a b c )d e
+--R                       + 
+--R                              3 11      2 2 10  3          2   11       3 10  4
+--R                         (128a c   - 32a b c  )d e + (- 16a b c   + 4a b c  )d
+--R                    *
+--R                       ROOT
+--R                                     8 6      7 2 5      6 4 4      5 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       4 8 2      3 10     2 12
+--R                                  - 37a b c  + 10a b  c - a b
+--R                             *
+--R                                 16
+--R                                e
+--R                            + 
+--R                                       7   6       6 3 5       5 5 4       4 7 3
+--R                                  - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                                + 
+--R                                        3 9 2      2 11
+--R                                  - 144a b c  + 16a b  c
+--R                             *
+--R                                   15
+--R                                d e
+--R                            + 
+--R                                     7 7        6 2 6        5 4 5        4 6 4
+--R                                  56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                                + 
+--R                                      3 8 3       2 10 2
+--R                                  960a b c  - 120a b  c
+--R                             *
+--R                                 2 14
+--R                                d e
+--R                            + 
+--R                                       6   7        5 3 6        4 5 5
+--R                                  1568a b c  - 7280a b c  + 8960a b c
+--R                                + 
+--R                                         3 7 4       2 9 3
+--R                                  - 3920a b c  + 560a b c
+--R                             *
+--R                                 3 13
+--R                                d e
+--R                            + 
+--R                                        6 8         5 2 7         4 4 6
+--R                                  - 924a c  + 11060a b c  - 20020a b c
+--R                                + 
+--R                                        3 6 5        2 8 4
+--R                                  10920a b c  - 1820a b c
+--R                             *
+--R                                 4 12
+--R                                d e
+--R                            + 
+--R                                         5   8         4 3 7         3 5 6
+--R                                  - 9744a b c  + 30464a b c  - 21840a b c
+--R                                + 
+--R                                       2 7 5
+--R                                  4368a b c
+--R                             *
+--R                                 5 11
+--R                                d e
+--R                            + 
+--R                                       5 9         4 2 8         3 4 7
+--R                                  3976a c  - 31248a b c  + 32088a b c
+--R                                + 
+--R                                         2 6 6
+--R                                  - 8008a b c
+--R                             *
+--R                                 6 10
+--R                                d e
+--R                            + 
+--R                                     4   9         3 3 8         2 5 7  7 9
+--R                              (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                            + 
+--R                                         4 10         3 2 9         2 4 8
+--R                                  - 6470a c   + 27060a b c  - 12750a b c
+--R                                + 
+--R                                      6 7
+--R                                  2a b c
+--R                             *
+--R                                 8 8
+--R                                d e
+--R                            + 
+--R                                       3   10         2 3 9        5 8  9 7
+--R                              (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                            + 
+--R                                    3 11        2 2 10        4 9  10 6
+--R                              (3976a c   - 7224a b c   + 56a b c )d  e
+--R                            + 
+--R                                    2   11         3 10  11 5
+--R                              (3360a b c   - 112a b c  )d  e
+--R                            + 
+--R                                     2 12         2 11  12 4           12 13 3
+--R                              (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                            + 
+--R                                   13 14 2    14 16
+--R                              56a c  d  e  - c  d
+--R                         /
+--R                               3 15      2 2 14
+--R                            64a c   - 16a b c
+--R                   + 
+--R                             7 5      6 2 4      5 4 3      4 6 2      3 8
+--R                         - 4a c  + 29a b c  - 51a b c  + 35a b c  - 10a b c
+--R                       + 
+--R                          2 10
+--R                         a b
+--R                    *
+--R                        12
+--R                       e
+--R                   + 
+--R                                 6   5       5 3 4       4 5 3       3 7 2
+--R                           - 112a b c  + 348a b c  - 320a b c  + 108a b c
+--R                         + 
+--R                                2 9
+--R                           - 12a b c
+--R                    *
+--R                          11
+--R                       d e
+--R                   + 
+--R                               6 6        5 2 5        4 4 4       3 6 3
+--R                           136a c  - 1010a b c  + 1324a b c  - 534a b c
+--R                         + 
+--R                              2 8 2
+--R                           66a b c
+--R                    *
+--R                        2 10
+--R                       d e
+--R                   + 
+--R                           5   6        4 3 5        3 5 4       2 7 3  3 9
+--R                     (1472a b c  - 3152a b c  + 1560a b c  - 216a b c )d e
+--R                   + 
+--R                                 5 7        4 2 6        3 4 5       2 6 4
+--R                           - 956a c  + 4631a b c  - 2966a b c  + 471a b c
+--R                         + 
+--R                                8 3
+--R                           - a b c
+--R                    *
+--R                        4 8
+--R                       d e
+--R                   + 
+--R                             4   7        3 3 6       2 5 5       7 4  5 7
+--R                     (- 4128a b c  + 3848a b c  - 736a b c  + 8a b c )d e
+--R                   + 
+--R                           4 8        3 2 7       2 4 6        6 5  6 6
+--R                     (1904a c  - 3500a b c  + 868a b c  - 28a b c )d e
+--R                   + 
+--R                           3   8       2 3 7        5 6  7 5
+--R                     (2240a b c  - 784a b c  + 56a b c )d e
+--R                   + 
+--R                            3 9       2 2 8        4 7  8 4
+--R                     (- 956a c  + 523a b c  - 71a b c )d e
+--R                   + 
+--R                            2   9        3 8  9 3        2 10        2 9  10 2
+--R                     (- 240a b c  + 60a b c )d e  + (136a c   - 34a b c )d  e
+--R                   + 
+--R                            11    2 10  12
+--R                     (- 4a c   + b c  )d
+--R                *
+--R                   ROOT
+--R                                2 8       2 7
+--R                            (16a c  - 4a b c )
+--R                         *
+--R                            ROOT
+--R                                          8 6      7 2 5      6 4 4      5 6 3
+--R                                       - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                     + 
+--R                                            4 8 2      3 10     2 12
+--R                                       - 37a b c  + 10a b  c - a b
+--R                                  *
+--R                                      16
+--R                                     e
+--R                                 + 
+--R                                            7   6       6 3 5       5 5 4
+--R                                       - 48a b c  + 352a b c  - 640a b c
+--R                                     + 
+--R                                           4 7 3       3 9 2      2 11
+--R                                       464a b c  - 144a b c  + 16a b  c
+--R                                  *
+--R                                        15
+--R                                     d e
+--R                                 + 
+--R                                          7 7        6 2 6        5 4 5
+--R                                       56a c  - 1080a b c  + 2880a b c
+--R                                     + 
+--R                                              4 6 4       3 8 3       2 10 2
+--R                                       - 2640a b c  + 960a b c  - 120a b  c
+--R                                  *
+--R                                      2 14
+--R                                     d e
+--R                                 + 
+--R                                            6   7        5 3 6        4 5 5
+--R                                       1568a b c  - 7280a b c  + 8960a b c
+--R                                     + 
+--R                                              3 7 4       2 9 3
+--R                                       - 3920a b c  + 560a b c
+--R                                  *
+--R                                      3 13
+--R                                     d e
+--R                                 + 
+--R                                             6 8         5 2 7         4 4 6
+--R                                       - 924a c  + 11060a b c  - 20020a b c
+--R                                     + 
+--R                                             3 6 5        2 8 4
+--R                                       10920a b c  - 1820a b c
+--R                                  *
+--R                                      4 12
+--R                                     d e
+--R                                 + 
+--R                                              5   8         4 3 7         3 5 6
+--R                                       - 9744a b c  + 30464a b c  - 21840a b c
+--R                                     + 
+--R                                            2 7 5
+--R                                       4368a b c
+--R                                  *
+--R                                      5 11
+--R                                     d e
+--R                                 + 
+--R                                            5 9         4 2 8         3 4 7
+--R                                       3976a c  - 31248a b c  + 32088a b c
+--R                                     + 
+--R                                              2 6 6
+--R                                       - 8008a b c
+--R                                  *
+--R                                      6 10
+--R                                     d e
+--R                                 + 
+--R                                          4   9         3 3 8         2 5 7  7 9
+--R                                   (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                                 + 
+--R                                              4 10         3 2 9         2 4 8
+--R                                       - 6470a c   + 27060a b c  - 12750a b c
+--R                                     + 
+--R                                           6 7
+--R                                       2a b c
+--R                                  *
+--R                                      8 8
+--R                                     d e
+--R                                 + 
+--R                                            3   10         2 3 9        5 8  9 7
+--R                                   (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                                 + 
+--R                                         3 11        2 2 10        4 9  10 6
+--R                                   (3976a c   - 7224a b c   + 56a b c )d  e
+--R                                 + 
+--R                                         2   11         3 10  11 5
+--R                                   (3360a b c   - 112a b c  )d  e
+--R                                 + 
+--R                                          2 12         2 11  12 4
+--R                                   (- 924a c   + 140a b c  )d  e
+--R                                 + 
+--R                                             12 13 3        13 14 2    14 16
+--R                                   - 112a b c  d  e  + 56a c  d  e  - c  d
+--R                              /
+--R                                    3 15      2 2 14
+--R                                 64a c   - 16a b c
+--R                        + 
+--R                               4   3      3 3 2     2 5       7  8
+--R                          (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                        + 
+--R                              4 4      3 2 3      2 4 2       6     7
+--R                          (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                        + 
+--R                               3   4       2 3 3        5 2  2 6
+--R                          (140a b c  - 140a b c  + 28a b c )d e
+--R                        + 
+--R                                 3 5       2 2 4        4 3  3 5
+--R                          (- 112a c  + 224a b c  - 56a b c )d e
+--R                        + 
+--R                                 2   5        3 4  4 4
+--R                          (- 210a b c  + 70a b c )d e
+--R                        + 
+--R                               2 6        2 5  5 3          6 6 2        7 7
+--R                          (112a c  - 56a b c )d e  + 28a b c d e  - 16a c d e
+--R                        + 
+--R                             7 8
+--R                          b c d
+--R                     /
+--R                          2 8       2 7
+--R                        8a c  - 2a b c
+--R               + 
+--R                        8 3      7 2 2      6 4      5 6  16
+--R                     (2a c  - 12a b c  + 10a b c - 2a b )e
+--R                   + 
+--R                         7   3      6 3 2      5 5      4 7    15
+--R                     (40a b c  - 16a b c  - 24a b c + 8a b )d e
+--R                   + 
+--R                           7 4      6 2 3       5 4 2      4 6       3 8  2 14
+--R                     (- 48a c  - 60a b c  + 168a b c  - 12a b c - 12a b )d e
+--R                   + 
+--R                          6   4       5 3 3       4 5 2      3 7      2 9  3 13
+--R                     (168a b c  - 392a b c  - 168a b c  + 80a b c + 8a b )d e
+--R                   + 
+--R                              6 5       5 2 4       4 4 3       3 6 2      2 8
+--R                         - 72a c  + 468a b c  + 830a b c  - 176a b c  - 78a b c
+--R                       + 
+--R                               10
+--R                         - 2a b
+--R                    *
+--R                        4 12
+--R                       d e
+--R                   + 
+--R                                 5   5        4 3 4      3 5 3       2 7 2
+--R                           - 408a b c  - 1800a b c  - 24a b c  + 336a b c
+--R                         + 
+--R                                9
+--R                           24a b c
+--R                    *
+--R                        5 11
+--R                       d e
+--R                   + 
+--R                               5 6        4 2 5       3 4 4       2 6 3
+--R                           176a c  + 2244a b c  + 880a b c  - 836a b c
+--R                         + 
+--R                                   8 2
+--R                           - 132a b c
+--R                    *
+--R                        6 10
+--R                       d e
+--R                   + 
+--R                             4   6        3 3 5        2 5 4         7 3  7 9
+--R                     (- 1496a b c  - 1936a b c  + 1320a b c  + 440a b c )d e
+--R                   + 
+--R                          4 7        3 2 6        2 4 5         6 4  8 8
+--R                     (396a c  + 1980a b c  - 1386a b c  - 990a b c )d e
+--R                   + 
+--R                            3   7        2 3 6          5 5  9 7
+--R                     (- 968a b c  + 1056a b c  + 1584a b c )d e
+--R                   + 
+--R                          3 8       2 2 7          4 6  10 6
+--R                     (176a c  - 660a b c  - 1848a b c )d  e
+--R                   + 
+--R                          2   8          3 7  11 5
+--R                     (312a b c  + 1560a b c )d  e
+--R                   + 
+--R                           2 9         2 8     4 7  12 4
+--R                     (- 72a c  - 900a b c  + 2b c )d  e
+--R                   + 
+--R                              9     3 8  13 3           10      2 9  14 2
+--R                     (312a b c  - 8b c )d  e  + (- 48a c   + 12b c )d  e
+--R                   + 
+--R                           10 15      11 16
+--R                     - 8b c  d  e + 2c  d
+--R                *
+--R                   x
+--R     + 
+--R            3
+--R         15c
+--R      *
+--R         ROOT
+--R                        2 8       2 7
+--R                  (- 16a c  + 4a b c )
+--R               *
+--R                  ROOT
+--R                                8 6      7 2 5      6 4 4      5 6 3      4 8 2
+--R                             - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                           + 
+--R                                3 10     2 12
+--R                             10a b  c - a b
+--R                        *
+--R                            16
+--R                           e
+--R                       + 
+--R                                  7   6       6 3 5       5 5 4       4 7 3
+--R                             - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                           + 
+--R                                   3 9 2      2 11
+--R                             - 144a b c  + 16a b  c
+--R                        *
+--R                              15
+--R                           d e
+--R                       + 
+--R                                7 7        6 2 6        5 4 5        4 6 4
+--R                             56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                           + 
+--R                                 3 8 3       2 10 2
+--R                             960a b c  - 120a b  c
+--R                        *
+--R                            2 14
+--R                           d e
+--R                       + 
+--R                                  6   7        5 3 6        4 5 5        3 7 4
+--R                             1568a b c  - 7280a b c  + 8960a b c  - 3920a b c
+--R                           + 
+--R                                 2 9 3
+--R                             560a b c
+--R                        *
+--R                            3 13
+--R                           d e
+--R                       + 
+--R                                   6 8         5 2 7         4 4 6         3 6 5
+--R                             - 924a c  + 11060a b c  - 20020a b c  + 10920a b c
+--R                           + 
+--R                                    2 8 4
+--R                             - 1820a b c
+--R                        *
+--R                            4 12
+--R                           d e
+--R                       + 
+--R                                      5   8         4 3 7         3 5 6
+--R                               - 9744a b c  + 30464a b c  - 21840a b c
+--R                             + 
+--R                                    2 7 5
+--R                               4368a b c
+--R                        *
+--R                            5 11
+--R                           d e
+--R                       + 
+--R                                 5 9         4 2 8         3 4 7        2 6 6  6
+--R                           (3976a c  - 31248a b c  + 32088a b c  - 8008a b c )d
+--R                        *
+--R                            10
+--R                           e
+--R                       + 
+--R                                4   9         3 3 8         2 5 7  7 9
+--R                         (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                       + 
+--R                                 4 10         3 2 9         2 4 8       6 7  8 8
+--R                         (- 6470a c   + 27060a b c  - 12750a b c  + 2a b c )d e
+--R                       + 
+--R                                  3   10         2 3 9        5 8  9 7
+--R                         (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                       + 
+--R                               3 11        2 2 10        4 9  10 6
+--R                         (3976a c   - 7224a b c   + 56a b c )d  e
+--R                       + 
+--R                               2   11         3 10  11 5
+--R                         (3360a b c   - 112a b c  )d  e
+--R                       + 
+--R                                2 12         2 11  12 4           12 13 3
+--R                         (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                       + 
+--R                              13 14 2    14 16
+--R                         56a c  d  e  - c  d
+--R                    /
+--R                          3 15      2 2 14
+--R                       64a c   - 16a b c
+--R              + 
+--R                     4   3      3 3 2     2 5       7  8
+--R                (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R              + 
+--R                    4 4      3 2 3      2 4 2       6     7
+--R                (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R              + 
+--R                     3   4       2 3 3        5 2  2 6
+--R                (140a b c  - 140a b c  + 28a b c )d e
+--R              + 
+--R                       3 5       2 2 4        4 3  3 5
+--R                (- 112a c  + 224a b c  - 56a b c )d e
+--R              + 
+--R                       2   5        3 4  4 4        2 6        2 5  5 3
+--R                (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R              + 
+--R                       6 6 2        7 7       7 8
+--R                28a b c d e  - 16a c d e + b c d
+--R           /
+--R                2 8       2 7
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                          4   9      3 3 8     2 5 7  4
+--R                      (48a b c  - 28a b c  + 4a b c )e
+--R                    + 
+--R                             4 10      3 2 9      2 4 8    3
+--R                      (- 128a c   + 96a b c  - 16a b c )d e
+--R                    + 
+--R                            3   10      2 3 9  2 2        3 11      2 2 10  3
+--R                      (- 96a b c   + 24a b c )d e  + (128a c   - 32a b c  )d e
+--R                    + 
+--R                            2   11       3 10  4
+--R                      (- 16a b c   + 4a b c  )d
+--R                 *
+--R                    ROOT
+--R                                  8 6      7 2 5      6 4 4      5 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    4 8 2      3 10     2 12
+--R                               - 37a b c  + 10a b  c - a b
+--R                          *
+--R                              16
+--R                             e
+--R                         + 
+--R                                    7   6       6 3 5       5 5 4       4 7 3
+--R                               - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                             + 
+--R                                     3 9 2      2 11
+--R                               - 144a b c  + 16a b  c
+--R                          *
+--R                                15
+--R                             d e
+--R                         + 
+--R                                  7 7        6 2 6        5 4 5        4 6 4
+--R                               56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                             + 
+--R                                   3 8 3       2 10 2
+--R                               960a b c  - 120a b  c
+--R                          *
+--R                              2 14
+--R                             d e
+--R                         + 
+--R                                    6   7        5 3 6        4 5 5        3 7 4
+--R                               1568a b c  - 7280a b c  + 8960a b c  - 3920a b c
+--R                             + 
+--R                                   2 9 3
+--R                               560a b c
+--R                          *
+--R                              3 13
+--R                             d e
+--R                         + 
+--R                                     6 8         5 2 7         4 4 6
+--R                               - 924a c  + 11060a b c  - 20020a b c
+--R                             + 
+--R                                     3 6 5        2 8 4
+--R                               10920a b c  - 1820a b c
+--R                          *
+--R                              4 12
+--R                             d e
+--R                         + 
+--R                                      5   8         4 3 7         3 5 6
+--R                               - 9744a b c  + 30464a b c  - 21840a b c
+--R                             + 
+--R                                    2 7 5
+--R                               4368a b c
+--R                          *
+--R                              5 11
+--R                             d e
+--R                         + 
+--R                                   5 9         4 2 8         3 4 7        2 6 6
+--R                             (3976a c  - 31248a b c  + 32088a b c  - 8008a b c )
+--R                          *
+--R                              6 10
+--R                             d e
+--R                         + 
+--R                                  4   9         3 3 8         2 5 7  7 9
+--R                           (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                         + 
+--R                                     4 10         3 2 9         2 4 8       6 7
+--R                             (- 6470a c   + 27060a b c  - 12750a b c  + 2a b c )
+--R                          *
+--R                              8 8
+--R                             d e
+--R                         + 
+--R                                    3   10         2 3 9        5 8  9 7
+--R                           (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                         + 
+--R                                 3 11        2 2 10        4 9  10 6
+--R                           (3976a c   - 7224a b c   + 56a b c )d  e
+--R                         + 
+--R                                 2   11         3 10  11 5
+--R                           (3360a b c   - 112a b c  )d  e
+--R                         + 
+--R                                  2 12         2 11  12 4           12 13 3
+--R                           (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                         + 
+--R                                13 14 2    14 16
+--R                           56a c  d  e  - c  d
+--R                      /
+--R                            3 15      2 2 14
+--R                         64a c   - 16a b c
+--R                + 
+--R                     7 5      6 2 4      5 4 3      4 6 2      3 8     2 10  12
+--R                  (4a c  - 29a b c  + 51a b c  - 35a b c  + 10a b c - a b  )e
+--R                + 
+--R                       6   5       5 3 4       4 5 3       3 7 2      2 9     11
+--R                  (112a b c  - 348a b c  + 320a b c  - 108a b c  + 12a b c)d e
+--R                + 
+--R                           6 6        5 2 5        4 4 4       3 6 3      2 8 2
+--R                    (- 136a c  + 1010a b c  - 1324a b c  + 534a b c  - 66a b c )
+--R                 *
+--R                     2 10
+--R                    d e
+--R                + 
+--R                          5   6        4 3 5        3 5 4       2 7 3  3 9
+--R                  (- 1472a b c  + 3152a b c  - 1560a b c  + 216a b c )d e
+--R                + 
+--R                       5 7        4 2 6        3 4 5       2 6 4      8 3  4 8
+--R                  (956a c  - 4631a b c  + 2966a b c  - 471a b c  + a b c )d e
+--R                + 
+--R                        4   7        3 3 6       2 5 5       7 4  5 7
+--R                  (4128a b c  - 3848a b c  + 736a b c  - 8a b c )d e
+--R                + 
+--R                          4 8        3 2 7       2 4 6        6 5  6 6
+--R                  (- 1904a c  + 3500a b c  - 868a b c  + 28a b c )d e
+--R                + 
+--R                          3   8       2 3 7        5 6  7 5
+--R                  (- 2240a b c  + 784a b c  - 56a b c )d e
+--R                + 
+--R                       3 9       2 2 8        4 7  8 4
+--R                  (956a c  - 523a b c  + 71a b c )d e
+--R                + 
+--R                       2   9        3 8  9 3          2 10        2 9  10 2
+--R                  (240a b c  - 60a b c )d e  + (- 136a c   + 34a b c )d  e
+--R                + 
+--R                       11    2 10  12
+--R                  (4a c   - b c  )d
+--R             *
+--R                ROOT
+--R                               2 8       2 7
+--R                         (- 16a c  + 4a b c )
+--R                      *
+--R                         ROOT
+--R                                       8 6      7 2 5      6 4 4      5 6 3
+--R                                    - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                  + 
+--R                                         4 8 2      3 10     2 12
+--R                                    - 37a b c  + 10a b  c - a b
+--R                               *
+--R                                   16
+--R                                  e
+--R                              + 
+--R                                         7   6       6 3 5       5 5 4
+--R                                    - 48a b c  + 352a b c  - 640a b c
+--R                                  + 
+--R                                        4 7 3       3 9 2      2 11
+--R                                    464a b c  - 144a b c  + 16a b  c
+--R                               *
+--R                                     15
+--R                                  d e
+--R                              + 
+--R                                       7 7        6 2 6        5 4 5
+--R                                    56a c  - 1080a b c  + 2880a b c
+--R                                  + 
+--R                                           4 6 4       3 8 3       2 10 2
+--R                                    - 2640a b c  + 960a b c  - 120a b  c
+--R                               *
+--R                                   2 14
+--R                                  d e
+--R                              + 
+--R                                         6   7        5 3 6        4 5 5
+--R                                    1568a b c  - 7280a b c  + 8960a b c
+--R                                  + 
+--R                                           3 7 4       2 9 3
+--R                                    - 3920a b c  + 560a b c
+--R                               *
+--R                                   3 13
+--R                                  d e
+--R                              + 
+--R                                          6 8         5 2 7         4 4 6
+--R                                    - 924a c  + 11060a b c  - 20020a b c
+--R                                  + 
+--R                                          3 6 5        2 8 4
+--R                                    10920a b c  - 1820a b c
+--R                               *
+--R                                   4 12
+--R                                  d e
+--R                              + 
+--R                                           5   8         4 3 7         3 5 6
+--R                                    - 9744a b c  + 30464a b c  - 21840a b c
+--R                                  + 
+--R                                         2 7 5
+--R                                    4368a b c
+--R                               *
+--R                                   5 11
+--R                                  d e
+--R                              + 
+--R                                         5 9         4 2 8         3 4 7
+--R                                    3976a c  - 31248a b c  + 32088a b c
+--R                                  + 
+--R                                           2 6 6
+--R                                    - 8008a b c
+--R                               *
+--R                                   6 10
+--R                                  d e
+--R                              + 
+--R                                       4   9         3 3 8         2 5 7  7 9
+--R                                (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                              + 
+--R                                           4 10         3 2 9         2 4 8
+--R                                    - 6470a c   + 27060a b c  - 12750a b c
+--R                                  + 
+--R                                        6 7
+--R                                    2a b c
+--R                               *
+--R                                   8 8
+--R                                  d e
+--R                              + 
+--R                                         3   10         2 3 9        5 8  9 7
+--R                                (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                              + 
+--R                                      3 11        2 2 10        4 9  10 6
+--R                                (3976a c   - 7224a b c   + 56a b c )d  e
+--R                              + 
+--R                                      2   11         3 10  11 5
+--R                                (3360a b c   - 112a b c  )d  e
+--R                              + 
+--R                                       2 12         2 11  12 4           12 13 3
+--R                                (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                              + 
+--R                                     13 14 2    14 16
+--R                                56a c  d  e  - c  d
+--R                           /
+--R                                 3 15      2 2 14
+--R                              64a c   - 16a b c
+--R                     + 
+--R                            4   3      3 3 2     2 5       7  8
+--R                       (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                     + 
+--R                           4 4      3 2 3      2 4 2       6     7
+--R                       (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                     + 
+--R                            3   4       2 3 3        5 2  2 6
+--R                       (140a b c  - 140a b c  + 28a b c )d e
+--R                     + 
+--R                              3 5       2 2 4        4 3  3 5
+--R                       (- 112a c  + 224a b c  - 56a b c )d e
+--R                     + 
+--R                              2   5        3 4  4 4        2 6        2 5  5 3
+--R                       (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R                     + 
+--R                              6 6 2        7 7       7 8
+--R                       28a b c d e  - 16a c d e + b c d
+--R                  /
+--R                       2 8       2 7
+--R                     8a c  - 2a b c
+--R            + 
+--R                     8 3      7 2 2      6 4      5 6  16
+--R                  (2a c  - 12a b c  + 10a b c - 2a b )e
+--R                + 
+--R                      7   3      6 3 2      5 5      4 7    15
+--R                  (40a b c  - 16a b c  - 24a b c + 8a b )d e
+--R                + 
+--R                        7 4      6 2 3       5 4 2      4 6       3 8  2 14
+--R                  (- 48a c  - 60a b c  + 168a b c  - 12a b c - 12a b )d e
+--R                + 
+--R                       6   4       5 3 3       4 5 2      3 7      2 9  3 13
+--R                  (168a b c  - 392a b c  - 168a b c  + 80a b c + 8a b )d e
+--R                + 
+--R                           6 5       5 2 4       4 4 3       3 6 2      2 8
+--R                      - 72a c  + 468a b c  + 830a b c  - 176a b c  - 78a b c
+--R                    + 
+--R                            10
+--R                      - 2a b
+--R                 *
+--R                     4 12
+--R                    d e
+--R                + 
+--R                           5   5        4 3 4      3 5 3       2 7 2        9
+--R                    (- 408a b c  - 1800a b c  - 24a b c  + 336a b c  + 24a b c)
+--R                 *
+--R                     5 11
+--R                    d e
+--R                + 
+--R                         5 6        4 2 5       3 4 4       2 6 3         8 2  6
+--R                    (176a c  + 2244a b c  + 880a b c  - 836a b c  - 132a b c )d
+--R                 *
+--R                     10
+--R                    e
+--R                + 
+--R                          4   6        3 3 5        2 5 4         7 3  7 9
+--R                  (- 1496a b c  - 1936a b c  + 1320a b c  + 440a b c )d e
+--R                + 
+--R                       4 7        3 2 6        2 4 5         6 4  8 8
+--R                  (396a c  + 1980a b c  - 1386a b c  - 990a b c )d e
+--R                + 
+--R                         3   7        2 3 6          5 5  9 7
+--R                  (- 968a b c  + 1056a b c  + 1584a b c )d e
+--R                + 
+--R                       3 8       2 2 7          4 6  10 6
+--R                  (176a c  - 660a b c  - 1848a b c )d  e
+--R                + 
+--R                       2   8          3 7  11 5
+--R                  (312a b c  + 1560a b c )d  e
+--R                + 
+--R                        2 9         2 8     4 7  12 4            9     3 8  13 3
+--R                  (- 72a c  - 900a b c  + 2b c )d  e  + (312a b c  - 8b c )d  e
+--R                + 
+--R                          10      2 9  14 2       10 15      11 16
+--R                  (- 48a c   + 12b c )d  e  - 8b c  d  e + 2c  d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R               3
+--R            15c
+--R         *
+--R            ROOT
+--R                           2 8       2 7
+--R                     (- 16a c  + 4a b c )
+--R                  *
+--R                     ROOT
+--R                                   8 6      7 2 5      6 4 4      5 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     4 8 2      3 10     2 12
+--R                                - 37a b c  + 10a b  c - a b
+--R                           *
+--R                               16
+--R                              e
+--R                          + 
+--R                                     7   6       6 3 5       5 5 4       4 7 3
+--R                                - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                              + 
+--R                                      3 9 2      2 11
+--R                                - 144a b c  + 16a b  c
+--R                           *
+--R                                 15
+--R                              d e
+--R                          + 
+--R                                   7 7        6 2 6        5 4 5        4 6 4
+--R                                56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                              + 
+--R                                    3 8 3       2 10 2
+--R                                960a b c  - 120a b  c
+--R                           *
+--R                               2 14
+--R                              d e
+--R                          + 
+--R                                     6   7        5 3 6        4 5 5
+--R                                1568a b c  - 7280a b c  + 8960a b c
+--R                              + 
+--R                                       3 7 4       2 9 3
+--R                                - 3920a b c  + 560a b c
+--R                           *
+--R                               3 13
+--R                              d e
+--R                          + 
+--R                                      6 8         5 2 7         4 4 6
+--R                                - 924a c  + 11060a b c  - 20020a b c
+--R                              + 
+--R                                      3 6 5        2 8 4
+--R                                10920a b c  - 1820a b c
+--R                           *
+--R                               4 12
+--R                              d e
+--R                          + 
+--R                                       5   8         4 3 7         3 5 6
+--R                                - 9744a b c  + 30464a b c  - 21840a b c
+--R                              + 
+--R                                     2 7 5
+--R                                4368a b c
+--R                           *
+--R                               5 11
+--R                              d e
+--R                          + 
+--R                                       5 9         4 2 8         3 4 7
+--R                                  3976a c  - 31248a b c  + 32088a b c
+--R                                + 
+--R                                         2 6 6
+--R                                  - 8008a b c
+--R                           *
+--R                               6 10
+--R                              d e
+--R                          + 
+--R                                   4   9         3 3 8         2 5 7  7 9
+--R                            (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                          + 
+--R                                         4 10         3 2 9         2 4 8
+--R                                  - 6470a c   + 27060a b c  - 12750a b c
+--R                                + 
+--R                                      6 7
+--R                                  2a b c
+--R                           *
+--R                               8 8
+--R                              d e
+--R                          + 
+--R                                     3   10         2 3 9        5 8  9 7
+--R                            (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                          + 
+--R                                  3 11        2 2 10        4 9  10 6
+--R                            (3976a c   - 7224a b c   + 56a b c )d  e
+--R                          + 
+--R                                  2   11         3 10  11 5
+--R                            (3360a b c   - 112a b c  )d  e
+--R                          + 
+--R                                   2 12         2 11  12 4           12 13 3
+--R                            (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                          + 
+--R                                 13 14 2    14 16
+--R                            56a c  d  e  - c  d
+--R                       /
+--R                             3 15      2 2 14
+--R                          64a c   - 16a b c
+--R                 + 
+--R                        4   3      3 3 2     2 5       7  8
+--R                   (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                 + 
+--R                       4 4      3 2 3      2 4 2       6     7
+--R                   (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                 + 
+--R                        3   4       2 3 3        5 2  2 6
+--R                   (140a b c  - 140a b c  + 28a b c )d e
+--R                 + 
+--R                          3 5       2 2 4        4 3  3 5
+--R                   (- 112a c  + 224a b c  - 56a b c )d e
+--R                 + 
+--R                          2   5        3 4  4 4        2 6        2 5  5 3
+--R                   (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R                 + 
+--R                          6 6 2        7 7       7 8
+--R                   28a b c d e  - 16a c d e + b c d
+--R              /
+--R                   2 8       2 7
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                               4   9      3 3 8     2 5 7  4
+--R                         (- 48a b c  + 28a b c  - 4a b c )e
+--R                       + 
+--R                              4 10      3 2 9      2 4 8    3
+--R                         (128a c   - 96a b c  + 16a b c )d e
+--R                       + 
+--R                             3   10      2 3 9  2 2
+--R                         (96a b c   - 24a b c )d e
+--R                       + 
+--R                                3 11      2 2 10  3        2   11       3 10  4
+--R                         (- 128a c   + 32a b c  )d e + (16a b c   - 4a b c  )d
+--R                    *
+--R                       ROOT
+--R                                     8 6      7 2 5      6 4 4      5 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       4 8 2      3 10     2 12
+--R                                  - 37a b c  + 10a b  c - a b
+--R                             *
+--R                                 16
+--R                                e
+--R                            + 
+--R                                       7   6       6 3 5       5 5 4       4 7 3
+--R                                  - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                                + 
+--R                                        3 9 2      2 11
+--R                                  - 144a b c  + 16a b  c
+--R                             *
+--R                                   15
+--R                                d e
+--R                            + 
+--R                                     7 7        6 2 6        5 4 5        4 6 4
+--R                                  56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                                + 
+--R                                      3 8 3       2 10 2
+--R                                  960a b c  - 120a b  c
+--R                             *
+--R                                 2 14
+--R                                d e
+--R                            + 
+--R                                       6   7        5 3 6        4 5 5
+--R                                  1568a b c  - 7280a b c  + 8960a b c
+--R                                + 
+--R                                         3 7 4       2 9 3
+--R                                  - 3920a b c  + 560a b c
+--R                             *
+--R                                 3 13
+--R                                d e
+--R                            + 
+--R                                        6 8         5 2 7         4 4 6
+--R                                  - 924a c  + 11060a b c  - 20020a b c
+--R                                + 
+--R                                        3 6 5        2 8 4
+--R                                  10920a b c  - 1820a b c
+--R                             *
+--R                                 4 12
+--R                                d e
+--R                            + 
+--R                                         5   8         4 3 7         3 5 6
+--R                                  - 9744a b c  + 30464a b c  - 21840a b c
+--R                                + 
+--R                                       2 7 5
+--R                                  4368a b c
+--R                             *
+--R                                 5 11
+--R                                d e
+--R                            + 
+--R                                       5 9         4 2 8         3 4 7
+--R                                  3976a c  - 31248a b c  + 32088a b c
+--R                                + 
+--R                                         2 6 6
+--R                                  - 8008a b c
+--R                             *
+--R                                 6 10
+--R                                d e
+--R                            + 
+--R                                     4   9         3 3 8         2 5 7  7 9
+--R                              (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                            + 
+--R                                         4 10         3 2 9         2 4 8
+--R                                  - 6470a c   + 27060a b c  - 12750a b c
+--R                                + 
+--R                                      6 7
+--R                                  2a b c
+--R                             *
+--R                                 8 8
+--R                                d e
+--R                            + 
+--R                                       3   10         2 3 9        5 8  9 7
+--R                              (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                            + 
+--R                                    3 11        2 2 10        4 9  10 6
+--R                              (3976a c   - 7224a b c   + 56a b c )d  e
+--R                            + 
+--R                                    2   11         3 10  11 5
+--R                              (3360a b c   - 112a b c  )d  e
+--R                            + 
+--R                                     2 12         2 11  12 4           12 13 3
+--R                              (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                            + 
+--R                                   13 14 2    14 16
+--R                              56a c  d  e  - c  d
+--R                         /
+--R                               3 15      2 2 14
+--R                            64a c   - 16a b c
+--R                   + 
+--R                             7 5      6 2 4      5 4 3      4 6 2      3 8
+--R                         - 4a c  + 29a b c  - 51a b c  + 35a b c  - 10a b c
+--R                       + 
+--R                          2 10
+--R                         a b
+--R                    *
+--R                        12
+--R                       e
+--R                   + 
+--R                                 6   5       5 3 4       4 5 3       3 7 2
+--R                           - 112a b c  + 348a b c  - 320a b c  + 108a b c
+--R                         + 
+--R                                2 9
+--R                           - 12a b c
+--R                    *
+--R                          11
+--R                       d e
+--R                   + 
+--R                               6 6        5 2 5        4 4 4       3 6 3
+--R                           136a c  - 1010a b c  + 1324a b c  - 534a b c
+--R                         + 
+--R                              2 8 2
+--R                           66a b c
+--R                    *
+--R                        2 10
+--R                       d e
+--R                   + 
+--R                           5   6        4 3 5        3 5 4       2 7 3  3 9
+--R                     (1472a b c  - 3152a b c  + 1560a b c  - 216a b c )d e
+--R                   + 
+--R                                 5 7        4 2 6        3 4 5       2 6 4
+--R                           - 956a c  + 4631a b c  - 2966a b c  + 471a b c
+--R                         + 
+--R                                8 3
+--R                           - a b c
+--R                    *
+--R                        4 8
+--R                       d e
+--R                   + 
+--R                             4   7        3 3 6       2 5 5       7 4  5 7
+--R                     (- 4128a b c  + 3848a b c  - 736a b c  + 8a b c )d e
+--R                   + 
+--R                           4 8        3 2 7       2 4 6        6 5  6 6
+--R                     (1904a c  - 3500a b c  + 868a b c  - 28a b c )d e
+--R                   + 
+--R                           3   8       2 3 7        5 6  7 5
+--R                     (2240a b c  - 784a b c  + 56a b c )d e
+--R                   + 
+--R                            3 9       2 2 8        4 7  8 4
+--R                     (- 956a c  + 523a b c  - 71a b c )d e
+--R                   + 
+--R                            2   9        3 8  9 3        2 10        2 9  10 2
+--R                     (- 240a b c  + 60a b c )d e  + (136a c   - 34a b c )d  e
+--R                   + 
+--R                            11    2 10  12
+--R                     (- 4a c   + b c  )d
+--R                *
+--R                   ROOT
+--R                                  2 8       2 7
+--R                            (- 16a c  + 4a b c )
+--R                         *
+--R                            ROOT
+--R                                          8 6      7 2 5      6 4 4      5 6 3
+--R                                       - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                     + 
+--R                                            4 8 2      3 10     2 12
+--R                                       - 37a b c  + 10a b  c - a b
+--R                                  *
+--R                                      16
+--R                                     e
+--R                                 + 
+--R                                            7   6       6 3 5       5 5 4
+--R                                       - 48a b c  + 352a b c  - 640a b c
+--R                                     + 
+--R                                           4 7 3       3 9 2      2 11
+--R                                       464a b c  - 144a b c  + 16a b  c
+--R                                  *
+--R                                        15
+--R                                     d e
+--R                                 + 
+--R                                          7 7        6 2 6        5 4 5
+--R                                       56a c  - 1080a b c  + 2880a b c
+--R                                     + 
+--R                                              4 6 4       3 8 3       2 10 2
+--R                                       - 2640a b c  + 960a b c  - 120a b  c
+--R                                  *
+--R                                      2 14
+--R                                     d e
+--R                                 + 
+--R                                            6   7        5 3 6        4 5 5
+--R                                       1568a b c  - 7280a b c  + 8960a b c
+--R                                     + 
+--R                                              3 7 4       2 9 3
+--R                                       - 3920a b c  + 560a b c
+--R                                  *
+--R                                      3 13
+--R                                     d e
+--R                                 + 
+--R                                             6 8         5 2 7         4 4 6
+--R                                       - 924a c  + 11060a b c  - 20020a b c
+--R                                     + 
+--R                                             3 6 5        2 8 4
+--R                                       10920a b c  - 1820a b c
+--R                                  *
+--R                                      4 12
+--R                                     d e
+--R                                 + 
+--R                                              5   8         4 3 7         3 5 6
+--R                                       - 9744a b c  + 30464a b c  - 21840a b c
+--R                                     + 
+--R                                            2 7 5
+--R                                       4368a b c
+--R                                  *
+--R                                      5 11
+--R                                     d e
+--R                                 + 
+--R                                            5 9         4 2 8         3 4 7
+--R                                       3976a c  - 31248a b c  + 32088a b c
+--R                                     + 
+--R                                              2 6 6
+--R                                       - 8008a b c
+--R                                  *
+--R                                      6 10
+--R                                     d e
+--R                                 + 
+--R                                          4   9         3 3 8         2 5 7  7 9
+--R                                   (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                                 + 
+--R                                              4 10         3 2 9         2 4 8
+--R                                       - 6470a c   + 27060a b c  - 12750a b c
+--R                                     + 
+--R                                           6 7
+--R                                       2a b c
+--R                                  *
+--R                                      8 8
+--R                                     d e
+--R                                 + 
+--R                                            3   10         2 3 9        5 8  9 7
+--R                                   (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                                 + 
+--R                                         3 11        2 2 10        4 9  10 6
+--R                                   (3976a c   - 7224a b c   + 56a b c )d  e
+--R                                 + 
+--R                                         2   11         3 10  11 5
+--R                                   (3360a b c   - 112a b c  )d  e
+--R                                 + 
+--R                                          2 12         2 11  12 4
+--R                                   (- 924a c   + 140a b c  )d  e
+--R                                 + 
+--R                                             12 13 3        13 14 2    14 16
+--R                                   - 112a b c  d  e  + 56a c  d  e  - c  d
+--R                              /
+--R                                    3 15      2 2 14
+--R                                 64a c   - 16a b c
+--R                        + 
+--R                               4   3      3 3 2     2 5       7  8
+--R                          (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                        + 
+--R                              4 4      3 2 3      2 4 2       6     7
+--R                          (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                        + 
+--R                               3   4       2 3 3        5 2  2 6
+--R                          (140a b c  - 140a b c  + 28a b c )d e
+--R                        + 
+--R                                 3 5       2 2 4        4 3  3 5
+--R                          (- 112a c  + 224a b c  - 56a b c )d e
+--R                        + 
+--R                                 2   5        3 4  4 4
+--R                          (- 210a b c  + 70a b c )d e
+--R                        + 
+--R                               2 6        2 5  5 3          6 6 2        7 7
+--R                          (112a c  - 56a b c )d e  + 28a b c d e  - 16a c d e
+--R                        + 
+--R                             7 8
+--R                          b c d
+--R                     /
+--R                          2 8       2 7
+--R                        8a c  - 2a b c
+--R               + 
+--R                        8 3      7 2 2      6 4      5 6  16
+--R                     (2a c  - 12a b c  + 10a b c - 2a b )e
+--R                   + 
+--R                         7   3      6 3 2      5 5      4 7    15
+--R                     (40a b c  - 16a b c  - 24a b c + 8a b )d e
+--R                   + 
+--R                           7 4      6 2 3       5 4 2      4 6       3 8  2 14
+--R                     (- 48a c  - 60a b c  + 168a b c  - 12a b c - 12a b )d e
+--R                   + 
+--R                          6   4       5 3 3       4 5 2      3 7      2 9  3 13
+--R                     (168a b c  - 392a b c  - 168a b c  + 80a b c + 8a b )d e
+--R                   + 
+--R                              6 5       5 2 4       4 4 3       3 6 2      2 8
+--R                         - 72a c  + 468a b c  + 830a b c  - 176a b c  - 78a b c
+--R                       + 
+--R                               10
+--R                         - 2a b
+--R                    *
+--R                        4 12
+--R                       d e
+--R                   + 
+--R                                 5   5        4 3 4      3 5 3       2 7 2
+--R                           - 408a b c  - 1800a b c  - 24a b c  + 336a b c
+--R                         + 
+--R                                9
+--R                           24a b c
+--R                    *
+--R                        5 11
+--R                       d e
+--R                   + 
+--R                               5 6        4 2 5       3 4 4       2 6 3
+--R                           176a c  + 2244a b c  + 880a b c  - 836a b c
+--R                         + 
+--R                                   8 2
+--R                           - 132a b c
+--R                    *
+--R                        6 10
+--R                       d e
+--R                   + 
+--R                             4   6        3 3 5        2 5 4         7 3  7 9
+--R                     (- 1496a b c  - 1936a b c  + 1320a b c  + 440a b c )d e
+--R                   + 
+--R                          4 7        3 2 6        2 4 5         6 4  8 8
+--R                     (396a c  + 1980a b c  - 1386a b c  - 990a b c )d e
+--R                   + 
+--R                            3   7        2 3 6          5 5  9 7
+--R                     (- 968a b c  + 1056a b c  + 1584a b c )d e
+--R                   + 
+--R                          3 8       2 2 7          4 6  10 6
+--R                     (176a c  - 660a b c  - 1848a b c )d  e
+--R                   + 
+--R                          2   8          3 7  11 5
+--R                     (312a b c  + 1560a b c )d  e
+--R                   + 
+--R                           2 9         2 8     4 7  12 4
+--R                     (- 72a c  - 900a b c  + 2b c )d  e
+--R                   + 
+--R                              9     3 8  13 3           10      2 9  14 2
+--R                     (312a b c  - 8b c )d  e  + (- 48a c   + 12b c )d  e
+--R                   + 
+--R                           10 15      11 16
+--R                     - 8b c  d  e + 2c  d
+--R                *
+--R                   x
+--R     + 
+--R            3
+--R         15c
+--R      *
+--R         ROOT
+--R                      2 8       2 7
+--R                  (16a c  - 4a b c )
+--R               *
+--R                  ROOT
+--R                                8 6      7 2 5      6 4 4      5 6 3      4 8 2
+--R                             - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                           + 
+--R                                3 10     2 12
+--R                             10a b  c - a b
+--R                        *
+--R                            16
+--R                           e
+--R                       + 
+--R                                  7   6       6 3 5       5 5 4       4 7 3
+--R                             - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                           + 
+--R                                   3 9 2      2 11
+--R                             - 144a b c  + 16a b  c
+--R                        *
+--R                              15
+--R                           d e
+--R                       + 
+--R                                7 7        6 2 6        5 4 5        4 6 4
+--R                             56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                           + 
+--R                                 3 8 3       2 10 2
+--R                             960a b c  - 120a b  c
+--R                        *
+--R                            2 14
+--R                           d e
+--R                       + 
+--R                                  6   7        5 3 6        4 5 5        3 7 4
+--R                             1568a b c  - 7280a b c  + 8960a b c  - 3920a b c
+--R                           + 
+--R                                 2 9 3
+--R                             560a b c
+--R                        *
+--R                            3 13
+--R                           d e
+--R                       + 
+--R                                   6 8         5 2 7         4 4 6         3 6 5
+--R                             - 924a c  + 11060a b c  - 20020a b c  + 10920a b c
+--R                           + 
+--R                                    2 8 4
+--R                             - 1820a b c
+--R                        *
+--R                            4 12
+--R                           d e
+--R                       + 
+--R                                      5   8         4 3 7         3 5 6
+--R                               - 9744a b c  + 30464a b c  - 21840a b c
+--R                             + 
+--R                                    2 7 5
+--R                               4368a b c
+--R                        *
+--R                            5 11
+--R                           d e
+--R                       + 
+--R                                 5 9         4 2 8         3 4 7        2 6 6  6
+--R                           (3976a c  - 31248a b c  + 32088a b c  - 8008a b c )d
+--R                        *
+--R                            10
+--R                           e
+--R                       + 
+--R                                4   9         3 3 8         2 5 7  7 9
+--R                         (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                       + 
+--R                                 4 10         3 2 9         2 4 8       6 7  8 8
+--R                         (- 6470a c   + 27060a b c  - 12750a b c  + 2a b c )d e
+--R                       + 
+--R                                  3   10         2 3 9        5 8  9 7
+--R                         (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                       + 
+--R                               3 11        2 2 10        4 9  10 6
+--R                         (3976a c   - 7224a b c   + 56a b c )d  e
+--R                       + 
+--R                               2   11         3 10  11 5
+--R                         (3360a b c   - 112a b c  )d  e
+--R                       + 
+--R                                2 12         2 11  12 4           12 13 3
+--R                         (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                       + 
+--R                              13 14 2    14 16
+--R                         56a c  d  e  - c  d
+--R                    /
+--R                          3 15      2 2 14
+--R                       64a c   - 16a b c
+--R              + 
+--R                     4   3      3 3 2     2 5       7  8
+--R                (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R              + 
+--R                    4 4      3 2 3      2 4 2       6     7
+--R                (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R              + 
+--R                     3   4       2 3 3        5 2  2 6
+--R                (140a b c  - 140a b c  + 28a b c )d e
+--R              + 
+--R                       3 5       2 2 4        4 3  3 5
+--R                (- 112a c  + 224a b c  - 56a b c )d e
+--R              + 
+--R                       2   5        3 4  4 4        2 6        2 5  5 3
+--R                (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R              + 
+--R                       6 6 2        7 7       7 8
+--R                28a b c d e  - 16a c d e + b c d
+--R           /
+--R                2 8       2 7
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                            4   9      3 3 8     2 5 7  4
+--R                      (- 48a b c  + 28a b c  - 4a b c )e
+--R                    + 
+--R                           4 10      3 2 9      2 4 8    3
+--R                      (128a c   - 96a b c  + 16a b c )d e
+--R                    + 
+--R                          3   10      2 3 9  2 2          3 11      2 2 10  3
+--R                      (96a b c   - 24a b c )d e  + (- 128a c   + 32a b c  )d e
+--R                    + 
+--R                          2   11       3 10  4
+--R                      (16a b c   - 4a b c  )d
+--R                 *
+--R                    ROOT
+--R                                  8 6      7 2 5      6 4 4      5 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    4 8 2      3 10     2 12
+--R                               - 37a b c  + 10a b  c - a b
+--R                          *
+--R                              16
+--R                             e
+--R                         + 
+--R                                    7   6       6 3 5       5 5 4       4 7 3
+--R                               - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                             + 
+--R                                     3 9 2      2 11
+--R                               - 144a b c  + 16a b  c
+--R                          *
+--R                                15
+--R                             d e
+--R                         + 
+--R                                  7 7        6 2 6        5 4 5        4 6 4
+--R                               56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                             + 
+--R                                   3 8 3       2 10 2
+--R                               960a b c  - 120a b  c
+--R                          *
+--R                              2 14
+--R                             d e
+--R                         + 
+--R                                    6   7        5 3 6        4 5 5        3 7 4
+--R                               1568a b c  - 7280a b c  + 8960a b c  - 3920a b c
+--R                             + 
+--R                                   2 9 3
+--R                               560a b c
+--R                          *
+--R                              3 13
+--R                             d e
+--R                         + 
+--R                                     6 8         5 2 7         4 4 6
+--R                               - 924a c  + 11060a b c  - 20020a b c
+--R                             + 
+--R                                     3 6 5        2 8 4
+--R                               10920a b c  - 1820a b c
+--R                          *
+--R                              4 12
+--R                             d e
+--R                         + 
+--R                                      5   8         4 3 7         3 5 6
+--R                               - 9744a b c  + 30464a b c  - 21840a b c
+--R                             + 
+--R                                    2 7 5
+--R                               4368a b c
+--R                          *
+--R                              5 11
+--R                             d e
+--R                         + 
+--R                                   5 9         4 2 8         3 4 7        2 6 6
+--R                             (3976a c  - 31248a b c  + 32088a b c  - 8008a b c )
+--R                          *
+--R                              6 10
+--R                             d e
+--R                         + 
+--R                                  4   9         3 3 8         2 5 7  7 9
+--R                           (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                         + 
+--R                                     4 10         3 2 9         2 4 8       6 7
+--R                             (- 6470a c   + 27060a b c  - 12750a b c  + 2a b c )
+--R                          *
+--R                              8 8
+--R                             d e
+--R                         + 
+--R                                    3   10         2 3 9        5 8  9 7
+--R                           (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                         + 
+--R                                 3 11        2 2 10        4 9  10 6
+--R                           (3976a c   - 7224a b c   + 56a b c )d  e
+--R                         + 
+--R                                 2   11         3 10  11 5
+--R                           (3360a b c   - 112a b c  )d  e
+--R                         + 
+--R                                  2 12         2 11  12 4           12 13 3
+--R                           (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                         + 
+--R                                13 14 2    14 16
+--R                           56a c  d  e  - c  d
+--R                      /
+--R                            3 15      2 2 14
+--R                         64a c   - 16a b c
+--R                + 
+--R                     7 5      6 2 4      5 4 3      4 6 2      3 8     2 10  12
+--R                  (4a c  - 29a b c  + 51a b c  - 35a b c  + 10a b c - a b  )e
+--R                + 
+--R                       6   5       5 3 4       4 5 3       3 7 2      2 9     11
+--R                  (112a b c  - 348a b c  + 320a b c  - 108a b c  + 12a b c)d e
+--R                + 
+--R                           6 6        5 2 5        4 4 4       3 6 3      2 8 2
+--R                    (- 136a c  + 1010a b c  - 1324a b c  + 534a b c  - 66a b c )
+--R                 *
+--R                     2 10
+--R                    d e
+--R                + 
+--R                          5   6        4 3 5        3 5 4       2 7 3  3 9
+--R                  (- 1472a b c  + 3152a b c  - 1560a b c  + 216a b c )d e
+--R                + 
+--R                       5 7        4 2 6        3 4 5       2 6 4      8 3  4 8
+--R                  (956a c  - 4631a b c  + 2966a b c  - 471a b c  + a b c )d e
+--R                + 
+--R                        4   7        3 3 6       2 5 5       7 4  5 7
+--R                  (4128a b c  - 3848a b c  + 736a b c  - 8a b c )d e
+--R                + 
+--R                          4 8        3 2 7       2 4 6        6 5  6 6
+--R                  (- 1904a c  + 3500a b c  - 868a b c  + 28a b c )d e
+--R                + 
+--R                          3   8       2 3 7        5 6  7 5
+--R                  (- 2240a b c  + 784a b c  - 56a b c )d e
+--R                + 
+--R                       3 9       2 2 8        4 7  8 4
+--R                  (956a c  - 523a b c  + 71a b c )d e
+--R                + 
+--R                       2   9        3 8  9 3          2 10        2 9  10 2
+--R                  (240a b c  - 60a b c )d e  + (- 136a c   + 34a b c )d  e
+--R                + 
+--R                       11    2 10  12
+--R                  (4a c   - b c  )d
+--R             *
+--R                ROOT
+--R                             2 8       2 7
+--R                         (16a c  - 4a b c )
+--R                      *
+--R                         ROOT
+--R                                       8 6      7 2 5      6 4 4      5 6 3
+--R                                    - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                  + 
+--R                                         4 8 2      3 10     2 12
+--R                                    - 37a b c  + 10a b  c - a b
+--R                               *
+--R                                   16
+--R                                  e
+--R                              + 
+--R                                         7   6       6 3 5       5 5 4
+--R                                    - 48a b c  + 352a b c  - 640a b c
+--R                                  + 
+--R                                        4 7 3       3 9 2      2 11
+--R                                    464a b c  - 144a b c  + 16a b  c
+--R                               *
+--R                                     15
+--R                                  d e
+--R                              + 
+--R                                       7 7        6 2 6        5 4 5
+--R                                    56a c  - 1080a b c  + 2880a b c
+--R                                  + 
+--R                                           4 6 4       3 8 3       2 10 2
+--R                                    - 2640a b c  + 960a b c  - 120a b  c
+--R                               *
+--R                                   2 14
+--R                                  d e
+--R                              + 
+--R                                         6   7        5 3 6        4 5 5
+--R                                    1568a b c  - 7280a b c  + 8960a b c
+--R                                  + 
+--R                                           3 7 4       2 9 3
+--R                                    - 3920a b c  + 560a b c
+--R                               *
+--R                                   3 13
+--R                                  d e
+--R                              + 
+--R                                          6 8         5 2 7         4 4 6
+--R                                    - 924a c  + 11060a b c  - 20020a b c
+--R                                  + 
+--R                                          3 6 5        2 8 4
+--R                                    10920a b c  - 1820a b c
+--R                               *
+--R                                   4 12
+--R                                  d e
+--R                              + 
+--R                                           5   8         4 3 7         3 5 6
+--R                                    - 9744a b c  + 30464a b c  - 21840a b c
+--R                                  + 
+--R                                         2 7 5
+--R                                    4368a b c
+--R                               *
+--R                                   5 11
+--R                                  d e
+--R                              + 
+--R                                         5 9         4 2 8         3 4 7
+--R                                    3976a c  - 31248a b c  + 32088a b c
+--R                                  + 
+--R                                           2 6 6
+--R                                    - 8008a b c
+--R                               *
+--R                                   6 10
+--R                                  d e
+--R                              + 
+--R                                       4   9         3 3 8         2 5 7  7 9
+--R                                (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                              + 
+--R                                           4 10         3 2 9         2 4 8
+--R                                    - 6470a c   + 27060a b c  - 12750a b c
+--R                                  + 
+--R                                        6 7
+--R                                    2a b c
+--R                               *
+--R                                   8 8
+--R                                  d e
+--R                              + 
+--R                                         3   10         2 3 9        5 8  9 7
+--R                                (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                              + 
+--R                                      3 11        2 2 10        4 9  10 6
+--R                                (3976a c   - 7224a b c   + 56a b c )d  e
+--R                              + 
+--R                                      2   11         3 10  11 5
+--R                                (3360a b c   - 112a b c  )d  e
+--R                              + 
+--R                                       2 12         2 11  12 4           12 13 3
+--R                                (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                              + 
+--R                                     13 14 2    14 16
+--R                                56a c  d  e  - c  d
+--R                           /
+--R                                 3 15      2 2 14
+--R                              64a c   - 16a b c
+--R                     + 
+--R                            4   3      3 3 2     2 5       7  8
+--R                       (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                     + 
+--R                           4 4      3 2 3      2 4 2       6     7
+--R                       (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                     + 
+--R                            3   4       2 3 3        5 2  2 6
+--R                       (140a b c  - 140a b c  + 28a b c )d e
+--R                     + 
+--R                              3 5       2 2 4        4 3  3 5
+--R                       (- 112a c  + 224a b c  - 56a b c )d e
+--R                     + 
+--R                              2   5        3 4  4 4        2 6        2 5  5 3
+--R                       (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R                     + 
+--R                              6 6 2        7 7       7 8
+--R                       28a b c d e  - 16a c d e + b c d
+--R                  /
+--R                       2 8       2 7
+--R                     8a c  - 2a b c
+--R            + 
+--R                     8 3      7 2 2      6 4      5 6  16
+--R                  (2a c  - 12a b c  + 10a b c - 2a b )e
+--R                + 
+--R                      7   3      6 3 2      5 5      4 7    15
+--R                  (40a b c  - 16a b c  - 24a b c + 8a b )d e
+--R                + 
+--R                        7 4      6 2 3       5 4 2      4 6       3 8  2 14
+--R                  (- 48a c  - 60a b c  + 168a b c  - 12a b c - 12a b )d e
+--R                + 
+--R                       6   4       5 3 3       4 5 2      3 7      2 9  3 13
+--R                  (168a b c  - 392a b c  - 168a b c  + 80a b c + 8a b )d e
+--R                + 
+--R                           6 5       5 2 4       4 4 3       3 6 2      2 8
+--R                      - 72a c  + 468a b c  + 830a b c  - 176a b c  - 78a b c
+--R                    + 
+--R                            10
+--R                      - 2a b
+--R                 *
+--R                     4 12
+--R                    d e
+--R                + 
+--R                           5   5        4 3 4      3 5 3       2 7 2        9
+--R                    (- 408a b c  - 1800a b c  - 24a b c  + 336a b c  + 24a b c)
+--R                 *
+--R                     5 11
+--R                    d e
+--R                + 
+--R                         5 6        4 2 5       3 4 4       2 6 3         8 2  6
+--R                    (176a c  + 2244a b c  + 880a b c  - 836a b c  - 132a b c )d
+--R                 *
+--R                     10
+--R                    e
+--R                + 
+--R                          4   6        3 3 5        2 5 4         7 3  7 9
+--R                  (- 1496a b c  - 1936a b c  + 1320a b c  + 440a b c )d e
+--R                + 
+--R                       4 7        3 2 6        2 4 5         6 4  8 8
+--R                  (396a c  + 1980a b c  - 1386a b c  - 990a b c )d e
+--R                + 
+--R                         3   7        2 3 6          5 5  9 7
+--R                  (- 968a b c  + 1056a b c  + 1584a b c )d e
+--R                + 
+--R                       3 8       2 2 7          4 6  10 6
+--R                  (176a c  - 660a b c  - 1848a b c )d  e
+--R                + 
+--R                       2   8          3 7  11 5
+--R                  (312a b c  + 1560a b c )d  e
+--R                + 
+--R                        2 9         2 8     4 7  12 4            9     3 8  13 3
+--R                  (- 72a c  - 900a b c  + 2b c )d  e  + (312a b c  - 8b c )d  e
+--R                + 
+--R                          10      2 9  14 2       10 15      11 16
+--R                  (- 48a c   + 12b c )d  e  - 8b c  d  e + 2c  d
+--R             *
+--R                x
+--R     + 
+--R         2 4 5             4      2   3  3
+--R       6c e x  + (- 10b c e  + 40c d e )x
+--R     + 
+--R                      2  4             3       2 2 2
+--R       ((- 30a c + 30b )e  - 120b c d e  + 180c d e )x
+--R  /
+--R        3
+--R     30c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2800
+
+--S 2801 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                     +--------------------+
+--R                   +-----------+     |   +-----------+
+--R             3 +-+ |          2  +-+ |   |          2
+--R            c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                         2 8       2 7
+--R                     (16a c  - 4a b c )
+--R                  *
+--R                     ROOT
+--R                                   8 6      7 2 5      6 4 4      5 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     4 8 2      3 10     2 12
+--R                                - 37a b c  + 10a b  c - a b
+--R                           *
+--R                               16
+--R                              e
+--R                          + 
+--R                                     7   6       6 3 5       5 5 4       4 7 3
+--R                                - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                              + 
+--R                                      3 9 2      2 11
+--R                                - 144a b c  + 16a b  c
+--R                           *
+--R                                 15
+--R                              d e
+--R                          + 
+--R                                   7 7        6 2 6        5 4 5        4 6 4
+--R                                56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                              + 
+--R                                    3 8 3       2 10 2
+--R                                960a b c  - 120a b  c
+--R                           *
+--R                               2 14
+--R                              d e
+--R                          + 
+--R                                     6   7        5 3 6        4 5 5
+--R                                1568a b c  - 7280a b c  + 8960a b c
+--R                              + 
+--R                                       3 7 4       2 9 3
+--R                                - 3920a b c  + 560a b c
+--R                           *
+--R                               3 13
+--R                              d e
+--R                          + 
+--R                                      6 8         5 2 7         4 4 6
+--R                                - 924a c  + 11060a b c  - 20020a b c
+--R                              + 
+--R                                      3 6 5        2 8 4
+--R                                10920a b c  - 1820a b c
+--R                           *
+--R                               4 12
+--R                              d e
+--R                          + 
+--R                                       5   8         4 3 7         3 5 6
+--R                                - 9744a b c  + 30464a b c  - 21840a b c
+--R                              + 
+--R                                     2 7 5
+--R                                4368a b c
+--R                           *
+--R                               5 11
+--R                              d e
+--R                          + 
+--R                                       5 9         4 2 8         3 4 7
+--R                                  3976a c  - 31248a b c  + 32088a b c
+--R                                + 
+--R                                         2 6 6
+--R                                  - 8008a b c
+--R                           *
+--R                               6 10
+--R                              d e
+--R                          + 
+--R                                   4   9         3 3 8         2 5 7  7 9
+--R                            (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                          + 
+--R                                         4 10         3 2 9         2 4 8
+--R                                  - 6470a c   + 27060a b c  - 12750a b c
+--R                                + 
+--R                                      6 7
+--R                                  2a b c
+--R                           *
+--R                               8 8
+--R                              d e
+--R                          + 
+--R                                     3   10         2 3 9        5 8  9 7
+--R                            (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                          + 
+--R                                  3 11        2 2 10        4 9  10 6
+--R                            (3976a c   - 7224a b c   + 56a b c )d  e
+--R                          + 
+--R                                  2   11         3 10  11 5
+--R                            (3360a b c   - 112a b c  )d  e
+--R                          + 
+--R                                   2 12         2 11  12 4           12 13 3
+--R                            (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                          + 
+--R                                 13 14 2    14 16
+--R                            56a c  d  e  - c  d
+--R                       /
+--R                             3 15      2 2 14
+--R                          64a c   - 16a b c
+--R                 + 
+--R                        4   3      3 3 2     2 5       7  8
+--R                   (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                 + 
+--R                       4 4      3 2 3      2 4 2       6     7
+--R                   (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                 + 
+--R                        3   4       2 3 3        5 2  2 6
+--R                   (140a b c  - 140a b c  + 28a b c )d e
+--R                 + 
+--R                          3 5       2 2 4        4 3  3 5
+--R                   (- 112a c  + 224a b c  - 56a b c )d e
+--R                 + 
+--R                          2   5        3 4  4 4        2 6        2 5  5 3
+--R                   (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R                 + 
+--R                          6 6 2        7 7       7 8
+--R                   28a b c d e  - 16a c d e + b c d
+--R              /
+--R                   2 8       2 7
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                             4   9      3 3 8     2 5 7  4
+--R                         (48a b c  - 28a b c  + 4a b c )e
+--R                       + 
+--R                                4 10      3 2 9      2 4 8    3
+--R                         (- 128a c   + 96a b c  - 16a b c )d e
+--R                       + 
+--R                               3   10      2 3 9  2 2
+--R                         (- 96a b c   + 24a b c )d e
+--R                       + 
+--R                              3 11      2 2 10  3          2   11       3 10  4
+--R                         (128a c   - 32a b c  )d e + (- 16a b c   + 4a b c  )d
+--R                    *
+--R                       ROOT
+--R                                     8 6      7 2 5      6 4 4      5 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       4 8 2      3 10     2 12
+--R                                  - 37a b c  + 10a b  c - a b
+--R                             *
+--R                                 16
+--R                                e
+--R                            + 
+--R                                       7   6       6 3 5       5 5 4       4 7 3
+--R                                  - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                                + 
+--R                                        3 9 2      2 11
+--R                                  - 144a b c  + 16a b  c
+--R                             *
+--R                                   15
+--R                                d e
+--R                            + 
+--R                                     7 7        6 2 6        5 4 5        4 6 4
+--R                                  56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                                + 
+--R                                      3 8 3       2 10 2
+--R                                  960a b c  - 120a b  c
+--R                             *
+--R                                 2 14
+--R                                d e
+--R                            + 
+--R                                       6   7        5 3 6        4 5 5
+--R                                  1568a b c  - 7280a b c  + 8960a b c
+--R                                + 
+--R                                         3 7 4       2 9 3
+--R                                  - 3920a b c  + 560a b c
+--R                             *
+--R                                 3 13
+--R                                d e
+--R                            + 
+--R                                        6 8         5 2 7         4 4 6
+--R                                  - 924a c  + 11060a b c  - 20020a b c
+--R                                + 
+--R                                        3 6 5        2 8 4
+--R                                  10920a b c  - 1820a b c
+--R                             *
+--R                                 4 12
+--R                                d e
+--R                            + 
+--R                                         5   8         4 3 7         3 5 6
+--R                                  - 9744a b c  + 30464a b c  - 21840a b c
+--R                                + 
+--R                                       2 7 5
+--R                                  4368a b c
+--R                             *
+--R                                 5 11
+--R                                d e
+--R                            + 
+--R                                       5 9         4 2 8         3 4 7
+--R                                  3976a c  - 31248a b c  + 32088a b c
+--R                                + 
+--R                                         2 6 6
+--R                                  - 8008a b c
+--R                             *
+--R                                 6 10
+--R                                d e
+--R                            + 
+--R                                     4   9         3 3 8         2 5 7  7 9
+--R                              (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                            + 
+--R                                         4 10         3 2 9         2 4 8
+--R                                  - 6470a c   + 27060a b c  - 12750a b c
+--R                                + 
+--R                                      6 7
+--R                                  2a b c
+--R                             *
+--R                                 8 8
+--R                                d e
+--R                            + 
+--R                                       3   10         2 3 9        5 8  9 7
+--R                              (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                            + 
+--R                                    3 11        2 2 10        4 9  10 6
+--R                              (3976a c   - 7224a b c   + 56a b c )d  e
+--R                            + 
+--R                                    2   11         3 10  11 5
+--R                              (3360a b c   - 112a b c  )d  e
+--R                            + 
+--R                                     2 12         2 11  12 4           12 13 3
+--R                              (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                            + 
+--R                                   13 14 2    14 16
+--R                              56a c  d  e  - c  d
+--R                         /
+--R                               3 15      2 2 14
+--R                            64a c   - 16a b c
+--R                   + 
+--R                             7 5      6 2 4      5 4 3      4 6 2      3 8
+--R                         - 4a c  + 29a b c  - 51a b c  + 35a b c  - 10a b c
+--R                       + 
+--R                          2 10
+--R                         a b
+--R                    *
+--R                        12
+--R                       e
+--R                   + 
+--R                                 6   5       5 3 4       4 5 3       3 7 2
+--R                           - 112a b c  + 348a b c  - 320a b c  + 108a b c
+--R                         + 
+--R                                2 9
+--R                           - 12a b c
+--R                    *
+--R                          11
+--R                       d e
+--R                   + 
+--R                               6 6        5 2 5        4 4 4       3 6 3
+--R                           136a c  - 1010a b c  + 1324a b c  - 534a b c
+--R                         + 
+--R                              2 8 2
+--R                           66a b c
+--R                    *
+--R                        2 10
+--R                       d e
+--R                   + 
+--R                           5   6        4 3 5        3 5 4       2 7 3  3 9
+--R                     (1472a b c  - 3152a b c  + 1560a b c  - 216a b c )d e
+--R                   + 
+--R                                 5 7        4 2 6        3 4 5       2 6 4
+--R                           - 956a c  + 4631a b c  - 2966a b c  + 471a b c
+--R                         + 
+--R                                8 3
+--R                           - a b c
+--R                    *
+--R                        4 8
+--R                       d e
+--R                   + 
+--R                             4   7        3 3 6       2 5 5       7 4  5 7
+--R                     (- 4128a b c  + 3848a b c  - 736a b c  + 8a b c )d e
+--R                   + 
+--R                           4 8        3 2 7       2 4 6        6 5  6 6
+--R                     (1904a c  - 3500a b c  + 868a b c  - 28a b c )d e
+--R                   + 
+--R                           3   8       2 3 7        5 6  7 5
+--R                     (2240a b c  - 784a b c  + 56a b c )d e
+--R                   + 
+--R                            3 9       2 2 8        4 7  8 4
+--R                     (- 956a c  + 523a b c  - 71a b c )d e
+--R                   + 
+--R                            2   9        3 8  9 3        2 10        2 9  10 2
+--R                     (- 240a b c  + 60a b c )d e  + (136a c   - 34a b c )d  e
+--R                   + 
+--R                            11    2 10  12
+--R                     (- 4a c   + b c  )d
+--R                *
+--R                   ROOT
+--R                                2 8       2 7
+--R                            (16a c  - 4a b c )
+--R                         *
+--R                            ROOT
+--R                                          8 6      7 2 5      6 4 4      5 6 3
+--R                                       - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                     + 
+--R                                            4 8 2      3 10     2 12
+--R                                       - 37a b c  + 10a b  c - a b
+--R                                  *
+--R                                      16
+--R                                     e
+--R                                 + 
+--R                                            7   6       6 3 5       5 5 4
+--R                                       - 48a b c  + 352a b c  - 640a b c
+--R                                     + 
+--R                                           4 7 3       3 9 2      2 11
+--R                                       464a b c  - 144a b c  + 16a b  c
+--R                                  *
+--R                                        15
+--R                                     d e
+--R                                 + 
+--R                                          7 7        6 2 6        5 4 5
+--R                                       56a c  - 1080a b c  + 2880a b c
+--R                                     + 
+--R                                              4 6 4       3 8 3       2 10 2
+--R                                       - 2640a b c  + 960a b c  - 120a b  c
+--R                                  *
+--R                                      2 14
+--R                                     d e
+--R                                 + 
+--R                                            6   7        5 3 6        4 5 5
+--R                                       1568a b c  - 7280a b c  + 8960a b c
+--R                                     + 
+--R                                              3 7 4       2 9 3
+--R                                       - 3920a b c  + 560a b c
+--R                                  *
+--R                                      3 13
+--R                                     d e
+--R                                 + 
+--R                                             6 8         5 2 7         4 4 6
+--R                                       - 924a c  + 11060a b c  - 20020a b c
+--R                                     + 
+--R                                             3 6 5        2 8 4
+--R                                       10920a b c  - 1820a b c
+--R                                  *
+--R                                      4 12
+--R                                     d e
+--R                                 + 
+--R                                              5   8         4 3 7         3 5 6
+--R                                       - 9744a b c  + 30464a b c  - 21840a b c
+--R                                     + 
+--R                                            2 7 5
+--R                                       4368a b c
+--R                                  *
+--R                                      5 11
+--R                                     d e
+--R                                 + 
+--R                                            5 9         4 2 8         3 4 7
+--R                                       3976a c  - 31248a b c  + 32088a b c
+--R                                     + 
+--R                                              2 6 6
+--R                                       - 8008a b c
+--R                                  *
+--R                                      6 10
+--R                                     d e
+--R                                 + 
+--R                                          4   9         3 3 8         2 5 7  7 9
+--R                                   (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                                 + 
+--R                                              4 10         3 2 9         2 4 8
+--R                                       - 6470a c   + 27060a b c  - 12750a b c
+--R                                     + 
+--R                                           6 7
+--R                                       2a b c
+--R                                  *
+--R                                      8 8
+--R                                     d e
+--R                                 + 
+--R                                            3   10         2 3 9        5 8  9 7
+--R                                   (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                                 + 
+--R                                         3 11        2 2 10        4 9  10 6
+--R                                   (3976a c   - 7224a b c   + 56a b c )d  e
+--R                                 + 
+--R                                         2   11         3 10  11 5
+--R                                   (3360a b c   - 112a b c  )d  e
+--R                                 + 
+--R                                          2 12         2 11  12 4
+--R                                   (- 924a c   + 140a b c  )d  e
+--R                                 + 
+--R                                             12 13 3        13 14 2    14 16
+--R                                   - 112a b c  d  e  + 56a c  d  e  - c  d
+--R                              /
+--R                                    3 15      2 2 14
+--R                                 64a c   - 16a b c
+--R                        + 
+--R                               4   3      3 3 2     2 5       7  8
+--R                          (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                        + 
+--R                              4 4      3 2 3      2 4 2       6     7
+--R                          (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                        + 
+--R                               3   4       2 3 3        5 2  2 6
+--R                          (140a b c  - 140a b c  + 28a b c )d e
+--R                        + 
+--R                                 3 5       2 2 4        4 3  3 5
+--R                          (- 112a c  + 224a b c  - 56a b c )d e
+--R                        + 
+--R                                 2   5        3 4  4 4
+--R                          (- 210a b c  + 70a b c )d e
+--R                        + 
+--R                               2 6        2 5  5 3          6 6 2        7 7
+--R                          (112a c  - 56a b c )d e  + 28a b c d e  - 16a c d e
+--R                        + 
+--R                             7 8
+--R                          b c d
+--R                     /
+--R                          2 8       2 7
+--R                        8a c  - 2a b c
+--R               + 
+--R                        8 3      7 2 2      6 4      5 6  16
+--R                     (2a c  - 12a b c  + 10a b c - 2a b )e
+--R                   + 
+--R                         7   3      6 3 2      5 5      4 7    15
+--R                     (40a b c  - 16a b c  - 24a b c + 8a b )d e
+--R                   + 
+--R                           7 4      6 2 3       5 4 2      4 6       3 8  2 14
+--R                     (- 48a c  - 60a b c  + 168a b c  - 12a b c - 12a b )d e
+--R                   + 
+--R                          6   4       5 3 3       4 5 2      3 7      2 9  3 13
+--R                     (168a b c  - 392a b c  - 168a b c  + 80a b c + 8a b )d e
+--R                   + 
+--R                              6 5       5 2 4       4 4 3       3 6 2      2 8
+--R                         - 72a c  + 468a b c  + 830a b c  - 176a b c  - 78a b c
+--R                       + 
+--R                               10
+--R                         - 2a b
+--R                    *
+--R                        4 12
+--R                       d e
+--R                   + 
+--R                                 5   5        4 3 4      3 5 3       2 7 2
+--R                           - 408a b c  - 1800a b c  - 24a b c  + 336a b c
+--R                         + 
+--R                                9
+--R                           24a b c
+--R                    *
+--R                        5 11
+--R                       d e
+--R                   + 
+--R                               5 6        4 2 5       3 4 4       2 6 3
+--R                           176a c  + 2244a b c  + 880a b c  - 836a b c
+--R                         + 
+--R                                   8 2
+--R                           - 132a b c
+--R                    *
+--R                        6 10
+--R                       d e
+--R                   + 
+--R                             4   6        3 3 5        2 5 4         7 3  7 9
+--R                     (- 1496a b c  - 1936a b c  + 1320a b c  + 440a b c )d e
+--R                   + 
+--R                          4 7        3 2 6        2 4 5         6 4  8 8
+--R                     (396a c  + 1980a b c  - 1386a b c  - 990a b c )d e
+--R                   + 
+--R                            3   7        2 3 6          5 5  9 7
+--R                     (- 968a b c  + 1056a b c  + 1584a b c )d e
+--R                   + 
+--R                          3 8       2 2 7          4 6  10 6
+--R                     (176a c  - 660a b c  - 1848a b c )d  e
+--R                   + 
+--R                          2   8          3 7  11 5
+--R                     (312a b c  + 1560a b c )d  e
+--R                   + 
+--R                           2 9         2 8     4 7  12 4
+--R                     (- 72a c  - 900a b c  + 2b c )d  e
+--R                   + 
+--R                              9     3 8  13 3           10      2 9  14 2
+--R                     (312a b c  - 8b c )d  e  + (- 48a c   + 12b c )d  e
+--R                   + 
+--R                           10 15      11 16
+--R                     - 8b c  d  e + 2c  d
+--R                *
+--R                   x
+--R     + 
+--R                                  +--------------------+
+--R                +-----------+     |   +-----------+
+--R          3 +-+ |          2  +-+ |   |          2
+--R         c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        2 8       2 7
+--R                  (- 16a c  + 4a b c )
+--R               *
+--R                  ROOT
+--R                                8 6      7 2 5      6 4 4      5 6 3      4 8 2
+--R                             - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                           + 
+--R                                3 10     2 12
+--R                             10a b  c - a b
+--R                        *
+--R                            16
+--R                           e
+--R                       + 
+--R                                  7   6       6 3 5       5 5 4       4 7 3
+--R                             - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                           + 
+--R                                   3 9 2      2 11
+--R                             - 144a b c  + 16a b  c
+--R                        *
+--R                              15
+--R                           d e
+--R                       + 
+--R                                7 7        6 2 6        5 4 5        4 6 4
+--R                             56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                           + 
+--R                                 3 8 3       2 10 2
+--R                             960a b c  - 120a b  c
+--R                        *
+--R                            2 14
+--R                           d e
+--R                       + 
+--R                                  6   7        5 3 6        4 5 5        3 7 4
+--R                             1568a b c  - 7280a b c  + 8960a b c  - 3920a b c
+--R                           + 
+--R                                 2 9 3
+--R                             560a b c
+--R                        *
+--R                            3 13
+--R                           d e
+--R                       + 
+--R                                   6 8         5 2 7         4 4 6         3 6 5
+--R                             - 924a c  + 11060a b c  - 20020a b c  + 10920a b c
+--R                           + 
+--R                                    2 8 4
+--R                             - 1820a b c
+--R                        *
+--R                            4 12
+--R                           d e
+--R                       + 
+--R                                      5   8         4 3 7         3 5 6
+--R                               - 9744a b c  + 30464a b c  - 21840a b c
+--R                             + 
+--R                                    2 7 5
+--R                               4368a b c
+--R                        *
+--R                            5 11
+--R                           d e
+--R                       + 
+--R                                 5 9         4 2 8         3 4 7        2 6 6  6
+--R                           (3976a c  - 31248a b c  + 32088a b c  - 8008a b c )d
+--R                        *
+--R                            10
+--R                           e
+--R                       + 
+--R                                4   9         3 3 8         2 5 7  7 9
+--R                         (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                       + 
+--R                                 4 10         3 2 9         2 4 8       6 7  8 8
+--R                         (- 6470a c   + 27060a b c  - 12750a b c  + 2a b c )d e
+--R                       + 
+--R                                  3   10         2 3 9        5 8  9 7
+--R                         (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                       + 
+--R                               3 11        2 2 10        4 9  10 6
+--R                         (3976a c   - 7224a b c   + 56a b c )d  e
+--R                       + 
+--R                               2   11         3 10  11 5
+--R                         (3360a b c   - 112a b c  )d  e
+--R                       + 
+--R                                2 12         2 11  12 4           12 13 3
+--R                         (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                       + 
+--R                              13 14 2    14 16
+--R                         56a c  d  e  - c  d
+--R                    /
+--R                          3 15      2 2 14
+--R                       64a c   - 16a b c
+--R              + 
+--R                     4   3      3 3 2     2 5       7  8
+--R                (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R              + 
+--R                    4 4      3 2 3      2 4 2       6     7
+--R                (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R              + 
+--R                     3   4       2 3 3        5 2  2 6
+--R                (140a b c  - 140a b c  + 28a b c )d e
+--R              + 
+--R                       3 5       2 2 4        4 3  3 5
+--R                (- 112a c  + 224a b c  - 56a b c )d e
+--R              + 
+--R                       2   5        3 4  4 4        2 6        2 5  5 3
+--R                (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R              + 
+--R                       6 6 2        7 7       7 8
+--R                28a b c d e  - 16a c d e + b c d
+--R           /
+--R                2 8       2 7
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          4   9      3 3 8     2 5 7  4
+--R                      (48a b c  - 28a b c  + 4a b c )e
+--R                    + 
+--R                             4 10      3 2 9      2 4 8    3
+--R                      (- 128a c   + 96a b c  - 16a b c )d e
+--R                    + 
+--R                            3   10      2 3 9  2 2        3 11      2 2 10  3
+--R                      (- 96a b c   + 24a b c )d e  + (128a c   - 32a b c  )d e
+--R                    + 
+--R                            2   11       3 10  4
+--R                      (- 16a b c   + 4a b c  )d
+--R                 *
+--R                    ROOT
+--R                                  8 6      7 2 5      6 4 4      5 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    4 8 2      3 10     2 12
+--R                               - 37a b c  + 10a b  c - a b
+--R                          *
+--R                              16
+--R                             e
+--R                         + 
+--R                                    7   6       6 3 5       5 5 4       4 7 3
+--R                               - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                             + 
+--R                                     3 9 2      2 11
+--R                               - 144a b c  + 16a b  c
+--R                          *
+--R                                15
+--R                             d e
+--R                         + 
+--R                                  7 7        6 2 6        5 4 5        4 6 4
+--R                               56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                             + 
+--R                                   3 8 3       2 10 2
+--R                               960a b c  - 120a b  c
+--R                          *
+--R                              2 14
+--R                             d e
+--R                         + 
+--R                                    6   7        5 3 6        4 5 5        3 7 4
+--R                               1568a b c  - 7280a b c  + 8960a b c  - 3920a b c
+--R                             + 
+--R                                   2 9 3
+--R                               560a b c
+--R                          *
+--R                              3 13
+--R                             d e
+--R                         + 
+--R                                     6 8         5 2 7         4 4 6
+--R                               - 924a c  + 11060a b c  - 20020a b c
+--R                             + 
+--R                                     3 6 5        2 8 4
+--R                               10920a b c  - 1820a b c
+--R                          *
+--R                              4 12
+--R                             d e
+--R                         + 
+--R                                      5   8         4 3 7         3 5 6
+--R                               - 9744a b c  + 30464a b c  - 21840a b c
+--R                             + 
+--R                                    2 7 5
+--R                               4368a b c
+--R                          *
+--R                              5 11
+--R                             d e
+--R                         + 
+--R                                   5 9         4 2 8         3 4 7        2 6 6
+--R                             (3976a c  - 31248a b c  + 32088a b c  - 8008a b c )
+--R                          *
+--R                              6 10
+--R                             d e
+--R                         + 
+--R                                  4   9         3 3 8         2 5 7  7 9
+--R                           (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                         + 
+--R                                     4 10         3 2 9         2 4 8       6 7
+--R                             (- 6470a c   + 27060a b c  - 12750a b c  + 2a b c )
+--R                          *
+--R                              8 8
+--R                             d e
+--R                         + 
+--R                                    3   10         2 3 9        5 8  9 7
+--R                           (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                         + 
+--R                                 3 11        2 2 10        4 9  10 6
+--R                           (3976a c   - 7224a b c   + 56a b c )d  e
+--R                         + 
+--R                                 2   11         3 10  11 5
+--R                           (3360a b c   - 112a b c  )d  e
+--R                         + 
+--R                                  2 12         2 11  12 4           12 13 3
+--R                           (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                         + 
+--R                                13 14 2    14 16
+--R                           56a c  d  e  - c  d
+--R                      /
+--R                            3 15      2 2 14
+--R                         64a c   - 16a b c
+--R                + 
+--R                     7 5      6 2 4      5 4 3      4 6 2      3 8     2 10  12
+--R                  (4a c  - 29a b c  + 51a b c  - 35a b c  + 10a b c - a b  )e
+--R                + 
+--R                       6   5       5 3 4       4 5 3       3 7 2      2 9     11
+--R                  (112a b c  - 348a b c  + 320a b c  - 108a b c  + 12a b c)d e
+--R                + 
+--R                           6 6        5 2 5        4 4 4       3 6 3      2 8 2
+--R                    (- 136a c  + 1010a b c  - 1324a b c  + 534a b c  - 66a b c )
+--R                 *
+--R                     2 10
+--R                    d e
+--R                + 
+--R                          5   6        4 3 5        3 5 4       2 7 3  3 9
+--R                  (- 1472a b c  + 3152a b c  - 1560a b c  + 216a b c )d e
+--R                + 
+--R                       5 7        4 2 6        3 4 5       2 6 4      8 3  4 8
+--R                  (956a c  - 4631a b c  + 2966a b c  - 471a b c  + a b c )d e
+--R                + 
+--R                        4   7        3 3 6       2 5 5       7 4  5 7
+--R                  (4128a b c  - 3848a b c  + 736a b c  - 8a b c )d e
+--R                + 
+--R                          4 8        3 2 7       2 4 6        6 5  6 6
+--R                  (- 1904a c  + 3500a b c  - 868a b c  + 28a b c )d e
+--R                + 
+--R                          3   8       2 3 7        5 6  7 5
+--R                  (- 2240a b c  + 784a b c  - 56a b c )d e
+--R                + 
+--R                       3 9       2 2 8        4 7  8 4
+--R                  (956a c  - 523a b c  + 71a b c )d e
+--R                + 
+--R                       2   9        3 8  9 3          2 10        2 9  10 2
+--R                  (240a b c  - 60a b c )d e  + (- 136a c   + 34a b c )d  e
+--R                + 
+--R                       11    2 10  12
+--R                  (4a c   - b c  )d
+--R             *
+--R                ROOT
+--R                               2 8       2 7
+--R                         (- 16a c  + 4a b c )
+--R                      *
+--R                         ROOT
+--R                                       8 6      7 2 5      6 4 4      5 6 3
+--R                                    - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                  + 
+--R                                         4 8 2      3 10     2 12
+--R                                    - 37a b c  + 10a b  c - a b
+--R                               *
+--R                                   16
+--R                                  e
+--R                              + 
+--R                                         7   6       6 3 5       5 5 4
+--R                                    - 48a b c  + 352a b c  - 640a b c
+--R                                  + 
+--R                                        4 7 3       3 9 2      2 11
+--R                                    464a b c  - 144a b c  + 16a b  c
+--R                               *
+--R                                     15
+--R                                  d e
+--R                              + 
+--R                                       7 7        6 2 6        5 4 5
+--R                                    56a c  - 1080a b c  + 2880a b c
+--R                                  + 
+--R                                           4 6 4       3 8 3       2 10 2
+--R                                    - 2640a b c  + 960a b c  - 120a b  c
+--R                               *
+--R                                   2 14
+--R                                  d e
+--R                              + 
+--R                                         6   7        5 3 6        4 5 5
+--R                                    1568a b c  - 7280a b c  + 8960a b c
+--R                                  + 
+--R                                           3 7 4       2 9 3
+--R                                    - 3920a b c  + 560a b c
+--R                               *
+--R                                   3 13
+--R                                  d e
+--R                              + 
+--R                                          6 8         5 2 7         4 4 6
+--R                                    - 924a c  + 11060a b c  - 20020a b c
+--R                                  + 
+--R                                          3 6 5        2 8 4
+--R                                    10920a b c  - 1820a b c
+--R                               *
+--R                                   4 12
+--R                                  d e
+--R                              + 
+--R                                           5   8         4 3 7         3 5 6
+--R                                    - 9744a b c  + 30464a b c  - 21840a b c
+--R                                  + 
+--R                                         2 7 5
+--R                                    4368a b c
+--R                               *
+--R                                   5 11
+--R                                  d e
+--R                              + 
+--R                                         5 9         4 2 8         3 4 7
+--R                                    3976a c  - 31248a b c  + 32088a b c
+--R                                  + 
+--R                                           2 6 6
+--R                                    - 8008a b c
+--R                               *
+--R                                   6 10
+--R                                  d e
+--R                              + 
+--R                                       4   9         3 3 8         2 5 7  7 9
+--R                                (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                              + 
+--R                                           4 10         3 2 9         2 4 8
+--R                                    - 6470a c   + 27060a b c  - 12750a b c
+--R                                  + 
+--R                                        6 7
+--R                                    2a b c
+--R                               *
+--R                                   8 8
+--R                                  d e
+--R                              + 
+--R                                         3   10         2 3 9        5 8  9 7
+--R                                (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                              + 
+--R                                      3 11        2 2 10        4 9  10 6
+--R                                (3976a c   - 7224a b c   + 56a b c )d  e
+--R                              + 
+--R                                      2   11         3 10  11 5
+--R                                (3360a b c   - 112a b c  )d  e
+--R                              + 
+--R                                       2 12         2 11  12 4           12 13 3
+--R                                (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                              + 
+--R                                     13 14 2    14 16
+--R                                56a c  d  e  - c  d
+--R                           /
+--R                                 3 15      2 2 14
+--R                              64a c   - 16a b c
+--R                     + 
+--R                            4   3      3 3 2     2 5       7  8
+--R                       (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                     + 
+--R                           4 4      3 2 3      2 4 2       6     7
+--R                       (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                     + 
+--R                            3   4       2 3 3        5 2  2 6
+--R                       (140a b c  - 140a b c  + 28a b c )d e
+--R                     + 
+--R                              3 5       2 2 4        4 3  3 5
+--R                       (- 112a c  + 224a b c  - 56a b c )d e
+--R                     + 
+--R                              2   5        3 4  4 4        2 6        2 5  5 3
+--R                       (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R                     + 
+--R                              6 6 2        7 7       7 8
+--R                       28a b c d e  - 16a c d e + b c d
+--R                  /
+--R                       2 8       2 7
+--R                     8a c  - 2a b c
+--R            + 
+--R                     8 3      7 2 2      6 4      5 6  16
+--R                  (2a c  - 12a b c  + 10a b c - 2a b )e
+--R                + 
+--R                      7   3      6 3 2      5 5      4 7    15
+--R                  (40a b c  - 16a b c  - 24a b c + 8a b )d e
+--R                + 
+--R                        7 4      6 2 3       5 4 2      4 6       3 8  2 14
+--R                  (- 48a c  - 60a b c  + 168a b c  - 12a b c - 12a b )d e
+--R                + 
+--R                       6   4       5 3 3       4 5 2      3 7      2 9  3 13
+--R                  (168a b c  - 392a b c  - 168a b c  + 80a b c + 8a b )d e
+--R                + 
+--R                           6 5       5 2 4       4 4 3       3 6 2      2 8
+--R                      - 72a c  + 468a b c  + 830a b c  - 176a b c  - 78a b c
+--R                    + 
+--R                            10
+--R                      - 2a b
+--R                 *
+--R                     4 12
+--R                    d e
+--R                + 
+--R                           5   5        4 3 4      3 5 3       2 7 2        9
+--R                    (- 408a b c  - 1800a b c  - 24a b c  + 336a b c  + 24a b c)
+--R                 *
+--R                     5 11
+--R                    d e
+--R                + 
+--R                         5 6        4 2 5       3 4 4       2 6 3         8 2  6
+--R                    (176a c  + 2244a b c  + 880a b c  - 836a b c  - 132a b c )d
+--R                 *
+--R                     10
+--R                    e
+--R                + 
+--R                          4   6        3 3 5        2 5 4         7 3  7 9
+--R                  (- 1496a b c  - 1936a b c  + 1320a b c  + 440a b c )d e
+--R                + 
+--R                       4 7        3 2 6        2 4 5         6 4  8 8
+--R                  (396a c  + 1980a b c  - 1386a b c  - 990a b c )d e
+--R                + 
+--R                         3   7        2 3 6          5 5  9 7
+--R                  (- 968a b c  + 1056a b c  + 1584a b c )d e
+--R                + 
+--R                       3 8       2 2 7          4 6  10 6
+--R                  (176a c  - 660a b c  - 1848a b c )d  e
+--R                + 
+--R                       2   8          3 7  11 5
+--R                  (312a b c  + 1560a b c )d  e
+--R                + 
+--R                        2 9         2 8     4 7  12 4            9     3 8  13 3
+--R                  (- 72a c  - 900a b c  + 2b c )d  e  + (312a b c  - 8b c )d  e
+--R                + 
+--R                          10      2 9  14 2       10 15      11 16
+--R                  (- 48a c   + 12b c )d  e  - 8b c  d  e + 2c  d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                     +--------------------+
+--R                   +-----------+     |   +-----------+
+--R             3 +-+ |          2  +-+ |   |          2
+--R            c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                           2 8       2 7
+--R                     (- 16a c  + 4a b c )
+--R                  *
+--R                     ROOT
+--R                                   8 6      7 2 5      6 4 4      5 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     4 8 2      3 10     2 12
+--R                                - 37a b c  + 10a b  c - a b
+--R                           *
+--R                               16
+--R                              e
+--R                          + 
+--R                                     7   6       6 3 5       5 5 4       4 7 3
+--R                                - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                              + 
+--R                                      3 9 2      2 11
+--R                                - 144a b c  + 16a b  c
+--R                           *
+--R                                 15
+--R                              d e
+--R                          + 
+--R                                   7 7        6 2 6        5 4 5        4 6 4
+--R                                56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                              + 
+--R                                    3 8 3       2 10 2
+--R                                960a b c  - 120a b  c
+--R                           *
+--R                               2 14
+--R                              d e
+--R                          + 
+--R                                     6   7        5 3 6        4 5 5
+--R                                1568a b c  - 7280a b c  + 8960a b c
+--R                              + 
+--R                                       3 7 4       2 9 3
+--R                                - 3920a b c  + 560a b c
+--R                           *
+--R                               3 13
+--R                              d e
+--R                          + 
+--R                                      6 8         5 2 7         4 4 6
+--R                                - 924a c  + 11060a b c  - 20020a b c
+--R                              + 
+--R                                      3 6 5        2 8 4
+--R                                10920a b c  - 1820a b c
+--R                           *
+--R                               4 12
+--R                              d e
+--R                          + 
+--R                                       5   8         4 3 7         3 5 6
+--R                                - 9744a b c  + 30464a b c  - 21840a b c
+--R                              + 
+--R                                     2 7 5
+--R                                4368a b c
+--R                           *
+--R                               5 11
+--R                              d e
+--R                          + 
+--R                                       5 9         4 2 8         3 4 7
+--R                                  3976a c  - 31248a b c  + 32088a b c
+--R                                + 
+--R                                         2 6 6
+--R                                  - 8008a b c
+--R                           *
+--R                               6 10
+--R                              d e
+--R                          + 
+--R                                   4   9         3 3 8         2 5 7  7 9
+--R                            (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                          + 
+--R                                         4 10         3 2 9         2 4 8
+--R                                  - 6470a c   + 27060a b c  - 12750a b c
+--R                                + 
+--R                                      6 7
+--R                                  2a b c
+--R                           *
+--R                               8 8
+--R                              d e
+--R                          + 
+--R                                     3   10         2 3 9        5 8  9 7
+--R                            (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                          + 
+--R                                  3 11        2 2 10        4 9  10 6
+--R                            (3976a c   - 7224a b c   + 56a b c )d  e
+--R                          + 
+--R                                  2   11         3 10  11 5
+--R                            (3360a b c   - 112a b c  )d  e
+--R                          + 
+--R                                   2 12         2 11  12 4           12 13 3
+--R                            (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                          + 
+--R                                 13 14 2    14 16
+--R                            56a c  d  e  - c  d
+--R                       /
+--R                             3 15      2 2 14
+--R                          64a c   - 16a b c
+--R                 + 
+--R                        4   3      3 3 2     2 5       7  8
+--R                   (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                 + 
+--R                       4 4      3 2 3      2 4 2       6     7
+--R                   (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                 + 
+--R                        3   4       2 3 3        5 2  2 6
+--R                   (140a b c  - 140a b c  + 28a b c )d e
+--R                 + 
+--R                          3 5       2 2 4        4 3  3 5
+--R                   (- 112a c  + 224a b c  - 56a b c )d e
+--R                 + 
+--R                          2   5        3 4  4 4        2 6        2 5  5 3
+--R                   (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R                 + 
+--R                          6 6 2        7 7       7 8
+--R                   28a b c d e  - 16a c d e + b c d
+--R              /
+--R                   2 8       2 7
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                               4   9      3 3 8     2 5 7  4
+--R                         (- 48a b c  + 28a b c  - 4a b c )e
+--R                       + 
+--R                              4 10      3 2 9      2 4 8    3
+--R                         (128a c   - 96a b c  + 16a b c )d e
+--R                       + 
+--R                             3   10      2 3 9  2 2
+--R                         (96a b c   - 24a b c )d e
+--R                       + 
+--R                                3 11      2 2 10  3        2   11       3 10  4
+--R                         (- 128a c   + 32a b c  )d e + (16a b c   - 4a b c  )d
+--R                    *
+--R                       ROOT
+--R                                     8 6      7 2 5      6 4 4      5 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       4 8 2      3 10     2 12
+--R                                  - 37a b c  + 10a b  c - a b
+--R                             *
+--R                                 16
+--R                                e
+--R                            + 
+--R                                       7   6       6 3 5       5 5 4       4 7 3
+--R                                  - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                                + 
+--R                                        3 9 2      2 11
+--R                                  - 144a b c  + 16a b  c
+--R                             *
+--R                                   15
+--R                                d e
+--R                            + 
+--R                                     7 7        6 2 6        5 4 5        4 6 4
+--R                                  56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                                + 
+--R                                      3 8 3       2 10 2
+--R                                  960a b c  - 120a b  c
+--R                             *
+--R                                 2 14
+--R                                d e
+--R                            + 
+--R                                       6   7        5 3 6        4 5 5
+--R                                  1568a b c  - 7280a b c  + 8960a b c
+--R                                + 
+--R                                         3 7 4       2 9 3
+--R                                  - 3920a b c  + 560a b c
+--R                             *
+--R                                 3 13
+--R                                d e
+--R                            + 
+--R                                        6 8         5 2 7         4 4 6
+--R                                  - 924a c  + 11060a b c  - 20020a b c
+--R                                + 
+--R                                        3 6 5        2 8 4
+--R                                  10920a b c  - 1820a b c
+--R                             *
+--R                                 4 12
+--R                                d e
+--R                            + 
+--R                                         5   8         4 3 7         3 5 6
+--R                                  - 9744a b c  + 30464a b c  - 21840a b c
+--R                                + 
+--R                                       2 7 5
+--R                                  4368a b c
+--R                             *
+--R                                 5 11
+--R                                d e
+--R                            + 
+--R                                       5 9         4 2 8         3 4 7
+--R                                  3976a c  - 31248a b c  + 32088a b c
+--R                                + 
+--R                                         2 6 6
+--R                                  - 8008a b c
+--R                             *
+--R                                 6 10
+--R                                d e
+--R                            + 
+--R                                     4   9         3 3 8         2 5 7  7 9
+--R                              (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                            + 
+--R                                         4 10         3 2 9         2 4 8
+--R                                  - 6470a c   + 27060a b c  - 12750a b c
+--R                                + 
+--R                                      6 7
+--R                                  2a b c
+--R                             *
+--R                                 8 8
+--R                                d e
+--R                            + 
+--R                                       3   10         2 3 9        5 8  9 7
+--R                              (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                            + 
+--R                                    3 11        2 2 10        4 9  10 6
+--R                              (3976a c   - 7224a b c   + 56a b c )d  e
+--R                            + 
+--R                                    2   11         3 10  11 5
+--R                              (3360a b c   - 112a b c  )d  e
+--R                            + 
+--R                                     2 12         2 11  12 4           12 13 3
+--R                              (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                            + 
+--R                                   13 14 2    14 16
+--R                              56a c  d  e  - c  d
+--R                         /
+--R                               3 15      2 2 14
+--R                            64a c   - 16a b c
+--R                   + 
+--R                             7 5      6 2 4      5 4 3      4 6 2      3 8
+--R                         - 4a c  + 29a b c  - 51a b c  + 35a b c  - 10a b c
+--R                       + 
+--R                          2 10
+--R                         a b
+--R                    *
+--R                        12
+--R                       e
+--R                   + 
+--R                                 6   5       5 3 4       4 5 3       3 7 2
+--R                           - 112a b c  + 348a b c  - 320a b c  + 108a b c
+--R                         + 
+--R                                2 9
+--R                           - 12a b c
+--R                    *
+--R                          11
+--R                       d e
+--R                   + 
+--R                               6 6        5 2 5        4 4 4       3 6 3
+--R                           136a c  - 1010a b c  + 1324a b c  - 534a b c
+--R                         + 
+--R                              2 8 2
+--R                           66a b c
+--R                    *
+--R                        2 10
+--R                       d e
+--R                   + 
+--R                           5   6        4 3 5        3 5 4       2 7 3  3 9
+--R                     (1472a b c  - 3152a b c  + 1560a b c  - 216a b c )d e
+--R                   + 
+--R                                 5 7        4 2 6        3 4 5       2 6 4
+--R                           - 956a c  + 4631a b c  - 2966a b c  + 471a b c
+--R                         + 
+--R                                8 3
+--R                           - a b c
+--R                    *
+--R                        4 8
+--R                       d e
+--R                   + 
+--R                             4   7        3 3 6       2 5 5       7 4  5 7
+--R                     (- 4128a b c  + 3848a b c  - 736a b c  + 8a b c )d e
+--R                   + 
+--R                           4 8        3 2 7       2 4 6        6 5  6 6
+--R                     (1904a c  - 3500a b c  + 868a b c  - 28a b c )d e
+--R                   + 
+--R                           3   8       2 3 7        5 6  7 5
+--R                     (2240a b c  - 784a b c  + 56a b c )d e
+--R                   + 
+--R                            3 9       2 2 8        4 7  8 4
+--R                     (- 956a c  + 523a b c  - 71a b c )d e
+--R                   + 
+--R                            2   9        3 8  9 3        2 10        2 9  10 2
+--R                     (- 240a b c  + 60a b c )d e  + (136a c   - 34a b c )d  e
+--R                   + 
+--R                            11    2 10  12
+--R                     (- 4a c   + b c  )d
+--R                *
+--R                   ROOT
+--R                                  2 8       2 7
+--R                            (- 16a c  + 4a b c )
+--R                         *
+--R                            ROOT
+--R                                          8 6      7 2 5      6 4 4      5 6 3
+--R                                       - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                     + 
+--R                                            4 8 2      3 10     2 12
+--R                                       - 37a b c  + 10a b  c - a b
+--R                                  *
+--R                                      16
+--R                                     e
+--R                                 + 
+--R                                            7   6       6 3 5       5 5 4
+--R                                       - 48a b c  + 352a b c  - 640a b c
+--R                                     + 
+--R                                           4 7 3       3 9 2      2 11
+--R                                       464a b c  - 144a b c  + 16a b  c
+--R                                  *
+--R                                        15
+--R                                     d e
+--R                                 + 
+--R                                          7 7        6 2 6        5 4 5
+--R                                       56a c  - 1080a b c  + 2880a b c
+--R                                     + 
+--R                                              4 6 4       3 8 3       2 10 2
+--R                                       - 2640a b c  + 960a b c  - 120a b  c
+--R                                  *
+--R                                      2 14
+--R                                     d e
+--R                                 + 
+--R                                            6   7        5 3 6        4 5 5
+--R                                       1568a b c  - 7280a b c  + 8960a b c
+--R                                     + 
+--R                                              3 7 4       2 9 3
+--R                                       - 3920a b c  + 560a b c
+--R                                  *
+--R                                      3 13
+--R                                     d e
+--R                                 + 
+--R                                             6 8         5 2 7         4 4 6
+--R                                       - 924a c  + 11060a b c  - 20020a b c
+--R                                     + 
+--R                                             3 6 5        2 8 4
+--R                                       10920a b c  - 1820a b c
+--R                                  *
+--R                                      4 12
+--R                                     d e
+--R                                 + 
+--R                                              5   8         4 3 7         3 5 6
+--R                                       - 9744a b c  + 30464a b c  - 21840a b c
+--R                                     + 
+--R                                            2 7 5
+--R                                       4368a b c
+--R                                  *
+--R                                      5 11
+--R                                     d e
+--R                                 + 
+--R                                            5 9         4 2 8         3 4 7
+--R                                       3976a c  - 31248a b c  + 32088a b c
+--R                                     + 
+--R                                              2 6 6
+--R                                       - 8008a b c
+--R                                  *
+--R                                      6 10
+--R                                     d e
+--R                                 + 
+--R                                          4   9         3 3 8         2 5 7  7 9
+--R                                   (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                                 + 
+--R                                              4 10         3 2 9         2 4 8
+--R                                       - 6470a c   + 27060a b c  - 12750a b c
+--R                                     + 
+--R                                           6 7
+--R                                       2a b c
+--R                                  *
+--R                                      8 8
+--R                                     d e
+--R                                 + 
+--R                                            3   10         2 3 9        5 8  9 7
+--R                                   (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                                 + 
+--R                                         3 11        2 2 10        4 9  10 6
+--R                                   (3976a c   - 7224a b c   + 56a b c )d  e
+--R                                 + 
+--R                                         2   11         3 10  11 5
+--R                                   (3360a b c   - 112a b c  )d  e
+--R                                 + 
+--R                                          2 12         2 11  12 4
+--R                                   (- 924a c   + 140a b c  )d  e
+--R                                 + 
+--R                                             12 13 3        13 14 2    14 16
+--R                                   - 112a b c  d  e  + 56a c  d  e  - c  d
+--R                              /
+--R                                    3 15      2 2 14
+--R                                 64a c   - 16a b c
+--R                        + 
+--R                               4   3      3 3 2     2 5       7  8
+--R                          (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                        + 
+--R                              4 4      3 2 3      2 4 2       6     7
+--R                          (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                        + 
+--R                               3   4       2 3 3        5 2  2 6
+--R                          (140a b c  - 140a b c  + 28a b c )d e
+--R                        + 
+--R                                 3 5       2 2 4        4 3  3 5
+--R                          (- 112a c  + 224a b c  - 56a b c )d e
+--R                        + 
+--R                                 2   5        3 4  4 4
+--R                          (- 210a b c  + 70a b c )d e
+--R                        + 
+--R                               2 6        2 5  5 3          6 6 2        7 7
+--R                          (112a c  - 56a b c )d e  + 28a b c d e  - 16a c d e
+--R                        + 
+--R                             7 8
+--R                          b c d
+--R                     /
+--R                          2 8       2 7
+--R                        8a c  - 2a b c
+--R               + 
+--R                        8 3      7 2 2      6 4      5 6  16
+--R                     (2a c  - 12a b c  + 10a b c - 2a b )e
+--R                   + 
+--R                         7   3      6 3 2      5 5      4 7    15
+--R                     (40a b c  - 16a b c  - 24a b c + 8a b )d e
+--R                   + 
+--R                           7 4      6 2 3       5 4 2      4 6       3 8  2 14
+--R                     (- 48a c  - 60a b c  + 168a b c  - 12a b c - 12a b )d e
+--R                   + 
+--R                          6   4       5 3 3       4 5 2      3 7      2 9  3 13
+--R                     (168a b c  - 392a b c  - 168a b c  + 80a b c + 8a b )d e
+--R                   + 
+--R                              6 5       5 2 4       4 4 3       3 6 2      2 8
+--R                         - 72a c  + 468a b c  + 830a b c  - 176a b c  - 78a b c
+--R                       + 
+--R                               10
+--R                         - 2a b
+--R                    *
+--R                        4 12
+--R                       d e
+--R                   + 
+--R                                 5   5        4 3 4      3 5 3       2 7 2
+--R                           - 408a b c  - 1800a b c  - 24a b c  + 336a b c
+--R                         + 
+--R                                9
+--R                           24a b c
+--R                    *
+--R                        5 11
+--R                       d e
+--R                   + 
+--R                               5 6        4 2 5       3 4 4       2 6 3
+--R                           176a c  + 2244a b c  + 880a b c  - 836a b c
+--R                         + 
+--R                                   8 2
+--R                           - 132a b c
+--R                    *
+--R                        6 10
+--R                       d e
+--R                   + 
+--R                             4   6        3 3 5        2 5 4         7 3  7 9
+--R                     (- 1496a b c  - 1936a b c  + 1320a b c  + 440a b c )d e
+--R                   + 
+--R                          4 7        3 2 6        2 4 5         6 4  8 8
+--R                     (396a c  + 1980a b c  - 1386a b c  - 990a b c )d e
+--R                   + 
+--R                            3   7        2 3 6          5 5  9 7
+--R                     (- 968a b c  + 1056a b c  + 1584a b c )d e
+--R                   + 
+--R                          3 8       2 2 7          4 6  10 6
+--R                     (176a c  - 660a b c  - 1848a b c )d  e
+--R                   + 
+--R                          2   8          3 7  11 5
+--R                     (312a b c  + 1560a b c )d  e
+--R                   + 
+--R                           2 9         2 8     4 7  12 4
+--R                     (- 72a c  - 900a b c  + 2b c )d  e
+--R                   + 
+--R                              9     3 8  13 3           10      2 9  14 2
+--R                     (312a b c  - 8b c )d  e  + (- 48a c   + 12b c )d  e
+--R                   + 
+--R                           10 15      11 16
+--R                     - 8b c  d  e + 2c  d
+--R                *
+--R                   x
+--R     + 
+--R                                  +--------------------+
+--R                +-----------+     |   +-----------+
+--R          3 +-+ |          2  +-+ |   |          2
+--R         c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                      2 8       2 7
+--R                  (16a c  - 4a b c )
+--R               *
+--R                  ROOT
+--R                                8 6      7 2 5      6 4 4      5 6 3      4 8 2
+--R                             - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                           + 
+--R                                3 10     2 12
+--R                             10a b  c - a b
+--R                        *
+--R                            16
+--R                           e
+--R                       + 
+--R                                  7   6       6 3 5       5 5 4       4 7 3
+--R                             - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                           + 
+--R                                   3 9 2      2 11
+--R                             - 144a b c  + 16a b  c
+--R                        *
+--R                              15
+--R                           d e
+--R                       + 
+--R                                7 7        6 2 6        5 4 5        4 6 4
+--R                             56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                           + 
+--R                                 3 8 3       2 10 2
+--R                             960a b c  - 120a b  c
+--R                        *
+--R                            2 14
+--R                           d e
+--R                       + 
+--R                                  6   7        5 3 6        4 5 5        3 7 4
+--R                             1568a b c  - 7280a b c  + 8960a b c  - 3920a b c
+--R                           + 
+--R                                 2 9 3
+--R                             560a b c
+--R                        *
+--R                            3 13
+--R                           d e
+--R                       + 
+--R                                   6 8         5 2 7         4 4 6         3 6 5
+--R                             - 924a c  + 11060a b c  - 20020a b c  + 10920a b c
+--R                           + 
+--R                                    2 8 4
+--R                             - 1820a b c
+--R                        *
+--R                            4 12
+--R                           d e
+--R                       + 
+--R                                      5   8         4 3 7         3 5 6
+--R                               - 9744a b c  + 30464a b c  - 21840a b c
+--R                             + 
+--R                                    2 7 5
+--R                               4368a b c
+--R                        *
+--R                            5 11
+--R                           d e
+--R                       + 
+--R                                 5 9         4 2 8         3 4 7        2 6 6  6
+--R                           (3976a c  - 31248a b c  + 32088a b c  - 8008a b c )d
+--R                        *
+--R                            10
+--R                           e
+--R                       + 
+--R                                4   9         3 3 8         2 5 7  7 9
+--R                         (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                       + 
+--R                                 4 10         3 2 9         2 4 8       6 7  8 8
+--R                         (- 6470a c   + 27060a b c  - 12750a b c  + 2a b c )d e
+--R                       + 
+--R                                  3   10         2 3 9        5 8  9 7
+--R                         (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                       + 
+--R                               3 11        2 2 10        4 9  10 6
+--R                         (3976a c   - 7224a b c   + 56a b c )d  e
+--R                       + 
+--R                               2   11         3 10  11 5
+--R                         (3360a b c   - 112a b c  )d  e
+--R                       + 
+--R                                2 12         2 11  12 4           12 13 3
+--R                         (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                       + 
+--R                              13 14 2    14 16
+--R                         56a c  d  e  - c  d
+--R                    /
+--R                          3 15      2 2 14
+--R                       64a c   - 16a b c
+--R              + 
+--R                     4   3      3 3 2     2 5       7  8
+--R                (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R              + 
+--R                    4 4      3 2 3      2 4 2       6     7
+--R                (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R              + 
+--R                     3   4       2 3 3        5 2  2 6
+--R                (140a b c  - 140a b c  + 28a b c )d e
+--R              + 
+--R                       3 5       2 2 4        4 3  3 5
+--R                (- 112a c  + 224a b c  - 56a b c )d e
+--R              + 
+--R                       2   5        3 4  4 4        2 6        2 5  5 3
+--R                (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R              + 
+--R                       6 6 2        7 7       7 8
+--R                28a b c d e  - 16a c d e + b c d
+--R           /
+--R                2 8       2 7
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            4   9      3 3 8     2 5 7  4
+--R                      (- 48a b c  + 28a b c  - 4a b c )e
+--R                    + 
+--R                           4 10      3 2 9      2 4 8    3
+--R                      (128a c   - 96a b c  + 16a b c )d e
+--R                    + 
+--R                          3   10      2 3 9  2 2          3 11      2 2 10  3
+--R                      (96a b c   - 24a b c )d e  + (- 128a c   + 32a b c  )d e
+--R                    + 
+--R                          2   11       3 10  4
+--R                      (16a b c   - 4a b c  )d
+--R                 *
+--R                    ROOT
+--R                                  8 6      7 2 5      6 4 4      5 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    4 8 2      3 10     2 12
+--R                               - 37a b c  + 10a b  c - a b
+--R                          *
+--R                              16
+--R                             e
+--R                         + 
+--R                                    7   6       6 3 5       5 5 4       4 7 3
+--R                               - 48a b c  + 352a b c  - 640a b c  + 464a b c
+--R                             + 
+--R                                     3 9 2      2 11
+--R                               - 144a b c  + 16a b  c
+--R                          *
+--R                                15
+--R                             d e
+--R                         + 
+--R                                  7 7        6 2 6        5 4 5        4 6 4
+--R                               56a c  - 1080a b c  + 2880a b c  - 2640a b c
+--R                             + 
+--R                                   3 8 3       2 10 2
+--R                               960a b c  - 120a b  c
+--R                          *
+--R                              2 14
+--R                             d e
+--R                         + 
+--R                                    6   7        5 3 6        4 5 5        3 7 4
+--R                               1568a b c  - 7280a b c  + 8960a b c  - 3920a b c
+--R                             + 
+--R                                   2 9 3
+--R                               560a b c
+--R                          *
+--R                              3 13
+--R                             d e
+--R                         + 
+--R                                     6 8         5 2 7         4 4 6
+--R                               - 924a c  + 11060a b c  - 20020a b c
+--R                             + 
+--R                                     3 6 5        2 8 4
+--R                               10920a b c  - 1820a b c
+--R                          *
+--R                              4 12
+--R                             d e
+--R                         + 
+--R                                      5   8         4 3 7         3 5 6
+--R                               - 9744a b c  + 30464a b c  - 21840a b c
+--R                             + 
+--R                                    2 7 5
+--R                               4368a b c
+--R                          *
+--R                              5 11
+--R                             d e
+--R                         + 
+--R                                   5 9         4 2 8         3 4 7        2 6 6
+--R                             (3976a c  - 31248a b c  + 32088a b c  - 8008a b c )
+--R                          *
+--R                              6 10
+--R                             d e
+--R                         + 
+--R                                  4   9         3 3 8         2 5 7  7 9
+--R                           (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                         + 
+--R                                     4 10         3 2 9         2 4 8       6 7
+--R                             (- 6470a c   + 27060a b c  - 12750a b c  + 2a b c )
+--R                          *
+--R                              8 8
+--R                             d e
+--R                         + 
+--R                                    3   10         2 3 9        5 8  9 7
+--R                           (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                         + 
+--R                                 3 11        2 2 10        4 9  10 6
+--R                           (3976a c   - 7224a b c   + 56a b c )d  e
+--R                         + 
+--R                                 2   11         3 10  11 5
+--R                           (3360a b c   - 112a b c  )d  e
+--R                         + 
+--R                                  2 12         2 11  12 4           12 13 3
+--R                           (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                         + 
+--R                                13 14 2    14 16
+--R                           56a c  d  e  - c  d
+--R                      /
+--R                            3 15      2 2 14
+--R                         64a c   - 16a b c
+--R                + 
+--R                     7 5      6 2 4      5 4 3      4 6 2      3 8     2 10  12
+--R                  (4a c  - 29a b c  + 51a b c  - 35a b c  + 10a b c - a b  )e
+--R                + 
+--R                       6   5       5 3 4       4 5 3       3 7 2      2 9     11
+--R                  (112a b c  - 348a b c  + 320a b c  - 108a b c  + 12a b c)d e
+--R                + 
+--R                           6 6        5 2 5        4 4 4       3 6 3      2 8 2
+--R                    (- 136a c  + 1010a b c  - 1324a b c  + 534a b c  - 66a b c )
+--R                 *
+--R                     2 10
+--R                    d e
+--R                + 
+--R                          5   6        4 3 5        3 5 4       2 7 3  3 9
+--R                  (- 1472a b c  + 3152a b c  - 1560a b c  + 216a b c )d e
+--R                + 
+--R                       5 7        4 2 6        3 4 5       2 6 4      8 3  4 8
+--R                  (956a c  - 4631a b c  + 2966a b c  - 471a b c  + a b c )d e
+--R                + 
+--R                        4   7        3 3 6       2 5 5       7 4  5 7
+--R                  (4128a b c  - 3848a b c  + 736a b c  - 8a b c )d e
+--R                + 
+--R                          4 8        3 2 7       2 4 6        6 5  6 6
+--R                  (- 1904a c  + 3500a b c  - 868a b c  + 28a b c )d e
+--R                + 
+--R                          3   8       2 3 7        5 6  7 5
+--R                  (- 2240a b c  + 784a b c  - 56a b c )d e
+--R                + 
+--R                       3 9       2 2 8        4 7  8 4
+--R                  (956a c  - 523a b c  + 71a b c )d e
+--R                + 
+--R                       2   9        3 8  9 3          2 10        2 9  10 2
+--R                  (240a b c  - 60a b c )d e  + (- 136a c   + 34a b c )d  e
+--R                + 
+--R                       11    2 10  12
+--R                  (4a c   - b c  )d
+--R             *
+--R                ROOT
+--R                             2 8       2 7
+--R                         (16a c  - 4a b c )
+--R                      *
+--R                         ROOT
+--R                                       8 6      7 2 5      6 4 4      5 6 3
+--R                                    - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                  + 
+--R                                         4 8 2      3 10     2 12
+--R                                    - 37a b c  + 10a b  c - a b
+--R                               *
+--R                                   16
+--R                                  e
+--R                              + 
+--R                                         7   6       6 3 5       5 5 4
+--R                                    - 48a b c  + 352a b c  - 640a b c
+--R                                  + 
+--R                                        4 7 3       3 9 2      2 11
+--R                                    464a b c  - 144a b c  + 16a b  c
+--R                               *
+--R                                     15
+--R                                  d e
+--R                              + 
+--R                                       7 7        6 2 6        5 4 5
+--R                                    56a c  - 1080a b c  + 2880a b c
+--R                                  + 
+--R                                           4 6 4       3 8 3       2 10 2
+--R                                    - 2640a b c  + 960a b c  - 120a b  c
+--R                               *
+--R                                   2 14
+--R                                  d e
+--R                              + 
+--R                                         6   7        5 3 6        4 5 5
+--R                                    1568a b c  - 7280a b c  + 8960a b c
+--R                                  + 
+--R                                           3 7 4       2 9 3
+--R                                    - 3920a b c  + 560a b c
+--R                               *
+--R                                   3 13
+--R                                  d e
+--R                              + 
+--R                                          6 8         5 2 7         4 4 6
+--R                                    - 924a c  + 11060a b c  - 20020a b c
+--R                                  + 
+--R                                          3 6 5        2 8 4
+--R                                    10920a b c  - 1820a b c
+--R                               *
+--R                                   4 12
+--R                                  d e
+--R                              + 
+--R                                           5   8         4 3 7         3 5 6
+--R                                    - 9744a b c  + 30464a b c  - 21840a b c
+--R                                  + 
+--R                                         2 7 5
+--R                                    4368a b c
+--R                               *
+--R                                   5 11
+--R                                  d e
+--R                              + 
+--R                                         5 9         4 2 8         3 4 7
+--R                                    3976a c  - 31248a b c  + 32088a b c
+--R                                  + 
+--R                                           2 6 6
+--R                                    - 8008a b c
+--R                               *
+--R                                   6 10
+--R                                  d e
+--R                              + 
+--R                                       4   9         3 3 8         2 5 7  7 9
+--R                                (20160a b c  - 34720a b c  + 11424a b c )d e
+--R                              + 
+--R                                           4 10         3 2 9         2 4 8
+--R                                    - 6470a c   + 27060a b c  - 12750a b c
+--R                                  + 
+--R                                        6 7
+--R                                    2a b c
+--R                               *
+--R                                   8 8
+--R                                  d e
+--R                              + 
+--R                                         3   10         2 3 9        5 8  9 7
+--R                                (- 14160a b c   + 11040a b c  - 16a b c )d e
+--R                              + 
+--R                                      3 11        2 2 10        4 9  10 6
+--R                                (3976a c   - 7224a b c   + 56a b c )d  e
+--R                              + 
+--R                                      2   11         3 10  11 5
+--R                                (3360a b c   - 112a b c  )d  e
+--R                              + 
+--R                                       2 12         2 11  12 4           12 13 3
+--R                                (- 924a c   + 140a b c  )d  e  - 112a b c  d  e
+--R                              + 
+--R                                     13 14 2    14 16
+--R                                56a c  d  e  - c  d
+--R                           /
+--R                                 3 15      2 2 14
+--R                              64a c   - 16a b c
+--R                     + 
+--R                            4   3      3 3 2     2 5       7  8
+--R                       (- 7a b c  + 14a b c  - 7a b c + a b )e
+--R                     + 
+--R                           4 4      3 2 3      2 4 2       6     7
+--R                       (16a c  - 72a b c  + 48a b c  - 8a b c)d e
+--R                     + 
+--R                            3   4       2 3 3        5 2  2 6
+--R                       (140a b c  - 140a b c  + 28a b c )d e
+--R                     + 
+--R                              3 5       2 2 4        4 3  3 5
+--R                       (- 112a c  + 224a b c  - 56a b c )d e
+--R                     + 
+--R                              2   5        3 4  4 4        2 6        2 5  5 3
+--R                       (- 210a b c  + 70a b c )d e  + (112a c  - 56a b c )d e
+--R                     + 
+--R                              6 6 2        7 7       7 8
+--R                       28a b c d e  - 16a c d e + b c d
+--R                  /
+--R                       2 8       2 7
+--R                     8a c  - 2a b c
+--R            + 
+--R                     8 3      7 2 2      6 4      5 6  16
+--R                  (2a c  - 12a b c  + 10a b c - 2a b )e
+--R                + 
+--R                      7   3      6 3 2      5 5      4 7    15
+--R                  (40a b c  - 16a b c  - 24a b c + 8a b )d e
+--R                + 
+--R                        7 4      6 2 3       5 4 2      4 6       3 8  2 14
+--R                  (- 48a c  - 60a b c  + 168a b c  - 12a b c - 12a b )d e
+--R                + 
+--R                       6   4       5 3 3       4 5 2      3 7      2 9  3 13
+--R                  (168a b c  - 392a b c  - 168a b c  + 80a b c + 8a b )d e
+--R                + 
+--R                           6 5       5 2 4       4 4 3       3 6 2      2 8
+--R                      - 72a c  + 468a b c  + 830a b c  - 176a b c  - 78a b c
+--R                    + 
+--R                            10
+--R                      - 2a b
+--R                 *
+--R                     4 12
+--R                    d e
+--R                + 
+--R                           5   5        4 3 4      3 5 3       2 7 2        9
+--R                    (- 408a b c  - 1800a b c  - 24a b c  + 336a b c  + 24a b c)
+--R                 *
+--R                     5 11
+--R                    d e
+--R                + 
+--R                         5 6        4 2 5       3 4 4       2 6 3         8 2  6
+--R                    (176a c  + 2244a b c  + 880a b c  - 836a b c  - 132a b c )d
+--R                 *
+--R                     10
+--R                    e
+--R                + 
+--R                          4   6        3 3 5        2 5 4         7 3  7 9
+--R                  (- 1496a b c  - 1936a b c  + 1320a b c  + 440a b c )d e
+--R                + 
+--R                       4 7        3 2 6        2 4 5         6 4  8 8
+--R                  (396a c  + 1980a b c  - 1386a b c  - 990a b c )d e
+--R                + 
+--R                         3   7        2 3 6          5 5  9 7
+--R                  (- 968a b c  + 1056a b c  + 1584a b c )d e
+--R                + 
+--R                       3 8       2 2 7          4 6  10 6
+--R                  (176a c  - 660a b c  - 1848a b c )d  e
+--R                + 
+--R                       2   8          3 7  11 5
+--R                  (312a b c  + 1560a b c )d  e
+--R                + 
+--R                        2 9         2 8     4 7  12 4            9     3 8  13 3
+--R                  (- 72a c  - 900a b c  + 2b c )d  e  + (312a b c  - 8b c )d  e
+--R                + 
+--R                          10      2 9  14 2       10 15      11 16
+--R                  (- 48a c   + 12b c )d  e  - 8b c  d  e + 2c  d
+--R             *
+--R                x
+--R     + 
+--R                            3  4        2     2     3        2 2 2     3 3
+--R             ((- 4a b c + 2b )e  + (8a c  - 8b c)d e  + 12b c d e  - 8c d e)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 2       2      4  4             2     3     3
+--R           (- 4a c  + 8a b c - 2b )e  + (- 24a b c  + 8b c)d e
+--R         + 
+--R                 3      2 2  2 2       3 3      4 4
+--R           (24a c  - 12b c )d e  + 8b c d e - 4c d
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                            3  4        2     2     3        2 2 2     3 3
+--R             ((- 4a b c + 2b )e  + (8a c  - 8b c)d e  + 12b c d e  - 8c d e)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R              2 2       2      4  4           2     3     3
+--R           (4a c  - 8a b c + 2b )e  + (24a b c  - 8b c)d e
+--R         + 
+--R                   3      2 2  2 2       3 3      4 4
+--R           (- 24a c  + 12b c )d e  - 8b c d e + 4c d
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       3 +-+ |          2  +-+ |   |          2       | |          2
+--R     2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2801
+
+--S 2802 of 3139
+--d0:=D(m0,x)
+--E 2802
+
+)clear all
+
+--S 2803 of 3139
+t0:=(d+e*x^2)^3/(a+b*x^2+c*x^4)
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        e x  + 3d e x  + 3d e x  + d
+--R   (1)  -----------------------------
+--R                  4      2
+--R               c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2803
+
+--S 2804 of 3139
+r0:=e^2*(3*c*d-b*e)*x/c^2+1/3*e^3*x^3/c+atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*(e*(3*c^2*d^2+b^2*e^2-c*e*(3*b*d+a*e))+(2*c*d-b*e)*_
+   (c^2*d^2+b^2*e^2-c*e*(b*d+3*a*e))/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (e*(3*c^2*d^2+b^2*e^2-c*e*(3*b*d+a*e))-(2*c*d-b*e)*(c^2*d^2+b^2*e^2-_
+   c*e*(b*d+3*a*e))/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                   +-----------+
+--R                        2  3           2     2 2   |          2
+--R           ((- 3a c + 3b )e  - 9b c d e  + 9c d e)\|- 4a c + b
+--R         + 
+--R                       3  3           2     2     2       2 2      3 3
+--R           (9a b c - 3b )e  + (- 18a c  + 9b c)d e  - 9b c d e + 6c d
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                                   +-----------+
+--R                        2  3           2     2 2   |          2
+--R           ((- 3a c + 3b )e  - 9b c d e  + 9c d e)\|- 4a c + b
+--R         + 
+--R                         3  3         2     2     2       2 2      3 3
+--R           (- 9a b c + 3b )e  + (18a c  - 9b c)d e  + 9b c d e - 6c d
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                             +-----------+
+--R             3 3          3         2    +-+ |          2  +-+
+--R         (c e x  + (- 3b e  + 9c d e )x)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     3c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2804
+
+--S 2805 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R              2
+--R            3c
+--R         *
+--R            ROOT
+--R                         2 6       2 5
+--R                     (16a c  - 4a b c )
+--R                  *
+--R                     ROOT
+--R                                6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                            (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                          + 
+--R                                  5   4      4 3 3      3 5 2      2 7     11
+--R                            (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                          + 
+--R                                5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                            (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                          + 
+--R                                 4   5       3 3 4       2 5 3  3 9
+--R                            (400a b c  - 660a b c  + 220a b c )d e
+--R                          + 
+--R                                   4 6        3 2 5       2 4 4  4 8
+--R                            (- 255a c  + 1020a b c  - 495a b c )d e
+--R                          + 
+--R                                   3   6       2 3 5  5 7
+--R                            (- 960a b c  + 780a b c )d e
+--R                          + 
+--R                                 3 7       2 2 6       4 5  6 6
+--R                            (452a c  - 856a b c  + 2a b c )d e
+--R                          + 
+--R                                 2   7        3 6  7 5
+--R                            (624a b c  - 12a b c )d e
+--R                          + 
+--R                                   2 8        2 7  8 4          8 9 3
+--R                            (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                          + 
+--R                                 9 10 2    10 12
+--R                            30a c d  e  - c  d
+--R                       /
+--R                             3 11      2 2 10
+--R                          64a c   - 16a b c
+--R                 + 
+--R                      3   2     2 3       5  6
+--R                   (5a b c  - 5a b c + a b )e
+--R                 + 
+--R                         3 3      2 2 2       4     5
+--R                   (- 12a c  + 24a b c  - 6a b c)d e
+--R                 + 
+--R                         2   3        3 2  2 4       2 4        2 3  3 3
+--R                   (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                 + 
+--R                          4 4 2        5 5       5 6
+--R                   15a b c d e  - 12a c d e + b c d
+--R              /
+--R                   2 6       2 5
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                             4 7      3 2 6     2 4 5  3
+--R                         (32a c  - 24a b c  + 4a b c )e
+--R                       + 
+--R                             3   7      2 3 6    2         3 8      2 2 7  2
+--R                         (48a b c  - 12a b c )d e  + (- 96a c  + 24a b c )d e
+--R                       + 
+--R                             2   8       3 7  3
+--R                         (16a b c  - 4a b c )d
+--R                    *
+--R                       ROOT
+--R                                  6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                            + 
+--R                                    5   4      4 3 3      3 5 2      2 7     11
+--R                              (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                            + 
+--R                                  5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                              (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                            + 
+--R                                   4   5       3 3 4       2 5 3  3 9
+--R                              (400a b c  - 660a b c  + 220a b c )d e
+--R                            + 
+--R                                     4 6        3 2 5       2 4 4  4 8
+--R                              (- 255a c  + 1020a b c  - 495a b c )d e
+--R                            + 
+--R                                     3   6       2 3 5  5 7
+--R                              (- 960a b c  + 780a b c )d e
+--R                            + 
+--R                                   3 7       2 2 6       4 5  6 6
+--R                              (452a c  - 856a b c  + 2a b c )d e
+--R                            + 
+--R                                   2   7        3 6  7 5
+--R                              (624a b c  - 12a b c )d e
+--R                            + 
+--R                                     2 8        2 7  8 4          8 9 3
+--R                              (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                            + 
+--R                                   9 10 2    10 12
+--R                              30a c d  e  - c  d
+--R                         /
+--R                               3 11      2 2 10
+--R                            64a c   - 16a b c
+--R                   + 
+--R                          5   3      4 3 2     3 5     2 7  9
+--R                     (- 4a b c  + 13a b c  - 7a b c + a b )e
+--R                   + 
+--R                         5 4      4 2 3      3 4 2     2 6     8
+--R                     (12a c  - 87a b c  + 57a b c  - 9a b c)d e
+--R                   + 
+--R                          4   4       3 3 3      2 5 2  2 7
+--R                     (204a b c  - 183a b c  + 33a b c )d e
+--R                   + 
+--R                            4 5       3 2 4      2 4 3      6 2  3 6
+--R                     (- 184a c  + 318a b c  - 72a b c  + a b c )d e
+--R                   + 
+--R                            3   5       2 3 4       5 3  4 5
+--R                     (- 348a b c  + 111a b c  - 6a b c )d e
+--R                   + 
+--R                          3 6       2 2 5        4 4  5 4
+--R                     (240a c  - 120a b c  + 15a b c )d e
+--R                   + 
+--R                         2   6        3 5  6 3         2 7        2 6  7 2
+--R                     (84a b c  - 21a b c )d e  + (- 72a c  + 18a b c )d e
+--R                   + 
+--R                          8    2 7  9
+--R                     (4a c  - b c )d
+--R                *
+--R                   ROOT
+--R                                2 6       2 5
+--R                            (16a c  - 4a b c )
+--R                         *
+--R                            ROOT
+--R                                            6 4     5 2 3      4 4 2     3 6
+--R                                         - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                       + 
+--R                                            2 8
+--R                                         - a b
+--R                                  *
+--R                                      12
+--R                                     e
+--R                                 + 
+--R                                              5   4      4 3 3      3 5 2
+--R                                         - 24a b c  + 84a b c  - 60a b c
+--R                                       + 
+--R                                            2 7
+--R                                         12a b c
+--R                                  *
+--R                                        11
+--R                                     d e
+--R                                 + 
+--R                                         5 5       4 2 4       3 4 3      2 6 2
+--R                                     (30a c  - 264a b c  + 264a b c  - 66a b c )
+--R                                  *
+--R                                      2 10
+--R                                     d e
+--R                                 + 
+--R                                        4   5       3 3 4       2 5 3  3 9
+--R                                   (400a b c  - 660a b c  + 220a b c )d e
+--R                                 + 
+--R                                          4 6        3 2 5       2 4 4  4 8
+--R                                   (- 255a c  + 1020a b c  - 495a b c )d e
+--R                                 + 
+--R                                          3   6       2 3 5  5 7
+--R                                   (- 960a b c  + 780a b c )d e
+--R                                 + 
+--R                                        3 7       2 2 6       4 5  6 6
+--R                                   (452a c  - 856a b c  + 2a b c )d e
+--R                                 + 
+--R                                        2   7        3 6  7 5
+--R                                   (624a b c  - 12a b c )d e
+--R                                 + 
+--R                                          2 8        2 7  8 4          8 9 3
+--R                                   (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                                 + 
+--R                                        9 10 2    10 12
+--R                                   30a c d  e  - c  d
+--R                              /
+--R                                    3 11      2 2 10
+--R                                 64a c   - 16a b c
+--R                        + 
+--R                             3   2     2 3       5  6
+--R                          (5a b c  - 5a b c + a b )e
+--R                        + 
+--R                                3 3      2 2 2       4     5
+--R                          (- 12a c  + 24a b c  - 6a b c)d e
+--R                        + 
+--R                                2   3        3 2  2 4       2 4        2 3  3 3
+--R                          (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                        + 
+--R                                 4 4 2        5 5       5 6
+--R                          15a b c d e  - 12a c d e + b c d
+--R                     /
+--R                          2 6       2 5
+--R                        8a c  - 2a b c
+--R               + 
+--R                        6 2     5 2      4 4  12
+--R                     (2a c  - 6a b c + 2a b )e
+--R                   + 
+--R                         5   2     4 3      3 5    11
+--R                     (18a b c  + 6a b c - 6a b )d e
+--R                   + 
+--R                           5 3      4 2 2      3 4      2 6  2 10
+--R                     (- 24a c  - 54a b c  + 24a b c + 6a b )d e
+--R                   + 
+--R                          4   3      3 3 2      2 5        7  3 9
+--R                     (110a b c  - 20a b c  - 42a b c - 2a b )d e
+--R                   + 
+--R                           4 4      3 2 3       2 4 2        6   4 8
+--R                     (- 54a c  - 36a b c  + 126a b c  + 18a b c)d e
+--R                   + 
+--R                         3   4       2 3 3        5 2  5 7
+--R                     (36a b c  - 216a b c  - 72a b c )d e
+--R                   + 
+--R                          2 2 4         4 3  6 6          2   5         3 4  7 5
+--R                     (252a b c  + 168a b c )d e  + (- 180a b c  - 252a b c )d e
+--R                   + 
+--R                         2 6         2 5  8 4              6     3 5  9 3
+--R                     (54a c  + 234a b c )d e  + (- 118a b c  + 2b c )d e
+--R                   + 
+--R                           7     2 6  10 2       7 11      8 12
+--R                     (24a c  - 6b c )d  e  + 6b c d  e - 2c d
+--R                *
+--R                   x
+--R     + 
+--R           2
+--R         3c
+--R      *
+--R         ROOT
+--R                        2 6       2 5
+--R                  (- 16a c  + 4a b c )
+--R               *
+--R                  ROOT
+--R                             6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                       + 
+--R                               5   4      4 3 3      3 5 2      2 7     11
+--R                         (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                       + 
+--R                             5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                         (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                       + 
+--R                              4   5       3 3 4       2 5 3  3 9
+--R                         (400a b c  - 660a b c  + 220a b c )d e
+--R                       + 
+--R                                4 6        3 2 5       2 4 4  4 8
+--R                         (- 255a c  + 1020a b c  - 495a b c )d e
+--R                       + 
+--R                                3   6       2 3 5  5 7
+--R                         (- 960a b c  + 780a b c )d e
+--R                       + 
+--R                              3 7       2 2 6       4 5  6 6
+--R                         (452a c  - 856a b c  + 2a b c )d e
+--R                       + 
+--R                              2   7        3 6  7 5          2 8        2 7  8 4
+--R                         (624a b c  - 12a b c )d e  + (- 255a c  + 30a b c )d e
+--R                       + 
+--R                                  8 9 3        9 10 2    10 12
+--R                         - 40a b c d e  + 30a c d  e  - c  d
+--R                    /
+--R                          3 11      2 2 10
+--R                       64a c   - 16a b c
+--R              + 
+--R                   3   2     2 3       5  6         3 3      2 2 2       4     5
+--R                (5a b c  - 5a b c + a b )e  + (- 12a c  + 24a b c  - 6a b c)d e
+--R              + 
+--R                      2   3        3 2  2 4       2 4        2 3  3 3
+--R                (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R              + 
+--R                       4 4 2        5 5       5 6
+--R                15a b c d e  - 12a c d e + b c d
+--R           /
+--R                2 6       2 5
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                          4 7      3 2 6     2 4 5  3
+--R                      (32a c  - 24a b c  + 4a b c )e
+--R                    + 
+--R                          3   7      2 3 6    2         3 8      2 2 7  2
+--R                      (48a b c  - 12a b c )d e  + (- 96a c  + 24a b c )d e
+--R                    + 
+--R                          2   8       3 7  3
+--R                      (16a b c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                         + 
+--R                                 5   4      4 3 3      3 5 2      2 7     11
+--R                           (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                         + 
+--R                               5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                           (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                         + 
+--R                                4   5       3 3 4       2 5 3  3 9
+--R                           (400a b c  - 660a b c  + 220a b c )d e
+--R                         + 
+--R                                  4 6        3 2 5       2 4 4  4 8
+--R                           (- 255a c  + 1020a b c  - 495a b c )d e
+--R                         + 
+--R                                  3   6       2 3 5  5 7
+--R                           (- 960a b c  + 780a b c )d e
+--R                         + 
+--R                                3 7       2 2 6       4 5  6 6
+--R                           (452a c  - 856a b c  + 2a b c )d e
+--R                         + 
+--R                                2   7        3 6  7 5
+--R                           (624a b c  - 12a b c )d e
+--R                         + 
+--R                                  2 8        2 7  8 4          8 9 3
+--R                           (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                         + 
+--R                                9 10 2    10 12
+--R                           30a c d  e  - c  d
+--R                      /
+--R                            3 11      2 2 10
+--R                         64a c   - 16a b c
+--R                + 
+--R                     5   3      4 3 2     3 5     2 7  9
+--R                  (4a b c  - 13a b c  + 7a b c - a b )e
+--R                + 
+--R                        5 4      4 2 3      3 4 2     2 6     8
+--R                  (- 12a c  + 87a b c  - 57a b c  + 9a b c)d e
+--R                + 
+--R                         4   4       3 3 3      2 5 2  2 7
+--R                  (- 204a b c  + 183a b c  - 33a b c )d e
+--R                + 
+--R                       4 5       3 2 4      2 4 3      6 2  3 6
+--R                  (184a c  - 318a b c  + 72a b c  - a b c )d e
+--R                + 
+--R                       3   5       2 3 4       5 3  4 5
+--R                  (348a b c  - 111a b c  + 6a b c )d e
+--R                + 
+--R                         3 6       2 2 5        4 4  5 4
+--R                  (- 240a c  + 120a b c  - 15a b c )d e
+--R                + 
+--R                        2   6        3 5  6 3       2 7        2 6  7 2
+--R                  (- 84a b c  + 21a b c )d e  + (72a c  - 18a b c )d e
+--R                + 
+--R                         8    2 7  9
+--R                  (- 4a c  + b c )d
+--R             *
+--R                ROOT
+--R                               2 6       2 5
+--R                         (- 16a c  + 4a b c )
+--R                      *
+--R                         ROOT
+--R                                    6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                              + 
+--R                                        5   4      4 3 3      3 5 2      2 7
+--R                                  (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d
+--R                               *
+--R                                   11
+--R                                  e
+--R                              + 
+--R                                    5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                                (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                              + 
+--R                                     4   5       3 3 4       2 5 3  3 9
+--R                                (400a b c  - 660a b c  + 220a b c )d e
+--R                              + 
+--R                                       4 6        3 2 5       2 4 4  4 8
+--R                                (- 255a c  + 1020a b c  - 495a b c )d e
+--R                              + 
+--R                                       3   6       2 3 5  5 7
+--R                                (- 960a b c  + 780a b c )d e
+--R                              + 
+--R                                     3 7       2 2 6       4 5  6 6
+--R                                (452a c  - 856a b c  + 2a b c )d e
+--R                              + 
+--R                                     2   7        3 6  7 5
+--R                                (624a b c  - 12a b c )d e
+--R                              + 
+--R                                       2 8        2 7  8 4          8 9 3
+--R                                (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                              + 
+--R                                     9 10 2    10 12
+--R                                30a c d  e  - c  d
+--R                           /
+--R                                 3 11      2 2 10
+--R                              64a c   - 16a b c
+--R                     + 
+--R                          3   2     2 3       5  6
+--R                       (5a b c  - 5a b c + a b )e
+--R                     + 
+--R                             3 3      2 2 2       4     5
+--R                       (- 12a c  + 24a b c  - 6a b c)d e
+--R                     + 
+--R                             2   3        3 2  2 4       2 4        2 3  3 3
+--R                       (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                     + 
+--R                              4 4 2        5 5       5 6
+--R                       15a b c d e  - 12a c d e + b c d
+--R                  /
+--R                       2 6       2 5
+--R                     8a c  - 2a b c
+--R            + 
+--R                     6 2     5 2      4 4  12       5   2     4 3      3 5    11
+--R                  (2a c  - 6a b c + 2a b )e   + (18a b c  + 6a b c - 6a b )d e
+--R                + 
+--R                        5 3      4 2 2      3 4      2 6  2 10
+--R                  (- 24a c  - 54a b c  + 24a b c + 6a b )d e
+--R                + 
+--R                       4   3      3 3 2      2 5        7  3 9
+--R                  (110a b c  - 20a b c  - 42a b c - 2a b )d e
+--R                + 
+--R                        4 4      3 2 3       2 4 2        6   4 8
+--R                  (- 54a c  - 36a b c  + 126a b c  + 18a b c)d e
+--R                + 
+--R                      3   4       2 3 3        5 2  5 7
+--R                  (36a b c  - 216a b c  - 72a b c )d e
+--R                + 
+--R                       2 2 4         4 3  6 6          2   5         3 4  7 5
+--R                  (252a b c  + 168a b c )d e  + (- 180a b c  - 252a b c )d e
+--R                + 
+--R                      2 6         2 5  8 4              6     3 5  9 3
+--R                  (54a c  + 234a b c )d e  + (- 118a b c  + 2b c )d e
+--R                + 
+--R                        7     2 6  10 2       7 11      8 12
+--R                  (24a c  - 6b c )d  e  + 6b c d  e - 2c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R              2
+--R            3c
+--R         *
+--R            ROOT
+--R                           2 6       2 5
+--R                     (- 16a c  + 4a b c )
+--R                  *
+--R                     ROOT
+--R                                6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                            (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                          + 
+--R                                  5   4      4 3 3      3 5 2      2 7     11
+--R                            (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                          + 
+--R                                5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                            (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                          + 
+--R                                 4   5       3 3 4       2 5 3  3 9
+--R                            (400a b c  - 660a b c  + 220a b c )d e
+--R                          + 
+--R                                   4 6        3 2 5       2 4 4  4 8
+--R                            (- 255a c  + 1020a b c  - 495a b c )d e
+--R                          + 
+--R                                   3   6       2 3 5  5 7
+--R                            (- 960a b c  + 780a b c )d e
+--R                          + 
+--R                                 3 7       2 2 6       4 5  6 6
+--R                            (452a c  - 856a b c  + 2a b c )d e
+--R                          + 
+--R                                 2   7        3 6  7 5
+--R                            (624a b c  - 12a b c )d e
+--R                          + 
+--R                                   2 8        2 7  8 4          8 9 3
+--R                            (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                          + 
+--R                                 9 10 2    10 12
+--R                            30a c d  e  - c  d
+--R                       /
+--R                             3 11      2 2 10
+--R                          64a c   - 16a b c
+--R                 + 
+--R                      3   2     2 3       5  6
+--R                   (5a b c  - 5a b c + a b )e
+--R                 + 
+--R                         3 3      2 2 2       4     5
+--R                   (- 12a c  + 24a b c  - 6a b c)d e
+--R                 + 
+--R                         2   3        3 2  2 4       2 4        2 3  3 3
+--R                   (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                 + 
+--R                          4 4 2        5 5       5 6
+--R                   15a b c d e  - 12a c d e + b c d
+--R              /
+--R                   2 6       2 5
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                               4 7      3 2 6     2 4 5  3
+--R                         (- 32a c  + 24a b c  - 4a b c )e
+--R                       + 
+--R                               3   7      2 3 6    2       3 8      2 2 7  2
+--R                         (- 48a b c  + 12a b c )d e  + (96a c  - 24a b c )d e
+--R                       + 
+--R                               2   8       3 7  3
+--R                         (- 16a b c  + 4a b c )d
+--R                    *
+--R                       ROOT
+--R                                  6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                            + 
+--R                                    5   4      4 3 3      3 5 2      2 7     11
+--R                              (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                            + 
+--R                                  5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                              (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                            + 
+--R                                   4   5       3 3 4       2 5 3  3 9
+--R                              (400a b c  - 660a b c  + 220a b c )d e
+--R                            + 
+--R                                     4 6        3 2 5       2 4 4  4 8
+--R                              (- 255a c  + 1020a b c  - 495a b c )d e
+--R                            + 
+--R                                     3   6       2 3 5  5 7
+--R                              (- 960a b c  + 780a b c )d e
+--R                            + 
+--R                                   3 7       2 2 6       4 5  6 6
+--R                              (452a c  - 856a b c  + 2a b c )d e
+--R                            + 
+--R                                   2   7        3 6  7 5
+--R                              (624a b c  - 12a b c )d e
+--R                            + 
+--R                                     2 8        2 7  8 4          8 9 3
+--R                              (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                            + 
+--R                                   9 10 2    10 12
+--R                              30a c d  e  - c  d
+--R                         /
+--R                               3 11      2 2 10
+--R                            64a c   - 16a b c
+--R                   + 
+--R                          5   3      4 3 2     3 5     2 7  9
+--R                     (- 4a b c  + 13a b c  - 7a b c + a b )e
+--R                   + 
+--R                         5 4      4 2 3      3 4 2     2 6     8
+--R                     (12a c  - 87a b c  + 57a b c  - 9a b c)d e
+--R                   + 
+--R                          4   4       3 3 3      2 5 2  2 7
+--R                     (204a b c  - 183a b c  + 33a b c )d e
+--R                   + 
+--R                            4 5       3 2 4      2 4 3      6 2  3 6
+--R                     (- 184a c  + 318a b c  - 72a b c  + a b c )d e
+--R                   + 
+--R                            3   5       2 3 4       5 3  4 5
+--R                     (- 348a b c  + 111a b c  - 6a b c )d e
+--R                   + 
+--R                          3 6       2 2 5        4 4  5 4
+--R                     (240a c  - 120a b c  + 15a b c )d e
+--R                   + 
+--R                         2   6        3 5  6 3         2 7        2 6  7 2
+--R                     (84a b c  - 21a b c )d e  + (- 72a c  + 18a b c )d e
+--R                   + 
+--R                          8    2 7  9
+--R                     (4a c  - b c )d
+--R                *
+--R                   ROOT
+--R                                  2 6       2 5
+--R                            (- 16a c  + 4a b c )
+--R                         *
+--R                            ROOT
+--R                                            6 4     5 2 3      4 4 2     3 6
+--R                                         - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                       + 
+--R                                            2 8
+--R                                         - a b
+--R                                  *
+--R                                      12
+--R                                     e
+--R                                 + 
+--R                                              5   4      4 3 3      3 5 2
+--R                                         - 24a b c  + 84a b c  - 60a b c
+--R                                       + 
+--R                                            2 7
+--R                                         12a b c
+--R                                  *
+--R                                        11
+--R                                     d e
+--R                                 + 
+--R                                         5 5       4 2 4       3 4 3      2 6 2
+--R                                     (30a c  - 264a b c  + 264a b c  - 66a b c )
+--R                                  *
+--R                                      2 10
+--R                                     d e
+--R                                 + 
+--R                                        4   5       3 3 4       2 5 3  3 9
+--R                                   (400a b c  - 660a b c  + 220a b c )d e
+--R                                 + 
+--R                                          4 6        3 2 5       2 4 4  4 8
+--R                                   (- 255a c  + 1020a b c  - 495a b c )d e
+--R                                 + 
+--R                                          3   6       2 3 5  5 7
+--R                                   (- 960a b c  + 780a b c )d e
+--R                                 + 
+--R                                        3 7       2 2 6       4 5  6 6
+--R                                   (452a c  - 856a b c  + 2a b c )d e
+--R                                 + 
+--R                                        2   7        3 6  7 5
+--R                                   (624a b c  - 12a b c )d e
+--R                                 + 
+--R                                          2 8        2 7  8 4          8 9 3
+--R                                   (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                                 + 
+--R                                        9 10 2    10 12
+--R                                   30a c d  e  - c  d
+--R                              /
+--R                                    3 11      2 2 10
+--R                                 64a c   - 16a b c
+--R                        + 
+--R                             3   2     2 3       5  6
+--R                          (5a b c  - 5a b c + a b )e
+--R                        + 
+--R                                3 3      2 2 2       4     5
+--R                          (- 12a c  + 24a b c  - 6a b c)d e
+--R                        + 
+--R                                2   3        3 2  2 4       2 4        2 3  3 3
+--R                          (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                        + 
+--R                                 4 4 2        5 5       5 6
+--R                          15a b c d e  - 12a c d e + b c d
+--R                     /
+--R                          2 6       2 5
+--R                        8a c  - 2a b c
+--R               + 
+--R                        6 2     5 2      4 4  12
+--R                     (2a c  - 6a b c + 2a b )e
+--R                   + 
+--R                         5   2     4 3      3 5    11
+--R                     (18a b c  + 6a b c - 6a b )d e
+--R                   + 
+--R                           5 3      4 2 2      3 4      2 6  2 10
+--R                     (- 24a c  - 54a b c  + 24a b c + 6a b )d e
+--R                   + 
+--R                          4   3      3 3 2      2 5        7  3 9
+--R                     (110a b c  - 20a b c  - 42a b c - 2a b )d e
+--R                   + 
+--R                           4 4      3 2 3       2 4 2        6   4 8
+--R                     (- 54a c  - 36a b c  + 126a b c  + 18a b c)d e
+--R                   + 
+--R                         3   4       2 3 3        5 2  5 7
+--R                     (36a b c  - 216a b c  - 72a b c )d e
+--R                   + 
+--R                          2 2 4         4 3  6 6          2   5         3 4  7 5
+--R                     (252a b c  + 168a b c )d e  + (- 180a b c  - 252a b c )d e
+--R                   + 
+--R                         2 6         2 5  8 4              6     3 5  9 3
+--R                     (54a c  + 234a b c )d e  + (- 118a b c  + 2b c )d e
+--R                   + 
+--R                           7     2 6  10 2       7 11      8 12
+--R                     (24a c  - 6b c )d  e  + 6b c d  e - 2c d
+--R                *
+--R                   x
+--R     + 
+--R           2
+--R         3c
+--R      *
+--R         ROOT
+--R                      2 6       2 5
+--R                  (16a c  - 4a b c )
+--R               *
+--R                  ROOT
+--R                             6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                       + 
+--R                               5   4      4 3 3      3 5 2      2 7     11
+--R                         (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                       + 
+--R                             5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                         (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                       + 
+--R                              4   5       3 3 4       2 5 3  3 9
+--R                         (400a b c  - 660a b c  + 220a b c )d e
+--R                       + 
+--R                                4 6        3 2 5       2 4 4  4 8
+--R                         (- 255a c  + 1020a b c  - 495a b c )d e
+--R                       + 
+--R                                3   6       2 3 5  5 7
+--R                         (- 960a b c  + 780a b c )d e
+--R                       + 
+--R                              3 7       2 2 6       4 5  6 6
+--R                         (452a c  - 856a b c  + 2a b c )d e
+--R                       + 
+--R                              2   7        3 6  7 5          2 8        2 7  8 4
+--R                         (624a b c  - 12a b c )d e  + (- 255a c  + 30a b c )d e
+--R                       + 
+--R                                  8 9 3        9 10 2    10 12
+--R                         - 40a b c d e  + 30a c d  e  - c  d
+--R                    /
+--R                          3 11      2 2 10
+--R                       64a c   - 16a b c
+--R              + 
+--R                   3   2     2 3       5  6         3 3      2 2 2       4     5
+--R                (5a b c  - 5a b c + a b )e  + (- 12a c  + 24a b c  - 6a b c)d e
+--R              + 
+--R                      2   3        3 2  2 4       2 4        2 3  3 3
+--R                (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R              + 
+--R                       4 4 2        5 5       5 6
+--R                15a b c d e  - 12a c d e + b c d
+--R           /
+--R                2 6       2 5
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                            4 7      3 2 6     2 4 5  3
+--R                      (- 32a c  + 24a b c  - 4a b c )e
+--R                    + 
+--R                            3   7      2 3 6    2       3 8      2 2 7  2
+--R                      (- 48a b c  + 12a b c )d e  + (96a c  - 24a b c )d e
+--R                    + 
+--R                            2   8       3 7  3
+--R                      (- 16a b c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                         + 
+--R                                 5   4      4 3 3      3 5 2      2 7     11
+--R                           (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                         + 
+--R                               5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                           (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                         + 
+--R                                4   5       3 3 4       2 5 3  3 9
+--R                           (400a b c  - 660a b c  + 220a b c )d e
+--R                         + 
+--R                                  4 6        3 2 5       2 4 4  4 8
+--R                           (- 255a c  + 1020a b c  - 495a b c )d e
+--R                         + 
+--R                                  3   6       2 3 5  5 7
+--R                           (- 960a b c  + 780a b c )d e
+--R                         + 
+--R                                3 7       2 2 6       4 5  6 6
+--R                           (452a c  - 856a b c  + 2a b c )d e
+--R                         + 
+--R                                2   7        3 6  7 5
+--R                           (624a b c  - 12a b c )d e
+--R                         + 
+--R                                  2 8        2 7  8 4          8 9 3
+--R                           (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                         + 
+--R                                9 10 2    10 12
+--R                           30a c d  e  - c  d
+--R                      /
+--R                            3 11      2 2 10
+--R                         64a c   - 16a b c
+--R                + 
+--R                     5   3      4 3 2     3 5     2 7  9
+--R                  (4a b c  - 13a b c  + 7a b c - a b )e
+--R                + 
+--R                        5 4      4 2 3      3 4 2     2 6     8
+--R                  (- 12a c  + 87a b c  - 57a b c  + 9a b c)d e
+--R                + 
+--R                         4   4       3 3 3      2 5 2  2 7
+--R                  (- 204a b c  + 183a b c  - 33a b c )d e
+--R                + 
+--R                       4 5       3 2 4      2 4 3      6 2  3 6
+--R                  (184a c  - 318a b c  + 72a b c  - a b c )d e
+--R                + 
+--R                       3   5       2 3 4       5 3  4 5
+--R                  (348a b c  - 111a b c  + 6a b c )d e
+--R                + 
+--R                         3 6       2 2 5        4 4  5 4
+--R                  (- 240a c  + 120a b c  - 15a b c )d e
+--R                + 
+--R                        2   6        3 5  6 3       2 7        2 6  7 2
+--R                  (- 84a b c  + 21a b c )d e  + (72a c  - 18a b c )d e
+--R                + 
+--R                         8    2 7  9
+--R                  (- 4a c  + b c )d
+--R             *
+--R                ROOT
+--R                             2 6       2 5
+--R                         (16a c  - 4a b c )
+--R                      *
+--R                         ROOT
+--R                                    6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                              + 
+--R                                        5   4      4 3 3      3 5 2      2 7
+--R                                  (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d
+--R                               *
+--R                                   11
+--R                                  e
+--R                              + 
+--R                                    5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                                (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                              + 
+--R                                     4   5       3 3 4       2 5 3  3 9
+--R                                (400a b c  - 660a b c  + 220a b c )d e
+--R                              + 
+--R                                       4 6        3 2 5       2 4 4  4 8
+--R                                (- 255a c  + 1020a b c  - 495a b c )d e
+--R                              + 
+--R                                       3   6       2 3 5  5 7
+--R                                (- 960a b c  + 780a b c )d e
+--R                              + 
+--R                                     3 7       2 2 6       4 5  6 6
+--R                                (452a c  - 856a b c  + 2a b c )d e
+--R                              + 
+--R                                     2   7        3 6  7 5
+--R                                (624a b c  - 12a b c )d e
+--R                              + 
+--R                                       2 8        2 7  8 4          8 9 3
+--R                                (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                              + 
+--R                                     9 10 2    10 12
+--R                                30a c d  e  - c  d
+--R                           /
+--R                                 3 11      2 2 10
+--R                              64a c   - 16a b c
+--R                     + 
+--R                          3   2     2 3       5  6
+--R                       (5a b c  - 5a b c + a b )e
+--R                     + 
+--R                             3 3      2 2 2       4     5
+--R                       (- 12a c  + 24a b c  - 6a b c)d e
+--R                     + 
+--R                             2   3        3 2  2 4       2 4        2 3  3 3
+--R                       (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                     + 
+--R                              4 4 2        5 5       5 6
+--R                       15a b c d e  - 12a c d e + b c d
+--R                  /
+--R                       2 6       2 5
+--R                     8a c  - 2a b c
+--R            + 
+--R                     6 2     5 2      4 4  12       5   2     4 3      3 5    11
+--R                  (2a c  - 6a b c + 2a b )e   + (18a b c  + 6a b c - 6a b )d e
+--R                + 
+--R                        5 3      4 2 2      3 4      2 6  2 10
+--R                  (- 24a c  - 54a b c  + 24a b c + 6a b )d e
+--R                + 
+--R                       4   3      3 3 2      2 5        7  3 9
+--R                  (110a b c  - 20a b c  - 42a b c - 2a b )d e
+--R                + 
+--R                        4 4      3 2 3       2 4 2        6   4 8
+--R                  (- 54a c  - 36a b c  + 126a b c  + 18a b c)d e
+--R                + 
+--R                      3   4       2 3 3        5 2  5 7
+--R                  (36a b c  - 216a b c  - 72a b c )d e
+--R                + 
+--R                       2 2 4         4 3  6 6          2   5         3 4  7 5
+--R                  (252a b c  + 168a b c )d e  + (- 180a b c  - 252a b c )d e
+--R                + 
+--R                      2 6         2 5  8 4              6     3 5  9 3
+--R                  (54a c  + 234a b c )d e  + (- 118a b c  + 2b c )d e
+--R                + 
+--R                        7     2 6  10 2       7 11      8 12
+--R                  (24a c  - 6b c )d  e  + 6b c d  e - 2c d
+--R             *
+--R                x
+--R     + 
+--R           3 3          3          2
+--R       2c e x  + (- 6b e  + 18c d e )x
+--R  /
+--R       2
+--R     6c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2805
+
+--S 2806 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                     +--------------------+
+--R                   +-----------+     |   +-----------+
+--R             2 +-+ |          2  +-+ |   |          2
+--R            c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                         2 6       2 5
+--R                     (16a c  - 4a b c )
+--R                  *
+--R                     ROOT
+--R                                6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                            (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                          + 
+--R                                  5   4      4 3 3      3 5 2      2 7     11
+--R                            (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                          + 
+--R                                5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                            (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                          + 
+--R                                 4   5       3 3 4       2 5 3  3 9
+--R                            (400a b c  - 660a b c  + 220a b c )d e
+--R                          + 
+--R                                   4 6        3 2 5       2 4 4  4 8
+--R                            (- 255a c  + 1020a b c  - 495a b c )d e
+--R                          + 
+--R                                   3   6       2 3 5  5 7
+--R                            (- 960a b c  + 780a b c )d e
+--R                          + 
+--R                                 3 7       2 2 6       4 5  6 6
+--R                            (452a c  - 856a b c  + 2a b c )d e
+--R                          + 
+--R                                 2   7        3 6  7 5
+--R                            (624a b c  - 12a b c )d e
+--R                          + 
+--R                                   2 8        2 7  8 4          8 9 3
+--R                            (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                          + 
+--R                                 9 10 2    10 12
+--R                            30a c d  e  - c  d
+--R                       /
+--R                             3 11      2 2 10
+--R                          64a c   - 16a b c
+--R                 + 
+--R                      3   2     2 3       5  6
+--R                   (5a b c  - 5a b c + a b )e
+--R                 + 
+--R                         3 3      2 2 2       4     5
+--R                   (- 12a c  + 24a b c  - 6a b c)d e
+--R                 + 
+--R                         2   3        3 2  2 4       2 4        2 3  3 3
+--R                   (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                 + 
+--R                          4 4 2        5 5       5 6
+--R                   15a b c d e  - 12a c d e + b c d
+--R              /
+--R                   2 6       2 5
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                             4 7      3 2 6     2 4 5  3
+--R                         (32a c  - 24a b c  + 4a b c )e
+--R                       + 
+--R                             3   7      2 3 6    2         3 8      2 2 7  2
+--R                         (48a b c  - 12a b c )d e  + (- 96a c  + 24a b c )d e
+--R                       + 
+--R                             2   8       3 7  3
+--R                         (16a b c  - 4a b c )d
+--R                    *
+--R                       ROOT
+--R                                  6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                            + 
+--R                                    5   4      4 3 3      3 5 2      2 7     11
+--R                              (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                            + 
+--R                                  5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                              (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                            + 
+--R                                   4   5       3 3 4       2 5 3  3 9
+--R                              (400a b c  - 660a b c  + 220a b c )d e
+--R                            + 
+--R                                     4 6        3 2 5       2 4 4  4 8
+--R                              (- 255a c  + 1020a b c  - 495a b c )d e
+--R                            + 
+--R                                     3   6       2 3 5  5 7
+--R                              (- 960a b c  + 780a b c )d e
+--R                            + 
+--R                                   3 7       2 2 6       4 5  6 6
+--R                              (452a c  - 856a b c  + 2a b c )d e
+--R                            + 
+--R                                   2   7        3 6  7 5
+--R                              (624a b c  - 12a b c )d e
+--R                            + 
+--R                                     2 8        2 7  8 4          8 9 3
+--R                              (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                            + 
+--R                                   9 10 2    10 12
+--R                              30a c d  e  - c  d
+--R                         /
+--R                               3 11      2 2 10
+--R                            64a c   - 16a b c
+--R                   + 
+--R                          5   3      4 3 2     3 5     2 7  9
+--R                     (- 4a b c  + 13a b c  - 7a b c + a b )e
+--R                   + 
+--R                         5 4      4 2 3      3 4 2     2 6     8
+--R                     (12a c  - 87a b c  + 57a b c  - 9a b c)d e
+--R                   + 
+--R                          4   4       3 3 3      2 5 2  2 7
+--R                     (204a b c  - 183a b c  + 33a b c )d e
+--R                   + 
+--R                            4 5       3 2 4      2 4 3      6 2  3 6
+--R                     (- 184a c  + 318a b c  - 72a b c  + a b c )d e
+--R                   + 
+--R                            3   5       2 3 4       5 3  4 5
+--R                     (- 348a b c  + 111a b c  - 6a b c )d e
+--R                   + 
+--R                          3 6       2 2 5        4 4  5 4
+--R                     (240a c  - 120a b c  + 15a b c )d e
+--R                   + 
+--R                         2   6        3 5  6 3         2 7        2 6  7 2
+--R                     (84a b c  - 21a b c )d e  + (- 72a c  + 18a b c )d e
+--R                   + 
+--R                          8    2 7  9
+--R                     (4a c  - b c )d
+--R                *
+--R                   ROOT
+--R                                2 6       2 5
+--R                            (16a c  - 4a b c )
+--R                         *
+--R                            ROOT
+--R                                            6 4     5 2 3      4 4 2     3 6
+--R                                         - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                       + 
+--R                                            2 8
+--R                                         - a b
+--R                                  *
+--R                                      12
+--R                                     e
+--R                                 + 
+--R                                              5   4      4 3 3      3 5 2
+--R                                         - 24a b c  + 84a b c  - 60a b c
+--R                                       + 
+--R                                            2 7
+--R                                         12a b c
+--R                                  *
+--R                                        11
+--R                                     d e
+--R                                 + 
+--R                                         5 5       4 2 4       3 4 3      2 6 2
+--R                                     (30a c  - 264a b c  + 264a b c  - 66a b c )
+--R                                  *
+--R                                      2 10
+--R                                     d e
+--R                                 + 
+--R                                        4   5       3 3 4       2 5 3  3 9
+--R                                   (400a b c  - 660a b c  + 220a b c )d e
+--R                                 + 
+--R                                          4 6        3 2 5       2 4 4  4 8
+--R                                   (- 255a c  + 1020a b c  - 495a b c )d e
+--R                                 + 
+--R                                          3   6       2 3 5  5 7
+--R                                   (- 960a b c  + 780a b c )d e
+--R                                 + 
+--R                                        3 7       2 2 6       4 5  6 6
+--R                                   (452a c  - 856a b c  + 2a b c )d e
+--R                                 + 
+--R                                        2   7        3 6  7 5
+--R                                   (624a b c  - 12a b c )d e
+--R                                 + 
+--R                                          2 8        2 7  8 4          8 9 3
+--R                                   (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                                 + 
+--R                                        9 10 2    10 12
+--R                                   30a c d  e  - c  d
+--R                              /
+--R                                    3 11      2 2 10
+--R                                 64a c   - 16a b c
+--R                        + 
+--R                             3   2     2 3       5  6
+--R                          (5a b c  - 5a b c + a b )e
+--R                        + 
+--R                                3 3      2 2 2       4     5
+--R                          (- 12a c  + 24a b c  - 6a b c)d e
+--R                        + 
+--R                                2   3        3 2  2 4       2 4        2 3  3 3
+--R                          (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                        + 
+--R                                 4 4 2        5 5       5 6
+--R                          15a b c d e  - 12a c d e + b c d
+--R                     /
+--R                          2 6       2 5
+--R                        8a c  - 2a b c
+--R               + 
+--R                        6 2     5 2      4 4  12
+--R                     (2a c  - 6a b c + 2a b )e
+--R                   + 
+--R                         5   2     4 3      3 5    11
+--R                     (18a b c  + 6a b c - 6a b )d e
+--R                   + 
+--R                           5 3      4 2 2      3 4      2 6  2 10
+--R                     (- 24a c  - 54a b c  + 24a b c + 6a b )d e
+--R                   + 
+--R                          4   3      3 3 2      2 5        7  3 9
+--R                     (110a b c  - 20a b c  - 42a b c - 2a b )d e
+--R                   + 
+--R                           4 4      3 2 3       2 4 2        6   4 8
+--R                     (- 54a c  - 36a b c  + 126a b c  + 18a b c)d e
+--R                   + 
+--R                         3   4       2 3 3        5 2  5 7
+--R                     (36a b c  - 216a b c  - 72a b c )d e
+--R                   + 
+--R                          2 2 4         4 3  6 6          2   5         3 4  7 5
+--R                     (252a b c  + 168a b c )d e  + (- 180a b c  - 252a b c )d e
+--R                   + 
+--R                         2 6         2 5  8 4              6     3 5  9 3
+--R                     (54a c  + 234a b c )d e  + (- 118a b c  + 2b c )d e
+--R                   + 
+--R                           7     2 6  10 2       7 11      8 12
+--R                     (24a c  - 6b c )d  e  + 6b c d  e - 2c d
+--R                *
+--R                   x
+--R     + 
+--R                                  +--------------------+
+--R                +-----------+     |   +-----------+
+--R          2 +-+ |          2  +-+ |   |          2
+--R         c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        2 6       2 5
+--R                  (- 16a c  + 4a b c )
+--R               *
+--R                  ROOT
+--R                             6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                       + 
+--R                               5   4      4 3 3      3 5 2      2 7     11
+--R                         (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                       + 
+--R                             5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                         (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                       + 
+--R                              4   5       3 3 4       2 5 3  3 9
+--R                         (400a b c  - 660a b c  + 220a b c )d e
+--R                       + 
+--R                                4 6        3 2 5       2 4 4  4 8
+--R                         (- 255a c  + 1020a b c  - 495a b c )d e
+--R                       + 
+--R                                3   6       2 3 5  5 7
+--R                         (- 960a b c  + 780a b c )d e
+--R                       + 
+--R                              3 7       2 2 6       4 5  6 6
+--R                         (452a c  - 856a b c  + 2a b c )d e
+--R                       + 
+--R                              2   7        3 6  7 5          2 8        2 7  8 4
+--R                         (624a b c  - 12a b c )d e  + (- 255a c  + 30a b c )d e
+--R                       + 
+--R                                  8 9 3        9 10 2    10 12
+--R                         - 40a b c d e  + 30a c d  e  - c  d
+--R                    /
+--R                          3 11      2 2 10
+--R                       64a c   - 16a b c
+--R              + 
+--R                   3   2     2 3       5  6         3 3      2 2 2       4     5
+--R                (5a b c  - 5a b c + a b )e  + (- 12a c  + 24a b c  - 6a b c)d e
+--R              + 
+--R                      2   3        3 2  2 4       2 4        2 3  3 3
+--R                (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R              + 
+--R                       4 4 2        5 5       5 6
+--R                15a b c d e  - 12a c d e + b c d
+--R           /
+--R                2 6       2 5
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          4 7      3 2 6     2 4 5  3
+--R                      (32a c  - 24a b c  + 4a b c )e
+--R                    + 
+--R                          3   7      2 3 6    2         3 8      2 2 7  2
+--R                      (48a b c  - 12a b c )d e  + (- 96a c  + 24a b c )d e
+--R                    + 
+--R                          2   8       3 7  3
+--R                      (16a b c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                         + 
+--R                                 5   4      4 3 3      3 5 2      2 7     11
+--R                           (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                         + 
+--R                               5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                           (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                         + 
+--R                                4   5       3 3 4       2 5 3  3 9
+--R                           (400a b c  - 660a b c  + 220a b c )d e
+--R                         + 
+--R                                  4 6        3 2 5       2 4 4  4 8
+--R                           (- 255a c  + 1020a b c  - 495a b c )d e
+--R                         + 
+--R                                  3   6       2 3 5  5 7
+--R                           (- 960a b c  + 780a b c )d e
+--R                         + 
+--R                                3 7       2 2 6       4 5  6 6
+--R                           (452a c  - 856a b c  + 2a b c )d e
+--R                         + 
+--R                                2   7        3 6  7 5
+--R                           (624a b c  - 12a b c )d e
+--R                         + 
+--R                                  2 8        2 7  8 4          8 9 3
+--R                           (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                         + 
+--R                                9 10 2    10 12
+--R                           30a c d  e  - c  d
+--R                      /
+--R                            3 11      2 2 10
+--R                         64a c   - 16a b c
+--R                + 
+--R                     5   3      4 3 2     3 5     2 7  9
+--R                  (4a b c  - 13a b c  + 7a b c - a b )e
+--R                + 
+--R                        5 4      4 2 3      3 4 2     2 6     8
+--R                  (- 12a c  + 87a b c  - 57a b c  + 9a b c)d e
+--R                + 
+--R                         4   4       3 3 3      2 5 2  2 7
+--R                  (- 204a b c  + 183a b c  - 33a b c )d e
+--R                + 
+--R                       4 5       3 2 4      2 4 3      6 2  3 6
+--R                  (184a c  - 318a b c  + 72a b c  - a b c )d e
+--R                + 
+--R                       3   5       2 3 4       5 3  4 5
+--R                  (348a b c  - 111a b c  + 6a b c )d e
+--R                + 
+--R                         3 6       2 2 5        4 4  5 4
+--R                  (- 240a c  + 120a b c  - 15a b c )d e
+--R                + 
+--R                        2   6        3 5  6 3       2 7        2 6  7 2
+--R                  (- 84a b c  + 21a b c )d e  + (72a c  - 18a b c )d e
+--R                + 
+--R                         8    2 7  9
+--R                  (- 4a c  + b c )d
+--R             *
+--R                ROOT
+--R                               2 6       2 5
+--R                         (- 16a c  + 4a b c )
+--R                      *
+--R                         ROOT
+--R                                    6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                              + 
+--R                                        5   4      4 3 3      3 5 2      2 7
+--R                                  (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d
+--R                               *
+--R                                   11
+--R                                  e
+--R                              + 
+--R                                    5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                                (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                              + 
+--R                                     4   5       3 3 4       2 5 3  3 9
+--R                                (400a b c  - 660a b c  + 220a b c )d e
+--R                              + 
+--R                                       4 6        3 2 5       2 4 4  4 8
+--R                                (- 255a c  + 1020a b c  - 495a b c )d e
+--R                              + 
+--R                                       3   6       2 3 5  5 7
+--R                                (- 960a b c  + 780a b c )d e
+--R                              + 
+--R                                     3 7       2 2 6       4 5  6 6
+--R                                (452a c  - 856a b c  + 2a b c )d e
+--R                              + 
+--R                                     2   7        3 6  7 5
+--R                                (624a b c  - 12a b c )d e
+--R                              + 
+--R                                       2 8        2 7  8 4          8 9 3
+--R                                (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                              + 
+--R                                     9 10 2    10 12
+--R                                30a c d  e  - c  d
+--R                           /
+--R                                 3 11      2 2 10
+--R                              64a c   - 16a b c
+--R                     + 
+--R                          3   2     2 3       5  6
+--R                       (5a b c  - 5a b c + a b )e
+--R                     + 
+--R                             3 3      2 2 2       4     5
+--R                       (- 12a c  + 24a b c  - 6a b c)d e
+--R                     + 
+--R                             2   3        3 2  2 4       2 4        2 3  3 3
+--R                       (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                     + 
+--R                              4 4 2        5 5       5 6
+--R                       15a b c d e  - 12a c d e + b c d
+--R                  /
+--R                       2 6       2 5
+--R                     8a c  - 2a b c
+--R            + 
+--R                     6 2     5 2      4 4  12       5   2     4 3      3 5    11
+--R                  (2a c  - 6a b c + 2a b )e   + (18a b c  + 6a b c - 6a b )d e
+--R                + 
+--R                        5 3      4 2 2      3 4      2 6  2 10
+--R                  (- 24a c  - 54a b c  + 24a b c + 6a b )d e
+--R                + 
+--R                       4   3      3 3 2      2 5        7  3 9
+--R                  (110a b c  - 20a b c  - 42a b c - 2a b )d e
+--R                + 
+--R                        4 4      3 2 3       2 4 2        6   4 8
+--R                  (- 54a c  - 36a b c  + 126a b c  + 18a b c)d e
+--R                + 
+--R                      3   4       2 3 3        5 2  5 7
+--R                  (36a b c  - 216a b c  - 72a b c )d e
+--R                + 
+--R                       2 2 4         4 3  6 6          2   5         3 4  7 5
+--R                  (252a b c  + 168a b c )d e  + (- 180a b c  - 252a b c )d e
+--R                + 
+--R                      2 6         2 5  8 4              6     3 5  9 3
+--R                  (54a c  + 234a b c )d e  + (- 118a b c  + 2b c )d e
+--R                + 
+--R                        7     2 6  10 2       7 11      8 12
+--R                  (24a c  - 6b c )d  e  + 6b c d  e - 2c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                     +--------------------+
+--R                   +-----------+     |   +-----------+
+--R             2 +-+ |          2  +-+ |   |          2
+--R            c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                           2 6       2 5
+--R                     (- 16a c  + 4a b c )
+--R                  *
+--R                     ROOT
+--R                                6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                            (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                          + 
+--R                                  5   4      4 3 3      3 5 2      2 7     11
+--R                            (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                          + 
+--R                                5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                            (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                          + 
+--R                                 4   5       3 3 4       2 5 3  3 9
+--R                            (400a b c  - 660a b c  + 220a b c )d e
+--R                          + 
+--R                                   4 6        3 2 5       2 4 4  4 8
+--R                            (- 255a c  + 1020a b c  - 495a b c )d e
+--R                          + 
+--R                                   3   6       2 3 5  5 7
+--R                            (- 960a b c  + 780a b c )d e
+--R                          + 
+--R                                 3 7       2 2 6       4 5  6 6
+--R                            (452a c  - 856a b c  + 2a b c )d e
+--R                          + 
+--R                                 2   7        3 6  7 5
+--R                            (624a b c  - 12a b c )d e
+--R                          + 
+--R                                   2 8        2 7  8 4          8 9 3
+--R                            (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                          + 
+--R                                 9 10 2    10 12
+--R                            30a c d  e  - c  d
+--R                       /
+--R                             3 11      2 2 10
+--R                          64a c   - 16a b c
+--R                 + 
+--R                      3   2     2 3       5  6
+--R                   (5a b c  - 5a b c + a b )e
+--R                 + 
+--R                         3 3      2 2 2       4     5
+--R                   (- 12a c  + 24a b c  - 6a b c)d e
+--R                 + 
+--R                         2   3        3 2  2 4       2 4        2 3  3 3
+--R                   (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                 + 
+--R                          4 4 2        5 5       5 6
+--R                   15a b c d e  - 12a c d e + b c d
+--R              /
+--R                   2 6       2 5
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                               4 7      3 2 6     2 4 5  3
+--R                         (- 32a c  + 24a b c  - 4a b c )e
+--R                       + 
+--R                               3   7      2 3 6    2       3 8      2 2 7  2
+--R                         (- 48a b c  + 12a b c )d e  + (96a c  - 24a b c )d e
+--R                       + 
+--R                               2   8       3 7  3
+--R                         (- 16a b c  + 4a b c )d
+--R                    *
+--R                       ROOT
+--R                                  6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                            + 
+--R                                    5   4      4 3 3      3 5 2      2 7     11
+--R                              (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                            + 
+--R                                  5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                              (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                            + 
+--R                                   4   5       3 3 4       2 5 3  3 9
+--R                              (400a b c  - 660a b c  + 220a b c )d e
+--R                            + 
+--R                                     4 6        3 2 5       2 4 4  4 8
+--R                              (- 255a c  + 1020a b c  - 495a b c )d e
+--R                            + 
+--R                                     3   6       2 3 5  5 7
+--R                              (- 960a b c  + 780a b c )d e
+--R                            + 
+--R                                   3 7       2 2 6       4 5  6 6
+--R                              (452a c  - 856a b c  + 2a b c )d e
+--R                            + 
+--R                                   2   7        3 6  7 5
+--R                              (624a b c  - 12a b c )d e
+--R                            + 
+--R                                     2 8        2 7  8 4          8 9 3
+--R                              (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                            + 
+--R                                   9 10 2    10 12
+--R                              30a c d  e  - c  d
+--R                         /
+--R                               3 11      2 2 10
+--R                            64a c   - 16a b c
+--R                   + 
+--R                          5   3      4 3 2     3 5     2 7  9
+--R                     (- 4a b c  + 13a b c  - 7a b c + a b )e
+--R                   + 
+--R                         5 4      4 2 3      3 4 2     2 6     8
+--R                     (12a c  - 87a b c  + 57a b c  - 9a b c)d e
+--R                   + 
+--R                          4   4       3 3 3      2 5 2  2 7
+--R                     (204a b c  - 183a b c  + 33a b c )d e
+--R                   + 
+--R                            4 5       3 2 4      2 4 3      6 2  3 6
+--R                     (- 184a c  + 318a b c  - 72a b c  + a b c )d e
+--R                   + 
+--R                            3   5       2 3 4       5 3  4 5
+--R                     (- 348a b c  + 111a b c  - 6a b c )d e
+--R                   + 
+--R                          3 6       2 2 5        4 4  5 4
+--R                     (240a c  - 120a b c  + 15a b c )d e
+--R                   + 
+--R                         2   6        3 5  6 3         2 7        2 6  7 2
+--R                     (84a b c  - 21a b c )d e  + (- 72a c  + 18a b c )d e
+--R                   + 
+--R                          8    2 7  9
+--R                     (4a c  - b c )d
+--R                *
+--R                   ROOT
+--R                                  2 6       2 5
+--R                            (- 16a c  + 4a b c )
+--R                         *
+--R                            ROOT
+--R                                            6 4     5 2 3      4 4 2     3 6
+--R                                         - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                       + 
+--R                                            2 8
+--R                                         - a b
+--R                                  *
+--R                                      12
+--R                                     e
+--R                                 + 
+--R                                              5   4      4 3 3      3 5 2
+--R                                         - 24a b c  + 84a b c  - 60a b c
+--R                                       + 
+--R                                            2 7
+--R                                         12a b c
+--R                                  *
+--R                                        11
+--R                                     d e
+--R                                 + 
+--R                                         5 5       4 2 4       3 4 3      2 6 2
+--R                                     (30a c  - 264a b c  + 264a b c  - 66a b c )
+--R                                  *
+--R                                      2 10
+--R                                     d e
+--R                                 + 
+--R                                        4   5       3 3 4       2 5 3  3 9
+--R                                   (400a b c  - 660a b c  + 220a b c )d e
+--R                                 + 
+--R                                          4 6        3 2 5       2 4 4  4 8
+--R                                   (- 255a c  + 1020a b c  - 495a b c )d e
+--R                                 + 
+--R                                          3   6       2 3 5  5 7
+--R                                   (- 960a b c  + 780a b c )d e
+--R                                 + 
+--R                                        3 7       2 2 6       4 5  6 6
+--R                                   (452a c  - 856a b c  + 2a b c )d e
+--R                                 + 
+--R                                        2   7        3 6  7 5
+--R                                   (624a b c  - 12a b c )d e
+--R                                 + 
+--R                                          2 8        2 7  8 4          8 9 3
+--R                                   (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                                 + 
+--R                                        9 10 2    10 12
+--R                                   30a c d  e  - c  d
+--R                              /
+--R                                    3 11      2 2 10
+--R                                 64a c   - 16a b c
+--R                        + 
+--R                             3   2     2 3       5  6
+--R                          (5a b c  - 5a b c + a b )e
+--R                        + 
+--R                                3 3      2 2 2       4     5
+--R                          (- 12a c  + 24a b c  - 6a b c)d e
+--R                        + 
+--R                                2   3        3 2  2 4       2 4        2 3  3 3
+--R                          (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                        + 
+--R                                 4 4 2        5 5       5 6
+--R                          15a b c d e  - 12a c d e + b c d
+--R                     /
+--R                          2 6       2 5
+--R                        8a c  - 2a b c
+--R               + 
+--R                        6 2     5 2      4 4  12
+--R                     (2a c  - 6a b c + 2a b )e
+--R                   + 
+--R                         5   2     4 3      3 5    11
+--R                     (18a b c  + 6a b c - 6a b )d e
+--R                   + 
+--R                           5 3      4 2 2      3 4      2 6  2 10
+--R                     (- 24a c  - 54a b c  + 24a b c + 6a b )d e
+--R                   + 
+--R                          4   3      3 3 2      2 5        7  3 9
+--R                     (110a b c  - 20a b c  - 42a b c - 2a b )d e
+--R                   + 
+--R                           4 4      3 2 3       2 4 2        6   4 8
+--R                     (- 54a c  - 36a b c  + 126a b c  + 18a b c)d e
+--R                   + 
+--R                         3   4       2 3 3        5 2  5 7
+--R                     (36a b c  - 216a b c  - 72a b c )d e
+--R                   + 
+--R                          2 2 4         4 3  6 6          2   5         3 4  7 5
+--R                     (252a b c  + 168a b c )d e  + (- 180a b c  - 252a b c )d e
+--R                   + 
+--R                         2 6         2 5  8 4              6     3 5  9 3
+--R                     (54a c  + 234a b c )d e  + (- 118a b c  + 2b c )d e
+--R                   + 
+--R                           7     2 6  10 2       7 11      8 12
+--R                     (24a c  - 6b c )d  e  + 6b c d  e - 2c d
+--R                *
+--R                   x
+--R     + 
+--R                                  +--------------------+
+--R                +-----------+     |   +-----------+
+--R          2 +-+ |          2  +-+ |   |          2
+--R         c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                      2 6       2 5
+--R                  (16a c  - 4a b c )
+--R               *
+--R                  ROOT
+--R                             6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                       + 
+--R                               5   4      4 3 3      3 5 2      2 7     11
+--R                         (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                       + 
+--R                             5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                         (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                       + 
+--R                              4   5       3 3 4       2 5 3  3 9
+--R                         (400a b c  - 660a b c  + 220a b c )d e
+--R                       + 
+--R                                4 6        3 2 5       2 4 4  4 8
+--R                         (- 255a c  + 1020a b c  - 495a b c )d e
+--R                       + 
+--R                                3   6       2 3 5  5 7
+--R                         (- 960a b c  + 780a b c )d e
+--R                       + 
+--R                              3 7       2 2 6       4 5  6 6
+--R                         (452a c  - 856a b c  + 2a b c )d e
+--R                       + 
+--R                              2   7        3 6  7 5          2 8        2 7  8 4
+--R                         (624a b c  - 12a b c )d e  + (- 255a c  + 30a b c )d e
+--R                       + 
+--R                                  8 9 3        9 10 2    10 12
+--R                         - 40a b c d e  + 30a c d  e  - c  d
+--R                    /
+--R                          3 11      2 2 10
+--R                       64a c   - 16a b c
+--R              + 
+--R                   3   2     2 3       5  6         3 3      2 2 2       4     5
+--R                (5a b c  - 5a b c + a b )e  + (- 12a c  + 24a b c  - 6a b c)d e
+--R              + 
+--R                      2   3        3 2  2 4       2 4        2 3  3 3
+--R                (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R              + 
+--R                       4 4 2        5 5       5 6
+--R                15a b c d e  - 12a c d e + b c d
+--R           /
+--R                2 6       2 5
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            4 7      3 2 6     2 4 5  3
+--R                      (- 32a c  + 24a b c  - 4a b c )e
+--R                    + 
+--R                            3   7      2 3 6    2       3 8      2 2 7  2
+--R                      (- 48a b c  + 12a b c )d e  + (96a c  - 24a b c )d e
+--R                    + 
+--R                            2   8       3 7  3
+--R                      (- 16a b c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                         + 
+--R                                 5   4      4 3 3      3 5 2      2 7     11
+--R                           (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d e
+--R                         + 
+--R                               5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                           (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                         + 
+--R                                4   5       3 3 4       2 5 3  3 9
+--R                           (400a b c  - 660a b c  + 220a b c )d e
+--R                         + 
+--R                                  4 6        3 2 5       2 4 4  4 8
+--R                           (- 255a c  + 1020a b c  - 495a b c )d e
+--R                         + 
+--R                                  3   6       2 3 5  5 7
+--R                           (- 960a b c  + 780a b c )d e
+--R                         + 
+--R                                3 7       2 2 6       4 5  6 6
+--R                           (452a c  - 856a b c  + 2a b c )d e
+--R                         + 
+--R                                2   7        3 6  7 5
+--R                           (624a b c  - 12a b c )d e
+--R                         + 
+--R                                  2 8        2 7  8 4          8 9 3
+--R                           (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                         + 
+--R                                9 10 2    10 12
+--R                           30a c d  e  - c  d
+--R                      /
+--R                            3 11      2 2 10
+--R                         64a c   - 16a b c
+--R                + 
+--R                     5   3      4 3 2     3 5     2 7  9
+--R                  (4a b c  - 13a b c  + 7a b c - a b )e
+--R                + 
+--R                        5 4      4 2 3      3 4 2     2 6     8
+--R                  (- 12a c  + 87a b c  - 57a b c  + 9a b c)d e
+--R                + 
+--R                         4   4       3 3 3      2 5 2  2 7
+--R                  (- 204a b c  + 183a b c  - 33a b c )d e
+--R                + 
+--R                       4 5       3 2 4      2 4 3      6 2  3 6
+--R                  (184a c  - 318a b c  + 72a b c  - a b c )d e
+--R                + 
+--R                       3   5       2 3 4       5 3  4 5
+--R                  (348a b c  - 111a b c  + 6a b c )d e
+--R                + 
+--R                         3 6       2 2 5        4 4  5 4
+--R                  (- 240a c  + 120a b c  - 15a b c )d e
+--R                + 
+--R                        2   6        3 5  6 3       2 7        2 6  7 2
+--R                  (- 84a b c  + 21a b c )d e  + (72a c  - 18a b c )d e
+--R                + 
+--R                         8    2 7  9
+--R                  (- 4a c  + b c )d
+--R             *
+--R                ROOT
+--R                             2 6       2 5
+--R                         (16a c  - 4a b c )
+--R                      *
+--R                         ROOT
+--R                                    6 4     5 2 3      4 4 2     3 6     2 8  12
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - a b )e
+--R                              + 
+--R                                        5   4      4 3 3      3 5 2      2 7
+--R                                  (- 24a b c  + 84a b c  - 60a b c  + 12a b c)d
+--R                               *
+--R                                   11
+--R                                  e
+--R                              + 
+--R                                    5 5       4 2 4       3 4 3      2 6 2  2 10
+--R                                (30a c  - 264a b c  + 264a b c  - 66a b c )d e
+--R                              + 
+--R                                     4   5       3 3 4       2 5 3  3 9
+--R                                (400a b c  - 660a b c  + 220a b c )d e
+--R                              + 
+--R                                       4 6        3 2 5       2 4 4  4 8
+--R                                (- 255a c  + 1020a b c  - 495a b c )d e
+--R                              + 
+--R                                       3   6       2 3 5  5 7
+--R                                (- 960a b c  + 780a b c )d e
+--R                              + 
+--R                                     3 7       2 2 6       4 5  6 6
+--R                                (452a c  - 856a b c  + 2a b c )d e
+--R                              + 
+--R                                     2   7        3 6  7 5
+--R                                (624a b c  - 12a b c )d e
+--R                              + 
+--R                                       2 8        2 7  8 4          8 9 3
+--R                                (- 255a c  + 30a b c )d e  - 40a b c d e
+--R                              + 
+--R                                     9 10 2    10 12
+--R                                30a c d  e  - c  d
+--R                           /
+--R                                 3 11      2 2 10
+--R                              64a c   - 16a b c
+--R                     + 
+--R                          3   2     2 3       5  6
+--R                       (5a b c  - 5a b c + a b )e
+--R                     + 
+--R                             3 3      2 2 2       4     5
+--R                       (- 12a c  + 24a b c  - 6a b c)d e
+--R                     + 
+--R                             2   3        3 2  2 4       2 4        2 3  3 3
+--R                       (- 45a b c  + 15a b c )d e  + (40a c  - 20a b c )d e
+--R                     + 
+--R                              4 4 2        5 5       5 6
+--R                       15a b c d e  - 12a c d e + b c d
+--R                  /
+--R                       2 6       2 5
+--R                     8a c  - 2a b c
+--R            + 
+--R                     6 2     5 2      4 4  12       5   2     4 3      3 5    11
+--R                  (2a c  - 6a b c + 2a b )e   + (18a b c  + 6a b c - 6a b )d e
+--R                + 
+--R                        5 3      4 2 2      3 4      2 6  2 10
+--R                  (- 24a c  - 54a b c  + 24a b c + 6a b )d e
+--R                + 
+--R                       4   3      3 3 2      2 5        7  3 9
+--R                  (110a b c  - 20a b c  - 42a b c - 2a b )d e
+--R                + 
+--R                        4 4      3 2 3       2 4 2        6   4 8
+--R                  (- 54a c  - 36a b c  + 126a b c  + 18a b c)d e
+--R                + 
+--R                      3   4       2 3 3        5 2  5 7
+--R                  (36a b c  - 216a b c  - 72a b c )d e
+--R                + 
+--R                       2 2 4         4 3  6 6          2   5         3 4  7 5
+--R                  (252a b c  + 168a b c )d e  + (- 180a b c  - 252a b c )d e
+--R                + 
+--R                      2 6         2 5  8 4              6     3 5  9 3
+--R                  (54a c  + 234a b c )d e  + (- 118a b c  + 2b c )d e
+--R                + 
+--R                        7     2 6  10 2       7 11      8 12
+--R                  (24a c  - 6b c )d  e  + 6b c d  e - 2c d
+--R             *
+--R                x
+--R     + 
+--R                                                 +-----------+
+--R                      2  3           2     2 2   |          2
+--R           ((2a c - 2b )e  + 6b c d e  - 6c d e)\|- 4a c + b
+--R         + 
+--R                         3  3         2     2     2       2 2      3 3
+--R           (- 6a b c + 2b )e  + (12a c  - 6b c)d e  + 6b c d e - 4c d
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                                 +-----------+
+--R                      2  3           2     2 2   |          2
+--R           ((2a c - 2b )e  + 6b c d e  - 6c d e)\|- 4a c + b
+--R         + 
+--R                       3  3           2     2     2       2 2      3 3
+--R           (6a b c - 2b )e  + (- 12a c  + 6b c)d e  - 6b c d e + 4c d
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2806
+
+--S 2807 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2807
+
+)clear all
+
+--S 2808 of 3139
+t0:=(d+e*x^2)^2/(a+b*x^2+c*x^4)
+--R 
+--R
+--R         2 4         2    2
+--R        e x  + 2d e x  + d
+--R   (1)  -------------------
+--R             4      2
+--R          c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2808
+
+--S 2809 of 3139
+r0:=e^2*x/c+atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(e*(2*c*d-b*e)+_
+   (2*c^2*d^2+b^2*e^2-2*c*e*(b*d+a*e))/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (e*(2*c*d-b*e)+(-2*c^2*d^2-b^2*e^2+2*c*e*(b*d+a*e))/sqrt(b^2-4*a*c))/_
+   (c^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                            +-----------+
+--R                2           |          2               2  2                2 2
+--R         ((- b e  + 2c d e)\|- 4a c + b   + (- 2a c + b )e  - 2b c d e + 2c d )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                            +-----------+
+--R                2           |          2             2  2                2 2
+--R         ((- b e  + 2c d e)\|- 4a c + b   + (2a c - b )e  + 2b c d e - 2c d )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R        2  +-+ |          2  +-+ |   |          2       | |          2
+--R       e x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2809
+
+--S 2810 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         c
+--R      *
+--R         ROOT
+--R                      2 4       2 3
+--R                  (16a c  - 4a b c )
+--R               *
+--R                  ROOT
+--R                             4 2     3 2     2 4  8        3   2     2 3     7
+--R                         (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                       + 
+--R                             3 3      2 2 2  2 6      2   3 3 5
+--R                         (12a c  - 28a b c )d e  + 48a b c d e
+--R                       + 
+--R                               2 4       2 3  4 4         4 5 3        5 6 2
+--R                         (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                       + 
+--R                            6 8
+--R                         - c d
+--R                    /
+--R                          3 7      2 2 6
+--R                       64a c  - 16a b c
+--R              + 
+--R                     2         3  4      2 2       2     3         2 2 2
+--R                (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R              + 
+--R                      3 3       3 4
+--R                - 8a c d e + b c d
+--R           /
+--R                2 4       2 3
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                          3   4     2 3 3  2         3 5      2 2 4
+--R                      (16a b c  - 4a b c )e  + (- 64a c  + 16a b c )d e
+--R                    + 
+--R                          2   5       3 4  2
+--R                      (16a b c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               4 2     3 2     2 4  8        3   2     2 3     7
+--R                           (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                         + 
+--R                               3 3      2 2 2  2 6      2   3 3 5
+--R                           (12a c  - 28a b c )d e  + 48a b c d e
+--R                         + 
+--R                                 2 4       2 3  4 4         4 5 3        5 6 2
+--R                           (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                         + 
+--R                              6 8
+--R                           - c d
+--R                      /
+--R                            3 7      2 2 6
+--R                         64a c  - 16a b c
+--R                + 
+--R                       4 2     3 2     2 4  6         3   2     2 3     5
+--R                  (- 4a c  + 5a b c - a b )e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                      3 3      2 2 2      4   2 4       2   3       3 2  3 3
+--R                  (28a c  - 11a b c  + a b c)d e  + (16a b c  - 4a b c )d e
+--R                + 
+--R                        2 4       2 3  4 2        5    2 4  6
+--R                  (- 28a c  + 7a b c )d e  + (4a c  - b c )d
+--R             *
+--R                ROOT
+--R                             2 4       2 3
+--R                         (16a c  - 4a b c )
+--R                      *
+--R                         ROOT
+--R                                    4 2     3 2     2 4  8
+--R                                (- a c  + 2a b c - a b )e
+--R                              + 
+--R                                     3   2     2 3     7
+--R                                (- 8a b c  + 8a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 6      2   3 3 5
+--R                                (12a c  - 28a b c )d e  + 48a b c d e
+--R                              + 
+--R                                      2 4       2 3  4 4         4 5 3
+--R                                (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                              + 
+--R                                     5 6 2    6 8
+--R                                12a c d e  - c d
+--R                           /
+--R                                 3 7      2 2 6
+--R                              64a c  - 16a b c
+--R                     + 
+--R                            2         3  4      2 2       2     3         2 2 2
+--R                       (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R                     + 
+--R                             3 3       3 4
+--R                       - 8a c d e + b c d
+--R                  /
+--R                       2 4       2 3
+--R                     8a c  - 2a b c
+--R            + 
+--R                     4      3 2  8      3        2 3    7
+--R                  (2a c - 2a b )e  + (4a b c + 4a b )d e
+--R                + 
+--R                       3 2      2 2        4  2 6       2   2        3   3 5
+--R                  (- 8a c  - 18a b c - 2a b )d e  + (36a b c  + 12a b c)d e
+--R                + 
+--R                        2 3        2 2  4 4          3 5 3
+--R                  (- 20a c  - 30a b c )d e  + 28a b c d e
+--R                + 
+--R                         4     2 3  6 2       4 7      5 8
+--R                  (- 8a c  + 2b c )d e  - 4b c d e + 2c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                           2 4       2 3
+--R                     (- 16a c  + 4a b c )
+--R                  *
+--R                     ROOT
+--R                                4 2     3 2     2 4  8
+--R                            (- a c  + 2a b c - a b )e
+--R                          + 
+--R                                 3   2     2 3     7       3 3      2 2 2  2 6
+--R                            (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                          + 
+--R                               2   3 3 5         2 4       2 3  4 4
+--R                            48a b c d e  + (- 38a c  + 2a b c )d e
+--R                          + 
+--R                                    4 5 3        5 6 2    6 8
+--R                            - 8a b c d e  + 12a c d e  - c d
+--R                       /
+--R                             3 7      2 2 6
+--R                          64a c  - 16a b c
+--R                 + 
+--R                        2         3  4      2 2       2     3         2 2 2
+--R                   (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R                 + 
+--R                         3 3       3 4
+--R                   - 8a c d e + b c d
+--R              /
+--R                   2 4       2 3
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                             3   4     2 3 3  2         3 5      2 2 4
+--R                         (16a b c  - 4a b c )e  + (- 64a c  + 16a b c )d e
+--R                       + 
+--R                             2   5       3 4  2
+--R                         (16a b c  - 4a b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                               3 7      2 2 6
+--R                            64a c  - 16a b c
+--R                   + 
+--R                        4 2     3 2     2 4  6       3   2     2 3     5
+--R                     (4a c  - 5a b c + a b )e  + (16a b c  - 4a b c)d e
+--R                   + 
+--R                           3 3      2 2 2      4   2 4
+--R                     (- 28a c  + 11a b c  - a b c)d e
+--R                   + 
+--R                           2   3       3 2  3 3       2 4       2 3  4 2
+--R                     (- 16a b c  + 4a b c )d e  + (28a c  - 7a b c )d e
+--R                   + 
+--R                            5    2 4  6
+--R                     (- 4a c  + b c )d
+--R                *
+--R                   ROOT
+--R                                  2 4       2 3
+--R                            (- 16a c  + 4a b c )
+--R                         *
+--R                            ROOT
+--R                                       4 2     3 2     2 4  8
+--R                                   (- a c  + 2a b c - a b )e
+--R                                 + 
+--R                                        3   2     2 3     7
+--R                                   (- 8a b c  + 8a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 6      2   3 3 5
+--R                                   (12a c  - 28a b c )d e  + 48a b c d e
+--R                                 + 
+--R                                         2 4       2 3  4 4         4 5 3
+--R                                   (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                 + 
+--R                                        5 6 2    6 8
+--R                                   12a c d e  - c d
+--R                              /
+--R                                    3 7      2 2 6
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                               2         3  4      2 2       2     3
+--R                          (- 3a b c + a b )e  + (8a c  - 4a b c)d e
+--R                        + 
+--R                                2 2 2       3 3       3 4
+--R                          6a b c d e  - 8a c d e + b c d
+--R                     /
+--R                          2 4       2 3
+--R                        8a c  - 2a b c
+--R               + 
+--R                        4      3 2  8      3        2 3    7
+--R                     (2a c - 2a b )e  + (4a b c + 4a b )d e
+--R                   + 
+--R                          3 2      2 2        4  2 6       2   2        3   3 5
+--R                     (- 8a c  - 18a b c - 2a b )d e  + (36a b c  + 12a b c)d e
+--R                   + 
+--R                           2 3        2 2  4 4          3 5 3
+--R                     (- 20a c  - 30a b c )d e  + 28a b c d e
+--R                   + 
+--R                            4     2 3  6 2       4 7      5 8
+--R                     (- 8a c  + 2b c )d e  - 4b c d e + 2c d
+--R                *
+--R                   x
+--R     + 
+--R         c
+--R      *
+--R         ROOT
+--R                        2 4       2 3
+--R                  (- 16a c  + 4a b c )
+--R               *
+--R                  ROOT
+--R                             4 2     3 2     2 4  8        3   2     2 3     7
+--R                         (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                       + 
+--R                             3 3      2 2 2  2 6      2   3 3 5
+--R                         (12a c  - 28a b c )d e  + 48a b c d e
+--R                       + 
+--R                               2 4       2 3  4 4         4 5 3        5 6 2
+--R                         (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                       + 
+--R                            6 8
+--R                         - c d
+--R                    /
+--R                          3 7      2 2 6
+--R                       64a c  - 16a b c
+--R              + 
+--R                     2         3  4      2 2       2     3         2 2 2
+--R                (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R              + 
+--R                      3 3       3 4
+--R                - 8a c d e + b c d
+--R           /
+--R                2 4       2 3
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                            3   4     2 3 3  2       3 5      2 2 4
+--R                      (- 16a b c  + 4a b c )e  + (64a c  - 16a b c )d e
+--R                    + 
+--R                            2   5       3 4  2
+--R                      (- 16a b c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               4 2     3 2     2 4  8        3   2     2 3     7
+--R                           (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                         + 
+--R                               3 3      2 2 2  2 6      2   3 3 5
+--R                           (12a c  - 28a b c )d e  + 48a b c d e
+--R                         + 
+--R                                 2 4       2 3  4 4         4 5 3        5 6 2
+--R                           (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                         + 
+--R                              6 8
+--R                           - c d
+--R                      /
+--R                            3 7      2 2 6
+--R                         64a c  - 16a b c
+--R                + 
+--R                       4 2     3 2     2 4  6         3   2     2 3     5
+--R                  (- 4a c  + 5a b c - a b )e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                      3 3      2 2 2      4   2 4       2   3       3 2  3 3
+--R                  (28a c  - 11a b c  + a b c)d e  + (16a b c  - 4a b c )d e
+--R                + 
+--R                        2 4       2 3  4 2        5    2 4  6
+--R                  (- 28a c  + 7a b c )d e  + (4a c  - b c )d
+--R             *
+--R                ROOT
+--R                               2 4       2 3
+--R                         (- 16a c  + 4a b c )
+--R                      *
+--R                         ROOT
+--R                                    4 2     3 2     2 4  8
+--R                                (- a c  + 2a b c - a b )e
+--R                              + 
+--R                                     3   2     2 3     7
+--R                                (- 8a b c  + 8a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 6      2   3 3 5
+--R                                (12a c  - 28a b c )d e  + 48a b c d e
+--R                              + 
+--R                                      2 4       2 3  4 4         4 5 3
+--R                                (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                              + 
+--R                                     5 6 2    6 8
+--R                                12a c d e  - c d
+--R                           /
+--R                                 3 7      2 2 6
+--R                              64a c  - 16a b c
+--R                     + 
+--R                            2         3  4      2 2       2     3         2 2 2
+--R                       (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R                     + 
+--R                             3 3       3 4
+--R                       - 8a c d e + b c d
+--R                  /
+--R                       2 4       2 3
+--R                     8a c  - 2a b c
+--R            + 
+--R                     4      3 2  8      3        2 3    7
+--R                  (2a c - 2a b )e  + (4a b c + 4a b )d e
+--R                + 
+--R                       3 2      2 2        4  2 6       2   2        3   3 5
+--R                  (- 8a c  - 18a b c - 2a b )d e  + (36a b c  + 12a b c)d e
+--R                + 
+--R                        2 3        2 2  4 4          3 5 3
+--R                  (- 20a c  - 30a b c )d e  + 28a b c d e
+--R                + 
+--R                         4     2 3  6 2       4 7      5 8
+--R                  (- 8a c  + 2b c )d e  - 4b c d e + 2c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                         2 4       2 3
+--R                     (16a c  - 4a b c )
+--R                  *
+--R                     ROOT
+--R                                4 2     3 2     2 4  8
+--R                            (- a c  + 2a b c - a b )e
+--R                          + 
+--R                                 3   2     2 3     7       3 3      2 2 2  2 6
+--R                            (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                          + 
+--R                               2   3 3 5         2 4       2 3  4 4
+--R                            48a b c d e  + (- 38a c  + 2a b c )d e
+--R                          + 
+--R                                    4 5 3        5 6 2    6 8
+--R                            - 8a b c d e  + 12a c d e  - c d
+--R                       /
+--R                             3 7      2 2 6
+--R                          64a c  - 16a b c
+--R                 + 
+--R                        2         3  4      2 2       2     3         2 2 2
+--R                   (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R                 + 
+--R                         3 3       3 4
+--R                   - 8a c d e + b c d
+--R              /
+--R                   2 4       2 3
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                               3   4     2 3 3  2       3 5      2 2 4
+--R                         (- 16a b c  + 4a b c )e  + (64a c  - 16a b c )d e
+--R                       + 
+--R                               2   5       3 4  2
+--R                         (- 16a b c  + 4a b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                               3 7      2 2 6
+--R                            64a c  - 16a b c
+--R                   + 
+--R                        4 2     3 2     2 4  6       3   2     2 3     5
+--R                     (4a c  - 5a b c + a b )e  + (16a b c  - 4a b c)d e
+--R                   + 
+--R                           3 3      2 2 2      4   2 4
+--R                     (- 28a c  + 11a b c  - a b c)d e
+--R                   + 
+--R                           2   3       3 2  3 3       2 4       2 3  4 2
+--R                     (- 16a b c  + 4a b c )d e  + (28a c  - 7a b c )d e
+--R                   + 
+--R                            5    2 4  6
+--R                     (- 4a c  + b c )d
+--R                *
+--R                   ROOT
+--R                                2 4       2 3
+--R                            (16a c  - 4a b c )
+--R                         *
+--R                            ROOT
+--R                                       4 2     3 2     2 4  8
+--R                                   (- a c  + 2a b c - a b )e
+--R                                 + 
+--R                                        3   2     2 3     7
+--R                                   (- 8a b c  + 8a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 6      2   3 3 5
+--R                                   (12a c  - 28a b c )d e  + 48a b c d e
+--R                                 + 
+--R                                         2 4       2 3  4 4         4 5 3
+--R                                   (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                 + 
+--R                                        5 6 2    6 8
+--R                                   12a c d e  - c d
+--R                              /
+--R                                    3 7      2 2 6
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                               2         3  4      2 2       2     3
+--R                          (- 3a b c + a b )e  + (8a c  - 4a b c)d e
+--R                        + 
+--R                                2 2 2       3 3       3 4
+--R                          6a b c d e  - 8a c d e + b c d
+--R                     /
+--R                          2 4       2 3
+--R                        8a c  - 2a b c
+--R               + 
+--R                        4      3 2  8      3        2 3    7
+--R                     (2a c - 2a b )e  + (4a b c + 4a b )d e
+--R                   + 
+--R                          3 2      2 2        4  2 6       2   2        3   3 5
+--R                     (- 8a c  - 18a b c - 2a b )d e  + (36a b c  + 12a b c)d e
+--R                   + 
+--R                           2 3        2 2  4 4          3 5 3
+--R                     (- 20a c  - 30a b c )d e  + 28a b c d e
+--R                   + 
+--R                            4     2 3  6 2       4 7      5 8
+--R                     (- 8a c  + 2b c )d e  - 4b c d e + 2c d
+--R                *
+--R                   x
+--R     + 
+--R         2
+--R       2e x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2810
+
+--S 2811 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------------------+
+--R               +-----------+     |   +-----------+
+--R           +-+ |          2  +-+ |   |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                      2 4       2 3
+--R                  (16a c  - 4a b c )
+--R               *
+--R                  ROOT
+--R                             4 2     3 2     2 4  8        3   2     2 3     7
+--R                         (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                       + 
+--R                             3 3      2 2 2  2 6      2   3 3 5
+--R                         (12a c  - 28a b c )d e  + 48a b c d e
+--R                       + 
+--R                               2 4       2 3  4 4         4 5 3        5 6 2
+--R                         (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                       + 
+--R                            6 8
+--R                         - c d
+--R                    /
+--R                          3 7      2 2 6
+--R                       64a c  - 16a b c
+--R              + 
+--R                     2         3  4      2 2       2     3         2 2 2
+--R                (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R              + 
+--R                      3 3       3 4
+--R                - 8a c d e + b c d
+--R           /
+--R                2 4       2 3
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          3   4     2 3 3  2         3 5      2 2 4
+--R                      (16a b c  - 4a b c )e  + (- 64a c  + 16a b c )d e
+--R                    + 
+--R                          2   5       3 4  2
+--R                      (16a b c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               4 2     3 2     2 4  8        3   2     2 3     7
+--R                           (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                         + 
+--R                               3 3      2 2 2  2 6      2   3 3 5
+--R                           (12a c  - 28a b c )d e  + 48a b c d e
+--R                         + 
+--R                                 2 4       2 3  4 4         4 5 3        5 6 2
+--R                           (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                         + 
+--R                              6 8
+--R                           - c d
+--R                      /
+--R                            3 7      2 2 6
+--R                         64a c  - 16a b c
+--R                + 
+--R                       4 2     3 2     2 4  6         3   2     2 3     5
+--R                  (- 4a c  + 5a b c - a b )e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                      3 3      2 2 2      4   2 4       2   3       3 2  3 3
+--R                  (28a c  - 11a b c  + a b c)d e  + (16a b c  - 4a b c )d e
+--R                + 
+--R                        2 4       2 3  4 2        5    2 4  6
+--R                  (- 28a c  + 7a b c )d e  + (4a c  - b c )d
+--R             *
+--R                ROOT
+--R                             2 4       2 3
+--R                         (16a c  - 4a b c )
+--R                      *
+--R                         ROOT
+--R                                    4 2     3 2     2 4  8
+--R                                (- a c  + 2a b c - a b )e
+--R                              + 
+--R                                     3   2     2 3     7
+--R                                (- 8a b c  + 8a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 6      2   3 3 5
+--R                                (12a c  - 28a b c )d e  + 48a b c d e
+--R                              + 
+--R                                      2 4       2 3  4 4         4 5 3
+--R                                (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                              + 
+--R                                     5 6 2    6 8
+--R                                12a c d e  - c d
+--R                           /
+--R                                 3 7      2 2 6
+--R                              64a c  - 16a b c
+--R                     + 
+--R                            2         3  4      2 2       2     3         2 2 2
+--R                       (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R                     + 
+--R                             3 3       3 4
+--R                       - 8a c d e + b c d
+--R                  /
+--R                       2 4       2 3
+--R                     8a c  - 2a b c
+--R            + 
+--R                     4      3 2  8      3        2 3    7
+--R                  (2a c - 2a b )e  + (4a b c + 4a b )d e
+--R                + 
+--R                       3 2      2 2        4  2 6       2   2        3   3 5
+--R                  (- 8a c  - 18a b c - 2a b )d e  + (36a b c  + 12a b c)d e
+--R                + 
+--R                        2 3        2 2  4 4          3 5 3
+--R                  (- 20a c  - 30a b c )d e  + 28a b c d e
+--R                + 
+--R                         4     2 3  6 2       4 7      5 8
+--R                  (- 8a c  + 2b c )d e  - 4b c d e + 2c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                    +--------------------+
+--R                  +-----------+     |   +-----------+
+--R              +-+ |          2  +-+ |   |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                           2 4       2 3
+--R                     (- 16a c  + 4a b c )
+--R                  *
+--R                     ROOT
+--R                                4 2     3 2     2 4  8
+--R                            (- a c  + 2a b c - a b )e
+--R                          + 
+--R                                 3   2     2 3     7       3 3      2 2 2  2 6
+--R                            (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                          + 
+--R                               2   3 3 5         2 4       2 3  4 4
+--R                            48a b c d e  + (- 38a c  + 2a b c )d e
+--R                          + 
+--R                                    4 5 3        5 6 2    6 8
+--R                            - 8a b c d e  + 12a c d e  - c d
+--R                       /
+--R                             3 7      2 2 6
+--R                          64a c  - 16a b c
+--R                 + 
+--R                        2         3  4      2 2       2     3         2 2 2
+--R                   (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R                 + 
+--R                         3 3       3 4
+--R                   - 8a c d e + b c d
+--R              /
+--R                   2 4       2 3
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                             3   4     2 3 3  2         3 5      2 2 4
+--R                         (16a b c  - 4a b c )e  + (- 64a c  + 16a b c )d e
+--R                       + 
+--R                             2   5       3 4  2
+--R                         (16a b c  - 4a b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                               3 7      2 2 6
+--R                            64a c  - 16a b c
+--R                   + 
+--R                        4 2     3 2     2 4  6       3   2     2 3     5
+--R                     (4a c  - 5a b c + a b )e  + (16a b c  - 4a b c)d e
+--R                   + 
+--R                           3 3      2 2 2      4   2 4
+--R                     (- 28a c  + 11a b c  - a b c)d e
+--R                   + 
+--R                           2   3       3 2  3 3       2 4       2 3  4 2
+--R                     (- 16a b c  + 4a b c )d e  + (28a c  - 7a b c )d e
+--R                   + 
+--R                            5    2 4  6
+--R                     (- 4a c  + b c )d
+--R                *
+--R                   ROOT
+--R                                  2 4       2 3
+--R                            (- 16a c  + 4a b c )
+--R                         *
+--R                            ROOT
+--R                                       4 2     3 2     2 4  8
+--R                                   (- a c  + 2a b c - a b )e
+--R                                 + 
+--R                                        3   2     2 3     7
+--R                                   (- 8a b c  + 8a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 6      2   3 3 5
+--R                                   (12a c  - 28a b c )d e  + 48a b c d e
+--R                                 + 
+--R                                         2 4       2 3  4 4         4 5 3
+--R                                   (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                 + 
+--R                                        5 6 2    6 8
+--R                                   12a c d e  - c d
+--R                              /
+--R                                    3 7      2 2 6
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                               2         3  4      2 2       2     3
+--R                          (- 3a b c + a b )e  + (8a c  - 4a b c)d e
+--R                        + 
+--R                                2 2 2       3 3       3 4
+--R                          6a b c d e  - 8a c d e + b c d
+--R                     /
+--R                          2 4       2 3
+--R                        8a c  - 2a b c
+--R               + 
+--R                        4      3 2  8      3        2 3    7
+--R                     (2a c - 2a b )e  + (4a b c + 4a b )d e
+--R                   + 
+--R                          3 2      2 2        4  2 6       2   2        3   3 5
+--R                     (- 8a c  - 18a b c - 2a b )d e  + (36a b c  + 12a b c)d e
+--R                   + 
+--R                           2 3        2 2  4 4          3 5 3
+--R                     (- 20a c  - 30a b c )d e  + 28a b c d e
+--R                   + 
+--R                            4     2 3  6 2       4 7      5 8
+--R                     (- 8a c  + 2b c )d e  - 4b c d e + 2c d
+--R                *
+--R                   x
+--R     + 
+--R                                 +--------------------+
+--R               +-----------+     |   +-----------+
+--R           +-+ |          2  +-+ |   |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        2 4       2 3
+--R                  (- 16a c  + 4a b c )
+--R               *
+--R                  ROOT
+--R                             4 2     3 2     2 4  8        3   2     2 3     7
+--R                         (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                       + 
+--R                             3 3      2 2 2  2 6      2   3 3 5
+--R                         (12a c  - 28a b c )d e  + 48a b c d e
+--R                       + 
+--R                               2 4       2 3  4 4         4 5 3        5 6 2
+--R                         (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                       + 
+--R                            6 8
+--R                         - c d
+--R                    /
+--R                          3 7      2 2 6
+--R                       64a c  - 16a b c
+--R              + 
+--R                     2         3  4      2 2       2     3         2 2 2
+--R                (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R              + 
+--R                      3 3       3 4
+--R                - 8a c d e + b c d
+--R           /
+--R                2 4       2 3
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            3   4     2 3 3  2       3 5      2 2 4
+--R                      (- 16a b c  + 4a b c )e  + (64a c  - 16a b c )d e
+--R                    + 
+--R                            2   5       3 4  2
+--R                      (- 16a b c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               4 2     3 2     2 4  8        3   2     2 3     7
+--R                           (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                         + 
+--R                               3 3      2 2 2  2 6      2   3 3 5
+--R                           (12a c  - 28a b c )d e  + 48a b c d e
+--R                         + 
+--R                                 2 4       2 3  4 4         4 5 3        5 6 2
+--R                           (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                         + 
+--R                              6 8
+--R                           - c d
+--R                      /
+--R                            3 7      2 2 6
+--R                         64a c  - 16a b c
+--R                + 
+--R                       4 2     3 2     2 4  6         3   2     2 3     5
+--R                  (- 4a c  + 5a b c - a b )e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                      3 3      2 2 2      4   2 4       2   3       3 2  3 3
+--R                  (28a c  - 11a b c  + a b c)d e  + (16a b c  - 4a b c )d e
+--R                + 
+--R                        2 4       2 3  4 2        5    2 4  6
+--R                  (- 28a c  + 7a b c )d e  + (4a c  - b c )d
+--R             *
+--R                ROOT
+--R                               2 4       2 3
+--R                         (- 16a c  + 4a b c )
+--R                      *
+--R                         ROOT
+--R                                    4 2     3 2     2 4  8
+--R                                (- a c  + 2a b c - a b )e
+--R                              + 
+--R                                     3   2     2 3     7
+--R                                (- 8a b c  + 8a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 6      2   3 3 5
+--R                                (12a c  - 28a b c )d e  + 48a b c d e
+--R                              + 
+--R                                      2 4       2 3  4 4         4 5 3
+--R                                (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                              + 
+--R                                     5 6 2    6 8
+--R                                12a c d e  - c d
+--R                           /
+--R                                 3 7      2 2 6
+--R                              64a c  - 16a b c
+--R                     + 
+--R                            2         3  4      2 2       2     3         2 2 2
+--R                       (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R                     + 
+--R                             3 3       3 4
+--R                       - 8a c d e + b c d
+--R                  /
+--R                       2 4       2 3
+--R                     8a c  - 2a b c
+--R            + 
+--R                     4      3 2  8      3        2 3    7
+--R                  (2a c - 2a b )e  + (4a b c + 4a b )d e
+--R                + 
+--R                       3 2      2 2        4  2 6       2   2        3   3 5
+--R                  (- 8a c  - 18a b c - 2a b )d e  + (36a b c  + 12a b c)d e
+--R                + 
+--R                        2 3        2 2  4 4          3 5 3
+--R                  (- 20a c  - 30a b c )d e  + 28a b c d e
+--R                + 
+--R                         4     2 3  6 2       4 7      5 8
+--R                  (- 8a c  + 2b c )d e  - 4b c d e + 2c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                    +--------------------+
+--R                  +-----------+     |   +-----------+
+--R              +-+ |          2  +-+ |   |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                         2 4       2 3
+--R                     (16a c  - 4a b c )
+--R                  *
+--R                     ROOT
+--R                                4 2     3 2     2 4  8
+--R                            (- a c  + 2a b c - a b )e
+--R                          + 
+--R                                 3   2     2 3     7       3 3      2 2 2  2 6
+--R                            (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                          + 
+--R                               2   3 3 5         2 4       2 3  4 4
+--R                            48a b c d e  + (- 38a c  + 2a b c )d e
+--R                          + 
+--R                                    4 5 3        5 6 2    6 8
+--R                            - 8a b c d e  + 12a c d e  - c d
+--R                       /
+--R                             3 7      2 2 6
+--R                          64a c  - 16a b c
+--R                 + 
+--R                        2         3  4      2 2       2     3         2 2 2
+--R                   (- 3a b c + a b )e  + (8a c  - 4a b c)d e  + 6a b c d e
+--R                 + 
+--R                         3 3       3 4
+--R                   - 8a c d e + b c d
+--R              /
+--R                   2 4       2 3
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                               3   4     2 3 3  2       3 5      2 2 4
+--R                         (- 16a b c  + 4a b c )e  + (64a c  - 16a b c )d e
+--R                       + 
+--R                               2   5       3 4  2
+--R                         (- 16a b c  + 4a b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                               3 7      2 2 6
+--R                            64a c  - 16a b c
+--R                   + 
+--R                        4 2     3 2     2 4  6       3   2     2 3     5
+--R                     (4a c  - 5a b c + a b )e  + (16a b c  - 4a b c)d e
+--R                   + 
+--R                           3 3      2 2 2      4   2 4
+--R                     (- 28a c  + 11a b c  - a b c)d e
+--R                   + 
+--R                           2   3       3 2  3 3       2 4       2 3  4 2
+--R                     (- 16a b c  + 4a b c )d e  + (28a c  - 7a b c )d e
+--R                   + 
+--R                            5    2 4  6
+--R                     (- 4a c  + b c )d
+--R                *
+--R                   ROOT
+--R                                2 4       2 3
+--R                            (16a c  - 4a b c )
+--R                         *
+--R                            ROOT
+--R                                       4 2     3 2     2 4  8
+--R                                   (- a c  + 2a b c - a b )e
+--R                                 + 
+--R                                        3   2     2 3     7
+--R                                   (- 8a b c  + 8a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 6      2   3 3 5
+--R                                   (12a c  - 28a b c )d e  + 48a b c d e
+--R                                 + 
+--R                                         2 4       2 3  4 4         4 5 3
+--R                                   (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                 + 
+--R                                        5 6 2    6 8
+--R                                   12a c d e  - c d
+--R                              /
+--R                                    3 7      2 2 6
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                               2         3  4      2 2       2     3
+--R                          (- 3a b c + a b )e  + (8a c  - 4a b c)d e
+--R                        + 
+--R                                2 2 2       3 3       3 4
+--R                          6a b c d e  - 8a c d e + b c d
+--R                     /
+--R                          2 4       2 3
+--R                        8a c  - 2a b c
+--R               + 
+--R                        4      3 2  8      3        2 3    7
+--R                     (2a c - 2a b )e  + (4a b c + 4a b )d e
+--R                   + 
+--R                          3 2      2 2        4  2 6       2   2        3   3 5
+--R                     (- 8a c  - 18a b c - 2a b )d e  + (36a b c  + 12a b c)d e
+--R                   + 
+--R                           2 3        2 2  4 4          3 5 3
+--R                     (- 20a c  - 30a b c )d e  + 28a b c d e
+--R                   + 
+--R                            4     2 3  6 2       4 7      5 8
+--R                     (- 8a c  + 2b c )d e  - 4b c d e + 2c d
+--R                *
+--R                   x
+--R     + 
+--R                           +-----------+
+--R               2           |          2              2  2                2 2
+--R         ((2b e  - 4c d e)\|- 4a c + b   + (4a c - 2b )e  + 4b c d e - 4c d )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                           +-----------+
+--R               2           |          2                2  2                2 2
+--R         ((2b e  - 4c d e)\|- 4a c + b   + (- 4a c + 2b )e  - 4b c d e + 4c d )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2811
+
+--S 2812 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2812
+
+)clear all
+
+--S 2813 of 3139
+t0:=(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2813
+
+--S 2814 of 3139
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(e+(2*c*d-b*e)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(e+(-2*c*d+b*e)/sqrt(b^2-_
+   4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2                | |          2
+--R         (e\|- 4a c + b   - b e + 2c d)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2                |   |          2
+--R         (e\|- 4a c + b   + b e - 2c d)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2814
+
+--S 2815 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R                                  +-------------------------+
+--R                                  |   2 4         2 2    2 4
+--R                    2 2       2   |- a e  + 2a c d e  - c d          2
+--R                (16a c  - 4a b c) |-------------------------  + a b e
+--R                                  |       3 3      2 2 2
+--R                                 \|    64a c  - 16a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                         3 2     2 2            2   2       3
+--R                    ((32a c  - 8a b c)e + (- 16a b c  + 4a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                         +-------------------------+
+--R                                         |   2 4         2 2    2 4
+--R                           2 2       2   |- a e  + 2a c d e  - c d          2
+--R                       (16a c  - 4a b c) |-------------------------  + a b e
+--R                                         |       3 3      2 2 2
+--R                                        \|    64a c  - 16a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 2 4           3         3      2 4
+--R              (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R       -
+--R            ROOT
+--R                                       +-------------------------+
+--R                                       |   2 4         2 2    2 4
+--R                         2 2       2   |- a e  + 2a c d e  - c d          2
+--R                   (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                       |       3 3      2 2 2
+--R                                      \|    64a c  - 16a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                            3 2     2 2            2   2       3
+--R                       ((32a c  - 8a b c)e + (- 16a b c  + 4a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                              +-------------------------+
+--R                                              |   2 4         2 2    2 4
+--R                                2 2       2   |- a e  + 2a c d e  - c d
+--R                          (- 16a c  + 4a b c) |-------------------------
+--R                                              |       3 3      2 2 2
+--R                                             \|    64a c  - 16a b c
+--R                        + 
+--R                               2                   2
+--R                          a b e  - 4a c d e + b c d
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    2 4           3         3      2 4
+--R                 (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R         ROOT
+--R                                    +-------------------------+
+--R                                    |   2 4         2 2    2 4
+--R                      2 2       2   |- a e  + 2a c d e  - c d          2
+--R                (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                    |       3 3      2 2 2
+--R                                   \|    64a c  - 16a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                           3 2     2 2          2   2       3
+--R                    ((- 32a c  + 8a b c)e + (16a b c  - 4a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                           +-------------------------+
+--R                                           |   2 4         2 2    2 4
+--R                             2 2       2   |- a e  + 2a c d e  - c d          2
+--R                       (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                           |       3 3      2 2 2
+--R                                          \|    64a c  - 16a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 2 4           3         3      2 4
+--R              (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R       -
+--R            ROOT
+--R                                     +-------------------------+
+--R                                     |   2 4         2 2    2 4
+--R                       2 2       2   |- a e  + 2a c d e  - c d          2
+--R                   (16a c  - 4a b c) |-------------------------  + a b e
+--R                                     |       3 3      2 2 2
+--R                                    \|    64a c  - 16a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                              3 2     2 2          2   2       3
+--R                       ((- 32a c  + 8a b c)e + (16a b c  - 4a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                            +-------------------------+
+--R                                            |   2 4         2 2    2 4
+--R                              2 2       2   |- a e  + 2a c d e  - c d          2
+--R                          (16a c  - 4a b c) |-------------------------  + a b e
+--R                                            |       3 3      2 2 2
+--R                                           \|    64a c  - 16a b c
+--R                        + 
+--R                                            2
+--R                          - 4a c d e + b c d
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    2 4           3         3      2 4
+--R                 (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2815
+
+--S 2816 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +--------------------+
+--R              +-----------+     |   +-----------+
+--R          +-+ |          2  +-+ |   |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                  +-------------------------+
+--R                                  |   2 4         2 2    2 4
+--R                    2 2       2   |- a e  + 2a c d e  - c d          2
+--R                (16a c  - 4a b c) |-------------------------  + a b e
+--R                                  |       3 3      2 2 2
+--R                                 \|    64a c  - 16a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                         3 2     2 2            2   2       3
+--R                    ((32a c  - 8a b c)e + (- 16a b c  + 4a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                         +-------------------------+
+--R                                         |   2 4         2 2    2 4
+--R                           2 2       2   |- a e  + 2a c d e  - c d          2
+--R                       (16a c  - 4a b c) |-------------------------  + a b e
+--R                                         |       3 3      2 2 2
+--R                                        \|    64a c  - 16a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 2 4           3         3      2 4
+--R              (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R       -
+--R                                   +--------------------+
+--R                 +-----------+     |   +-----------+
+--R             +-+ |          2  +-+ |   |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                       +-------------------------+
+--R                                       |   2 4         2 2    2 4
+--R                         2 2       2   |- a e  + 2a c d e  - c d          2
+--R                   (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                       |       3 3      2 2 2
+--R                                      \|    64a c  - 16a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                            3 2     2 2            2   2       3
+--R                       ((32a c  - 8a b c)e + (- 16a b c  + 4a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                              +-------------------------+
+--R                                              |   2 4         2 2    2 4
+--R                                2 2       2   |- a e  + 2a c d e  - c d
+--R                          (- 16a c  + 4a b c) |-------------------------
+--R                                              |       3 3      2 2 2
+--R                                             \|    64a c  - 16a b c
+--R                        + 
+--R                               2                   2
+--R                          a b e  - 4a c d e + b c d
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    2 4           3         3      2 4
+--R                 (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R                                +--------------------+
+--R              +-----------+     |   +-----------+
+--R          +-+ |          2  +-+ |   |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                    +-------------------------+
+--R                                    |   2 4         2 2    2 4
+--R                      2 2       2   |- a e  + 2a c d e  - c d          2
+--R                (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                    |       3 3      2 2 2
+--R                                   \|    64a c  - 16a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                           3 2     2 2          2   2       3
+--R                    ((- 32a c  + 8a b c)e + (16a b c  - 4a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                           +-------------------------+
+--R                                           |   2 4         2 2    2 4
+--R                             2 2       2   |- a e  + 2a c d e  - c d          2
+--R                       (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                           |       3 3      2 2 2
+--R                                          \|    64a c  - 16a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 2 4           3         3      2 4
+--R              (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R       -
+--R                                   +--------------------+
+--R                 +-----------+     |   +-----------+
+--R             +-+ |          2  +-+ |   |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                     +-------------------------+
+--R                                     |   2 4         2 2    2 4
+--R                       2 2       2   |- a e  + 2a c d e  - c d          2
+--R                   (16a c  - 4a b c) |-------------------------  + a b e
+--R                                     |       3 3      2 2 2
+--R                                    \|    64a c  - 16a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                              3 2     2 2          2   2       3
+--R                       ((- 32a c  + 8a b c)e + (16a b c  - 4a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                            +-------------------------+
+--R                                            |   2 4         2 2    2 4
+--R                              2 2       2   |- a e  + 2a c d e  - c d          2
+--R                          (16a c  - 4a b c) |-------------------------  + a b e
+--R                                            |       3 3      2 2 2
+--R                                           \|    64a c  - 16a b c
+--R                        + 
+--R                                            2
+--R                          - 4a c d e + b c d
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    2 4           3         3      2 4
+--R                 (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R                                            +------------------+
+--R               +-----------+                | +-----------+
+--R               |          2                 | |          2
+--R         (- 2e\|- 4a c + b   + 2b e - 4c d)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R               +-----------+                |   +-----------+
+--R               |          2                 |   |          2
+--R         (- 2e\|- 4a c + b   - 2b e + 4c d)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2816
+
+--S 2817 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2817
+
+)clear all
+
+--S 2818 of 3139
+t0:=1/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2818
+
+--S 2819 of 3139
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/_
+   (sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                +------------------+
+--R                | +-----------+                   +-+ +-+
+--R        +-+ +-+ | |          2                  x\|2 \|c
+--R       \|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                          +--------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + b
+--R     + 
+--R                  +--------------------+
+--R                  |   +-----------+                  +-+ +-+
+--R          +-+ +-+ |   |          2                 x\|2 \|c
+--R       - \|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                              | |          2
+--R                                             \|\|- 4a c + b   + b
+--R  /
+--R                    +--------------------+ +------------------+
+--R      +-----------+ |   +-----------+      | +-----------+
+--R      |          2  |   |          2       | |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2819
+
+--S 2820 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +--------------------------------------+
+--R          |                +----------------+
+--R          |    2        2  |         1
+--R          |(16a c - 4a b ) |- --------------  + b
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |--------------------------------------
+--R          |               2        2
+--R         \|             8a c - 2a b
+--R      *
+--R         log
+--R                                   +----------------+
+--R                     2          3  |         1                  2
+--R                ((16a b c - 4a b ) |- --------------  + 4a c - b )
+--R                                   |     3       2 2
+--R                                  \|  64a c - 16a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |                +----------------+
+--R                 |    2        2  |         1
+--R                 |(16a c - 4a b ) |- --------------  + b
+--R                 |                |     3       2 2
+--R                 |               \|  64a c - 16a b
+--R                 |--------------------------------------
+--R                 |               2        2
+--R                \|             8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R             +----------------------------------------+
+--R             |                  +----------------+
+--R             |      2        2  |         1
+--R             |(- 16a c + 4a b ) |- --------------  + b
+--R             |                  |     3       2 2
+--R             |                 \|  64a c - 16a b
+--R             |----------------------------------------
+--R             |                2        2
+--R            \|              8a c - 2a b
+--R         *
+--R            log
+--R                                      +----------------+
+--R                        2          3  |         1                  2
+--R                   ((16a b c - 4a b ) |- --------------  - 4a c + b )
+--R                                      |     3       2 2
+--R                                     \|  64a c - 16a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |                  +----------------+
+--R                    |      2        2  |         1
+--R                    |(- 16a c + 4a b ) |- --------------  + b
+--R                    |                  |     3       2 2
+--R                    |                 \|  64a c - 16a b
+--R                    |----------------------------------------
+--R                    |                2        2
+--R                   \|              8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R          +----------------------------------------+
+--R          |                  +----------------+
+--R          |      2        2  |         1
+--R          |(- 16a c + 4a b ) |- --------------  + b
+--R          |                  |     3       2 2
+--R          |                 \|  64a c - 16a b
+--R          |----------------------------------------
+--R          |                2        2
+--R         \|              8a c - 2a b
+--R      *
+--R         log
+--R                                     +----------------+
+--R                       2          3  |         1                  2
+--R                ((- 16a b c + 4a b ) |- --------------  + 4a c - b )
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |                  +----------------+
+--R                 |      2        2  |         1
+--R                 |(- 16a c + 4a b ) |- --------------  + b
+--R                 |                  |     3       2 2
+--R                 |                 \|  64a c - 16a b
+--R                 |----------------------------------------
+--R                 |                2        2
+--R                \|              8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R             +--------------------------------------+
+--R             |                +----------------+
+--R             |    2        2  |         1
+--R             |(16a c - 4a b ) |- --------------  + b
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |--------------------------------------
+--R             |               2        2
+--R            \|             8a c - 2a b
+--R         *
+--R            log
+--R                                        +----------------+
+--R                          2          3  |         1                  2
+--R                   ((- 16a b c + 4a b ) |- --------------  - 4a c + b )
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |                +----------------+
+--R                    |    2        2  |         1
+--R                    |(16a c - 4a b ) |- --------------  + b
+--R                    |                |     3       2 2
+--R                    |               \|  64a c - 16a b
+--R                    |--------------------------------------
+--R                    |               2        2
+--R                   \|             8a c - 2a b
+--R               + 
+--R                 2c x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2820
+
+--S 2821 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2  |   |          2       | |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +--------------------------------------+
+--R          |                +----------------+
+--R          |    2        2  |         1
+--R          |(16a c - 4a b ) |- --------------  + b
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |--------------------------------------
+--R          |               2        2
+--R         \|             8a c - 2a b
+--R      *
+--R         log
+--R                                   +----------------+
+--R                     2          3  |         1                  2
+--R                ((16a b c - 4a b ) |- --------------  + 4a c - b )
+--R                                   |     3       2 2
+--R                                  \|  64a c - 16a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |                +----------------+
+--R                 |    2        2  |         1
+--R                 |(16a c - 4a b ) |- --------------  + b
+--R                 |                |     3       2 2
+--R                 |               \|  64a c - 16a b
+--R                 |--------------------------------------
+--R                 |               2        2
+--R                \|             8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R                           +----------------------------------------+
+--R                           |                  +----------------+
+--R                           |      2        2  |         1
+--R                           |(- 16a c + 4a b ) |- --------------  + b
+--R             +-----------+ |                  |     3       2 2
+--R             |          2  |                 \|  64a c - 16a b
+--R            \|- 4a c + b   |----------------------------------------
+--R                           |                2        2
+--R                          \|              8a c - 2a b
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                      +----------------+
+--R                        2          3  |         1                  2
+--R                   ((16a b c - 4a b ) |- --------------  - 4a c + b )
+--R                                      |     3       2 2
+--R                                     \|  64a c - 16a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |                  +----------------+
+--R                    |      2        2  |         1
+--R                    |(- 16a c + 4a b ) |- --------------  + b
+--R                    |                  |     3       2 2
+--R                    |                 \|  64a c - 16a b
+--R                    |----------------------------------------
+--R                    |                2        2
+--R                   \|              8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R                        +----------------------------------------+
+--R                        |                  +----------------+
+--R                        |      2        2  |         1
+--R                        |(- 16a c + 4a b ) |- --------------  + b
+--R          +-----------+ |                  |     3       2 2
+--R          |          2  |                 \|  64a c - 16a b
+--R         \|- 4a c + b   |----------------------------------------
+--R                        |                2        2
+--R                       \|              8a c - 2a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                     +----------------+
+--R                       2          3  |         1                  2
+--R                ((- 16a b c + 4a b ) |- --------------  + 4a c - b )
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |                  +----------------+
+--R                 |      2        2  |         1
+--R                 |(- 16a c + 4a b ) |- --------------  + b
+--R                 |                  |     3       2 2
+--R                 |                 \|  64a c - 16a b
+--R                 |----------------------------------------
+--R                 |                2        2
+--R                \|              8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R             |          2  |   |          2       | |          2
+--R            \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +--------------------------------------+
+--R             |                +----------------+
+--R             |    2        2  |         1
+--R             |(16a c - 4a b ) |- --------------  + b
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |--------------------------------------
+--R             |               2        2
+--R            \|             8a c - 2a b
+--R         *
+--R            log
+--R                                        +----------------+
+--R                          2          3  |         1                  2
+--R                   ((- 16a b c + 4a b ) |- --------------  - 4a c + b )
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |                +----------------+
+--R                    |    2        2  |         1
+--R                    |(16a c - 4a b ) |- --------------  + b
+--R                    |                |     3       2 2
+--R                    |               \|  64a c - 16a b
+--R                    |--------------------------------------
+--R                    |               2        2
+--R                   \|             8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R                   +------------------+
+--R                   | +-----------+                   +-+ +-+
+--R           +-+ +-+ | |          2                  x\|2 \|c
+--R       - 2\|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                             +--------------------+
+--R                                             |   +-----------+
+--R                                             |   |          2
+--R                                            \|- \|- 4a c + b   + b
+--R     + 
+--R                 +--------------------+
+--R                 |   +-----------+                  +-+ +-+
+--R         +-+ +-+ |   |          2                 x\|2 \|c
+--R       2\|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                             | |          2
+--R                                            \|\|- 4a c + b   + b
+--R  /
+--R                     +--------------------+ +------------------+
+--R       +-----------+ |   +-----------+      | +-----------+
+--R       |          2  |   |          2       | |          2
+--R     2\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2821
+
+--S 2822 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2822
+
+)clear all
+
+--S 2823 of 3139
+t0:=1/((d+e*x^2)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R             6               4               2
+--R        c e x  + (b e + c d)x  + (a e + b d)x  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2823
+
+--S 2824 of 3139
+r0:=e^(3/2)*atan(x*sqrt(e)/sqrt(d))/((c*d^2-b*d*e+a*e^2)*sqrt(d))-_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(e+_
+   (-2*c*d+b*e)/sqrt(b^2-4*a*c))/((c*d^2-b*d*e+a*e^2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/((c*d^2-b*d*e+a*e^2)*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                  +------------------+
+--R              +-----------+                       | +-----------+
+--R              |          2                +-+ +-+ | |          2
+--R         (- e\|- 4a c + b   - b e + 2c d)\|c \|d \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                  +--------------------+
+--R              +-----------+                       |   +-----------+
+--R              |          2                +-+ +-+ |   |          2
+--R         (- e\|- 4a c + b   + b e - 2c d)\|c \|d \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R               +-----------+           +-+  |   +-----------+
+--R           +-+ |          2  +-+     x\|e   |   |          2
+--R         e\|2 \|- 4a c + b  \|e atan(-----)\|- \|- 4a c + b   + b
+--R                                       +-+
+--R                                      \|d
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                                                   +--------------------+
+--R                                 +-----------+     |   +-----------+
+--R           2              2  +-+ |          2  +-+ |   |          2
+--R       (a e  - b d e + c d )\|2 \|- 4a c + b  \|d \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2824
+
+--S 2825 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2              2
+--R           (- a e  + b d e - c d )
+--R        *
+--R           ROOT
+--R                          4      3 2  4         3        2 3    3
+--R                      (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                    + 
+--R                          3 2     2 2        4  2 2         2   2       3   3
+--R                      (32a c  + 8a b c - 4a b )d e  + (- 32a b c  + 8a b c)d e
+--R                    + 
+--R                          2 3       2 2  4
+--R                      (16a c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                               3  2        2     2           2 2
+--R                  (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R             /
+--R                     4      3 2  4         3        2 3    3
+--R                  (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                + 
+--R                      3 2     2 2        4  2 2         2   2       3   3
+--R                  (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                     2 3       2 2  4
+--R                  (8a c  - 2a b c )d
+--R        *
+--R           log
+--R                            5 2      4 2      3 4  5
+--R                        (32a c  - 24a b c + 4a b )e
+--R                      + 
+--R                              4   2      3 3      2 5    4
+--R                        (- 48a b c  + 44a b c - 8a b )d e
+--R                      + 
+--R                            4 3      3 2 2     2 4        6  2 3
+--R                        (64a c  - 48a b c  - 8a b c + 4a b )d e
+--R                      + 
+--R                              3   3      2 3 2        5   3 2
+--R                        (- 32a b c  + 56a b c  - 12a b c)d e
+--R                      + 
+--R                          3 4      2 2 3        4 2  4        2   4       3 3  5
+--R                      (32a c  - 56a b c  + 12a b c )d e + (16a b c  - 4a b c )d
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  4            2     3     3
+--R                             (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                           + 
+--R                                  3     2 2  2 2       3 3     4 4
+--R                             (2a c  - 6b c )d e  + 4b c d e - c d
+--R                        /
+--R                                 7       6 2  8          6         5 3    7
+--R                             (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                           + 
+--R                                  6 2       5 2       4 4  2 6
+--R                             (256a c  + 320a b c - 96a b )d e
+--R                           + 
+--R                                    5   2      4 3       3 5  3 5
+--R                             (- 768a b c  - 64a b c + 64a b )d e
+--R                           + 
+--R                                  5 3       4 2 2       3 4       2 6  4 4
+--R                             (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                           + 
+--R                                    4   3      3 3 2      2 5   5 3
+--R                             (- 768a b c  - 64a b c  + 64a b c)d e
+--R                           + 
+--R                                  4 4       3 2 3      2 4 2  6 2
+--R                             (256a c  + 320a b c  - 96a b c )d e
+--R                           + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                  + 
+--R                       2   2       3     5  3        2 3        2 2     4     2
+--R                    (4a b c  - 5a b c + b )e  + (- 4a c  + 13a b c  - 3b c)d e
+--R                  + 
+--R                              3     3 2  2         4    2 3  3
+--R                    (- 12a b c  + 3b c )d e + (4a c  - b c )d
+--R               *
+--R                  ROOT
+--R                                 4      3 2  4         3        2 3    3
+--R                             (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                           + 
+--R                                 3 2     2 2        4  2 2
+--R                             (32a c  + 8a b c - 4a b )d e
+--R                           + 
+--R                                   2   2       3   3        2 3       2 2  4
+--R                             (- 32a b c  + 8a b c)d e + (16a c  - 4a b c )d
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  4
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     3        3     2 2  2 2
+--R                                  (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                                + 
+--R                                      3 3     4 4
+--R                                  4b c d e - c d
+--R                             /
+--R                                      7       6 2  8          6         5 3    7
+--R                                  (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                                + 
+--R                                       6 2       5 2       4 4  2 6
+--R                                  (256a c  + 320a b c - 96a b )d e
+--R                                + 
+--R                                         5   2      4 3       3 5  3 5
+--R                                  (- 768a b c  - 64a b c + 64a b )d e
+--R                                + 
+--R                                       5 3       4 2 2       3 4       2 6  4 4
+--R                                  (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                                + 
+--R                                         4   3      3 3 2      2 5   5 3
+--R                                  (- 768a b c  - 64a b c  + 64a b c)d e
+--R                                + 
+--R                                       4 4       3 2 3      2 4 2  6 2
+--R                                  (256a c  + 320a b c  - 96a b c )d e
+--R                                + 
+--R                                         3   4      2 3 3  7
+--R                                  (- 256a b c  + 64a b c )d e
+--R                                + 
+--R                                      3 5      2 2 4  8
+--R                                  (64a c  - 16a b c )d
+--R                       + 
+--R                                      3  2        2     2           2 2
+--R                         (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                    /
+--R                            4      3 2  4         3        2 3    3
+--R                         (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                       + 
+--R                             3 2     2 2        4  2 2
+--R                         (16a c  + 4a b c - 2a b )d e
+--R                       + 
+--R                               2   2       3   3       2 3       2 2  4
+--R                         (- 16a b c  + 4a b c)d e + (8a c  - 2a b c )d
+--R              + 
+--R                      3     2 2  2       3        4 2
+--R                ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R       + 
+--R               2              2
+--R           (a e  - b d e + c d )
+--R        *
+--R           ROOT
+--R                            4      3 2  4       3        2 3    3
+--R                      (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                    + 
+--R                            3 2     2 2        4  2 2       2   2       3   3
+--R                      (- 32a c  - 8a b c + 4a b )d e  + (32a b c  - 8a b c)d e
+--R                    + 
+--R                            2 3       2 2  4
+--R                      (- 16a c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                               3  2        2     2           2 2
+--R                  (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R             /
+--R                     4      3 2  4         3        2 3    3
+--R                  (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                + 
+--R                      3 2     2 2        4  2 2         2   2       3   3
+--R                  (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                     2 3       2 2  4
+--R                  (8a c  - 2a b c )d
+--R        *
+--R           log
+--R                            5 2      4 2      3 4  5
+--R                        (32a c  - 24a b c + 4a b )e
+--R                      + 
+--R                              4   2      3 3      2 5    4
+--R                        (- 48a b c  + 44a b c - 8a b )d e
+--R                      + 
+--R                            4 3      3 2 2     2 4        6  2 3
+--R                        (64a c  - 48a b c  - 8a b c + 4a b )d e
+--R                      + 
+--R                              3   3      2 3 2        5   3 2
+--R                        (- 32a b c  + 56a b c  - 12a b c)d e
+--R                      + 
+--R                          3 4      2 2 3        4 2  4        2   4       3 3  5
+--R                      (32a c  - 56a b c  + 12a b c )d e + (16a b c  - 4a b c )d
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  4            2     3     3
+--R                             (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                           + 
+--R                                  3     2 2  2 2       3 3     4 4
+--R                             (2a c  - 6b c )d e  + 4b c d e - c d
+--R                        /
+--R                                 7       6 2  8          6         5 3    7
+--R                             (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                           + 
+--R                                  6 2       5 2       4 4  2 6
+--R                             (256a c  + 320a b c - 96a b )d e
+--R                           + 
+--R                                    5   2      4 3       3 5  3 5
+--R                             (- 768a b c  - 64a b c + 64a b )d e
+--R                           + 
+--R                                  5 3       4 2 2       3 4       2 6  4 4
+--R                             (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                           + 
+--R                                    4   3      3 3 2      2 5   5 3
+--R                             (- 768a b c  - 64a b c  + 64a b c)d e
+--R                           + 
+--R                                  4 4       3 2 3      2 4 2  6 2
+--R                             (256a c  + 320a b c  - 96a b c )d e
+--R                           + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                  + 
+--R                         2   2       3     5  3      2 3        2 2     4     2
+--R                    (- 4a b c  + 5a b c - b )e  + (4a c  - 13a b c  + 3b c)d e
+--R                  + 
+--R                            3     3 2  2           4    2 3  3
+--R                    (12a b c  - 3b c )d e + (- 4a c  + b c )d
+--R               *
+--R                  ROOT
+--R                                   4      3 2  4       3        2 3    3
+--R                             (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                           + 
+--R                                   3 2     2 2        4  2 2
+--R                             (- 32a c  - 8a b c + 4a b )d e
+--R                           + 
+--R                                 2   2       3   3          2 3       2 2  4
+--R                             (32a b c  - 8a b c)d e + (- 16a c  + 4a b c )d
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  4
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     3        3     2 2  2 2
+--R                                  (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                                + 
+--R                                      3 3     4 4
+--R                                  4b c d e - c d
+--R                             /
+--R                                      7       6 2  8          6         5 3    7
+--R                                  (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                                + 
+--R                                       6 2       5 2       4 4  2 6
+--R                                  (256a c  + 320a b c - 96a b )d e
+--R                                + 
+--R                                         5   2      4 3       3 5  3 5
+--R                                  (- 768a b c  - 64a b c + 64a b )d e
+--R                                + 
+--R                                       5 3       4 2 2       3 4       2 6  4 4
+--R                                  (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                                + 
+--R                                         4   3      3 3 2      2 5   5 3
+--R                                  (- 768a b c  - 64a b c  + 64a b c)d e
+--R                                + 
+--R                                       4 4       3 2 3      2 4 2  6 2
+--R                                  (256a c  + 320a b c  - 96a b c )d e
+--R                                + 
+--R                                         3   4      2 3 3  7
+--R                                  (- 256a b c  + 64a b c )d e
+--R                                + 
+--R                                      3 5      2 2 4  8
+--R                                  (64a c  - 16a b c )d
+--R                       + 
+--R                                      3  2        2     2           2 2
+--R                         (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                    /
+--R                            4      3 2  4         3        2 3    3
+--R                         (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                       + 
+--R                             3 2     2 2        4  2 2
+--R                         (16a c  + 4a b c - 2a b )d e
+--R                       + 
+--R                               2   2       3   3       2 3       2 2  4
+--R                         (- 16a b c  + 4a b c)d e + (8a c  - 2a b c )d
+--R              + 
+--R                      3     2 2  2       3        4 2
+--R                ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R       + 
+--R                 2              2
+--R           (- a e  + b d e - c d )
+--R        *
+--R           ROOT
+--R                            4      3 2  4       3        2 3    3
+--R                      (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                    + 
+--R                            3 2     2 2        4  2 2       2   2       3   3
+--R                      (- 32a c  - 8a b c + 4a b )d e  + (32a b c  - 8a b c)d e
+--R                    + 
+--R                            2 3       2 2  4
+--R                      (- 16a c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                               3  2        2     2           2 2
+--R                  (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R             /
+--R                     4      3 2  4         3        2 3    3
+--R                  (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                + 
+--R                      3 2     2 2        4  2 2         2   2       3   3
+--R                  (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                     2 3       2 2  4
+--R                  (8a c  - 2a b c )d
+--R        *
+--R           log
+--R                              5 2      4 2      3 4  5
+--R                        (- 32a c  + 24a b c - 4a b )e
+--R                      + 
+--R                            4   2      3 3      2 5    4
+--R                        (48a b c  - 44a b c + 8a b )d e
+--R                      + 
+--R                              4 3      3 2 2     2 4        6  2 3
+--R                        (- 64a c  + 48a b c  + 8a b c - 4a b )d e
+--R                      + 
+--R                            3   3      2 3 2        5   3 2
+--R                        (32a b c  - 56a b c  + 12a b c)d e
+--R                      + 
+--R                              3 4      2 2 3        4 2  4
+--R                        (- 32a c  + 56a b c  - 12a b c )d e
+--R                      + 
+--R                              2   4       3 3  5
+--R                        (- 16a b c  + 4a b c )d
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  4            2     3     3
+--R                             (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                           + 
+--R                                  3     2 2  2 2       3 3     4 4
+--R                             (2a c  - 6b c )d e  + 4b c d e - c d
+--R                        /
+--R                                 7       6 2  8          6         5 3    7
+--R                             (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                           + 
+--R                                  6 2       5 2       4 4  2 6
+--R                             (256a c  + 320a b c - 96a b )d e
+--R                           + 
+--R                                    5   2      4 3       3 5  3 5
+--R                             (- 768a b c  - 64a b c + 64a b )d e
+--R                           + 
+--R                                  5 3       4 2 2       3 4       2 6  4 4
+--R                             (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                           + 
+--R                                    4   3      3 3 2      2 5   5 3
+--R                             (- 768a b c  - 64a b c  + 64a b c)d e
+--R                           + 
+--R                                  4 4       3 2 3      2 4 2  6 2
+--R                             (256a c  + 320a b c  - 96a b c )d e
+--R                           + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                  + 
+--R                       2   2       3     5  3        2 3        2 2     4     2
+--R                    (4a b c  - 5a b c + b )e  + (- 4a c  + 13a b c  - 3b c)d e
+--R                  + 
+--R                              3     3 2  2         4    2 3  3
+--R                    (- 12a b c  + 3b c )d e + (4a c  - b c )d
+--R               *
+--R                  ROOT
+--R                                   4      3 2  4       3        2 3    3
+--R                             (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                           + 
+--R                                   3 2     2 2        4  2 2
+--R                             (- 32a c  - 8a b c + 4a b )d e
+--R                           + 
+--R                                 2   2       3   3          2 3       2 2  4
+--R                             (32a b c  - 8a b c)d e + (- 16a c  + 4a b c )d
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  4
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     3        3     2 2  2 2
+--R                                  (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                                + 
+--R                                      3 3     4 4
+--R                                  4b c d e - c d
+--R                             /
+--R                                      7       6 2  8          6         5 3    7
+--R                                  (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                                + 
+--R                                       6 2       5 2       4 4  2 6
+--R                                  (256a c  + 320a b c - 96a b )d e
+--R                                + 
+--R                                         5   2      4 3       3 5  3 5
+--R                                  (- 768a b c  - 64a b c + 64a b )d e
+--R                                + 
+--R                                       5 3       4 2 2       3 4       2 6  4 4
+--R                                  (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                                + 
+--R                                         4   3      3 3 2      2 5   5 3
+--R                                  (- 768a b c  - 64a b c  + 64a b c)d e
+--R                                + 
+--R                                       4 4       3 2 3      2 4 2  6 2
+--R                                  (256a c  + 320a b c  - 96a b c )d e
+--R                                + 
+--R                                         3   4      2 3 3  7
+--R                                  (- 256a b c  + 64a b c )d e
+--R                                + 
+--R                                      3 5      2 2 4  8
+--R                                  (64a c  - 16a b c )d
+--R                       + 
+--R                                      3  2        2     2           2 2
+--R                         (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                    /
+--R                            4      3 2  4         3        2 3    3
+--R                         (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                       + 
+--R                             3 2     2 2        4  2 2
+--R                         (16a c  + 4a b c - 2a b )d e
+--R                       + 
+--R                               2   2       3   3       2 3       2 2  4
+--R                         (- 16a b c  + 4a b c)d e + (8a c  - 2a b c )d
+--R              + 
+--R                      3     2 2  2       3        4 2
+--R                ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R       + 
+--R               2              2
+--R           (a e  - b d e + c d )
+--R        *
+--R           ROOT
+--R                          4      3 2  4         3        2 3    3
+--R                      (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                    + 
+--R                          3 2     2 2        4  2 2         2   2       3   3
+--R                      (32a c  + 8a b c - 4a b )d e  + (- 32a b c  + 8a b c)d e
+--R                    + 
+--R                          2 3       2 2  4
+--R                      (16a c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                               3  2        2     2           2 2
+--R                  (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R             /
+--R                     4      3 2  4         3        2 3    3
+--R                  (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                + 
+--R                      3 2     2 2        4  2 2         2   2       3   3
+--R                  (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                     2 3       2 2  4
+--R                  (8a c  - 2a b c )d
+--R        *
+--R           log
+--R                              5 2      4 2      3 4  5
+--R                        (- 32a c  + 24a b c - 4a b )e
+--R                      + 
+--R                            4   2      3 3      2 5    4
+--R                        (48a b c  - 44a b c + 8a b )d e
+--R                      + 
+--R                              4 3      3 2 2     2 4        6  2 3
+--R                        (- 64a c  + 48a b c  + 8a b c - 4a b )d e
+--R                      + 
+--R                            3   3      2 3 2        5   3 2
+--R                        (32a b c  - 56a b c  + 12a b c)d e
+--R                      + 
+--R                              3 4      2 2 3        4 2  4
+--R                        (- 32a c  + 56a b c  - 12a b c )d e
+--R                      + 
+--R                              2   4       3 3  5
+--R                        (- 16a b c  + 4a b c )d
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  4            2     3     3
+--R                             (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                           + 
+--R                                  3     2 2  2 2       3 3     4 4
+--R                             (2a c  - 6b c )d e  + 4b c d e - c d
+--R                        /
+--R                                 7       6 2  8          6         5 3    7
+--R                             (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                           + 
+--R                                  6 2       5 2       4 4  2 6
+--R                             (256a c  + 320a b c - 96a b )d e
+--R                           + 
+--R                                    5   2      4 3       3 5  3 5
+--R                             (- 768a b c  - 64a b c + 64a b )d e
+--R                           + 
+--R                                  5 3       4 2 2       3 4       2 6  4 4
+--R                             (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                           + 
+--R                                    4   3      3 3 2      2 5   5 3
+--R                             (- 768a b c  - 64a b c  + 64a b c)d e
+--R                           + 
+--R                                  4 4       3 2 3      2 4 2  6 2
+--R                             (256a c  + 320a b c  - 96a b c )d e
+--R                           + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                  + 
+--R                         2   2       3     5  3      2 3        2 2     4     2
+--R                    (- 4a b c  + 5a b c - b )e  + (4a c  - 13a b c  + 3b c)d e
+--R                  + 
+--R                            3     3 2  2           4    2 3  3
+--R                    (12a b c  - 3b c )d e + (- 4a c  + b c )d
+--R               *
+--R                  ROOT
+--R                                 4      3 2  4         3        2 3    3
+--R                             (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                           + 
+--R                                 3 2     2 2        4  2 2
+--R                             (32a c  + 8a b c - 4a b )d e
+--R                           + 
+--R                                   2   2       3   3        2 3       2 2  4
+--R                             (- 32a b c  + 8a b c)d e + (16a c  - 4a b c )d
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  4
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     3        3     2 2  2 2
+--R                                  (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                                + 
+--R                                      3 3     4 4
+--R                                  4b c d e - c d
+--R                             /
+--R                                      7       6 2  8          6         5 3    7
+--R                                  (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                                + 
+--R                                       6 2       5 2       4 4  2 6
+--R                                  (256a c  + 320a b c - 96a b )d e
+--R                                + 
+--R                                         5   2      4 3       3 5  3 5
+--R                                  (- 768a b c  - 64a b c + 64a b )d e
+--R                                + 
+--R                                       5 3       4 2 2       3 4       2 6  4 4
+--R                                  (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                                + 
+--R                                         4   3      3 3 2      2 5   5 3
+--R                                  (- 768a b c  - 64a b c  + 64a b c)d e
+--R                                + 
+--R                                       4 4       3 2 3      2 4 2  6 2
+--R                                  (256a c  + 320a b c  - 96a b c )d e
+--R                                + 
+--R                                         3   4      2 3 3  7
+--R                                  (- 256a b c  + 64a b c )d e
+--R                                + 
+--R                                      3 5      2 2 4  8
+--R                                  (64a c  - 16a b c )d
+--R                       + 
+--R                                      3  2        2     2           2 2
+--R                         (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                    /
+--R                            4      3 2  4         3        2 3    3
+--R                         (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                       + 
+--R                             3 2     2 2        4  2 2
+--R                         (16a c  + 4a b c - 2a b )d e
+--R                       + 
+--R                               2   2       3   3       2 3       2 2  4
+--R                         (- 16a b c  + 4a b c)d e + (8a c  - 2a b c )d
+--R              + 
+--R                      3     2 2  2       3        4 2
+--R                ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R       + 
+--R                         +---+
+--R                         |  e       2
+--R           +---+    2d x |- -  + e x  - d
+--R           |  e         \|  d
+--R         e |- - log(---------------------)
+--R          \|  d               2
+--R                           e x  + d
+--R    /
+--R           2                2
+--R       2a e  - 2b d e + 2c d
+--R     ,
+--R
+--R                 2              2
+--R           (- a e  + b d e - c d )
+--R        *
+--R           ROOT
+--R                          4      3 2  4         3        2 3    3
+--R                      (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                    + 
+--R                          3 2     2 2        4  2 2         2   2       3   3
+--R                      (32a c  + 8a b c - 4a b )d e  + (- 32a b c  + 8a b c)d e
+--R                    + 
+--R                          2 3       2 2  4
+--R                      (16a c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                               3  2        2     2           2 2
+--R                  (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R             /
+--R                     4      3 2  4         3        2 3    3
+--R                  (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                + 
+--R                      3 2     2 2        4  2 2         2   2       3   3
+--R                  (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                     2 3       2 2  4
+--R                  (8a c  - 2a b c )d
+--R        *
+--R           log
+--R                            5 2      4 2      3 4  5
+--R                        (32a c  - 24a b c + 4a b )e
+--R                      + 
+--R                              4   2      3 3      2 5    4
+--R                        (- 48a b c  + 44a b c - 8a b )d e
+--R                      + 
+--R                            4 3      3 2 2     2 4        6  2 3
+--R                        (64a c  - 48a b c  - 8a b c + 4a b )d e
+--R                      + 
+--R                              3   3      2 3 2        5   3 2
+--R                        (- 32a b c  + 56a b c  - 12a b c)d e
+--R                      + 
+--R                          3 4      2 2 3        4 2  4        2   4       3 3  5
+--R                      (32a c  - 56a b c  + 12a b c )d e + (16a b c  - 4a b c )d
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  4            2     3     3
+--R                             (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                           + 
+--R                                  3     2 2  2 2       3 3     4 4
+--R                             (2a c  - 6b c )d e  + 4b c d e - c d
+--R                        /
+--R                                 7       6 2  8          6         5 3    7
+--R                             (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                           + 
+--R                                  6 2       5 2       4 4  2 6
+--R                             (256a c  + 320a b c - 96a b )d e
+--R                           + 
+--R                                    5   2      4 3       3 5  3 5
+--R                             (- 768a b c  - 64a b c + 64a b )d e
+--R                           + 
+--R                                  5 3       4 2 2       3 4       2 6  4 4
+--R                             (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                           + 
+--R                                    4   3      3 3 2      2 5   5 3
+--R                             (- 768a b c  - 64a b c  + 64a b c)d e
+--R                           + 
+--R                                  4 4       3 2 3      2 4 2  6 2
+--R                             (256a c  + 320a b c  - 96a b c )d e
+--R                           + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                  + 
+--R                       2   2       3     5  3        2 3        2 2     4     2
+--R                    (4a b c  - 5a b c + b )e  + (- 4a c  + 13a b c  - 3b c)d e
+--R                  + 
+--R                              3     3 2  2         4    2 3  3
+--R                    (- 12a b c  + 3b c )d e + (4a c  - b c )d
+--R               *
+--R                  ROOT
+--R                                 4      3 2  4         3        2 3    3
+--R                             (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                           + 
+--R                                 3 2     2 2        4  2 2
+--R                             (32a c  + 8a b c - 4a b )d e
+--R                           + 
+--R                                   2   2       3   3        2 3       2 2  4
+--R                             (- 32a b c  + 8a b c)d e + (16a c  - 4a b c )d
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  4
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     3        3     2 2  2 2
+--R                                  (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                                + 
+--R                                      3 3     4 4
+--R                                  4b c d e - c d
+--R                             /
+--R                                      7       6 2  8          6         5 3    7
+--R                                  (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                                + 
+--R                                       6 2       5 2       4 4  2 6
+--R                                  (256a c  + 320a b c - 96a b )d e
+--R                                + 
+--R                                         5   2      4 3       3 5  3 5
+--R                                  (- 768a b c  - 64a b c + 64a b )d e
+--R                                + 
+--R                                       5 3       4 2 2       3 4       2 6  4 4
+--R                                  (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                                + 
+--R                                         4   3      3 3 2      2 5   5 3
+--R                                  (- 768a b c  - 64a b c  + 64a b c)d e
+--R                                + 
+--R                                       4 4       3 2 3      2 4 2  6 2
+--R                                  (256a c  + 320a b c  - 96a b c )d e
+--R                                + 
+--R                                         3   4      2 3 3  7
+--R                                  (- 256a b c  + 64a b c )d e
+--R                                + 
+--R                                      3 5      2 2 4  8
+--R                                  (64a c  - 16a b c )d
+--R                       + 
+--R                                      3  2        2     2           2 2
+--R                         (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                    /
+--R                            4      3 2  4         3        2 3    3
+--R                         (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                       + 
+--R                             3 2     2 2        4  2 2
+--R                         (16a c  + 4a b c - 2a b )d e
+--R                       + 
+--R                               2   2       3   3       2 3       2 2  4
+--R                         (- 16a b c  + 4a b c)d e + (8a c  - 2a b c )d
+--R              + 
+--R                      3     2 2  2       3        4 2
+--R                ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R       + 
+--R               2              2
+--R           (a e  - b d e + c d )
+--R        *
+--R           ROOT
+--R                            4      3 2  4       3        2 3    3
+--R                      (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                    + 
+--R                            3 2     2 2        4  2 2       2   2       3   3
+--R                      (- 32a c  - 8a b c + 4a b )d e  + (32a b c  - 8a b c)d e
+--R                    + 
+--R                            2 3       2 2  4
+--R                      (- 16a c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                               3  2        2     2           2 2
+--R                  (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R             /
+--R                     4      3 2  4         3        2 3    3
+--R                  (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                + 
+--R                      3 2     2 2        4  2 2         2   2       3   3
+--R                  (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                     2 3       2 2  4
+--R                  (8a c  - 2a b c )d
+--R        *
+--R           log
+--R                            5 2      4 2      3 4  5
+--R                        (32a c  - 24a b c + 4a b )e
+--R                      + 
+--R                              4   2      3 3      2 5    4
+--R                        (- 48a b c  + 44a b c - 8a b )d e
+--R                      + 
+--R                            4 3      3 2 2     2 4        6  2 3
+--R                        (64a c  - 48a b c  - 8a b c + 4a b )d e
+--R                      + 
+--R                              3   3      2 3 2        5   3 2
+--R                        (- 32a b c  + 56a b c  - 12a b c)d e
+--R                      + 
+--R                          3 4      2 2 3        4 2  4        2   4       3 3  5
+--R                      (32a c  - 56a b c  + 12a b c )d e + (16a b c  - 4a b c )d
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  4            2     3     3
+--R                             (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                           + 
+--R                                  3     2 2  2 2       3 3     4 4
+--R                             (2a c  - 6b c )d e  + 4b c d e - c d
+--R                        /
+--R                                 7       6 2  8          6         5 3    7
+--R                             (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                           + 
+--R                                  6 2       5 2       4 4  2 6
+--R                             (256a c  + 320a b c - 96a b )d e
+--R                           + 
+--R                                    5   2      4 3       3 5  3 5
+--R                             (- 768a b c  - 64a b c + 64a b )d e
+--R                           + 
+--R                                  5 3       4 2 2       3 4       2 6  4 4
+--R                             (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                           + 
+--R                                    4   3      3 3 2      2 5   5 3
+--R                             (- 768a b c  - 64a b c  + 64a b c)d e
+--R                           + 
+--R                                  4 4       3 2 3      2 4 2  6 2
+--R                             (256a c  + 320a b c  - 96a b c )d e
+--R                           + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                  + 
+--R                         2   2       3     5  3      2 3        2 2     4     2
+--R                    (- 4a b c  + 5a b c - b )e  + (4a c  - 13a b c  + 3b c)d e
+--R                  + 
+--R                            3     3 2  2           4    2 3  3
+--R                    (12a b c  - 3b c )d e + (- 4a c  + b c )d
+--R               *
+--R                  ROOT
+--R                                   4      3 2  4       3        2 3    3
+--R                             (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                           + 
+--R                                   3 2     2 2        4  2 2
+--R                             (- 32a c  - 8a b c + 4a b )d e
+--R                           + 
+--R                                 2   2       3   3          2 3       2 2  4
+--R                             (32a b c  - 8a b c)d e + (- 16a c  + 4a b c )d
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  4
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     3        3     2 2  2 2
+--R                                  (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                                + 
+--R                                      3 3     4 4
+--R                                  4b c d e - c d
+--R                             /
+--R                                      7       6 2  8          6         5 3    7
+--R                                  (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                                + 
+--R                                       6 2       5 2       4 4  2 6
+--R                                  (256a c  + 320a b c - 96a b )d e
+--R                                + 
+--R                                         5   2      4 3       3 5  3 5
+--R                                  (- 768a b c  - 64a b c + 64a b )d e
+--R                                + 
+--R                                       5 3       4 2 2       3 4       2 6  4 4
+--R                                  (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                                + 
+--R                                         4   3      3 3 2      2 5   5 3
+--R                                  (- 768a b c  - 64a b c  + 64a b c)d e
+--R                                + 
+--R                                       4 4       3 2 3      2 4 2  6 2
+--R                                  (256a c  + 320a b c  - 96a b c )d e
+--R                                + 
+--R                                         3   4      2 3 3  7
+--R                                  (- 256a b c  + 64a b c )d e
+--R                                + 
+--R                                      3 5      2 2 4  8
+--R                                  (64a c  - 16a b c )d
+--R                       + 
+--R                                      3  2        2     2           2 2
+--R                         (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                    /
+--R                            4      3 2  4         3        2 3    3
+--R                         (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                       + 
+--R                             3 2     2 2        4  2 2
+--R                         (16a c  + 4a b c - 2a b )d e
+--R                       + 
+--R                               2   2       3   3       2 3       2 2  4
+--R                         (- 16a b c  + 4a b c)d e + (8a c  - 2a b c )d
+--R              + 
+--R                      3     2 2  2       3        4 2
+--R                ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R       + 
+--R                 2              2
+--R           (- a e  + b d e - c d )
+--R        *
+--R           ROOT
+--R                            4      3 2  4       3        2 3    3
+--R                      (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                    + 
+--R                            3 2     2 2        4  2 2       2   2       3   3
+--R                      (- 32a c  - 8a b c + 4a b )d e  + (32a b c  - 8a b c)d e
+--R                    + 
+--R                            2 3       2 2  4
+--R                      (- 16a c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                               3  2        2     2           2 2
+--R                  (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R             /
+--R                     4      3 2  4         3        2 3    3
+--R                  (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                + 
+--R                      3 2     2 2        4  2 2         2   2       3   3
+--R                  (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                     2 3       2 2  4
+--R                  (8a c  - 2a b c )d
+--R        *
+--R           log
+--R                              5 2      4 2      3 4  5
+--R                        (- 32a c  + 24a b c - 4a b )e
+--R                      + 
+--R                            4   2      3 3      2 5    4
+--R                        (48a b c  - 44a b c + 8a b )d e
+--R                      + 
+--R                              4 3      3 2 2     2 4        6  2 3
+--R                        (- 64a c  + 48a b c  + 8a b c - 4a b )d e
+--R                      + 
+--R                            3   3      2 3 2        5   3 2
+--R                        (32a b c  - 56a b c  + 12a b c)d e
+--R                      + 
+--R                              3 4      2 2 3        4 2  4
+--R                        (- 32a c  + 56a b c  - 12a b c )d e
+--R                      + 
+--R                              2   4       3 3  5
+--R                        (- 16a b c  + 4a b c )d
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  4            2     3     3
+--R                             (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                           + 
+--R                                  3     2 2  2 2       3 3     4 4
+--R                             (2a c  - 6b c )d e  + 4b c d e - c d
+--R                        /
+--R                                 7       6 2  8          6         5 3    7
+--R                             (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                           + 
+--R                                  6 2       5 2       4 4  2 6
+--R                             (256a c  + 320a b c - 96a b )d e
+--R                           + 
+--R                                    5   2      4 3       3 5  3 5
+--R                             (- 768a b c  - 64a b c + 64a b )d e
+--R                           + 
+--R                                  5 3       4 2 2       3 4       2 6  4 4
+--R                             (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                           + 
+--R                                    4   3      3 3 2      2 5   5 3
+--R                             (- 768a b c  - 64a b c  + 64a b c)d e
+--R                           + 
+--R                                  4 4       3 2 3      2 4 2  6 2
+--R                             (256a c  + 320a b c  - 96a b c )d e
+--R                           + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                  + 
+--R                       2   2       3     5  3        2 3        2 2     4     2
+--R                    (4a b c  - 5a b c + b )e  + (- 4a c  + 13a b c  - 3b c)d e
+--R                  + 
+--R                              3     3 2  2         4    2 3  3
+--R                    (- 12a b c  + 3b c )d e + (4a c  - b c )d
+--R               *
+--R                  ROOT
+--R                                   4      3 2  4       3        2 3    3
+--R                             (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                           + 
+--R                                   3 2     2 2        4  2 2
+--R                             (- 32a c  - 8a b c + 4a b )d e
+--R                           + 
+--R                                 2   2       3   3          2 3       2 2  4
+--R                             (32a b c  - 8a b c)d e + (- 16a c  + 4a b c )d
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  4
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     3        3     2 2  2 2
+--R                                  (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                                + 
+--R                                      3 3     4 4
+--R                                  4b c d e - c d
+--R                             /
+--R                                      7       6 2  8          6         5 3    7
+--R                                  (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                                + 
+--R                                       6 2       5 2       4 4  2 6
+--R                                  (256a c  + 320a b c - 96a b )d e
+--R                                + 
+--R                                         5   2      4 3       3 5  3 5
+--R                                  (- 768a b c  - 64a b c + 64a b )d e
+--R                                + 
+--R                                       5 3       4 2 2       3 4       2 6  4 4
+--R                                  (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                                + 
+--R                                         4   3      3 3 2      2 5   5 3
+--R                                  (- 768a b c  - 64a b c  + 64a b c)d e
+--R                                + 
+--R                                       4 4       3 2 3      2 4 2  6 2
+--R                                  (256a c  + 320a b c  - 96a b c )d e
+--R                                + 
+--R                                         3   4      2 3 3  7
+--R                                  (- 256a b c  + 64a b c )d e
+--R                                + 
+--R                                      3 5      2 2 4  8
+--R                                  (64a c  - 16a b c )d
+--R                       + 
+--R                                      3  2        2     2           2 2
+--R                         (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                    /
+--R                            4      3 2  4         3        2 3    3
+--R                         (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                       + 
+--R                             3 2     2 2        4  2 2
+--R                         (16a c  + 4a b c - 2a b )d e
+--R                       + 
+--R                               2   2       3   3       2 3       2 2  4
+--R                         (- 16a b c  + 4a b c)d e + (8a c  - 2a b c )d
+--R              + 
+--R                      3     2 2  2       3        4 2
+--R                ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R       + 
+--R               2              2
+--R           (a e  - b d e + c d )
+--R        *
+--R           ROOT
+--R                          4      3 2  4         3        2 3    3
+--R                      (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                    + 
+--R                          3 2     2 2        4  2 2         2   2       3   3
+--R                      (32a c  + 8a b c - 4a b )d e  + (- 32a b c  + 8a b c)d e
+--R                    + 
+--R                          2 3       2 2  4
+--R                      (16a c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                               3  2        2     2           2 2
+--R                  (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R             /
+--R                     4      3 2  4         3        2 3    3
+--R                  (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                + 
+--R                      3 2     2 2        4  2 2         2   2       3   3
+--R                  (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                + 
+--R                     2 3       2 2  4
+--R                  (8a c  - 2a b c )d
+--R        *
+--R           log
+--R                              5 2      4 2      3 4  5
+--R                        (- 32a c  + 24a b c - 4a b )e
+--R                      + 
+--R                            4   2      3 3      2 5    4
+--R                        (48a b c  - 44a b c + 8a b )d e
+--R                      + 
+--R                              4 3      3 2 2     2 4        6  2 3
+--R                        (- 64a c  + 48a b c  + 8a b c - 4a b )d e
+--R                      + 
+--R                            3   3      2 3 2        5   3 2
+--R                        (32a b c  - 56a b c  + 12a b c)d e
+--R                      + 
+--R                              3 4      2 2 3        4 2  4
+--R                        (- 32a c  + 56a b c  - 12a b c )d e
+--R                      + 
+--R                              2   4       3 3  5
+--R                        (- 16a b c  + 4a b c )d
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  4            2     3     3
+--R                             (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                           + 
+--R                                  3     2 2  2 2       3 3     4 4
+--R                             (2a c  - 6b c )d e  + 4b c d e - c d
+--R                        /
+--R                                 7       6 2  8          6         5 3    7
+--R                             (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                           + 
+--R                                  6 2       5 2       4 4  2 6
+--R                             (256a c  + 320a b c - 96a b )d e
+--R                           + 
+--R                                    5   2      4 3       3 5  3 5
+--R                             (- 768a b c  - 64a b c + 64a b )d e
+--R                           + 
+--R                                  5 3       4 2 2       3 4       2 6  4 4
+--R                             (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                           + 
+--R                                    4   3      3 3 2      2 5   5 3
+--R                             (- 768a b c  - 64a b c  + 64a b c)d e
+--R                           + 
+--R                                  4 4       3 2 3      2 4 2  6 2
+--R                             (256a c  + 320a b c  - 96a b c )d e
+--R                           + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                  + 
+--R                         2   2       3     5  3      2 3        2 2     4     2
+--R                    (- 4a b c  + 5a b c - b )e  + (4a c  - 13a b c  + 3b c)d e
+--R                  + 
+--R                            3     3 2  2           4    2 3  3
+--R                    (12a b c  - 3b c )d e + (- 4a c  + b c )d
+--R               *
+--R                  ROOT
+--R                                 4      3 2  4         3        2 3    3
+--R                             (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                           + 
+--R                                 3 2     2 2        4  2 2
+--R                             (32a c  + 8a b c - 4a b )d e
+--R                           + 
+--R                                   2   2       3   3        2 3       2 2  4
+--R                             (- 32a b c  + 8a b c)d e + (16a c  - 4a b c )d
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  4
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     3        3     2 2  2 2
+--R                                  (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                                + 
+--R                                      3 3     4 4
+--R                                  4b c d e - c d
+--R                             /
+--R                                      7       6 2  8          6         5 3    7
+--R                                  (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                                + 
+--R                                       6 2       5 2       4 4  2 6
+--R                                  (256a c  + 320a b c - 96a b )d e
+--R                                + 
+--R                                         5   2      4 3       3 5  3 5
+--R                                  (- 768a b c  - 64a b c + 64a b )d e
+--R                                + 
+--R                                       5 3       4 2 2       3 4       2 6  4 4
+--R                                  (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                                + 
+--R                                         4   3      3 3 2      2 5   5 3
+--R                                  (- 768a b c  - 64a b c  + 64a b c)d e
+--R                                + 
+--R                                       4 4       3 2 3      2 4 2  6 2
+--R                                  (256a c  + 320a b c  - 96a b c )d e
+--R                                + 
+--R                                         3   4      2 3 3  7
+--R                                  (- 256a b c  + 64a b c )d e
+--R                                + 
+--R                                      3 5      2 2 4  8
+--R                                  (64a c  - 16a b c )d
+--R                       + 
+--R                                      3  2        2     2           2 2
+--R                         (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                    /
+--R                            4      3 2  4         3        2 3    3
+--R                         (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                       + 
+--R                             3 2     2 2        4  2 2
+--R                         (16a c  + 4a b c - 2a b )d e
+--R                       + 
+--R                               2   2       3   3       2 3       2 2  4
+--R                         (- 16a b c  + 4a b c)d e + (8a c  - 2a b c )d
+--R              + 
+--R                      3     2 2  2       3        4 2
+--R                ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R       + 
+--R                        +-+
+--R                        |e
+--R              +-+     d |-
+--R              |e       \|d
+--R         - 2e |- atan(-----)
+--R             \|d       e x
+--R    /
+--R           2                2
+--R       2a e  - 2b d e + 2c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2825
+
+--S 2826 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                       +--------------------+
+--R                                     +-----------+     |   +-----------+
+--R               2              2  +-+ |          2  +-+ |   |          2
+--R         (- a e  + b d e - c d )\|2 \|- 4a c + b  \|d \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4      3 2  4         3        2 3    3
+--R                    (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                  + 
+--R                        3 2     2 2        4  2 2         2   2       3   3
+--R                    (32a c  + 8a b c - 4a b )d e  + (- 32a b c  + 8a b c)d e
+--R                  + 
+--R                        2 3       2 2  4
+--R                    (16a c  - 4a b c )d
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  4            2     3     3
+--R                         (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                       + 
+--R                              3     2 2  2 2       3 3     4 4
+--R                         (2a c  - 6b c )d e  + 4b c d e - c d
+--R                    /
+--R                             7       6 2  8          6         5 3    7
+--R                         (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                       + 
+--R                              6 2       5 2       4 4  2 6
+--R                         (256a c  + 320a b c - 96a b )d e
+--R                       + 
+--R                                5   2      4 3       3 5  3 5
+--R                         (- 768a b c  - 64a b c + 64a b )d e
+--R                       + 
+--R                              5 3       4 2 2       3 4       2 6  4 4
+--R                         (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                       + 
+--R                                4   3      3 3 2      2 5   5 3
+--R                         (- 768a b c  - 64a b c  + 64a b c)d e
+--R                       + 
+--R                              4 4       3 2 3      2 4 2  6 2
+--R                         (256a c  + 320a b c  - 96a b c )d e
+--R                       + 
+--R                                3   4      2 3 3  7        3 5      2 2 4  8
+--R                         (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R              + 
+--R                             3  2        2     2           2 2
+--R                (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R           /
+--R                   4      3 2  4         3        2 3    3
+--R                (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R              + 
+--R                    3 2     2 2        4  2 2         2   2       3   3
+--R                (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R              + 
+--R                   2 3       2 2  4
+--R                (8a c  - 2a b c )d
+--R      *
+--R         log
+--R                          5 2      4 2      3 4  5
+--R                      (32a c  - 24a b c + 4a b )e
+--R                    + 
+--R                            4   2      3 3      2 5    4
+--R                      (- 48a b c  + 44a b c - 8a b )d e
+--R                    + 
+--R                          4 3      3 2 2     2 4        6  2 3
+--R                      (64a c  - 48a b c  - 8a b c + 4a b )d e
+--R                    + 
+--R                            3   3      2 3 2        5   3 2
+--R                      (- 32a b c  + 56a b c  - 12a b c)d e
+--R                    + 
+--R                        3 4      2 2 3        4 2  4        2   4       3 3  5
+--R                    (32a c  - 56a b c  + 12a b c )d e + (16a b c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                     2   2       3     5  3        2 3        2 2     4     2
+--R                  (4a b c  - 5a b c + b )e  + (- 4a c  + 13a b c  - 3b c)d e
+--R                + 
+--R                            3     3 2  2         4    2 3  3
+--R                  (- 12a b c  + 3b c )d e + (4a c  - b c )d
+--R             *
+--R                ROOT
+--R                               4      3 2  4         3        2 3    3
+--R                           (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                         + 
+--R                               3 2     2 2        4  2 2
+--R                           (32a c  + 8a b c - 4a b )d e
+--R                         + 
+--R                                 2   2       3   3        2 3       2 2  4
+--R                           (- 32a b c  + 8a b c)d e + (16a c  - 4a b c )d
+--R                      *
+--R                         ROOT
+--R                                    2 2       2     4  4
+--R                                (- a c  + 2a b c - b )e
+--R                              + 
+--R                                         2     3     3        3     2 2  2 2
+--R                                (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                              + 
+--R                                    3 3     4 4
+--R                                4b c d e - c d
+--R                           /
+--R                                    7       6 2  8          6         5 3    7
+--R                                (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                              + 
+--R                                     6 2       5 2       4 4  2 6
+--R                                (256a c  + 320a b c - 96a b )d e
+--R                              + 
+--R                                       5   2      4 3       3 5  3 5
+--R                                (- 768a b c  - 64a b c + 64a b )d e
+--R                              + 
+--R                                     5 3       4 2 2       3 4       2 6  4 4
+--R                                (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                              + 
+--R                                       4   3      3 3 2      2 5   5 3
+--R                                (- 768a b c  - 64a b c  + 64a b c)d e
+--R                              + 
+--R                                     4 4       3 2 3      2 4 2  6 2
+--R                                (256a c  + 320a b c  - 96a b c )d e
+--R                              + 
+--R                                       3   4      2 3 3  7
+--R                                (- 256a b c  + 64a b c )d e
+--R                              + 
+--R                                    3 5      2 2 4  8
+--R                                (64a c  - 16a b c )d
+--R                     + 
+--R                                    3  2        2     2           2 2
+--R                       (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                  /
+--R                          4      3 2  4         3        2 3    3
+--R                       (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                     + 
+--R                           3 2     2 2        4  2 2         2   2       3   3
+--R                       (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                     + 
+--R                          2 3       2 2  4
+--R                       (8a c  - 2a b c )d
+--R            + 
+--R                    3     2 2  2       3        4 2
+--R              ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R     + 
+--R                                   +-----------+
+--R             2              2  +-+ |          2  +-+
+--R         (a e  - b d e + c d )\|2 \|- 4a c + b  \|d
+--R      *
+--R         ROOT
+--R                          4      3 2  4       3        2 3    3
+--R                    (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                  + 
+--R                          3 2     2 2        4  2 2       2   2       3   3
+--R                    (- 32a c  - 8a b c + 4a b )d e  + (32a b c  - 8a b c)d e
+--R                  + 
+--R                          2 3       2 2  4
+--R                    (- 16a c  + 4a b c )d
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  4            2     3     3
+--R                         (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                       + 
+--R                              3     2 2  2 2       3 3     4 4
+--R                         (2a c  - 6b c )d e  + 4b c d e - c d
+--R                    /
+--R                             7       6 2  8          6         5 3    7
+--R                         (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                       + 
+--R                              6 2       5 2       4 4  2 6
+--R                         (256a c  + 320a b c - 96a b )d e
+--R                       + 
+--R                                5   2      4 3       3 5  3 5
+--R                         (- 768a b c  - 64a b c + 64a b )d e
+--R                       + 
+--R                              5 3       4 2 2       3 4       2 6  4 4
+--R                         (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                       + 
+--R                                4   3      3 3 2      2 5   5 3
+--R                         (- 768a b c  - 64a b c  + 64a b c)d e
+--R                       + 
+--R                              4 4       3 2 3      2 4 2  6 2
+--R                         (256a c  + 320a b c  - 96a b c )d e
+--R                       + 
+--R                                3   4      2 3 3  7        3 5      2 2 4  8
+--R                         (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R              + 
+--R                             3  2        2     2           2 2
+--R                (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R           /
+--R                   4      3 2  4         3        2 3    3
+--R                (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R              + 
+--R                    3 2     2 2        4  2 2         2   2       3   3
+--R                (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R              + 
+--R                   2 3       2 2  4
+--R                (8a c  - 2a b c )d
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          5 2      4 2      3 4  5
+--R                      (32a c  - 24a b c + 4a b )e
+--R                    + 
+--R                            4   2      3 3      2 5    4
+--R                      (- 48a b c  + 44a b c - 8a b )d e
+--R                    + 
+--R                          4 3      3 2 2     2 4        6  2 3
+--R                      (64a c  - 48a b c  - 8a b c + 4a b )d e
+--R                    + 
+--R                            3   3      2 3 2        5   3 2
+--R                      (- 32a b c  + 56a b c  - 12a b c)d e
+--R                    + 
+--R                        3 4      2 2 3        4 2  4        2   4       3 3  5
+--R                    (32a c  - 56a b c  + 12a b c )d e + (16a b c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                       2   2       3     5  3      2 3        2 2     4     2
+--R                  (- 4a b c  + 5a b c - b )e  + (4a c  - 13a b c  + 3b c)d e
+--R                + 
+--R                          3     3 2  2           4    2 3  3
+--R                  (12a b c  - 3b c )d e + (- 4a c  + b c )d
+--R             *
+--R                ROOT
+--R                                 4      3 2  4       3        2 3    3
+--R                           (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                         + 
+--R                                 3 2     2 2        4  2 2
+--R                           (- 32a c  - 8a b c + 4a b )d e
+--R                         + 
+--R                               2   2       3   3          2 3       2 2  4
+--R                           (32a b c  - 8a b c)d e + (- 16a c  + 4a b c )d
+--R                      *
+--R                         ROOT
+--R                                    2 2       2     4  4
+--R                                (- a c  + 2a b c - b )e
+--R                              + 
+--R                                         2     3     3        3     2 2  2 2
+--R                                (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                              + 
+--R                                    3 3     4 4
+--R                                4b c d e - c d
+--R                           /
+--R                                    7       6 2  8          6         5 3    7
+--R                                (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                              + 
+--R                                     6 2       5 2       4 4  2 6
+--R                                (256a c  + 320a b c - 96a b )d e
+--R                              + 
+--R                                       5   2      4 3       3 5  3 5
+--R                                (- 768a b c  - 64a b c + 64a b )d e
+--R                              + 
+--R                                     5 3       4 2 2       3 4       2 6  4 4
+--R                                (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                              + 
+--R                                       4   3      3 3 2      2 5   5 3
+--R                                (- 768a b c  - 64a b c  + 64a b c)d e
+--R                              + 
+--R                                     4 4       3 2 3      2 4 2  6 2
+--R                                (256a c  + 320a b c  - 96a b c )d e
+--R                              + 
+--R                                       3   4      2 3 3  7
+--R                                (- 256a b c  + 64a b c )d e
+--R                              + 
+--R                                    3 5      2 2 4  8
+--R                                (64a c  - 16a b c )d
+--R                     + 
+--R                                    3  2        2     2           2 2
+--R                       (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                  /
+--R                          4      3 2  4         3        2 3    3
+--R                       (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                     + 
+--R                           3 2     2 2        4  2 2         2   2       3   3
+--R                       (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                     + 
+--R                          2 3       2 2  4
+--R                       (8a c  - 2a b c )d
+--R            + 
+--R                    3     2 2  2       3        4 2
+--R              ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R     + 
+--R                                     +-----------+
+--R               2              2  +-+ |          2  +-+
+--R         (- a e  + b d e - c d )\|2 \|- 4a c + b  \|d
+--R      *
+--R         ROOT
+--R                          4      3 2  4       3        2 3    3
+--R                    (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                  + 
+--R                          3 2     2 2        4  2 2       2   2       3   3
+--R                    (- 32a c  - 8a b c + 4a b )d e  + (32a b c  - 8a b c)d e
+--R                  + 
+--R                          2 3       2 2  4
+--R                    (- 16a c  + 4a b c )d
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  4            2     3     3
+--R                         (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                       + 
+--R                              3     2 2  2 2       3 3     4 4
+--R                         (2a c  - 6b c )d e  + 4b c d e - c d
+--R                    /
+--R                             7       6 2  8          6         5 3    7
+--R                         (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                       + 
+--R                              6 2       5 2       4 4  2 6
+--R                         (256a c  + 320a b c - 96a b )d e
+--R                       + 
+--R                                5   2      4 3       3 5  3 5
+--R                         (- 768a b c  - 64a b c + 64a b )d e
+--R                       + 
+--R                              5 3       4 2 2       3 4       2 6  4 4
+--R                         (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                       + 
+--R                                4   3      3 3 2      2 5   5 3
+--R                         (- 768a b c  - 64a b c  + 64a b c)d e
+--R                       + 
+--R                              4 4       3 2 3      2 4 2  6 2
+--R                         (256a c  + 320a b c  - 96a b c )d e
+--R                       + 
+--R                                3   4      2 3 3  7        3 5      2 2 4  8
+--R                         (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R              + 
+--R                             3  2        2     2           2 2
+--R                (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R           /
+--R                   4      3 2  4         3        2 3    3
+--R                (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R              + 
+--R                    3 2     2 2        4  2 2         2   2       3   3
+--R                (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R              + 
+--R                   2 3       2 2  4
+--R                (8a c  - 2a b c )d
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            5 2      4 2      3 4  5
+--R                      (- 32a c  + 24a b c - 4a b )e
+--R                    + 
+--R                          4   2      3 3      2 5    4
+--R                      (48a b c  - 44a b c + 8a b )d e
+--R                    + 
+--R                            4 3      3 2 2     2 4        6  2 3
+--R                      (- 64a c  + 48a b c  + 8a b c - 4a b )d e
+--R                    + 
+--R                          3   3      2 3 2        5   3 2
+--R                      (32a b c  - 56a b c  + 12a b c)d e
+--R                    + 
+--R                            3 4      2 2 3        4 2  4
+--R                      (- 32a c  + 56a b c  - 12a b c )d e
+--R                    + 
+--R                            2   4       3 3  5
+--R                      (- 16a b c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                     2   2       3     5  3        2 3        2 2     4     2
+--R                  (4a b c  - 5a b c + b )e  + (- 4a c  + 13a b c  - 3b c)d e
+--R                + 
+--R                            3     3 2  2         4    2 3  3
+--R                  (- 12a b c  + 3b c )d e + (4a c  - b c )d
+--R             *
+--R                ROOT
+--R                                 4      3 2  4       3        2 3    3
+--R                           (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                         + 
+--R                                 3 2     2 2        4  2 2
+--R                           (- 32a c  - 8a b c + 4a b )d e
+--R                         + 
+--R                               2   2       3   3          2 3       2 2  4
+--R                           (32a b c  - 8a b c)d e + (- 16a c  + 4a b c )d
+--R                      *
+--R                         ROOT
+--R                                    2 2       2     4  4
+--R                                (- a c  + 2a b c - b )e
+--R                              + 
+--R                                         2     3     3        3     2 2  2 2
+--R                                (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                              + 
+--R                                    3 3     4 4
+--R                                4b c d e - c d
+--R                           /
+--R                                    7       6 2  8          6         5 3    7
+--R                                (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                              + 
+--R                                     6 2       5 2       4 4  2 6
+--R                                (256a c  + 320a b c - 96a b )d e
+--R                              + 
+--R                                       5   2      4 3       3 5  3 5
+--R                                (- 768a b c  - 64a b c + 64a b )d e
+--R                              + 
+--R                                     5 3       4 2 2       3 4       2 6  4 4
+--R                                (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                              + 
+--R                                       4   3      3 3 2      2 5   5 3
+--R                                (- 768a b c  - 64a b c  + 64a b c)d e
+--R                              + 
+--R                                     4 4       3 2 3      2 4 2  6 2
+--R                                (256a c  + 320a b c  - 96a b c )d e
+--R                              + 
+--R                                       3   4      2 3 3  7
+--R                                (- 256a b c  + 64a b c )d e
+--R                              + 
+--R                                    3 5      2 2 4  8
+--R                                (64a c  - 16a b c )d
+--R                     + 
+--R                                    3  2        2     2           2 2
+--R                       (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                  /
+--R                          4      3 2  4         3        2 3    3
+--R                       (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                     + 
+--R                           3 2     2 2        4  2 2         2   2       3   3
+--R                       (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                     + 
+--R                          2 3       2 2  4
+--R                       (8a c  - 2a b c )d
+--R            + 
+--R                    3     2 2  2       3        4 2
+--R              ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R     + 
+--R                                                     +--------------------+
+--R                                   +-----------+     |   +-----------+
+--R             2              2  +-+ |          2  +-+ |   |          2
+--R         (a e  - b d e + c d )\|2 \|- 4a c + b  \|d \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4      3 2  4         3        2 3    3
+--R                    (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                  + 
+--R                        3 2     2 2        4  2 2         2   2       3   3
+--R                    (32a c  + 8a b c - 4a b )d e  + (- 32a b c  + 8a b c)d e
+--R                  + 
+--R                        2 3       2 2  4
+--R                    (16a c  - 4a b c )d
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  4            2     3     3
+--R                         (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                       + 
+--R                              3     2 2  2 2       3 3     4 4
+--R                         (2a c  - 6b c )d e  + 4b c d e - c d
+--R                    /
+--R                             7       6 2  8          6         5 3    7
+--R                         (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                       + 
+--R                              6 2       5 2       4 4  2 6
+--R                         (256a c  + 320a b c - 96a b )d e
+--R                       + 
+--R                                5   2      4 3       3 5  3 5
+--R                         (- 768a b c  - 64a b c + 64a b )d e
+--R                       + 
+--R                              5 3       4 2 2       3 4       2 6  4 4
+--R                         (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                       + 
+--R                                4   3      3 3 2      2 5   5 3
+--R                         (- 768a b c  - 64a b c  + 64a b c)d e
+--R                       + 
+--R                              4 4       3 2 3      2 4 2  6 2
+--R                         (256a c  + 320a b c  - 96a b c )d e
+--R                       + 
+--R                                3   4      2 3 3  7        3 5      2 2 4  8
+--R                         (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R              + 
+--R                             3  2        2     2           2 2
+--R                (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R           /
+--R                   4      3 2  4         3        2 3    3
+--R                (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R              + 
+--R                    3 2     2 2        4  2 2         2   2       3   3
+--R                (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R              + 
+--R                   2 3       2 2  4
+--R                (8a c  - 2a b c )d
+--R      *
+--R         log
+--R                            5 2      4 2      3 4  5
+--R                      (- 32a c  + 24a b c - 4a b )e
+--R                    + 
+--R                          4   2      3 3      2 5    4
+--R                      (48a b c  - 44a b c + 8a b )d e
+--R                    + 
+--R                            4 3      3 2 2     2 4        6  2 3
+--R                      (- 64a c  + 48a b c  + 8a b c - 4a b )d e
+--R                    + 
+--R                          3   3      2 3 2        5   3 2
+--R                      (32a b c  - 56a b c  + 12a b c)d e
+--R                    + 
+--R                            3 4      2 2 3        4 2  4
+--R                      (- 32a c  + 56a b c  - 12a b c )d e
+--R                    + 
+--R                            2   4       3 3  5
+--R                      (- 16a b c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                       2   2       3     5  3      2 3        2 2     4     2
+--R                  (- 4a b c  + 5a b c - b )e  + (4a c  - 13a b c  + 3b c)d e
+--R                + 
+--R                          3     3 2  2           4    2 3  3
+--R                  (12a b c  - 3b c )d e + (- 4a c  + b c )d
+--R             *
+--R                ROOT
+--R                               4      3 2  4         3        2 3    3
+--R                           (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                         + 
+--R                               3 2     2 2        4  2 2
+--R                           (32a c  + 8a b c - 4a b )d e
+--R                         + 
+--R                                 2   2       3   3        2 3       2 2  4
+--R                           (- 32a b c  + 8a b c)d e + (16a c  - 4a b c )d
+--R                      *
+--R                         ROOT
+--R                                    2 2       2     4  4
+--R                                (- a c  + 2a b c - b )e
+--R                              + 
+--R                                         2     3     3        3     2 2  2 2
+--R                                (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                              + 
+--R                                    3 3     4 4
+--R                                4b c d e - c d
+--R                           /
+--R                                    7       6 2  8          6         5 3    7
+--R                                (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                              + 
+--R                                     6 2       5 2       4 4  2 6
+--R                                (256a c  + 320a b c - 96a b )d e
+--R                              + 
+--R                                       5   2      4 3       3 5  3 5
+--R                                (- 768a b c  - 64a b c + 64a b )d e
+--R                              + 
+--R                                     5 3       4 2 2       3 4       2 6  4 4
+--R                                (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                              + 
+--R                                       4   3      3 3 2      2 5   5 3
+--R                                (- 768a b c  - 64a b c  + 64a b c)d e
+--R                              + 
+--R                                     4 4       3 2 3      2 4 2  6 2
+--R                                (256a c  + 320a b c  - 96a b c )d e
+--R                              + 
+--R                                       3   4      2 3 3  7
+--R                                (- 256a b c  + 64a b c )d e
+--R                              + 
+--R                                    3 5      2 2 4  8
+--R                                (64a c  - 16a b c )d
+--R                     + 
+--R                                    3  2        2     2           2 2
+--R                       (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                  /
+--R                          4      3 2  4         3        2 3    3
+--R                       (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                     + 
+--R                           3 2     2 2        4  2 2         2   2       3   3
+--R                       (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                     + 
+--R                          2 3       2 2  4
+--R                       (8a c  - 2a b c )d
+--R            + 
+--R                    3     2 2  2       3        4 2
+--R              ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R     + 
+--R                                                  +------------------+
+--R             +-----------+                        | +-----------+
+--R             |          2                 +-+ +-+ | |          2
+--R         (2e\|- 4a c + b   + 2b e - 4c d)\|c \|d \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                  +--------------------+
+--R             +-----------+                        |   +-----------+
+--R             |          2                 +-+ +-+ |   |          2
+--R         (2e\|- 4a c + b   - 2b e + 4c d)\|c \|d \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                                 +---+
+--R                                                 |  e       2
+--R                 +---+ +-----------+        2d x |- -  + e x  - d
+--R             +-+ |  e  |          2  +-+        \|  d
+--R           e\|2  |- - \|- 4a c + b  \|d log(---------------------)
+--R                \|  d                                 2
+--R                                                   e x  + d
+--R         + 
+--R                    +-----------+           +-+
+--R                +-+ |          2  +-+     x\|e
+--R           - 2e\|2 \|- 4a c + b  \|e atan(-----)
+--R                                            +-+
+--R                                           \|d
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                      +--------------------+
+--R                                    +-----------+     |   +-----------+
+--R            2                2  +-+ |          2  +-+ |   |          2
+--R       (2a e  - 2b d e + 2c d )\|2 \|- 4a c + b  \|d \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2826
+
+--S 2827 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2827
+
+--S 2828 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                       +--------------------+
+--R                                     +-----------+     |   +-----------+
+--R               2              2  +-+ |          2  +-+ |   |          2
+--R         (- a e  + b d e - c d )\|2 \|- 4a c + b  \|d \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4      3 2  4         3        2 3    3
+--R                    (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                  + 
+--R                        3 2     2 2        4  2 2         2   2       3   3
+--R                    (32a c  + 8a b c - 4a b )d e  + (- 32a b c  + 8a b c)d e
+--R                  + 
+--R                        2 3       2 2  4
+--R                    (16a c  - 4a b c )d
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  4            2     3     3
+--R                         (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                       + 
+--R                              3     2 2  2 2       3 3     4 4
+--R                         (2a c  - 6b c )d e  + 4b c d e - c d
+--R                    /
+--R                             7       6 2  8          6         5 3    7
+--R                         (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                       + 
+--R                              6 2       5 2       4 4  2 6
+--R                         (256a c  + 320a b c - 96a b )d e
+--R                       + 
+--R                                5   2      4 3       3 5  3 5
+--R                         (- 768a b c  - 64a b c + 64a b )d e
+--R                       + 
+--R                              5 3       4 2 2       3 4       2 6  4 4
+--R                         (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                       + 
+--R                                4   3      3 3 2      2 5   5 3
+--R                         (- 768a b c  - 64a b c  + 64a b c)d e
+--R                       + 
+--R                              4 4       3 2 3      2 4 2  6 2
+--R                         (256a c  + 320a b c  - 96a b c )d e
+--R                       + 
+--R                                3   4      2 3 3  7        3 5      2 2 4  8
+--R                         (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R              + 
+--R                             3  2        2     2           2 2
+--R                (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R           /
+--R                   4      3 2  4         3        2 3    3
+--R                (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R              + 
+--R                    3 2     2 2        4  2 2         2   2       3   3
+--R                (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R              + 
+--R                   2 3       2 2  4
+--R                (8a c  - 2a b c )d
+--R      *
+--R         log
+--R                          5 2      4 2      3 4  5
+--R                      (32a c  - 24a b c + 4a b )e
+--R                    + 
+--R                            4   2      3 3      2 5    4
+--R                      (- 48a b c  + 44a b c - 8a b )d e
+--R                    + 
+--R                          4 3      3 2 2     2 4        6  2 3
+--R                      (64a c  - 48a b c  - 8a b c + 4a b )d e
+--R                    + 
+--R                            3   3      2 3 2        5   3 2
+--R                      (- 32a b c  + 56a b c  - 12a b c)d e
+--R                    + 
+--R                        3 4      2 2 3        4 2  4        2   4       3 3  5
+--R                    (32a c  - 56a b c  + 12a b c )d e + (16a b c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                     2   2       3     5  3        2 3        2 2     4     2
+--R                  (4a b c  - 5a b c + b )e  + (- 4a c  + 13a b c  - 3b c)d e
+--R                + 
+--R                            3     3 2  2         4    2 3  3
+--R                  (- 12a b c  + 3b c )d e + (4a c  - b c )d
+--R             *
+--R                ROOT
+--R                               4      3 2  4         3        2 3    3
+--R                           (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                         + 
+--R                               3 2     2 2        4  2 2
+--R                           (32a c  + 8a b c - 4a b )d e
+--R                         + 
+--R                                 2   2       3   3        2 3       2 2  4
+--R                           (- 32a b c  + 8a b c)d e + (16a c  - 4a b c )d
+--R                      *
+--R                         ROOT
+--R                                    2 2       2     4  4
+--R                                (- a c  + 2a b c - b )e
+--R                              + 
+--R                                         2     3     3        3     2 2  2 2
+--R                                (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                              + 
+--R                                    3 3     4 4
+--R                                4b c d e - c d
+--R                           /
+--R                                    7       6 2  8          6         5 3    7
+--R                                (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                              + 
+--R                                     6 2       5 2       4 4  2 6
+--R                                (256a c  + 320a b c - 96a b )d e
+--R                              + 
+--R                                       5   2      4 3       3 5  3 5
+--R                                (- 768a b c  - 64a b c + 64a b )d e
+--R                              + 
+--R                                     5 3       4 2 2       3 4       2 6  4 4
+--R                                (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                              + 
+--R                                       4   3      3 3 2      2 5   5 3
+--R                                (- 768a b c  - 64a b c  + 64a b c)d e
+--R                              + 
+--R                                     4 4       3 2 3      2 4 2  6 2
+--R                                (256a c  + 320a b c  - 96a b c )d e
+--R                              + 
+--R                                       3   4      2 3 3  7
+--R                                (- 256a b c  + 64a b c )d e
+--R                              + 
+--R                                    3 5      2 2 4  8
+--R                                (64a c  - 16a b c )d
+--R                     + 
+--R                                    3  2        2     2           2 2
+--R                       (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                  /
+--R                          4      3 2  4         3        2 3    3
+--R                       (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                     + 
+--R                           3 2     2 2        4  2 2         2   2       3   3
+--R                       (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                     + 
+--R                          2 3       2 2  4
+--R                       (8a c  - 2a b c )d
+--R            + 
+--R                    3     2 2  2       3        4 2
+--R              ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R     + 
+--R                                   +-----------+
+--R             2              2  +-+ |          2  +-+
+--R         (a e  - b d e + c d )\|2 \|- 4a c + b  \|d
+--R      *
+--R         ROOT
+--R                          4      3 2  4       3        2 3    3
+--R                    (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                  + 
+--R                          3 2     2 2        4  2 2       2   2       3   3
+--R                    (- 32a c  - 8a b c + 4a b )d e  + (32a b c  - 8a b c)d e
+--R                  + 
+--R                          2 3       2 2  4
+--R                    (- 16a c  + 4a b c )d
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  4            2     3     3
+--R                         (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                       + 
+--R                              3     2 2  2 2       3 3     4 4
+--R                         (2a c  - 6b c )d e  + 4b c d e - c d
+--R                    /
+--R                             7       6 2  8          6         5 3    7
+--R                         (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                       + 
+--R                              6 2       5 2       4 4  2 6
+--R                         (256a c  + 320a b c - 96a b )d e
+--R                       + 
+--R                                5   2      4 3       3 5  3 5
+--R                         (- 768a b c  - 64a b c + 64a b )d e
+--R                       + 
+--R                              5 3       4 2 2       3 4       2 6  4 4
+--R                         (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                       + 
+--R                                4   3      3 3 2      2 5   5 3
+--R                         (- 768a b c  - 64a b c  + 64a b c)d e
+--R                       + 
+--R                              4 4       3 2 3      2 4 2  6 2
+--R                         (256a c  + 320a b c  - 96a b c )d e
+--R                       + 
+--R                                3   4      2 3 3  7        3 5      2 2 4  8
+--R                         (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R              + 
+--R                             3  2        2     2           2 2
+--R                (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R           /
+--R                   4      3 2  4         3        2 3    3
+--R                (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R              + 
+--R                    3 2     2 2        4  2 2         2   2       3   3
+--R                (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R              + 
+--R                   2 3       2 2  4
+--R                (8a c  - 2a b c )d
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          5 2      4 2      3 4  5
+--R                      (32a c  - 24a b c + 4a b )e
+--R                    + 
+--R                            4   2      3 3      2 5    4
+--R                      (- 48a b c  + 44a b c - 8a b )d e
+--R                    + 
+--R                          4 3      3 2 2     2 4        6  2 3
+--R                      (64a c  - 48a b c  - 8a b c + 4a b )d e
+--R                    + 
+--R                            3   3      2 3 2        5   3 2
+--R                      (- 32a b c  + 56a b c  - 12a b c)d e
+--R                    + 
+--R                        3 4      2 2 3        4 2  4        2   4       3 3  5
+--R                    (32a c  - 56a b c  + 12a b c )d e + (16a b c  - 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                       2   2       3     5  3      2 3        2 2     4     2
+--R                  (- 4a b c  + 5a b c - b )e  + (4a c  - 13a b c  + 3b c)d e
+--R                + 
+--R                          3     3 2  2           4    2 3  3
+--R                  (12a b c  - 3b c )d e + (- 4a c  + b c )d
+--R             *
+--R                ROOT
+--R                                 4      3 2  4       3        2 3    3
+--R                           (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                         + 
+--R                                 3 2     2 2        4  2 2
+--R                           (- 32a c  - 8a b c + 4a b )d e
+--R                         + 
+--R                               2   2       3   3          2 3       2 2  4
+--R                           (32a b c  - 8a b c)d e + (- 16a c  + 4a b c )d
+--R                      *
+--R                         ROOT
+--R                                    2 2       2     4  4
+--R                                (- a c  + 2a b c - b )e
+--R                              + 
+--R                                         2     3     3        3     2 2  2 2
+--R                                (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                              + 
+--R                                    3 3     4 4
+--R                                4b c d e - c d
+--R                           /
+--R                                    7       6 2  8          6         5 3    7
+--R                                (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                              + 
+--R                                     6 2       5 2       4 4  2 6
+--R                                (256a c  + 320a b c - 96a b )d e
+--R                              + 
+--R                                       5   2      4 3       3 5  3 5
+--R                                (- 768a b c  - 64a b c + 64a b )d e
+--R                              + 
+--R                                     5 3       4 2 2       3 4       2 6  4 4
+--R                                (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                              + 
+--R                                       4   3      3 3 2      2 5   5 3
+--R                                (- 768a b c  - 64a b c  + 64a b c)d e
+--R                              + 
+--R                                     4 4       3 2 3      2 4 2  6 2
+--R                                (256a c  + 320a b c  - 96a b c )d e
+--R                              + 
+--R                                       3   4      2 3 3  7
+--R                                (- 256a b c  + 64a b c )d e
+--R                              + 
+--R                                    3 5      2 2 4  8
+--R                                (64a c  - 16a b c )d
+--R                     + 
+--R                                    3  2        2     2           2 2
+--R                       (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                  /
+--R                          4      3 2  4         3        2 3    3
+--R                       (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                     + 
+--R                           3 2     2 2        4  2 2         2   2       3   3
+--R                       (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                     + 
+--R                          2 3       2 2  4
+--R                       (8a c  - 2a b c )d
+--R            + 
+--R                    3     2 2  2       3        4 2
+--R              ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R     + 
+--R                                     +-----------+
+--R               2              2  +-+ |          2  +-+
+--R         (- a e  + b d e - c d )\|2 \|- 4a c + b  \|d
+--R      *
+--R         ROOT
+--R                          4      3 2  4       3        2 3    3
+--R                    (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                  + 
+--R                          3 2     2 2        4  2 2       2   2       3   3
+--R                    (- 32a c  - 8a b c + 4a b )d e  + (32a b c  - 8a b c)d e
+--R                  + 
+--R                          2 3       2 2  4
+--R                    (- 16a c  + 4a b c )d
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  4            2     3     3
+--R                         (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                       + 
+--R                              3     2 2  2 2       3 3     4 4
+--R                         (2a c  - 6b c )d e  + 4b c d e - c d
+--R                    /
+--R                             7       6 2  8          6         5 3    7
+--R                         (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                       + 
+--R                              6 2       5 2       4 4  2 6
+--R                         (256a c  + 320a b c - 96a b )d e
+--R                       + 
+--R                                5   2      4 3       3 5  3 5
+--R                         (- 768a b c  - 64a b c + 64a b )d e
+--R                       + 
+--R                              5 3       4 2 2       3 4       2 6  4 4
+--R                         (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                       + 
+--R                                4   3      3 3 2      2 5   5 3
+--R                         (- 768a b c  - 64a b c  + 64a b c)d e
+--R                       + 
+--R                              4 4       3 2 3      2 4 2  6 2
+--R                         (256a c  + 320a b c  - 96a b c )d e
+--R                       + 
+--R                                3   4      2 3 3  7        3 5      2 2 4  8
+--R                         (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R              + 
+--R                             3  2        2     2           2 2
+--R                (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R           /
+--R                   4      3 2  4         3        2 3    3
+--R                (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R              + 
+--R                    3 2     2 2        4  2 2         2   2       3   3
+--R                (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R              + 
+--R                   2 3       2 2  4
+--R                (8a c  - 2a b c )d
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            5 2      4 2      3 4  5
+--R                      (- 32a c  + 24a b c - 4a b )e
+--R                    + 
+--R                          4   2      3 3      2 5    4
+--R                      (48a b c  - 44a b c + 8a b )d e
+--R                    + 
+--R                            4 3      3 2 2     2 4        6  2 3
+--R                      (- 64a c  + 48a b c  + 8a b c - 4a b )d e
+--R                    + 
+--R                          3   3      2 3 2        5   3 2
+--R                      (32a b c  - 56a b c  + 12a b c)d e
+--R                    + 
+--R                            3 4      2 2 3        4 2  4
+--R                      (- 32a c  + 56a b c  - 12a b c )d e
+--R                    + 
+--R                            2   4       3 3  5
+--R                      (- 16a b c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                     2   2       3     5  3        2 3        2 2     4     2
+--R                  (4a b c  - 5a b c + b )e  + (- 4a c  + 13a b c  - 3b c)d e
+--R                + 
+--R                            3     3 2  2         4    2 3  3
+--R                  (- 12a b c  + 3b c )d e + (4a c  - b c )d
+--R             *
+--R                ROOT
+--R                                 4      3 2  4       3        2 3    3
+--R                           (- 16a c + 4a b )e  + (32a b c - 8a b )d e
+--R                         + 
+--R                                 3 2     2 2        4  2 2
+--R                           (- 32a c  - 8a b c + 4a b )d e
+--R                         + 
+--R                               2   2       3   3          2 3       2 2  4
+--R                           (32a b c  - 8a b c)d e + (- 16a c  + 4a b c )d
+--R                      *
+--R                         ROOT
+--R                                    2 2       2     4  4
+--R                                (- a c  + 2a b c - b )e
+--R                              + 
+--R                                         2     3     3        3     2 2  2 2
+--R                                (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                              + 
+--R                                    3 3     4 4
+--R                                4b c d e - c d
+--R                           /
+--R                                    7       6 2  8          6         5 3    7
+--R                                (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                              + 
+--R                                     6 2       5 2       4 4  2 6
+--R                                (256a c  + 320a b c - 96a b )d e
+--R                              + 
+--R                                       5   2      4 3       3 5  3 5
+--R                                (- 768a b c  - 64a b c + 64a b )d e
+--R                              + 
+--R                                     5 3       4 2 2       3 4       2 6  4 4
+--R                                (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                              + 
+--R                                       4   3      3 3 2      2 5   5 3
+--R                                (- 768a b c  - 64a b c  + 64a b c)d e
+--R                              + 
+--R                                     4 4       3 2 3      2 4 2  6 2
+--R                                (256a c  + 320a b c  - 96a b c )d e
+--R                              + 
+--R                                       3   4      2 3 3  7
+--R                                (- 256a b c  + 64a b c )d e
+--R                              + 
+--R                                    3 5      2 2 4  8
+--R                                (64a c  - 16a b c )d
+--R                     + 
+--R                                    3  2        2     2           2 2
+--R                       (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                  /
+--R                          4      3 2  4         3        2 3    3
+--R                       (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                     + 
+--R                           3 2     2 2        4  2 2         2   2       3   3
+--R                       (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                     + 
+--R                          2 3       2 2  4
+--R                       (8a c  - 2a b c )d
+--R            + 
+--R                    3     2 2  2       3        4 2
+--R              ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R     + 
+--R                                                     +--------------------+
+--R                                   +-----------+     |   +-----------+
+--R             2              2  +-+ |          2  +-+ |   |          2
+--R         (a e  - b d e + c d )\|2 \|- 4a c + b  \|d \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4      3 2  4         3        2 3    3
+--R                    (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                  + 
+--R                        3 2     2 2        4  2 2         2   2       3   3
+--R                    (32a c  + 8a b c - 4a b )d e  + (- 32a b c  + 8a b c)d e
+--R                  + 
+--R                        2 3       2 2  4
+--R                    (16a c  - 4a b c )d
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  4            2     3     3
+--R                         (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                       + 
+--R                              3     2 2  2 2       3 3     4 4
+--R                         (2a c  - 6b c )d e  + 4b c d e - c d
+--R                    /
+--R                             7       6 2  8          6         5 3    7
+--R                         (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                       + 
+--R                              6 2       5 2       4 4  2 6
+--R                         (256a c  + 320a b c - 96a b )d e
+--R                       + 
+--R                                5   2      4 3       3 5  3 5
+--R                         (- 768a b c  - 64a b c + 64a b )d e
+--R                       + 
+--R                              5 3       4 2 2       3 4       2 6  4 4
+--R                         (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                       + 
+--R                                4   3      3 3 2      2 5   5 3
+--R                         (- 768a b c  - 64a b c  + 64a b c)d e
+--R                       + 
+--R                              4 4       3 2 3      2 4 2  6 2
+--R                         (256a c  + 320a b c  - 96a b c )d e
+--R                       + 
+--R                                3   4      2 3 3  7        3 5      2 2 4  8
+--R                         (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R              + 
+--R                             3  2        2     2           2 2
+--R                (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R           /
+--R                   4      3 2  4         3        2 3    3
+--R                (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R              + 
+--R                    3 2     2 2        4  2 2         2   2       3   3
+--R                (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R              + 
+--R                   2 3       2 2  4
+--R                (8a c  - 2a b c )d
+--R      *
+--R         log
+--R                            5 2      4 2      3 4  5
+--R                      (- 32a c  + 24a b c - 4a b )e
+--R                    + 
+--R                          4   2      3 3      2 5    4
+--R                      (48a b c  - 44a b c + 8a b )d e
+--R                    + 
+--R                            4 3      3 2 2     2 4        6  2 3
+--R                      (- 64a c  + 48a b c  + 8a b c - 4a b )d e
+--R                    + 
+--R                          3   3      2 3 2        5   3 2
+--R                      (32a b c  - 56a b c  + 12a b c)d e
+--R                    + 
+--R                            3 4      2 2 3        4 2  4
+--R                      (- 32a c  + 56a b c  - 12a b c )d e
+--R                    + 
+--R                            2   4       3 3  5
+--R                      (- 16a b c  + 4a b c )d
+--R                 *
+--R                    ROOT
+--R                               2 2       2     4  4            2     3     3
+--R                           (- a c  + 2a b c - b )e  + (- 4a b c  + 4b c)d e
+--R                         + 
+--R                                3     2 2  2 2       3 3     4 4
+--R                           (2a c  - 6b c )d e  + 4b c d e - c d
+--R                      /
+--R                               7       6 2  8          6         5 3    7
+--R                           (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                         + 
+--R                                6 2       5 2       4 4  2 6
+--R                           (256a c  + 320a b c - 96a b )d e
+--R                         + 
+--R                                  5   2      4 3       3 5  3 5
+--R                           (- 768a b c  - 64a b c + 64a b )d e
+--R                         + 
+--R                                5 3       4 2 2       3 4       2 6  4 4
+--R                           (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                         + 
+--R                                  4   3      3 3 2      2 5   5 3
+--R                           (- 768a b c  - 64a b c  + 64a b c)d e
+--R                         + 
+--R                                4 4       3 2 3      2 4 2  6 2
+--R                           (256a c  + 320a b c  - 96a b c )d e
+--R                         + 
+--R                                  3   4      2 3 3  7        3 5      2 2 4  8
+--R                           (- 256a b c  + 64a b c )d e + (64a c  - 16a b c )d
+--R                + 
+--R                       2   2       3     5  3      2 3        2 2     4     2
+--R                  (- 4a b c  + 5a b c - b )e  + (4a c  - 13a b c  + 3b c)d e
+--R                + 
+--R                          3     3 2  2           4    2 3  3
+--R                  (12a b c  - 3b c )d e + (- 4a c  + b c )d
+--R             *
+--R                ROOT
+--R                               4      3 2  4         3        2 3    3
+--R                           (16a c - 4a b )e  + (- 32a b c + 8a b )d e
+--R                         + 
+--R                               3 2     2 2        4  2 2
+--R                           (32a c  + 8a b c - 4a b )d e
+--R                         + 
+--R                                 2   2       3   3        2 3       2 2  4
+--R                           (- 32a b c  + 8a b c)d e + (16a c  - 4a b c )d
+--R                      *
+--R                         ROOT
+--R                                    2 2       2     4  4
+--R                                (- a c  + 2a b c - b )e
+--R                              + 
+--R                                         2     3     3        3     2 2  2 2
+--R                                (- 4a b c  + 4b c)d e  + (2a c  - 6b c )d e
+--R                              + 
+--R                                    3 3     4 4
+--R                                4b c d e - c d
+--R                           /
+--R                                    7       6 2  8          6         5 3    7
+--R                                (64a c - 16a b )e  + (- 256a b c + 64a b )d e
+--R                              + 
+--R                                     6 2       5 2       4 4  2 6
+--R                                (256a c  + 320a b c - 96a b )d e
+--R                              + 
+--R                                       5   2      4 3       3 5  3 5
+--R                                (- 768a b c  - 64a b c + 64a b )d e
+--R                              + 
+--R                                     5 3       4 2 2       3 4       2 6  4 4
+--R                                (384a c  + 672a b c  - 128a b c - 16a b )d e
+--R                              + 
+--R                                       4   3      3 3 2      2 5   5 3
+--R                                (- 768a b c  - 64a b c  + 64a b c)d e
+--R                              + 
+--R                                     4 4       3 2 3      2 4 2  6 2
+--R                                (256a c  + 320a b c  - 96a b c )d e
+--R                              + 
+--R                                       3   4      2 3 3  7
+--R                                (- 256a b c  + 64a b c )d e
+--R                              + 
+--R                                    3 5      2 2 4  8
+--R                                (64a c  - 16a b c )d
+--R                     + 
+--R                                    3  2        2     2           2 2
+--R                       (- 3a b c + b )e  + (4a c  - 2b c)d e + b c d
+--R                  /
+--R                          4      3 2  4         3        2 3    3
+--R                       (8a c - 2a b )e  + (- 16a b c + 4a b )d e
+--R                     + 
+--R                           3 2     2 2        4  2 2         2   2       3   3
+--R                       (16a c  + 4a b c - 2a b )d e  + (- 16a b c  + 4a b c)d e
+--R                     + 
+--R                          2 3       2 2  4
+--R                       (8a c  - 2a b c )d
+--R            + 
+--R                    3     2 2  2       3        4 2
+--R              ((2a c  - 2b c )e  + 4b c d e - 2c d )x
+--R     + 
+--R                                                  +------------------+
+--R             +-----------+                        | +-----------+
+--R             |          2                 +-+ +-+ | |          2
+--R         (2e\|- 4a c + b   + 2b e - 4c d)\|c \|d \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                  +--------------------+
+--R             +-----------+                        |   +-----------+
+--R             |          2                 +-+ +-+ |   |          2
+--R         (2e\|- 4a c + b   - 2b e + 4c d)\|c \|d \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                    +-----------+           +-+
+--R                +-+ |          2  +-+     x\|e
+--R           - 2e\|2 \|- 4a c + b  \|e atan(-----)
+--R                                            +-+
+--R                                           \|d
+--R         + 
+--R                                                +-+
+--R                                                |e
+--R                    +-----------+     +-+     d |-
+--R                +-+ |          2  +-+ |e       \|d
+--R           - 2e\|2 \|- 4a c + b  \|d  |- atan(-----)
+--R                                     \|d       e x
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                      +--------------------+
+--R                                    +-----------+     |   +-----------+
+--R            2                2  +-+ |          2  +-+ |   |          2
+--R       (2a e  - 2b d e + 2c d )\|2 \|- 4a c + b  \|d \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2828
+
+--S 2829 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2829
+
+)clear all
+
+--S 2830 of 3139
+t0:=1/((d+e*x^2)^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          2 8       2           6       2               2  4                2  2
+--R       c e x  + (b e  + 2c d e)x  + (a e  + 2b d e + c d )x  + (2a d e + b d )x
+--R     + 
+--R          2
+--R       a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2830
+
+--S 2831 of 3139
+r0:=1/2*e^2*x/(d*(c*d^2-b*d*e+a*e^2)*(d+e*x^2))+1/2*e^(3/2)*atan(x*_
+   sqrt(e)/sqrt(d))/(d^(3/2)*(c*d^2-b*d*e+a*e^2))+e^(3/2)*(2*c*d-b*e)*_
+   atan(x*sqrt(e)/sqrt(d))/((c*d^2-b*d*e+a*e^2)^2*sqrt(d))-atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(2*c*d*e-b*e^2+(-2*c^2*d^2-_
+   b^2*e^2+2*c*e*(b*d+a*e))/sqrt(b^2-4*a*c))/((c*d^2-b*d*e+a*e^2)^2*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(2*c*d*e-b*e^2+(2*c^2*d^2+b^2*e^2-2*c*e*_
+   (b*d+a*e))/sqrt(b^2-4*a*c))/((c*d^2-b*d*e+a*e^2)^2*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                      +-----------+
+--R                   3       2 2  2       2 2       3   |          2
+--R           ((2b d e  - 4c d e )x  + 2b d e  - 4c d e)\|- 4a c + b
+--R         + 
+--R                        2    3         2 2     2 3   2               2  2 2
+--R           ((- 4a c + 2b )d e  - 4b c d e  + 4c d e)x  + (- 4a c + 2b )d e
+--R         + 
+--R                   3      2 4
+--R           - 4b c d e + 4c d
+--R      *
+--R                  +------------------+
+--R                  | +-----------+                   +-+ +-+
+--R          +-+ +-+ | |          2                  x\|2 \|c
+--R         \|c \|d \|\|- 4a c + b   + b atan(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                            |   |          2
+--R                                           \|- \|- 4a c + b   + b
+--R     + 
+--R                                                      +-----------+
+--R                   3       2 2  2       2 2       3   |          2
+--R           ((2b d e  - 4c d e )x  + 2b d e  - 4c d e)\|- 4a c + b
+--R         + 
+--R                      2    3         2 2     2 3   2             2  2 2
+--R           ((4a c - 2b )d e  + 4b c d e  - 4c d e)x  + (4a c - 2b )d e
+--R         + 
+--R                 3      2 4
+--R           4b c d e - 4c d
+--R      *
+--R                  +--------------------+
+--R                  |   +-----------+                  +-+ +-+
+--R          +-+ +-+ |   |          2                 x\|2 \|c
+--R         \|c \|d \|- \|- 4a c + b   + b atan(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                              | |          2
+--R                                             \|\|- 4a c + b   + b
+--R     + 
+--R                  4         3       2 2  2        3       2 2       3   +-+
+--R             ((a e  - 3b d e  + 5c d e )x  + a d e  - 3b d e  + 5c d e)\|2
+--R          *
+--R              +-----------+           +-+
+--R              |          2  +-+     x\|e
+--R             \|- 4a c + b  \|e atan(-----)
+--R                                      +-+
+--R                                     \|d
+--R         + 
+--R                                         +-----------+
+--R               4        3      2 2   +-+ |          2  +-+
+--R           (a e  - b d e  + c d e )x\|2 \|- 4a c + b  \|d
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            2   5         2 4             2  3 3         4 2     2 5   2
+--R         (2a d e  - 4a b d e  + (4a c + 2b )d e  - 4b c d e  + 2c d e)x
+--R       + 
+--R           2 2 4         3 3             2  4 2         5      2 6
+--R         2a d e  - 4a b d e  + (4a c + 2b )d e  - 4b c d e + 2c d
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|d \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2831
+
+--S 2832 of 3139
+--a0:=integrate(t0,x)
+--E 2832
+
+--S 2833 of 3139
+--m0:=a0-r0
+--E 2833
+
+--S 2834 of 3139
+--d0:=D(m0,x)
+--E 2834
+
+)clear all
+
+--S 2835 of 3139
+t0:=(d+e*x^2)*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                   +---------------+
+--R            2      |   4      2
+--R   (1)  (e x  + d)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2835
+
+--S 2836 of 3139
+--r0:=1/15*x*(5*c*d+b*e+3*c*e*x^2)*sqrt(a+b*x^2+c*x^4)/c+1/30*(5*b*c*d-_
+---  2*b^2*e+6*a*c*e)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+_
+---  c*x^4))-1/30*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+---  sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+---  (b+sqrt(b^2-4*a*c))*(5*b*c*d-2*b^2*e+6*a*c*e-2*a*c*(10*c*d-b*e)/_
+---  (b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*_
+---  sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 2836
+
+--S 2837 of 3139
+--a0:=integrate(t0,x)
+--E 2837
+
+--S 2838 of 3139
+--m0:=a0-r0
+--E 2838
+
+--S 2839 of 3139
+--d0:=D(m0,x)
+--E 2839
+
+)clear all
+
+--S 2840 of 3139
+t0:=sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R   (1)  \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2840
+
+--S 2841 of 3139
+--r0:=1/3*x*sqrt(a+b*x^2+c*x^4)+1/6*b*elliptic_e(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-_
+---  4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+---  (c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/6*elliptic_f(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/_
+---  (b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 2841
+
+--S 2842 of 3139
+--a0:=integrate(t0,x)
+--E 2842
+
+--S 2843 of 3139
+--m0:=a0-r0
+--E 2843
+
+--S 2844 of 3139
+--d0:=D(m0,x)
+--E 2844
+
+)clear all
+
+--S 2845 of 3139
+t0:=sqrt(a+b*x^2+c*x^4)/(d+e*x^2)
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                2
+--R             e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2845
+
+--S 2846 of 3139
+--r0:=-elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)*_
+---  sqrt(a+b*x^2+c*x^4)/(e*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))+_
+---  elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)*(2*c*d-_
+---  e*(b-sqrt(b^2-4*a*c)))*sqrt(a+b*x^2+c*x^4)/(e^2*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))-2*(c*d^2-b*d*e+a*e^2)*_
+---  elliptic_pi(1/2*e*(b+sqrt(b^2-4*a*c))/(c*d),asin(x*sqrt(2)*_
+---  sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/_
+---  (b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(-c)*sqrt(a+b*x^2+c*x^4)/(d*e^2*_
+---  (b-sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))
+--E 2846
+
+--S 2847 of 3139
+--a0:=integrate(t0,x)
+--E 2847
+
+--S 2848 of 3139
+--m0:=a0-r0
+--E 2848
+
+--S 2849 of 3139
+--d0:=D(m0,x)
+--E 2849
+
+)clear all
+
+--S 2850 of 3139
+t0:=x^5/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     5
+--R                    x
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2850
+
+--S 2851 of 3139
+r0:=-1/4*b*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(3/2)-_
+   1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/sqrt(c)-_
+   1/2*atanh(1/2*(2*a-b+(b-2*c)*x^2)/(sqrt(a-b+c)*sqrt(a+b*x^2+c*x^4)))/_
+   sqrt(a-b+c)+1/2*sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                  2
+--R          +-+            (2c - b)x  + b - 2a
+--R       2c\|c atanh(-------------------------------)
+--R                                 +---------------+
+--R                     +---------+ |   4      2
+--R                   2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                                              2
+--R                  +---------+             2c x  + b
+--R       (- 2c - b)\|c - b + a atanh(-----------------------)
+--R                                         +---------------+
+--R                                     +-+ |   4      2
+--R                                   2\|c \|c x  + b x  + a
+--R     + 
+--R                         +---------------+
+--R         +---------+ +-+ |   4      2
+--R       2\|c - b + a \|c \|c x  + b x  + a
+--R  /
+--R        +---------+ +-+
+--R     4c\|c - b + a \|c
+--R                                                    Type: Expression(Integer)
+--E 2851
+
+--S 2852 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                       +---------------+
+--R                       +-+ +---------+ |   4      2
+--R             (4c + 2b)\|a \|c - b + a \|c x  + b x  + a
+--R           + 
+--R                         2  2                +---------+
+--R             ((- 2b c - b )x  - 4a c - 2a b)\|c - b + a
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                       +---------------+
+--R               +-+ +-+ |   4      2                 2         +-+
+--R           (4c\|a \|c \|c x  + b x  + a  + (- 2b c x  - 4a c)\|c )
+--R        *
+--R           log
+--R                        2      +-+ +---------+                    2
+--R                    ((2x  + 2)\|a \|c - b + a  + (- 2c + 2b - 2a)x )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                                   4              2       +---------+
+--R                  ((- 2c + b - 2a)x  + (- b - 2a)x  - 2a)\|c - b + a
+--R                + 
+--R                                  4                  2  +-+
+--R                  ((2c - 2b + 2a)x  + (2c - 2b + 2a)x )\|a
+--R             /
+--R                              +---------------+
+--R                   2      +-+ |   4      2           4              2
+--R                (2x  + 2)\|a \|c x  + b x  + a  - b x  + (- b - 2a)x  - 2a
+--R       + 
+--R                                 +---------------+
+--R               2 +---------+ +-+ |   4      2
+--R         - 2b x \|c - b + a \|c \|c x  + b x  + a
+--R       + 
+--R              4       2  +-+ +---------+ +-+
+--R         (4c x  + 2b x )\|a \|c - b + a \|c
+--R    /
+--R                                +---------------+
+--R            +-+ +---------+ +-+ |   4      2
+--R         8c\|a \|c - b + a \|c \|c x  + b x  + a
+--R       + 
+--R                  2         +---------+ +-+
+--R         (- 4b c x  - 8a c)\|c - b + a \|c
+--R     ,
+--R
+--R                                         +---------------+
+--R                       +-----------+ +-+ |   4      2
+--R             (4c + 2b)\|- c + b - a \|a \|c x  + b x  + a
+--R           + 
+--R                         2  2                +-----------+
+--R             ((- 2b c - b )x  - 4a c - 2a b)\|- c + b - a
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R                       +---------------+
+--R               +-+ +-+ |   4      2                 2         +-+
+--R           (8c\|a \|c \|c x  + b x  + a  + (- 4b c x  - 8a c)\|c )
+--R        *
+--R                             +---------------+
+--R               +-----------+ |   4      2            2      +-----------+ +-+
+--R              \|- c + b - a \|c x  + b x  + a  + (- x  - 1)\|- c + b - a \|a
+--R         atan(---------------------------------------------------------------)
+--R                                                   2
+--R                                       (c - b + a)x
+--R       + 
+--R                                   +---------------+
+--R               2 +-----------+ +-+ |   4      2
+--R         - 2b x \|- c + b - a \|c \|c x  + b x  + a
+--R       + 
+--R              4       2  +-----------+ +-+ +-+
+--R         (4c x  + 2b x )\|- c + b - a \|a \|c
+--R    /
+--R                                  +---------------+
+--R            +-----------+ +-+ +-+ |   4      2
+--R         8c\|- c + b - a \|a \|c \|c x  + b x  + a
+--R       + 
+--R                  2         +-----------+ +-+
+--R         (- 4b c x  - 8a c)\|- c + b - a \|c
+--R     ,
+--R
+--R                         +---------------+
+--R               +---+ +-+ |   4      2                2         +---+
+--R           (2c\|- c \|a \|c x  + b x  + a  + (- b c x  - 2a c)\|- c )
+--R        *
+--R           log
+--R                        2      +-+ +---------+                    2
+--R                    ((2x  + 2)\|a \|c - b + a  + (- 2c + 2b - 2a)x )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                                   4              2       +---------+
+--R                  ((- 2c + b - 2a)x  + (- b - 2a)x  - 2a)\|c - b + a
+--R                + 
+--R                                  4                  2  +-+
+--R                  ((2c - 2b + 2a)x  + (2c - 2b + 2a)x )\|a
+--R             /
+--R                              +---------------+
+--R                   2      +-+ |   4      2           4              2
+--R                (2x  + 2)\|a \|c x  + b x  + a  - b x  + (- b - 2a)x  - 2a
+--R       + 
+--R                                         +---------------+
+--R                         +-+ +---------+ |   4      2
+--R             (- 4c - 2b)\|a \|c - b + a \|c x  + b x  + a
+--R           + 
+--R                       2  2                +---------+
+--R             ((2b c + b )x  + 4a c + 2a b)\|c - b + a
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                                  +---------------+
+--R              2 +---+ +---------+ |   4      2
+--R         - b x \|- c \|c - b + a \|c x  + b x  + a
+--R       + 
+--R              4      2  +---+ +-+ +---------+
+--R         (2c x  + b x )\|- c \|a \|c - b + a
+--R    /
+--R                                  +---------------+
+--R            +---+ +-+ +---------+ |   4      2
+--R         4c\|- c \|a \|c - b + a \|c x  + b x  + a
+--R       + 
+--R                  2         +---+ +---------+
+--R         (- 2b c x  - 4a c)\|- c \|c - b + a
+--R     ,
+--R
+--R                         +---------------+
+--R               +---+ +-+ |   4      2                 2         +---+
+--R           (4c\|- c \|a \|c x  + b x  + a  + (- 2b c x  - 4a c)\|- c )
+--R        *
+--R                             +---------------+
+--R               +-----------+ |   4      2            2      +-----------+ +-+
+--R              \|- c + b - a \|c x  + b x  + a  + (- x  - 1)\|- c + b - a \|a
+--R         atan(---------------------------------------------------------------)
+--R                                                   2
+--R                                       (c - b + a)x
+--R       + 
+--R                                           +---------------+
+--R                         +-----------+ +-+ |   4      2
+--R             (- 4c - 2b)\|- c + b - a \|a \|c x  + b x  + a
+--R           + 
+--R                       2  2                +-----------+
+--R             ((2b c + b )x  + 4a c + 2a b)\|- c + b - a
+--R        *
+--R                       +---------------+
+--R                 +---+ |   4      2         +---+ +-+
+--R                \|- c \|c x  + b x  + a  - \|- c \|a
+--R           atan(-------------------------------------)
+--R                                    2
+--R                                 c x
+--R       + 
+--R                                    +---------------+
+--R              2 +---+ +-----------+ |   4      2
+--R         - b x \|- c \|- c + b - a \|c x  + b x  + a
+--R       + 
+--R              4      2  +---+ +-----------+ +-+
+--R         (2c x  + b x )\|- c \|- c + b - a \|a
+--R    /
+--R                                    +---------------+
+--R            +---+ +-----------+ +-+ |   4      2
+--R         4c\|- c \|- c + b - a \|a \|c x  + b x  + a
+--R       + 
+--R                  2         +---+ +-----------+
+--R         (- 2b c x  - 4a c)\|- c \|- c + b - a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2852
+
+--S 2853 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                     +---------------+
+--R                     +-+ +---------+ |   4      2
+--R           (4c + 2b)\|a \|c - b + a \|c x  + b x  + a
+--R         + 
+--R                       2  2                +---------+
+--R           ((- 2b c - b )x  - 4a c - 2a b)\|c - b + a
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                     +---------------+
+--R             +-+ +-+ |   4      2                 2         +-+
+--R         (4c\|a \|c \|c x  + b x  + a  + (- 2b c x  - 4a c)\|c )
+--R      *
+--R         log
+--R                      2      +-+ +---------+                    2
+--R                  ((2x  + 2)\|a \|c - b + a  + (- 2c + 2b - 2a)x )
+--R               *
+--R                   +---------------+
+--R                   |   4      2
+--R                  \|c x  + b x  + a
+--R              + 
+--R                                 4              2       +---------+
+--R                ((- 2c + b - 2a)x  + (- b - 2a)x  - 2a)\|c - b + a
+--R              + 
+--R                                4                  2  +-+
+--R                ((2c - 2b + 2a)x  + (2c - 2b + 2a)x )\|a
+--R           /
+--R                            +---------------+
+--R                 2      +-+ |   4      2           4              2
+--R              (2x  + 2)\|a \|c x  + b x  + a  - b x  + (- b - 2a)x  - 2a
+--R     + 
+--R                       +---------------+
+--R               +-+ +-+ |   4      2               2         +-+
+--R         (- 4c\|a \|c \|c x  + b x  + a  + (2b c x  + 4a c)\|c )
+--R      *
+--R                              2
+--R                     (2c - b)x  + b - 2a
+--R         atanh(-------------------------------)
+--R                             +---------------+
+--R                 +---------+ |   4      2
+--R               2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                                     +---------------+
+--R                     +-+ +---------+ |   4      2
+--R           (4c + 2b)\|a \|c - b + a \|c x  + b x  + a
+--R         + 
+--R                       2  2                +---------+
+--R           ((- 2b c - b )x  - 4a c - 2a b)\|c - b + a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                        +---------------+
+--R        +---------+ +-+ |   4      2               2       +-+ +---------+ +-+
+--R     4a\|c - b + a \|c \|c x  + b x  + a  + (- 2b x  - 4a)\|a \|c - b + a \|c
+--R  /
+--R                              +---------------+
+--R          +-+ +---------+ +-+ |   4      2
+--R       8c\|a \|c - b + a \|c \|c x  + b x  + a
+--R     + 
+--R                2         +---------+ +-+
+--R       (- 4b c x  - 8a c)\|c - b + a \|c
+--R                                                    Type: Expression(Integer)
+--E 2853
+
+--S 2854 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2854
+
+--S 2855 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                   +---------------+
+--R                     +-----------+ +-+ +---------+ |   4      2
+--R           (4c + 2b)\|- c + b - a \|a \|c - b + a \|c x  + b x  + a
+--R         + 
+--R                       2  2                +-----------+ +---------+
+--R           ((- 2b c - b )x  - 4a c - 2a b)\|- c + b - a \|c - b + a
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  + 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  - 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R                                      +---------------+
+--R                +-----------+ +-+ +-+ |   4      2
+--R           - 4c\|- c + b - a \|a \|c \|c x  + b x  + a
+--R         + 
+--R                  2         +-----------+ +-+
+--R           (2b c x  + 4a c)\|- c + b - a \|c
+--R      *
+--R                              2
+--R                     (2c - b)x  + b - 2a
+--R         atanh(-------------------------------)
+--R                             +---------------+
+--R                 +---------+ |   4      2
+--R               2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                                                   +---------------+
+--R                     +-----------+ +-+ +---------+ |   4      2
+--R           (4c + 2b)\|- c + b - a \|a \|c - b + a \|c x  + b x  + a
+--R         + 
+--R                       2  2                +-----------+ +---------+
+--R           ((- 2b c - b )x  - 4a c - 2a b)\|- c + b - a \|c - b + a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                                  +---------------+
+--R              +-+ +---------+ +-+ |   4      2
+--R           8c\|a \|c - b + a \|c \|c x  + b x  + a
+--R         + 
+--R                    2         +---------+ +-+
+--R           (- 4b c x  - 8a c)\|c - b + a \|c
+--R      *
+--R                             +---------------+
+--R               +-----------+ |   4      2            2      +-----------+ +-+
+--R              \|- c + b - a \|c x  + b x  + a  + (- x  - 1)\|- c + b - a \|a
+--R         atan(---------------------------------------------------------------)
+--R                                                   2
+--R                                       (c - b + a)x
+--R     + 
+--R                                        +---------------+
+--R          +-----------+ +---------+ +-+ |   4      2
+--R       4a\|- c + b - a \|c - b + a \|c \|c x  + b x  + a
+--R     + 
+--R              2       +-----------+ +-+ +---------+ +-+
+--R       (- 2b x  - 4a)\|- c + b - a \|a \|c - b + a \|c
+--R  /
+--R                                            +---------------+
+--R          +-----------+ +-+ +---------+ +-+ |   4      2
+--R       8c\|- c + b - a \|a \|c - b + a \|c \|c x  + b x  + a
+--R     + 
+--R                2         +-----------+ +---------+ +-+
+--R       (- 4b c x  - 8a c)\|- c + b - a \|c - b + a \|c
+--R                                                    Type: Expression(Integer)
+--E 2855
+
+--S 2856 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2856
+
+)clear all
+
+--S 2857 of 3139
+t0:=x^4/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     4
+--R                    x
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2857
+
+--S 2858 of 3139
+--r0:=elliptic_pi(1/2*(b+sqrt(b^2-4*a*c))/c,asin(x*sqrt(2)*sqrt(-c)/_
+---  sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(a+b*x^2+c*x^4)*sqrt(b+sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(-c)*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-_
+---  4*a*c))))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(-b+sqrt(b^2-_
+---  4*a*c))^(3/2)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/_
+---  (b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-_
+---  elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))-_
+---  1/2*elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),_
+---  (b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*(b-sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/((-c)^(3/2)*sqrt(2)*_
+---  sqrt(a+b*x^2+c*x^4))
+--E 2858
+
+--S 2859 of 3139
+--a0:=integrate(t0,x)
+--E 2859
+
+--S 2860 of 3139
+--m0:=a0-r0
+--E 2860
+
+--S 2861 of 3139
+--d0:=D(m0,x)
+--E 2861
+
+)clear all
+
+--S 2862 of 3139
+t0:=x^3/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     3
+--R                    x
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2862
+
+--S 2863 of 3139
+r0:=1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/sqrt(c)+_
+   1/2*atanh(1/2*(2*a-b+(b-2*c)*x^2)/(sqrt(a-b+c)*sqrt(a+b*x^2+c*x^4)))/_
+   sqrt(a-b+c)
+--R 
+--R
+--R   (2)
+--R                                  2
+--R          +-+            (2c - b)x  + b - 2a
+--R       - \|c atanh(-------------------------------)
+--R                                 +---------------+
+--R                     +---------+ |   4      2
+--R                   2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                                    2
+--R        +---------+             2c x  + b
+--R       \|c - b + a atanh(-----------------------)
+--R                               +---------------+
+--R                           +-+ |   4      2
+--R                         2\|c \|c x  + b x  + a
+--R  /
+--R       +---------+ +-+
+--R     2\|c - b + a \|c
+--R                                                    Type: Expression(Integer)
+--E 2863
+
+--S 2864 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R            +---------+
+--R           \|c - b + a
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R            +-+
+--R           \|c
+--R        *
+--R           log
+--R                        2      +-+ +---------+                  2
+--R                    ((2x  + 2)\|a \|c - b + a  + (2c - 2b + 2a)x )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                                   4              2       +---------+
+--R                  ((- 2c + b - 2a)x  + (- b - 2a)x  - 2a)\|c - b + a
+--R                + 
+--R                                    4                    2  +-+
+--R                  ((- 2c + 2b - 2a)x  + (- 2c + 2b - 2a)x )\|a
+--R             /
+--R                              +---------------+
+--R                   2      +-+ |   4      2           4              2
+--R                (2x  + 2)\|a \|c x  + b x  + a  - b x  + (- b - 2a)x  - 2a
+--R    /
+--R         +---------+ +-+
+--R       2\|c - b + a \|c
+--R     ,
+--R
+--R            +---+
+--R           \|- c
+--R        *
+--R           log
+--R                        2      +-+ +---------+                  2
+--R                    ((2x  + 2)\|a \|c - b + a  + (2c - 2b + 2a)x )
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                                   4              2       +---------+
+--R                  ((- 2c + b - 2a)x  + (- b - 2a)x  - 2a)\|c - b + a
+--R                + 
+--R                                    4                    2  +-+
+--R                  ((- 2c + 2b - 2a)x  + (- 2c + 2b - 2a)x )\|a
+--R             /
+--R                              +---------------+
+--R                   2      +-+ |   4      2           4              2
+--R                (2x  + 2)\|a \|c x  + b x  + a  - b x  + (- b - 2a)x  - 2a
+--R       + 
+--R                                  +---------------+
+--R                            +---+ |   4      2         +---+ +-+
+--R           +---------+     \|- c \|c x  + b x  + a  - \|- c \|a
+--R         2\|c - b + a atan(-------------------------------------)
+--R                                               2
+--R                                            c x
+--R    /
+--R         +---+ +---------+
+--R       2\|- c \|c - b + a
+--R     ,
+--R
+--R            +-----------+
+--R           \|- c + b - a
+--R        *
+--R           log
+--R                                      +---------------+
+--R                     +-+ +-+       2  |   4      2
+--R                  (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R                + 
+--R                         4      2       +-+       2 +-+
+--R                  (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R             /
+--R                      +---------------+
+--R                  +-+ |   4      2           2
+--R                2\|a \|c x  + b x  + a  - b x  - 2a
+--R       + 
+--R         -
+--R                +-+
+--R              2\|c
+--R           *
+--R              atan
+--R                                +---------------+
+--R                  +-----------+ |   4      2            2      +-----------+ +-+
+--R                 \|- c + b - a \|c x  + b x  + a  + (- x  - 1)\|- c + b - a \|a
+--R                 ---------------------------------------------------------------
+--R                                                      2
+--R                                          (c - b + a)x
+--R    /
+--R         +-----------+ +-+
+--R       2\|- c + b - a \|c
+--R     ,
+--R
+--R         -
+--R               +---+
+--R              \|- c
+--R           *
+--R              atan
+--R                                +---------------+
+--R                  +-----------+ |   4      2            2      +-----------+ +-+
+--R                 \|- c + b - a \|c x  + b x  + a  + (- x  - 1)\|- c + b - a \|a
+--R                 ---------------------------------------------------------------
+--R                                                      2
+--R                                          (c - b + a)x
+--R       + 
+--R                                   +---------------+
+--R                             +---+ |   4      2         +---+ +-+
+--R          +-----------+     \|- c \|c x  + b x  + a  - \|- c \|a
+--R         \|- c + b - a atan(-------------------------------------)
+--R                                                2
+--R                                             c x
+--R    /
+--R        +---+ +-----------+
+--R       \|- c \|- c + b - a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2864
+
+--S 2865 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +---------+
+--R         \|c - b + a
+--R      *
+--R         log
+--R                                    +---------------+
+--R                   +-+ +-+       2  |   4      2
+--R                (2\|a \|c  - 2c x )\|c x  + b x  + a
+--R              + 
+--R                       4      2       +-+       2 +-+
+--R                (- 2c x  - b x  - 2a)\|c  + 2c x \|a
+--R           /
+--R                    +---------------+
+--R                +-+ |   4      2           2
+--R              2\|a \|c x  + b x  + a  - b x  - 2a
+--R     + 
+--R          +-+
+--R         \|c
+--R      *
+--R         log
+--R                                                               +---------------+
+--R                    2      +-+ +---------+                  2  |   4      2
+--R                ((2x  + 2)\|a \|c - b + a  + (2c - 2b + 2a)x )\|c x  + b x  + a
+--R              + 
+--R                                 4              2       +---------+
+--R                ((- 2c + b - 2a)x  + (- b - 2a)x  - 2a)\|c - b + a
+--R              + 
+--R                                  4                    2  +-+
+--R                ((- 2c + 2b - 2a)x  + (- 2c + 2b - 2a)x )\|a
+--R           /
+--R                            +---------------+
+--R                 2      +-+ |   4      2           4              2
+--R              (2x  + 2)\|a \|c x  + b x  + a  - b x  + (- b - 2a)x  - 2a
+--R     + 
+--R                                2
+--R        +-+            (2c - b)x  + b - 2a
+--R       \|c atanh(-------------------------------)
+--R                               +---------------+
+--R                   +---------+ |   4      2
+--R                 2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                                      2
+--R          +---------+             2c x  + b
+--R       - \|c - b + a atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|c \|c x  + b x  + a
+--R  /
+--R       +---------+ +-+
+--R     2\|c - b + a \|c
+--R                                                    Type: Expression(Integer)
+--E 2865
+
+--S 2866 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2866
+
+--S 2867 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +---+ +-+
+--R         \|- c \|c
+--R      *
+--R         log
+--R                                                               +---------------+
+--R                    2      +-+ +---------+                  2  |   4      2
+--R                ((2x  + 2)\|a \|c - b + a  + (2c - 2b + 2a)x )\|c x  + b x  + a
+--R              + 
+--R                                 4              2       +---------+
+--R                ((- 2c + b - 2a)x  + (- b - 2a)x  - 2a)\|c - b + a
+--R              + 
+--R                                  4                    2  +-+
+--R                ((- 2c + 2b - 2a)x  + (- 2c + 2b - 2a)x )\|a
+--R           /
+--R                            +---------------+
+--R                 2      +-+ |   4      2           4              2
+--R              (2x  + 2)\|a \|c x  + b x  + a  - b x  + (- b - 2a)x  - 2a
+--R     + 
+--R                                      2
+--R        +---+ +-+            (2c - b)x  + b - 2a
+--R       \|- c \|c atanh(-------------------------------)
+--R                                     +---------------+
+--R                         +---------+ |   4      2
+--R                       2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                                            2
+--R          +---+ +---------+             2c x  + b
+--R       - \|- c \|c - b + a atanh(-----------------------)
+--R                                       +---------------+
+--R                                   +-+ |   4      2
+--R                                 2\|c \|c x  + b x  + a
+--R     + 
+--R                                    +---------------+
+--R                              +---+ |   4      2         +---+ +-+
+--R         +---------+ +-+     \|- c \|c x  + b x  + a  - \|- c \|a
+--R       2\|c - b + a \|c atan(-------------------------------------)
+--R                                                 2
+--R                                              c x
+--R  /
+--R       +---+ +---------+ +-+
+--R     2\|- c \|c - b + a \|c
+--R                                                    Type: Expression(Integer)
+--E 2867
+
+--S 2868 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2868
+
+)clear all
+
+--S 2869 of 3139
+t0:=x^2/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     2
+--R                    x
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2869
+
+--S 2870 of 3139
+--r0:=-elliptic_pi(1/2*(b+sqrt(b^2-4*a*c))/c,asin(x*sqrt(2)*_
+---  sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(a+b*x^2+c*x^4)*sqrt(b+sqrt(b^2-4*a*c))/_
+---  (a*sqrt(2)*sqrt(-c)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))+elliptic_f(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*_
+---  sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 2870
+
+--S 2871 of 3139
+--a0:=integrate(t0,x)
+--E 2871
+
+--S 2872 of 3139
+--m0:=a0-r0
+--E 2872
+
+--S 2873 of 3139
+--d0:=D(m0,x)
+--E 2873
+
+)clear all
+
+--S 2874 of 3139
+t0:=x/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     x
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2874
+
+--S 2875 of 3139
+r0:=-1/2*atanh(1/2*(2*a-b+(b-2*c)*x^2)/(sqrt(a-b+c)*sqrt(a+b*x^2+c*x^4)))/_
+   sqrt(a-b+c)
+--R 
+--R
+--R                             2
+--R                    (2c - b)x  + b - 2a
+--R        atanh(-------------------------------)
+--R                            +---------------+
+--R                +---------+ |   4      2
+--R              2\|c - b + a \|c x  + b x  + a
+--R   (2)  --------------------------------------
+--R                       +---------+
+--R                     2\|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 2875
+
+--S 2876 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                                               +---------------+
+--R                  2      +-+ +---------+                    2  |   4      2
+--R              ((2x  + 2)\|a \|c - b + a  + (- 2c + 2b - 2a)x )\|c x  + b x  + a
+--R            + 
+--R                               4              2       +---------+
+--R              ((- 2c + b - 2a)x  + (- b - 2a)x  - 2a)\|c - b + a
+--R            + 
+--R                              4                  2  +-+
+--R              ((2c - 2b + 2a)x  + (2c - 2b + 2a)x )\|a
+--R         /
+--R                          +---------------+
+--R               2      +-+ |   4      2           4              2
+--R            (2x  + 2)\|a \|c x  + b x  + a  - b x  + (- b - 2a)x  - 2a
+--R    /
+--R         +---------+
+--R       2\|c - b + a
+--R     ,
+--R                        +---------------+
+--R          +-----------+ |   4      2            2      +-----------+ +-+
+--R         \|- c + b - a \|c x  + b x  + a  + (- x  - 1)\|- c + b - a \|a
+--R    atan(---------------------------------------------------------------)
+--R                                              2
+--R                                  (c - b + a)x
+--R    ---------------------------------------------------------------------]
+--R                                 +-----------+
+--R                                \|- c + b - a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2876
+
+--S 2877 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                                               +---------------+
+--R                  2      +-+ +---------+                    2  |   4      2
+--R              ((2x  + 2)\|a \|c - b + a  + (- 2c + 2b - 2a)x )\|c x  + b x  + a
+--R            + 
+--R                               4              2       +---------+
+--R              ((- 2c + b - 2a)x  + (- b - 2a)x  - 2a)\|c - b + a
+--R            + 
+--R                              4                  2  +-+
+--R              ((2c - 2b + 2a)x  + (2c - 2b + 2a)x )\|a
+--R         /
+--R                          +---------------+
+--R               2      +-+ |   4      2           4              2
+--R            (2x  + 2)\|a \|c x  + b x  + a  - b x  + (- b - 2a)x  - 2a
+--R     + 
+--R                              2
+--R                     (2c - b)x  + b - 2a
+--R       - atanh(-------------------------------)
+--R                             +---------------+
+--R                 +---------+ |   4      2
+--R               2\|c - b + a \|c x  + b x  + a
+--R  /
+--R       +---------+
+--R     2\|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 2877
+
+--S 2878 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2878
+
+--S 2879 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                            2
+--R          +-----------+            (2c - b)x  + b - 2a
+--R       - \|- c + b - a atanh(-------------------------------)
+--R                                           +---------------+
+--R                               +---------+ |   4      2
+--R                             2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R           +---------+
+--R         2\|c - b + a
+--R      *
+--R                             +---------------+
+--R               +-----------+ |   4      2            2      +-----------+ +-+
+--R              \|- c + b - a \|c x  + b x  + a  + (- x  - 1)\|- c + b - a \|a
+--R         atan(---------------------------------------------------------------)
+--R                                                   2
+--R                                       (c - b + a)x
+--R  /
+--R       +-----------+ +---------+
+--R     2\|- c + b - a \|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 2879
+
+--S 2880 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2880
+
+)clear all
+
+--S 2881 of 3139
+t0:=1/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2881
+
+--S 2882 of 3139
+--r0:=elliptic_pi(1/2*(b+sqrt(b^2-4*a*c))/c,asin(x*sqrt(2)*sqrt(-c)/_
+---  sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(a+b*x^2+c*x^4)*sqrt(b+sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(-c)*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))
+--E 2882
+
+--S 2883 of 3139
+--a0:=integrate(t0,x)
+--E 2883
+
+--S 2884 of 3139
+--m0:=a0-r0
+--E 2884
+
+--S 2885 of 3139
+--d0:=D(m0,x)
+--E 2885
+
+)clear all
+
+--S 2886 of 3139
+t0:=1/(x*(1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          3      |   4      2
+--R        (x  + x)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2886
+
+--S 2887 of 3139
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)+_
+   1/2*atanh(1/2*(2*a-b+(b-2*c)*x^2)/(sqrt(a-b+c)*sqrt(a+b*x^2+c*x^4)))/_
+   sqrt(a-b+c)
+--R 
+--R
+--R   (2)
+--R                                     2
+--R          +---------+             b x  + 2a
+--R       - \|c - b + a atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|a \|c x  + b x  + a
+--R     + 
+--R                                  2
+--R          +-+            (2c - b)x  + b - 2a
+--R       - \|a atanh(-------------------------------)
+--R                                 +---------------+
+--R                     +---------+ |   4      2
+--R                   2\|c - b + a \|c x  + b x  + a
+--R  /
+--R       +-+ +---------+
+--R     2\|a \|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 2887
+
+--S 2888 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               +---------------+
+--R                           +-+ |   4      2           2
+--R          +---------+    2\|a \|c x  + b x  + a  - b x  - 2a
+--R         \|c - b + a log(-----------------------------------)
+--R                                           2
+--R                                          x
+--R       + 
+--R            +-+
+--R           \|a
+--R        *
+--R           log
+--R                                 2  4             2  2     2  +---------+
+--R                      ((4a c + 4a )x  + (4a b + 8a )x  + 8a )\|c - b + a
+--R                    + 
+--R                                          2            2  4
+--R                          ((2b + 4a)c - 2b  - 2a b + 4a )x
+--R                        + 
+--R                                           2  2
+--R                          (8a c - 8a b + 8a )x
+--R                     *
+--R                         +-+
+--R                        \|a
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                                       2         6
+--R                      ((- 2b - 4a)c + b  - 2a b)x
+--R                    + 
+--R                                 2            2  4               2  2     2
+--R                      (- 8a c - b  - 4a b - 4a )x  + (- 8a b - 8a )x  - 8a
+--R                 *
+--R                     +-+ +---------+
+--R                    \|a \|c - b + a
+--R                + 
+--R                         2             2         2     2   6
+--R                  (- 4a c  + (2a b - 4a )c + 2a b  - 2a b)x
+--R                + 
+--R                               2         2     2      3  4
+--R                  ((- 6a b - 4a )c + 6a b  - 2a b - 4a )x
+--R                + 
+--R                       2      2      3  2
+--R                  (- 8a c + 8a b - 8a )x
+--R             /
+--R                                                   +---------------+
+--R                         4             2  2     2  |   4      2
+--R                  (4a b x  + (4a b + 8a )x  + 8a )\|c x  + b x  + a
+--R                + 
+--R                                 2  6              2         4
+--R                      (- 4a c - b )x  + (- 4a c - b  - 8a b)x
+--R                    + 
+--R                                  2  2     2
+--R                      (- 8a b - 8a )x  - 8a
+--R                 *
+--R                     +-+
+--R                    \|a
+--R    /
+--R         +-+ +---------+
+--R       2\|a \|c - b + a
+--R     ,
+--R
+--R                                 +---------------+
+--R                             +-+ |   4      2           2
+--R          +-----------+    2\|a \|c x  + b x  + a  - b x  - 2a
+--R         \|- c + b - a log(-----------------------------------)
+--R                                             2
+--R                                            x
+--R       + 
+--R         -
+--R                +-+
+--R              2\|a
+--R           *
+--R              atan
+--R                                        +---------------+
+--R                      +-----------+ +-+ |   4      2
+--R                     \|- c + b - a \|a \|c x  + b x  + a
+--R                   + 
+--R                           2      +-----------+
+--R                     (- a x  - a)\|- c + b - a
+--R                /
+--R                               2 +-+
+--R                   (c - b + a)x \|a
+--R    /
+--R         +-----------+ +-+
+--R       2\|- c + b - a \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2888
+
+--S 2889 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             +---------------+
+--R                         +-+ |   4      2           2
+--R        +---------+    2\|a \|c x  + b x  + a  - b x  - 2a
+--R       \|c - b + a log(-----------------------------------)
+--R                                         2
+--R                                        x
+--R     + 
+--R          +-+
+--R         \|a
+--R      *
+--R         log
+--R                               2  4             2  2     2  +---------+
+--R                    ((4a c + 4a )x  + (4a b + 8a )x  + 8a )\|c - b + a
+--R                  + 
+--R                                          2            2  4
+--R                          ((2b + 4a)c - 2b  - 2a b + 4a )x
+--R                        + 
+--R                                           2  2
+--R                          (8a c - 8a b + 8a )x
+--R                   *
+--R                       +-+
+--R                      \|a
+--R               *
+--R                   +---------------+
+--R                   |   4      2
+--R                  \|c x  + b x  + a
+--R              + 
+--R                                     2         6              2            2  4
+--R                    ((- 2b - 4a)c + b  - 2a b)x  + (- 8a c - b  - 4a b - 4a )x
+--R                  + 
+--R                                2  2     2
+--R                    (- 8a b - 8a )x  - 8a
+--R               *
+--R                   +-+ +---------+
+--R                  \|a \|c - b + a
+--R              + 
+--R                       2             2         2     2   6
+--R                (- 4a c  + (2a b - 4a )c + 2a b  - 2a b)x
+--R              + 
+--R                           2         2     2      3  4        2      2      3  2
+--R              ((- 6a b - 4a )c + 6a b  - 2a b - 4a )x  + (- 8a c + 8a b - 8a )x
+--R           /
+--R                                                 +---------------+
+--R                       4             2  2     2  |   4      2
+--R                (4a b x  + (4a b + 8a )x  + 8a )\|c x  + b x  + a
+--R              + 
+--R                               2  6              2         4               2  2
+--R                    (- 4a c - b )x  + (- 4a c - b  - 8a b)x  + (- 8a b - 8a )x
+--R                  + 
+--R                        2
+--R                    - 8a
+--R               *
+--R                   +-+
+--R                  \|a
+--R     + 
+--R                                   2
+--R        +---------+             b x  + 2a
+--R       \|c - b + a atanh(-----------------------)
+--R                               +---------------+
+--R                           +-+ |   4      2
+--R                         2\|a \|c x  + b x  + a
+--R     + 
+--R                                2
+--R        +-+            (2c - b)x  + b - 2a
+--R       \|a atanh(-------------------------------)
+--R                               +---------------+
+--R                   +---------+ |   4      2
+--R                 2\|c - b + a \|c x  + b x  + a
+--R  /
+--R       +-+ +---------+
+--R     2\|a \|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 2889
+
+--S 2890 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2890
+
+--S 2891 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                           +---------------+
+--R                                       +-+ |   4      2           2
+--R        +-----------+ +---------+    2\|a \|c x  + b x  + a  - b x  - 2a
+--R       \|- c + b - a \|c - b + a log(-----------------------------------)
+--R                                                       2
+--R                                                      x
+--R     + 
+--R                                                 2
+--R        +-----------+ +---------+             b x  + 2a
+--R       \|- c + b - a \|c - b + a atanh(-----------------------)
+--R                                             +---------------+
+--R                                         +-+ |   4      2
+--R                                       2\|a \|c x  + b x  + a
+--R     + 
+--R                                              2
+--R        +-----------+ +-+            (2c - b)x  + b - 2a
+--R       \|- c + b - a \|a atanh(-------------------------------)
+--R                                             +---------------+
+--R                                 +---------+ |   4      2
+--R                               2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R       -
+--R              +-+ +---------+
+--R            2\|a \|c - b + a
+--R         *
+--R            atan
+--R                                  +---------------+
+--R                +-----------+ +-+ |   4      2              2      +-----------+
+--R               \|- c + b - a \|a \|c x  + b x  + a  + (- a x  - a)\|- c + b - a
+--R               -----------------------------------------------------------------
+--R                                                   2 +-+
+--R                                       (c - b + a)x \|a
+--R  /
+--R       +-----------+ +-+ +---------+
+--R     2\|- c + b - a \|a \|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 2891
+
+--S 2892 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2892
+
+)clear all
+
+--S 2893 of 3139
+t0:=1/(x^2*(1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                  +---------------+
+--R          4    2  |   4      2
+--R        (x  + x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2893
+
+--S 2894 of 3139
+--r0:=-sqrt(a+b*x^2+c*x^4)/(a*x)-elliptic_pi(1/2*(b+sqrt(b^2-4*a*c))/c,_
+---  asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/_
+---  (b-sqrt(b^2-4*a*c)))*sqrt(a+b*x^2+c*x^4)*sqrt(b+sqrt(b^2-4*a*c))/(a*_
+---  sqrt(2)*sqrt(-c)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/_
+---  (b+sqrt(b^2-4*a*c))))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+---  sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(-b+_
+---  sqrt(b^2-4*a*c))^(3/2)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+_
+---  c*x^4))+1/2*elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+_
+---  sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*_
+---  (b-sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*_
+---  sqrt(-c)*sqrt(a+b*x^2+c*x^4))
+--E 2894
+
+--S 2895 of 3139
+--a0:=integrate(t0,x)
+--E 2895
+
+--S 2896 of 3139
+--m0:=a0-r0
+--E 2896
+
+--S 2897 of 3139
+--d0:=D(m0,x)
+--E 2897
+
+)clear all
+
+--S 2898 of 3139
+t0:=1/(x^3*(1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                  +---------------+
+--R          5    3  |   4      2
+--R        (x  + x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2898
+
+--S 2899 of 3139
+r0:=1/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(3/2)+_
+   1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)-_
+   1/2*atanh(1/2*(2*a-b+(b-2*c)*x^2)/(sqrt(a-b+c)*sqrt(a+b*x^2+c*x^4)))/_
+   sqrt(a-b+c)-1/2*sqrt(a+b*x^2+c*x^4)/(a*x^2)
+--R 
+--R
+--R   (2)
+--R                                             2
+--R                2 +---------+             b x  + 2a
+--R       (b + 2a)x \|c - b + a atanh(-----------------------)
+--R                                         +---------------+
+--R                                     +-+ |   4      2
+--R                                   2\|a \|c x  + b x  + a
+--R     + 
+--R                                     2
+--R           2 +-+            (2c - b)x  + b - 2a
+--R       2a x \|a atanh(-------------------------------)
+--R                                    +---------------+
+--R                        +---------+ |   4      2
+--R                      2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                           +---------------+
+--R           +-+ +---------+ |   4      2
+--R       - 2\|a \|c - b + a \|c x  + b x  + a
+--R  /
+--R         2 +-+ +---------+
+--R     4a x \|a \|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 2899
+
+--S 2900 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                           +---------------+
+--R                         2 +-+ +---------+ |   4      2
+--R             (- 4b - 8a)x \|a \|c - b + a \|c x  + b x  + a
+--R           + 
+--R                 2         4             2  2  +---------+
+--R             ((2b  + 4a b)x  + (4a b + 8a )x )\|c - b + a
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                  +---------------+
+--R              2 2 |   4      2                 4     2 2  +-+
+--R           (8a x \|c x  + b x  + a  + (- 4a b x  - 8a x )\|a )
+--R        *
+--R           log
+--R                                 2  4             2  2     2  +---------+
+--R                      ((4a c + 4a )x  + (4a b + 8a )x  + 8a )\|c - b + a
+--R                    + 
+--R                                            2            2  4
+--R                          ((- 2b - 4a)c + 2b  + 2a b - 4a )x
+--R                        + 
+--R                                             2  2
+--R                          (- 8a c + 8a b - 8a )x
+--R                     *
+--R                         +-+
+--R                        \|a
+--R                 *
+--R                     +---------------+
+--R                     |   4      2
+--R                    \|c x  + b x  + a
+--R                + 
+--R                                       2         6
+--R                      ((- 2b - 4a)c + b  - 2a b)x
+--R                    + 
+--R                                 2            2  4               2  2     2
+--R                      (- 8a c - b  - 4a b - 4a )x  + (- 8a b - 8a )x  - 8a
+--R                 *
+--R                     +-+ +---------+
+--R                    \|a \|c - b + a
+--R                + 
+--R                       2               2         2     2   6
+--R                  (4a c  + (- 2a b + 4a )c - 2a b  + 2a b)x
+--R                + 
+--R                           2         2     2      3  4      2      2      3  2
+--R                ((6a b + 4a )c - 6a b  + 2a b + 4a )x  + (8a c - 8a b + 8a )x
+--R             /
+--R                                                   +---------------+
+--R                         4             2  2     2  |   4      2
+--R                  (4a b x  + (4a b + 8a )x  + 8a )\|c x  + b x  + a
+--R                + 
+--R                                 2  6              2         4
+--R                      (- 4a c - b )x  + (- 4a c - b  - 8a b)x
+--R                    + 
+--R                                  2  2     2
+--R                      (- 8a b - 8a )x  - 8a
+--R                 *
+--R                     +-+
+--R                    \|a
+--R       + 
+--R                                      +---------------+
+--R              2       +-+ +---------+ |   4      2
+--R         (2b x  + 8a)\|a \|c - b + a \|c x  + b x  + a
+--R       + 
+--R                     2  4         2     2  +---------+
+--R         ((- 8a c + b )x  - 6a b x  - 8a )\|c - b + a
+--R    /
+--R                            +---------------+
+--R            2 2 +---------+ |   4      2
+--R         16a x \|c - b + a \|c x  + b x  + a
+--R       + 
+--R                  4      2 2  +-+ +---------+
+--R         (- 8a b x  - 16a x )\|a \|c - b + a
+--R     ,
+--R
+--R                                             +---------------+
+--R                         2 +-----------+ +-+ |   4      2
+--R             (- 4b - 8a)x \|- c + b - a \|a \|c x  + b x  + a
+--R           + 
+--R                 2         4             2  2  +-----------+
+--R             ((2b  + 4a b)x  + (4a b + 8a )x )\|- c + b - a
+--R        *
+--R                     +---------------+
+--R                 +-+ |   4      2           2
+--R               2\|a \|c x  + b x  + a  - b x  - 2a
+--R           log(-----------------------------------)
+--R                               2 +-+
+--R                             2x \|a
+--R       + 
+--R                   +---------------+
+--R               2 2 |   4      2                 4      2 2  +-+
+--R           (16a x \|c x  + b x  + a  + (- 8a b x  - 16a x )\|a )
+--R        *
+--R                                 +---------------+
+--R               +-----------+ +-+ |   4      2              2      +-----------+
+--R              \|- c + b - a \|a \|c x  + b x  + a  + (- a x  - a)\|- c + b - a
+--R         atan(-----------------------------------------------------------------)
+--R                                                  2 +-+
+--R                                      (c - b + a)x \|a
+--R       + 
+--R                                        +---------------+
+--R              2       +-----------+ +-+ |   4      2
+--R         (2b x  + 8a)\|- c + b - a \|a \|c x  + b x  + a
+--R       + 
+--R                     2  4         2     2  +-----------+
+--R         ((- 8a c + b )x  - 6a b x  - 8a )\|- c + b - a
+--R    /
+--R                              +---------------+
+--R            2 2 +-----------+ |   4      2
+--R         16a x \|- c + b - a \|c x  + b x  + a
+--R       + 
+--R                  4      2 2  +-----------+ +-+
+--R         (- 8a b x  - 16a x )\|- c + b - a \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2900
+
+--S 2901 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                      +---------------+
+--R                       2  +---------+ |   4      2
+--R           (- 4a b - 8a )\|c - b + a \|c x  + b x  + a
+--R         + 
+--R               2         2            2  +-+ +---------+
+--R           ((2b  + 4a b)x  + 4a b + 8a )\|a \|c - b + a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                  +---------------+
+--R            2 +-+ |   4      2          2   2     3
+--R         (8a \|a \|c x  + b x  + a  - 4a b x  - 8a )
+--R      *
+--R         log
+--R                               2  4             2  2     2  +---------+
+--R                    ((4a c + 4a )x  + (4a b + 8a )x  + 8a )\|c - b + a
+--R                  + 
+--R                                          2            2  4
+--R                        ((- 2b - 4a)c + 2b  + 2a b - 4a )x
+--R                      + 
+--R                                           2  2
+--R                        (- 8a c + 8a b - 8a )x
+--R                   *
+--R                       +-+
+--R                      \|a
+--R               *
+--R                   +---------------+
+--R                   |   4      2
+--R                  \|c x  + b x  + a
+--R              + 
+--R                                     2         6              2            2  4
+--R                    ((- 2b - 4a)c + b  - 2a b)x  + (- 8a c - b  - 4a b - 4a )x
+--R                  + 
+--R                                2  2     2
+--R                    (- 8a b - 8a )x  - 8a
+--R               *
+--R                   +-+ +---------+
+--R                  \|a \|c - b + a
+--R              + 
+--R                     2               2         2     2   6
+--R                (4a c  + (- 2a b + 4a )c - 2a b  + 2a b)x
+--R              + 
+--R                           2         2     2      3  4      2      2      3  2
+--R                ((6a b + 4a )c - 6a b  + 2a b + 4a )x  + (8a c - 8a b + 8a )x
+--R           /
+--R                                                 +---------------+
+--R                       4             2  2     2  |   4      2
+--R                (4a b x  + (4a b + 8a )x  + 8a )\|c x  + b x  + a
+--R              + 
+--R                               2  6              2         4               2  2
+--R                    (- 4a c - b )x  + (- 4a c - b  - 8a b)x  + (- 8a b - 8a )x
+--R                  + 
+--R                        2
+--R                    - 8a
+--R               *
+--R                   +-+
+--R                  \|a
+--R     + 
+--R                                      +---------------+
+--R                       2  +---------+ |   4      2
+--R           (- 4a b - 8a )\|c - b + a \|c x  + b x  + a
+--R         + 
+--R               2         2            2  +-+ +---------+
+--R           ((2b  + 4a b)x  + 4a b + 8a )\|a \|c - b + a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                    +---------------+
+--R              2 +-+ |   4      2          2   2     3
+--R         (- 8a \|a \|c x  + b x  + a  + 4a b x  + 8a )
+--R      *
+--R                              2
+--R                     (2c - b)x  + b - 2a
+--R         atanh(-------------------------------)
+--R                             +---------------+
+--R                 +---------+ |   4      2
+--R               2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                          +---------------+
+--R              +---------+ |   4      2          2 2         +-+ +---------+
+--R       - 2a b\|c - b + a \|c x  + b x  + a  + (b x  + 2a b)\|a \|c - b + a
+--R  /
+--R                          +---------------+
+--R        2 +-+ +---------+ |   4      2             2   2      3  +---------+
+--R     16a \|a \|c - b + a \|c x  + b x  + a  + (- 8a b x  - 16a )\|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 2901
+
+--S 2902 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2902
+
+--S 2903 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                    +---------------+
+--R                       2  +-----------+ +---------+ |   4      2
+--R           (- 4a b - 8a )\|- c + b - a \|c - b + a \|c x  + b x  + a
+--R         + 
+--R               2         2            2  +-----------+ +-+ +---------+
+--R           ((2b  + 4a b)x  + 4a b + 8a )\|- c + b - a \|a \|c - b + a
+--R      *
+--R                   +---------------+
+--R               +-+ |   4      2           2
+--R             2\|a \|c x  + b x  + a  - b x  - 2a
+--R         log(-----------------------------------)
+--R                             2 +-+
+--R                           2x \|a
+--R     + 
+--R                                                    +---------------+
+--R                       2  +-----------+ +---------+ |   4      2
+--R           (- 4a b - 8a )\|- c + b - a \|c - b + a \|c x  + b x  + a
+--R         + 
+--R               2         2            2  +-----------+ +-+ +---------+
+--R           ((2b  + 4a b)x  + 4a b + 8a )\|- c + b - a \|a \|c - b + a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                                   +---------------+
+--R               2 +-----------+ +-+ |   4      2
+--R           - 8a \|- c + b - a \|a \|c x  + b x  + a
+--R         + 
+--R              2   2     3  +-----------+
+--R           (4a b x  + 8a )\|- c + b - a
+--R      *
+--R                              2
+--R                     (2c - b)x  + b - 2a
+--R         atanh(-------------------------------)
+--R                             +---------------+
+--R                 +---------+ |   4      2
+--R               2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                                  +---------------+
+--R                2 +-+ +---------+ |   4      2
+--R             16a \|a \|c - b + a \|c x  + b x  + a
+--R           + 
+--R                  2   2      3  +---------+
+--R             (- 8a b x  - 16a )\|c - b + a
+--R      *
+--R                               +---------------+
+--R             +-----------+ +-+ |   4      2              2      +-----------+
+--R            \|- c + b - a \|a \|c x  + b x  + a  + (- a x  - a)\|- c + b - a
+--R       atan(-----------------------------------------------------------------)
+--R                                                2 +-+
+--R                                    (c - b + a)x \|a
+--R     + 
+--R                                        +---------------+
+--R              +-----------+ +---------+ |   4      2
+--R       - 2a b\|- c + b - a \|c - b + a \|c x  + b x  + a
+--R     + 
+--R         2 2         +-----------+ +-+ +---------+
+--R       (b x  + 2a b)\|- c + b - a \|a \|c - b + a
+--R  /
+--R                                          +---------------+
+--R          2 +-----------+ +-+ +---------+ |   4      2
+--R       16a \|- c + b - a \|a \|c - b + a \|c x  + b x  + a
+--R     + 
+--R            2   2      3  +-----------+ +---------+
+--R       (- 8a b x  - 16a )\|- c + b - a \|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 2903
+
+--S 2904 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2904
+
+)clear all
+
+--S 2905 of 3139
+t0:=(d+e*x^2)^2/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R         2 4         2    2
+--R        e x  + 2d e x  + d
+--R   (1)  -------------------
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2905
+
+--S 2906 of 3139
+--r0:=1/3*e^2*x*sqrt(a+b*x^2+c*x^4)/c+1/12*b*e^2*elliptic_e(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-_
+---  4*a*c)))*(-b+sqrt(b^2-4*a*c))^(3/2)*(b+sqrt(b^2-4*a*c))^2*sqrt(a+_
+---  b*x^2+c*x^4)/(a^2*c^(7/2)*sqrt(2)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))-1/12*e^2*elliptic_f(asin(x*_
+---  sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(-b+sqrt(b^2-4*a*c))^(3/2)*(b+sqrt(b^2-4*a*c))*_
+---  (b^2-a*c+b*sqrt(b^2-4*a*c))*sqrt(a+b*x^2+c*x^4)/(a^2*c^(7/2)*sqrt(2)*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-_
+---  4*a*c))))+d^2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(a+b*x^2+_
+---  c*x^4)*sqrt(-b+sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(c)*sqrt(1+2*c*x^2/_
+---  (b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))+d*e*_
+---  elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-_
+---  sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(a+_
+---  b*x^2+c*x^4)*sqrt(-b+sqrt(b^2-4*a*c))/(a*c^(3/2)*sqrt(2)*sqrt(1+_
+---  2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))-_
+---  d*e*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(a+b*x^2+c*x^4)*sqrt(-b+sqrt(b^2-4*a*c))/(a*c^(3/2)*sqrt(2)*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))
+--E 2906
+
+--S 2907 of 3139
+--a0:=integrate(t0,x)
+--E 2907
+
+--S 2908 of 3139
+--m0:=a0-r0
+--E 2908
+
+--S 2909 of 3139
+--d0:=D(m0,x)
+--E 2909
+
+)clear all
+
+--S 2910 of 3139
+t0:=(d+e*x^2)/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                2
+--R             e x  + d
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2910
+
+--S 2911 of 3139
+--r0:=1/2*e*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+_
+---  2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+_
+---  2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))+_
+---  1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(2*c*d-e*(b+sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 2911
+
+--S 2912 of 3139
+--a0:=integrate(t0,x)
+--E 2912
+
+--S 2913 of 3139
+--m0:=a0-r0
+--E 2913
+
+--S 2914 of 3139
+--d0:=D(m0,x)
+--E 2914
+
+)clear all
+
+--S 2915 of 3139
+t0:=1/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2915
+
+--S 2916 of 3139
+--r0:=elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 2916
+
+--S 2917 of 3139
+--a0:=integrate(t0,x)
+--E 2917
+
+--S 2918 of 3139
+--m0:=a0-r0
+--E 2918
+
+--S 2919 of 3139
+--d0:=D(m0,x)
+--E 2919
+
+)clear all
+
+--S 2920 of 3139
+t0:=1/((d+e*x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R                   +---------------+
+--R            2      |   4      2
+--R        (e x  + d)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2920
+
+--S 2921 of 3139
+--r0:=elliptic_pi(1/2*e*(b+sqrt(b^2-4*a*c))/(c*d),asin(x*sqrt(2)*_
+---  sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-_
+---  4*a*c)))*sqrt(a+b*x^2+c*x^4)*sqrt(b+sqrt(b^2-4*a*c))/(a*d*sqrt(2)*_
+---  sqrt(-c)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c))))
+--E 2921
+
+--S 2922 of 3139
+--a0:=integrate(t0,x)
+--E 2922
+
+--S 2923 of 3139
+--m0:=a0-r0
+--E 2923
+
+--S 2924 of 3139
+--d0:=D(m0,x)
+--E 2924
+
+)clear all
+
+--S 2925 of 3139
+t0:=(d+e*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                         2
+--R                      e x  + d
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2925
+
+--S 2926 of 3139
+--r0:=x*(b^2*d-2*a*c*d-a*b*e+c*(b*d-2*a*e)*x^2)/(a*(b^2-4*a*c)*_
+---  sqrt(a+b*x^2+c*x^4))-1/2*(b*d-2*a*e)*elliptic_e(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-_
+---  4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*_
+---  (b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))+_
+---  1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2*d-4*a*c*d+(b*d-2*a*e)*_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*_
+---  sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 2926
+
+--S 2927 of 3139
+--a0:=integrate(t0,x)
+--E 2927
+
+--S 2928 of 3139
+--m0:=a0-r0
+--E 2928
+
+--S 2929 of 3139
+--d0:=D(m0,x)
+--E 2929
+
+)clear all
+
+--S 2930 of 3139
+t0:=1/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                         1
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2930
+
+--S 2931 of 3139
+--r0:=x*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-_
+---  1/2*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*_
+---  sqrt(a+b*x^2+c*x^4))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+---  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+---  (b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*_
+---  (b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 2931
+
+--S 2932 of 3139
+--a0:=integrate(t0,x)
+--E 2932
+
+--S 2933 of 3139
+--m0:=a0-r0
+--E 2933
+
+--S 2934 of 3139
+--d0:=D(m0,x)
+--E 2934
+
+)clear all
+
+--S 2935 of 3139
+t0:=(d+e*x^2)^(5/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (1)
+--R          2 8       2           6       2               2  4                2  2
+--R       c e x  + (b e  + 2c d e)x  + (a e  + 2b d e + c d )x  + (2a d e + b d )x
+--R     + 
+--R          2
+--R       a d
+--R  *
+--R      +--------+
+--R      |   2
+--R     \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2935
+
+--S 2936 of 3139
+r0:=1/384*d*(3*c*d^2-10*b*d*e+80*a*e^2)*x*(d+e*x^2)^(3/2)/e^2+_
+   1/480*(3*c*d^2-10*b*d*e+80*a*e^2)*x*(d+e*x^2)^(5/2)/e^2-1/7*(c*d^2-_
+   b*d*e+a*e^2)*x*(d+e*x^2)^(7/2)/(d*e^2)+1/560*(3*c*d^2-10*b*d*e+_
+   80*a*e^2)*x*(d+e*x^2)^(7/2)/(d*e^2)+1/10*c*x*(d+e*x^2)^(9/2)/e^2+_
+   1/256*d^3*(3*c*d^2-10*b*d*e+80*a*e^2)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/_
+   e^(5/2)+1/256*d^2*(3*c*d^2-10*b*d*e+80*a*e^2)*x*sqrt(d+e*x^2)/e^2
+--R 
+--R
+--R   (2)
+--R                                                  +-+
+--R               3 2         4         5          x\|e
+--R       (1200a d e  - 150b d e + 45c d )atanh(-----------)
+--R                                              +--------+
+--R                                              |   2
+--R                                             \|e x  + d
+--R     + 
+--R                 4 9          4            3  7
+--R           384c e x  + (480b e  + 1008c d e )x
+--R         + 
+--R                  4            3         2 2  5
+--R           (640a e  + 1360b d e  + 744c d e )x
+--R         + 
+--R                     3          2 2        3   3
+--R           (2080a d e  + 1180b d e  + 30c d e)x
+--R         + 
+--R                   2 2         3         4
+--R           (2640a d e  + 150b d e - 45c d )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|e \|e x  + d
+--R  /
+--R          2 +-+
+--R     3840e \|e
+--R                                                    Type: Expression(Integer)
+--E 2936
+
+--S 2937 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          3 6          4 5         5 4  8
+--R                 (12000a d e  - 1500b d e  + 450c d e )x
+--R               + 
+--R                           4 5           5 4          6 3  6
+--R                 (192000a d e  - 24000b d e  + 7200c d e )x
+--R               + 
+--R                           5 4            6 3           7 2  4
+--R                 (806400a d e  - 100800b d e  + 30240c d e )x
+--R               + 
+--R                            6 3            7 2           8   2            7 2
+--R                 (1228800a d e  - 153600b d e  + 46080c d e)x  + 614400a d e
+--R               + 
+--R                           8            9
+--R                 - 76800b d e + 23040c d
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|d \|e x  + d
+--R           + 
+--R                       3 7         4 6        5 5  10
+--R             (- 1200a d e  + 150b d e  - 45c d e )x
+--R           + 
+--R                        4 6          5 5          6 4  8
+--R             (- 60000a d e  + 7500b d e  - 2250c d e )x
+--R           + 
+--R                         5 5           6 4           7 3  6
+--R             (- 480000a d e  + 60000b d e  - 18000c d e )x
+--R           + 
+--R                          6 4            7 3           8 2  4
+--R             (- 1344000a d e  + 168000b d e  - 50400c d e )x
+--R           + 
+--R                          7 3            8 2           9   2            8 2
+--R             (- 1536000a d e  + 192000b d e  - 57600c d e)x  - 614400a d e
+--R           + 
+--R                     9            10
+--R             76800b d e - 23040c d
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|d \|e x  + d  - d
+--R       + 
+--R                     9 19            9             8  17
+--R             - 384c e x   + (- 480b e  - 20208c d e )x
+--R           + 
+--R                      9             8            2 7  15
+--R             (- 640a e  - 25360b d e  - 204744c d e )x
+--R           + 
+--R                          8            2 7            3 6  13
+--R             (- 34080a d e  - 261180b d e  - 870510c d e )x
+--R           + 
+--R                         2 7             3 6             4 5  11
+--R             (- 362640a d e  - 1140750b d e  - 1919535c d e )x
+--R           + 
+--R                          3 6             4 5             5 4  9
+--R             (- 1680800a d e  - 2617100b d e  - 2329878c d e )x
+--R           + 
+--R                          4 5             5 4             6 3  7
+--R             (- 4204800a d e  - 3368160b d e  - 1484016c d e )x
+--R           + 
+--R                          5 4             6 3            7 2  5
+--R             (- 5946880a d e  - 2374720b d e  - 368928c d e )x
+--R           + 
+--R                          6 3            7 2           8   3
+--R             (- 4444160a d e  - 796160b d e  + 42240c d e)x
+--R           + 
+--R                          7 2           8            9
+--R             (- 1351680a d e  - 76800b d e + 23040c d )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|e \|e x  + d
+--R       + 
+--R                    9 19           9             8  17
+--R             3840c e x   + (4800b e  + 75360c d e )x
+--R           + 
+--R                     9             8            2 7  15
+--R             (6400a e  + 95200b d e  + 498288c d e )x
+--R           + 
+--R                         8            2 7             3 6  13
+--R             (129600a d e  + 642360b d e  + 1616700c d e )x
+--R           + 
+--R                       2 7             3 6             4 5  11
+--R             (912480a d e  + 2147700b d e  + 2923050c d e )x
+--R           + 
+--R                        3 6             4 5             5 4  9
+--R             (3264800a d e  + 4051100b d e  + 3024030c d e )x
+--R           + 
+--R                        4 5             5 4             6 3  7
+--R             (6707200a d e  + 4460800b d e  + 1672320c d e )x
+--R           + 
+--R                        5 4             6 3            7 2  5
+--R             (8000000a d e  + 2763200b d e  + 350688c d e )x
+--R           + 
+--R                        6 3            7 2           8   3
+--R             (5120000a d e  + 834560b d e  - 53760c d e)x
+--R           + 
+--R                        7 2           8            9
+--R             (1351680a d e  + 76800b d e - 23040c d )x
+--R        *
+--R            +-+ +-+
+--R           \|d \|e
+--R    /
+--R                   6 8            5 6           2 4 4           3 3 2
+--R             38400e x  + 614400d e x  + 2580480d e x  + 3932160d e x
+--R           + 
+--R                     4 2
+--R             1966080d e
+--R        *
+--R                    +--------+
+--R            +-+ +-+ |   2
+--R           \|d \|e \|e x  + d
+--R       + 
+--R                    7 10            6 8           2 5 6           3 4 4
+--R             - 3840e x   - 192000d e x  - 1536000d e x  - 4300800d e x
+--R           + 
+--R                       4 3 2           5 2
+--R             - 4915200d e x  - 1966080d e
+--R        *
+--R            +-+
+--R           \|e
+--R     ,
+--R
+--R                          3 6          4 5         5 4  8
+--R                 (24000a d e  - 3000b d e  + 900c d e )x
+--R               + 
+--R                           4 5           5 4           6 3  6
+--R                 (384000a d e  - 48000b d e  + 14400c d e )x
+--R               + 
+--R                            5 4            6 3           7 2  4
+--R                 (1612800a d e  - 201600b d e  + 60480c d e )x
+--R               + 
+--R                            6 3            7 2           8   2             7 2
+--R                 (2457600a d e  - 307200b d e  + 92160c d e)x  + 1228800a d e
+--R               + 
+--R                            8            9
+--R                 - 153600b d e + 46080c d
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|d \|e x  + d
+--R           + 
+--R                       3 7         4 6        5 5  10
+--R             (- 2400a d e  + 300b d e  - 90c d e )x
+--R           + 
+--R                         4 6           5 5          6 4  8
+--R             (- 120000a d e  + 15000b d e  - 4500c d e )x
+--R           + 
+--R                         5 5            6 4           7 3  6
+--R             (- 960000a d e  + 120000b d e  - 36000c d e )x
+--R           + 
+--R                          6 4            7 3            8 2  4
+--R             (- 2688000a d e  + 336000b d e  - 100800c d e )x
+--R           + 
+--R                          7 3            8 2            9   2             8 2
+--R             (- 3072000a d e  + 384000b d e  - 115200c d e)x  - 1228800a d e
+--R           + 
+--R                      9            10
+--R             153600b d e - 46080c d
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- e \|e x  + d  - \|- e \|d
+--R           atan(------------------------------)
+--R                              e x
+--R       + 
+--R                     9 19            9             8  17
+--R             - 384c e x   + (- 480b e  - 20208c d e )x
+--R           + 
+--R                      9             8            2 7  15
+--R             (- 640a e  - 25360b d e  - 204744c d e )x
+--R           + 
+--R                          8            2 7            3 6  13
+--R             (- 34080a d e  - 261180b d e  - 870510c d e )x
+--R           + 
+--R                         2 7             3 6             4 5  11
+--R             (- 362640a d e  - 1140750b d e  - 1919535c d e )x
+--R           + 
+--R                          3 6             4 5             5 4  9
+--R             (- 1680800a d e  - 2617100b d e  - 2329878c d e )x
+--R           + 
+--R                          4 5             5 4             6 3  7
+--R             (- 4204800a d e  - 3368160b d e  - 1484016c d e )x
+--R           + 
+--R                          5 4             6 3            7 2  5
+--R             (- 5946880a d e  - 2374720b d e  - 368928c d e )x
+--R           + 
+--R                          6 3            7 2           8   3
+--R             (- 4444160a d e  - 796160b d e  + 42240c d e)x
+--R           + 
+--R                          7 2           8            9
+--R             (- 1351680a d e  - 76800b d e + 23040c d )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- e \|e x  + d
+--R       + 
+--R                    9 19           9             8  17
+--R             3840c e x   + (4800b e  + 75360c d e )x
+--R           + 
+--R                     9             8            2 7  15
+--R             (6400a e  + 95200b d e  + 498288c d e )x
+--R           + 
+--R                         8            2 7             3 6  13
+--R             (129600a d e  + 642360b d e  + 1616700c d e )x
+--R           + 
+--R                       2 7             3 6             4 5  11
+--R             (912480a d e  + 2147700b d e  + 2923050c d e )x
+--R           + 
+--R                        3 6             4 5             5 4  9
+--R             (3264800a d e  + 4051100b d e  + 3024030c d e )x
+--R           + 
+--R                        4 5             5 4             6 3  7
+--R             (6707200a d e  + 4460800b d e  + 1672320c d e )x
+--R           + 
+--R                        5 4             6 3            7 2  5
+--R             (8000000a d e  + 2763200b d e  + 350688c d e )x
+--R           + 
+--R                        6 3            7 2           8   3
+--R             (5120000a d e  + 834560b d e  - 53760c d e)x
+--R           + 
+--R                        7 2           8            9
+--R             (1351680a d e  + 76800b d e - 23040c d )x
+--R        *
+--R            +---+ +-+
+--R           \|- e \|d
+--R    /
+--R                   6 8            5 6           2 4 4           3 3 2
+--R             38400e x  + 614400d e x  + 2580480d e x  + 3932160d e x
+--R           + 
+--R                     4 2
+--R             1966080d e
+--R        *
+--R                      +--------+
+--R            +---+ +-+ |   2
+--R           \|- e \|d \|e x  + d
+--R       + 
+--R                    7 10            6 8           2 5 6           3 4 4
+--R             - 3840e x   - 192000d e x  - 1536000d e x  - 4300800d e x
+--R           + 
+--R                       4 3 2           5 2
+--R             - 4915200d e x  - 1966080d e
+--R        *
+--R            +---+
+--R           \|- e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2937
+
+--S 2938 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               3 2        4        5
+--R         (80a d e  - 10b d e + 3c d )
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R     + 
+--R                                                +-+
+--R               3 2        4        5          x\|e
+--R       (- 80a d e  + 10b d e - 3c d )atanh(-----------)
+--R                                            +--------+
+--R                                            |   2
+--R                                           \|e x  + d
+--R  /
+--R         2 +-+
+--R     256e \|e
+--R                                                    Type: Expression(Integer)
+--E 2938
+
+--S 2939 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2939
+
+--S 2940 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                      +-+
+--R               3 2        4        5  +---+         x\|e
+--R       (- 80a d e  + 10b d e - 3c d )\|- e atanh(-----------)
+--R                                                  +--------+
+--R                                                  |   2
+--R                                                 \|e x  + d
+--R     + 
+--R                                                    +--------+
+--R                                              +---+ |   2         +---+ +-+
+--R              3 2        4        5  +-+     \|- e \|e x  + d  - \|- e \|d
+--R       (160a d e  - 20b d e + 6c d )\|e atan(------------------------------)
+--R                                                           e x
+--R  /
+--R         2 +---+ +-+
+--R     256e \|- e \|e
+--R                                                    Type: Expression(Integer)
+--E 2940
+
+--S 2941 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2941
+
+)clear all
+
+--S 2942 of 3139
+t0:=(d+e*x^2)^(3/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R                                                       +--------+
+--R              6               4               2        |   2
+--R   (1)  (c e x  + (b e + c d)x  + (a e + b d)x  + a d)\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2942
+
+--S 2943 of 3139
+r0:=1/192*(3*c*d^2-8*b*d*e+48*a*e^2)*x*(d+e*x^2)^(3/2)/e^2-_
+   1/5*(c*d^2-b*d*e+a*e^2)*x*(d+e*x^2)^(5/2)/(d*e^2)+1/240*(3*c*d^2-_
+   8*b*d*e+48*a*e^2)*x*(d+e*x^2)^(5/2)/(d*e^2)+1/8*c*x*(d+e*x^2)^(7/2)/e^2+_
+   1/128*d^2*(3*c*d^2-8*b*d*e+48*a*e^2)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/_
+   e^(5/2)+1/128*d*(3*c*d^2-8*b*d*e+48*a*e^2)*x*sqrt(d+e*x^2)/e^2
+--R 
+--R
+--R   (2)
+--R                                               +-+
+--R              2 2        3        4          x\|e
+--R       (144a d e  - 24b d e + 9c d )atanh(-----------)
+--R                                           +--------+
+--R                                           |   2
+--R                                          \|e x  + d
+--R     + 
+--R                3 7         3          2  5         3           2       2   3
+--R           48c e x  + (64b e  + 72c d e )x  + (96a e  + 112b d e  + 6c d e)x
+--R         + 
+--R                    2        2        3
+--R           (240a d e  + 24b d e - 9c d )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|e \|e x  + d
+--R  /
+--R         2 +-+
+--R     384e \|e
+--R                                                    Type: Expression(Integer)
+--E 2943
+
+--S 2944 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         2 5         3 4        4 3  6
+--R                 (1152a d e  - 192b d e  + 72c d e )x
+--R               + 
+--R                          3 4          4 3         5 2  4
+--R                 (11520a d e  - 1920b d e  + 720c d e )x
+--R               + 
+--R                          4 3          5 2          6   2           5 2
+--R                 (27648a d e  - 4608b d e  + 1728c d e)x  + 18432a d e
+--R               + 
+--R                          6           7
+--R                 - 3072b d e + 1152c d
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|d \|e x  + d
+--R           + 
+--R                      2 6        3 5       4 4  8
+--R             (- 144a d e  + 24b d e  - 9c d e )x
+--R           + 
+--R                       3 5         4 4         5 3  6
+--R             (- 4608a d e  + 768b d e  - 288c d e )x
+--R           + 
+--R                        4 4          5 3          6 2  4
+--R             (- 23040a d e  + 3840b d e  - 1440c d e )x
+--R           + 
+--R                        5 3          6 2          7   2           6 2
+--R             (- 36864a d e  + 6144b d e  - 2304c d e)x  - 18432a d e
+--R           + 
+--R                    7           8
+--R             3072b d e - 1152c d
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|d \|e x  + d  - d
+--R       + 
+--R                    7 15           7            6  13
+--R             - 48c e x   + (- 64b e  - 1608c d e )x
+--R           + 
+--R                     7            6          2 5  11
+--R             (- 96a e  - 2160b d e  - 9990c d e )x
+--R           + 
+--R                         6           2 5           3 4  9
+--R             (- 3312a d e  - 13848b d e  - 23991c d e )x
+--R           + 
+--R                        2 5           3 4           4 3  7
+--R             (- 23040a d e  - 35072b d e  - 25248c d e )x
+--R           + 
+--R                        3 4           4 3          5 2  5
+--R             (- 62976a d e  - 40704b d e  - 9312c d e )x
+--R           + 
+--R                        4 3           5 2          6   3
+--R             (- 73728a d e  - 20480b d e  + 1536c d e)x
+--R           + 
+--R                        5 2          6           7
+--R             (- 30720a d e  - 3072b d e + 1152c d )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|e \|e x  + d
+--R       + 
+--R                   7 15          7            6  13
+--R             384c e x   + (512b e  + 4800c d e )x
+--R           + 
+--R                    7            6           2 5  11
+--R             (768a e  + 6528b d e  + 19440c d e )x
+--R           + 
+--R                        6           2 5           3 4  9
+--R             (10368a d e  + 27456b d e  + 35400c d e )x
+--R           + 
+--R                      2 5           3 4           4 3  7
+--R             (47232a d e  + 53056b d e  + 30024c d e )x
+--R           + 
+--R                      3 4           4 3          5 2  5
+--R             (96000a d e  + 50560b d e  + 8688c d e )x
+--R           + 
+--R                      4 3           5 2          6   3
+--R             (89088a d e  + 22016b d e  - 2112c d e)x
+--R           + 
+--R                      5 2          6           7
+--R             (30720a d e  + 3072b d e - 1152c d )x
+--R        *
+--R            +-+ +-+
+--R           \|d \|e
+--R    /
+--R                                                                    +--------+
+--R               5 6           4 4         2 3 2         3 2  +-+ +-+ |   2
+--R         (3072e x  + 30720d e x  + 73728d e x  + 49152d e )\|d \|e \|e x  + d
+--R       + 
+--R                6 8           5 6         2 4 4         3 3 2         4 2  +-+
+--R         (- 384e x  - 12288d e x  - 61440d e x  - 98304d e x  - 49152d e )\|e
+--R     ,
+--R
+--R                         2 5         3 4         4 3  6
+--R                 (2304a d e  - 384b d e  + 144c d e )x
+--R               + 
+--R                          3 4          4 3          5 2  4
+--R                 (23040a d e  - 3840b d e  + 1440c d e )x
+--R               + 
+--R                          4 3          5 2          6   2           5 2
+--R                 (55296a d e  - 9216b d e  + 3456c d e)x  + 36864a d e
+--R               + 
+--R                          6           7
+--R                 - 6144b d e + 2304c d
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|d \|e x  + d
+--R           + 
+--R                      2 6        3 5        4 4  8
+--R             (- 288a d e  + 48b d e  - 18c d e )x
+--R           + 
+--R                       3 5          4 4         5 3  6
+--R             (- 9216a d e  + 1536b d e  - 576c d e )x
+--R           + 
+--R                        4 4          5 3          6 2  4
+--R             (- 46080a d e  + 7680b d e  - 2880c d e )x
+--R           + 
+--R                        5 3           6 2          7   2           6 2
+--R             (- 73728a d e  + 12288b d e  - 4608c d e)x  - 36864a d e
+--R           + 
+--R                    7           8
+--R             6144b d e - 2304c d
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- e \|e x  + d  - \|- e \|d
+--R           atan(------------------------------)
+--R                              e x
+--R       + 
+--R                    7 15           7            6  13
+--R             - 48c e x   + (- 64b e  - 1608c d e )x
+--R           + 
+--R                     7            6          2 5  11
+--R             (- 96a e  - 2160b d e  - 9990c d e )x
+--R           + 
+--R                         6           2 5           3 4  9
+--R             (- 3312a d e  - 13848b d e  - 23991c d e )x
+--R           + 
+--R                        2 5           3 4           4 3  7
+--R             (- 23040a d e  - 35072b d e  - 25248c d e )x
+--R           + 
+--R                        3 4           4 3          5 2  5
+--R             (- 62976a d e  - 40704b d e  - 9312c d e )x
+--R           + 
+--R                        4 3           5 2          6   3
+--R             (- 73728a d e  - 20480b d e  + 1536c d e)x
+--R           + 
+--R                        5 2          6           7
+--R             (- 30720a d e  - 3072b d e + 1152c d )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- e \|e x  + d
+--R       + 
+--R                   7 15          7            6  13
+--R             384c e x   + (512b e  + 4800c d e )x
+--R           + 
+--R                    7            6           2 5  11
+--R             (768a e  + 6528b d e  + 19440c d e )x
+--R           + 
+--R                        6           2 5           3 4  9
+--R             (10368a d e  + 27456b d e  + 35400c d e )x
+--R           + 
+--R                      2 5           3 4           4 3  7
+--R             (47232a d e  + 53056b d e  + 30024c d e )x
+--R           + 
+--R                      3 4           4 3          5 2  5
+--R             (96000a d e  + 50560b d e  + 8688c d e )x
+--R           + 
+--R                      4 3           5 2          6   3
+--R             (89088a d e  + 22016b d e  - 2112c d e)x
+--R           + 
+--R                      5 2          6           7
+--R             (30720a d e  + 3072b d e - 1152c d )x
+--R        *
+--R            +---+ +-+
+--R           \|- e \|d
+--R    /
+--R                                                                      +--------+
+--R               5 6           4 4         2 3 2         3 2  +---+ +-+ |   2
+--R         (3072e x  + 30720d e x  + 73728d e x  + 49152d e )\|- e \|d \|e x  + d
+--R       + 
+--R              6 8           5 6         2 4 4         3 3 2         4 2  +---+
+--R       (- 384e x  - 12288d e x  - 61440d e x  - 98304d e x  - 49152d e )\|- e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2944
+
+--S 2945 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               2 2       3        4
+--R         (48a d e  - 8b d e + 3c d )
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R     + 
+--R                                               +-+
+--R               2 2       3        4          x\|e
+--R       (- 48a d e  + 8b d e - 3c d )atanh(-----------)
+--R                                           +--------+
+--R                                           |   2
+--R                                          \|e x  + d
+--R  /
+--R         2 +-+
+--R     128e \|e
+--R                                                    Type: Expression(Integer)
+--E 2945
+
+--S 2946 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2946
+
+--S 2947 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                     +-+
+--R               2 2       3        4  +---+         x\|e
+--R       (- 48a d e  + 8b d e - 3c d )\|- e atanh(-----------)
+--R                                                 +--------+
+--R                                                 |   2
+--R                                                \|e x  + d
+--R     + 
+--R                                                   +--------+
+--R                                             +---+ |   2         +---+ +-+
+--R             2 2        3        4  +-+     \|- e \|e x  + d  - \|- e \|d
+--R       (96a d e  - 16b d e + 6c d )\|e atan(------------------------------)
+--R                                                          e x
+--R  /
+--R         2 +---+ +-+
+--R     128e \|- e \|e
+--R                                                    Type: Expression(Integer)
+--E 2947
+
+--S 2948 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2948
+
+)clear all
+
+--S 2949 of 3139
+t0:=(a+b*x^2+c*x^4)*sqrt(d+e*x^2)
+--R 
+--R
+--R                          +--------+
+--R            4      2      |   2
+--R   (1)  (c x  + b x  + a)\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2949
+
+--S 2950 of 3139
+r0:=-1/3*(c*d^2-b*d*e+a*e^2)*x*(d+e*x^2)^(3/2)/(d*e^2)+1/24*(c*d^2-_
+   2*b*d*e+8*a*e^2)*x*(d+e*x^2)^(3/2)/(d*e^2)+1/6*c*x*(d+e*x^2)^(5/2)/e^2+_
+   1/16*d*(c*d^2-2*b*d*e+8*a*e^2)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/e^(5/2)+_
+   1/16*(c*d^2-2*b*d*e+8*a*e^2)*x*sqrt(d+e*x^2)/e^2
+--R 
+--R
+--R   (2)
+--R                                             +-+
+--R               2       2        3          x\|e
+--R       (24a d e  - 6b d e + 3c d )atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|e x  + d
+--R     + 
+--R                                                                      +--------+
+--R          2 5         2           3         2                2    +-+ |   2
+--R     (8c e x  + (12b e  + 2c d e)x  + (24a e  + 6b d e - 3c d )x)\|e \|e x  + d
+--R  /
+--R        2 +-+
+--R     48e \|e
+--R                                                    Type: Expression(Integer)
+--E 2950
+
+--S 2951 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          4        2 3        3 2  4
+--R                 (144a d e  - 36b d e  + 18c d e )x
+--R               + 
+--R                        2 3         3 2        4   2         3 2         4
+--R                 (768a d e  - 192b d e  + 96c d e)x  + 768a d e  - 192b d e
+--R               + 
+--R                      5
+--R                 96c d
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|d \|e x  + d
+--R           + 
+--R                       5       2 4       3 3  6
+--R             (- 24a d e  + 6b d e  - 3c d e )x
+--R           + 
+--R                      2 4         3 3        4 2  4
+--R             (- 432a d e  + 108b d e  - 54c d e )x
+--R           + 
+--R                       3 3         4 2         5   2         4 2         5
+--R             (- 1152a d e  + 288b d e  - 144c d e)x  - 768a d e  + 192b d e
+--R           + 
+--R                    6
+--R             - 96c d
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|d \|e x  + d  - d
+--R       + 
+--R                   5 11           5           4  9
+--R             - 8c e x   + (- 12b e  - 146c d e )x
+--R           + 
+--R                     5           4         2 3  7
+--R             (- 24a e  - 222b d e  - 417c d e )x
+--R           + 
+--R                        4         2 3         3 2  5
+--R             (- 432a d e  - 684b d e  - 298c d e )x
+--R           + 
+--R                       2 3         3 2        4   3
+--R             (- 1152a d e  - 672b d e  + 80c d e)x
+--R           + 
+--R                      3 2         4         5
+--R             (- 768a d e  - 192b d e + 96c d )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|e \|e x  + d
+--R       + 
+--R                  5 11         5           4  9
+--R             48c e x   + (72b e  + 316c d e )x
+--R           + 
+--R                    5           4         2 3  7
+--R             (144a e  + 492b d e  + 570c d e )x
+--R           + 
+--R                      4         2 3         3 2  5
+--R             (912a d e  + 996b d e  + 270c d e )x
+--R           + 
+--R                     2 3         3 2         4   3
+--R             (1536a d e  + 768b d e  - 128c d e)x
+--R           + 
+--R                    3 2         4         5
+--R             (768a d e  + 192b d e - 96c d )x
+--R        *
+--R            +-+ +-+
+--R           \|d \|e
+--R    /
+--R                                                   +--------+
+--R              4 4          3 2        2 2  +-+ +-+ |   2
+--R         (288e x  + 1536d e x  + 1536d e )\|d \|e \|e x  + d
+--R       + 
+--R               5 6         4 4        2 3 2        3 2  +-+
+--R         (- 48e x  - 864d e x  - 2304d e x  - 1536d e )\|e
+--R     ,
+--R
+--R                          4        2 3        3 2  4
+--R                 (288a d e  - 72b d e  + 36c d e )x
+--R               + 
+--R                         2 3         3 2         4   2          3 2         4
+--R                 (1536a d e  - 384b d e  + 192c d e)x  + 1536a d e  - 384b d e
+--R               + 
+--R                       5
+--R                 192c d
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|d \|e x  + d
+--R           + 
+--R                       5        2 4       3 3  6
+--R             (- 48a d e  + 12b d e  - 6c d e )x
+--R           + 
+--R                      2 4         3 3         4 2  4
+--R             (- 864a d e  + 216b d e  - 108c d e )x
+--R           + 
+--R                       3 3         4 2         5   2          4 2         5
+--R             (- 2304a d e  + 576b d e  - 288c d e)x  - 1536a d e  + 384b d e
+--R           + 
+--R                     6
+--R             - 192c d
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- e \|e x  + d  - \|- e \|d
+--R           atan(------------------------------)
+--R                              e x
+--R       + 
+--R                   5 11           5           4  9
+--R             - 8c e x   + (- 12b e  - 146c d e )x
+--R           + 
+--R                     5           4         2 3  7
+--R             (- 24a e  - 222b d e  - 417c d e )x
+--R           + 
+--R                        4         2 3         3 2  5
+--R             (- 432a d e  - 684b d e  - 298c d e )x
+--R           + 
+--R                       2 3         3 2        4   3
+--R             (- 1152a d e  - 672b d e  + 80c d e)x
+--R           + 
+--R                      3 2         4         5
+--R             (- 768a d e  - 192b d e + 96c d )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- e \|e x  + d
+--R       + 
+--R                  5 11         5           4  9
+--R             48c e x   + (72b e  + 316c d e )x
+--R           + 
+--R                    5           4         2 3  7
+--R             (144a e  + 492b d e  + 570c d e )x
+--R           + 
+--R                      4         2 3         3 2  5
+--R             (912a d e  + 996b d e  + 270c d e )x
+--R           + 
+--R                     2 3         3 2         4   3
+--R             (1536a d e  + 768b d e  - 128c d e)x
+--R           + 
+--R                    3 2         4         5
+--R             (768a d e  + 192b d e - 96c d )x
+--R        *
+--R            +---+ +-+
+--R           \|- e \|d
+--R    /
+--R                                                     +--------+
+--R              4 4          3 2        2 2  +---+ +-+ |   2
+--R         (288e x  + 1536d e x  + 1536d e )\|- e \|d \|e x  + d
+--R       + 
+--R               5 6         4 4        2 3 2        3 2  +---+
+--R         (- 48e x  - 864d e x  - 2304d e x  - 1536d e )\|- e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2951
+
+--S 2952 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                2       2       3
+--R         (8a d e  - 2b d e + c d )
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R     + 
+--R                                             +-+
+--R                2       2       3          x\|e
+--R       (- 8a d e  + 2b d e - c d )atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|e x  + d
+--R  /
+--R        2 +-+
+--R     16e \|e
+--R                                                    Type: Expression(Integer)
+--E 2952
+
+--S 2953 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2953
+
+--S 2954 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                   +-+
+--R                2       2       3  +---+         x\|e
+--R       (- 8a d e  + 2b d e - c d )\|- e atanh(-----------)
+--R                                               +--------+
+--R                                               |   2
+--R                                              \|e x  + d
+--R     + 
+--R                                                  +--------+
+--R                                            +---+ |   2         +---+ +-+
+--R               2       2        3  +-+     \|- e \|e x  + d  - \|- e \|d
+--R       (16a d e  - 4b d e + 2c d )\|e atan(------------------------------)
+--R                                                         e x
+--R  /
+--R        2 +---+ +-+
+--R     16e \|- e \|e
+--R                                                    Type: Expression(Integer)
+--E 2954
+
+--S 2955 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2955
+
+)clear all
+
+--S 2956 of 3139
+t0:=(a+b*x^2+c*x^4)/sqrt(d+e*x^2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R           +--------+
+--R           |   2
+--R          \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2956
+
+--S 2957 of 3139
+r0:=1/4*c*x*(d+e*x^2)^(3/2)/e^2+1/8*(3*c*d^2-4*b*d*e+8*a*e^2)*atanh(x*_
+   sqrt(e)/sqrt(d+e*x^2))/e^(5/2)-(c*d^2-b*d*e+a*e^2)*x*sqrt(d+e*x^2)/_
+   (d*e^2)+1/8*(3*c*d^2-4*b*d*e+8*a*e^2)*x*sqrt(d+e*x^2)/(d*e^2)
+--R 
+--R
+--R   (2)
+--R                                          +-+
+--R            2                2          x\|e
+--R       (8a e  - 4b d e + 3c d )atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|e x  + d
+--R     + 
+--R                                      +--------+
+--R              3                   +-+ |   2
+--R       (2c e x  + (4b e - 3c d)x)\|e \|e x  + d
+--R  /
+--R       2 +-+
+--R     8e \|e
+--R                                                    Type: Expression(Integer)
+--E 2957
+
+--S 2958 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3          2        2   2          2        2         3
+--R               ((32a e  - 16b d e  + 12c d e)x  + 64a d e  - 32b d e + 24c d )
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|d \|e x  + d
+--R           + 
+--R                    4         3       2 2  4
+--R             (- 8a e  + 4b d e  - 3c d e )x
+--R           + 
+--R                       3        2 2        3   2        2 2        3         4
+--R             (- 64a d e  + 32b d e  - 24c d e)x  - 64a d e  + 32b d e - 24c d
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|d \|e x  + d  - d
+--R       + 
+--R                   3 7          3          2  5             2       2   3
+--R             - 2c e x  + (- 4b e  - 13c d e )x  + (- 32b d e  + 8c d e)x
+--R           + 
+--R                     2         3
+--R             (- 32b d e + 24c d )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|e \|e x  + d
+--R       + 
+--R                 3 7         3          2  5           2        2   3
+--R             8c e x  + (16b e  + 12c d e )x  + (48b d e  - 20c d e)x
+--R           + 
+--R                   2         3
+--R             (32b d e - 24c d )x
+--R        *
+--R            +-+ +-+
+--R           \|d \|e
+--R    /
+--R                                 +--------+
+--R           3 2        2  +-+ +-+ |   2             4 4        3 2      2 2  +-+
+--R       (32e x  + 64d e )\|d \|e \|e x  + d  + (- 8e x  - 64d e x  - 64d e )\|e
+--R     ,
+--R
+--R                      3          2        2   2           2        2         3
+--R               ((64a e  - 32b d e  + 24c d e)x  + 128a d e  - 64b d e + 48c d )
+--R            *
+--R                    +--------+
+--R                +-+ |   2
+--R               \|d \|e x  + d
+--R           + 
+--R                     4         3       2 2  4
+--R             (- 16a e  + 8b d e  - 6c d e )x
+--R           + 
+--R                      3        2 2        3   2         2 2        3         4
+--R           (- 128a d e  + 64b d e  - 48c d e)x  - 128a d e  + 64b d e - 48c d
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- e \|e x  + d  - \|- e \|d
+--R           atan(------------------------------)
+--R                              e x
+--R       + 
+--R                   3 7          3          2  5             2       2   3
+--R             - 2c e x  + (- 4b e  - 13c d e )x  + (- 32b d e  + 8c d e)x
+--R           + 
+--R                     2         3
+--R             (- 32b d e + 24c d )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- e \|e x  + d
+--R       + 
+--R                 3 7         3          2  5           2        2   3
+--R             8c e x  + (16b e  + 12c d e )x  + (48b d e  - 20c d e)x
+--R           + 
+--R                   2         3
+--R             (32b d e - 24c d )x
+--R        *
+--R            +---+ +-+
+--R           \|- e \|d
+--R    /
+--R                                     +--------+
+--R             3 2        2  +---+ +-+ |   2
+--R         (32e x  + 64d e )\|- e \|d \|e x  + d
+--R       + 
+--R              4 4        3 2      2 2  +---+
+--R         (- 8e x  - 64d e x  - 64d e )\|- e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2958
+
+--S 2959 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2                2
+--R         (8a e  - 4b d e + 3c d )
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R     + 
+--R                                            +-+
+--R              2                2          x\|e
+--R       (- 8a e  + 4b d e - 3c d )atanh(-----------)
+--R                                        +--------+
+--R                                        |   2
+--R                                       \|e x  + d
+--R  /
+--R       2 +-+
+--R     8e \|e
+--R                                                    Type: Expression(Integer)
+--E 2959
+
+--S 2960 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2960
+
+--S 2961 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                  +-+
+--R              2                2  +---+         x\|e
+--R       (- 8a e  + 4b d e - 3c d )\|- e atanh(-----------)
+--R                                              +--------+
+--R                                              |   2
+--R                                             \|e x  + d
+--R     + 
+--R                                                +--------+
+--R                                          +---+ |   2         +---+ +-+
+--R             2                2  +-+     \|- e \|e x  + d  - \|- e \|d
+--R       (16a e  - 8b d e + 6c d )\|e atan(------------------------------)
+--R                                                       e x
+--R  /
+--R       2 +---+ +-+
+--R     8e \|- e \|e
+--R                                                    Type: Expression(Integer)
+--E 2961
+
+--S 2962 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2962
+
+)clear all
+
+--S 2963 of 3139
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^(3/2)
+--R 
+--R
+--R              4      2
+--R           c x  + b x  + a
+--R   (1)  ---------------------
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2963
+
+--S 2964 of 3139
+r0:=-1/2*(3*c*d-2*b*e)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/e^(5/2)+_
+   (c*d^2-b*d*e+a*e^2)*x/(d*e^2*sqrt(d+e*x^2))+1/2*c*x*sqrt(d+e*x^2)/e^2
+--R 
+--R
+--R   (2)
+--R                        +--------+           +-+
+--R                     2  |   2              x\|e
+--R       (2b d e - 3c d )\|e x  + d atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|e x  + d
+--R     + 
+--R               3        2                2    +-+
+--R       (c d e x  + (2a e  - 2b d e + 3c d )x)\|e
+--R  /
+--R               +--------+
+--R         2 +-+ |   2
+--R     2d e \|e \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2964
+
+--S 2965 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                          +--------+
+--R                     2       2   2       2         3  +-+ |   2
+--R             ((6b d e  - 9c d e)x  + 8b d e - 12c d )\|d \|e x  + d
+--R           + 
+--R                    3       2 2  4           2 2        3   2       3         4
+--R           (- 2b d e  + 3c d e )x  + (- 10b d e  + 15c d e)x  - 8b d e + 12c d
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|d \|e x  + d  - d
+--R       + 
+--R                    2 5          3         2       2   3
+--R             - c d e x  + (- 2a e  + 2b d e  - 7c d e)x
+--R           + 
+--R                      2       2         3
+--R             (- 8a d e  + 8b d e - 12c d )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|e \|e x  + d
+--R       + 
+--R                   2 5        3         2        2   3
+--R             3c d e x  + (6a e  - 6b d e  + 13c d e)x
+--R           + 
+--R                    2       2         3
+--R             (8a d e  - 8b d e + 12c d )x
+--R        *
+--R            +-+ +-+
+--R           \|d \|e
+--R    /
+--R                                 +--------+
+--R            3 2     2 2  +-+ +-+ |   2               4 4      2 3 2     3 2  +-+
+--R       (6d e x  + 8d e )\|d \|e \|e x  + d  + (- 2d e x  - 10d e x  - 8d e )\|e
+--R     ,
+--R
+--R                                                             +--------+
+--R                      2        2   2        2         3  +-+ |   2
+--R             ((12b d e  - 18c d e)x  + 16b d e - 24c d )\|d \|e x  + d
+--R           + 
+--R                    3       2 2  4           2 2        3   2        3         4
+--R           (- 4b d e  + 6c d e )x  + (- 20b d e  + 30c d e)x  - 16b d e + 24c d
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- e \|e x  + d  - \|- e \|d
+--R           atan(------------------------------)
+--R                              e x
+--R       + 
+--R                    2 5          3         2       2   3
+--R             - c d e x  + (- 2a e  + 2b d e  - 7c d e)x
+--R           + 
+--R                      2       2         3
+--R             (- 8a d e  + 8b d e - 12c d )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- e \|e x  + d
+--R       + 
+--R                   2 5        3         2        2   3
+--R             3c d e x  + (6a e  - 6b d e  + 13c d e)x
+--R           + 
+--R                    2       2         3
+--R             (8a d e  - 8b d e + 12c d )x
+--R        *
+--R            +---+ +-+
+--R           \|- e \|d
+--R    /
+--R                                     +--------+
+--R              3 2     2 2  +---+ +-+ |   2
+--R         (6d e x  + 8d e )\|- e \|d \|e x  + d
+--R       + 
+--R                4 4      2 3 2     3 2  +---+
+--R         (- 2d e x  - 10d e x  - 8d e )\|- e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2965
+
+--S 2966 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (2b e - 3c d)
+--R      *
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R         log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R     + 
+--R                                 +-+
+--R                               x\|e
+--R       (- 2b e + 3c d)atanh(-----------)
+--R                             +--------+
+--R                             |   2
+--R                            \|e x  + d
+--R  /
+--R       2 +-+
+--R     2e \|e
+--R                                                    Type: Expression(Integer)
+--E 2966
+
+--S 2967 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2967
+
+--S 2968 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                       +-+
+--R                       +---+         x\|e
+--R       (- 2b e + 3c d)\|- e atanh(-----------)
+--R                                   +--------+
+--R                                   |   2
+--R                                  \|e x  + d
+--R     + 
+--R                                    +--------+
+--R                              +---+ |   2         +---+ +-+
+--R                     +-+     \|- e \|e x  + d  - \|- e \|d
+--R       (4b e - 6c d)\|e atan(------------------------------)
+--R                                           e x
+--R  /
+--R       2 +---+ +-+
+--R     2e \|- e \|e
+--R                                                    Type: Expression(Integer)
+--E 2968
+
+--S 2969 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2969
+
+)clear all
+
+--S 2970 of 3139
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^(5/2)
+--R 
+--R
+--R                    4      2
+--R                 c x  + b x  + a
+--R   (1)  --------------------------------
+--R                              +--------+
+--R          2 4         2    2  |   2
+--R        (e x  + 2d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2970
+
+--S 2971 of 3139
+r0:=1/3*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^(3/2))+c*atanh(x*sqrt(e)/_
+   sqrt(d+e*x^2))/e^(5/2)-1/3*(4*c*d^2-e*(b*d+2*a*e))*x/(d^2*e^2*sqrt(d+e*x^2))
+--R 
+--R
+--R   (2)
+--R                           +--------+           +-+
+--R            2   2       3  |   2              x\|e
+--R       (3c d e x  + 3c d )\|e x  + d atanh(-----------)
+--R                                            +--------+
+--R                                            |   2
+--R                                           \|e x  + d
+--R     + 
+--R             3        2       2   3          2       3    +-+
+--R       ((2a e  + b d e  - 4c d e)x  + (3a d e  - 3c d )x)\|e
+--R  /
+--R                           +--------+
+--R        2 3 2     3 2  +-+ |   2
+--R     (3d e x  + 3d e )\|e \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2971
+
+--S 2972 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                   +--------+
+--R                  2 2 4        3   2        4  +-+ |   2            2 3 6
+--R             (9c d e x  + 21c d e x  + 12c d )\|d \|e x  + d  - 3c d e x
+--R           + 
+--R                    3 2 4        4   2        5
+--R             - 18c d e x  - 27c d e x  - 12c d
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|d \|e x  + d  - d
+--R       + 
+--R                    4        3       2 2  5             3       2 2        3   3
+--R             (- 2a e  - b d e  + 4c d e )x  + (- 11a d e  - 4b d e  + 19c d e)x
+--R           + 
+--R                     2 2        4
+--R             (- 12a d e  + 12c d )x
+--R        *
+--R                +--------+
+--R            +-+ |   2
+--R           \|e \|e x  + d
+--R       + 
+--R                  4         3        2 2  5           3       2 2        3   3
+--R             (6a e  + 3b d e  - 12c d e )x  + (17a d e  + 4b d e  - 25c d e)x
+--R           + 
+--R                   2 2        4
+--R             (12a d e  - 12c d )x
+--R        *
+--R            +-+ +-+
+--R           \|d \|e
+--R    /
+--R                                               +--------+
+--R            2 4 4      3 3 2      4 2  +-+ +-+ |   2
+--R         (9d e x  + 21d e x  + 12d e )\|d \|e \|e x  + d
+--R       + 
+--R              2 5 6      3 4 4      4 3 2      5 2  +-+
+--R         (- 3d e x  - 18d e x  - 27d e x  - 12d e )\|e
+--R     ,
+--R
+--R                                                    +--------+
+--R                   2 2 4        3   2        4  +-+ |   2            2 3 6
+--R             (18c d e x  + 42c d e x  + 24c d )\|d \|e x  + d  - 6c d e x
+--R           + 
+--R                    3 2 4        4   2        5
+--R             - 36c d e x  - 54c d e x  - 24c d
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- e \|e x  + d  - \|- e \|d
+--R           atan(------------------------------)
+--R                              e x
+--R       + 
+--R                    4        3       2 2  5             3       2 2        3   3
+--R             (- 2a e  - b d e  + 4c d e )x  + (- 11a d e  - 4b d e  + 19c d e)x
+--R           + 
+--R                     2 2        4
+--R             (- 12a d e  + 12c d )x
+--R        *
+--R                  +--------+
+--R            +---+ |   2
+--R           \|- e \|e x  + d
+--R       + 
+--R                  4         3        2 2  5           3       2 2        3   3
+--R             (6a e  + 3b d e  - 12c d e )x  + (17a d e  + 4b d e  - 25c d e)x
+--R           + 
+--R                   2 2        4
+--R             (12a d e  - 12c d )x
+--R        *
+--R            +---+ +-+
+--R           \|- e \|d
+--R    /
+--R                                                 +--------+
+--R            2 4 4      3 3 2      4 2  +---+ +-+ |   2
+--R         (9d e x  + 21d e x  + 12d e )\|- e \|d \|e x  + d
+--R       + 
+--R              2 5 6      3 4 4      4 3 2      5 2  +---+
+--R         (- 3d e x  - 18d e x  - 27d e x  - 12d e )\|- e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2972
+
+--S 2973 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                              +--------+
+--R               +-+ +-+        |   2              2      +-+       +-+
+--R             (\|d \|e  - e x)\|e x  + d  + (- e x  - d)\|e  + e x\|d
+--R       c log(--------------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R     + 
+--R                      +-+
+--R                    x\|e
+--R       - c atanh(-----------)
+--R                  +--------+
+--R                  |   2
+--R                 \|e x  + d
+--R  /
+--R      2 +-+
+--R     e \|e
+--R                                                    Type: Expression(Integer)
+--E 2973
+
+--S 2974 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2974
+
+--S 2975 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                   +--------+
+--R                       +-+                   +---+ |   2         +---+ +-+
+--R       +---+         x\|e           +-+     \|- e \|e x  + d  - \|- e \|d
+--R   - c\|- e atanh(-----------) + 2c\|e atan(------------------------------)
+--R                   +--------+                             e x
+--R                   |   2
+--R                  \|e x  + d
+--R   ------------------------------------------------------------------------
+--R                                  2 +---+ +-+
+--R                                 e \|- e \|e
+--R                                                    Type: Expression(Integer)
+--E 2975
+
+--S 2976 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2976
+
+)clear all
+
+--S 2977 of 3139
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^(7/2)
+--R 
+--R
+--R                         4      2
+--R                      c x  + b x  + a
+--R   (1)  ------------------------------------------
+--R                                        +--------+
+--R          3 6       2 4     2   2    3  |   2
+--R        (e x  + 3d e x  + 3d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2977
+
+--S 2978 of 3139
+r0:=1/5*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^(5/2))-1/15*(6*c*d^2-_
+   e*(b*d+4*a*e))*x/(d^2*e^2*(d+e*x^2)^(3/2))+1/15*(3*c*d^2+2*e*(b*d+_
+   4*a*e))*x/(d^3*e^2*sqrt(d+e*x^2))
+--R 
+--R
+--R             2                2  5                  2  3        2
+--R        (8a e  + 2b d e + 3c d )x  + (20a d e + 5b d )x  + 15a d x
+--R   (2)  ----------------------------------------------------------
+--R                                               +--------+
+--R                      3 2 4      4   2      5  |   2
+--R                  (15d e x  + 30d e x  + 15d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2978
+
+--S 2979 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  4         3       2 2  9
+--R           (- 8a e  - 2b d e  - 3c d e )x
+--R         + 
+--R                      3        2 2        3   7
+--R           (- 116a d e  - 29b d e  - 36c d e)x
+--R         + 
+--R                  2 2        3         4  5            3         4  3         4
+--R         (- 383a d e  - 92b d e - 48c d )x  + (- 500a d e - 80b d )x  - 240a d x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|e x  + d
+--R     + 
+--R                 4          3        2 2  9            3        2 2        3   7
+--R           (40a e  + 10b d e  + 15c d e )x  + (260a d e  + 65b d e  + 60c d e)x
+--R         + 
+--R                  2 2         3         4  5          3         4  3         4
+--R           (603a d e  + 132b d e + 48c d )x  + (620a d e + 80b d )x  + 240a d x
+--R      *
+--R          +-+
+--R         \|d
+--R  /
+--R                                                                  +--------+
+--R           3 4 8       4 3 6       5 2 4       6   2       7  +-+ |   2
+--R       (75d e x  + 450d e x  + 915d e x  + 780d e x  + 240d )\|d \|e x  + d
+--R     + 
+--R            3 5 10       4 4 8       5 3 6        6 2 4       7   2       8
+--R       - 15d e x   - 225d e x  - 825d e x  - 1275d e x  - 900d e x  - 240d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2979
+
+--S 2980 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2980
+
+--S 2981 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2981
+
+)clear all
+
+--S 2982 of 3139
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^(9/2)
+--R 
+--R
+--R                              4      2
+--R                           c x  + b x  + a
+--R   (1)  ----------------------------------------------------
+--R                                                  +--------+
+--R          4 8       3 6     2 2 4     3   2    4  |   2
+--R        (e x  + 4d e x  + 6d e x  + 4d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2982
+
+--S 2983 of 3139
+r0:=1/7*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^(7/2))-1/35*(8*c*d^2-_
+   e*(b*d+6*a*e))*x/(d^2*e^2*(d+e*x^2)^(5/2))+1/105*(3*c*d^2+4*e*(b*d+_
+   6*a*e))*x/(d^3*e^2*(d+e*x^2)^(3/2))+2/105*(3*c*d^2+4*e*(b*d+6*a*e))*x/_
+   (d^4*e^2*sqrt(d+e*x^2))
+--R 
+--R
+--R   (2)
+--R             3         2       2   7            2        2         3  5
+--R       (48a e  + 8b d e  + 6c d e)x  + (168a d e  + 28b d e + 21c d )x
+--R     + 
+--R              2         3  3         3
+--R       (210a d e + 35b d )x  + 105a d x
+--R  /
+--R                                                 +--------+
+--R          4 3 6       5 2 4       6   2       7  |   2
+--R     (105d e x  + 315d e x  + 315d e x  + 105d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2983
+
+--S 2984 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   6         5       2 4  13
+--R           (- 48a e  - 8b d e  - 6c d e )x
+--R         + 
+--R                       5         2 4         3 3  11
+--R           (- 1320a d e  - 220b d e  - 165c d e )x
+--R         + 
+--R                     2 4          3 3         4 2  9
+--R           (- 8082a d e  - 1347b d e  - 984c d e )x
+--R         + 
+--R                      3 3          4 2          5   7
+--R           (- 21657a d e  - 3592b d e  - 2064c d e)x
+--R         + 
+--R                      4 2          5           6  5
+--R           (- 30072a d e  - 4592b d e - 1344c d )x
+--R         + 
+--R                      5           6  3          6
+--R           (- 21840a d e - 2240b d )x  - 6720a d x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|e x  + d
+--R     + 
+--R                  6          5        2 4  13
+--R           (336a e  + 56b d e  + 42c d e )x
+--R         + 
+--R                     5         2 4         3 3  11
+--R           (3864a d e  + 644b d e  + 483c d e )x
+--R         + 
+--R                    2 4          3 3          4 2  9
+--R           (16254a d e  + 2709b d e  + 1848c d e )x
+--R         + 
+--R                    3 3          4 2          5   7
+--R           (34383a d e  + 5608b d e  + 2736c d e)x
+--R         + 
+--R                    4 2          5           6  5            5           6  3
+--R           (40152a d e  + 5712b d e + 1344c d )x  + (25200a d e + 2240b d )x
+--R         + 
+--R                  6
+--R           6720a d x
+--R      *
+--R          +-+
+--R         \|d
+--R  /
+--R               4 6 12        5 5 10         6 4 8         7 3 6         8 2 4
+--R           735d e x   + 8085d e x   + 31605d e x  + 60375d e x  + 61320d e x
+--R         + 
+--R                 9   2        10
+--R           31920d e x  + 6720d
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|d \|e x  + d
+--R     + 
+--R             4 7 14        5 6 12         6 5 10         7 4 8         8 3 6
+--R       - 105d e x   - 2940d e x   - 19110d e x   - 55860d e x  - 87465d e x
+--R     + 
+--R               9 2 4         10   2        11
+--R       - 76440d e x  - 35280d  e x  - 6720d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2984
+
+--S 2985 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2985
+
+--S 2986 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2986
+
+)clear all
+
+--S 2987 of 3139
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^(11/2)
+--R 
+--R
+--R                                    4      2
+--R                                 c x  + b x  + a
+--R   (1)  -----------------------------------------------------------------
+--R                                                               +--------+
+--R          5 10       4 8      2 3 6      3 2 4     4   2    5  |   2
+--R        (e x   + 5d e x  + 10d e x  + 10d e x  + 5d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2987
+
+--S 2988 of 3139
+r0:=1/9*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^(9/2))-1/63*(10*c*d^2-_
+   e*(b*d+8*a*e))*x/(d^2*e^2*(d+e*x^2)^(7/2))+1/105*(c*d^2+2*e*(b*d+_
+   8*a*e))*x/(d^3*e^2*(d+e*x^2)^(5/2))+4/315*(c*d^2+2*e*(b*d+8*a*e))*_
+   x/(d^4*e^2*(d+e*x^2)^(3/2))+8/315*(c*d^2+2*e*(b*d+8*a*e))*x/(d^5*e^2*_
+   sqrt(d+e*x^2))
+--R 
+--R
+--R   (2)
+--R              4          3       2 2  9            3        2 2        3   7
+--R       (128a e  + 16b d e  + 8c d e )x  + (576a d e  + 72b d e  + 36c d e)x
+--R     + 
+--R               2 2         3         4  5          3          4  3         4
+--R       (1008a d e  + 126b d e + 63c d )x  + (840a d e + 105b d )x  + 315a d x
+--R  /
+--R                                                                +--------+
+--R          5 4 8        6 3 6        7 2 4        8   2       9  |   2
+--R     (315d e x  + 1260d e x  + 1890d e x  + 1260d e x  + 315d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 2988
+
+--S 2989 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    8          7       2 6  17
+--R           (- 128a e  - 16b d e  - 8c d e )x
+--R         + 
+--R                       7         2 6         3 5  15
+--R           (- 5696a d e  - 712b d e  - 356c d e )x
+--R         + 
+--R                      2 6          3 5          4 4  13
+--R           (- 54768a d e  - 6846b d e  - 3423c d e )x
+--R         + 
+--R                       3 5           4 4           5 3  11
+--R           (- 236744a d e  - 29593b d e  - 14744c d e )x
+--R         + 
+--R                       4 4           5 3           6 2  9
+--R           (- 566651a d e  - 70792b d e  - 33296c d e )x
+--R         + 
+--R                       5 3            6 2           7   7
+--R           (- 813240a d e  - 100080b d e  - 37440c d e)x
+--R         + 
+--R                       6 2           7            8  5
+--R           (- 709968a d e  - 79296b d e - 16128c d )x
+--R         + 
+--R                       7            8  3           8
+--R           (- 356160a d e - 26880b d )x  - 80640a d x
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|e x  + d
+--R     + 
+--R                   8           7        2 6  17
+--R           (1152a e  + 144b d e  + 72c d e )x
+--R         + 
+--R                      7          2 6          3 5  15
+--R           (20544a d e  + 2568b d e  + 1284c d e )x
+--R         + 
+--R                     2 6           3 5          4 4  13
+--R           (133488a d e  + 16686b d e  + 8343c d e )x
+--R         + 
+--R                     3 5           4 4           5 3  11
+--R           (451080a d e  + 56385b d e  + 27720c d e )x
+--R         + 
+--R                     4 4            5 3           6 2  9
+--R           (903635a d e  + 112600b d e  + 50000c d e )x
+--R         + 
+--R                      5 3            6 2           7   7
+--R           (1128744a d e  + 136368b d e  + 45504c d e)x
+--R         + 
+--R                     6 2           7            8  5
+--R           (877968a d e  + 92736b d e + 16128c d )x
+--R         + 
+--R                     7            8  3           8
+--R           (396480a d e + 26880b d )x  + 80640a d x
+--R      *
+--R          +-+
+--R         \|d
+--R  /
+--R                5 8 16         6 7 14          7 6 12          8 5 10
+--R           2835d e x   + 49140d e x   + 304290d e x   + 963900d e x
+--R         + 
+--R                   9 4 8           10 3 6           11 2 4          12   2
+--R           1776915d e x  + 1993320d  e x  + 1345680d  e x  + 504000d  e x
+--R         + 
+--R                 13
+--R           80640d
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|d \|e x  + d
+--R     + 
+--R             5 9 18         6 8 16          7 7 14          8 6 12
+--R       - 315d e x   - 14175d e x   - 141750d e x   - 648270d e x
+--R     + 
+--R                 9 5 10           10 4 8           11 3 6           12 2 4
+--R       - 1669815d e x   - 2633715d  e x  - 2608200d  e x  - 1587600d  e x
+--R     + 
+--R                13   2         14
+--R       - 544320d  e x  - 80640d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2989
+
+--S 2990 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2990
+
+--S 2991 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2991
+
+)clear all
+
+--S 2992 of 3139
+t0:=x^4*sqrt(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          4 |   2
+--R         x \|e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2992
+
+--S 2993 of 3139
+r0:=1/2*(c*d-2*b*e)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/(c^2*sqrt(e))+_
+   1/2*x*sqrt(d+e*x^2)/c+atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*(b*c*d-b^2*e+a*c*e+_
+   (-b^2*c*d+2*a*c^2*d+b^3*e-3*a*b*c*e)/sqrt(b^2-4*a*c))/(c^2*_
+   sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c)))-_
+   atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+_
+   sqrt(b^2-4*a*c))))*(b*c*d-b^2*e+a*c*e+(b^2*c*d-2*a*c^2*d-b^3*e+_
+   3*a*b*c*e)/sqrt(b^2-4*a*c))/(c^2*sqrt(b+sqrt(b^2-4*a*c))*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                                    +-----------+
+--R                      2             |          2                  3
+--R           ((2a c - 2b )e + 2b c d)\|- 4a c + b   + (- 6a b c + 2b )e
+--R         + 
+--R                2     2
+--R           (4a c  - 2b c)d
+--R      *
+--R              +------------------------------+ +------------------+
+--R              |    +-----------+               | +-----------+
+--R          +-+ |    |          2                | |          2
+--R         \|e \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                      +-----------+
+--R                        2             |          2                  3
+--R           ((- 2a c + 2b )e - 2b c d)\|- 4a c + b   + (- 6a b c + 2b )e
+--R         + 
+--R                2     2
+--R           (4a c  - 2b c)d
+--R      *
+--R              +------------------+ +----------------------------+
+--R              | +-----------+      |  +-----------+
+--R          +-+ | |          2       |  |          2
+--R         \|e \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                          +-----------+           +-+
+--R                          |          2          x\|e
+--R           (- 2b e + c d)\|- 4a c + b  atanh(-----------)
+--R                                              +--------+
+--R                                              |   2
+--R                                             \|e x  + d
+--R         + 
+--R               +-----------+     +--------+
+--R               |          2  +-+ |   2
+--R           c x\|- 4a c + b  \|e \|e x  + d
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                             +------------------------------+
+--R           +-----------+     |    +-----------+
+--R         2 |          2  +-+ |    |          2
+--R       2c \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R      +------------------+ +------------------+ +----------------------------+
+--R      | +-----------+      | +-----------+      |  +-----------+
+--R      | |          2       | |          2       |  |          2
+--R     \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 2993
+
+--S 2994 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          +--------+
+--R                2 +-+ +-+ |   2          2   2     2   +-+
+--R           (- 2c \|d \|e \|e x  + d  + (c e x  + 2c d)\|e )
+--R        *
+--R           ROOT
+--R                          5     2 4
+--R                    (16a c  - 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  2
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                              2   3       3 2     5
+--R                           (4a b c  - 6a b c  + 2b c)d e
+--R                         + 
+--R                               2 4       2 3    4 2  2
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4              2    3
+--R                  (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                2 6        2 5     4 4
+--R                            (32a c  - 24a b c  + 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                 2   3       3 2    5
+--R                              (4a b c  - 5a b c  + b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                  2 6        2 5     4 4
+--R                            (- 32a c  + 24a b c  - 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                   2   3       3 2    5
+--R                              (- 4a b c  + 5a b c  - b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                   5     2 4
+--R                             (16a c  - 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4              2    3
+--R                           (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                                                                +--------+
+--R                        3        2 3        3 2     2 2     +-+ |   2
+--R                  ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                + 
+--R                      3        2 3  2        3 2     2 2       2
+--R                  ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                + 
+--R                     3        2 3            3 2     2 2   2
+--R                  (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                        +--------+
+--R              2 +-+ +-+ |   2            2   2     2   +-+
+--R           (2c \|d \|e \|e x  + d  + (- c e x  - 2c d)\|e )
+--R        *
+--R           ROOT
+--R                            5     2 4
+--R                    (- 16a c  + 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  2
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                              2   3       3 2     5
+--R                           (4a b c  - 6a b c  + 2b c)d e
+--R                         + 
+--R                               2 4       2 3    4 2  2
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4              2    3
+--R                  (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                2 6        2 5     4 4
+--R                            (32a c  - 24a b c  + 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                   2   3       3 2    5
+--R                              (- 4a b c  + 5a b c  - b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                  2 6        2 5     4 4
+--R                            (- 32a c  + 24a b c  - 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                 2   3       3 2    5
+--R                              (4a b c  - 5a b c  + b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                     5     2 4
+--R                             (- 16a c  + 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4              2    3
+--R                           (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                                                                +--------+
+--R                        3        2 3        3 2     2 2     +-+ |   2
+--R                  ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                + 
+--R                      3        2 3  2        3 2     2 2       2
+--R                  ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                + 
+--R                     3        2 3            3 2     2 2   2
+--R                  (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                          +--------+
+--R                2 +-+ +-+ |   2          2   2     2   +-+
+--R           (- 2c \|d \|e \|e x  + d  + (c e x  + 2c d)\|e )
+--R        *
+--R           ROOT
+--R                            5     2 4
+--R                    (- 16a c  + 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  2
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                              2   3       3 2     5
+--R                           (4a b c  - 6a b c  + 2b c)d e
+--R                         + 
+--R                               2 4       2 3    4 2  2
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4              2    3
+--R                  (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                  2 6        2 5     4 4
+--R                            (- 32a c  + 24a b c  - 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                 2   3       3 2    5
+--R                              (4a b c  - 5a b c  + b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                2 6        2 5     4 4
+--R                            (32a c  - 24a b c  + 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                   2   3       3 2    5
+--R                              (- 4a b c  + 5a b c  - b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                     5     2 4
+--R                             (- 16a c  + 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4              2    3
+--R                           (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                                                                +--------+
+--R                        3        2 3        3 2     2 2     +-+ |   2
+--R                  ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                + 
+--R                      3        2 3  2        3 2     2 2       2
+--R                  ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                + 
+--R                     3        2 3            3 2     2 2   2
+--R                  (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                        +--------+
+--R              2 +-+ +-+ |   2            2   2     2   +-+
+--R           (2c \|d \|e \|e x  + d  + (- c e x  - 2c d)\|e )
+--R        *
+--R           ROOT
+--R                          5     2 4
+--R                    (16a c  - 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  2
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                              2   3       3 2     5
+--R                           (4a b c  - 6a b c  + 2b c)d e
+--R                         + 
+--R                               2 4       2 3    4 2  2
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4              2    3
+--R                  (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                  2 6        2 5     4 4
+--R                            (- 32a c  + 24a b c  - 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                   2   3       3 2    5
+--R                              (- 4a b c  + 5a b c  - b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                2 6        2 5     4 4
+--R                            (32a c  - 24a b c  + 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                 2   3       3 2    5
+--R                              (4a b c  - 5a b c  + b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                   5     2 4
+--R                             (16a c  - 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4              2    3
+--R                           (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                                                                +--------+
+--R                        3        2 3        3 2     2 2     +-+ |   2
+--R                  ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                + 
+--R                      3        2 3  2        3 2     2 2       2
+--R                  ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                + 
+--R                     3        2 3            3 2     2 2   2
+--R                  (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                              +--------+
+--R                          +-+ |   2               2          2                2
+--R           ((4b e - 2c d)\|d \|e x  + d  + (- 2b e  + c d e)x  - 4b d e + 2c d )
+--R        *
+--R                                +--------+
+--R                 +-+ +-+        |   2              2      +-+       +-+
+--R               (\|d \|e  + e x)\|e x  + d  + (- e x  - d)\|e  - e x\|d
+--R           log(--------------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|d \|e x  + d  - d
+--R       + 
+--R                                 +--------+
+--R                 3           +-+ |   2               3           +-+ +-+
+--R         (- c e x  - 2c d x)\|e \|e x  + d  + (2c e x  + 2c d x)\|d \|e
+--R    /
+--R                   +--------+
+--R         2 +-+ +-+ |   2             2   2     2   +-+
+--R       4c \|d \|e \|e x  + d  + (- 2c e x  - 4c d)\|e
+--R     ,
+--R
+--R                            +--------+
+--R                2 +---+ +-+ |   2          2   2     2   +---+
+--R           (- 2c \|- e \|d \|e x  + d  + (c e x  + 2c d)\|- e )
+--R        *
+--R           ROOT
+--R                          5     2 4
+--R                    (16a c  - 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  2
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                              2   3       3 2     5
+--R                           (4a b c  - 6a b c  + 2b c)d e
+--R                         + 
+--R                               2 4       2 3    4 2  2
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4              2    3
+--R                  (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                2 6        2 5     4 4
+--R                            (32a c  - 24a b c  + 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                 2   3       3 2    5
+--R                              (4a b c  - 5a b c  + b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                  2 6        2 5     4 4
+--R                            (- 32a c  + 24a b c  - 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                   2   3       3 2    5
+--R                              (- 4a b c  + 5a b c  - b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                   5     2 4
+--R                             (16a c  - 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4              2    3
+--R                           (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                                                                +--------+
+--R                        3        2 3        3 2     2 2     +-+ |   2
+--R                  ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                + 
+--R                      3        2 3  2        3 2     2 2       2
+--R                  ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                + 
+--R                     3        2 3            3 2     2 2   2
+--R                  (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                          +--------+
+--R              2 +---+ +-+ |   2            2   2     2   +---+
+--R           (2c \|- e \|d \|e x  + d  + (- c e x  - 2c d)\|- e )
+--R        *
+--R           ROOT
+--R                            5     2 4
+--R                    (- 16a c  + 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  2
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                              2   3       3 2     5
+--R                           (4a b c  - 6a b c  + 2b c)d e
+--R                         + 
+--R                               2 4       2 3    4 2  2
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4              2    3
+--R                  (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                2 6        2 5     4 4
+--R                            (32a c  - 24a b c  + 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                   2   3       3 2    5
+--R                              (- 4a b c  + 5a b c  - b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                  2 6        2 5     4 4
+--R                            (- 32a c  + 24a b c  - 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                 2   3       3 2    5
+--R                              (4a b c  - 5a b c  + b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                     5     2 4
+--R                             (- 16a c  + 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4              2    3
+--R                           (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                                                                +--------+
+--R                        3        2 3        3 2     2 2     +-+ |   2
+--R                  ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                + 
+--R                      3        2 3  2        3 2     2 2       2
+--R                  ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                + 
+--R                     3        2 3            3 2     2 2   2
+--R                  (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                            +--------+
+--R                2 +---+ +-+ |   2          2   2     2   +---+
+--R           (- 2c \|- e \|d \|e x  + d  + (c e x  + 2c d)\|- e )
+--R        *
+--R           ROOT
+--R                            5     2 4
+--R                    (- 16a c  + 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  2
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                              2   3       3 2     5
+--R                           (4a b c  - 6a b c  + 2b c)d e
+--R                         + 
+--R                               2 4       2 3    4 2  2
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4              2    3
+--R                  (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                  2 6        2 5     4 4
+--R                            (- 32a c  + 24a b c  - 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                 2   3       3 2    5
+--R                              (4a b c  - 5a b c  + b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                2 6        2 5     4 4
+--R                            (32a c  - 24a b c  + 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                   2   3       3 2    5
+--R                              (- 4a b c  + 5a b c  - b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                     5     2 4
+--R                             (- 16a c  + 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4              2    3
+--R                           (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                                                                +--------+
+--R                        3        2 3        3 2     2 2     +-+ |   2
+--R                  ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                + 
+--R                      3        2 3  2        3 2     2 2       2
+--R                  ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                + 
+--R                     3        2 3            3 2     2 2   2
+--R                  (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                          +--------+
+--R              2 +---+ +-+ |   2            2   2     2   +---+
+--R           (2c \|- e \|d \|e x  + d  + (- c e x  - 2c d)\|- e )
+--R        *
+--R           ROOT
+--R                          5     2 4
+--R                    (16a c  - 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  2
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                              2   3       3 2     5
+--R                           (4a b c  - 6a b c  + 2b c)d e
+--R                         + 
+--R                               2 4       2 3    4 2  2
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4              2    3
+--R                  (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                  2 6        2 5     4 4
+--R                            (- 32a c  + 24a b c  - 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                   2   3       3 2    5
+--R                              (- 4a b c  + 5a b c  - b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                2 6        2 5     4 4
+--R                            (32a c  - 24a b c  + 4b c )x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  2
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                      2   3       3 2     5
+--R                                   (4a b c  - 6a b c  + 2b c)d e
+--R                                 + 
+--R                                       2 4       2 3    4 2  2
+--R                                   (- a c  + 2a b c  - b c )d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                 2   3       3 2    5
+--R                              (4a b c  - 5a b c  + b c)d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                   5     2 4
+--R                             (16a c  - 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4              2    3
+--R                           (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                                                                +--------+
+--R                        3        2 3        3 2     2 2     +-+ |   2
+--R                  ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                + 
+--R                      3        2 3  2        3 2     2 2       2
+--R                  ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                + 
+--R                     3        2 3            3 2     2 2   2
+--R                  (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                                   +--------+
+--R                               +-+ |   2             2           2
+--R               (- 8b e + 4c d)\|d \|e x  + d  + (4b e  - 2c d e)x  + 8b d e
+--R             + 
+--R                     2
+--R               - 4c d
+--R        *
+--R                       +--------+
+--R                 +---+ |   2         +---+ +-+
+--R                \|- e \|e x  + d  - \|- e \|d
+--R           atan(------------------------------)
+--R                              e x
+--R       + 
+--R                                   +--------+
+--R                 3           +---+ |   2               3           +---+ +-+
+--R         (- c e x  - 2c d x)\|- e \|e x  + d  + (2c e x  + 2c d x)\|- e \|d
+--R    /
+--R                     +--------+
+--R         2 +---+ +-+ |   2             2   2     2   +---+
+--R       4c \|- e \|d \|e x  + d  + (- 2c e x  - 4c d)\|- e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2994
+
+--S 2995 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                 +------------------------------+
+--R               +-----------+     |    +-----------+
+--R             2 |          2  +-+ |    |          2
+--R            c \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                           5     2 4
+--R                     (16a c  - 4b c )
+--R                  *
+--R                     ROOT
+--R                                 2 2 2       4     6  2
+--R                            (- 4a b c  + 4a b c - b )e
+--R                          + 
+--R                               2   3       3 2     5
+--R                            (4a b c  - 6a b c  + 2b c)d e
+--R                          + 
+--R                                2 4       2 3    4 2  2
+--R                            (- a c  + 2a b c  - b c )d
+--R                       /
+--R                               9      2 8
+--R                          64a c  - 16b c
+--R                 + 
+--R                        2 2       2     4              2    3
+--R                   (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R              /
+--R                     5     2 4
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                 2 6        2 5     4 4
+--R                             (32a c  - 24a b c  + 4b c )x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                    2 2 2       4     6
+--R                               (- 8a b c  + 6a b c - b )e
+--R                             + 
+--R                                  2   3       3 2    5
+--R                               (4a b c  - 5a b c  + b c)d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                   2 6        2 5     4 4
+--R                             (- 32a c  + 24a b c  - 4b c )x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                  2 2 2       4     6
+--R                               (8a b c  - 6a b c + b )e
+--R                             + 
+--R                                    2   3       3 2    5
+--R                               (- 4a b c  + 5a b c  - b c)d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                    5     2 4
+--R                              (16a c  - 4b c )
+--R                           *
+--R                              ROOT
+--R                                          2 2 2       4     6  2
+--R                                     (- 4a b c  + 4a b c - b )e
+--R                                   + 
+--R                                        2   3       3 2     5
+--R                                     (4a b c  - 6a b c  + 2b c)d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  2
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                        9      2 8
+--R                                   64a c  - 16b c
+--R                          + 
+--R                                 2 2       2     4              2    3
+--R                            (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                       /
+--R                              5     2 4
+--R                          8a c  - 2b c
+--R                 + 
+--R                                                                 +--------+
+--R                         3        2 3        3 2     2 2     +-+ |   2
+--R                   ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                 + 
+--R                       3        2 3  2        3 2     2 2       2
+--R                   ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                 + 
+--R                      3        2 3            3 2     2 2   2
+--R                   (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                              +------------------------------+
+--R            +-----------+     |    +-----------+
+--R          2 |          2  +-+ |    |          2
+--R         c \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                          5     2 4
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2 2       4     6  2
+--R                         (- 4a b c  + 4a b c - b )e
+--R                       + 
+--R                            2   3       3 2     5
+--R                         (4a b c  - 6a b c  + 2b c)d e
+--R                       + 
+--R                             2 4       2 3    4 2  2
+--R                         (- a c  + 2a b c  - b c )d
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                     2 2       2     4              2    3
+--R                (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                              2 6        2 5     4 4
+--R                          (32a c  - 24a b c  + 4b c )x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  2
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                    2   3       3 2     5
+--R                                 (4a b c  - 6a b c  + 2b c)d e
+--R                               + 
+--R                                     2 4       2 3    4 2  2
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                          2 2 2       4     6          2   3       3 2    5
+--R                      ((8a b c  - 6a b c + b )e + (- 4a b c  + 5a b c  - b c)d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                2 6        2 5     4 4
+--R                          (- 32a c  + 24a b c  - 4b c )x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  2
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                    2   3       3 2     5
+--R                                 (4a b c  - 6a b c  + 2b c)d e
+--R                               + 
+--R                                     2 4       2 3    4 2  2
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                            2 2 2       4     6        2   3       3 2    5
+--R                      ((- 8a b c  + 6a b c - b )e + (4a b c  - 5a b c  + b c)d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                   5     2 4
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2 2       4     6  2
+--R                                  (- 4a b c  + 4a b c - b )e
+--R                                + 
+--R                                     2   3       3 2     5
+--R                                  (4a b c  - 6a b c  + 2b c)d e
+--R                                + 
+--R                                      2 4       2 3    4 2  2
+--R                                  (- a c  + 2a b c  - b c )d
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                              2 2       2     4              2    3
+--R                         (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                                                              +--------+
+--R                      3        2 3        3 2     2 2     +-+ |   2
+--R                ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R              + 
+--R                    3        2 3  2        3 2     2 2       2
+--R                ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R              + 
+--R                   3        2 3            3 2     2 2   2
+--R                (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                                 +------------------------------+
+--R               +-----------+     |    +-----------+
+--R             2 |          2  +-+ |    |          2
+--R            c \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                             5     2 4
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                     ROOT
+--R                                 2 2 2       4     6  2
+--R                            (- 4a b c  + 4a b c - b )e
+--R                          + 
+--R                               2   3       3 2     5
+--R                            (4a b c  - 6a b c  + 2b c)d e
+--R                          + 
+--R                                2 4       2 3    4 2  2
+--R                            (- a c  + 2a b c  - b c )d
+--R                       /
+--R                               9      2 8
+--R                          64a c  - 16b c
+--R                 + 
+--R                        2 2       2     4              2    3
+--R                   (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R              /
+--R                     5     2 4
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                   2 6        2 5     4 4
+--R                             (- 32a c  + 24a b c  - 4b c )x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                    2 2 2       4     6
+--R                               (- 8a b c  + 6a b c - b )e
+--R                             + 
+--R                                  2   3       3 2    5
+--R                               (4a b c  - 5a b c  + b c)d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                 2 6        2 5     4 4
+--R                             (32a c  - 24a b c  + 4b c )x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                  2 2 2       4     6
+--R                               (8a b c  - 6a b c + b )e
+--R                             + 
+--R                                    2   3       3 2    5
+--R                               (- 4a b c  + 5a b c  - b c)d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                      5     2 4
+--R                              (- 16a c  + 4b c )
+--R                           *
+--R                              ROOT
+--R                                          2 2 2       4     6  2
+--R                                     (- 4a b c  + 4a b c - b )e
+--R                                   + 
+--R                                        2   3       3 2     5
+--R                                     (4a b c  - 6a b c  + 2b c)d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  2
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                        9      2 8
+--R                                   64a c  - 16b c
+--R                          + 
+--R                                 2 2       2     4              2    3
+--R                            (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                       /
+--R                              5     2 4
+--R                          8a c  - 2b c
+--R                 + 
+--R                                                                 +--------+
+--R                         3        2 3        3 2     2 2     +-+ |   2
+--R                   ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                 + 
+--R                       3        2 3  2        3 2     2 2       2
+--R                   ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                 + 
+--R                      3        2 3            3 2     2 2   2
+--R                   (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                              +------------------------------+
+--R            +-----------+     |    +-----------+
+--R          2 |          2  +-+ |    |          2
+--R         c \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        5     2 4
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2 2       4     6  2
+--R                         (- 4a b c  + 4a b c - b )e
+--R                       + 
+--R                            2   3       3 2     5
+--R                         (4a b c  - 6a b c  + 2b c)d e
+--R                       + 
+--R                             2 4       2 3    4 2  2
+--R                         (- a c  + 2a b c  - b c )d
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                     2 2       2     4              2    3
+--R                (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                2 6        2 5     4 4
+--R                          (- 32a c  + 24a b c  - 4b c )x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  2
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                    2   3       3 2     5
+--R                                 (4a b c  - 6a b c  + 2b c)d e
+--R                               + 
+--R                                     2 4       2 3    4 2  2
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                          2 2 2       4     6          2   3       3 2    5
+--R                      ((8a b c  - 6a b c + b )e + (- 4a b c  + 5a b c  - b c)d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                              2 6        2 5     4 4
+--R                          (32a c  - 24a b c  + 4b c )x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  2
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                    2   3       3 2     5
+--R                                 (4a b c  - 6a b c  + 2b c)d e
+--R                               + 
+--R                                     2 4       2 3    4 2  2
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                            2 2 2       4     6        2   3       3 2    5
+--R                      ((- 8a b c  + 6a b c - b )e + (4a b c  - 5a b c  + b c)d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 5     2 4
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2 2       4     6  2
+--R                                  (- 4a b c  + 4a b c - b )e
+--R                                + 
+--R                                     2   3       3 2     5
+--R                                  (4a b c  - 6a b c  + 2b c)d e
+--R                                + 
+--R                                      2 4       2 3    4 2  2
+--R                                  (- a c  + 2a b c  - b c )d
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                              2 2       2     4              2    3
+--R                         (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                                                              +--------+
+--R                      3        2 3        3 2     2 2     +-+ |   2
+--R                ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R              + 
+--R                    3        2 3  2        3 2     2 2       2
+--R                ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R              + 
+--R                   3        2 3            3 2     2 2   2
+--R                (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                      +-----------+
+--R                        2             |          2                3
+--R           ((- 2a c + 2b )e - 2b c d)\|- 4a c + b   + (6a b c - 2b )e
+--R         + 
+--R                  2     2
+--R           (- 4a c  + 2b c)d
+--R      *
+--R              +------------------------------+ +------------------+
+--R              |    +-----------+               | +-----------+
+--R          +-+ |    |          2                | |          2
+--R         \|e \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                      2             |          2                3
+--R           ((2a c - 2b )e + 2b c d)\|- 4a c + b   + (6a b c - 2b )e
+--R         + 
+--R                  2     2
+--R           (- 4a c  + 2b c)d
+--R      *
+--R              +------------------+ +----------------------------+
+--R              | +-----------+      |  +-----------+
+--R          +-+ | |          2       |  |          2
+--R         \|e \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                          |          2
+--R             (2b e - c d)\|- 4a c + b
+--R          *
+--R                                  +--------+
+--R                   +-+ +-+        |   2              2      +-+       +-+
+--R                 (\|d \|e  + e x)\|e x  + d  + (- e x  - d)\|e  - e x\|d
+--R             log(--------------------------------------------------------)
+--R                                         +--------+
+--R                                     +-+ |   2
+--R                                    \|d \|e x  + d  - d
+--R         + 
+--R                        +-----------+           +-+
+--R                        |          2          x\|e
+--R           (2b e - c d)\|- 4a c + b  atanh(-----------)
+--R                                            +--------+
+--R                                            |   2
+--R                                           \|e x  + d
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                             +------------------------------+
+--R           +-----------+     |    +-----------+
+--R         2 |          2  +-+ |    |          2
+--R       2c \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R      +------------------+ +------------------+ +----------------------------+
+--R      | +-----------+      | +-----------+      |  +-----------+
+--R      | |          2       | |          2       |  |          2
+--R     \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 2995
+
+--S 2996 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2996
+
+--S 2997 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       -
+--R                                       +------------------------------+
+--R                     +-----------+     |    +-----------+
+--R             2 +---+ |          2  +-+ |    |          2
+--R            c \|- e \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                           5     2 4
+--R                     (16a c  - 4b c )
+--R                  *
+--R                     ROOT
+--R                                 2 2 2       4     6  2
+--R                            (- 4a b c  + 4a b c - b )e
+--R                          + 
+--R                               2   3       3 2     5
+--R                            (4a b c  - 6a b c  + 2b c)d e
+--R                          + 
+--R                                2 4       2 3    4 2  2
+--R                            (- a c  + 2a b c  - b c )d
+--R                       /
+--R                               9      2 8
+--R                          64a c  - 16b c
+--R                 + 
+--R                        2 2       2     4              2    3
+--R                   (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R              /
+--R                     5     2 4
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                 2 6        2 5     4 4
+--R                             (32a c  - 24a b c  + 4b c )x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                    2 2 2       4     6
+--R                               (- 8a b c  + 6a b c - b )e
+--R                             + 
+--R                                  2   3       3 2    5
+--R                               (4a b c  - 5a b c  + b c)d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                   2 6        2 5     4 4
+--R                             (- 32a c  + 24a b c  - 4b c )x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                  2 2 2       4     6
+--R                               (8a b c  - 6a b c + b )e
+--R                             + 
+--R                                    2   3       3 2    5
+--R                               (- 4a b c  + 5a b c  - b c)d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                    5     2 4
+--R                              (16a c  - 4b c )
+--R                           *
+--R                              ROOT
+--R                                          2 2 2       4     6  2
+--R                                     (- 4a b c  + 4a b c - b )e
+--R                                   + 
+--R                                        2   3       3 2     5
+--R                                     (4a b c  - 6a b c  + 2b c)d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  2
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                        9      2 8
+--R                                   64a c  - 16b c
+--R                          + 
+--R                                 2 2       2     4              2    3
+--R                            (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                       /
+--R                              5     2 4
+--R                          8a c  - 2b c
+--R                 + 
+--R                                                                 +--------+
+--R                         3        2 3        3 2     2 2     +-+ |   2
+--R                   ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                 + 
+--R                       3        2 3  2        3 2     2 2       2
+--R                   ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                 + 
+--R                      3        2 3            3 2     2 2   2
+--R                   (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                                    +------------------------------+
+--R                  +-----------+     |    +-----------+
+--R          2 +---+ |          2  +-+ |    |          2
+--R         c \|- e \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                          5     2 4
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2 2       4     6  2
+--R                         (- 4a b c  + 4a b c - b )e
+--R                       + 
+--R                            2   3       3 2     5
+--R                         (4a b c  - 6a b c  + 2b c)d e
+--R                       + 
+--R                             2 4       2 3    4 2  2
+--R                         (- a c  + 2a b c  - b c )d
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                     2 2       2     4              2    3
+--R                (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                              2 6        2 5     4 4
+--R                          (32a c  - 24a b c  + 4b c )x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  2
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                    2   3       3 2     5
+--R                                 (4a b c  - 6a b c  + 2b c)d e
+--R                               + 
+--R                                     2 4       2 3    4 2  2
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                          2 2 2       4     6          2   3       3 2    5
+--R                      ((8a b c  - 6a b c + b )e + (- 4a b c  + 5a b c  - b c)d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                2 6        2 5     4 4
+--R                          (- 32a c  + 24a b c  - 4b c )x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  2
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                    2   3       3 2     5
+--R                                 (4a b c  - 6a b c  + 2b c)d e
+--R                               + 
+--R                                     2 4       2 3    4 2  2
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                            2 2 2       4     6        2   3       3 2    5
+--R                      ((- 8a b c  + 6a b c - b )e + (4a b c  - 5a b c  + b c)d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                   5     2 4
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2 2       4     6  2
+--R                                  (- 4a b c  + 4a b c - b )e
+--R                                + 
+--R                                     2   3       3 2     5
+--R                                  (4a b c  - 6a b c  + 2b c)d e
+--R                                + 
+--R                                      2 4       2 3    4 2  2
+--R                                  (- a c  + 2a b c  - b c )d
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                              2 2       2     4              2    3
+--R                         (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                                                              +--------+
+--R                      3        2 3        3 2     2 2     +-+ |   2
+--R                ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R              + 
+--R                    3        2 3  2        3 2     2 2       2
+--R                ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R              + 
+--R                   3        2 3            3 2     2 2   2
+--R                (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                                       +------------------------------+
+--R                     +-----------+     |    +-----------+
+--R             2 +---+ |          2  +-+ |    |          2
+--R            c \|- e \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                             5     2 4
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                     ROOT
+--R                                 2 2 2       4     6  2
+--R                            (- 4a b c  + 4a b c - b )e
+--R                          + 
+--R                               2   3       3 2     5
+--R                            (4a b c  - 6a b c  + 2b c)d e
+--R                          + 
+--R                                2 4       2 3    4 2  2
+--R                            (- a c  + 2a b c  - b c )d
+--R                       /
+--R                               9      2 8
+--R                          64a c  - 16b c
+--R                 + 
+--R                        2 2       2     4              2    3
+--R                   (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R              /
+--R                     5     2 4
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                   2 6        2 5     4 4
+--R                             (- 32a c  + 24a b c  - 4b c )x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                    2 2 2       4     6
+--R                               (- 8a b c  + 6a b c - b )e
+--R                             + 
+--R                                  2   3       3 2    5
+--R                               (4a b c  - 5a b c  + b c)d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                 2 6        2 5     4 4
+--R                             (32a c  - 24a b c  + 4b c )x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  2
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                       2   3       3 2     5
+--R                                    (4a b c  - 6a b c  + 2b c)d e
+--R                                  + 
+--R                                        2 4       2 3    4 2  2
+--R                                    (- a c  + 2a b c  - b c )d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                  2 2 2       4     6
+--R                               (8a b c  - 6a b c + b )e
+--R                             + 
+--R                                    2   3       3 2    5
+--R                               (- 4a b c  + 5a b c  - b c)d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                      5     2 4
+--R                              (- 16a c  + 4b c )
+--R                           *
+--R                              ROOT
+--R                                          2 2 2       4     6  2
+--R                                     (- 4a b c  + 4a b c - b )e
+--R                                   + 
+--R                                        2   3       3 2     5
+--R                                     (4a b c  - 6a b c  + 2b c)d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  2
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                        9      2 8
+--R                                   64a c  - 16b c
+--R                          + 
+--R                                 2 2       2     4              2    3
+--R                            (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                       /
+--R                              5     2 4
+--R                          8a c  - 2b c
+--R                 + 
+--R                                                                 +--------+
+--R                         3        2 3        3 2     2 2     +-+ |   2
+--R                   ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R                 + 
+--R                       3        2 3  2        3 2     2 2       2
+--R                   ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R                 + 
+--R                      3        2 3            3 2     2 2   2
+--R                   (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                                    +------------------------------+
+--R                  +-----------+     |    +-----------+
+--R          2 +---+ |          2  +-+ |    |          2
+--R         c \|- e \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        5     2 4
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2 2       4     6  2
+--R                         (- 4a b c  + 4a b c - b )e
+--R                       + 
+--R                            2   3       3 2     5
+--R                         (4a b c  - 6a b c  + 2b c)d e
+--R                       + 
+--R                             2 4       2 3    4 2  2
+--R                         (- a c  + 2a b c  - b c )d
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                     2 2       2     4              2    3
+--R                (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                2 6        2 5     4 4
+--R                          (- 32a c  + 24a b c  - 4b c )x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  2
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                    2   3       3 2     5
+--R                                 (4a b c  - 6a b c  + 2b c)d e
+--R                               + 
+--R                                     2 4       2 3    4 2  2
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                          2 2 2       4     6          2   3       3 2    5
+--R                      ((8a b c  - 6a b c + b )e + (- 4a b c  + 5a b c  - b c)d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                              2 6        2 5     4 4
+--R                          (32a c  - 24a b c  + 4b c )x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  2
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                    2   3       3 2     5
+--R                                 (4a b c  - 6a b c  + 2b c)d e
+--R                               + 
+--R                                     2 4       2 3    4 2  2
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                            2 2 2       4     6        2   3       3 2    5
+--R                      ((- 8a b c  + 6a b c - b )e + (4a b c  - 5a b c  + b c)d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 5     2 4
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2 2       4     6  2
+--R                                  (- 4a b c  + 4a b c - b )e
+--R                                + 
+--R                                     2   3       3 2     5
+--R                                  (4a b c  - 6a b c  + 2b c)d e
+--R                                + 
+--R                                      2 4       2 3    4 2  2
+--R                                  (- a c  + 2a b c  - b c )d
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                              2 2       2     4              2    3
+--R                         (- 2a c  + 4a b c - b )e + (- 3a b c  + b c)d
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                                                              +--------+
+--R                      3        2 3        3 2     2 2     +-+ |   2
+--R                ((- 4a b c + 2a b )e + (2a c  - 2a b c)d)\|d \|e x  + d
+--R              + 
+--R                    3        2 3  2        3 2     2 2       2
+--R                ((4a b c - 2a b )e  + (- 2a c  + 2a b c)d e)x
+--R              + 
+--R                   3        2 3            3 2     2 2   2
+--R                (4a b c - 2a b )d e + (- 2a c  + 2a b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                            +-----------+
+--R                        2             +---+ |          2
+--R           ((- 2a c + 2b )e - 2b c d)\|- e \|- 4a c + b
+--R         + 
+--R                        3            2     2     +---+
+--R           ((6a b c - 2b )e + (- 4a c  + 2b c)d)\|- e
+--R      *
+--R              +------------------------------+ +------------------+
+--R              |    +-----------+               | +-----------+
+--R          +-+ |    |          2                | |          2
+--R         \|e \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                          +-----------+
+--R                      2             +---+ |          2
+--R           ((2a c - 2b )e + 2b c d)\|- e \|- 4a c + b
+--R         + 
+--R                        3            2     2     +---+
+--R           ((6a b c - 2b )e + (- 4a c  + 2b c)d)\|- e
+--R      *
+--R              +------------------+ +----------------------------+
+--R              | +-----------+      |  +-----------+
+--R          +-+ | |          2       |  |          2
+--R         \|e \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                              +-----------+           +-+
+--R                        +---+ |          2          x\|e
+--R           (2b e - c d)\|- e \|- 4a c + b  atanh(-----------)
+--R                                                  +--------+
+--R                                                  |   2
+--R                                                 \|e x  + d
+--R         + 
+--R                                                      +--------+
+--R                         +-----------+          +---+ |   2         +---+ +-+
+--R                         |          2  +-+     \|- e \|e x  + d  - \|- e \|d
+--R         (- 4b e + 2c d)\|- 4a c + b  \|e atan(------------------------------)
+--R                                                             e x
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                                   +------------------------------+
+--R                 +-----------+     |    +-----------+
+--R         2 +---+ |          2  +-+ |    |          2
+--R       2c \|- e \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R      +------------------+ +------------------+ +----------------------------+
+--R      | +-----------+      | +-----------+      |  +-----------+
+--R      | |          2       | |          2       |  |          2
+--R     \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 2997
+
+--S 2998 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2998
+
+)clear all
+
+--S 2999 of 3139
+t0:=x^3*sqrt(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          3 |   2
+--R         x \|e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2999
+
+--S 3000 of 3139
+r0:=sqrt(d+e*x^2)/c-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c))))*(c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-_
+   4*a*c))/(c^(3/2)*sqrt(2)*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))-_
+   atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*_
+   (c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                      +-----------+
+--R                      |          2               2
+--R         ((b e - c d)\|- 4a c + b   + (- 2a c + b )e - b c d)
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                      +-----------+
+--R                      |          2             2
+--R         ((b e - c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                           +------------------------------+
+--R              +-----------+     +--------+ |    +-----------+
+--R          +-+ |          2  +-+ |   2      |    |          2
+--R         \|2 \|- 4a c + b  \|c \|e x  + d \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                               +------------------------------+
+--R             +-----------+     |    +-----------+
+--R         +-+ |          2  +-+ |    |          2
+--R       c\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3000
+
+--S 3001 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  +--------+
+--R              +-+ |   2
+--R         (- c\|d \|e x  + d  + c d)
+--R      *
+--R         ROOT
+--R                        4     2 3
+--R                  (16a c  - 4b c )
+--R               *
+--R                   +---------------------------------------------------------+
+--R                   |    2 2       2     4  2            2     3         2 2 2
+--R                   |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                   |---------------------------------------------------------
+--R                   |                          7      2 6
+--R                  \|                     64a c  - 16b c
+--R              + 
+--R                             3          2    2
+--R                (- 3a b c + b )e + (2a c  - b c)d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                          2 5        2 4     4 3  2
+--R                      (32a c  - 24a b c  + 4b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                        2   2       3     5          2 2    4     2
+--R                    ((4a b c  - 5a b c + b )e + (4a b c  - b c)d)x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3         2 2 2
+--R                                  (- 2a b c  + 2b c)d e - b c d
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                      3          2    2
+--R                         (- 3a b c + b )e + (2a c  - b c)d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                                               +--------+
+--R                      3      2 2       2       |   2
+--R                ((- 2a c + 2a b )e - 2a b c d)\|e x  + d
+--R              + 
+--R                          2 4       2 3  2
+--R                      (16a c  - 4a b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                       2         3        2     2      3      2 2       2
+--R                    ((a b c - a b )e + a b c d)x  + (2a c - 2a b )e + 2a b c d
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +--------+
+--R            +-+ |   2
+--R         (c\|d \|e x  + d  - c d)
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                   +---------------------------------------------------------+
+--R                   |    2 2       2     4  2            2     3         2 2 2
+--R                   |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                   |---------------------------------------------------------
+--R                   |                          7      2 6
+--R                  \|                     64a c  - 16b c
+--R              + 
+--R                             3          2    2
+--R                (- 3a b c + b )e + (2a c  - b c)d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                          2 5        2 4     4 3  2
+--R                      (32a c  - 24a b c  + 4b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                          2   2       3     5            2 2    4     2
+--R                    ((- 4a b c  + 5a b c - b )e + (- 4a b c  + b c)d)x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3         2 2 2
+--R                                  (- 2a b c  + 2b c)d e - b c d
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                      3          2    2
+--R                         (- 3a b c + b )e + (2a c  - b c)d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                                               +--------+
+--R                      3      2 2       2       |   2
+--R                ((- 2a c + 2a b )e - 2a b c d)\|e x  + d
+--R              + 
+--R                            2 4       2 3  2
+--R                      (- 16a c  + 4a b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                       2         3        2     2      3      2 2       2
+--R                    ((a b c - a b )e + a b c d)x  + (2a c - 2a b )e + 2a b c d
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                  +--------+
+--R              +-+ |   2
+--R         (- c\|d \|e x  + d  + c d)
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                   +---------------------------------------------------------+
+--R                   |    2 2       2     4  2            2     3         2 2 2
+--R                   |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                   |---------------------------------------------------------
+--R                   |                          7      2 6
+--R                  \|                     64a c  - 16b c
+--R              + 
+--R                             3          2    2
+--R                (- 3a b c + b )e + (2a c  - b c)d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                            2 5        2 4     4 3  2
+--R                      (- 32a c  + 24a b c  - 4b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                        2   2       3     5          2 2    4     2
+--R                    ((4a b c  - 5a b c + b )e + (4a b c  - b c)d)x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3         2 2 2
+--R                                  (- 2a b c  + 2b c)d e - b c d
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                      3          2    2
+--R                         (- 3a b c + b )e + (2a c  - b c)d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                                               +--------+
+--R                      3      2 2       2       |   2
+--R                ((- 2a c + 2a b )e - 2a b c d)\|e x  + d
+--R              + 
+--R                            2 4       2 3  2
+--R                      (- 16a c  + 4a b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                       2         3        2     2      3      2 2       2
+--R                    ((a b c - a b )e + a b c d)x  + (2a c - 2a b )e + 2a b c d
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +--------+
+--R            +-+ |   2
+--R         (c\|d \|e x  + d  - c d)
+--R      *
+--R         ROOT
+--R                        4     2 3
+--R                  (16a c  - 4b c )
+--R               *
+--R                   +---------------------------------------------------------+
+--R                   |    2 2       2     4  2            2     3         2 2 2
+--R                   |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                   |---------------------------------------------------------
+--R                   |                          7      2 6
+--R                  \|                     64a c  - 16b c
+--R              + 
+--R                             3          2    2
+--R                (- 3a b c + b )e + (2a c  - b c)d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                            2 5        2 4     4 3  2
+--R                      (- 32a c  + 24a b c  - 4b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                          2   2       3     5            2 2    4     2
+--R                    ((- 4a b c  + 5a b c - b )e + (- 4a b c  + b c)d)x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3         2 2 2
+--R                                  (- 2a b c  + 2b c)d e - b c d
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                      3          2    2
+--R                         (- 3a b c + b )e + (2a c  - b c)d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                                               +--------+
+--R                      3      2 2       2       |   2
+--R                ((- 2a c + 2a b )e - 2a b c d)\|e x  + d
+--R              + 
+--R                          2 4       2 3  2
+--R                      (16a c  - 4a b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                       2         3        2     2      3      2 2       2
+--R                    ((a b c - a b )e + a b c d)x  + (2a c - 2a b )e + 2a b c d
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R           2 +-+
+--R       2e x \|d
+--R  /
+--R            +--------+
+--R        +-+ |   2
+--R     2c\|d \|e x  + d  - 2c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3001
+
+--S 3002 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +-----------+         +--------+           +-----------+
+--R              +-+ |          2  +-+ +-+ |   2            +-+ |          2  +-+
+--R         (- c\|2 \|- 4a c + b  \|c \|d \|e x  + d  + c d\|2 \|- 4a c + b  \|c )
+--R      *
+--R          +------------------------------+
+--R          |    +-----------+
+--R          |    |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        4     2 3
+--R                  (16a c  - 4b c )
+--R               *
+--R                   +---------------------------------------------------------+
+--R                   |    2 2       2     4  2            2     3         2 2 2
+--R                   |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                   |---------------------------------------------------------
+--R                   |                          7      2 6
+--R                  \|                     64a c  - 16b c
+--R              + 
+--R                             3          2    2
+--R                (- 3a b c + b )e + (2a c  - b c)d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                          2 5        2 4     4 3  2
+--R                      (32a c  - 24a b c  + 4b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                        2   2       3     5          2 2    4     2
+--R                    ((4a b c  - 5a b c + b )e + (4a b c  - b c)d)x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3         2 2 2
+--R                                  (- 2a b c  + 2b c)d e - b c d
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                      3          2    2
+--R                         (- 3a b c + b )e + (2a c  - b c)d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                                               +--------+
+--R                      3      2 2       2       |   2
+--R                ((- 2a c + 2a b )e - 2a b c d)\|e x  + d
+--R              + 
+--R                          2 4       2 3  2
+--R                      (16a c  - 4a b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                       2         3        2     2      3      2 2       2
+--R                    ((a b c - a b )e + a b c d)x  + (2a c - 2a b )e + 2a b c d
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +-----------+         +--------+           +-----------+
+--R            +-+ |          2  +-+ +-+ |   2            +-+ |          2  +-+
+--R         (c\|2 \|- 4a c + b  \|c \|d \|e x  + d  - c d\|2 \|- 4a c + b  \|c )
+--R      *
+--R          +------------------------------+
+--R          |    +-----------+
+--R          |    |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                   +---------------------------------------------------------+
+--R                   |    2 2       2     4  2            2     3         2 2 2
+--R                   |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                   |---------------------------------------------------------
+--R                   |                          7      2 6
+--R                  \|                     64a c  - 16b c
+--R              + 
+--R                             3          2    2
+--R                (- 3a b c + b )e + (2a c  - b c)d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                          2 5        2 4     4 3  2
+--R                      (32a c  - 24a b c  + 4b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                          2   2       3     5            2 2    4     2
+--R                    ((- 4a b c  + 5a b c - b )e + (- 4a b c  + b c)d)x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3         2 2 2
+--R                                  (- 2a b c  + 2b c)d e - b c d
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                      3          2    2
+--R                         (- 3a b c + b )e + (2a c  - b c)d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                                               +--------+
+--R                      3      2 2       2       |   2
+--R                ((- 2a c + 2a b )e - 2a b c d)\|e x  + d
+--R              + 
+--R                            2 4       2 3  2
+--R                      (- 16a c  + 4a b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                       2         3        2     2      3      2 2       2
+--R                    ((a b c - a b )e + a b c d)x  + (2a c - 2a b )e + 2a b c d
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                  +-----------+         +--------+           +-----------+
+--R              +-+ |          2  +-+ +-+ |   2            +-+ |          2  +-+
+--R         (- c\|2 \|- 4a c + b  \|c \|d \|e x  + d  + c d\|2 \|- 4a c + b  \|c )
+--R      *
+--R          +------------------------------+
+--R          |    +-----------+
+--R          |    |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                   +---------------------------------------------------------+
+--R                   |    2 2       2     4  2            2     3         2 2 2
+--R                   |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                   |---------------------------------------------------------
+--R                   |                          7      2 6
+--R                  \|                     64a c  - 16b c
+--R              + 
+--R                             3          2    2
+--R                (- 3a b c + b )e + (2a c  - b c)d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                            2 5        2 4     4 3  2
+--R                      (- 32a c  + 24a b c  - 4b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                        2   2       3     5          2 2    4     2
+--R                    ((4a b c  - 5a b c + b )e + (4a b c  - b c)d)x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3         2 2 2
+--R                                  (- 2a b c  + 2b c)d e - b c d
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                      3          2    2
+--R                         (- 3a b c + b )e + (2a c  - b c)d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                                               +--------+
+--R                      3      2 2       2       |   2
+--R                ((- 2a c + 2a b )e - 2a b c d)\|e x  + d
+--R              + 
+--R                            2 4       2 3  2
+--R                      (- 16a c  + 4a b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                       2         3        2     2      3      2 2       2
+--R                    ((a b c - a b )e + a b c d)x  + (2a c - 2a b )e + 2a b c d
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +-----------+         +--------+           +-----------+
+--R            +-+ |          2  +-+ +-+ |   2            +-+ |          2  +-+
+--R         (c\|2 \|- 4a c + b  \|c \|d \|e x  + d  - c d\|2 \|- 4a c + b  \|c )
+--R      *
+--R          +------------------------------+
+--R          |    +-----------+
+--R          |    |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        4     2 3
+--R                  (16a c  - 4b c )
+--R               *
+--R                   +---------------------------------------------------------+
+--R                   |    2 2       2     4  2            2     3         2 2 2
+--R                   |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                   |---------------------------------------------------------
+--R                   |                          7      2 6
+--R                  \|                     64a c  - 16b c
+--R              + 
+--R                             3          2    2
+--R                (- 3a b c + b )e + (2a c  - b c)d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                            2 5        2 4     4 3  2
+--R                      (- 32a c  + 24a b c  - 4b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                          2   2       3     5            2 2    4     2
+--R                    ((- 4a b c  + 5a b c - b )e + (- 4a b c  + b c)d)x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3         2 2 2
+--R                                  (- 2a b c  + 2b c)d e - b c d
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                      3          2    2
+--R                         (- 3a b c + b )e + (2a c  - b c)d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                                               +--------+
+--R                      3      2 2       2       |   2
+--R                ((- 2a c + 2a b )e - 2a b c d)\|e x  + d
+--R              + 
+--R                          2 4       2 3  2
+--R                      (16a c  - 4a b c )x
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |    2 2       2     4  2            2     3         2 2 2
+--R                     |(- a c  + 2a b c - b )e  + (- 2a b c  + 2b c)d e - b c d
+--R                     |---------------------------------------------------------
+--R                     |                          7      2 6
+--R                    \|                     64a c  - 16b c
+--R                  + 
+--R                       2         3        2     2      3      2 2       2
+--R                    ((a b c - a b )e + a b c d)x  + (2a c - 2a b )e + 2a b c d
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                              +-----------+
+--R                              |          2              2             +-+
+--R             ((- 2b e + 2c d)\|- 4a c + b   + (4a c - 2b )e + 2b c d)\|d
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|e x  + d
+--R         + 
+--R                            +-----------+
+--R                         2  |          2                2             2
+--R           (2b d e - 2c d )\|- 4a c + b   + (- 4a c + 2b )d e - 2b c d
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                              +-----------+
+--R                              |          2                2             +-+
+--R             ((- 2b e + 2c d)\|- 4a c + b   + (- 4a c + 2b )e - 2b c d)\|d
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|e x  + d
+--R         + 
+--R                            +-----------+
+--R                         2  |          2              2             2
+--R           (2b d e - 2c d )\|- 4a c + b   + (4a c - 2b )d e + 2b c d
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                 +-----------+     +--------+          +-----------+
+--R             +-+ |          2  +-+ |   2           +-+ |          2  +-+ +-+
+--R         (2d\|2 \|- 4a c + b  \|c \|e x  + d  - 2d\|2 \|- 4a c + b  \|c \|d )
+--R      *
+--R          +------------------------------+ +----------------------------+
+--R          |    +-----------+               |  +-----------+
+--R          |    |          2                |  |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R               +-----------+         +--------+            +-----------+
+--R           +-+ |          2  +-+ +-+ |   2             +-+ |          2  +-+
+--R       (2c\|2 \|- 4a c + b  \|c \|d \|e x  + d  - 2c d\|2 \|- 4a c + b  \|c )
+--R    *
+--R        +------------------------------+ +----------------------------+
+--R        |    +-----------+               |  +-----------+
+--R        |    |          2                |  |          2
+--R       \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3002
+
+--S 3003 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3003
+
+)clear all
+
+--S 3004 of 3139
+t0:=x^2*sqrt(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          2 |   2
+--R         x \|e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3004
+
+--S 3005 of 3139
+r0:=atanh(x*sqrt(e)/sqrt(d+e*x^2))*sqrt(e)/c-atanh(x*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*_
+   (c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(c*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c)))+atan(x*sqrt(2*c*d-_
+   e*(b+sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*_
+   (c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-4*a*c))/(c*sqrt(b+sqrt(b^2-_
+   4*a*c))*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                      +-----------+
+--R                      |          2             2
+--R         ((b e - c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                        |          2             2
+--R         ((- b e + c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                              +------------------------------+
+--R          +-----------+               +-+     |    +-----------+
+--R          |          2  +-+         x\|e      |    |          2
+--R         \|- 4a c + b  \|e atanh(-----------)\|- e\|- 4a c + b   - b e + 2c d
+--R                                  +--------+
+--R                                  |   2
+--R                                 \|e x  + d
+--R      *
+--R        +------------------+ +------------------+ +----------------------------+
+--R        | +-----------+      | +-----------+      |  +-----------+
+--R        | |          2       | |          2       |  |          2
+--R       \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                       +------------------------------+ +------------------+
+--R         +-----------+ |    +-----------+               | +-----------+
+--R         |          2  |    |          2                | |          2
+--R       c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3005
+
+--S 3006 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           c
+--R        *
+--R            +------------------------------------------------------------------+
+--R            |                 +------------------------+
+--R            |                 |   2 2               2 2
+--R            |      3     2 2  |- b e  + 2b c d e - c d              2
+--R            |(16a c  - 4b c ) |------------------------  + (2a c - b )e + b c d
+--R            |                 |          5      2 4
+--R            |                \|     64a c  - 16b c
+--R            |------------------------------------------------------------------
+--R            |                               3     2 2
+--R           \|                           8a c  - 2b c
+--R        *
+--R           log
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                  3     3 2   |- b e  + 2b c d e - c d
+--R                          (16a b c  - 4b c )x |------------------------
+--R                                              |          5      2 4
+--R                                             \|     64a c  - 16b c
+--R                        + 
+--R                                        3          2    2
+--R                          ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                                +------------------------+
+--R                                                |   2 2               2 2
+--R                                    3     3 2   |- b e  + 2b c d e - c d
+--R                          (- 16a b c  + 4b c )x |------------------------
+--R                                                |          5      2 4
+--R                                               \|     64a c  - 16b c
+--R                        + 
+--R                                      3            2    2
+--R                          ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                            +------------------------+
+--R                                            |   2 2               2 2
+--R                                 3     2 2  |- b e  + 2b c d e - c d
+--R                           (16a c  - 4b c ) |------------------------
+--R                                            |          5      2 4
+--R                                           \|     64a c  - 16b c
+--R                         + 
+--R                                    2
+--R                           (2a c - b )e + b c d
+--R                      /
+--R                             3     2 2
+--R                         8a c  - 2b c
+--R                + 
+--R                                          +--------+
+--R                                      +-+ |   2               2             2
+--R                  (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                + 
+--R                                   2
+--R                  2a b d e - 2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R         -
+--R              c
+--R           *
+--R              ROOT
+--R                                        +------------------------+
+--R                                        |   2 2               2 2
+--R                             3     2 2  |- b e  + 2b c d e - c d
+--R                     (- 16a c  + 4b c ) |------------------------
+--R                                        |          5      2 4
+--R                                       \|     64a c  - 16b c
+--R                   + 
+--R                              2
+--R                     (2a c - b )e + b c d
+--R                /
+--R                       3     2 2
+--R                   8a c  - 2b c
+--R           *
+--R              log
+--R                                                 +------------------------+
+--R                                                 |   2 2               2 2
+--R                                     3     3 2   |- b e  + 2b c d e - c d
+--R                             (16a b c  - 4b c )x |------------------------
+--R                                                 |          5      2 4
+--R                                                \|     64a c  - 16b c
+--R                           + 
+--R                                         3            2    2
+--R                             ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                        *
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R                       + 
+--R                                                   +------------------------+
+--R                                                   |   2 2               2 2
+--R                                       3     3 2   |- b e  + 2b c d e - c d
+--R                             (- 16a b c  + 4b c )x |------------------------
+--R                                                   |          5      2 4
+--R                                                  \|     64a c  - 16b c
+--R                           + 
+--R                                           3          2    2
+--R                             ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                        *
+--R                            +-+
+--R                           \|d
+--R                    *
+--R                       ROOT
+--R                                                 +------------------------+
+--R                                                 |   2 2               2 2
+--R                                      3     2 2  |- b e  + 2b c d e - c d
+--R                              (- 16a c  + 4b c ) |------------------------
+--R                                                 |          5      2 4
+--R                                                \|     64a c  - 16b c
+--R                            + 
+--R                                       2
+--R                              (2a c - b )e + b c d
+--R                         /
+--R                                3     2 2
+--R                            8a c  - 2b c
+--R                   + 
+--R                                             +--------+
+--R                                         +-+ |   2               2             2
+--R                     (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                   + 
+--R                                      2
+--R                     2a b d e - 2a c d
+--R                /
+--R                    2
+--R                   x
+--R       + 
+--R           c
+--R        *
+--R           ROOT
+--R                                     +------------------------+
+--R                                     |   2 2               2 2
+--R                          3     2 2  |- b e  + 2b c d e - c d              2
+--R                  (- 16a c  + 4b c ) |------------------------  + (2a c - b )e
+--R                                     |          5      2 4
+--R                                    \|     64a c  - 16b c
+--R                + 
+--R                  b c d
+--R             /
+--R                    3     2 2
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                                +------------------------+
+--R                                                |   2 2               2 2
+--R                                    3     3 2   |- b e  + 2b c d e - c d
+--R                          (- 16a b c  + 4b c )x |------------------------
+--R                                                |          5      2 4
+--R                                               \|     64a c  - 16b c
+--R                        + 
+--R                                        3          2    2
+--R                          ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                  3     3 2   |- b e  + 2b c d e - c d
+--R                          (16a b c  - 4b c )x |------------------------
+--R                                              |          5      2 4
+--R                                             \|     64a c  - 16b c
+--R                        + 
+--R                                      3            2    2
+--R                          ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                   3     2 2  |- b e  + 2b c d e - c d
+--R                           (- 16a c  + 4b c ) |------------------------
+--R                                              |          5      2 4
+--R                                             \|     64a c  - 16b c
+--R                         + 
+--R                                    2
+--R                           (2a c - b )e + b c d
+--R                      /
+--R                             3     2 2
+--R                         8a c  - 2b c
+--R                + 
+--R                                          +--------+
+--R                                      +-+ |   2               2             2
+--R                  (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                + 
+--R                                   2
+--R                  2a b d e - 2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R         -
+--R              c
+--R           *
+--R              ROOT
+--R                                      +------------------------+
+--R                                      |   2 2               2 2
+--R                           3     2 2  |- b e  + 2b c d e - c d              2
+--R                     (16a c  - 4b c ) |------------------------  + (2a c - b )e
+--R                                      |          5      2 4
+--R                                     \|     64a c  - 16b c
+--R                   + 
+--R                     b c d
+--R                /
+--R                       3     2 2
+--R                   8a c  - 2b c
+--R           *
+--R              log
+--R                                                   +------------------------+
+--R                                                   |   2 2               2 2
+--R                                       3     3 2   |- b e  + 2b c d e - c d
+--R                             (- 16a b c  + 4b c )x |------------------------
+--R                                                   |          5      2 4
+--R                                                  \|     64a c  - 16b c
+--R                           + 
+--R                                         3            2    2
+--R                             ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                        *
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R                       + 
+--R                                                 +------------------------+
+--R                                                 |   2 2               2 2
+--R                                     3     3 2   |- b e  + 2b c d e - c d
+--R                             (16a b c  - 4b c )x |------------------------
+--R                                                 |          5      2 4
+--R                                                \|     64a c  - 16b c
+--R                           + 
+--R                                           3          2    2
+--R                             ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                        *
+--R                            +-+
+--R                           \|d
+--R                    *
+--R                       ROOT
+--R                                               +------------------------+
+--R                                               |   2 2               2 2
+--R                                    3     2 2  |- b e  + 2b c d e - c d
+--R                              (16a c  - 4b c ) |------------------------
+--R                                               |          5      2 4
+--R                                              \|     64a c  - 16b c
+--R                            + 
+--R                                       2
+--R                              (2a c - b )e + b c d
+--R                         /
+--R                                3     2 2
+--R                            8a c  - 2b c
+--R                   + 
+--R                                             +--------+
+--R                                         +-+ |   2               2             2
+--R                     (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                   + 
+--R                                      2
+--R                     2a b d e - 2a c d
+--R                /
+--R                    2
+--R                   x
+--R       + 
+--R                                   +--------+
+--R                       +-+    +-+  |   2          +-+ +-+      2
+--R           +-+    (- x\|e  + \|d )\|e x  + d  + x\|d \|e  - e x  - d
+--R         2\|e log(--------------------------------------------------)
+--R                                       +--------+
+--R                                   +-+ |   2
+--R                                  \|d \|e x  + d  - d
+--R    /
+--R       2c
+--R     ,
+--R
+--R           c
+--R        *
+--R            +------------------------------------------------------------------+
+--R            |                 +------------------------+
+--R            |                 |   2 2               2 2
+--R            |      3     2 2  |- b e  + 2b c d e - c d              2
+--R            |(16a c  - 4b c ) |------------------------  + (2a c - b )e + b c d
+--R            |                 |          5      2 4
+--R            |                \|     64a c  - 16b c
+--R            |------------------------------------------------------------------
+--R            |                               3     2 2
+--R           \|                           8a c  - 2b c
+--R        *
+--R           log
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                  3     3 2   |- b e  + 2b c d e - c d
+--R                          (16a b c  - 4b c )x |------------------------
+--R                                              |          5      2 4
+--R                                             \|     64a c  - 16b c
+--R                        + 
+--R                                        3          2    2
+--R                          ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                                +------------------------+
+--R                                                |   2 2               2 2
+--R                                    3     3 2   |- b e  + 2b c d e - c d
+--R                          (- 16a b c  + 4b c )x |------------------------
+--R                                                |          5      2 4
+--R                                               \|     64a c  - 16b c
+--R                        + 
+--R                                      3            2    2
+--R                          ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                            +------------------------+
+--R                                            |   2 2               2 2
+--R                                 3     2 2  |- b e  + 2b c d e - c d
+--R                           (16a c  - 4b c ) |------------------------
+--R                                            |          5      2 4
+--R                                           \|     64a c  - 16b c
+--R                         + 
+--R                                    2
+--R                           (2a c - b )e + b c d
+--R                      /
+--R                             3     2 2
+--R                         8a c  - 2b c
+--R                + 
+--R                                          +--------+
+--R                                      +-+ |   2               2             2
+--R                  (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                + 
+--R                                   2
+--R                  2a b d e - 2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R         -
+--R              c
+--R           *
+--R              ROOT
+--R                                        +------------------------+
+--R                                        |   2 2               2 2
+--R                             3     2 2  |- b e  + 2b c d e - c d
+--R                     (- 16a c  + 4b c ) |------------------------
+--R                                        |          5      2 4
+--R                                       \|     64a c  - 16b c
+--R                   + 
+--R                              2
+--R                     (2a c - b )e + b c d
+--R                /
+--R                       3     2 2
+--R                   8a c  - 2b c
+--R           *
+--R              log
+--R                                                 +------------------------+
+--R                                                 |   2 2               2 2
+--R                                     3     3 2   |- b e  + 2b c d e - c d
+--R                             (16a b c  - 4b c )x |------------------------
+--R                                                 |          5      2 4
+--R                                                \|     64a c  - 16b c
+--R                           + 
+--R                                         3            2    2
+--R                             ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                        *
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R                       + 
+--R                                                   +------------------------+
+--R                                                   |   2 2               2 2
+--R                                       3     3 2   |- b e  + 2b c d e - c d
+--R                             (- 16a b c  + 4b c )x |------------------------
+--R                                                   |          5      2 4
+--R                                                  \|     64a c  - 16b c
+--R                           + 
+--R                                           3          2    2
+--R                             ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                        *
+--R                            +-+
+--R                           \|d
+--R                    *
+--R                       ROOT
+--R                                                 +------------------------+
+--R                                                 |   2 2               2 2
+--R                                      3     2 2  |- b e  + 2b c d e - c d
+--R                              (- 16a c  + 4b c ) |------------------------
+--R                                                 |          5      2 4
+--R                                                \|     64a c  - 16b c
+--R                            + 
+--R                                       2
+--R                              (2a c - b )e + b c d
+--R                         /
+--R                                3     2 2
+--R                            8a c  - 2b c
+--R                   + 
+--R                                             +--------+
+--R                                         +-+ |   2               2             2
+--R                     (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                   + 
+--R                                      2
+--R                     2a b d e - 2a c d
+--R                /
+--R                    2
+--R                   x
+--R       + 
+--R           c
+--R        *
+--R           ROOT
+--R                                     +------------------------+
+--R                                     |   2 2               2 2
+--R                          3     2 2  |- b e  + 2b c d e - c d              2
+--R                  (- 16a c  + 4b c ) |------------------------  + (2a c - b )e
+--R                                     |          5      2 4
+--R                                    \|     64a c  - 16b c
+--R                + 
+--R                  b c d
+--R             /
+--R                    3     2 2
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                                +------------------------+
+--R                                                |   2 2               2 2
+--R                                    3     3 2   |- b e  + 2b c d e - c d
+--R                          (- 16a b c  + 4b c )x |------------------------
+--R                                                |          5      2 4
+--R                                               \|     64a c  - 16b c
+--R                        + 
+--R                                        3          2    2
+--R                          ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                  3     3 2   |- b e  + 2b c d e - c d
+--R                          (16a b c  - 4b c )x |------------------------
+--R                                              |          5      2 4
+--R                                             \|     64a c  - 16b c
+--R                        + 
+--R                                      3            2    2
+--R                          ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                   3     2 2  |- b e  + 2b c d e - c d
+--R                           (- 16a c  + 4b c ) |------------------------
+--R                                              |          5      2 4
+--R                                             \|     64a c  - 16b c
+--R                         + 
+--R                                    2
+--R                           (2a c - b )e + b c d
+--R                      /
+--R                             3     2 2
+--R                         8a c  - 2b c
+--R                + 
+--R                                          +--------+
+--R                                      +-+ |   2               2             2
+--R                  (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                + 
+--R                                   2
+--R                  2a b d e - 2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R         -
+--R              c
+--R           *
+--R              ROOT
+--R                                      +------------------------+
+--R                                      |   2 2               2 2
+--R                           3     2 2  |- b e  + 2b c d e - c d              2
+--R                     (16a c  - 4b c ) |------------------------  + (2a c - b )e
+--R                                      |          5      2 4
+--R                                     \|     64a c  - 16b c
+--R                   + 
+--R                     b c d
+--R                /
+--R                       3     2 2
+--R                   8a c  - 2b c
+--R           *
+--R              log
+--R                                                   +------------------------+
+--R                                                   |   2 2               2 2
+--R                                       3     3 2   |- b e  + 2b c d e - c d
+--R                             (- 16a b c  + 4b c )x |------------------------
+--R                                                   |          5      2 4
+--R                                                  \|     64a c  - 16b c
+--R                           + 
+--R                                         3            2    2
+--R                             ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                        *
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R                       + 
+--R                                                 +------------------------+
+--R                                                 |   2 2               2 2
+--R                                     3     3 2   |- b e  + 2b c d e - c d
+--R                             (16a b c  - 4b c )x |------------------------
+--R                                                 |          5      2 4
+--R                                                \|     64a c  - 16b c
+--R                           + 
+--R                                           3          2    2
+--R                             ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                        *
+--R                            +-+
+--R                           \|d
+--R                    *
+--R                       ROOT
+--R                                               +------------------------+
+--R                                               |   2 2               2 2
+--R                                    3     2 2  |- b e  + 2b c d e - c d
+--R                              (16a c  - 4b c ) |------------------------
+--R                                               |          5      2 4
+--R                                              \|     64a c  - 16b c
+--R                            + 
+--R                                       2
+--R                              (2a c - b )e + b c d
+--R                         /
+--R                                3     2 2
+--R                            8a c  - 2b c
+--R                   + 
+--R                                             +--------+
+--R                                         +-+ |   2               2             2
+--R                     (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                   + 
+--R                                      2
+--R                     2a b d e - 2a c d
+--R                /
+--R                    2
+--R                   x
+--R       + 
+--R                      +--------+
+--R                      |   2         +-+
+--R           +---+     \|e x  + d  - \|d
+--R         4\|- e atan(------------------)
+--R                             +---+
+--R                           x\|- e
+--R    /
+--R       2c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 3006
+
+--S 3007 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         +------------------------------+
+--R           +-----------+ |    +-----------+
+--R           |          2  |    |          2
+--R         c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R          +------------------------------------------------------------------+
+--R          |                 +------------------------+
+--R          |                 |   2 2               2 2
+--R          |      3     2 2  |- b e  + 2b c d e - c d              2
+--R          |(16a c  - 4b c ) |------------------------  + (2a c - b )e + b c d
+--R          |                 |          5      2 4
+--R          |                \|     64a c  - 16b c
+--R          |------------------------------------------------------------------
+--R          |                               3     2 2
+--R         \|                           8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                            +------------------------+
+--R                                            |   2 2               2 2
+--R                                3     3 2   |- b e  + 2b c d e - c d
+--R                        (16a b c  - 4b c )x |------------------------
+--R                                            |          5      2 4
+--R                                           \|     64a c  - 16b c
+--R                      + 
+--R                                      3          2    2
+--R                        ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                  3     3 2   |- b e  + 2b c d e - c d
+--R                        (- 16a b c  + 4b c )x |------------------------
+--R                                              |          5      2 4
+--R                                             \|     64a c  - 16b c
+--R                      + 
+--R                                    3            2    2
+--R                        ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                          +------------------------+
+--R                                          |   2 2               2 2
+--R                               3     2 2  |- b e  + 2b c d e - c d
+--R                         (16a c  - 4b c ) |------------------------
+--R                                          |          5      2 4
+--R                                         \|     64a c  - 16b c
+--R                       + 
+--R                                  2
+--R                         (2a c - b )e + b c d
+--R                    /
+--R                           3     2 2
+--R                       8a c  - 2b c
+--R              + 
+--R                                        +--------+
+--R                                    +-+ |   2               2             2
+--R                (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R              + 
+--R                                 2
+--R                2a b d e - 2a c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R              |          2  |    |          2
+--R            c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                                      +------------------------+
+--R                                      |   2 2               2 2
+--R                           3     2 2  |- b e  + 2b c d e - c d              2
+--R                   (- 16a c  + 4b c ) |------------------------  + (2a c - b )e
+--R                                      |          5      2 4
+--R                                     \|     64a c  - 16b c
+--R                 + 
+--R                   b c d
+--R              /
+--R                     3     2 2
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                               +------------------------+
+--R                                               |   2 2               2 2
+--R                                   3     3 2   |- b e  + 2b c d e - c d
+--R                           (16a b c  - 4b c )x |------------------------
+--R                                               |          5      2 4
+--R                                              \|     64a c  - 16b c
+--R                         + 
+--R                                       3            2    2
+--R                           ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                                 +------------------------+
+--R                                                 |   2 2               2 2
+--R                                     3     3 2   |- b e  + 2b c d e - c d
+--R                           (- 16a b c  + 4b c )x |------------------------
+--R                                                 |          5      2 4
+--R                                                \|     64a c  - 16b c
+--R                         + 
+--R                                         3          2    2
+--R                           ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                               +------------------------+
+--R                                               |   2 2               2 2
+--R                                    3     2 2  |- b e  + 2b c d e - c d
+--R                            (- 16a c  + 4b c ) |------------------------
+--R                                               |          5      2 4
+--R                                              \|     64a c  - 16b c
+--R                          + 
+--R                                     2
+--R                            (2a c - b )e + b c d
+--R                       /
+--R                              3     2 2
+--R                          8a c  - 2b c
+--R                 + 
+--R                                           +--------+
+--R                                       +-+ |   2               2             2
+--R                   (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                 + 
+--R                                    2
+--R                   2a b d e - 2a c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                         +------------------------------+
+--R           +-----------+ |    +-----------+
+--R           |          2  |    |          2
+--R         c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |                   +------------------------+
+--R          |                   |   2 2               2 2
+--R          |        3     2 2  |- b e  + 2b c d e - c d              2
+--R          |(- 16a c  + 4b c ) |------------------------  + (2a c - b )e + b c d
+--R          |                   |          5      2 4
+--R          |                  \|     64a c  - 16b c
+--R          |--------------------------------------------------------------------
+--R          |                                3     2 2
+--R         \|                            8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                  3     3 2   |- b e  + 2b c d e - c d
+--R                        (- 16a b c  + 4b c )x |------------------------
+--R                                              |          5      2 4
+--R                                             \|     64a c  - 16b c
+--R                      + 
+--R                                      3          2    2
+--R                        ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                            +------------------------+
+--R                                            |   2 2               2 2
+--R                                3     3 2   |- b e  + 2b c d e - c d
+--R                        (16a b c  - 4b c )x |------------------------
+--R                                            |          5      2 4
+--R                                           \|     64a c  - 16b c
+--R                      + 
+--R                                    3            2    2
+--R                        ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                            +------------------------+
+--R                                            |   2 2               2 2
+--R                                 3     2 2  |- b e  + 2b c d e - c d
+--R                         (- 16a c  + 4b c ) |------------------------
+--R                                            |          5      2 4
+--R                                           \|     64a c  - 16b c
+--R                       + 
+--R                                  2
+--R                         (2a c - b )e + b c d
+--R                    /
+--R                           3     2 2
+--R                       8a c  - 2b c
+--R              + 
+--R                                        +--------+
+--R                                    +-+ |   2               2             2
+--R                (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R              + 
+--R                                 2
+--R                2a b d e - 2a c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R              |          2  |    |          2
+--R            c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                                    +------------------------+
+--R                                    |   2 2               2 2
+--R                         3     2 2  |- b e  + 2b c d e - c d              2
+--R                   (16a c  - 4b c ) |------------------------  + (2a c - b )e
+--R                                    |          5      2 4
+--R                                   \|     64a c  - 16b c
+--R                 + 
+--R                   b c d
+--R              /
+--R                     3     2 2
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                                 +------------------------+
+--R                                                 |   2 2               2 2
+--R                                     3     3 2   |- b e  + 2b c d e - c d
+--R                           (- 16a b c  + 4b c )x |------------------------
+--R                                                 |          5      2 4
+--R                                                \|     64a c  - 16b c
+--R                         + 
+--R                                       3            2    2
+--R                           ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                               +------------------------+
+--R                                               |   2 2               2 2
+--R                                   3     3 2   |- b e  + 2b c d e - c d
+--R                           (16a b c  - 4b c )x |------------------------
+--R                                               |          5      2 4
+--R                                              \|     64a c  - 16b c
+--R                         + 
+--R                                         3          2    2
+--R                           ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                             +------------------------+
+--R                                             |   2 2               2 2
+--R                                  3     2 2  |- b e  + 2b c d e - c d
+--R                            (16a c  - 4b c ) |------------------------
+--R                                             |          5      2 4
+--R                                            \|     64a c  - 16b c
+--R                          + 
+--R                                     2
+--R                            (2a c - b )e + b c d
+--R                       /
+--R                              3     2 2
+--R                          8a c  - 2b c
+--R                 + 
+--R                                           +--------+
+--R                                       +-+ |   2               2             2
+--R                   (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                 + 
+--R                                    2
+--R                   2a b d e - 2a c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                          +-----------+
+--R                          |          2                2
+--R         ((- 2b e + 2c d)\|- 4a c + b   + (- 4a c + 2b )e - 2b c d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                        |          2                2
+--R         ((2b e - 2c d)\|- 4a c + b   + (- 4a c + 2b )e - 2b c d)
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R               +-----------+
+--R               |          2  +-+
+--R             2\|- 4a c + b  \|e
+--R          *
+--R                                  +--------+
+--R                      +-+    +-+  |   2          +-+ +-+      2
+--R                 (- x\|e  + \|d )\|e x  + d  + x\|d \|e  - e x  - d
+--R             log(--------------------------------------------------)
+--R                                      +--------+
+--R                                  +-+ |   2
+--R                                 \|d \|e x  + d  - d
+--R         + 
+--R               +-----------+               +-+
+--R               |          2  +-+         x\|e
+--R           - 2\|- 4a c + b  \|e atanh(-----------)
+--R                                       +--------+
+--R                                       |   2
+--R                                      \|e x  + d
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                        +------------------------------+ +------------------+
+--R          +-----------+ |    +-----------+               | +-----------+
+--R          |          2  |    |          2                | |          2
+--R       2c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3007
+
+--S 3008 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3008
+
+--S 3009 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         +------------------------------+
+--R           +-----------+ |    +-----------+
+--R           |          2  |    |          2
+--R         c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R          +------------------------------------------------------------------+
+--R          |                 +------------------------+
+--R          |                 |   2 2               2 2
+--R          |      3     2 2  |- b e  + 2b c d e - c d              2
+--R          |(16a c  - 4b c ) |------------------------  + (2a c - b )e + b c d
+--R          |                 |          5      2 4
+--R          |                \|     64a c  - 16b c
+--R          |------------------------------------------------------------------
+--R          |                               3     2 2
+--R         \|                           8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                            +------------------------+
+--R                                            |   2 2               2 2
+--R                                3     3 2   |- b e  + 2b c d e - c d
+--R                        (16a b c  - 4b c )x |------------------------
+--R                                            |          5      2 4
+--R                                           \|     64a c  - 16b c
+--R                      + 
+--R                                      3          2    2
+--R                        ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                  3     3 2   |- b e  + 2b c d e - c d
+--R                        (- 16a b c  + 4b c )x |------------------------
+--R                                              |          5      2 4
+--R                                             \|     64a c  - 16b c
+--R                      + 
+--R                                    3            2    2
+--R                        ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                          +------------------------+
+--R                                          |   2 2               2 2
+--R                               3     2 2  |- b e  + 2b c d e - c d
+--R                         (16a c  - 4b c ) |------------------------
+--R                                          |          5      2 4
+--R                                         \|     64a c  - 16b c
+--R                       + 
+--R                                  2
+--R                         (2a c - b )e + b c d
+--R                    /
+--R                           3     2 2
+--R                       8a c  - 2b c
+--R              + 
+--R                                        +--------+
+--R                                    +-+ |   2               2             2
+--R                (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R              + 
+--R                                 2
+--R                2a b d e - 2a c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R              |          2  |    |          2
+--R            c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                                      +------------------------+
+--R                                      |   2 2               2 2
+--R                           3     2 2  |- b e  + 2b c d e - c d              2
+--R                   (- 16a c  + 4b c ) |------------------------  + (2a c - b )e
+--R                                      |          5      2 4
+--R                                     \|     64a c  - 16b c
+--R                 + 
+--R                   b c d
+--R              /
+--R                     3     2 2
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                               +------------------------+
+--R                                               |   2 2               2 2
+--R                                   3     3 2   |- b e  + 2b c d e - c d
+--R                           (16a b c  - 4b c )x |------------------------
+--R                                               |          5      2 4
+--R                                              \|     64a c  - 16b c
+--R                         + 
+--R                                       3            2    2
+--R                           ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                                 +------------------------+
+--R                                                 |   2 2               2 2
+--R                                     3     3 2   |- b e  + 2b c d e - c d
+--R                           (- 16a b c  + 4b c )x |------------------------
+--R                                                 |          5      2 4
+--R                                                \|     64a c  - 16b c
+--R                         + 
+--R                                         3          2    2
+--R                           ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                               +------------------------+
+--R                                               |   2 2               2 2
+--R                                    3     2 2  |- b e  + 2b c d e - c d
+--R                            (- 16a c  + 4b c ) |------------------------
+--R                                               |          5      2 4
+--R                                              \|     64a c  - 16b c
+--R                          + 
+--R                                     2
+--R                            (2a c - b )e + b c d
+--R                       /
+--R                              3     2 2
+--R                          8a c  - 2b c
+--R                 + 
+--R                                           +--------+
+--R                                       +-+ |   2               2             2
+--R                   (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                 + 
+--R                                    2
+--R                   2a b d e - 2a c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                         +------------------------------+
+--R           +-----------+ |    +-----------+
+--R           |          2  |    |          2
+--R         c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R          +--------------------------------------------------------------------+
+--R          |                   +------------------------+
+--R          |                   |   2 2               2 2
+--R          |        3     2 2  |- b e  + 2b c d e - c d              2
+--R          |(- 16a c  + 4b c ) |------------------------  + (2a c - b )e + b c d
+--R          |                   |          5      2 4
+--R          |                  \|     64a c  - 16b c
+--R          |--------------------------------------------------------------------
+--R          |                                3     2 2
+--R         \|                            8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                  3     3 2   |- b e  + 2b c d e - c d
+--R                        (- 16a b c  + 4b c )x |------------------------
+--R                                              |          5      2 4
+--R                                             \|     64a c  - 16b c
+--R                      + 
+--R                                      3          2    2
+--R                        ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                            +------------------------+
+--R                                            |   2 2               2 2
+--R                                3     3 2   |- b e  + 2b c d e - c d
+--R                        (16a b c  - 4b c )x |------------------------
+--R                                            |          5      2 4
+--R                                           \|     64a c  - 16b c
+--R                      + 
+--R                                    3            2    2
+--R                        ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                            +------------------------+
+--R                                            |   2 2               2 2
+--R                                 3     2 2  |- b e  + 2b c d e - c d
+--R                         (- 16a c  + 4b c ) |------------------------
+--R                                            |          5      2 4
+--R                                           \|     64a c  - 16b c
+--R                       + 
+--R                                  2
+--R                         (2a c - b )e + b c d
+--R                    /
+--R                           3     2 2
+--R                       8a c  - 2b c
+--R              + 
+--R                                        +--------+
+--R                                    +-+ |   2               2             2
+--R                (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R              + 
+--R                                 2
+--R                2a b d e - 2a c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R              |          2  |    |          2
+--R            c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                                    +------------------------+
+--R                                    |   2 2               2 2
+--R                         3     2 2  |- b e  + 2b c d e - c d              2
+--R                   (16a c  - 4b c ) |------------------------  + (2a c - b )e
+--R                                    |          5      2 4
+--R                                   \|     64a c  - 16b c
+--R                 + 
+--R                   b c d
+--R              /
+--R                     3     2 2
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                                 +------------------------+
+--R                                                 |   2 2               2 2
+--R                                     3     3 2   |- b e  + 2b c d e - c d
+--R                           (- 16a b c  + 4b c )x |------------------------
+--R                                                 |          5      2 4
+--R                                                \|     64a c  - 16b c
+--R                         + 
+--R                                       3            2    2
+--R                           ((4a b c - b )e + (- 4a c  + b c)d)x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                               +------------------------+
+--R                                               |   2 2               2 2
+--R                                   3     3 2   |- b e  + 2b c d e - c d
+--R                           (16a b c  - 4b c )x |------------------------
+--R                                               |          5      2 4
+--R                                              \|     64a c  - 16b c
+--R                         + 
+--R                                         3          2    2
+--R                           ((- 4a b c + b )e + (4a c  - b c)d)x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                             +------------------------+
+--R                                             |   2 2               2 2
+--R                                  3     2 2  |- b e  + 2b c d e - c d
+--R                            (16a c  - 4b c ) |------------------------
+--R                                             |          5      2 4
+--R                                            \|     64a c  - 16b c
+--R                          + 
+--R                                     2
+--R                            (2a c - b )e + b c d
+--R                       /
+--R                              3     2 2
+--R                          8a c  - 2b c
+--R                 + 
+--R                                           +--------+
+--R                                       +-+ |   2               2             2
+--R                   (- 2a b e + 2a c d)\|d \|e x  + d  + (2a b e  - 2a c d e)x
+--R                 + 
+--R                                    2
+--R                   2a b d e - 2a c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                          +-----------+
+--R                          |          2                2
+--R         ((- 2b e + 2c d)\|- 4a c + b   + (- 4a c + 2b )e - 2b c d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                        |          2                2
+--R         ((2b e - 2c d)\|- 4a c + b   + (- 4a c + 2b )e - 2b c d)
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R               +-----------+               +-+
+--R               |          2  +-+         x\|e
+--R           - 2\|- 4a c + b  \|e atanh(-----------)
+--R                                       +--------+
+--R                                       |   2
+--R                                      \|e x  + d
+--R         + 
+--R                                      +--------+
+--R                   +-----------+      |   2         +-+
+--R             +---+ |          2      \|e x  + d  - \|d
+--R           4\|- e \|- 4a c + b  atan(------------------)
+--R                                             +---+
+--R                                           x\|- e
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                        +------------------------------+ +------------------+
+--R          +-----------+ |    +-----------+               | +-----------+
+--R          |          2  |    |          2                | |          2
+--R       2c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3009
+
+--S 3010 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 3010
+
+)clear all
+
+--S 3011 of 3139
+t0:=x*sqrt(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R          x\|e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3011
+
+--S 3012 of 3139
+r0:=-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))*_
+   sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+_
+   atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +------------------------------+                      +--------+
+--R        |    +-----------+                            +-+ +-+ |   2
+--R        |    |          2                            \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                               +------------------------------+
+--R                                               |    +-----------+
+--R                                               |    |          2
+--R                                              \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R          +----------------------------+                     +--------+
+--R          |  +-----------+                           +-+ +-+ |   2
+--R          |  |          2                           \|2 \|c \|e x  + d
+--R       - \|e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R          +-----------+
+--R      +-+ |          2  +-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 3012
+
+--S 3013 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +------------------------------------------------+
+--R          |                +-----------------+
+--R          |                |          2
+--R          |      2     2   |         e
+--R          |(16a c  - 4b c) |- ---------------  + b e - 2c d
+--R          |                |       3      2 2
+--R          |               \|  64a c  - 16b c
+--R          |------------------------------------------------
+--R          |                      2     2
+--R         \|                  8a c  - 2b c
+--R      *
+--R         log
+--R                                       +-----------------+
+--R                                       |          2
+--R                           2     3   2 |         e                    2    2
+--R                  ((16a b c  - 4b c)x  |- ---------------  + (4a c - b )e x )
+--R                                       |       3      2 2
+--R                                      \|  64a c  - 16b c
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                +-----------------+
+--R                   |                |          2
+--R                   |      2     2   |         e
+--R                   |(16a c  - 4b c) |- ---------------  + b e - 2c d
+--R                   |                |       3      2 2
+--R                   |               \|  64a c  - 16b c
+--R                   |------------------------------------------------
+--R                   |                      2     2
+--R                  \|                  8a c  - 2b c
+--R              + 
+--R                       +--------+
+--R                       |   2
+--R                - 2a e\|e x  + d
+--R              + 
+--R                                     +-----------------+
+--R                                     |          2
+--R                         2     2   2 |         e                2         +-+
+--R                ((- 16a c  + 4b c)x  |- ---------------  + b e x  + 2a e)\|d
+--R                                     |       3      2 2
+--R                                    \|  64a c  - 16b c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R             +--------------------------------------------------+
+--R             |                  +-----------------+
+--R             |                  |          2
+--R             |        2     2   |         e
+--R             |(- 16a c  + 4b c) |- ---------------  + b e - 2c d
+--R             |                  |       3      2 2
+--R             |                 \|  64a c  - 16b c
+--R             |--------------------------------------------------
+--R             |                       2     2
+--R            \|                   8a c  - 2b c
+--R         *
+--R            log
+--R                                             +-----------------+
+--R                                             |          2
+--R                                 2     3   2 |         e
+--R                         (16a b c  - 4b c)x  |- ---------------
+--R                                             |       3      2 2
+--R                                            \|  64a c  - 16b c
+--R                       + 
+--R                                    2    2
+--R                         (- 4a c + b )e x
+--R                  *
+--R                      +--------------------------------------------------+
+--R                      |                  +-----------------+
+--R                      |                  |          2
+--R                      |        2     2   |         e
+--R                      |(- 16a c  + 4b c) |- ---------------  + b e - 2c d
+--R                      |                  |       3      2 2
+--R                      |                 \|  64a c  - 16b c
+--R                      |--------------------------------------------------
+--R                      |                       2     2
+--R                     \|                   8a c  - 2b c
+--R                 + 
+--R                          +--------+
+--R                          |   2
+--R                   - 2a e\|e x  + d
+--R                 + 
+--R                                      +-----------------+
+--R                                      |          2
+--R                          2     2   2 |         e                2         +-+
+--R                   ((16a c  - 4b c)x  |- ---------------  + b e x  + 2a e)\|d
+--R                                      |       3      2 2
+--R                                     \|  64a c  - 16b c
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R          +--------------------------------------------------+
+--R          |                  +-----------------+
+--R          |                  |          2
+--R          |        2     2   |         e
+--R          |(- 16a c  + 4b c) |- ---------------  + b e - 2c d
+--R          |                  |       3      2 2
+--R          |                 \|  64a c  - 16b c
+--R          |--------------------------------------------------
+--R          |                       2     2
+--R         \|                   8a c  - 2b c
+--R      *
+--R         log
+--R                                         +-----------------+
+--R                                         |          2
+--R                             2     3   2 |         e                    2    2
+--R                  ((- 16a b c  + 4b c)x  |- ---------------  + (4a c - b )e x )
+--R                                         |       3      2 2
+--R                                        \|  64a c  - 16b c
+--R               *
+--R                   +--------------------------------------------------+
+--R                   |                  +-----------------+
+--R                   |                  |          2
+--R                   |        2     2   |         e
+--R                   |(- 16a c  + 4b c) |- ---------------  + b e - 2c d
+--R                   |                  |       3      2 2
+--R                   |                 \|  64a c  - 16b c
+--R                   |--------------------------------------------------
+--R                   |                       2     2
+--R                  \|                   8a c  - 2b c
+--R              + 
+--R                       +--------+
+--R                       |   2
+--R                - 2a e\|e x  + d
+--R              + 
+--R                                   +-----------------+
+--R                                   |          2
+--R                       2     2   2 |         e                2         +-+
+--R                ((16a c  - 4b c)x  |- ---------------  + b e x  + 2a e)\|d
+--R                                   |       3      2 2
+--R                                  \|  64a c  - 16b c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R             +------------------------------------------------+
+--R             |                +-----------------+
+--R             |                |          2
+--R             |      2     2   |         e
+--R             |(16a c  - 4b c) |- ---------------  + b e - 2c d
+--R             |                |       3      2 2
+--R             |               \|  64a c  - 16b c
+--R             |------------------------------------------------
+--R             |                      2     2
+--R            \|                  8a c  - 2b c
+--R         *
+--R            log
+--R                                             +-----------------+
+--R                                             |          2
+--R                                 2     3   2 |         e
+--R                       (- 16a b c  + 4b c)x  |- ---------------
+--R                                             |       3      2 2
+--R                                            \|  64a c  - 16b c
+--R                     + 
+--R                                  2    2
+--R                       (- 4a c + b )e x
+--R                  *
+--R                      +------------------------------------------------+
+--R                      |                +-----------------+
+--R                      |                |          2
+--R                      |      2     2   |         e
+--R                      |(16a c  - 4b c) |- ---------------  + b e - 2c d
+--R                      |                |       3      2 2
+--R                      |               \|  64a c  - 16b c
+--R                      |------------------------------------------------
+--R                      |                      2     2
+--R                     \|                  8a c  - 2b c
+--R                 + 
+--R                          +--------+
+--R                          |   2
+--R                   - 2a e\|e x  + d
+--R                 + 
+--R                                      +-----------------+
+--R                                      |          2
+--R                          2     2   2 |         e                2         +-+
+--R                 ((- 16a c  + 4b c)x  |- ---------------  + b e x  + 2a e)\|d
+--R                                      |       3      2 2
+--R                                     \|  64a c  - 16b c
+--R              /
+--R                  2
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 3013
+
+--S 3014 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-----------+
+--R          +-+ |          2  +-+
+--R         \|2 \|- 4a c + b  \|c
+--R      *
+--R          +------------------------------------------------+
+--R          |                +-----------------+
+--R          |                |          2
+--R          |      2     2   |         e
+--R          |(16a c  - 4b c) |- ---------------  + b e - 2c d
+--R          |                |       3      2 2
+--R          |               \|  64a c  - 16b c
+--R          |------------------------------------------------
+--R          |                      2     2
+--R         \|                  8a c  - 2b c
+--R      *
+--R         log
+--R                                       +-----------------+
+--R                                       |          2
+--R                           2     3   2 |         e                    2    2
+--R                  ((16a b c  - 4b c)x  |- ---------------  + (4a c - b )e x )
+--R                                       |       3      2 2
+--R                                      \|  64a c  - 16b c
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                +-----------------+
+--R                   |                |          2
+--R                   |      2     2   |         e
+--R                   |(16a c  - 4b c) |- ---------------  + b e - 2c d
+--R                   |                |       3      2 2
+--R                   |               \|  64a c  - 16b c
+--R                   |------------------------------------------------
+--R                   |                      2     2
+--R                  \|                  8a c  - 2b c
+--R              + 
+--R                       +--------+
+--R                       |   2
+--R                - 2a e\|e x  + d
+--R              + 
+--R                                     +-----------------+
+--R                                     |          2
+--R                         2     2   2 |         e                2         +-+
+--R                ((- 16a c  + 4b c)x  |- ---------------  + b e x  + 2a e)\|d
+--R                                     |       3      2 2
+--R                                    \|  64a c  - 16b c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2  +-+
+--R            \|2 \|- 4a c + b  \|c
+--R         *
+--R             +--------------------------------------------------+
+--R             |                  +-----------------+
+--R             |                  |          2
+--R             |        2     2   |         e
+--R             |(- 16a c  + 4b c) |- ---------------  + b e - 2c d
+--R             |                  |       3      2 2
+--R             |                 \|  64a c  - 16b c
+--R             |--------------------------------------------------
+--R             |                       2     2
+--R            \|                   8a c  - 2b c
+--R         *
+--R            log
+--R                                             +-----------------+
+--R                                             |          2
+--R                                 2     3   2 |         e
+--R                         (16a b c  - 4b c)x  |- ---------------
+--R                                             |       3      2 2
+--R                                            \|  64a c  - 16b c
+--R                       + 
+--R                                    2    2
+--R                         (- 4a c + b )e x
+--R                  *
+--R                      +--------------------------------------------------+
+--R                      |                  +-----------------+
+--R                      |                  |          2
+--R                      |        2     2   |         e
+--R                      |(- 16a c  + 4b c) |- ---------------  + b e - 2c d
+--R                      |                  |       3      2 2
+--R                      |                 \|  64a c  - 16b c
+--R                      |--------------------------------------------------
+--R                      |                       2     2
+--R                     \|                   8a c  - 2b c
+--R                 + 
+--R                          +--------+
+--R                          |   2
+--R                   - 2a e\|e x  + d
+--R                 + 
+--R                                      +-----------------+
+--R                                      |          2
+--R                          2     2   2 |         e                2         +-+
+--R                   ((16a c  - 4b c)x  |- ---------------  + b e x  + 2a e)\|d
+--R                                      |       3      2 2
+--R                                     \|  64a c  - 16b c
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R              +-----------+
+--R          +-+ |          2  +-+
+--R         \|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------------------------------------+
+--R          |                  +-----------------+
+--R          |                  |          2
+--R          |        2     2   |         e
+--R          |(- 16a c  + 4b c) |- ---------------  + b e - 2c d
+--R          |                  |       3      2 2
+--R          |                 \|  64a c  - 16b c
+--R          |--------------------------------------------------
+--R          |                       2     2
+--R         \|                   8a c  - 2b c
+--R      *
+--R         log
+--R                                         +-----------------+
+--R                                         |          2
+--R                             2     3   2 |         e                    2    2
+--R                  ((- 16a b c  + 4b c)x  |- ---------------  + (4a c - b )e x )
+--R                                         |       3      2 2
+--R                                        \|  64a c  - 16b c
+--R               *
+--R                   +--------------------------------------------------+
+--R                   |                  +-----------------+
+--R                   |                  |          2
+--R                   |        2     2   |         e
+--R                   |(- 16a c  + 4b c) |- ---------------  + b e - 2c d
+--R                   |                  |       3      2 2
+--R                   |                 \|  64a c  - 16b c
+--R                   |--------------------------------------------------
+--R                   |                       2     2
+--R                  \|                   8a c  - 2b c
+--R              + 
+--R                       +--------+
+--R                       |   2
+--R                - 2a e\|e x  + d
+--R              + 
+--R                                   +-----------------+
+--R                                   |          2
+--R                       2     2   2 |         e                2         +-+
+--R                ((16a c  - 4b c)x  |- ---------------  + b e x  + 2a e)\|d
+--R                                   |       3      2 2
+--R                                  \|  64a c  - 16b c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2  +-+
+--R            \|2 \|- 4a c + b  \|c
+--R         *
+--R             +------------------------------------------------+
+--R             |                +-----------------+
+--R             |                |          2
+--R             |      2     2   |         e
+--R             |(16a c  - 4b c) |- ---------------  + b e - 2c d
+--R             |                |       3      2 2
+--R             |               \|  64a c  - 16b c
+--R             |------------------------------------------------
+--R             |                      2     2
+--R            \|                  8a c  - 2b c
+--R         *
+--R            log
+--R                                             +-----------------+
+--R                                             |          2
+--R                                 2     3   2 |         e
+--R                       (- 16a b c  + 4b c)x  |- ---------------
+--R                                             |       3      2 2
+--R                                            \|  64a c  - 16b c
+--R                     + 
+--R                                  2    2
+--R                       (- 4a c + b )e x
+--R                  *
+--R                      +------------------------------------------------+
+--R                      |                +-----------------+
+--R                      |                |          2
+--R                      |      2     2   |         e
+--R                      |(16a c  - 4b c) |- ---------------  + b e - 2c d
+--R                      |                |       3      2 2
+--R                      |               \|  64a c  - 16b c
+--R                      |------------------------------------------------
+--R                      |                      2     2
+--R                     \|                  8a c  - 2b c
+--R                 + 
+--R                          +--------+
+--R                          |   2
+--R                   - 2a e\|e x  + d
+--R                 + 
+--R                                      +-----------------+
+--R                                      |          2
+--R                          2     2   2 |         e                2         +-+
+--R                 ((- 16a c  + 4b c)x  |- ---------------  + b e x  + 2a e)\|d
+--R                                      |       3      2 2
+--R                                     \|  64a c  - 16b c
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R       -
+--R              +------------------------------+
+--R              |    +-----------+
+--R              |    |          2
+--R            2\|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R                                  +--------+
+--R                          +-+ +-+ |   2
+--R                         \|2 \|c \|e x  + d
+--R            atanh(---------------------------------)
+--R                   +------------------------------+
+--R                   |    +-----------+
+--R                   |    |          2
+--R                  \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R         +----------------------------+                     +--------+
+--R         |  +-----------+                           +-+ +-+ |   2
+--R         |  |          2                           \|2 \|c \|e x  + d
+--R       2\|e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                              +----------------------------+
+--R                                              |  +-----------+
+--R                                              |  |          2
+--R                                             \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 3014
+
+--S 3015 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3015
+
+)clear all
+
+--S 3016 of 3139
+t0:=sqrt(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R          \|e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3016
+
+--S 3017 of 3139
+r0:=-atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*_
+   sqrt(-b+sqrt(b^2-4*a*c))))*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (sqrt(b^2-4*a*c)*sqrt(-b+sqrt(b^2-4*a*c)))-atan(x*sqrt(2*c*d-_
+   e*(b+sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(sqrt(b^2-4*a*c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +------------------+ +----------------------------+
+--R             | +-----------+      |  +-----------+
+--R             | |          2       |  |          2
+--R            \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R                    +----------------------------+
+--R                    |  +-----------+
+--R                    |  |          2
+--R                  x\|e\|- 4a c + b   - b e + 2c d
+--R            atanh(--------------------------------)
+--R                              +------------------+
+--R                   +--------+ | +-----------+
+--R                   |   2      | |          2
+--R                  \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R       -
+--R             +------------------------------+ +------------------+
+--R             |    +-----------+               | +-----------+
+--R             |    |          2                | |          2
+--R            \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R         *
+--R                   +------------------------------+
+--R                   |    +-----------+
+--R                   |    |          2
+--R                 x\|- e\|- 4a c + b   - b e + 2c d
+--R            atan(----------------------------------)
+--R                              +------------------+
+--R                   +--------+ | +-----------+
+--R                   |   2      | |          2
+--R                  \|e x  + d \|\|- 4a c + b   + b
+--R  /
+--R                    +------------------+ +------------------+
+--R      +-----------+ | +-----------+      | +-----------+
+--R      |          2  | |          2       | |          2
+--R     \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3017
+
+--S 3018 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +-----------------------------------------------+
+--R             |                +----------------+
+--R             |                |         2
+--R             |    2        2  |        d
+--R             |(16a c - 4a b ) |- --------------  - 2a e + b d
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |-----------------------------------------------
+--R             |                    2        2
+--R            \|                  8a c - 2a b
+--R         *
+--R            log
+--R                                        +----------------+
+--R                                        |         2        +--------+
+--R                           2        2   |        d         |   2
+--R                       (16a c - 4a b )x |- -------------- \|e x  + d
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                     + 
+--R                                          +----------------+
+--R                                          |         2
+--R                             2        2   |        d         +-+
+--R                       (- 16a c + 4a b )x |- -------------- \|d
+--R                                          |     3       2 2
+--R                                         \|  64a c - 16a b
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                +----------------+
+--R                      |                |         2
+--R                      |    2        2  |        d
+--R                      |(16a c - 4a b ) |- --------------  - 2a e + b d
+--R                      |                |     3       2 2
+--R                      |               \|  64a c - 16a b
+--R                      |-----------------------------------------------
+--R                      |                    2        2
+--R                     \|                  8a c - 2a b
+--R                 + 
+--R                           +--------+
+--R                       +-+ |   2             2    2
+--R                   - d\|d \|e x  + d  + d e x  + d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R          +-------------------------------------------------+
+--R          |                  +----------------+
+--R          |                  |         2
+--R          |      2        2  |        d
+--R          |(- 16a c + 4a b ) |- --------------  - 2a e + b d
+--R          |                  |     3       2 2
+--R          |                 \|  64a c - 16a b
+--R          |-------------------------------------------------
+--R          |                     2        2
+--R         \|                   8a c - 2a b
+--R      *
+--R         log
+--R                                     +----------------+
+--R                                     |         2        +--------+
+--R                        2        2   |        d         |   2
+--R                    (16a c - 4a b )x |- -------------- \|e x  + d
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R                  + 
+--R                                       +----------------+
+--R                                       |         2
+--R                          2        2   |        d         +-+
+--R                    (- 16a c + 4a b )x |- -------------- \|d
+--R                                       |     3       2 2
+--R                                      \|  64a c - 16a b
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  +----------------+
+--R                   |                  |         2
+--R                   |      2        2  |        d
+--R                   |(- 16a c + 4a b ) |- --------------  - 2a e + b d
+--R                   |                  |     3       2 2
+--R                   |                 \|  64a c - 16a b
+--R                   |-------------------------------------------------
+--R                   |                     2        2
+--R                  \|                   8a c - 2a b
+--R              + 
+--R                        +--------+
+--R                    +-+ |   2             2    2
+--R                - d\|d \|e x  + d  + d e x  + d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R             +-------------------------------------------------+
+--R             |                  +----------------+
+--R             |                  |         2
+--R             |      2        2  |        d
+--R             |(- 16a c + 4a b ) |- --------------  - 2a e + b d
+--R             |                  |     3       2 2
+--R             |                 \|  64a c - 16a b
+--R             |-------------------------------------------------
+--R             |                     2        2
+--R            \|                   8a c - 2a b
+--R         *
+--R            log
+--R                                          +----------------+
+--R                                          |         2        +--------+
+--R                             2        2   |        d         |   2
+--R                       (- 16a c + 4a b )x |- -------------- \|e x  + d
+--R                                          |     3       2 2
+--R                                         \|  64a c - 16a b
+--R                     + 
+--R                                        +----------------+
+--R                                        |         2
+--R                           2        2   |        d         +-+
+--R                       (16a c - 4a b )x |- -------------- \|d
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                  *
+--R                      +-------------------------------------------------+
+--R                      |                  +----------------+
+--R                      |                  |         2
+--R                      |      2        2  |        d
+--R                      |(- 16a c + 4a b ) |- --------------  - 2a e + b d
+--R                      |                  |     3       2 2
+--R                      |                 \|  64a c - 16a b
+--R                      |-------------------------------------------------
+--R                      |                     2        2
+--R                     \|                   8a c - 2a b
+--R                 + 
+--R                           +--------+
+--R                       +-+ |   2             2    2
+--R                   - d\|d \|e x  + d  + d e x  + d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R          +-----------------------------------------------+
+--R          |                +----------------+
+--R          |                |         2
+--R          |    2        2  |        d
+--R          |(16a c - 4a b ) |- --------------  - 2a e + b d
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |-----------------------------------------------
+--R          |                    2        2
+--R         \|                  8a c - 2a b
+--R      *
+--R         log
+--R                                       +----------------+
+--R                                       |         2        +--------+
+--R                          2        2   |        d         |   2
+--R                    (- 16a c + 4a b )x |- -------------- \|e x  + d
+--R                                       |     3       2 2
+--R                                      \|  64a c - 16a b
+--R                  + 
+--R                                     +----------------+
+--R                                     |         2
+--R                        2        2   |        d         +-+
+--R                    (16a c - 4a b )x |- -------------- \|d
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                +----------------+
+--R                   |                |         2
+--R                   |    2        2  |        d
+--R                   |(16a c - 4a b ) |- --------------  - 2a e + b d
+--R                   |                |     3       2 2
+--R                   |               \|  64a c - 16a b
+--R                   |-----------------------------------------------
+--R                   |                    2        2
+--R                  \|                  8a c - 2a b
+--R              + 
+--R                        +--------+
+--R                    +-+ |   2             2    2
+--R                - d\|d \|e x  + d  + d e x  + d
+--R           /
+--R               2
+--R              x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 3018
+
+--S 3019 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                           +-----------------------------------------------+
+--R                           |                +----------------+
+--R                           |                |         2
+--R                           |    2        2  |        d
+--R                           |(16a c - 4a b ) |- --------------  - 2a e + b d
+--R             +-----------+ |                |     3       2 2
+--R             |          2  |               \|  64a c - 16a b
+--R            \|- 4a c + b   |-----------------------------------------------
+--R                           |                    2        2
+--R                          \|                  8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                        +----------------+
+--R                                        |         2        +--------+
+--R                           2        2   |        d         |   2
+--R                       (16a c - 4a b )x |- -------------- \|e x  + d
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                     + 
+--R                                          +----------------+
+--R                                          |         2
+--R                             2        2   |        d         +-+
+--R                       (- 16a c + 4a b )x |- -------------- \|d
+--R                                          |     3       2 2
+--R                                         \|  64a c - 16a b
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                +----------------+
+--R                      |                |         2
+--R                      |    2        2  |        d
+--R                      |(16a c - 4a b ) |- --------------  - 2a e + b d
+--R                      |                |     3       2 2
+--R                      |               \|  64a c - 16a b
+--R                      |-----------------------------------------------
+--R                      |                    2        2
+--R                     \|                  8a c - 2a b
+--R                 + 
+--R                           +--------+
+--R                       +-+ |   2             2    2
+--R                   - d\|d \|e x  + d  + d e x  + d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                        +-------------------------------------------------+
+--R                        |                  +----------------+
+--R                        |                  |         2
+--R                        |      2        2  |        d
+--R                        |(- 16a c + 4a b ) |- --------------  - 2a e + b d
+--R          +-----------+ |                  |     3       2 2
+--R          |          2  |                 \|  64a c - 16a b
+--R         \|- 4a c + b   |-------------------------------------------------
+--R                        |                     2        2
+--R                       \|                   8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                     +----------------+
+--R                                     |         2        +--------+
+--R                        2        2   |        d         |   2
+--R                    (16a c - 4a b )x |- -------------- \|e x  + d
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R                  + 
+--R                                       +----------------+
+--R                                       |         2
+--R                          2        2   |        d         +-+
+--R                    (- 16a c + 4a b )x |- -------------- \|d
+--R                                       |     3       2 2
+--R                                      \|  64a c - 16a b
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |                  +----------------+
+--R                   |                  |         2
+--R                   |      2        2  |        d
+--R                   |(- 16a c + 4a b ) |- --------------  - 2a e + b d
+--R                   |                  |     3       2 2
+--R                   |                 \|  64a c - 16a b
+--R                   |-------------------------------------------------
+--R                   |                     2        2
+--R                  \|                   8a c - 2a b
+--R              + 
+--R                        +--------+
+--R                    +-+ |   2             2    2
+--R                - d\|d \|e x  + d  + d e x  + d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                           +-------------------------------------------------+
+--R                           |                  +----------------+
+--R                           |                  |         2
+--R                           |      2        2  |        d
+--R                           |(- 16a c + 4a b ) |- --------------  - 2a e + b d
+--R             +-----------+ |                  |     3       2 2
+--R             |          2  |                 \|  64a c - 16a b
+--R            \|- 4a c + b   |-------------------------------------------------
+--R                           |                     2        2
+--R                          \|                   8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                          +----------------+
+--R                                          |         2        +--------+
+--R                             2        2   |        d         |   2
+--R                       (- 16a c + 4a b )x |- -------------- \|e x  + d
+--R                                          |     3       2 2
+--R                                         \|  64a c - 16a b
+--R                     + 
+--R                                        +----------------+
+--R                                        |         2
+--R                           2        2   |        d         +-+
+--R                       (16a c - 4a b )x |- -------------- \|d
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                  *
+--R                      +-------------------------------------------------+
+--R                      |                  +----------------+
+--R                      |                  |         2
+--R                      |      2        2  |        d
+--R                      |(- 16a c + 4a b ) |- --------------  - 2a e + b d
+--R                      |                  |     3       2 2
+--R                      |                 \|  64a c - 16a b
+--R                      |-------------------------------------------------
+--R                      |                     2        2
+--R                     \|                   8a c - 2a b
+--R                 + 
+--R                           +--------+
+--R                       +-+ |   2             2    2
+--R                   - d\|d \|e x  + d  + d e x  + d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                        +-----------------------------------------------+
+--R                        |                +----------------+
+--R                        |                |         2
+--R                        |    2        2  |        d
+--R                        |(16a c - 4a b ) |- --------------  - 2a e + b d
+--R          +-----------+ |                |     3       2 2
+--R          |          2  |               \|  64a c - 16a b
+--R         \|- 4a c + b   |-----------------------------------------------
+--R                        |                    2        2
+--R                       \|                  8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                       +----------------+
+--R                                       |         2        +--------+
+--R                          2        2   |        d         |   2
+--R                    (- 16a c + 4a b )x |- -------------- \|e x  + d
+--R                                       |     3       2 2
+--R                                      \|  64a c - 16a b
+--R                  + 
+--R                                     +----------------+
+--R                                     |         2
+--R                        2        2   |        d         +-+
+--R                    (16a c - 4a b )x |- -------------- \|d
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                +----------------+
+--R                   |                |         2
+--R                   |    2        2  |        d
+--R                   |(16a c - 4a b ) |- --------------  - 2a e + b d
+--R                   |                |     3       2 2
+--R                   |               \|  64a c - 16a b
+--R                   |-----------------------------------------------
+--R                   |                    2        2
+--R                  \|                  8a c - 2a b
+--R              + 
+--R                        +--------+
+--R                    +-+ |   2             2    2
+--R                - d\|d \|e x  + d  + d e x  + d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R           +------------------+ +----------------------------+
+--R           | +-----------+      |  +-----------+
+--R           | |          2       |  |          2
+--R         2\|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R           +------------------------------+ +------------------+
+--R           |    +-----------+               | +-----------+
+--R           |    |          2                | |          2
+--R         2\|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R  /
+--R                     +------------------+ +------------------+
+--R       +-----------+ | +-----------+      | +-----------+
+--R       |          2  | |          2       | |          2
+--R     2\|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3019
+
+--S 3020 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3020
+
+)clear all
+
+--S 3021 of 3139
+t0:=sqrt(d+e*x^2)/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R           \|e x  + d
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3021
+
+--S 3022 of 3139
+r0:=-atanh(sqrt(d+e*x^2)/sqrt(d))*sqrt(d)/a+atanh(sqrt(2)*sqrt(c)*_
+   sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))*sqrt(c)*(d+_
+   (b*d-2*a*e)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c))))+atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*sqrt(c)*(d+(-b*d+2*a*e)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                                            +----------------------------+
+--R            +-----------+                   |  +-----------+
+--R            |          2                +-+ |  |          2
+--R         (d\|- 4a c + b   + 2a e - b d)\|c \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                               +--------+
+--R                       +-+ +-+ |   2
+--R                      \|2 \|c \|e x  + d
+--R         atanh(---------------------------------)
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R               \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                            +------------------------------+
+--R            +-----------+                   |    +-----------+
+--R            |          2                +-+ |    |          2
+--R         (d\|- 4a c + b   - 2a e + b d)\|c \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                              +--------+
+--R                      +-+ +-+ |   2
+--R                     \|2 \|c \|e x  + d
+--R         atanh(-------------------------------)
+--R                +----------------------------+
+--R                |  +-----------+
+--R                |  |          2
+--R               \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R       -
+--R                                         +--------+
+--R                 +-----------+           |   2
+--R             +-+ |          2  +-+      \|e x  + d
+--R            \|2 \|- 4a c + b  \|d atanh(-----------)
+--R                                             +-+
+--R                                            \|d
+--R         *
+--R             +------------------------------+ +----------------------------+
+--R             |    +-----------+               |  +-----------+
+--R             |    |          2                |  |          2
+--R            \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                           +------------------------------+
+--R             +-----------+ |    +-----------+
+--R         +-+ |          2  |    |          2
+--R       a\|2 \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3022
+
+--S 3023 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-----------------------------------------------------------------+
+--R           |                +------------------------+
+--R           |                |   2 2               2 2
+--R           |    3      2 2  |- a e  + 2a b d e - b d                      2
+--R           |(16a c - 4a b ) |------------------------  + a b e + (2a c - b )d
+--R           |                |        5       4 2
+--R           |               \|     64a c - 16a b
+--R         a |-----------------------------------------------------------------
+--R           |                             3      2 2
+--R          \|                           8a c - 2a b
+--R      *
+--R         log
+--R                                    +------------------------+
+--R                                    |   2 2               2 2
+--R                      4      3 2  2 |- a e  + 2a b d e - b d   +-+
+--R                  (32a c - 8a b )x  |------------------------ \|d
+--R                                    |        5       4 2
+--R                                   \|     64a c - 16a b
+--R               *
+--R                  ROOT
+--R                                         +------------------------+
+--R                                         |   2 2               2 2
+--R                             3      2 2  |- a e  + 2a b d e - b d
+--R                         (16a c - 4a b ) |------------------------  + a b e
+--R                                         |        5       4 2
+--R                                        \|     64a c - 16a b
+--R                       + 
+--R                                  2
+--R                         (2a c - b )d
+--R                    /
+--R                         3      2 2
+--R                       8a c - 2a b
+--R              + 
+--R                                      +--------+
+--R                     2            +-+ |   2
+--R                (- 2a e + 2a b d)\|d \|e x  + d
+--R              + 
+--R                                    +------------------------+
+--R                                    |   2 2               2 2
+--R                    3      2 2    2 |- a e  + 2a b d e - b d
+--R                (16a c - 4a b )d x  |------------------------
+--R                                    |        5       4 2
+--R                                   \|     64a c - 16a b
+--R              + 
+--R                            2 2  2     2            2
+--R                (a b d e - b d )x  + 2a d e - 2a b d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R            a
+--R         *
+--R            ROOT
+--R                                     +------------------------+
+--R                                     |   2 2               2 2
+--R                         3      2 2  |- a e  + 2a b d e - b d
+--R                   (- 16a c + 4a b ) |------------------------  + a b e
+--R                                     |        5       4 2
+--R                                    \|     64a c - 16a b
+--R                 + 
+--R                            2
+--R                   (2a c - b )d
+--R              /
+--R                   3      2 2
+--R                 8a c - 2a b
+--R         *
+--R            log
+--R                                       +------------------------+
+--R                                       |   2 2               2 2
+--R                         4      3 2  2 |- a e  + 2a b d e - b d   +-+
+--R                     (32a c - 8a b )x  |------------------------ \|d
+--R                                       |        5       4 2
+--R                                      \|     64a c - 16a b
+--R                  *
+--R                     ROOT
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                  3      2 2  |- a e  + 2a b d e - b d
+--R                            (- 16a c + 4a b ) |------------------------  + a b e
+--R                                              |        5       4 2
+--R                                             \|     64a c - 16a b
+--R                          + 
+--R                                     2
+--R                            (2a c - b )d
+--R                       /
+--R                            3      2 2
+--R                          8a c - 2a b
+--R                 + 
+--R                                         +--------+
+--R                        2            +-+ |   2
+--R                   (- 2a e + 2a b d)\|d \|e x  + d
+--R                 + 
+--R                                         +------------------------+
+--R                                         |   2 2               2 2
+--R                         3      2 2    2 |- a e  + 2a b d e - b d
+--R                   (- 16a c + 4a b )d x  |------------------------
+--R                                         |        5       4 2
+--R                                        \|     64a c - 16a b
+--R                 + 
+--R                               2 2  2     2            2
+--R                   (a b d e - b d )x  + 2a d e - 2a b d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R           +-------------------------------------------------------------------+
+--R           |                  +------------------------+
+--R           |                  |   2 2               2 2
+--R           |      3      2 2  |- a e  + 2a b d e - b d                      2
+--R           |(- 16a c + 4a b ) |------------------------  + a b e + (2a c - b )d
+--R           |                  |        5       4 2
+--R           |                 \|     64a c - 16a b
+--R         a |-------------------------------------------------------------------
+--R           |                              3      2 2
+--R          \|                            8a c - 2a b
+--R      *
+--R         log
+--R                                      +------------------------+
+--R                                      |   2 2               2 2
+--R                        4      3 2  2 |- a e  + 2a b d e - b d   +-+
+--R                  (- 32a c + 8a b )x  |------------------------ \|d
+--R                                      |        5       4 2
+--R                                     \|     64a c - 16a b
+--R               *
+--R                  ROOT
+--R                                           +------------------------+
+--R                                           |   2 2               2 2
+--R                               3      2 2  |- a e  + 2a b d e - b d
+--R                         (- 16a c + 4a b ) |------------------------  + a b e
+--R                                           |        5       4 2
+--R                                          \|     64a c - 16a b
+--R                       + 
+--R                                  2
+--R                         (2a c - b )d
+--R                    /
+--R                         3      2 2
+--R                       8a c - 2a b
+--R              + 
+--R                                      +--------+
+--R                     2            +-+ |   2
+--R                (- 2a e + 2a b d)\|d \|e x  + d
+--R              + 
+--R                                      +------------------------+
+--R                                      |   2 2               2 2
+--R                      3      2 2    2 |- a e  + 2a b d e - b d
+--R                (- 16a c + 4a b )d x  |------------------------
+--R                                      |        5       4 2
+--R                                     \|     64a c - 16a b
+--R              + 
+--R                            2 2  2     2            2
+--R                (a b d e - b d )x  + 2a d e - 2a b d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R            a
+--R         *
+--R             +-----------------------------------------------------------------+
+--R             |                +------------------------+
+--R             |                |   2 2               2 2
+--R             |    3      2 2  |- a e  + 2a b d e - b d                      2
+--R             |(16a c - 4a b ) |------------------------  + a b e + (2a c - b )d
+--R             |                |        5       4 2
+--R             |               \|     64a c - 16a b
+--R             |-----------------------------------------------------------------
+--R             |                             3      2 2
+--R            \|                           8a c - 2a b
+--R         *
+--R            log
+--R                                         +------------------------+
+--R                                         |   2 2               2 2
+--R                           4      3 2  2 |- a e  + 2a b d e - b d   +-+
+--R                     (- 32a c + 8a b )x  |------------------------ \|d
+--R                                         |        5       4 2
+--R                                        \|     64a c - 16a b
+--R                  *
+--R                     ROOT
+--R                                            +------------------------+
+--R                                            |   2 2               2 2
+--R                                3      2 2  |- a e  + 2a b d e - b d
+--R                            (16a c - 4a b ) |------------------------  + a b e
+--R                                            |        5       4 2
+--R                                           \|     64a c - 16a b
+--R                          + 
+--R                                     2
+--R                            (2a c - b )d
+--R                       /
+--R                            3      2 2
+--R                          8a c - 2a b
+--R                 + 
+--R                                         +--------+
+--R                        2            +-+ |   2
+--R                   (- 2a e + 2a b d)\|d \|e x  + d
+--R                 + 
+--R                                       +------------------------+
+--R                                       |   2 2               2 2
+--R                       3      2 2    2 |- a e  + 2a b d e - b d
+--R                   (16a c - 4a b )d x  |------------------------
+--R                                       |        5       4 2
+--R                                      \|     64a c - 16a b
+--R                 + 
+--R                               2 2  2     2            2
+--R                   (a b d e - b d )x  + 2a d e - 2a b d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                 +--------+
+--R                 |   2         +-+
+--R         +-+    \|e x  + d  - \|d
+--R       2\|d log(------------------)
+--R                         x
+--R  /
+--R     2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 3023
+
+--S 3024 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +------------------------------+
+--R               +-----------+ |    +-----------+
+--R           +-+ |          2  |    |          2
+--R         a\|2 \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R          +-----------------------------------------------------------------+
+--R          |                +------------------------+
+--R          |                |   2 2               2 2
+--R          |    3      2 2  |- a e  + 2a b d e - b d                      2
+--R          |(16a c - 4a b ) |------------------------  + a b e + (2a c - b )d
+--R          |                |        5       4 2
+--R          |               \|     64a c - 16a b
+--R          |-----------------------------------------------------------------
+--R          |                             3      2 2
+--R         \|                           8a c - 2a b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                    +------------------------+
+--R                                    |   2 2               2 2
+--R                      4      3 2  2 |- a e  + 2a b d e - b d   +-+
+--R                  (32a c - 8a b )x  |------------------------ \|d
+--R                                    |        5       4 2
+--R                                   \|     64a c - 16a b
+--R               *
+--R                  ROOT
+--R                                         +------------------------+
+--R                                         |   2 2               2 2
+--R                             3      2 2  |- a e  + 2a b d e - b d
+--R                         (16a c - 4a b ) |------------------------  + a b e
+--R                                         |        5       4 2
+--R                                        \|     64a c - 16a b
+--R                       + 
+--R                                  2
+--R                         (2a c - b )d
+--R                    /
+--R                         3      2 2
+--R                       8a c - 2a b
+--R              + 
+--R                                      +--------+
+--R                     2            +-+ |   2
+--R                (- 2a e + 2a b d)\|d \|e x  + d
+--R              + 
+--R                                    +------------------------+
+--R                                    |   2 2               2 2
+--R                    3      2 2    2 |- a e  + 2a b d e - b d
+--R                (16a c - 4a b )d x  |------------------------
+--R                                    |        5       4 2
+--R                                   \|     64a c - 16a b
+--R              + 
+--R                            2 2  2     2            2
+--R                (a b d e - b d )x  + 2a d e - 2a b d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                                +------------------------------+
+--R                  +-----------+ |    +-----------+
+--R              +-+ |          2  |    |          2
+--R            a\|2 \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                                     +------------------------+
+--R                                     |   2 2               2 2
+--R                         3      2 2  |- a e  + 2a b d e - b d
+--R                   (- 16a c + 4a b ) |------------------------  + a b e
+--R                                     |        5       4 2
+--R                                    \|     64a c - 16a b
+--R                 + 
+--R                            2
+--R                   (2a c - b )d
+--R              /
+--R                   3      2 2
+--R                 8a c - 2a b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                       +------------------------+
+--R                                       |   2 2               2 2
+--R                         4      3 2  2 |- a e  + 2a b d e - b d   +-+
+--R                     (32a c - 8a b )x  |------------------------ \|d
+--R                                       |        5       4 2
+--R                                      \|     64a c - 16a b
+--R                  *
+--R                     ROOT
+--R                                              +------------------------+
+--R                                              |   2 2               2 2
+--R                                  3      2 2  |- a e  + 2a b d e - b d
+--R                            (- 16a c + 4a b ) |------------------------  + a b e
+--R                                              |        5       4 2
+--R                                             \|     64a c - 16a b
+--R                          + 
+--R                                     2
+--R                            (2a c - b )d
+--R                       /
+--R                            3      2 2
+--R                          8a c - 2a b
+--R                 + 
+--R                                         +--------+
+--R                        2            +-+ |   2
+--R                   (- 2a e + 2a b d)\|d \|e x  + d
+--R                 + 
+--R                                         +------------------------+
+--R                                         |   2 2               2 2
+--R                         3      2 2    2 |- a e  + 2a b d e - b d
+--R                   (- 16a c + 4a b )d x  |------------------------
+--R                                         |        5       4 2
+--R                                        \|     64a c - 16a b
+--R                 + 
+--R                               2 2  2     2            2
+--R                   (a b d e - b d )x  + 2a d e - 2a b d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                             +------------------------------+
+--R               +-----------+ |    +-----------+
+--R           +-+ |          2  |    |          2
+--R         a\|2 \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R          +-------------------------------------------------------------------+
+--R          |                  +------------------------+
+--R          |                  |   2 2               2 2
+--R          |      3      2 2  |- a e  + 2a b d e - b d                      2
+--R          |(- 16a c + 4a b ) |------------------------  + a b e + (2a c - b )d
+--R          |                  |        5       4 2
+--R          |                 \|     64a c - 16a b
+--R          |-------------------------------------------------------------------
+--R          |                              3      2 2
+--R         \|                            8a c - 2a b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                      +------------------------+
+--R                                      |   2 2               2 2
+--R                        4      3 2  2 |- a e  + 2a b d e - b d   +-+
+--R                  (- 32a c + 8a b )x  |------------------------ \|d
+--R                                      |        5       4 2
+--R                                     \|     64a c - 16a b
+--R               *
+--R                  ROOT
+--R                                           +------------------------+
+--R                                           |   2 2               2 2
+--R                               3      2 2  |- a e  + 2a b d e - b d
+--R                         (- 16a c + 4a b ) |------------------------  + a b e
+--R                                           |        5       4 2
+--R                                          \|     64a c - 16a b
+--R                       + 
+--R                                  2
+--R                         (2a c - b )d
+--R                    /
+--R                         3      2 2
+--R                       8a c - 2a b
+--R              + 
+--R                                      +--------+
+--R                     2            +-+ |   2
+--R                (- 2a e + 2a b d)\|d \|e x  + d
+--R              + 
+--R                                      +------------------------+
+--R                                      |   2 2               2 2
+--R                      3      2 2    2 |- a e  + 2a b d e - b d
+--R                (- 16a c + 4a b )d x  |------------------------
+--R                                      |        5       4 2
+--R                                     \|     64a c - 16a b
+--R              + 
+--R                            2 2  2     2            2
+--R                (a b d e - b d )x  + 2a d e - 2a b d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                                +------------------------------+
+--R                  +-----------+ |    +-----------+
+--R              +-+ |          2  |    |          2
+--R            a\|2 \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R             +-----------------------------------------------------------------+
+--R             |                +------------------------+
+--R             |                |   2 2               2 2
+--R             |    3      2 2  |- a e  + 2a b d e - b d                      2
+--R             |(16a c - 4a b ) |------------------------  + a b e + (2a c - b )d
+--R             |                |        5       4 2
+--R             |               \|     64a c - 16a b
+--R             |-----------------------------------------------------------------
+--R             |                             3      2 2
+--R            \|                           8a c - 2a b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                         +------------------------+
+--R                                         |   2 2               2 2
+--R                           4      3 2  2 |- a e  + 2a b d e - b d   +-+
+--R                     (- 32a c + 8a b )x  |------------------------ \|d
+--R                                         |        5       4 2
+--R                                        \|     64a c - 16a b
+--R                  *
+--R                     ROOT
+--R                                            +------------------------+
+--R                                            |   2 2               2 2
+--R                                3      2 2  |- a e  + 2a b d e - b d
+--R                            (16a c - 4a b ) |------------------------  + a b e
+--R                                            |        5       4 2
+--R                                           \|     64a c - 16a b
+--R                          + 
+--R                                     2
+--R                            (2a c - b )d
+--R                       /
+--R                            3      2 2
+--R                          8a c - 2a b
+--R                 + 
+--R                                         +--------+
+--R                        2            +-+ |   2
+--R                   (- 2a e + 2a b d)\|d \|e x  + d
+--R                 + 
+--R                                       +------------------------+
+--R                                       |   2 2               2 2
+--R                       3      2 2    2 |- a e  + 2a b d e - b d
+--R                   (16a c - 4a b )d x  |------------------------
+--R                                       |        5       4 2
+--R                                      \|     64a c - 16a b
+--R                 + 
+--R                               2 2  2     2            2
+--R                   (a b d e - b d )x  + 2a d e - 2a b d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                                                +----------------------------+
+--R               +-----------+                    |  +-----------+
+--R               |          2                 +-+ |  |          2
+--R         (- 2d\|- 4a c + b   - 4a e + 2b d)\|c \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                               +--------+
+--R                       +-+ +-+ |   2
+--R                      \|2 \|c \|e x  + d
+--R         atanh(---------------------------------)
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R               \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                                +------------------------------+
+--R               +-----------+                    |    +-----------+
+--R               |          2                 +-+ |    |          2
+--R         (- 2d\|- 4a c + b   + 4a e - 2b d)\|c \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                              +--------+
+--R                      +-+ +-+ |   2
+--R                     \|2 \|c \|e x  + d
+--R         atanh(-------------------------------)
+--R                +----------------------------+
+--R                |  +-----------+
+--R                |  |          2
+--R               \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                       +--------+
+--R                 +-----------+         |   2         +-+
+--R             +-+ |          2  +-+    \|e x  + d  - \|d
+--R           2\|2 \|- 4a c + b  \|d log(------------------)
+--R                                               x
+--R         + 
+--R                                         +--------+
+--R                 +-----------+           |   2
+--R             +-+ |          2  +-+      \|e x  + d
+--R           2\|2 \|- 4a c + b  \|d atanh(-----------)
+--R                                             +-+
+--R                                            \|d
+--R      *
+--R          +------------------------------+ +----------------------------+
+--R          |    +-----------+               |  +-----------+
+--R          |    |          2                |  |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R          +-+ |          2  |    |          2
+--R       2a\|2 \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3024
+
+--S 3025 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3025
+
+)clear all
+
+--S 3026 of 3139
+t0:=sqrt(d+e*x^2)/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|e x  + d
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3026
+
+--S 3027 of 3139
+r0:=-sqrt(d+e*x^2)/(a*x)+c*atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*(d+(b*d-2*a*e)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+   sqrt(b^2-4*a*c)))-c*atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(d+(-b*d+2*a*e)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b+sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b+_
+   sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                +-----------+
+--R                |          2
+--R         (c d x\|- 4a c + b   + (- 2a c e + b c d)x)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                                       +------------------+
+--R                  +-----------+                        | +-----------+
+--R                  |          2                         | |          2
+--R         (- c d x\|- 4a c + b   + (- 2a c e + b c d)x)\|\|- 4a c + b   - b
+--R      *
+--R                                             +------------------------------+
+--R        +----------------------------+       |    +-----------+
+--R        |  +-----------+                     |    |          2
+--R        |  |          2                    x\|- e\|- 4a c + b   - b e + 2c d
+--R       \|e\|- 4a c + b   - b e + 2c d atan(----------------------------------)
+--R                                                        +------------------+
+--R                                             +--------+ | +-----------+
+--R                                             |   2      | |          2
+--R                                            \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                                      +------------------------------+
+--R             +-----------+ +--------+ |    +-----------+
+--R             |          2  |   2      |    |          2
+--R            \|- 4a c + b  \|e x  + d \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                         +------------------------------+ +------------------+
+--R           +-----------+ |    +-----------+               | +-----------+
+--R           |          2  |    |          2                | |          2
+--R       a x\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3027
+
+--S 3028 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                +--------+
+--R                |   2            +-+
+--R         (- a x\|e x  + d  + a x\|d )
+--R      *
+--R         ROOT
+--R                      4      3 2
+--R                  (16a c - 4a b )
+--R               *
+--R                 +-----------------------------------------------------------+
+--R                 |   2 2 2        2          3           2 2       2     4  2
+--R                 |- a b e  + (- 2a b c + 2a b )d e + (- a c  + 2a b c - b )d
+--R                 |-----------------------------------------------------------
+--R                 |                          7       6 2
+--R                \|                       64a c - 16a b
+--R              + 
+--R                   2       2                  3
+--R                (2a c - a b )e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                              4        3 3
+--R                          (16a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                              2         3          2 2       2     4
+--R                        ((- 4a b c + a b )e + (- 4a c  + 5a b c - b )d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                4        3 3
+--R                          (- 16a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                            2         3        2 2       2     4
+--R                        ((4a b c - a b )e + (4a c  - 5a b c + b )d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               4      3 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                     2 2 2        2          3
+--R                                  - a b e  + (- 2a b c + 2a b )d e
+--R                                + 
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                            2       2                  3
+--R                         (2a c - a b )e + (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                                                     +--------+
+--R                                     2     2     +-+ |   2
+--R                (- 2a b c e + (- 2a c  + 2b c)d)\|d \|e x  + d
+--R              + 
+--R                       2        2     2       2                     2     2   2
+--R              (2a b c e  + (2a c  - 2b c)d e)x  + 2a b c d e + (2a c  - 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R              +--------+
+--R              |   2            +-+
+--R         (a x\|e x  + d  - a x\|d )
+--R      *
+--R         ROOT
+--R                        4      3 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                 +-----------------------------------------------------------+
+--R                 |   2 2 2        2          3           2 2       2     4  2
+--R                 |- a b e  + (- 2a b c + 2a b )d e + (- a c  + 2a b c - b )d
+--R                 |-----------------------------------------------------------
+--R                 |                          7       6 2
+--R                \|                       64a c - 16a b
+--R              + 
+--R                   2       2                  3
+--R                (2a c - a b )e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                              4        3 3
+--R                          (16a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                            2         3        2 2       2     4
+--R                        ((4a b c - a b )e + (4a c  - 5a b c + b )d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                4        3 3
+--R                          (- 16a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                              2         3          2 2       2     4
+--R                        ((- 4a b c + a b )e + (- 4a c  + 5a b c - b )d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 4      3 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                     2 2 2        2          3
+--R                                  - a b e  + (- 2a b c + 2a b )d e
+--R                                + 
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                            2       2                  3
+--R                         (2a c - a b )e + (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                                                     +--------+
+--R                                     2     2     +-+ |   2
+--R                (- 2a b c e + (- 2a c  + 2b c)d)\|d \|e x  + d
+--R              + 
+--R                       2        2     2       2                     2     2   2
+--R              (2a b c e  + (2a c  - 2b c)d e)x  + 2a b c d e + (2a c  - 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +--------+
+--R                |   2            +-+
+--R         (- a x\|e x  + d  + a x\|d )
+--R      *
+--R         ROOT
+--R                        4      3 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                 +-----------------------------------------------------------+
+--R                 |   2 2 2        2          3           2 2       2     4  2
+--R                 |- a b e  + (- 2a b c + 2a b )d e + (- a c  + 2a b c - b )d
+--R                 |-----------------------------------------------------------
+--R                 |                          7       6 2
+--R                \|                       64a c - 16a b
+--R              + 
+--R                   2       2                  3
+--R                (2a c - a b )e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                                4        3 3
+--R                          (- 16a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                              2         3          2 2       2     4
+--R                        ((- 4a b c + a b )e + (- 4a c  + 5a b c - b )d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                              4        3 3
+--R                          (16a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                            2         3        2 2       2     4
+--R                        ((4a b c - a b )e + (4a c  - 5a b c + b )d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 4      3 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                     2 2 2        2          3
+--R                                  - a b e  + (- 2a b c + 2a b )d e
+--R                                + 
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                            2       2                  3
+--R                         (2a c - a b )e + (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                                                     +--------+
+--R                                     2     2     +-+ |   2
+--R                (- 2a b c e + (- 2a c  + 2b c)d)\|d \|e x  + d
+--R              + 
+--R                       2        2     2       2                     2     2   2
+--R              (2a b c e  + (2a c  - 2b c)d e)x  + 2a b c d e + (2a c  - 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R              +--------+
+--R              |   2            +-+
+--R         (a x\|e x  + d  - a x\|d )
+--R      *
+--R         ROOT
+--R                      4      3 2
+--R                  (16a c - 4a b )
+--R               *
+--R                 +-----------------------------------------------------------+
+--R                 |   2 2 2        2          3           2 2       2     4  2
+--R                 |- a b e  + (- 2a b c + 2a b )d e + (- a c  + 2a b c - b )d
+--R                 |-----------------------------------------------------------
+--R                 |                          7       6 2
+--R                \|                       64a c - 16a b
+--R              + 
+--R                   2       2                  3
+--R                (2a c - a b )e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                                4        3 3
+--R                          (- 16a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                            2         3        2 2       2     4
+--R                        ((4a b c - a b )e + (4a c  - 5a b c + b )d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                              4        3 3
+--R                          (16a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                              2         3          2 2       2     4
+--R                        ((- 4a b c + a b )e + (- 4a c  + 5a b c - b )d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               4      3 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                     2 2 2        2          3
+--R                                  - a b e  + (- 2a b c + 2a b )d e
+--R                                + 
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                            2       2                  3
+--R                         (2a c - a b )e + (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                                                     +--------+
+--R                                     2     2     +-+ |   2
+--R                (- 2a b c e + (- 2a c  + 2b c)d)\|d \|e x  + d
+--R              + 
+--R                       2        2     2       2                     2     2   2
+--R              (2a b c e  + (2a c  - 2b c)d e)x  + 2a b c d e + (2a c  - 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R             +--------+
+--R         +-+ |   2            2
+--R       2\|d \|e x  + d  - 2e x  - 2d
+--R  /
+--R          +--------+
+--R          |   2             +-+
+--R     2a x\|e x  + d  - 2a x\|d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3028
+
+--S 3029 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R              |          2  |    |          2
+--R            a\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                         4      3 2
+--R                     (16a c - 4a b )
+--R                  *
+--R                     ROOT
+--R                               2 2 2        2          3
+--R                            - a b e  + (- 2a b c + 2a b )d e
+--R                          + 
+--R                                2 2       2     4  2
+--R                            (- a c  + 2a b c - b )d
+--R                       /
+--R                             7       6 2
+--R                          64a c - 16a b
+--R                 + 
+--R                      2       2                  3
+--R                   (2a c - a b )e + (- 3a b c + b )d
+--R              /
+--R                   4      3 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                 4        3 3
+--R                             (16a b c - 4a b )x
+--R                          *
+--R                             ROOT
+--R                                       2 2 2        2          3
+--R                                    - a b e  + (- 2a b c + 2a b )d e
+--R                                  + 
+--R                                        2 2       2     4  2
+--R                                    (- a c  + 2a b c - b )d
+--R                               /
+--R                                     7       6 2
+--R                                  64a c - 16a b
+--R                         + 
+--R                                 2         3          2 2       2     4
+--R                           ((- 4a b c + a b )e + (- 4a c  + 5a b c - b )d)x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                   4        3 3
+--R                             (- 16a b c + 4a b )x
+--R                          *
+--R                             ROOT
+--R                                       2 2 2        2          3
+--R                                    - a b e  + (- 2a b c + 2a b )d e
+--R                                  + 
+--R                                        2 2       2     4  2
+--R                                    (- a c  + 2a b c - b )d
+--R                               /
+--R                                     7       6 2
+--R                                  64a c - 16a b
+--R                         + 
+--R                               2         3        2 2       2     4
+--R                           ((4a b c - a b )e + (4a c  - 5a b c + b )d)x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                  4      3 2
+--R                              (16a c - 4a b )
+--R                           *
+--R                              ROOT
+--R                                        2 2 2        2          3
+--R                                     - a b e  + (- 2a b c + 2a b )d e
+--R                                   + 
+--R                                         2 2       2     4  2
+--R                                     (- a c  + 2a b c - b )d
+--R                                /
+--R                                      7       6 2
+--R                                   64a c - 16a b
+--R                          + 
+--R                               2       2                  3
+--R                            (2a c - a b )e + (- 3a b c + b )d
+--R                       /
+--R                            4      3 2
+--R                          8a c - 2a b
+--R                 + 
+--R                                                        +--------+
+--R                                        2     2     +-+ |   2
+--R                   (- 2a b c e + (- 2a c  + 2b c)d)\|d \|e x  + d
+--R                 + 
+--R                            2        2     2       2
+--R                   (2a b c e  + (2a c  - 2b c)d e)x  + 2a b c d e
+--R                 + 
+--R                        2     2   2
+--R                   (2a c  - 2b c)d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                         +------------------------------+
+--R           +-----------+ |    +-----------+
+--R           |          2  |    |          2
+--R         a\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        4      3 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                 +-----------------------------------------------------------+
+--R                 |   2 2 2        2          3           2 2       2     4  2
+--R                 |- a b e  + (- 2a b c + 2a b )d e + (- a c  + 2a b c - b )d
+--R                 |-----------------------------------------------------------
+--R                 |                          7       6 2
+--R                \|                       64a c - 16a b
+--R              + 
+--R                   2       2                  3
+--R                (2a c - a b )e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                              4        3 3
+--R                          (16a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                            2         3        2 2       2     4
+--R                        ((4a b c - a b )e + (4a c  - 5a b c + b )d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                4        3 3
+--R                          (- 16a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                              2         3          2 2       2     4
+--R                        ((- 4a b c + a b )e + (- 4a c  + 5a b c - b )d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 4      3 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                     2 2 2        2          3
+--R                                  - a b e  + (- 2a b c + 2a b )d e
+--R                                + 
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                            2       2                  3
+--R                         (2a c - a b )e + (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                                                     +--------+
+--R                                     2     2     +-+ |   2
+--R                (- 2a b c e + (- 2a c  + 2b c)d)\|d \|e x  + d
+--R              + 
+--R                       2        2     2       2                     2     2   2
+--R              (2a b c e  + (2a c  - 2b c)d e)x  + 2a b c d e + (2a c  - 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R              |          2  |    |          2
+--R            a\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                           4      3 2
+--R                     (- 16a c + 4a b )
+--R                  *
+--R                     ROOT
+--R                               2 2 2        2          3
+--R                            - a b e  + (- 2a b c + 2a b )d e
+--R                          + 
+--R                                2 2       2     4  2
+--R                            (- a c  + 2a b c - b )d
+--R                       /
+--R                             7       6 2
+--R                          64a c - 16a b
+--R                 + 
+--R                      2       2                  3
+--R                   (2a c - a b )e + (- 3a b c + b )d
+--R              /
+--R                   4      3 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                   4        3 3
+--R                             (- 16a b c + 4a b )x
+--R                          *
+--R                             ROOT
+--R                                       2 2 2        2          3
+--R                                    - a b e  + (- 2a b c + 2a b )d e
+--R                                  + 
+--R                                        2 2       2     4  2
+--R                                    (- a c  + 2a b c - b )d
+--R                               /
+--R                                     7       6 2
+--R                                  64a c - 16a b
+--R                         + 
+--R                                 2         3          2 2       2     4
+--R                           ((- 4a b c + a b )e + (- 4a c  + 5a b c - b )d)x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                 4        3 3
+--R                             (16a b c - 4a b )x
+--R                          *
+--R                             ROOT
+--R                                       2 2 2        2          3
+--R                                    - a b e  + (- 2a b c + 2a b )d e
+--R                                  + 
+--R                                        2 2       2     4  2
+--R                                    (- a c  + 2a b c - b )d
+--R                               /
+--R                                     7       6 2
+--R                                  64a c - 16a b
+--R                         + 
+--R                               2         3        2 2       2     4
+--R                           ((4a b c - a b )e + (4a c  - 5a b c + b )d)x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                    4      3 2
+--R                              (- 16a c + 4a b )
+--R                           *
+--R                              ROOT
+--R                                        2 2 2        2          3
+--R                                     - a b e  + (- 2a b c + 2a b )d e
+--R                                   + 
+--R                                         2 2       2     4  2
+--R                                     (- a c  + 2a b c - b )d
+--R                                /
+--R                                      7       6 2
+--R                                   64a c - 16a b
+--R                          + 
+--R                               2       2                  3
+--R                            (2a c - a b )e + (- 3a b c + b )d
+--R                       /
+--R                            4      3 2
+--R                          8a c - 2a b
+--R                 + 
+--R                                                        +--------+
+--R                                        2     2     +-+ |   2
+--R                   (- 2a b c e + (- 2a c  + 2b c)d)\|d \|e x  + d
+--R                 + 
+--R                            2        2     2       2
+--R                   (2a b c e  + (2a c  - 2b c)d e)x  + 2a b c d e
+--R                 + 
+--R                        2     2   2
+--R                   (2a c  - 2b c)d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                         +------------------------------+
+--R           +-----------+ |    +-----------+
+--R           |          2  |    |          2
+--R         a\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                      4      3 2
+--R                  (16a c - 4a b )
+--R               *
+--R                 +-----------------------------------------------------------+
+--R                 |   2 2 2        2          3           2 2       2     4  2
+--R                 |- a b e  + (- 2a b c + 2a b )d e + (- a c  + 2a b c - b )d
+--R                 |-----------------------------------------------------------
+--R                 |                          7       6 2
+--R                \|                       64a c - 16a b
+--R              + 
+--R                   2       2                  3
+--R                (2a c - a b )e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                4        3 3
+--R                          (- 16a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                            2         3        2 2       2     4
+--R                        ((4a b c - a b )e + (4a c  - 5a b c + b )d)x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                              4        3 3
+--R                          (16a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                    2 2 2        2          3
+--R                                 - a b e  + (- 2a b c + 2a b )d e
+--R                               + 
+--R                                     2 2       2     4  2
+--R                                 (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                              2         3          2 2       2     4
+--R                        ((- 4a b c + a b )e + (- 4a c  + 5a b c - b )d)x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               4      3 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                     2 2 2        2          3
+--R                                  - a b e  + (- 2a b c + 2a b )d e
+--R                                + 
+--R                                      2 2       2     4  2
+--R                                  (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                            2       2                  3
+--R                         (2a c - a b )e + (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                                                     +--------+
+--R                                     2     2     +-+ |   2
+--R                (- 2a b c e + (- 2a c  + 2b c)d)\|d \|e x  + d
+--R              + 
+--R                       2        2     2       2                     2     2   2
+--R              (2a b c e  + (2a c  - 2b c)d e)x  + 2a b c d e + (2a c  - 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                 +-----------+
+--R                 |          2
+--R         (- 2c d\|- 4a c + b   + 4a c e - 2b c d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                                +------------------+
+--R               +-----------+                    | +-----------+
+--R               |          2                     | |          2
+--R         (2c d\|- 4a c + b   + 4a c e - 2b c d)\|\|- 4a c + b   - b
+--R      *
+--R                                             +------------------------------+
+--R        +----------------------------+       |    +-----------+
+--R        |  +-----------+                     |    |          2
+--R        |  |          2                    x\|- e\|- 4a c + b   - b e + 2c d
+--R       \|e\|- 4a c + b   - b e + 2c d atan(----------------------------------)
+--R                                                        +------------------+
+--R                                             +--------+ | +-----------+
+--R                                             |   2      | |          2
+--R                                            \|e x  + d \|\|- 4a c + b   + b
+--R  /
+--R                        +------------------------------+ +------------------+
+--R          +-----------+ |    +-----------+               | +-----------+
+--R          |          2  |    |          2                | |          2
+--R       2a\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3029
+
+--S 3030 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3030
+
+)clear all
+
+--S 3031 of 3139
+t0:=sqrt(d+e*x^2)/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|e x  + d
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3031
+
+--S 3032 of 3139
+r0:=1/2*e*atanh(sqrt(d+e*x^2)/sqrt(d))/(a*sqrt(d))+(b*d-a*e)*atanh(sqrt(d+_
+   e*x^2)/sqrt(d))/(a^2*sqrt(d))-1/2*sqrt(d+e*x^2)/(a*x^2)-atanh(sqrt(2)*_
+   sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))*sqrt(c)*_
+   (b*d-a*e+(b^2*d-2*a*c*d-a*b*e)/sqrt(b^2-4*a*c))/(a^2*sqrt(2)*_
+   sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))-atanh(sqrt(2)*sqrt(c)*_
+   sqrt(d+e*x^2)/sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*sqrt(c)*(b*d-a*e+_
+   (-b^2*d+2*a*c*d+a*b*e)/sqrt(b^2-4*a*c))/(a^2*sqrt(2)*sqrt(2*c*d-_
+   e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R                        2 |          2                            2    2  +-+
+--R         ((2a e - 2b d)x \|- 4a c + b   + (- 2a b e + (- 4a c + 2b )d)x )\|c
+--R      *
+--R              +----------------------------+
+--R              |  +-----------+
+--R          +-+ |  |          2
+--R         \|d \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                               +--------+
+--R                       +-+ +-+ |   2
+--R                      \|2 \|c \|e x  + d
+--R         atanh(---------------------------------)
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R               \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                          +-----------+
+--R                        2 |          2                        2    2  +-+ +-+
+--R         ((2a e - 2b d)x \|- 4a c + b   + (2a b e + (4a c - 2b )d)x )\|c \|d
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                                    +--------+
+--R                                +-----------+       |   2
+--R                          2 +-+ |          2       \|e x  + d
+--R           (- a e + 2b d)x \|2 \|- 4a c + b  atanh(-----------)
+--R                                                        +-+
+--R                                                       \|d
+--R         + 
+--R                   +-----------+     +--------+
+--R               +-+ |          2  +-+ |   2
+--R           - a\|2 \|- 4a c + b  \|d \|e x  + d
+--R      *
+--R          +------------------------------+ +----------------------------+
+--R          |    +-----------+               |  +-----------+
+--R          |    |          2                |  |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                                   +------------------------------+
+--R                 +-----------+     |    +-----------+
+--R         2 2 +-+ |          2  +-+ |    |          2
+--R       2a x \|2 \|- 4a c + b  \|d \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3032
+
+--S 3033 of 3139
+--a0:=integrate(t0,x)
+--E 3033
+
+--S 3034 of 3139
+--m0:=a0-r0
+--E 3034
+
+--S 3035 of 3139
+--d0:=D(m0,x)
+--E 3035
+
+)clear all
+
+--S 3036 of 3139
+t0:=sqrt(d+e*x^2)/(x^4*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|e x  + d
+--R   (1)  ------------------
+--R           8      6      4
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3036
+
+--S 3037 of 3139
+r0:=-1/3*sqrt(d+e*x^2)/(a*x^3)+2/3*e*sqrt(d+e*x^2)/(a*d*x)+(b*d-a*e)*_
+   sqrt(d+e*x^2)/(a^2*d*x)-c*atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*(b*d-a*e+(b^2*d-2*a*c*d-_
+   a*b*e)/sqrt(b^2-4*a*c))/(a^2*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))*_
+   sqrt(-b+sqrt(b^2-4*a*c)))+c*atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*_
+   (b*d-a*e+(-b^2*d+2*a*c*d+a*b*e)/sqrt(b^2-_
+   4*a*c))/(a^2*sqrt(b+sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                                  +-----------+
+--R                             2  3 |          2
+--R           (3a c d e - 3b c d )x \|- 4a c + b
+--R         + 
+--R                              2     2   2  3
+--R           (3a b c d e + (6a c  - 3b c)d )x
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                               2  3 |          2
+--R           (- 3a c d e + 3b c d )x \|- 4a c + b
+--R         + 
+--R                              2     2   2  3
+--R           (3a b c d e + (6a c  - 3b c)d )x
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                  +-----------+ +--------+
+--R                         2        |          2  |   2
+--R         ((- a e + 3b d)x  - a d)\|- 4a c + b  \|e x  + d
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                             +------------------------------+
+--R               +-----------+ |    +-----------+
+--R         2   3 |          2  |    |          2
+--R       3a d x \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R      +------------------+ +------------------+ +----------------------------+
+--R      | +-----------+      | +-----------+      |  +-----------+
+--R      | |          2       | |          2       |  |          2
+--R     \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3037
+
+--S 3038 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 +--------+
+--R             2     5      2 2 3  |   2             2     5      2 2 3  +-+
+--R         ((3a d e x  + 12a d x )\|e x  + d  + (- 9a d e x  - 12a d x )\|d )
+--R      *
+--R         ROOT
+--R                      6      5 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2     3 4     2 6  2
+--R                         (- 4a b c  + 4a b c - a b )e
+--R                       + 
+--R                              4   3      3 3 2      2 5        7
+--R                         (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  2
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                     3 2     2 2       4        2   2       3     5
+--R                (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                              7 2      6 2      5 4
+--R                          (32a c  - 24a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 3 2 2     2 4       6
+--R                            (- 8a b c  + 6a b c - a b )e
+--R                          + 
+--R                                 3   3      2 3 2       5     7
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                7 2      6 2      5 4
+--R                          (- 32a c  + 24a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               3 2 2     2 4       6
+--R                            (8a b c  - 6a b c + a b )e
+--R                          + 
+--R                               3   3      2 3 2       5     7
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               6      5 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                       4 2 2     3 4     2 6  2
+--R                                  (- 4a b c  + 4a b c - a b )e
+--R                                + 
+--R                                       4   3      3 3 2      2 5        7
+--R                                  (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  2
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                              3 2     2 2       4        2   2       3     5
+--R                         (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        2   3       3 2          2 4       2 3     4 2    +-+
+--R                  ((- 4a b c  + 2a b c )e + (- 2a c  + 6a b c  - 2b c )d)\|d
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                    2   3       3 2  2      2 4       2 3     4 2      2
+--R                ((4a b c  - 2a b c )e  + (2a c  - 6a b c  + 2b c )d e)x
+--R              + 
+--R                   2   3       3 2          2 4       2 3     4 2  2
+--R                (4a b c  - 2a b c )d e + (2a c  - 6a b c  + 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                   +--------+
+--R               2     5      2 2 3  |   2           2     5      2 2 3  +-+
+--R         ((- 3a d e x  - 12a d x )\|e x  + d  + (9a d e x  + 12a d x )\|d )
+--R      *
+--R         ROOT
+--R                        6      5 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2     3 4     2 6  2
+--R                         (- 4a b c  + 4a b c - a b )e
+--R                       + 
+--R                              4   3      3 3 2      2 5        7
+--R                         (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  2
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                     3 2     2 2       4        2   2       3     5
+--R                (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                              7 2      6 2      5 4
+--R                          (32a c  - 24a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               3 2 2     2 4       6
+--R                            (8a b c  - 6a b c + a b )e
+--R                          + 
+--R                               3   3      2 3 2       5     7
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                7 2      6 2      5 4
+--R                          (- 32a c  + 24a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 3 2 2     2 4       6
+--R                            (- 8a b c  + 6a b c - a b )e
+--R                          + 
+--R                                 3   3      2 3 2       5     7
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 6      5 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                       4 2 2     3 4     2 6  2
+--R                                  (- 4a b c  + 4a b c - a b )e
+--R                                + 
+--R                                       4   3      3 3 2      2 5        7
+--R                                  (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  2
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                              3 2     2 2       4        2   2       3     5
+--R                         (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        2   3       3 2          2 4       2 3     4 2    +-+
+--R                  ((- 4a b c  + 2a b c )e + (- 2a c  + 6a b c  - 2b c )d)\|d
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                    2   3       3 2  2      2 4       2 3     4 2      2
+--R                ((4a b c  - 2a b c )e  + (2a c  - 6a b c  + 2b c )d e)x
+--R              + 
+--R                   2   3       3 2          2 4       2 3     4 2  2
+--R                (4a b c  - 2a b c )d e + (2a c  - 6a b c  + 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                 +--------+
+--R             2     5      2 2 3  |   2             2     5      2 2 3  +-+
+--R         ((3a d e x  + 12a d x )\|e x  + d  + (- 9a d e x  - 12a d x )\|d )
+--R      *
+--R         ROOT
+--R                        6      5 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2     3 4     2 6  2
+--R                         (- 4a b c  + 4a b c - a b )e
+--R                       + 
+--R                              4   3      3 3 2      2 5        7
+--R                         (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  2
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                     3 2     2 2       4        2   2       3     5
+--R                (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                                7 2      6 2      5 4
+--R                          (- 32a c  + 24a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 3 2 2     2 4       6
+--R                            (- 8a b c  + 6a b c - a b )e
+--R                          + 
+--R                                 3   3      2 3 2       5     7
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                              7 2      6 2      5 4
+--R                          (32a c  - 24a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               3 2 2     2 4       6
+--R                            (8a b c  - 6a b c + a b )e
+--R                          + 
+--R                               3   3      2 3 2       5     7
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 6      5 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                       4 2 2     3 4     2 6  2
+--R                                  (- 4a b c  + 4a b c - a b )e
+--R                                + 
+--R                                       4   3      3 3 2      2 5        7
+--R                                  (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  2
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                              3 2     2 2       4        2   2       3     5
+--R                         (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        2   3       3 2          2 4       2 3     4 2    +-+
+--R                  ((- 4a b c  + 2a b c )e + (- 2a c  + 6a b c  - 2b c )d)\|d
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                    2   3       3 2  2      2 4       2 3     4 2      2
+--R                ((4a b c  - 2a b c )e  + (2a c  - 6a b c  + 2b c )d e)x
+--R              + 
+--R                   2   3       3 2          2 4       2 3     4 2  2
+--R                (4a b c  - 2a b c )d e + (2a c  - 6a b c  + 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                   +--------+
+--R               2     5      2 2 3  |   2           2     5      2 2 3  +-+
+--R         ((- 3a d e x  - 12a d x )\|e x  + d  + (9a d e x  + 12a d x )\|d )
+--R      *
+--R         ROOT
+--R                      6      5 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2     3 4     2 6  2
+--R                         (- 4a b c  + 4a b c - a b )e
+--R                       + 
+--R                              4   3      3 3 2      2 5        7
+--R                         (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  2
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                     3 2     2 2       4        2   2       3     5
+--R                (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                                7 2      6 2      5 4
+--R                          (- 32a c  + 24a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               3 2 2     2 4       6
+--R                            (8a b c  - 6a b c + a b )e
+--R                          + 
+--R                               3   3      2 3 2       5     7
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                              7 2      6 2      5 4
+--R                          (32a c  - 24a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 3 2 2     2 4       6
+--R                            (- 8a b c  + 6a b c - a b )e
+--R                          + 
+--R                                 3   3      2 3 2       5     7
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               6      5 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                       4 2 2     3 4     2 6  2
+--R                                  (- 4a b c  + 4a b c - a b )e
+--R                                + 
+--R                                       4   3      3 3 2      2 5        7
+--R                                  (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  2
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                              3 2     2 2       4        2   2       3     5
+--R                         (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        2   3       3 2          2 4       2 3     4 2    +-+
+--R                  ((- 4a b c  + 2a b c )e + (- 2a c  + 6a b c  - 2b c )d)\|d
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                    2   3       3 2  2      2 4       2 3     4 2      2
+--R                ((4a b c  - 2a b c )e  + (2a c  - 6a b c  + 2b c )d e)x
+--R              + 
+--R                   2   3       3 2          2 4       2 3     4 2  2
+--R                (4a b c  - 2a b c )d e + (2a c  - 6a b c  + 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                                                +--------+
+--R             2            4                   2  2       2  +-+ |   2
+--R       ((6a e  - 18b d e)x  + (14a d e - 24b d )x  + 8a d )\|d \|e x  + d
+--R     + 
+--R              3         2  6             2        2   4           2         3  2
+--R       (- 2a e  + 6b d e )x  + (- 12a d e  + 30b d e)x  + (- 18a d e + 24b d )x
+--R     + 
+--R             3
+--R       - 8a d
+--R  /
+--R                            +--------+
+--R        2     5      2 2 3  |   2              2     5      2 2 3  +-+
+--R     (6a d e x  + 24a d x )\|e x  + d  + (- 18a d e x  - 24a d x )\|d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3038
+
+--S 3039 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +------------------------------+
+--R            +-----------+ |    +-----------+
+--R          2 |          2  |    |          2
+--R         a \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                      6      5 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2     3 4     2 6  2
+--R                         (- 4a b c  + 4a b c - a b )e
+--R                       + 
+--R                              4   3      3 3 2      2 5        7
+--R                         (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  2
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                     3 2     2 2       4        2   2       3     5
+--R                (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                              7 2      6 2      5 4
+--R                          (32a c  - 24a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 3 2 2     2 4       6
+--R                            (- 8a b c  + 6a b c - a b )e
+--R                          + 
+--R                                 3   3      2 3 2       5     7
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                7 2      6 2      5 4
+--R                          (- 32a c  + 24a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               3 2 2     2 4       6
+--R                            (8a b c  - 6a b c + a b )e
+--R                          + 
+--R                               3   3      2 3 2       5     7
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               6      5 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                       4 2 2     3 4     2 6  2
+--R                                  (- 4a b c  + 4a b c - a b )e
+--R                                + 
+--R                                       4   3      3 3 2      2 5        7
+--R                                  (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  2
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                              3 2     2 2       4        2   2       3     5
+--R                         (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        2   3       3 2          2 4       2 3     4 2    +-+
+--R                  ((- 4a b c  + 2a b c )e + (- 2a c  + 6a b c  - 2b c )d)\|d
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                    2   3       3 2  2      2 4       2 3     4 2      2
+--R                ((4a b c  - 2a b c )e  + (2a c  - 6a b c  + 2b c )d e)x
+--R              + 
+--R                   2   3       3 2          2 4       2 3     4 2  2
+--R                (4a b c  - 2a b c )d e + (2a c  - 6a b c  + 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                             +------------------------------+
+--R               +-----------+ |    +-----------+
+--R             2 |          2  |    |          2
+--R            a \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                           6      5 2
+--R                     (- 16a c + 4a b )
+--R                  *
+--R                     ROOT
+--R                                 4 2 2     3 4     2 6  2
+--R                            (- 4a b c  + 4a b c - a b )e
+--R                          + 
+--R                                 4   3      3 3 2      2 5        7
+--R                            (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                          + 
+--R                                4 4     3 2 3      2 4 2       6     8  2
+--R                            (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                       /
+--R                             11       10 2
+--R                          64a  c - 16a  b
+--R                 + 
+--R                        3 2     2 2       4        2   2       3     5
+--R                   (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                 7 2      6 2      5 4
+--R                             (32a c  - 24a b c + 4a b )x
+--R                          *
+--R                             ROOT
+--R                                         4 2 2     3 4     2 6  2
+--R                                    (- 4a b c  + 4a b c - a b )e
+--R                                  + 
+--R                                         4   3      3 3 2      2 5        7
+--R                                    (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                  + 
+--R                                      4 4     3 2 3      2 4 2       6     8  2
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                               /
+--R                                     11       10 2
+--R                                  64a  c - 16a  b
+--R                         + 
+--R                                  3 2 2     2 4       6
+--R                               (8a b c  - 6a b c + a b )e
+--R                             + 
+--R                                  3   3      2 3 2       5     7
+--R                               (4a b c  - 13a b c  + 7a b c - b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                   7 2      6 2      5 4
+--R                             (- 32a c  + 24a b c - 4a b )x
+--R                          *
+--R                             ROOT
+--R                                         4 2 2     3 4     2 6  2
+--R                                    (- 4a b c  + 4a b c - a b )e
+--R                                  + 
+--R                                         4   3      3 3 2      2 5        7
+--R                                    (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                  + 
+--R                                      4 4     3 2 3      2 4 2       6     8  2
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                               /
+--R                                     11       10 2
+--R                                  64a  c - 16a  b
+--R                         + 
+--R                                    3 2 2     2 4       6
+--R                               (- 8a b c  + 6a b c - a b )e
+--R                             + 
+--R                                    3   3      2 3 2       5     7
+--R                               (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                    6      5 2
+--R                              (- 16a c + 4a b )
+--R                           *
+--R                              ROOT
+--R                                          4 2 2     3 4     2 6  2
+--R                                     (- 4a b c  + 4a b c - a b )e
+--R                                   + 
+--R                                          4   3      3 3 2      2 5        7
+--R                                     (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  2
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                      11       10 2
+--R                                   64a  c - 16a  b
+--R                          + 
+--R                               3 2     2 2       4        2   2       3     5
+--R                          (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R                       /
+--R                            6      5 2
+--R                          8a c - 2a b
+--R                 + 
+--R                           2   3       3 2          2 4       2 3     4 2    +-+
+--R                     ((- 4a b c  + 2a b c )e + (- 2a c  + 6a b c  - 2b c )d)\|d
+--R                  *
+--R                      +--------+
+--R                      |   2
+--R                     \|e x  + d
+--R                 + 
+--R                       2   3       3 2  2      2 4       2 3     4 2      2
+--R                   ((4a b c  - 2a b c )e  + (2a c  - 6a b c  + 2b c )d e)x
+--R                 + 
+--R                      2   3       3 2          2 4       2 3     4 2  2
+--R                   (4a b c  - 2a b c )d e + (2a c  - 6a b c  + 2b c )d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                          +------------------------------+
+--R            +-----------+ |    +-----------+
+--R          2 |          2  |    |          2
+--R         a \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        6      5 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                              4 2 2     3 4     2 6  2
+--R                         (- 4a b c  + 4a b c - a b )e
+--R                       + 
+--R                              4   3      3 3 2      2 5        7
+--R                         (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  2
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                     3 2     2 2       4        2   2       3     5
+--R                (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                7 2      6 2      5 4
+--R                          (- 32a c  + 24a b c - 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 3 2 2     2 4       6
+--R                            (- 8a b c  + 6a b c - a b )e
+--R                          + 
+--R                                 3   3      2 3 2       5     7
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                              7 2      6 2      5 4
+--R                          (32a c  - 24a b c + 4a b )x
+--R                       *
+--R                          ROOT
+--R                                      4 2 2     3 4     2 6  2
+--R                                 (- 4a b c  + 4a b c - a b )e
+--R                               + 
+--R                                      4   3      3 3 2      2 5        7
+--R                                 (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  2
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               3 2 2     2 4       6
+--R                            (8a b c  - 6a b c + a b )e
+--R                          + 
+--R                               3   3      2 3 2       5     7
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 6      5 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                       4 2 2     3 4     2 6  2
+--R                                  (- 4a b c  + 4a b c - a b )e
+--R                                + 
+--R                                       4   3      3 3 2      2 5        7
+--R                                  (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  2
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                              3 2     2 2       4        2   2       3     5
+--R                         (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        2   3       3 2          2 4       2 3     4 2    +-+
+--R                  ((- 4a b c  + 2a b c )e + (- 2a c  + 6a b c  - 2b c )d)\|d
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                    2   3       3 2  2      2 4       2 3     4 2      2
+--R                ((4a b c  - 2a b c )e  + (2a c  - 6a b c  + 2b c )d e)x
+--R              + 
+--R                   2   3       3 2          2 4       2 3     4 2  2
+--R                (4a b c  - 2a b c )d e + (2a c  - 6a b c  + 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                             +------------------------------+
+--R               +-----------+ |    +-----------+
+--R             2 |          2  |    |          2
+--R            a \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                         6      5 2
+--R                     (16a c - 4a b )
+--R                  *
+--R                     ROOT
+--R                                 4 2 2     3 4     2 6  2
+--R                            (- 4a b c  + 4a b c - a b )e
+--R                          + 
+--R                                 4   3      3 3 2      2 5        7
+--R                            (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                          + 
+--R                                4 4     3 2 3      2 4 2       6     8  2
+--R                            (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                       /
+--R                             11       10 2
+--R                          64a  c - 16a  b
+--R                 + 
+--R                        3 2     2 2       4        2   2       3     5
+--R                   (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                   7 2      6 2      5 4
+--R                             (- 32a c  + 24a b c - 4a b )x
+--R                          *
+--R                             ROOT
+--R                                         4 2 2     3 4     2 6  2
+--R                                    (- 4a b c  + 4a b c - a b )e
+--R                                  + 
+--R                                         4   3      3 3 2      2 5        7
+--R                                    (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                  + 
+--R                                      4 4     3 2 3      2 4 2       6     8  2
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                               /
+--R                                     11       10 2
+--R                                  64a  c - 16a  b
+--R                         + 
+--R                                  3 2 2     2 4       6
+--R                               (8a b c  - 6a b c + a b )e
+--R                             + 
+--R                                  3   3      2 3 2       5     7
+--R                               (4a b c  - 13a b c  + 7a b c - b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                 7 2      6 2      5 4
+--R                             (32a c  - 24a b c + 4a b )x
+--R                          *
+--R                             ROOT
+--R                                         4 2 2     3 4     2 6  2
+--R                                    (- 4a b c  + 4a b c - a b )e
+--R                                  + 
+--R                                         4   3      3 3 2      2 5        7
+--R                                    (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                  + 
+--R                                      4 4     3 2 3      2 4 2       6     8  2
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                               /
+--R                                     11       10 2
+--R                                  64a  c - 16a  b
+--R                         + 
+--R                                    3 2 2     2 4       6
+--R                               (- 8a b c  + 6a b c - a b )e
+--R                             + 
+--R                                    3   3      2 3 2       5     7
+--R                               (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                  6      5 2
+--R                              (16a c - 4a b )
+--R                           *
+--R                              ROOT
+--R                                          4 2 2     3 4     2 6  2
+--R                                     (- 4a b c  + 4a b c - a b )e
+--R                                   + 
+--R                                          4   3      3 3 2      2 5        7
+--R                                     (- 4a b c  + 14a b c  - 10a b c + 2a b )d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  2
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                      11       10 2
+--R                                   64a  c - 16a  b
+--R                          + 
+--R                               3 2     2 2       4        2   2       3     5
+--R                          (- 2a c  + 4a b c - a b )e + (5a b c  - 5a b c + b )d
+--R                       /
+--R                            6      5 2
+--R                          8a c - 2a b
+--R                 + 
+--R                           2   3       3 2          2 4       2 3     4 2    +-+
+--R                     ((- 4a b c  + 2a b c )e + (- 2a c  + 6a b c  - 2b c )d)\|d
+--R                  *
+--R                      +--------+
+--R                      |   2
+--R                     \|e x  + d
+--R                 + 
+--R                       2   3       3 2  2      2 4       2 3     4 2      2
+--R                   ((4a b c  - 2a b c )e  + (2a c  - 6a b c  + 2b c )d e)x
+--R                 + 
+--R                      2   3       3 2          2 4       2 3     4 2  2
+--R                   (4a b c  - 2a b c )d e + (2a c  - 6a b c  + 2b c )d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                              +-----------+
+--R                              |          2                      2     2
+--R         ((- 2a c e + 2b c d)\|- 4a c + b   - 2a b c e + (- 4a c  + 2b c)d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R                            |          2                      2     2
+--R         ((2a c e - 2b c d)\|- 4a c + b   - 2a b c e + (- 4a c  + 2b c)d)
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R  /
+--R                         +------------------------------+ +------------------+
+--R           +-----------+ |    +-----------+               | +-----------+
+--R         2 |          2  |    |          2                | |          2
+--R       2a \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3039
+
+--S 3040 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3040
+
+)clear all
+
+--S 3041 of 3139
+t0:=x^4*(d+e*x^2)^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                      +--------+
+--R            6      4  |   2
+--R        (e x  + d x )\|e x  + d
+--R   (1)  ------------------------
+--R                4      2
+--R             c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3041
+
+--S 3042 of 3139
+r0:=1/4*x*(d+e*x^2)^(3/2)/c+1/8*d*(3*c*d-4*b*e)*atanh(x*sqrt(e)/_
+   sqrt(d+e*x^2))/(c^2*sqrt(e))-1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*_
+   (b*c*d-b^2*e+a*c*e+(-b^2*c*d+2*a*c^2*d+b^3*e-3*a*b*c*e)/_
+   sqrt(b^2-4*a*c))*sqrt(e)/c^3-1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*_
+   (b*c*d-b^2*e+a*c*e+(b^2*c*d-2*a*c^2*d-b^3*e+3*a*b*c*e)/_
+   sqrt(b^2-4*a*c))*sqrt(e)/c^3+1/8*(3*c*d-4*b*e)*x*sqrt(d+e*x^2)/c^2+_
+   1/2*atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*_
+   sqrt(-b+sqrt(b^2-4*a*c))))*(b*c*d-b^2*e+a*c*e+(-b^2*c*d+2*a*c^2*d+_
+   b^3*e-3*a*b*c*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (c^3*sqrt(-b+sqrt(b^2-4*a*c)))-1/2*atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-_
+   4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(b*c*d-b^2*e+_
+   a*c*e+(b^2*c*d-2*a*c^2*d-b^3*e+3*a*b*c*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-_
+   e*(b+sqrt(b^2-4*a*c)))/(c^3*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                    +-----------+
+--R                      2             |          2                   3
+--R           ((4a c - 4b )e + 4b c d)\|- 4a c + b   + (- 12a b c + 4b )e
+--R         + 
+--R                2     2
+--R           (8a c  - 4b c)d
+--R      *
+--R              +------------------+ +----------------------------+
+--R              | +-----------+      |  +-----------+
+--R          +-+ | |          2       |  |          2
+--R         \|e \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                      +-----------+
+--R                        2             |          2                   3
+--R           ((- 4a c + 4b )e - 4b c d)\|- 4a c + b   + (- 12a b c + 4b )e
+--R         + 
+--R                2     2
+--R           (8a c  - 4b c)d
+--R      *
+--R              +------------------------------+ +------------------+
+--R              |    +-----------+               | +-----------+
+--R          +-+ |    |          2                | |          2
+--R         \|e \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                                    +-----------+
+--R                          2  2                 2 2  |          2
+--R             ((- 8a c + 8b )e  - 12b c d e + 3c d )\|- 4a c + b
+--R          *
+--R                        +-+
+--R                      x\|e
+--R             atanh(-----------)
+--R                    +--------+
+--R                    |   2
+--R                   \|e x  + d
+--R         + 
+--R                                          +-----------+     +--------+
+--R              2   3                 2     |          2  +-+ |   2
+--R           (2c e x  + (- 4b c e + 5c d)x)\|- 4a c + b  \|e \|e x  + d
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R  /
+--R                           +------------------+ +------------------+
+--R         +-----------+     | +-----------+      | +-----------+
+--R       3 |          2  +-+ | |          2       | |          2
+--R     8c \|- 4a c + b  \|e \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3042
+
+--S 3043 of 3139
+--a0:=integrate(t0,x)
+--E 3043
+
+--S 3044 of 3139
+--m0:=a0-r0
+--E 3044
+
+--S 3045 of 3139
+--d0:=D(m0,x)
+--E 3045
+
+)clear all
+
+--S 3046 of 3139
+t0:=x^3*(d+e*x^2)^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                      +--------+
+--R            5      3  |   2
+--R        (e x  + d x )\|e x  + d
+--R   (1)  ------------------------
+--R                4      2
+--R             c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3046
+
+--S 3047 of 3139
+r0:=1/3*(d+e*x^2)^(3/2)/c+(c*d-b*e)*sqrt(d+e*x^2)/c^2-atanh(sqrt(2)*_
+   sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))*(c^2*d^2+_
+   b^2*e^2-c*e*(2*b*d+a*e)+(2*b^2*c*d*e-4*a*c^2*d*e-b^3*e^2-b*c*(c*d^2-_
+   3*a*e^2))/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(2*c*d-e*(b-sqrt(b^2-_
+   4*a*c))))-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b+_
+   sqrt(b^2-4*a*c))))*(c^2*d^2+b^2*e^2-c*e*(2*b*d+a*e)+(-2*b^2*c*d*e+_
+   4*a*c^2*d*e+b^3*e^2+b*c*(c*d^2-3*a*e^2))/sqrt(b^2-4*a*c))/(c^(5/2)*_
+   sqrt(2)*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                                               +-----------+
+--R                      2  2                2 2  |          2                3  2
+--R           ((3a c - 3b )e  + 6b c d e - 3c d )\|- 4a c + b   + (9a b c - 3b )e
+--R         + 
+--R                   2     2            2 2
+--R           (- 12a c  + 6b c)d e - 3b c d
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                               +-----------+
+--R                      2  2                2 2  |          2
+--R           ((3a c - 3b )e  + 6b c d e - 3c d )\|- 4a c + b
+--R         + 
+--R                         3  2         2     2            2 2
+--R           (- 9a b c + 3b )e  + (12a c  - 6b c)d e + 3b c d
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                    +-----------+     +--------+
+--R               2                +-+ |          2  +-+ |   2
+--R         (c e x  - 3b e + 4c d)\|2 \|- 4a c + b  \|c \|e x  + d
+--R      *
+--R          +------------------------------+ +----------------------------+
+--R          |    +-----------+               |  +-----------+
+--R          |    |          2                |  |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                                 +------------------------------+
+--R               +-----------+     |    +-----------+
+--R         2 +-+ |          2  +-+ |    |          2
+--R       3c \|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3047
+
+--S 3048 of 3139
+--a0:=integrate(t0,x)
+--E 3048
+
+--S 3049 of 3139
+--m0:=a0-r0
+--E 3049
+
+--S 3050 of 3139
+--d0:=D(m0,x)
+--E 3050
+
+)clear all
+
+--S 3051 of 3139
+t0:=x^2*(d+e*x^2)^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                      +--------+
+--R            4      2  |   2
+--R        (e x  + d x )\|e x  + d
+--R   (1)  ------------------------
+--R                4      2
+--R             c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3051
+
+--S 3052 of 3139
+r0:=1/2*d*atanh(x*sqrt(e)/sqrt(d+e*x^2))*sqrt(e)/c+1/2*atanh(x*sqrt(e)/_
+   sqrt(d+e*x^2))*(c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))*_
+   sqrt(e)/c^2+1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*(c*d-b*e+(b*c*d-b^2*e+_
+   2*a*c*e)/sqrt(b^2-4*a*c))*sqrt(e)/c^2+1/2*e*x*sqrt(d+e*x^2)/c-_
+   1/2*atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*_
+   sqrt(-b+sqrt(b^2-4*a*c))))*(c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/_
+   sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(c^2*sqrt(-b+_
+   sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(c*d-b*e+(b*c*d-b^2*e+_
+   2*a*c*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(c^2*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                            +------------------+
+--R                      +-----------+                         | +-----------+
+--R                      |          2             2            | |          2
+--R         ((b e - c d)\|- 4a c + b   + (2a c - b )e + b c d)\|\|- 4a c + b   + b
+--R      *
+--R                                                +----------------------------+
+--R          +----------------------------+        |  +-----------+
+--R          |  +-----------+                      |  |          2
+--R          |  |          2                     x\|e\|- 4a c + b   - b e + 2c d
+--R         \|e\|- 4a c + b   - b e + 2c d atanh(--------------------------------)
+--R                                                          +------------------+
+--R                                               +--------+ | +-----------+
+--R                                               |   2      | |          2
+--R                                              \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                        |          2             2
+--R         ((- b e + c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                           +-----------+               +-+
+--R                           |          2  +-+         x\|e
+--R           (- 2b e + 3c d)\|- 4a c + b  \|e atanh(-----------)
+--R                                                   +--------+
+--R                                                   |   2
+--R                                                  \|e x  + d
+--R         + 
+--R                 +-----------+ +--------+
+--R                 |          2  |   2
+--R           c e x\|- 4a c + b  \|e x  + d
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R  /
+--R                       +------------------+ +------------------+
+--R         +-----------+ | +-----------+      | +-----------+
+--R       2 |          2  | |          2       | |          2
+--R     2c \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3052
+
+--S 3053 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      +--------+
+--R                2 +-+ |   2         2   2     2
+--R           (- 2c \|d \|e x  + d  + c e x  + 2c d)
+--R        *
+--R           ROOT
+--R                          5     2 4
+--R                    (16a c  - 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  6
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                               2   3        3 2     5     5
+--R                           (12a b c  - 18a b c  + 6b c)d e
+--R                         + 
+--R                                2 4        2 3      4 2  2 4
+--R                           (- 9a c  + 30a b c  - 15b c )d e
+--R                         + 
+--R                                     4      3 3  3 3        5      2 4  4 2
+--R                           (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                         + 
+--R                               5 5     6 6
+--R                           6b c d e - c d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4  3            2     3     2
+--R                  (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                + 
+--R                       3     2 2  2       3 3
+--R                  (6a c  - 3b c )d e + b c d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                 2 6        2 5     4 4             6     3 5
+--R                            ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6  4
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                  2   3        3 2     5     3
+--R                              (20a b c  - 21a b c  + 4b c)d e
+--R                            + 
+--R                                    2 4        2 3     4 2  2 2
+--R                              (- 12a c  + 27a b c  - 6b c )d e
+--R                            + 
+--R                                        4     3 3  3         5    2 4  4
+--R                              (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6  4
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                    2   3        3 2     5     3
+--R                              (- 20a b c  + 21a b c  - 4b c)d e
+--R                            + 
+--R                                  2 4        2 3     4 2  2 2
+--R                              (12a c  - 27a b c  + 6b c )d e
+--R                            + 
+--R                                      4     3 3  3           5    2 4  4
+--R                              (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                   5     2 4
+--R                             (16a c  - 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4  3            2     3     2
+--R                           (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                         + 
+--R                                3     2 2  2       3 3
+--R                           (6a c  - 3b c )d e + b c d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                           3        2 3  5      3 2     2 2        4    4
+--R                      (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                    + 
+--R                           2   2       3   2 3      2 3        2 2  3 2
+--R                      (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                    + 
+--R                            3 4        4 5
+--R                      8a b c d e - 2a c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                         3        2 3  6        3 2     2 2        4    5
+--R                      (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                    + 
+--R                         2   2       3   2 4        2 3        2 2  3 3
+--R                      (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                    + 
+--R                              3 4 2       4 5
+--R                      - 8a b c d e  + 2a c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                     3        2 3    5        3 2     2 2        4  2 4
+--R                  (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                + 
+--R                     2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                  (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R                + 
+--R                      4 6
+--R                  2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                    +--------+
+--R              2 +-+ |   2         2   2     2
+--R           (2c \|d \|e x  + d  - c e x  - 2c d)
+--R        *
+--R           ROOT
+--R                            5     2 4
+--R                    (- 16a c  + 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  6
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                               2   3        3 2     5     5
+--R                           (12a b c  - 18a b c  + 6b c)d e
+--R                         + 
+--R                                2 4        2 3      4 2  2 4
+--R                           (- 9a c  + 30a b c  - 15b c )d e
+--R                         + 
+--R                                     4      3 3  3 3        5      2 4  4 2
+--R                           (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                         + 
+--R                               5 5     6 6
+--R                           6b c d e - c d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4  3            2     3     2
+--R                  (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                + 
+--R                       3     2 2  2       3 3
+--R                  (6a c  - 3b c )d e + b c d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                 2 6        2 5     4 4             6     3 5
+--R                            ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6  4
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                    2   3        3 2     5     3
+--R                              (- 20a b c  + 21a b c  - 4b c)d e
+--R                            + 
+--R                                  2 4        2 3     4 2  2 2
+--R                              (12a c  - 27a b c  + 6b c )d e
+--R                            + 
+--R                                      4     3 3  3           5    2 4  4
+--R                              (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6  4
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                  2   3        3 2     5     3
+--R                              (20a b c  - 21a b c  + 4b c)d e
+--R                            + 
+--R                                    2 4        2 3     4 2  2 2
+--R                              (- 12a c  + 27a b c  - 6b c )d e
+--R                            + 
+--R                                        4     3 3  3         5    2 4  4
+--R                              (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                     5     2 4
+--R                             (- 16a c  + 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4  3            2     3     2
+--R                           (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                         + 
+--R                                3     2 2  2       3 3
+--R                           (6a c  - 3b c )d e + b c d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                           3        2 3  5      3 2     2 2        4    4
+--R                      (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                    + 
+--R                           2   2       3   2 3      2 3        2 2  3 2
+--R                      (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                    + 
+--R                            3 4        4 5
+--R                      8a b c d e - 2a c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                         3        2 3  6        3 2     2 2        4    5
+--R                      (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                    + 
+--R                         2   2       3   2 4        2 3        2 2  3 3
+--R                      (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                    + 
+--R                              3 4 2       4 5
+--R                      - 8a b c d e  + 2a c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                     3        2 3    5        3 2     2 2        4  2 4
+--R                  (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                + 
+--R                     2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                  (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R                + 
+--R                      4 6
+--R                  2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                      +--------+
+--R                2 +-+ |   2         2   2     2
+--R           (- 2c \|d \|e x  + d  + c e x  + 2c d)
+--R        *
+--R           ROOT
+--R                            5     2 4
+--R                    (- 16a c  + 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  6
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                               2   3        3 2     5     5
+--R                           (12a b c  - 18a b c  + 6b c)d e
+--R                         + 
+--R                                2 4        2 3      4 2  2 4
+--R                           (- 9a c  + 30a b c  - 15b c )d e
+--R                         + 
+--R                                     4      3 3  3 3        5      2 4  4 2
+--R                           (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                         + 
+--R                               5 5     6 6
+--R                           6b c d e - c d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4  3            2     3     2
+--R                  (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                + 
+--R                       3     2 2  2       3 3
+--R                  (6a c  - 3b c )d e + b c d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6  4
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                  2   3        3 2     5     3
+--R                              (20a b c  - 21a b c  + 4b c)d e
+--R                            + 
+--R                                    2 4        2 3     4 2  2 2
+--R                              (- 12a c  + 27a b c  - 6b c )d e
+--R                            + 
+--R                                        4     3 3  3         5    2 4  4
+--R                              (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                 2 6        2 5     4 4             6     3 5
+--R                            ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6  4
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                    2   3        3 2     5     3
+--R                              (- 20a b c  + 21a b c  - 4b c)d e
+--R                            + 
+--R                                  2 4        2 3     4 2  2 2
+--R                              (12a c  - 27a b c  + 6b c )d e
+--R                            + 
+--R                                      4     3 3  3           5    2 4  4
+--R                              (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                     5     2 4
+--R                             (- 16a c  + 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4  3            2     3     2
+--R                           (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                         + 
+--R                                3     2 2  2       3 3
+--R                           (6a c  - 3b c )d e + b c d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                           3        2 3  5      3 2     2 2        4    4
+--R                      (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                    + 
+--R                           2   2       3   2 3      2 3        2 2  3 2
+--R                      (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                    + 
+--R                            3 4        4 5
+--R                      8a b c d e - 2a c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                         3        2 3  6        3 2     2 2        4    5
+--R                      (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                    + 
+--R                         2   2       3   2 4        2 3        2 2  3 3
+--R                      (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                    + 
+--R                              3 4 2       4 5
+--R                      - 8a b c d e  + 2a c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                     3        2 3    5        3 2     2 2        4  2 4
+--R                  (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                + 
+--R                     2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                  (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R                + 
+--R                      4 6
+--R                  2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                    +--------+
+--R              2 +-+ |   2         2   2     2
+--R           (2c \|d \|e x  + d  - c e x  - 2c d)
+--R        *
+--R           ROOT
+--R                          5     2 4
+--R                    (16a c  - 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  6
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                               2   3        3 2     5     5
+--R                           (12a b c  - 18a b c  + 6b c)d e
+--R                         + 
+--R                                2 4        2 3      4 2  2 4
+--R                           (- 9a c  + 30a b c  - 15b c )d e
+--R                         + 
+--R                                     4      3 3  3 3        5      2 4  4 2
+--R                           (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                         + 
+--R                               5 5     6 6
+--R                           6b c d e - c d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4  3            2     3     2
+--R                  (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                + 
+--R                       3     2 2  2       3 3
+--R                  (6a c  - 3b c )d e + b c d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6  4
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                    2   3        3 2     5     3
+--R                              (- 20a b c  + 21a b c  - 4b c)d e
+--R                            + 
+--R                                  2 4        2 3     4 2  2 2
+--R                              (12a c  - 27a b c  + 6b c )d e
+--R                            + 
+--R                                      4     3 3  3           5    2 4  4
+--R                              (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                 2 6        2 5     4 4             6     3 5
+--R                            ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6  4
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                  2   3        3 2     5     3
+--R                              (20a b c  - 21a b c  + 4b c)d e
+--R                            + 
+--R                                    2 4        2 3     4 2  2 2
+--R                              (- 12a c  + 27a b c  - 6b c )d e
+--R                            + 
+--R                                        4     3 3  3         5    2 4  4
+--R                              (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                   5     2 4
+--R                             (16a c  - 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4  3            2     3     2
+--R                           (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                         + 
+--R                                3     2 2  2       3 3
+--R                           (6a c  - 3b c )d e + b c d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                           3        2 3  5      3 2     2 2        4    4
+--R                      (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                    + 
+--R                           2   2       3   2 3      2 3        2 2  3 2
+--R                      (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                    + 
+--R                            3 4        4 5
+--R                      8a b c d e - 2a c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                         3        2 3  6        3 2     2 2        4    5
+--R                      (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                    + 
+--R                         2   2       3   2 4        2 3        2 2  3 3
+--R                      (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                    + 
+--R                              3 4 2       4 5
+--R                      - 8a b c d e  + 2a c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                     3        2 3    5        3 2     2 2        4  2 4
+--R                  (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                + 
+--R                     2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                  (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R                + 
+--R                      4 6
+--R                  2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                                   +--------+
+--R                           +-+ +-+ |   2
+--R             (4b e - 6c d)\|d \|e \|e x  + d
+--R           + 
+--R                     2           2                2  +-+
+--R             ((- 2b e  + 3c d e)x  - 4b d e + 6c d )\|e
+--R        *
+--R                              +--------+
+--R                  +-+    +-+  |   2          +-+ +-+      2
+--R               (x\|e  + \|d )\|e x  + d  - x\|d \|e  - e x  - d
+--R           log(------------------------------------------------)
+--R                                   +--------+
+--R                               +-+ |   2
+--R                              \|d \|e x  + d  - d
+--R       + 
+--R                               +--------+
+--R               2 3             |   2             2 3             +-+
+--R         (- c e x  - 2c d e x)\|e x  + d  + (2c e x  + 2c d e x)\|d
+--R    /
+--R               +--------+
+--R         2 +-+ |   2          2   2     2
+--R       4c \|d \|e x  + d  - 2c e x  - 4c d
+--R     ,
+--R
+--R                      +--------+
+--R                2 +-+ |   2         2   2     2
+--R           (- 2c \|d \|e x  + d  + c e x  + 2c d)
+--R        *
+--R           ROOT
+--R                          5     2 4
+--R                    (16a c  - 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  6
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                               2   3        3 2     5     5
+--R                           (12a b c  - 18a b c  + 6b c)d e
+--R                         + 
+--R                                2 4        2 3      4 2  2 4
+--R                           (- 9a c  + 30a b c  - 15b c )d e
+--R                         + 
+--R                                     4      3 3  3 3        5      2 4  4 2
+--R                           (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                         + 
+--R                               5 5     6 6
+--R                           6b c d e - c d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4  3            2     3     2
+--R                  (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                + 
+--R                       3     2 2  2       3 3
+--R                  (6a c  - 3b c )d e + b c d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                 2 6        2 5     4 4             6     3 5
+--R                            ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6  4
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                  2   3        3 2     5     3
+--R                              (20a b c  - 21a b c  + 4b c)d e
+--R                            + 
+--R                                    2 4        2 3     4 2  2 2
+--R                              (- 12a c  + 27a b c  - 6b c )d e
+--R                            + 
+--R                                        4     3 3  3         5    2 4  4
+--R                              (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6  4
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                    2   3        3 2     5     3
+--R                              (- 20a b c  + 21a b c  - 4b c)d e
+--R                            + 
+--R                                  2 4        2 3     4 2  2 2
+--R                              (12a c  - 27a b c  + 6b c )d e
+--R                            + 
+--R                                      4     3 3  3           5    2 4  4
+--R                              (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                   5     2 4
+--R                             (16a c  - 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4  3            2     3     2
+--R                           (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                         + 
+--R                                3     2 2  2       3 3
+--R                           (6a c  - 3b c )d e + b c d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                           3        2 3  5      3 2     2 2        4    4
+--R                      (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                    + 
+--R                           2   2       3   2 3      2 3        2 2  3 2
+--R                      (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                    + 
+--R                            3 4        4 5
+--R                      8a b c d e - 2a c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                         3        2 3  6        3 2     2 2        4    5
+--R                      (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                    + 
+--R                         2   2       3   2 4        2 3        2 2  3 3
+--R                      (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                    + 
+--R                              3 4 2       4 5
+--R                      - 8a b c d e  + 2a c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                     3        2 3    5        3 2     2 2        4  2 4
+--R                  (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                + 
+--R                     2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                  (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R                + 
+--R                      4 6
+--R                  2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                    +--------+
+--R              2 +-+ |   2         2   2     2
+--R           (2c \|d \|e x  + d  - c e x  - 2c d)
+--R        *
+--R           ROOT
+--R                            5     2 4
+--R                    (- 16a c  + 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  6
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                               2   3        3 2     5     5
+--R                           (12a b c  - 18a b c  + 6b c)d e
+--R                         + 
+--R                                2 4        2 3      4 2  2 4
+--R                           (- 9a c  + 30a b c  - 15b c )d e
+--R                         + 
+--R                                     4      3 3  3 3        5      2 4  4 2
+--R                           (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                         + 
+--R                               5 5     6 6
+--R                           6b c d e - c d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4  3            2     3     2
+--R                  (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                + 
+--R                       3     2 2  2       3 3
+--R                  (6a c  - 3b c )d e + b c d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                 2 6        2 5     4 4             6     3 5
+--R                            ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6  4
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                    2   3        3 2     5     3
+--R                              (- 20a b c  + 21a b c  - 4b c)d e
+--R                            + 
+--R                                  2 4        2 3     4 2  2 2
+--R                              (12a c  - 27a b c  + 6b c )d e
+--R                            + 
+--R                                      4     3 3  3           5    2 4  4
+--R                              (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6  4
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                  2   3        3 2     5     3
+--R                              (20a b c  - 21a b c  + 4b c)d e
+--R                            + 
+--R                                    2 4        2 3     4 2  2 2
+--R                              (- 12a c  + 27a b c  - 6b c )d e
+--R                            + 
+--R                                        4     3 3  3         5    2 4  4
+--R                              (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                     5     2 4
+--R                             (- 16a c  + 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4  3            2     3     2
+--R                           (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                         + 
+--R                                3     2 2  2       3 3
+--R                           (6a c  - 3b c )d e + b c d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                           3        2 3  5      3 2     2 2        4    4
+--R                      (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                    + 
+--R                           2   2       3   2 3      2 3        2 2  3 2
+--R                      (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                    + 
+--R                            3 4        4 5
+--R                      8a b c d e - 2a c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                         3        2 3  6        3 2     2 2        4    5
+--R                      (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                    + 
+--R                         2   2       3   2 4        2 3        2 2  3 3
+--R                      (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                    + 
+--R                              3 4 2       4 5
+--R                      - 8a b c d e  + 2a c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                     3        2 3    5        3 2     2 2        4  2 4
+--R                  (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                + 
+--R                     2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                  (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R                + 
+--R                      4 6
+--R                  2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                      +--------+
+--R                2 +-+ |   2         2   2     2
+--R           (- 2c \|d \|e x  + d  + c e x  + 2c d)
+--R        *
+--R           ROOT
+--R                            5     2 4
+--R                    (- 16a c  + 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  6
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                               2   3        3 2     5     5
+--R                           (12a b c  - 18a b c  + 6b c)d e
+--R                         + 
+--R                                2 4        2 3      4 2  2 4
+--R                           (- 9a c  + 30a b c  - 15b c )d e
+--R                         + 
+--R                                     4      3 3  3 3        5      2 4  4 2
+--R                           (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                         + 
+--R                               5 5     6 6
+--R                           6b c d e - c d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4  3            2     3     2
+--R                  (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                + 
+--R                       3     2 2  2       3 3
+--R                  (6a c  - 3b c )d e + b c d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6  4
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                  2   3        3 2     5     3
+--R                              (20a b c  - 21a b c  + 4b c)d e
+--R                            + 
+--R                                    2 4        2 3     4 2  2 2
+--R                              (- 12a c  + 27a b c  - 6b c )d e
+--R                            + 
+--R                                        4     3 3  3         5    2 4  4
+--R                              (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                 2 6        2 5     4 4             6     3 5
+--R                            ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6  4
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                    2   3        3 2     5     3
+--R                              (- 20a b c  + 21a b c  - 4b c)d e
+--R                            + 
+--R                                  2 4        2 3     4 2  2 2
+--R                              (12a c  - 27a b c  + 6b c )d e
+--R                            + 
+--R                                      4     3 3  3           5    2 4  4
+--R                              (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                     5     2 4
+--R                             (- 16a c  + 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4  3            2     3     2
+--R                           (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                         + 
+--R                                3     2 2  2       3 3
+--R                           (6a c  - 3b c )d e + b c d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                           3        2 3  5      3 2     2 2        4    4
+--R                      (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                    + 
+--R                           2   2       3   2 3      2 3        2 2  3 2
+--R                      (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                    + 
+--R                            3 4        4 5
+--R                      8a b c d e - 2a c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                         3        2 3  6        3 2     2 2        4    5
+--R                      (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                    + 
+--R                         2   2       3   2 4        2 3        2 2  3 3
+--R                      (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                    + 
+--R                              3 4 2       4 5
+--R                      - 8a b c d e  + 2a c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                     3        2 3    5        3 2     2 2        4  2 4
+--R                  (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                + 
+--R                     2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                  (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R                + 
+--R                      4 6
+--R                  2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                    +--------+
+--R              2 +-+ |   2         2   2     2
+--R           (2c \|d \|e x  + d  - c e x  - 2c d)
+--R        *
+--R           ROOT
+--R                          5     2 4
+--R                    (16a c  - 4b c )
+--R                 *
+--R                    ROOT
+--R                                2 2 2       4     6  6
+--R                           (- 4a b c  + 4a b c - b )e
+--R                         + 
+--R                               2   3        3 2     5     5
+--R                           (12a b c  - 18a b c  + 6b c)d e
+--R                         + 
+--R                                2 4        2 3      4 2  2 4
+--R                           (- 9a c  + 30a b c  - 15b c )d e
+--R                         + 
+--R                                     4      3 3  3 3        5      2 4  4 2
+--R                           (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                         + 
+--R                               5 5     6 6
+--R                           6b c d e - c d
+--R                      /
+--R                              9      2 8
+--R                         64a c  - 16b c
+--R                + 
+--R                       2 2       2     4  3            2     3     2
+--R                  (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                + 
+--R                       3     2 2  2       3 3
+--R                  (6a c  - 3b c )d e + b c d
+--R             /
+--R                    5     2 4
+--R                8a c  - 2b c
+--R        *
+--R           log
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                 2 2 2       4     6  4
+--R                              (8a b c  - 6a b c + b )e
+--R                            + 
+--R                                    2   3        3 2     5     3
+--R                              (- 20a b c  + 21a b c  - 4b c)d e
+--R                            + 
+--R                                  2 4        2 3     4 2  2 2
+--R                              (12a c  - 27a b c  + 6b c )d e
+--R                            + 
+--R                                      4     3 3  3           5    2 4  4
+--R                              (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                 2 6        2 5     4 4             6     3 5
+--R                            ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)
+--R                         *
+--R                            x
+--R                         *
+--R                            ROOT
+--R                                        2 2 2       4     6  6
+--R                                   (- 4a b c  + 4a b c - b )e
+--R                                 + 
+--R                                       2   3        3 2     5     5
+--R                                   (12a b c  - 18a b c  + 6b c)d e
+--R                                 + 
+--R                                        2 4        2 3      4 2  2 4
+--R                                   (- 9a c  + 30a b c  - 15b c )d e
+--R                                 + 
+--R                                             4      3 3  3 3
+--R                                   (- 22a b c  + 20b c )d e
+--R                                 + 
+--R                                        5      2 4  4 2       5 5     6 6
+--R                                   (6a c  - 15b c )d e  + 6b c d e - c d
+--R                              /
+--R                                      9      2 8
+--R                                 64a c  - 16b c
+--R                        + 
+--R                                   2 2 2       4     6  4
+--R                              (- 8a b c  + 6a b c - b )e
+--R                            + 
+--R                                  2   3        3 2     5     3
+--R                              (20a b c  - 21a b c  + 4b c)d e
+--R                            + 
+--R                                    2 4        2 3     4 2  2 2
+--R                              (- 12a c  + 27a b c  - 6b c )d e
+--R                            + 
+--R                                        4     3 3  3         5    2 4  4
+--R                              (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                   5     2 4
+--R                             (16a c  - 4b c )
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                2 2       2     4  3            2     3     2
+--R                           (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                         + 
+--R                                3     2 2  2       3 3
+--R                           (6a c  - 3b c )d e + b c d
+--R                      /
+--R                             5     2 4
+--R                         8a c  - 2b c
+--R                + 
+--R                           3        2 3  5      3 2     2 2        4    4
+--R                      (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                    + 
+--R                           2   2       3   2 3      2 3        2 2  3 2
+--R                      (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                    + 
+--R                            3 4        4 5
+--R                      8a b c d e - 2a c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                         3        2 3  6        3 2     2 2        4    5
+--R                      (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                    + 
+--R                         2   2       3   2 4        2 3        2 2  3 3
+--R                      (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                    + 
+--R                              3 4 2       4 5
+--R                      - 8a b c d e  + 2a c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                     3        2 3    5        3 2     2 2        4  2 4
+--R                  (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                + 
+--R                     2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                  (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R                + 
+--R                      4 6
+--R                  2a c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R                                        +--------+
+--R                              +---+ +-+ |   2
+--R             (- 8b e + 12c d)\|- e \|d \|e x  + d
+--R           + 
+--R                   2           2                 2  +---+
+--R             ((4b e  - 6c d e)x  + 8b d e - 12c d )\|- e
+--R        *
+--R                 +--------+
+--R                 |   2         +-+
+--R                \|e x  + d  - \|d
+--R           atan(------------------)
+--R                        +---+
+--R                      x\|- e
+--R       + 
+--R                               +--------+
+--R               2 3             |   2             2 3             +-+
+--R         (- c e x  - 2c d e x)\|e x  + d  + (2c e x  + 2c d e x)\|d
+--R    /
+--R               +--------+
+--R         2 +-+ |   2          2   2     2
+--R       4c \|d \|e x  + d  - 2c e x  - 4c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 3053
+
+--S 3054 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R               +-----------+
+--R             2 |          2
+--R            c \|- 4a c + b
+--R         *
+--R            ROOT
+--R                           5     2 4
+--R                     (16a c  - 4b c )
+--R                  *
+--R                     ROOT
+--R                                 2 2 2       4     6  6
+--R                            (- 4a b c  + 4a b c - b )e
+--R                          + 
+--R                                2   3        3 2     5     5
+--R                            (12a b c  - 18a b c  + 6b c)d e
+--R                          + 
+--R                                 2 4        2 3      4 2  2 4
+--R                            (- 9a c  + 30a b c  - 15b c )d e
+--R                          + 
+--R                                      4      3 3  3 3        5      2 4  4 2
+--R                            (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                          + 
+--R                                5 5     6 6
+--R                            6b c d e - c d
+--R                       /
+--R                               9      2 8
+--R                          64a c  - 16b c
+--R                 + 
+--R                        2 2       2     4  3            2     3     2
+--R                   (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (6a c  - 3b c )d e + b c d
+--R              /
+--R                     5     2 4
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                     2 6        2 5     4 4
+--R                                 (32a c  - 24a b c  + 4b c )e
+--R                               + 
+--R                                         6     3 5
+--R                                 (16a b c  - 4b c )d
+--R                          *
+--R                             x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                    2 2 2       4     6  4
+--R                               (- 8a b c  + 6a b c - b )e
+--R                             + 
+--R                                   2   3        3 2     5     3
+--R                               (20a b c  - 21a b c  + 4b c)d e
+--R                             + 
+--R                                     2 4        2 3     4 2  2 2
+--R                               (- 12a c  + 27a b c  - 6b c )d e
+--R                             + 
+--R                                         4     3 3  3         5    2 4  4
+--R                               (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                     2 6        2 5     4 4
+--R                               (- 32a c  + 24a b c  - 4b c )e
+--R                             + 
+--R                                         6     3 5
+--R                               (- 16a b c  + 4b c )d
+--R                          *
+--R                             x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                  2 2 2       4     6  4
+--R                               (8a b c  - 6a b c + b )e
+--R                             + 
+--R                                     2   3        3 2     5     3
+--R                               (- 20a b c  + 21a b c  - 4b c)d e
+--R                             + 
+--R                                   2 4        2 3     4 2  2 2
+--R                               (12a c  - 27a b c  + 6b c )d e
+--R                             + 
+--R                                       4     3 3  3           5    2 4  4
+--R                               (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                    5     2 4
+--R                              (16a c  - 4b c )
+--R                           *
+--R                              ROOT
+--R                                          2 2 2       4     6  6
+--R                                     (- 4a b c  + 4a b c - b )e
+--R                                   + 
+--R                                         2   3        3 2     5     5
+--R                                     (12a b c  - 18a b c  + 6b c)d e
+--R                                   + 
+--R                                          2 4        2 3      4 2  2 4
+--R                                     (- 9a c  + 30a b c  - 15b c )d e
+--R                                   + 
+--R                                               4      3 3  3 3
+--R                                     (- 22a b c  + 20b c )d e
+--R                                   + 
+--R                                          5      2 4  4 2       5 5     6 6
+--R                                     (6a c  - 15b c )d e  + 6b c d e - c d
+--R                                /
+--R                                        9      2 8
+--R                                   64a c  - 16b c
+--R                          + 
+--R                                 2 2       2     4  3            2     3     2
+--R                            (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (6a c  - 3b c )d e + b c d
+--R                       /
+--R                              5     2 4
+--R                          8a c  - 2b c
+--R                 + 
+--R                            3        2 3  5      3 2     2 2        4    4
+--R                       (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                     + 
+--R                            2   2       3   2 3      2 3        2 2  3 2
+--R                       (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                     + 
+--R                             3 4        4 5
+--R                       8a b c d e - 2a c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                          3        2 3  6        3 2     2 2        4    5
+--R                       (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                     + 
+--R                          2   2       3   2 4        2 3        2 2  3 3
+--R                       (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                     + 
+--R                               3 4 2       4 5
+--R                       - 8a b c d e  + 2a c d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                      3        2 3    5        3 2     2 2        4  2 4
+--R                   (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                 + 
+--R                      2   2       3   3 3        2 3        2 2  4 2
+--R                   (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                 + 
+--R                           3 5        4 6
+--R                   - 8a b c d e + 2a c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R            +-----------+
+--R          2 |          2
+--R         c \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          5     2 4
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2 2       4     6  6
+--R                         (- 4a b c  + 4a b c - b )e
+--R                       + 
+--R                             2   3        3 2     5     5
+--R                         (12a b c  - 18a b c  + 6b c)d e
+--R                       + 
+--R                              2 4        2 3      4 2  2 4
+--R                         (- 9a c  + 30a b c  - 15b c )d e
+--R                       + 
+--R                                   4      3 3  3 3        5      2 4  4 2
+--R                         (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                       + 
+--R                             5 5     6 6
+--R                         6b c d e - c d
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                     2 2       2     4  3            2     3     2
+--R                (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R              + 
+--R                     3     2 2  2       3 3
+--R                (6a c  - 3b c )d e + b c d
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               2 6        2 5     4 4             6     3 5
+--R                          ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  6
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                     2   3        3 2     5     5
+--R                                 (12a b c  - 18a b c  + 6b c)d e
+--R                               + 
+--R                                      2 4        2 3      4 2  2 4
+--R                                 (- 9a c  + 30a b c  - 15b c )d e
+--R                               + 
+--R                                           4      3 3  3 3
+--R                                 (- 22a b c  + 20b c )d e
+--R                               + 
+--R                                      5      2 4  4 2       5 5     6 6
+--R                                 (6a c  - 15b c )d e  + 6b c d e - c d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                               2 2 2       4     6  4
+--R                            (8a b c  - 6a b c + b )e
+--R                          + 
+--R                                  2   3        3 2     5     3
+--R                            (- 20a b c  + 21a b c  - 4b c)d e
+--R                          + 
+--R                                2 4        2 3     4 2  2 2
+--R                            (12a c  - 27a b c  + 6b c )d e
+--R                          + 
+--R                                    4     3 3  3           5    2 4  4
+--R                            (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                       *
+--R                          x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  6
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                     2   3        3 2     5     5
+--R                                 (12a b c  - 18a b c  + 6b c)d e
+--R                               + 
+--R                                      2 4        2 3      4 2  2 4
+--R                                 (- 9a c  + 30a b c  - 15b c )d e
+--R                               + 
+--R                                           4      3 3  3 3
+--R                                 (- 22a b c  + 20b c )d e
+--R                               + 
+--R                                      5      2 4  4 2       5 5     6 6
+--R                                 (6a c  - 15b c )d e  + 6b c d e - c d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                                 2 2 2       4     6  4
+--R                            (- 8a b c  + 6a b c - b )e
+--R                          + 
+--R                                2   3        3 2     5     3
+--R                            (20a b c  - 21a b c  + 4b c)d e
+--R                          + 
+--R                                  2 4        2 3     4 2  2 2
+--R                            (- 12a c  + 27a b c  - 6b c )d e
+--R                          + 
+--R                                      4     3 3  3         5    2 4  4
+--R                            (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                   5     2 4
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2 2       4     6  6
+--R                                  (- 4a b c  + 4a b c - b )e
+--R                                + 
+--R                                      2   3        3 2     5     5
+--R                                  (12a b c  - 18a b c  + 6b c)d e
+--R                                + 
+--R                                       2 4        2 3      4 2  2 4
+--R                                  (- 9a c  + 30a b c  - 15b c )d e
+--R                                + 
+--R                                            4      3 3  3 3
+--R                                  (- 22a b c  + 20b c )d e
+--R                                + 
+--R                                       5      2 4  4 2       5 5     6 6
+--R                                  (6a c  - 15b c )d e  + 6b c d e - c d
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                              2 2       2     4  3            2     3     2
+--R                         (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                       + 
+--R                              3     2 2  2       3 3
+--R                         (6a c  - 3b c )d e + b c d
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                         3        2 3  5      3 2     2 2        4    4
+--R                    (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                  + 
+--R                         2   2       3   2 3      2 3        2 2  3 2
+--R                    (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                  + 
+--R                          3 4        4 5
+--R                    8a b c d e - 2a c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                       3        2 3  6        3 2     2 2        4    5
+--R                    (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                  + 
+--R                       2   2       3   2 4        2 3        2 2  3 3
+--R                    (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                  + 
+--R                            3 4 2       4 5
+--R                    - 8a b c d e  + 2a c d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                   3        2 3    5        3 2     2 2        4  2 4
+--R                (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R              + 
+--R                   2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R              + 
+--R                    4 6
+--R                2a c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R               +-----------+
+--R             2 |          2
+--R            c \|- 4a c + b
+--R         *
+--R            ROOT
+--R                             5     2 4
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                     ROOT
+--R                                 2 2 2       4     6  6
+--R                            (- 4a b c  + 4a b c - b )e
+--R                          + 
+--R                                2   3        3 2     5     5
+--R                            (12a b c  - 18a b c  + 6b c)d e
+--R                          + 
+--R                                 2 4        2 3      4 2  2 4
+--R                            (- 9a c  + 30a b c  - 15b c )d e
+--R                          + 
+--R                                      4      3 3  3 3        5      2 4  4 2
+--R                            (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                          + 
+--R                                5 5     6 6
+--R                            6b c d e - c d
+--R                       /
+--R                               9      2 8
+--R                          64a c  - 16b c
+--R                 + 
+--R                        2 2       2     4  3            2     3     2
+--R                   (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (6a c  - 3b c )d e + b c d
+--R              /
+--R                     5     2 4
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                     2 6        2 5     4 4
+--R                               (- 32a c  + 24a b c  - 4b c )e
+--R                             + 
+--R                                         6     3 5
+--R                               (- 16a b c  + 4b c )d
+--R                          *
+--R                             x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                    2 2 2       4     6  4
+--R                               (- 8a b c  + 6a b c - b )e
+--R                             + 
+--R                                   2   3        3 2     5     3
+--R                               (20a b c  - 21a b c  + 4b c)d e
+--R                             + 
+--R                                     2 4        2 3     4 2  2 2
+--R                               (- 12a c  + 27a b c  - 6b c )d e
+--R                             + 
+--R                                         4     3 3  3         5    2 4  4
+--R                               (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                     2 6        2 5     4 4
+--R                                 (32a c  - 24a b c  + 4b c )e
+--R                               + 
+--R                                         6     3 5
+--R                                 (16a b c  - 4b c )d
+--R                          *
+--R                             x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                  2 2 2       4     6  4
+--R                               (8a b c  - 6a b c + b )e
+--R                             + 
+--R                                     2   3        3 2     5     3
+--R                               (- 20a b c  + 21a b c  - 4b c)d e
+--R                             + 
+--R                                   2 4        2 3     4 2  2 2
+--R                               (12a c  - 27a b c  + 6b c )d e
+--R                             + 
+--R                                       4     3 3  3           5    2 4  4
+--R                               (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                      5     2 4
+--R                              (- 16a c  + 4b c )
+--R                           *
+--R                              ROOT
+--R                                          2 2 2       4     6  6
+--R                                     (- 4a b c  + 4a b c - b )e
+--R                                   + 
+--R                                         2   3        3 2     5     5
+--R                                     (12a b c  - 18a b c  + 6b c)d e
+--R                                   + 
+--R                                          2 4        2 3      4 2  2 4
+--R                                     (- 9a c  + 30a b c  - 15b c )d e
+--R                                   + 
+--R                                               4      3 3  3 3
+--R                                     (- 22a b c  + 20b c )d e
+--R                                   + 
+--R                                          5      2 4  4 2       5 5     6 6
+--R                                     (6a c  - 15b c )d e  + 6b c d e - c d
+--R                                /
+--R                                        9      2 8
+--R                                   64a c  - 16b c
+--R                          + 
+--R                                 2 2       2     4  3            2     3     2
+--R                            (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (6a c  - 3b c )d e + b c d
+--R                       /
+--R                              5     2 4
+--R                          8a c  - 2b c
+--R                 + 
+--R                            3        2 3  5      3 2     2 2        4    4
+--R                       (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                     + 
+--R                            2   2       3   2 3      2 3        2 2  3 2
+--R                       (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                     + 
+--R                             3 4        4 5
+--R                       8a b c d e - 2a c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                          3        2 3  6        3 2     2 2        4    5
+--R                       (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                     + 
+--R                          2   2       3   2 4        2 3        2 2  3 3
+--R                       (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                     + 
+--R                               3 4 2       4 5
+--R                       - 8a b c d e  + 2a c d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                      3        2 3    5        3 2     2 2        4  2 4
+--R                   (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                 + 
+--R                      2   2       3   3 3        2 3        2 2  4 2
+--R                   (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                 + 
+--R                           3 5        4 6
+--R                   - 8a b c d e + 2a c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R            +-----------+
+--R          2 |          2
+--R         c \|- 4a c + b
+--R      *
+--R         ROOT
+--R                        5     2 4
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2 2       4     6  6
+--R                         (- 4a b c  + 4a b c - b )e
+--R                       + 
+--R                             2   3        3 2     5     5
+--R                         (12a b c  - 18a b c  + 6b c)d e
+--R                       + 
+--R                              2 4        2 3      4 2  2 4
+--R                         (- 9a c  + 30a b c  - 15b c )d e
+--R                       + 
+--R                                   4      3 3  3 3        5      2 4  4 2
+--R                         (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                       + 
+--R                             5 5     6 6
+--R                         6b c d e - c d
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                     2 2       2     4  3            2     3     2
+--R                (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R              + 
+--R                     3     2 2  2       3 3
+--R                (6a c  - 3b c )d e + b c d
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                       *
+--R                          x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  6
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                     2   3        3 2     5     5
+--R                                 (12a b c  - 18a b c  + 6b c)d e
+--R                               + 
+--R                                      2 4        2 3      4 2  2 4
+--R                                 (- 9a c  + 30a b c  - 15b c )d e
+--R                               + 
+--R                                           4      3 3  3 3
+--R                                 (- 22a b c  + 20b c )d e
+--R                               + 
+--R                                      5      2 4  4 2       5 5     6 6
+--R                                 (6a c  - 15b c )d e  + 6b c d e - c d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                               2 2 2       4     6  4
+--R                            (8a b c  - 6a b c + b )e
+--R                          + 
+--R                                  2   3        3 2     5     3
+--R                            (- 20a b c  + 21a b c  - 4b c)d e
+--R                          + 
+--R                                2 4        2 3     4 2  2 2
+--R                            (12a c  - 27a b c  + 6b c )d e
+--R                          + 
+--R                                    4     3 3  3           5    2 4  4
+--R                            (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                               2 6        2 5     4 4             6     3 5
+--R                          ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  6
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                     2   3        3 2     5     5
+--R                                 (12a b c  - 18a b c  + 6b c)d e
+--R                               + 
+--R                                      2 4        2 3      4 2  2 4
+--R                                 (- 9a c  + 30a b c  - 15b c )d e
+--R                               + 
+--R                                           4      3 3  3 3
+--R                                 (- 22a b c  + 20b c )d e
+--R                               + 
+--R                                      5      2 4  4 2       5 5     6 6
+--R                                 (6a c  - 15b c )d e  + 6b c d e - c d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                                 2 2 2       4     6  4
+--R                            (- 8a b c  + 6a b c - b )e
+--R                          + 
+--R                                2   3        3 2     5     3
+--R                            (20a b c  - 21a b c  + 4b c)d e
+--R                          + 
+--R                                  2 4        2 3     4 2  2 2
+--R                            (- 12a c  + 27a b c  - 6b c )d e
+--R                          + 
+--R                                      4     3 3  3         5    2 4  4
+--R                            (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 5     2 4
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2 2       4     6  6
+--R                                  (- 4a b c  + 4a b c - b )e
+--R                                + 
+--R                                      2   3        3 2     5     5
+--R                                  (12a b c  - 18a b c  + 6b c)d e
+--R                                + 
+--R                                       2 4        2 3      4 2  2 4
+--R                                  (- 9a c  + 30a b c  - 15b c )d e
+--R                                + 
+--R                                            4      3 3  3 3
+--R                                  (- 22a b c  + 20b c )d e
+--R                                + 
+--R                                       5      2 4  4 2       5 5     6 6
+--R                                  (6a c  - 15b c )d e  + 6b c d e - c d
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                              2 2       2     4  3            2     3     2
+--R                         (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                       + 
+--R                              3     2 2  2       3 3
+--R                         (6a c  - 3b c )d e + b c d
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                         3        2 3  5      3 2     2 2        4    4
+--R                    (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                  + 
+--R                         2   2       3   2 3      2 3        2 2  3 2
+--R                    (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                  + 
+--R                          3 4        4 5
+--R                    8a b c d e - 2a c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                       3        2 3  6        3 2     2 2        4    5
+--R                    (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                  + 
+--R                       2   2       3   2 4        2 3        2 2  3 3
+--R                    (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                  + 
+--R                            3 4 2       4 5
+--R                    - 8a b c d e  + 2a c d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                   3        2 3    5        3 2     2 2        4  2 4
+--R                (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R              + 
+--R                   2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R              + 
+--R                    4 6
+--R                2a c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                        +-----------+
+--R                        |          2               2
+--R         ((- b e + c d)\|- 4a c + b   + (- 2a c + b )e - b c d)
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                      +-----------+
+--R                      |          2               2
+--R         ((b e - c d)\|- 4a c + b   + (- 2a c + b )e - b c d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                           +-----------+
+--R                           |          2  +-+
+--R             (2b e - 3c d)\|- 4a c + b  \|e
+--R          *
+--R                                +--------+
+--R                    +-+    +-+  |   2          +-+ +-+      2
+--R                 (x\|e  + \|d )\|e x  + d  - x\|d \|e  - e x  - d
+--R             log(------------------------------------------------)
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                                \|d \|e x  + d  - d
+--R         + 
+--R                         +-----------+               +-+
+--R                         |          2  +-+         x\|e
+--R           (2b e - 3c d)\|- 4a c + b  \|e atanh(-----------)
+--R                                                 +--------+
+--R                                                 |   2
+--R                                                \|e x  + d
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R  /
+--R                       +------------------+ +------------------+
+--R         +-----------+ | +-----------+      | +-----------+
+--R       2 |          2  | |          2       | |          2
+--R     2c \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3054
+
+--S 3055 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3055
+
+--S 3056 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       -
+--R               +-----------+
+--R             2 |          2
+--R            c \|- 4a c + b
+--R         *
+--R            ROOT
+--R                           5     2 4
+--R                     (16a c  - 4b c )
+--R                  *
+--R                     ROOT
+--R                                 2 2 2       4     6  6
+--R                            (- 4a b c  + 4a b c - b )e
+--R                          + 
+--R                                2   3        3 2     5     5
+--R                            (12a b c  - 18a b c  + 6b c)d e
+--R                          + 
+--R                                 2 4        2 3      4 2  2 4
+--R                            (- 9a c  + 30a b c  - 15b c )d e
+--R                          + 
+--R                                      4      3 3  3 3        5      2 4  4 2
+--R                            (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                          + 
+--R                                5 5     6 6
+--R                            6b c d e - c d
+--R                       /
+--R                               9      2 8
+--R                          64a c  - 16b c
+--R                 + 
+--R                        2 2       2     4  3            2     3     2
+--R                   (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (6a c  - 3b c )d e + b c d
+--R              /
+--R                     5     2 4
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                     2 6        2 5     4 4
+--R                                 (32a c  - 24a b c  + 4b c )e
+--R                               + 
+--R                                         6     3 5
+--R                                 (16a b c  - 4b c )d
+--R                          *
+--R                             x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                    2 2 2       4     6  4
+--R                               (- 8a b c  + 6a b c - b )e
+--R                             + 
+--R                                   2   3        3 2     5     3
+--R                               (20a b c  - 21a b c  + 4b c)d e
+--R                             + 
+--R                                     2 4        2 3     4 2  2 2
+--R                               (- 12a c  + 27a b c  - 6b c )d e
+--R                             + 
+--R                                         4     3 3  3         5    2 4  4
+--R                               (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                     2 6        2 5     4 4
+--R                               (- 32a c  + 24a b c  - 4b c )e
+--R                             + 
+--R                                         6     3 5
+--R                               (- 16a b c  + 4b c )d
+--R                          *
+--R                             x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                  2 2 2       4     6  4
+--R                               (8a b c  - 6a b c + b )e
+--R                             + 
+--R                                     2   3        3 2     5     3
+--R                               (- 20a b c  + 21a b c  - 4b c)d e
+--R                             + 
+--R                                   2 4        2 3     4 2  2 2
+--R                               (12a c  - 27a b c  + 6b c )d e
+--R                             + 
+--R                                       4     3 3  3           5    2 4  4
+--R                               (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                    5     2 4
+--R                              (16a c  - 4b c )
+--R                           *
+--R                              ROOT
+--R                                          2 2 2       4     6  6
+--R                                     (- 4a b c  + 4a b c - b )e
+--R                                   + 
+--R                                         2   3        3 2     5     5
+--R                                     (12a b c  - 18a b c  + 6b c)d e
+--R                                   + 
+--R                                          2 4        2 3      4 2  2 4
+--R                                     (- 9a c  + 30a b c  - 15b c )d e
+--R                                   + 
+--R                                               4      3 3  3 3
+--R                                     (- 22a b c  + 20b c )d e
+--R                                   + 
+--R                                          5      2 4  4 2       5 5     6 6
+--R                                     (6a c  - 15b c )d e  + 6b c d e - c d
+--R                                /
+--R                                        9      2 8
+--R                                   64a c  - 16b c
+--R                          + 
+--R                                 2 2       2     4  3            2     3     2
+--R                            (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (6a c  - 3b c )d e + b c d
+--R                       /
+--R                              5     2 4
+--R                          8a c  - 2b c
+--R                 + 
+--R                            3        2 3  5      3 2     2 2        4    4
+--R                       (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                     + 
+--R                            2   2       3   2 3      2 3        2 2  3 2
+--R                       (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                     + 
+--R                             3 4        4 5
+--R                       8a b c d e - 2a c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                          3        2 3  6        3 2     2 2        4    5
+--R                       (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                     + 
+--R                          2   2       3   2 4        2 3        2 2  3 3
+--R                       (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                     + 
+--R                               3 4 2       4 5
+--R                       - 8a b c d e  + 2a c d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                      3        2 3    5        3 2     2 2        4  2 4
+--R                   (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                 + 
+--R                      2   2       3   3 3        2 3        2 2  4 2
+--R                   (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                 + 
+--R                           3 5        4 6
+--R                   - 8a b c d e + 2a c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R            +-----------+
+--R          2 |          2
+--R         c \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          5     2 4
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2 2       4     6  6
+--R                         (- 4a b c  + 4a b c - b )e
+--R                       + 
+--R                             2   3        3 2     5     5
+--R                         (12a b c  - 18a b c  + 6b c)d e
+--R                       + 
+--R                              2 4        2 3      4 2  2 4
+--R                         (- 9a c  + 30a b c  - 15b c )d e
+--R                       + 
+--R                                   4      3 3  3 3        5      2 4  4 2
+--R                         (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                       + 
+--R                             5 5     6 6
+--R                         6b c d e - c d
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                     2 2       2     4  3            2     3     2
+--R                (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R              + 
+--R                     3     2 2  2       3 3
+--R                (6a c  - 3b c )d e + b c d
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               2 6        2 5     4 4             6     3 5
+--R                          ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  6
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                     2   3        3 2     5     5
+--R                                 (12a b c  - 18a b c  + 6b c)d e
+--R                               + 
+--R                                      2 4        2 3      4 2  2 4
+--R                                 (- 9a c  + 30a b c  - 15b c )d e
+--R                               + 
+--R                                           4      3 3  3 3
+--R                                 (- 22a b c  + 20b c )d e
+--R                               + 
+--R                                      5      2 4  4 2       5 5     6 6
+--R                                 (6a c  - 15b c )d e  + 6b c d e - c d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                               2 2 2       4     6  4
+--R                            (8a b c  - 6a b c + b )e
+--R                          + 
+--R                                  2   3        3 2     5     3
+--R                            (- 20a b c  + 21a b c  - 4b c)d e
+--R                          + 
+--R                                2 4        2 3     4 2  2 2
+--R                            (12a c  - 27a b c  + 6b c )d e
+--R                          + 
+--R                                    4     3 3  3           5    2 4  4
+--R                            (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                       *
+--R                          x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  6
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                     2   3        3 2     5     5
+--R                                 (12a b c  - 18a b c  + 6b c)d e
+--R                               + 
+--R                                      2 4        2 3      4 2  2 4
+--R                                 (- 9a c  + 30a b c  - 15b c )d e
+--R                               + 
+--R                                           4      3 3  3 3
+--R                                 (- 22a b c  + 20b c )d e
+--R                               + 
+--R                                      5      2 4  4 2       5 5     6 6
+--R                                 (6a c  - 15b c )d e  + 6b c d e - c d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                                 2 2 2       4     6  4
+--R                            (- 8a b c  + 6a b c - b )e
+--R                          + 
+--R                                2   3        3 2     5     3
+--R                            (20a b c  - 21a b c  + 4b c)d e
+--R                          + 
+--R                                  2 4        2 3     4 2  2 2
+--R                            (- 12a c  + 27a b c  - 6b c )d e
+--R                          + 
+--R                                      4     3 3  3         5    2 4  4
+--R                            (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                   5     2 4
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2 2       4     6  6
+--R                                  (- 4a b c  + 4a b c - b )e
+--R                                + 
+--R                                      2   3        3 2     5     5
+--R                                  (12a b c  - 18a b c  + 6b c)d e
+--R                                + 
+--R                                       2 4        2 3      4 2  2 4
+--R                                  (- 9a c  + 30a b c  - 15b c )d e
+--R                                + 
+--R                                            4      3 3  3 3
+--R                                  (- 22a b c  + 20b c )d e
+--R                                + 
+--R                                       5      2 4  4 2       5 5     6 6
+--R                                  (6a c  - 15b c )d e  + 6b c d e - c d
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                              2 2       2     4  3            2     3     2
+--R                         (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                       + 
+--R                              3     2 2  2       3 3
+--R                         (6a c  - 3b c )d e + b c d
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                         3        2 3  5      3 2     2 2        4    4
+--R                    (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                  + 
+--R                         2   2       3   2 3      2 3        2 2  3 2
+--R                    (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                  + 
+--R                          3 4        4 5
+--R                    8a b c d e - 2a c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                       3        2 3  6        3 2     2 2        4    5
+--R                    (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                  + 
+--R                       2   2       3   2 4        2 3        2 2  3 3
+--R                    (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                  + 
+--R                            3 4 2       4 5
+--R                    - 8a b c d e  + 2a c d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                   3        2 3    5        3 2     2 2        4  2 4
+--R                (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R              + 
+--R                   2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R              + 
+--R                    4 6
+--R                2a c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R               +-----------+
+--R             2 |          2
+--R            c \|- 4a c + b
+--R         *
+--R            ROOT
+--R                             5     2 4
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                     ROOT
+--R                                 2 2 2       4     6  6
+--R                            (- 4a b c  + 4a b c - b )e
+--R                          + 
+--R                                2   3        3 2     5     5
+--R                            (12a b c  - 18a b c  + 6b c)d e
+--R                          + 
+--R                                 2 4        2 3      4 2  2 4
+--R                            (- 9a c  + 30a b c  - 15b c )d e
+--R                          + 
+--R                                      4      3 3  3 3        5      2 4  4 2
+--R                            (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                          + 
+--R                                5 5     6 6
+--R                            6b c d e - c d
+--R                       /
+--R                               9      2 8
+--R                          64a c  - 16b c
+--R                 + 
+--R                        2 2       2     4  3            2     3     2
+--R                   (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (6a c  - 3b c )d e + b c d
+--R              /
+--R                     5     2 4
+--R                 8a c  - 2b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                     2 6        2 5     4 4
+--R                               (- 32a c  + 24a b c  - 4b c )e
+--R                             + 
+--R                                         6     3 5
+--R                               (- 16a b c  + 4b c )d
+--R                          *
+--R                             x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                    2 2 2       4     6  4
+--R                               (- 8a b c  + 6a b c - b )e
+--R                             + 
+--R                                   2   3        3 2     5     3
+--R                               (20a b c  - 21a b c  + 4b c)d e
+--R                             + 
+--R                                     2 4        2 3     4 2  2 2
+--R                               (- 12a c  + 27a b c  - 6b c )d e
+--R                             + 
+--R                                         4     3 3  3         5    2 4  4
+--R                               (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                     2 6        2 5     4 4
+--R                                 (32a c  - 24a b c  + 4b c )e
+--R                               + 
+--R                                         6     3 5
+--R                                 (16a b c  - 4b c )d
+--R                          *
+--R                             x
+--R                          *
+--R                             ROOT
+--R                                         2 2 2       4     6  6
+--R                                    (- 4a b c  + 4a b c - b )e
+--R                                  + 
+--R                                        2   3        3 2     5     5
+--R                                    (12a b c  - 18a b c  + 6b c)d e
+--R                                  + 
+--R                                         2 4        2 3      4 2  2 4
+--R                                    (- 9a c  + 30a b c  - 15b c )d e
+--R                                  + 
+--R                                              4      3 3  3 3
+--R                                    (- 22a b c  + 20b c )d e
+--R                                  + 
+--R                                         5      2 4  4 2       5 5     6 6
+--R                                    (6a c  - 15b c )d e  + 6b c d e - c d
+--R                               /
+--R                                       9      2 8
+--R                                  64a c  - 16b c
+--R                         + 
+--R                                  2 2 2       4     6  4
+--R                               (8a b c  - 6a b c + b )e
+--R                             + 
+--R                                     2   3        3 2     5     3
+--R                               (- 20a b c  + 21a b c  - 4b c)d e
+--R                             + 
+--R                                   2 4        2 3     4 2  2 2
+--R                               (12a c  - 27a b c  + 6b c )d e
+--R                             + 
+--R                                       4     3 3  3           5    2 4  4
+--R                               (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                      5     2 4
+--R                              (- 16a c  + 4b c )
+--R                           *
+--R                              ROOT
+--R                                          2 2 2       4     6  6
+--R                                     (- 4a b c  + 4a b c - b )e
+--R                                   + 
+--R                                         2   3        3 2     5     5
+--R                                     (12a b c  - 18a b c  + 6b c)d e
+--R                                   + 
+--R                                          2 4        2 3      4 2  2 4
+--R                                     (- 9a c  + 30a b c  - 15b c )d e
+--R                                   + 
+--R                                               4      3 3  3 3
+--R                                     (- 22a b c  + 20b c )d e
+--R                                   + 
+--R                                          5      2 4  4 2       5 5     6 6
+--R                                     (6a c  - 15b c )d e  + 6b c d e - c d
+--R                                /
+--R                                        9      2 8
+--R                                   64a c  - 16b c
+--R                          + 
+--R                                 2 2       2     4  3            2     3     2
+--R                            (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (6a c  - 3b c )d e + b c d
+--R                       /
+--R                              5     2 4
+--R                          8a c  - 2b c
+--R                 + 
+--R                            3        2 3  5      3 2     2 2        4    4
+--R                       (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                     + 
+--R                            2   2       3   2 3      2 3        2 2  3 2
+--R                       (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                     + 
+--R                             3 4        4 5
+--R                       8a b c d e - 2a c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                          3        2 3  6        3 2     2 2        4    5
+--R                       (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                     + 
+--R                          2   2       3   2 4        2 3        2 2  3 3
+--R                       (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                     + 
+--R                               3 4 2       4 5
+--R                       - 8a b c d e  + 2a c d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                      3        2 3    5        3 2     2 2        4  2 4
+--R                   (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R                 + 
+--R                      2   2       3   3 3        2 3        2 2  4 2
+--R                   (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                 + 
+--R                           3 5        4 6
+--R                   - 8a b c d e + 2a c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R            +-----------+
+--R          2 |          2
+--R         c \|- 4a c + b
+--R      *
+--R         ROOT
+--R                        5     2 4
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2 2       4     6  6
+--R                         (- 4a b c  + 4a b c - b )e
+--R                       + 
+--R                             2   3        3 2     5     5
+--R                         (12a b c  - 18a b c  + 6b c)d e
+--R                       + 
+--R                              2 4        2 3      4 2  2 4
+--R                         (- 9a c  + 30a b c  - 15b c )d e
+--R                       + 
+--R                                   4      3 3  3 3        5      2 4  4 2
+--R                         (- 22a b c  + 20b c )d e  + (6a c  - 15b c )d e
+--R                       + 
+--R                             5 5     6 6
+--R                         6b c d e - c d
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                     2 2       2     4  3            2     3     2
+--R                (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R              + 
+--R                     3     2 2  2       3 3
+--R                (6a c  - 3b c )d e + b c d
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                    2 6        2 5     4 4
+--R                              (- 32a c  + 24a b c  - 4b c )e
+--R                            + 
+--R                                        6     3 5
+--R                              (- 16a b c  + 4b c )d
+--R                       *
+--R                          x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  6
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                     2   3        3 2     5     5
+--R                                 (12a b c  - 18a b c  + 6b c)d e
+--R                               + 
+--R                                      2 4        2 3      4 2  2 4
+--R                                 (- 9a c  + 30a b c  - 15b c )d e
+--R                               + 
+--R                                           4      3 3  3 3
+--R                                 (- 22a b c  + 20b c )d e
+--R                               + 
+--R                                      5      2 4  4 2       5 5     6 6
+--R                                 (6a c  - 15b c )d e  + 6b c d e - c d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                               2 2 2       4     6  4
+--R                            (8a b c  - 6a b c + b )e
+--R                          + 
+--R                                  2   3        3 2     5     3
+--R                            (- 20a b c  + 21a b c  - 4b c)d e
+--R                          + 
+--R                                2 4        2 3     4 2  2 2
+--R                            (12a c  - 27a b c  + 6b c )d e
+--R                          + 
+--R                                    4     3 3  3           5    2 4  4
+--R                            (16a b c  - 4b c )d e + (- 4a c  + b c )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                               2 6        2 5     4 4             6     3 5
+--R                          ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)x
+--R                       *
+--R                          ROOT
+--R                                      2 2 2       4     6  6
+--R                                 (- 4a b c  + 4a b c - b )e
+--R                               + 
+--R                                     2   3        3 2     5     5
+--R                                 (12a b c  - 18a b c  + 6b c)d e
+--R                               + 
+--R                                      2 4        2 3      4 2  2 4
+--R                                 (- 9a c  + 30a b c  - 15b c )d e
+--R                               + 
+--R                                           4      3 3  3 3
+--R                                 (- 22a b c  + 20b c )d e
+--R                               + 
+--R                                      5      2 4  4 2       5 5     6 6
+--R                                 (6a c  - 15b c )d e  + 6b c d e - c d
+--R                            /
+--R                                    9      2 8
+--R                               64a c  - 16b c
+--R                      + 
+--R                                 2 2 2       4     6  4
+--R                            (- 8a b c  + 6a b c - b )e
+--R                          + 
+--R                                2   3        3 2     5     3
+--R                            (20a b c  - 21a b c  + 4b c)d e
+--R                          + 
+--R                                  2 4        2 3     4 2  2 2
+--R                            (- 12a c  + 27a b c  - 6b c )d e
+--R                          + 
+--R                                      4     3 3  3         5    2 4  4
+--R                            (- 16a b c  + 4b c )d e + (4a c  - b c )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 5     2 4
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2 2       4     6  6
+--R                                  (- 4a b c  + 4a b c - b )e
+--R                                + 
+--R                                      2   3        3 2     5     5
+--R                                  (12a b c  - 18a b c  + 6b c)d e
+--R                                + 
+--R                                       2 4        2 3      4 2  2 4
+--R                                  (- 9a c  + 30a b c  - 15b c )d e
+--R                                + 
+--R                                            4      3 3  3 3
+--R                                  (- 22a b c  + 20b c )d e
+--R                                + 
+--R                                       5      2 4  4 2       5 5     6 6
+--R                                  (6a c  - 15b c )d e  + 6b c d e - c d
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                              2 2       2     4  3            2     3     2
+--R                         (- 2a c  + 4a b c - b )e  + (- 9a b c  + 3b c)d e
+--R                       + 
+--R                              3     2 2  2       3 3
+--R                         (6a c  - 3b c )d e + b c d
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                         3        2 3  5      3 2     2 2        4    4
+--R                    (- 4a b c + 2a b )e  + (6a c  - 2a b c - 2a b )d e
+--R                  + 
+--R                         2   2       3   2 3      2 3        2 2  3 2
+--R                    (- 4a b c  + 8a b c)d e  + (4a c  - 12a b c )d e
+--R                  + 
+--R                          3 4        4 5
+--R                    8a b c d e - 2a c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                       3        2 3  6        3 2     2 2        4    5
+--R                    (4a b c - 2a b )e  + (- 6a c  + 2a b c + 2a b )d e
+--R                  + 
+--R                       2   2       3   2 4        2 3        2 2  3 3
+--R                    (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e
+--R                  + 
+--R                            3 4 2       4 5
+--R                    - 8a b c d e  + 2a c d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                   3        2 3    5        3 2     2 2        4  2 4
+--R                (4a b c - 2a b )d e  + (- 6a c  + 2a b c + 2a b )d e
+--R              + 
+--R                   2   2       3   3 3        2 3        2 2  4 2         3 5
+--R                (4a b c  - 8a b c)d e  + (- 4a c  + 12a b c )d e  - 8a b c d e
+--R              + 
+--R                    4 6
+--R                2a c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                        +-----------+
+--R                        |          2               2
+--R         ((- b e + c d)\|- 4a c + b   + (- 2a c + b )e - b c d)
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                      +-----------+
+--R                      |          2               2
+--R         ((b e - c d)\|- 4a c + b   + (- 2a c + b )e - b c d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                         +-----------+               +-+
+--R                         |          2  +-+         x\|e
+--R           (2b e - 3c d)\|- 4a c + b  \|e atanh(-----------)
+--R                                                 +--------+
+--R                                                 |   2
+--R                                                \|e x  + d
+--R         + 
+--R                                                    +--------+
+--R                                 +-----------+      |   2         +-+
+--R                           +---+ |          2      \|e x  + d  - \|d
+--R           (- 4b e + 6c d)\|- e \|- 4a c + b  atan(------------------)
+--R                                                           +---+
+--R                                                         x\|- e
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R  /
+--R                       +------------------+ +------------------+
+--R         +-----------+ | +-----------+      | +-----------+
+--R       2 |          2  | |          2       | |          2
+--R     2c \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3056
+
+--S 3057 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 3057
+
+)clear all
+
+--S 3058 of 3139
+t0:=x*(d+e*x^2)^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                     +--------+
+--R            3        |   2
+--R        (e x  + d x)\|e x  + d
+--R   (1)  -----------------------
+--R               4      2
+--R            c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3058
+
+--S 3059 of 3139
+r0:=e*sqrt(d+e*x^2)/c-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c))))*(e*(2*c*d-b*e)+(2*c^2*d^2+b^2*e^2-_
+   2*c*e*(b*d+a*e))/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c))))-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*(e*(2*c*d-b*e)+(-2*c^2*d^2-_
+   b^2*e^2+2*c*e*(b*d+a*e))/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R              2           |          2               2  2                2 2
+--R         ((b e  - 2c d e)\|- 4a c + b   + (- 2a c + b )e  - 2b c d e + 2c d )
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                          +-----------+
+--R              2           |          2             2  2                2 2
+--R         ((b e  - 2c d e)\|- 4a c + b   + (2a c - b )e  + 2b c d e - 2c d )
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                            +------------------------------+
+--R               +-----------+     +--------+ |    +-----------+
+--R           +-+ |          2  +-+ |   2      |    |          2
+--R         e\|2 \|- 4a c + b  \|c \|e x  + d \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                               +------------------------------+
+--R             +-----------+     |    +-----------+
+--R         +-+ |          2  +-+ |    |          2
+--R       c\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3059
+
+--S 3060 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  +--------+
+--R              +-+ |   2
+--R         (- c\|d \|e x  + d  + c d)
+--R      *
+--R         ROOT
+--R                        4     2 3
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  6            2     3     5
+--R                         (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                       + 
+--R                              3      2 2  2 4        3 3 3     4 4 2
+--R                         (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                             3  3        2     2     2       2 2      3 3
+--R                (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                           2 5        2 4     4 3             5     3 4    2
+--R                      ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                           2   2       3     5  4
+--R                        (4a b c  - 5a b c + b )e
+--R                      + 
+--R                             2 3        2 2     4     3
+--R                        (- 4a c  + 17a b c  - 4b c)d e
+--R                      + 
+--R                                  3     3 2  2 2         4     2 3  3
+--R                        (- 24a b c  + 6b c )d e  + (12a c  - 3b c )d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  6
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     5        3      2 2  2 4
+--R                                  (- 6a b c  + 6b c)d e  + (6a c  - 15b c )d e
+--R                                + 
+--R                                       3 3 3     4 4 2
+--R                                  18b c d e  - 9c d e
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2      3 3
+--R                       (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                         3      2 2  5        2          3    4
+--R                    (- 2a c + 2a b )e  + (- 4a b c - 2a b )d e
+--R                  + 
+--R                       2 2       2   2 3          2 3 2       3 4
+--R                    (4a c  + 8a b c)d e  - 12a b c d e  + 6a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                            2 4       2 3  2             4     3 3
+--R                        (16a c  - 4a b c )e  + (- 16a b c  + 4b c )d e
+--R                      + 
+--R                              5     2 4  2
+--R                        (16a c  - 4b c )d
+--R                   *
+--R                       2
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                          2         3  5        2     4    4
+--R                        (a b c - a b )e  + (2a b c + b )d e
+--R                      + 
+--R                                 2     3   2 3     2 2 3 2       3 4
+--R                        (- 2a b c  - 4b c)d e  + 6b c d e  - 3b c d e
+--R                   *
+--R                       2
+--R                      x
+--R                  + 
+--R                       3      2 2  5      2          3    4
+--R                    (2a c - 2a b )e  + (4a b c + 2a b )d e
+--R                  + 
+--R                         2 2       2   2 3          2 3 2       3 4
+--R                    (- 4a c  - 8a b c)d e  + 12a b c d e  - 6a c d e
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +--------+
+--R            +-+ |   2
+--R         (c\|d \|e x  + d  - c d)
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  6            2     3     5
+--R                         (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                       + 
+--R                              3      2 2  2 4        3 3 3     4 4 2
+--R                         (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                             3  3        2     2     2       2 2      3 3
+--R                (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                           2 5        2 4     4 3             5     3 4    2
+--R                      ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                             2   2       3     5  4
+--R                        (- 4a b c  + 5a b c - b )e
+--R                      + 
+--R                           2 3        2 2     4     3           3     3 2  2 2
+--R                        (4a c  - 17a b c  + 4b c)d e  + (24a b c  - 6b c )d e
+--R                      + 
+--R                                4     2 3  3
+--R                        (- 12a c  + 3b c )d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  6
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     5        3      2 2  2 4
+--R                                  (- 6a b c  + 6b c)d e  + (6a c  - 15b c )d e
+--R                                + 
+--R                                       3 3 3     4 4 2
+--R                                  18b c d e  - 9c d e
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2      3 3
+--R                       (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                         3      2 2  5        2          3    4
+--R                    (- 2a c + 2a b )e  + (- 4a b c - 2a b )d e
+--R                  + 
+--R                       2 2       2   2 3          2 3 2       3 4
+--R                    (4a c  + 8a b c)d e  - 12a b c d e  + 6a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                              2 4       2 3  2           4     3 3
+--R                        (- 16a c  + 4a b c )e  + (16a b c  - 4b c )d e
+--R                      + 
+--R                                5     2 4  2
+--R                        (- 16a c  + 4b c )d
+--R                   *
+--R                       2
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                          2         3  5        2     4    4
+--R                        (a b c - a b )e  + (2a b c + b )d e
+--R                      + 
+--R                                 2     3   2 3     2 2 3 2       3 4
+--R                        (- 2a b c  - 4b c)d e  + 6b c d e  - 3b c d e
+--R                   *
+--R                       2
+--R                      x
+--R                  + 
+--R                       3      2 2  5      2          3    4
+--R                    (2a c - 2a b )e  + (4a b c + 2a b )d e
+--R                  + 
+--R                         2 2       2   2 3          2 3 2       3 4
+--R                    (- 4a c  - 8a b c)d e  + 12a b c d e  - 6a c d e
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                  +--------+
+--R              +-+ |   2
+--R         (- c\|d \|e x  + d  + c d)
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  6            2     3     5
+--R                         (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                       + 
+--R                              3      2 2  2 4        3 3 3     4 4 2
+--R                         (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                             3  3        2     2     2       2 2      3 3
+--R                (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                             2 5        2 4     4 3               5     3 4    2
+--R                      ((- 32a c  + 24a b c  - 4b c )e + (- 16a b c  + 4b c )d)x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                           2   2       3     5  4
+--R                        (4a b c  - 5a b c + b )e
+--R                      + 
+--R                             2 3        2 2     4     3
+--R                        (- 4a c  + 17a b c  - 4b c)d e
+--R                      + 
+--R                                  3     3 2  2 2         4     2 3  3
+--R                        (- 24a b c  + 6b c )d e  + (12a c  - 3b c )d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  6
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     5        3      2 2  2 4
+--R                                  (- 6a b c  + 6b c)d e  + (6a c  - 15b c )d e
+--R                                + 
+--R                                       3 3 3     4 4 2
+--R                                  18b c d e  - 9c d e
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2      3 3
+--R                       (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                         3      2 2  5        2          3    4
+--R                    (- 2a c + 2a b )e  + (- 4a b c - 2a b )d e
+--R                  + 
+--R                       2 2       2   2 3          2 3 2       3 4
+--R                    (4a c  + 8a b c)d e  - 12a b c d e  + 6a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                              2 4       2 3  2           4     3 3
+--R                        (- 16a c  + 4a b c )e  + (16a b c  - 4b c )d e
+--R                      + 
+--R                                5     2 4  2
+--R                        (- 16a c  + 4b c )d
+--R                   *
+--R                       2
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                          2         3  5        2     4    4
+--R                        (a b c - a b )e  + (2a b c + b )d e
+--R                      + 
+--R                                 2     3   2 3     2 2 3 2       3 4
+--R                        (- 2a b c  - 4b c)d e  + 6b c d e  - 3b c d e
+--R                   *
+--R                       2
+--R                      x
+--R                  + 
+--R                       3      2 2  5      2          3    4
+--R                    (2a c - 2a b )e  + (4a b c + 2a b )d e
+--R                  + 
+--R                         2 2       2   2 3          2 3 2       3 4
+--R                    (- 4a c  - 8a b c)d e  + 12a b c d e  - 6a c d e
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +--------+
+--R            +-+ |   2
+--R         (c\|d \|e x  + d  - c d)
+--R      *
+--R         ROOT
+--R                        4     2 3
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  6            2     3     5
+--R                         (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                       + 
+--R                              3      2 2  2 4        3 3 3     4 4 2
+--R                         (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                             3  3        2     2     2       2 2      3 3
+--R                (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                             2 5        2 4     4 3               5     3 4    2
+--R                      ((- 32a c  + 24a b c  - 4b c )e + (- 16a b c  + 4b c )d)x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                             2   2       3     5  4
+--R                        (- 4a b c  + 5a b c - b )e
+--R                      + 
+--R                           2 3        2 2     4     3           3     3 2  2 2
+--R                        (4a c  - 17a b c  + 4b c)d e  + (24a b c  - 6b c )d e
+--R                      + 
+--R                                4     2 3  3
+--R                        (- 12a c  + 3b c )d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  6
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     5        3      2 2  2 4
+--R                                  (- 6a b c  + 6b c)d e  + (6a c  - 15b c )d e
+--R                                + 
+--R                                       3 3 3     4 4 2
+--R                                  18b c d e  - 9c d e
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2      3 3
+--R                       (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                         3      2 2  5        2          3    4
+--R                    (- 2a c + 2a b )e  + (- 4a b c - 2a b )d e
+--R                  + 
+--R                       2 2       2   2 3          2 3 2       3 4
+--R                    (4a c  + 8a b c)d e  - 12a b c d e  + 6a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                            2 4       2 3  2             4     3 3
+--R                        (16a c  - 4a b c )e  + (- 16a b c  + 4b c )d e
+--R                      + 
+--R                              5     2 4  2
+--R                        (16a c  - 4b c )d
+--R                   *
+--R                       2
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                          2         3  5        2     4    4
+--R                        (a b c - a b )e  + (2a b c + b )d e
+--R                      + 
+--R                                 2     3   2 3     2 2 3 2       3 4
+--R                        (- 2a b c  - 4b c)d e  + 6b c d e  - 3b c d e
+--R                   *
+--R                       2
+--R                      x
+--R                  + 
+--R                       3      2 2  5      2          3    4
+--R                    (2a c - 2a b )e  + (4a b c + 2a b )d e
+--R                  + 
+--R                         2 2       2   2 3          2 3 2       3 4
+--R                    (- 4a c  - 8a b c)d e  + 12a b c d e  - 6a c d e
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R         2 2 +-+
+--R       2e x \|d
+--R  /
+--R            +--------+
+--R        +-+ |   2
+--R     2c\|d \|e x  + d  - 2c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3060
+
+--S 3061 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +-----------+         +--------+           +-----------+
+--R              +-+ |          2  +-+ +-+ |   2            +-+ |          2  +-+
+--R         (- c\|2 \|- 4a c + b  \|c \|d \|e x  + d  + c d\|2 \|- 4a c + b  \|c )
+--R      *
+--R          +------------------------------+
+--R          |    +-----------+
+--R          |    |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        4     2 3
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  6            2     3     5
+--R                         (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                       + 
+--R                              3      2 2  2 4        3 3 3     4 4 2
+--R                         (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                             3  3        2     2     2       2 2      3 3
+--R                (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                           2 5        2 4     4 3             5     3 4    2
+--R                      ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                           2   2       3     5  4
+--R                        (4a b c  - 5a b c + b )e
+--R                      + 
+--R                             2 3        2 2     4     3
+--R                        (- 4a c  + 17a b c  - 4b c)d e
+--R                      + 
+--R                                  3     3 2  2 2         4     2 3  3
+--R                        (- 24a b c  + 6b c )d e  + (12a c  - 3b c )d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  6
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     5        3      2 2  2 4
+--R                                  (- 6a b c  + 6b c)d e  + (6a c  - 15b c )d e
+--R                                + 
+--R                                       3 3 3     4 4 2
+--R                                  18b c d e  - 9c d e
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2      3 3
+--R                       (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                         3      2 2  5        2          3    4
+--R                    (- 2a c + 2a b )e  + (- 4a b c - 2a b )d e
+--R                  + 
+--R                       2 2       2   2 3          2 3 2       3 4
+--R                    (4a c  + 8a b c)d e  - 12a b c d e  + 6a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                            2 4       2 3  2             4     3 3
+--R                        (16a c  - 4a b c )e  + (- 16a b c  + 4b c )d e
+--R                      + 
+--R                              5     2 4  2
+--R                        (16a c  - 4b c )d
+--R                   *
+--R                       2
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                          2         3  5        2     4    4
+--R                        (a b c - a b )e  + (2a b c + b )d e
+--R                      + 
+--R                                 2     3   2 3     2 2 3 2       3 4
+--R                        (- 2a b c  - 4b c)d e  + 6b c d e  - 3b c d e
+--R                   *
+--R                       2
+--R                      x
+--R                  + 
+--R                       3      2 2  5      2          3    4
+--R                    (2a c - 2a b )e  + (4a b c + 2a b )d e
+--R                  + 
+--R                         2 2       2   2 3          2 3 2       3 4
+--R                    (- 4a c  - 8a b c)d e  + 12a b c d e  - 6a c d e
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +-----------+         +--------+           +-----------+
+--R            +-+ |          2  +-+ +-+ |   2            +-+ |          2  +-+
+--R         (c\|2 \|- 4a c + b  \|c \|d \|e x  + d  - c d\|2 \|- 4a c + b  \|c )
+--R      *
+--R          +------------------------------+
+--R          |    +-----------+
+--R          |    |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  6            2     3     5
+--R                         (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                       + 
+--R                              3      2 2  2 4        3 3 3     4 4 2
+--R                         (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                             3  3        2     2     2       2 2      3 3
+--R                (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                           2 5        2 4     4 3             5     3 4    2
+--R                      ((32a c  - 24a b c  + 4b c )e + (16a b c  - 4b c )d)x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                             2   2       3     5  4
+--R                        (- 4a b c  + 5a b c - b )e
+--R                      + 
+--R                           2 3        2 2     4     3           3     3 2  2 2
+--R                        (4a c  - 17a b c  + 4b c)d e  + (24a b c  - 6b c )d e
+--R                      + 
+--R                                4     2 3  3
+--R                        (- 12a c  + 3b c )d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  6
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     5        3      2 2  2 4
+--R                                  (- 6a b c  + 6b c)d e  + (6a c  - 15b c )d e
+--R                                + 
+--R                                       3 3 3     4 4 2
+--R                                  18b c d e  - 9c d e
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2      3 3
+--R                       (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                         3      2 2  5        2          3    4
+--R                    (- 2a c + 2a b )e  + (- 4a b c - 2a b )d e
+--R                  + 
+--R                       2 2       2   2 3          2 3 2       3 4
+--R                    (4a c  + 8a b c)d e  - 12a b c d e  + 6a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                              2 4       2 3  2           4     3 3
+--R                        (- 16a c  + 4a b c )e  + (16a b c  - 4b c )d e
+--R                      + 
+--R                                5     2 4  2
+--R                        (- 16a c  + 4b c )d
+--R                   *
+--R                       2
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                          2         3  5        2     4    4
+--R                        (a b c - a b )e  + (2a b c + b )d e
+--R                      + 
+--R                                 2     3   2 3     2 2 3 2       3 4
+--R                        (- 2a b c  - 4b c)d e  + 6b c d e  - 3b c d e
+--R                   *
+--R                       2
+--R                      x
+--R                  + 
+--R                       3      2 2  5      2          3    4
+--R                    (2a c - 2a b )e  + (4a b c + 2a b )d e
+--R                  + 
+--R                         2 2       2   2 3          2 3 2       3 4
+--R                    (- 4a c  - 8a b c)d e  + 12a b c d e  - 6a c d e
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                  +-----------+         +--------+           +-----------+
+--R              +-+ |          2  +-+ +-+ |   2            +-+ |          2  +-+
+--R         (- c\|2 \|- 4a c + b  \|c \|d \|e x  + d  + c d\|2 \|- 4a c + b  \|c )
+--R      *
+--R          +------------------------------+
+--R          |    +-----------+
+--R          |    |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  6            2     3     5
+--R                         (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                       + 
+--R                              3      2 2  2 4        3 3 3     4 4 2
+--R                         (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                             3  3        2     2     2       2 2      3 3
+--R                (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                             2 5        2 4     4 3               5     3 4    2
+--R                      ((- 32a c  + 24a b c  - 4b c )e + (- 16a b c  + 4b c )d)x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                           2   2       3     5  4
+--R                        (4a b c  - 5a b c + b )e
+--R                      + 
+--R                             2 3        2 2     4     3
+--R                        (- 4a c  + 17a b c  - 4b c)d e
+--R                      + 
+--R                                  3     3 2  2 2         4     2 3  3
+--R                        (- 24a b c  + 6b c )d e  + (12a c  - 3b c )d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  6
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     5        3      2 2  2 4
+--R                                  (- 6a b c  + 6b c)d e  + (6a c  - 15b c )d e
+--R                                + 
+--R                                       3 3 3     4 4 2
+--R                                  18b c d e  - 9c d e
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2      3 3
+--R                       (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                         3      2 2  5        2          3    4
+--R                    (- 2a c + 2a b )e  + (- 4a b c - 2a b )d e
+--R                  + 
+--R                       2 2       2   2 3          2 3 2       3 4
+--R                    (4a c  + 8a b c)d e  - 12a b c d e  + 6a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                              2 4       2 3  2           4     3 3
+--R                        (- 16a c  + 4a b c )e  + (16a b c  - 4b c )d e
+--R                      + 
+--R                                5     2 4  2
+--R                        (- 16a c  + 4b c )d
+--R                   *
+--R                       2
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                          2         3  5        2     4    4
+--R                        (a b c - a b )e  + (2a b c + b )d e
+--R                      + 
+--R                                 2     3   2 3     2 2 3 2       3 4
+--R                        (- 2a b c  - 4b c)d e  + 6b c d e  - 3b c d e
+--R                   *
+--R                       2
+--R                      x
+--R                  + 
+--R                       3      2 2  5      2          3    4
+--R                    (2a c - 2a b )e  + (4a b c + 2a b )d e
+--R                  + 
+--R                         2 2       2   2 3          2 3 2       3 4
+--R                    (- 4a c  - 8a b c)d e  + 12a b c d e  - 6a c d e
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +-----------+         +--------+           +-----------+
+--R            +-+ |          2  +-+ +-+ |   2            +-+ |          2  +-+
+--R         (c\|2 \|- 4a c + b  \|c \|d \|e x  + d  - c d\|2 \|- 4a c + b  \|c )
+--R      *
+--R          +------------------------------+
+--R          |    +-----------+
+--R          |    |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        4     2 3
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                             2 2       2     4  6            2     3     5
+--R                         (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                       + 
+--R                              3      2 2  2 4        3 3 3     4 4 2
+--R                         (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                    /
+--R                            7      2 6
+--R                       64a c  - 16b c
+--R              + 
+--R                             3  3        2     2     2       2 2      3 3
+--R                (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                             2 5        2 4     4 3               5     3 4    2
+--R                      ((- 32a c  + 24a b c  - 4b c )e + (- 16a b c  + 4b c )d)x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                             2   2       3     5  4
+--R                        (- 4a b c  + 5a b c - b )e
+--R                      + 
+--R                           2 3        2 2     4     3           3     3 2  2 2
+--R                        (4a c  - 17a b c  + 4b c)d e  + (24a b c  - 6b c )d e
+--R                      + 
+--R                                4     2 3  3
+--R                        (- 12a c  + 3b c )d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                      2 2       2     4  6
+--R                                  (- a c  + 2a b c - b )e
+--R                                + 
+--R                                           2     3     5        3      2 2  2 4
+--R                                  (- 6a b c  + 6b c)d e  + (6a c  - 15b c )d e
+--R                                + 
+--R                                       3 3 3     4 4 2
+--R                                  18b c d e  - 9c d e
+--R                             /
+--R                                     7      2 6
+--R                                64a c  - 16b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2      3 3
+--R                       (- 3a b c + b )e  + (6a c  - 3b c)d e  + 3b c d e - 2c d
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                         3      2 2  5        2          3    4
+--R                    (- 2a c + 2a b )e  + (- 4a b c - 2a b )d e
+--R                  + 
+--R                       2 2       2   2 3          2 3 2       3 4
+--R                    (4a c  + 8a b c)d e  - 12a b c d e  + 6a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R              + 
+--R                            2 4       2 3  2             4     3 3
+--R                        (16a c  - 4a b c )e  + (- 16a b c  + 4b c )d e
+--R                      + 
+--R                              5     2 4  2
+--R                        (16a c  - 4b c )d
+--R                   *
+--R                       2
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 2 2       2     4  6            2     3     5
+--R                             (- a c  + 2a b c - b )e  + (- 6a b c  + 6b c)d e
+--R                           + 
+--R                                  3      2 2  2 4        3 3 3     4 4 2
+--R                             (6a c  - 15b c )d e  + 18b c d e  - 9c d e
+--R                        /
+--R                                7      2 6
+--R                           64a c  - 16b c
+--R                  + 
+--R                          2         3  5        2     4    4
+--R                        (a b c - a b )e  + (2a b c + b )d e
+--R                      + 
+--R                                 2     3   2 3     2 2 3 2       3 4
+--R                        (- 2a b c  - 4b c)d e  + 6b c d e  - 3b c d e
+--R                   *
+--R                       2
+--R                      x
+--R                  + 
+--R                       3      2 2  5      2          3    4
+--R                    (2a c - 2a b )e  + (4a b c + 2a b )d e
+--R                  + 
+--R                         2 2       2   2 3          2 3 2       3 4
+--R                    (- 4a c  - 8a b c)d e  + 12a b c d e  - 6a c d e
+--R               *
+--R                   +-+
+--R                  \|d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                  +-----------+
+--R                      2           |          2              2  2
+--R               (- 2b e  + 4c d e)\|- 4a c + b   + (4a c - 2b )e  + 4b c d e
+--R             + 
+--R                   2 2
+--R               - 4c d
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|d \|e x  + d
+--R         + 
+--R                              +-----------+
+--R                  2       2   |          2                2    2         2
+--R           (2b d e  - 4c d e)\|- 4a c + b   + (- 4a c + 2b )d e  - 4b c d e
+--R         + 
+--R             2 3
+--R           4c d
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                  +-----------+
+--R                      2           |          2                2  2
+--R               (- 2b e  + 4c d e)\|- 4a c + b   + (- 4a c + 2b )e  - 4b c d e
+--R             + 
+--R                 2 2
+--R               4c d
+--R          *
+--R                  +--------+
+--R              +-+ |   2
+--R             \|d \|e x  + d
+--R         + 
+--R                            +-----------+
+--R                2       2   |          2              2    2         2      2 3
+--R         (2b d e  - 4c d e)\|- 4a c + b   + (4a c - 2b )d e  + 4b c d e - 4c d
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                      +-----------+     +--------+
+--R                  +-+ |          2  +-+ |   2
+--R             2d e\|2 \|- 4a c + b  \|c \|e x  + d
+--R           + 
+--R                        +-----------+
+--R                    +-+ |          2  +-+ +-+
+--R             - 2d e\|2 \|- 4a c + b  \|c \|d
+--R      *
+--R          +------------------------------+ +----------------------------+
+--R          |    +-----------+               |  +-----------+
+--R          |    |          2                |  |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R               +-----------+         +--------+            +-----------+
+--R           +-+ |          2  +-+ +-+ |   2             +-+ |          2  +-+
+--R       (2c\|2 \|- 4a c + b  \|c \|d \|e x  + d  - 2c d\|2 \|- 4a c + b  \|c )
+--R    *
+--R        +------------------------------+ +----------------------------+
+--R        |    +-----------+               |  +-----------+
+--R        |    |          2                |  |          2
+--R       \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3061
+
+--S 3062 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3062
+
+)clear all
+
+--S 3063 of 3139
+t0:=(d+e*x^2)^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R              4      2
+--R           c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3063
+
+--S 3064 of 3139
+r0:=1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*(3*c*d-e*(b-sqrt(b^2-4*a*c)))*_
+   sqrt(e)/(c*sqrt(b^2-4*a*c))-1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*_
+   (3*c*d-e*(b+sqrt(b^2-4*a*c)))*sqrt(e)/(c*sqrt(b^2-4*a*c))-atanh(x*_
+   sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-_
+   4*a*c))))*(2*c^2*d^2+b*e^2*(b-sqrt(b^2-4*a*c))-2*c*e*(b*d+a*e-_
+   d*sqrt(b^2-4*a*c)))/(c*sqrt(b^2-4*a*c)*sqrt(2*c*d-e*(b-sqrt(b^2-_
+   4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c)))-atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-_
+   4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(2*c^2*d^2+b*e^2*_
+   (b+sqrt(b^2-4*a*c))-2*c*e*(b*d+a*e+d*sqrt(b^2-4*a*c)))/(c*_
+   sqrt(b^2-4*a*c)*sqrt(b+sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R              2           |          2             2  2                2 2
+--R         ((b e  - 2c d e)\|- 4a c + b   + (2a c - b )e  + 2b c d e - 2c d )
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R                2           |          2             2  2                2 2
+--R         ((- b e  + 2c d e)\|- 4a c + b   + (2a c - b )e  + 2b c d e - 2c d )
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                               +------------------------------+
+--R           +-----------+               +-+     |    +-----------+
+--R           |          2  +-+         x\|e      |    |          2
+--R         e\|- 4a c + b  \|e atanh(-----------)\|- e\|- 4a c + b   - b e + 2c d
+--R                                   +--------+
+--R                                   |   2
+--R                                  \|e x  + d
+--R      *
+--R        +------------------+ +------------------+ +----------------------------+
+--R        | +-----------+      | +-----------+      |  +-----------+
+--R        | |          2       | |          2       |  |          2
+--R       \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                       +------------------------------+ +------------------+
+--R         +-----------+ |    +-----------+               | +-----------+
+--R         |          2  |    |          2                | |          2
+--R       c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3064
+
+--S 3065 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           c
+--R        *
+--R           ROOT
+--R                        2 3       2 2
+--R                    (16a c  - 4a b c )
+--R                 *
+--R                    ROOT
+--R                              2 2 6     2       5     2 2 2 4         2 3 3
+--R                           - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                         + 
+--R                               3 4 2    4 6
+--R                           6a c d e  - c d
+--R                      /
+--R                            3 5      2 2 4
+--R                         64a c  - 16a b c
+--R                + 
+--R                     2       2  3             2       2 2       2 3
+--R                  (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R             /
+--R                  2 3       2 2
+--R                8a c  - 2a b c
+--R        *
+--R           log
+--R                                 2   3       3 2           2 4       2 3
+--R                            ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                         *
+--R                            ROOT
+--R                                      2 2 6     2       5     2 2 2 4
+--R                                   - a b e  + 6a b c d e  - 9a c d e
+--R                                 + 
+--R                                           2 3 3       3 4 2    4 6
+--R                                   - 2a b c d e  + 6a c d e  - c d
+--R                              /
+--R                                    3 5      2 2 4
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                                   2         3  4       2 2       2     3
+--R                              (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                            + 
+--R                                     3    2 2  3
+--R                              (- 4a c  + b c )d e
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                   2   3       3 2         2 4       2 3
+--R                            ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                         *
+--R                            ROOT
+--R                                      2 2 6     2       5     2 2 2 4
+--R                                   - a b e  + 6a b c d e  - 9a c d e
+--R                                 + 
+--R                                           2 3 3       3 4 2    4 6
+--R                                   - 2a b c d e  + 6a c d e  - c d
+--R                              /
+--R                                    3 5      2 2 4
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                                 2         3  4         2 2       2     3
+--R                              (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                            + 
+--R                                   3    2 2  3
+--R                              (4a c  - b c )d e
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                 2 3       2 2
+--R                             (16a c  - 4a b c )
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                              2       2  3             2       2 2       2 3
+--R                           (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                      /
+--R                           2 3       2 2
+--R                         8a c  - 2a b c
+--R                + 
+--R                          2   5      2        2    4           2 3       2 3 2
+--R                      - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                    + 
+--R                          2 4      3 5
+--R                      2b c d e - 2c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                        2   6        2        2    5           2 4       2 3 3
+--R                      2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                    + 
+--R                            2 4 2     3 5
+--R                      - 2b c d e  + 2c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                    2     5        2        2  2 4           3 3       2 4 2
+--R                  2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                + 
+--R                        2 5      3 6
+--R                  - 2b c d e + 2c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R         -
+--R              c
+--R           *
+--R              ROOT
+--R                             2 3       2 2
+--R                       (- 16a c  + 4a b c )
+--R                    *
+--R                       ROOT
+--R                                 2 2 6     2       5     2 2 2 4         2 3 3
+--R                              - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                            + 
+--R                                  3 4 2    4 6
+--R                              6a c d e  - c d
+--R                         /
+--R                               3 5      2 2 4
+--R                            64a c  - 16a b c
+--R                   + 
+--R                        2       2  3             2       2 2       2 3
+--R                     (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                /
+--R                     2 3       2 2
+--R                   8a c  - 2a b c
+--R           *
+--R              log
+--R                                    2   3       3 2           2 4       2 3
+--R                               ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                            *
+--R                               ROOT
+--R                                         2 2 6     2       5     2 2 2 4
+--R                                      - a b e  + 6a b c d e  - 9a c d e
+--R                                    + 
+--R                                              2 3 3       3 4 2    4 6
+--R                                      - 2a b c d e  + 6a c d e  - c d
+--R                                 /
+--R                                       3 5      2 2 4
+--R                                    64a c  - 16a b c
+--R                           + 
+--R                                    2         3  4         2 2       2     3
+--R                                 (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                               + 
+--R                                      3    2 2  3
+--R                                 (4a c  - b c )d e
+--R                            *
+--R                               x
+--R                        *
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R                       + 
+--R                                      2   3       3 2         2 4       2 3
+--R                               ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                            *
+--R                               ROOT
+--R                                         2 2 6     2       5     2 2 2 4
+--R                                      - a b e  + 6a b c d e  - 9a c d e
+--R                                    + 
+--R                                              2 3 3       3 4 2    4 6
+--R                                      - 2a b c d e  + 6a c d e  - c d
+--R                                 /
+--R                                       3 5      2 2 4
+--R                                    64a c  - 16a b c
+--R                           + 
+--R                                      2         3  4       2 2       2     3
+--R                                 (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                               + 
+--R                                        3    2 2  3
+--R                                 (- 4a c  + b c )d e
+--R                            *
+--R                               x
+--R                        *
+--R                            +-+
+--R                           \|d
+--R                    *
+--R                       ROOT
+--R                                      2 3       2 2
+--R                                (- 16a c  + 4a b c )
+--R                             *
+--R                                ROOT
+--R                                          2 2 6     2       5     2 2 2 4
+--R                                       - a b e  + 6a b c d e  - 9a c d e
+--R                                     + 
+--R                                               2 3 3       3 4 2    4 6
+--R                                       - 2a b c d e  + 6a c d e  - c d
+--R                                  /
+--R                                        3 5      2 2 4
+--R                                     64a c  - 16a b c
+--R                            + 
+--R                                 2       2  3             2       2 2       2 3
+--R                              (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                         /
+--R                              2 3       2 2
+--R                            8a c  - 2a b c
+--R                   + 
+--R                             2   5      2        2    4           2 3
+--R                         - 2a b e  + (6a c + 2a b )d e  - 8a b c d e
+--R                       + 
+--R                             2 3 2       2 4      3 5
+--R                         4a c d e  + 2b c d e - 2c d
+--R                    *
+--R                            +--------+
+--R                        +-+ |   2
+--R                       \|d \|e x  + d
+--R                   + 
+--R                           2   6        2        2    5           2 4
+--R                         2a b e  + (- 6a c - 2a b )d e  + 8a b c d e
+--R                       + 
+--R                               2 3 3       2 4 2     3 5
+--R                         - 4a c d e  - 2b c d e  + 2c d e
+--R                    *
+--R                        2
+--R                       x
+--R                   + 
+--R                       2     5        2        2  2 4           3 3       2 4 2
+--R                     2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                   + 
+--R                           2 5      3 6
+--R                     - 2b c d e + 2c d
+--R                /
+--R                    2
+--R                   x
+--R       + 
+--R           c
+--R        *
+--R           ROOT
+--R                          2 3       2 2
+--R                    (- 16a c  + 4a b c )
+--R                 *
+--R                    ROOT
+--R                              2 2 6     2       5     2 2 2 4         2 3 3
+--R                           - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                         + 
+--R                               3 4 2    4 6
+--R                           6a c d e  - c d
+--R                      /
+--R                            3 5      2 2 4
+--R                         64a c  - 16a b c
+--R                + 
+--R                     2       2  3             2       2 2       2 3
+--R                  (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R             /
+--R                  2 3       2 2
+--R                8a c  - 2a b c
+--R        *
+--R           log
+--R                                   2   3       3 2         2 4       2 3
+--R                            ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                         *
+--R                            ROOT
+--R                                      2 2 6     2       5     2 2 2 4
+--R                                   - a b e  + 6a b c d e  - 9a c d e
+--R                                 + 
+--R                                           2 3 3       3 4 2    4 6
+--R                                   - 2a b c d e  + 6a c d e  - c d
+--R                              /
+--R                                    3 5      2 2 4
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                                   2         3  4       2 2       2     3
+--R                              (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                            + 
+--R                                     3    2 2  3
+--R                              (- 4a c  + b c )d e
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                 2   3       3 2           2 4       2 3
+--R                            ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                         *
+--R                            ROOT
+--R                                      2 2 6     2       5     2 2 2 4
+--R                                   - a b e  + 6a b c d e  - 9a c d e
+--R                                 + 
+--R                                           2 3 3       3 4 2    4 6
+--R                                   - 2a b c d e  + 6a c d e  - c d
+--R                              /
+--R                                    3 5      2 2 4
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                                 2         3  4         2 2       2     3
+--R                              (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                            + 
+--R                                   3    2 2  3
+--R                              (4a c  - b c )d e
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                   2 3       2 2
+--R                             (- 16a c  + 4a b c )
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                              2       2  3             2       2 2       2 3
+--R                           (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                      /
+--R                           2 3       2 2
+--R                         8a c  - 2a b c
+--R                + 
+--R                          2   5      2        2    4           2 3       2 3 2
+--R                      - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                    + 
+--R                          2 4      3 5
+--R                      2b c d e - 2c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                        2   6        2        2    5           2 4       2 3 3
+--R                      2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                    + 
+--R                            2 4 2     3 5
+--R                      - 2b c d e  + 2c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                    2     5        2        2  2 4           3 3       2 4 2
+--R                  2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                + 
+--R                        2 5      3 6
+--R                  - 2b c d e + 2c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R         -
+--R              c
+--R           *
+--R              ROOT
+--R                           2 3       2 2
+--R                       (16a c  - 4a b c )
+--R                    *
+--R                       ROOT
+--R                                 2 2 6     2       5     2 2 2 4         2 3 3
+--R                              - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                            + 
+--R                                  3 4 2    4 6
+--R                              6a c d e  - c d
+--R                         /
+--R                               3 5      2 2 4
+--R                            64a c  - 16a b c
+--R                   + 
+--R                        2       2  3             2       2 2       2 3
+--R                     (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                /
+--R                     2 3       2 2
+--R                   8a c  - 2a b c
+--R           *
+--R              log
+--R                                      2   3       3 2         2 4       2 3
+--R                               ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                            *
+--R                               ROOT
+--R                                         2 2 6     2       5     2 2 2 4
+--R                                      - a b e  + 6a b c d e  - 9a c d e
+--R                                    + 
+--R                                              2 3 3       3 4 2    4 6
+--R                                      - 2a b c d e  + 6a c d e  - c d
+--R                                 /
+--R                                       3 5      2 2 4
+--R                                    64a c  - 16a b c
+--R                           + 
+--R                                    2         3  4         2 2       2     3
+--R                                 (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                               + 
+--R                                      3    2 2  3
+--R                                 (4a c  - b c )d e
+--R                            *
+--R                               x
+--R                        *
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R                       + 
+--R                                    2   3       3 2           2 4       2 3
+--R                               ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                            *
+--R                               ROOT
+--R                                         2 2 6     2       5     2 2 2 4
+--R                                      - a b e  + 6a b c d e  - 9a c d e
+--R                                    + 
+--R                                              2 3 3       3 4 2    4 6
+--R                                      - 2a b c d e  + 6a c d e  - c d
+--R                                 /
+--R                                       3 5      2 2 4
+--R                                    64a c  - 16a b c
+--R                           + 
+--R                                      2         3  4       2 2       2     3
+--R                                 (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                               + 
+--R                                        3    2 2  3
+--R                                 (- 4a c  + b c )d e
+--R                            *
+--R                               x
+--R                        *
+--R                            +-+
+--R                           \|d
+--R                    *
+--R                       ROOT
+--R                                    2 3       2 2
+--R                                (16a c  - 4a b c )
+--R                             *
+--R                                ROOT
+--R                                          2 2 6     2       5     2 2 2 4
+--R                                       - a b e  + 6a b c d e  - 9a c d e
+--R                                     + 
+--R                                               2 3 3       3 4 2    4 6
+--R                                       - 2a b c d e  + 6a c d e  - c d
+--R                                  /
+--R                                        3 5      2 2 4
+--R                                     64a c  - 16a b c
+--R                            + 
+--R                                 2       2  3             2       2 2       2 3
+--R                              (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                         /
+--R                              2 3       2 2
+--R                            8a c  - 2a b c
+--R                   + 
+--R                             2   5      2        2    4           2 3
+--R                         - 2a b e  + (6a c + 2a b )d e  - 8a b c d e
+--R                       + 
+--R                             2 3 2       2 4      3 5
+--R                         4a c d e  + 2b c d e - 2c d
+--R                    *
+--R                            +--------+
+--R                        +-+ |   2
+--R                       \|d \|e x  + d
+--R                   + 
+--R                           2   6        2        2    5           2 4
+--R                         2a b e  + (- 6a c - 2a b )d e  + 8a b c d e
+--R                       + 
+--R                               2 3 3       2 4 2     3 5
+--R                         - 4a c d e  - 2b c d e  + 2c d e
+--R                    *
+--R                        2
+--R                       x
+--R                   + 
+--R                       2     5        2        2  2 4           3 3       2 4 2
+--R                     2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                   + 
+--R                           2 5      3 6
+--R                     - 2b c d e + 2c d
+--R                /
+--R                    2
+--R                   x
+--R       + 
+--R                                    +--------+
+--R                        +-+    +-+  |   2          +-+ +-+      2
+--R            +-+    (- x\|e  + \|d )\|e x  + d  + x\|d \|e  - e x  - d
+--R         2e\|e log(--------------------------------------------------)
+--R                                        +--------+
+--R                                    +-+ |   2
+--R                                   \|d \|e x  + d  - d
+--R    /
+--R       2c
+--R     ,
+--R
+--R           c
+--R        *
+--R           ROOT
+--R                        2 3       2 2
+--R                    (16a c  - 4a b c )
+--R                 *
+--R                    ROOT
+--R                              2 2 6     2       5     2 2 2 4         2 3 3
+--R                           - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                         + 
+--R                               3 4 2    4 6
+--R                           6a c d e  - c d
+--R                      /
+--R                            3 5      2 2 4
+--R                         64a c  - 16a b c
+--R                + 
+--R                     2       2  3             2       2 2       2 3
+--R                  (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R             /
+--R                  2 3       2 2
+--R                8a c  - 2a b c
+--R        *
+--R           log
+--R                                 2   3       3 2           2 4       2 3
+--R                            ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                         *
+--R                            ROOT
+--R                                      2 2 6     2       5     2 2 2 4
+--R                                   - a b e  + 6a b c d e  - 9a c d e
+--R                                 + 
+--R                                           2 3 3       3 4 2    4 6
+--R                                   - 2a b c d e  + 6a c d e  - c d
+--R                              /
+--R                                    3 5      2 2 4
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                                   2         3  4       2 2       2     3
+--R                              (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                            + 
+--R                                     3    2 2  3
+--R                              (- 4a c  + b c )d e
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                   2   3       3 2         2 4       2 3
+--R                            ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                         *
+--R                            ROOT
+--R                                      2 2 6     2       5     2 2 2 4
+--R                                   - a b e  + 6a b c d e  - 9a c d e
+--R                                 + 
+--R                                           2 3 3       3 4 2    4 6
+--R                                   - 2a b c d e  + 6a c d e  - c d
+--R                              /
+--R                                    3 5      2 2 4
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                                 2         3  4         2 2       2     3
+--R                              (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                            + 
+--R                                   3    2 2  3
+--R                              (4a c  - b c )d e
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                 2 3       2 2
+--R                             (16a c  - 4a b c )
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                              2       2  3             2       2 2       2 3
+--R                           (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                      /
+--R                           2 3       2 2
+--R                         8a c  - 2a b c
+--R                + 
+--R                          2   5      2        2    4           2 3       2 3 2
+--R                      - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                    + 
+--R                          2 4      3 5
+--R                      2b c d e - 2c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                        2   6        2        2    5           2 4       2 3 3
+--R                      2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                    + 
+--R                            2 4 2     3 5
+--R                      - 2b c d e  + 2c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                    2     5        2        2  2 4           3 3       2 4 2
+--R                  2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                + 
+--R                        2 5      3 6
+--R                  - 2b c d e + 2c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R         -
+--R              c
+--R           *
+--R              ROOT
+--R                             2 3       2 2
+--R                       (- 16a c  + 4a b c )
+--R                    *
+--R                       ROOT
+--R                                 2 2 6     2       5     2 2 2 4         2 3 3
+--R                              - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                            + 
+--R                                  3 4 2    4 6
+--R                              6a c d e  - c d
+--R                         /
+--R                               3 5      2 2 4
+--R                            64a c  - 16a b c
+--R                   + 
+--R                        2       2  3             2       2 2       2 3
+--R                     (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                /
+--R                     2 3       2 2
+--R                   8a c  - 2a b c
+--R           *
+--R              log
+--R                                    2   3       3 2           2 4       2 3
+--R                               ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                            *
+--R                               ROOT
+--R                                         2 2 6     2       5     2 2 2 4
+--R                                      - a b e  + 6a b c d e  - 9a c d e
+--R                                    + 
+--R                                              2 3 3       3 4 2    4 6
+--R                                      - 2a b c d e  + 6a c d e  - c d
+--R                                 /
+--R                                       3 5      2 2 4
+--R                                    64a c  - 16a b c
+--R                           + 
+--R                                    2         3  4         2 2       2     3
+--R                                 (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                               + 
+--R                                      3    2 2  3
+--R                                 (4a c  - b c )d e
+--R                            *
+--R                               x
+--R                        *
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R                       + 
+--R                                      2   3       3 2         2 4       2 3
+--R                               ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                            *
+--R                               ROOT
+--R                                         2 2 6     2       5     2 2 2 4
+--R                                      - a b e  + 6a b c d e  - 9a c d e
+--R                                    + 
+--R                                              2 3 3       3 4 2    4 6
+--R                                      - 2a b c d e  + 6a c d e  - c d
+--R                                 /
+--R                                       3 5      2 2 4
+--R                                    64a c  - 16a b c
+--R                           + 
+--R                                      2         3  4       2 2       2     3
+--R                                 (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                               + 
+--R                                        3    2 2  3
+--R                                 (- 4a c  + b c )d e
+--R                            *
+--R                               x
+--R                        *
+--R                            +-+
+--R                           \|d
+--R                    *
+--R                       ROOT
+--R                                      2 3       2 2
+--R                                (- 16a c  + 4a b c )
+--R                             *
+--R                                ROOT
+--R                                          2 2 6     2       5     2 2 2 4
+--R                                       - a b e  + 6a b c d e  - 9a c d e
+--R                                     + 
+--R                                               2 3 3       3 4 2    4 6
+--R                                       - 2a b c d e  + 6a c d e  - c d
+--R                                  /
+--R                                        3 5      2 2 4
+--R                                     64a c  - 16a b c
+--R                            + 
+--R                                 2       2  3             2       2 2       2 3
+--R                              (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                         /
+--R                              2 3       2 2
+--R                            8a c  - 2a b c
+--R                   + 
+--R                             2   5      2        2    4           2 3
+--R                         - 2a b e  + (6a c + 2a b )d e  - 8a b c d e
+--R                       + 
+--R                             2 3 2       2 4      3 5
+--R                         4a c d e  + 2b c d e - 2c d
+--R                    *
+--R                            +--------+
+--R                        +-+ |   2
+--R                       \|d \|e x  + d
+--R                   + 
+--R                           2   6        2        2    5           2 4
+--R                         2a b e  + (- 6a c - 2a b )d e  + 8a b c d e
+--R                       + 
+--R                               2 3 3       2 4 2     3 5
+--R                         - 4a c d e  - 2b c d e  + 2c d e
+--R                    *
+--R                        2
+--R                       x
+--R                   + 
+--R                       2     5        2        2  2 4           3 3       2 4 2
+--R                     2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                   + 
+--R                           2 5      3 6
+--R                     - 2b c d e + 2c d
+--R                /
+--R                    2
+--R                   x
+--R       + 
+--R           c
+--R        *
+--R           ROOT
+--R                          2 3       2 2
+--R                    (- 16a c  + 4a b c )
+--R                 *
+--R                    ROOT
+--R                              2 2 6     2       5     2 2 2 4         2 3 3
+--R                           - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                         + 
+--R                               3 4 2    4 6
+--R                           6a c d e  - c d
+--R                      /
+--R                            3 5      2 2 4
+--R                         64a c  - 16a b c
+--R                + 
+--R                     2       2  3             2       2 2       2 3
+--R                  (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R             /
+--R                  2 3       2 2
+--R                8a c  - 2a b c
+--R        *
+--R           log
+--R                                   2   3       3 2         2 4       2 3
+--R                            ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                         *
+--R                            ROOT
+--R                                      2 2 6     2       5     2 2 2 4
+--R                                   - a b e  + 6a b c d e  - 9a c d e
+--R                                 + 
+--R                                           2 3 3       3 4 2    4 6
+--R                                   - 2a b c d e  + 6a c d e  - c d
+--R                              /
+--R                                    3 5      2 2 4
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                                   2         3  4       2 2       2     3
+--R                              (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                            + 
+--R                                     3    2 2  3
+--R                              (- 4a c  + b c )d e
+--R                         *
+--R                            x
+--R                     *
+--R                         +--------+
+--R                         |   2
+--R                        \|e x  + d
+--R                    + 
+--R                                 2   3       3 2           2 4       2 3
+--R                            ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                         *
+--R                            ROOT
+--R                                      2 2 6     2       5     2 2 2 4
+--R                                   - a b e  + 6a b c d e  - 9a c d e
+--R                                 + 
+--R                                           2 3 3       3 4 2    4 6
+--R                                   - 2a b c d e  + 6a c d e  - c d
+--R                              /
+--R                                    3 5      2 2 4
+--R                                 64a c  - 16a b c
+--R                        + 
+--R                                 2         3  4         2 2       2     3
+--R                              (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                            + 
+--R                                   3    2 2  3
+--R                              (4a c  - b c )d e
+--R                         *
+--R                            x
+--R                     *
+--R                         +-+
+--R                        \|d
+--R                 *
+--R                    ROOT
+--R                                   2 3       2 2
+--R                             (- 16a c  + 4a b c )
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                              2       2  3             2       2 2       2 3
+--R                           (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                      /
+--R                           2 3       2 2
+--R                         8a c  - 2a b c
+--R                + 
+--R                          2   5      2        2    4           2 3       2 3 2
+--R                      - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                    + 
+--R                          2 4      3 5
+--R                      2b c d e - 2c d
+--R                 *
+--R                         +--------+
+--R                     +-+ |   2
+--R                    \|d \|e x  + d
+--R                + 
+--R                        2   6        2        2    5           2 4       2 3 3
+--R                      2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                    + 
+--R                            2 4 2     3 5
+--R                      - 2b c d e  + 2c d e
+--R                 *
+--R                     2
+--R                    x
+--R                + 
+--R                    2     5        2        2  2 4           3 3       2 4 2
+--R                  2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                + 
+--R                        2 5      3 6
+--R                  - 2b c d e + 2c d
+--R             /
+--R                 2
+--R                x
+--R       + 
+--R         -
+--R              c
+--R           *
+--R              ROOT
+--R                           2 3       2 2
+--R                       (16a c  - 4a b c )
+--R                    *
+--R                       ROOT
+--R                                 2 2 6     2       5     2 2 2 4         2 3 3
+--R                              - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                            + 
+--R                                  3 4 2    4 6
+--R                              6a c d e  - c d
+--R                         /
+--R                               3 5      2 2 4
+--R                            64a c  - 16a b c
+--R                   + 
+--R                        2       2  3             2       2 2       2 3
+--R                     (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                /
+--R                     2 3       2 2
+--R                   8a c  - 2a b c
+--R           *
+--R              log
+--R                                      2   3       3 2         2 4       2 3
+--R                               ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                            *
+--R                               ROOT
+--R                                         2 2 6     2       5     2 2 2 4
+--R                                      - a b e  + 6a b c d e  - 9a c d e
+--R                                    + 
+--R                                              2 3 3       3 4 2    4 6
+--R                                      - 2a b c d e  + 6a c d e  - c d
+--R                                 /
+--R                                       3 5      2 2 4
+--R                                    64a c  - 16a b c
+--R                           + 
+--R                                    2         3  4         2 2       2     3
+--R                                 (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                               + 
+--R                                      3    2 2  3
+--R                                 (4a c  - b c )d e
+--R                            *
+--R                               x
+--R                        *
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R                       + 
+--R                                    2   3       3 2           2 4       2 3
+--R                               ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                            *
+--R                               ROOT
+--R                                         2 2 6     2       5     2 2 2 4
+--R                                      - a b e  + 6a b c d e  - 9a c d e
+--R                                    + 
+--R                                              2 3 3       3 4 2    4 6
+--R                                      - 2a b c d e  + 6a c d e  - c d
+--R                                 /
+--R                                       3 5      2 2 4
+--R                                    64a c  - 16a b c
+--R                           + 
+--R                                      2         3  4       2 2       2     3
+--R                                 (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                               + 
+--R                                        3    2 2  3
+--R                                 (- 4a c  + b c )d e
+--R                            *
+--R                               x
+--R                        *
+--R                            +-+
+--R                           \|d
+--R                    *
+--R                       ROOT
+--R                                    2 3       2 2
+--R                                (16a c  - 4a b c )
+--R                             *
+--R                                ROOT
+--R                                          2 2 6     2       5     2 2 2 4
+--R                                       - a b e  + 6a b c d e  - 9a c d e
+--R                                     + 
+--R                                               2 3 3       3 4 2    4 6
+--R                                       - 2a b c d e  + 6a c d e  - c d
+--R                                  /
+--R                                        3 5      2 2 4
+--R                                     64a c  - 16a b c
+--R                            + 
+--R                                 2       2  3             2       2 2       2 3
+--R                              (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                         /
+--R                              2 3       2 2
+--R                            8a c  - 2a b c
+--R                   + 
+--R                             2   5      2        2    4           2 3
+--R                         - 2a b e  + (6a c + 2a b )d e  - 8a b c d e
+--R                       + 
+--R                             2 3 2       2 4      3 5
+--R                         4a c d e  + 2b c d e - 2c d
+--R                    *
+--R                            +--------+
+--R                        +-+ |   2
+--R                       \|d \|e x  + d
+--R                   + 
+--R                           2   6        2        2    5           2 4
+--R                         2a b e  + (- 6a c - 2a b )d e  + 8a b c d e
+--R                       + 
+--R                               2 3 3       2 4 2     3 5
+--R                         - 4a c d e  - 2b c d e  + 2c d e
+--R                    *
+--R                        2
+--R                       x
+--R                   + 
+--R                       2     5        2        2  2 4           3 3       2 4 2
+--R                     2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                   + 
+--R                           2 5      3 6
+--R                     - 2b c d e + 2c d
+--R                /
+--R                    2
+--R                   x
+--R       + 
+--R                       +--------+
+--R                       |   2         +-+
+--R            +---+     \|e x  + d  - \|d
+--R         4e\|- e atan(------------------)
+--R                              +---+
+--R                            x\|- e
+--R    /
+--R       2c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 3065
+
+--S 3066 of 3139
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         +------------------------------+
+--R           +-----------+ |    +-----------+
+--R           |          2  |    |          2
+--R         c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                      2 3       2 2
+--R                  (16a c  - 4a b c )
+--R               *
+--R                  ROOT
+--R                            2 2 6     2       5     2 2 2 4         2 3 3
+--R                         - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                       + 
+--R                             3 4 2    4 6
+--R                         6a c d e  - c d
+--R                    /
+--R                          3 5      2 2 4
+--R                       64a c  - 16a b c
+--R              + 
+--R                   2       2  3             2       2 2       2 3
+--R                (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R           /
+--R                2 3       2 2
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                               2   3       3 2           2 4       2 3
+--R                          ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                       *
+--R                          ROOT
+--R                                    2 2 6     2       5     2 2 2 4
+--R                                 - a b e  + 6a b c d e  - 9a c d e
+--R                               + 
+--R                                         2 3 3       3 4 2    4 6
+--R                                 - 2a b c d e  + 6a c d e  - c d
+--R                            /
+--R                                  3 5      2 2 4
+--R                               64a c  - 16a b c
+--R                      + 
+--R                                 2         3  4       2 2       2     3
+--R                            (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                          + 
+--R                                   3    2 2  3
+--R                            (- 4a c  + b c )d e
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                 2   3       3 2         2 4       2 3
+--R                          ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                       *
+--R                          ROOT
+--R                                    2 2 6     2       5     2 2 2 4
+--R                                 - a b e  + 6a b c d e  - 9a c d e
+--R                               + 
+--R                                         2 3 3       3 4 2    4 6
+--R                                 - 2a b c d e  + 6a c d e  - c d
+--R                            /
+--R                                  3 5      2 2 4
+--R                               64a c  - 16a b c
+--R                      + 
+--R                               2         3  4         2 2       2     3
+--R                            (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                          + 
+--R                                 3    2 2  3
+--R                            (4a c  - b c )d e
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               2 3       2 2
+--R                           (16a c  - 4a b c )
+--R                        *
+--R                           ROOT
+--R                                     2 2 6     2       5     2 2 2 4
+--R                                  - a b e  + 6a b c d e  - 9a c d e
+--R                                + 
+--R                                          2 3 3       3 4 2    4 6
+--R                                  - 2a b c d e  + 6a c d e  - c d
+--R                             /
+--R                                   3 5      2 2 4
+--R                                64a c  - 16a b c
+--R                       + 
+--R                            2       2  3             2       2 2       2 3
+--R                         (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                    /
+--R                         2 3       2 2
+--R                       8a c  - 2a b c
+--R              + 
+--R                        2   5      2        2    4           2 3       2 3 2
+--R                    - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                  + 
+--R                        2 4      3 5
+--R                    2b c d e - 2c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      2   6        2        2    5           2 4       2 3 3
+--R                    2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                  + 
+--R                          2 4 2     3 5
+--R                    - 2b c d e  + 2c d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  2     5        2        2  2 4           3 3       2 4 2
+--R                2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R              + 
+--R                      2 5      3 6
+--R                - 2b c d e + 2c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R              |          2  |    |          2
+--R            c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                           2 3       2 2
+--R                     (- 16a c  + 4a b c )
+--R                  *
+--R                     ROOT
+--R                               2 2 6     2       5     2 2 2 4         2 3 3
+--R                            - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                          + 
+--R                                3 4 2    4 6
+--R                            6a c d e  - c d
+--R                       /
+--R                             3 5      2 2 4
+--R                          64a c  - 16a b c
+--R                 + 
+--R                      2       2  3             2       2 2       2 3
+--R                   (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R              /
+--R                   2 3       2 2
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                  2   3       3 2           2 4       2 3
+--R                             ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                                  2         3  4         2 2       2     3
+--R                               (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                             + 
+--R                                    3    2 2  3
+--R                               (4a c  - b c )d e
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                    2   3       3 2         2 4       2 3
+--R                             ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                                    2         3  4       2 2       2     3
+--R                               (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                             + 
+--R                                      3    2 2  3
+--R                               (- 4a c  + b c )d e
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                    2 3       2 2
+--R                              (- 16a c  + 4a b c )
+--R                           *
+--R                              ROOT
+--R                                        2 2 6     2       5     2 2 2 4
+--R                                     - a b e  + 6a b c d e  - 9a c d e
+--R                                   + 
+--R                                             2 3 3       3 4 2    4 6
+--R                                     - 2a b c d e  + 6a c d e  - c d
+--R                                /
+--R                                      3 5      2 2 4
+--R                                   64a c  - 16a b c
+--R                          + 
+--R                               2       2  3             2       2 2       2 3
+--R                            (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                       /
+--R                            2 3       2 2
+--R                          8a c  - 2a b c
+--R                 + 
+--R                           2   5      2        2    4           2 3       2 3 2
+--R                       - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                     + 
+--R                           2 4      3 5
+--R                       2b c d e - 2c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                         2   6        2        2    5           2 4       2 3 3
+--R                       2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                     + 
+--R                             2 4 2     3 5
+--R                       - 2b c d e  + 2c d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     2     5        2        2  2 4           3 3       2 4 2
+--R                   2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                 + 
+--R                         2 5      3 6
+--R                   - 2b c d e + 2c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                         +------------------------------+
+--R           +-----------+ |    +-----------+
+--R           |          2  |    |          2
+--R         c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        2 3       2 2
+--R                  (- 16a c  + 4a b c )
+--R               *
+--R                  ROOT
+--R                            2 2 6     2       5     2 2 2 4         2 3 3
+--R                         - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                       + 
+--R                             3 4 2    4 6
+--R                         6a c d e  - c d
+--R                    /
+--R                          3 5      2 2 4
+--R                       64a c  - 16a b c
+--R              + 
+--R                   2       2  3             2       2 2       2 3
+--R                (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R           /
+--R                2 3       2 2
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                 2   3       3 2         2 4       2 3
+--R                          ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                       *
+--R                          ROOT
+--R                                    2 2 6     2       5     2 2 2 4
+--R                                 - a b e  + 6a b c d e  - 9a c d e
+--R                               + 
+--R                                         2 3 3       3 4 2    4 6
+--R                                 - 2a b c d e  + 6a c d e  - c d
+--R                            /
+--R                                  3 5      2 2 4
+--R                               64a c  - 16a b c
+--R                      + 
+--R                                 2         3  4       2 2       2     3
+--R                            (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                          + 
+--R                                   3    2 2  3
+--R                            (- 4a c  + b c )d e
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                               2   3       3 2           2 4       2 3
+--R                          ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                       *
+--R                          ROOT
+--R                                    2 2 6     2       5     2 2 2 4
+--R                                 - a b e  + 6a b c d e  - 9a c d e
+--R                               + 
+--R                                         2 3 3       3 4 2    4 6
+--R                                 - 2a b c d e  + 6a c d e  - c d
+--R                            /
+--R                                  3 5      2 2 4
+--R                               64a c  - 16a b c
+--R                      + 
+--R                               2         3  4         2 2       2     3
+--R                            (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                          + 
+--R                                 3    2 2  3
+--R                            (4a c  - b c )d e
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 2 3       2 2
+--R                           (- 16a c  + 4a b c )
+--R                        *
+--R                           ROOT
+--R                                     2 2 6     2       5     2 2 2 4
+--R                                  - a b e  + 6a b c d e  - 9a c d e
+--R                                + 
+--R                                          2 3 3       3 4 2    4 6
+--R                                  - 2a b c d e  + 6a c d e  - c d
+--R                             /
+--R                                   3 5      2 2 4
+--R                                64a c  - 16a b c
+--R                       + 
+--R                            2       2  3             2       2 2       2 3
+--R                         (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                    /
+--R                         2 3       2 2
+--R                       8a c  - 2a b c
+--R              + 
+--R                        2   5      2        2    4           2 3       2 3 2
+--R                    - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                  + 
+--R                        2 4      3 5
+--R                    2b c d e - 2c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      2   6        2        2    5           2 4       2 3 3
+--R                    2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                  + 
+--R                          2 4 2     3 5
+--R                    - 2b c d e  + 2c d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  2     5        2        2  2 4           3 3       2 4 2
+--R                2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R              + 
+--R                      2 5      3 6
+--R                - 2b c d e + 2c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R              |          2  |    |          2
+--R            c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                         2 3       2 2
+--R                     (16a c  - 4a b c )
+--R                  *
+--R                     ROOT
+--R                               2 2 6     2       5     2 2 2 4         2 3 3
+--R                            - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                          + 
+--R                                3 4 2    4 6
+--R                            6a c d e  - c d
+--R                       /
+--R                             3 5      2 2 4
+--R                          64a c  - 16a b c
+--R                 + 
+--R                      2       2  3             2       2 2       2 3
+--R                   (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R              /
+--R                   2 3       2 2
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                    2   3       3 2         2 4       2 3
+--R                             ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                                  2         3  4         2 2       2     3
+--R                               (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                             + 
+--R                                    3    2 2  3
+--R                               (4a c  - b c )d e
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                  2   3       3 2           2 4       2 3
+--R                             ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                                    2         3  4       2 2       2     3
+--R                               (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                             + 
+--R                                      3    2 2  3
+--R                               (- 4a c  + b c )d e
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                  2 3       2 2
+--R                              (16a c  - 4a b c )
+--R                           *
+--R                              ROOT
+--R                                        2 2 6     2       5     2 2 2 4
+--R                                     - a b e  + 6a b c d e  - 9a c d e
+--R                                   + 
+--R                                             2 3 3       3 4 2    4 6
+--R                                     - 2a b c d e  + 6a c d e  - c d
+--R                                /
+--R                                      3 5      2 2 4
+--R                                   64a c  - 16a b c
+--R                          + 
+--R                               2       2  3             2       2 2       2 3
+--R                            (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                       /
+--R                            2 3       2 2
+--R                          8a c  - 2a b c
+--R                 + 
+--R                           2   5      2        2    4           2 3       2 3 2
+--R                       - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                     + 
+--R                           2 4      3 5
+--R                       2b c d e - 2c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                         2   6        2        2    5           2 4       2 3 3
+--R                       2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                     + 
+--R                             2 4 2     3 5
+--R                       - 2b c d e  + 2c d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     2     5        2        2  2 4           3 3       2 4 2
+--R                   2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                 + 
+--R                         2 5      3 6
+--R                   - 2b c d e + 2c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                                +-----------+
+--R                    2           |          2                2  2
+--R             (- 2b e  + 4c d e)\|- 4a c + b   + (- 4a c + 2b )e  - 4b c d e
+--R           + 
+--R               2 2
+--R             4c d
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                           +-----------+
+--R               2           |          2                2  2                2 2
+--R         ((2b e  - 4c d e)\|- 4a c + b   + (- 4a c + 2b )e  - 4b c d e + 4c d )
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                +-----------+
+--R                |          2  +-+
+--R             2e\|- 4a c + b  \|e
+--R          *
+--R                                  +--------+
+--R                      +-+    +-+  |   2          +-+ +-+      2
+--R                 (- x\|e  + \|d )\|e x  + d  + x\|d \|e  - e x  - d
+--R             log(--------------------------------------------------)
+--R                                      +--------+
+--R                                  +-+ |   2
+--R                                 \|d \|e x  + d  - d
+--R         + 
+--R                +-----------+               +-+
+--R                |          2  +-+         x\|e
+--R           - 2e\|- 4a c + b  \|e atanh(-----------)
+--R                                        +--------+
+--R                                        |   2
+--R                                       \|e x  + d
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                        +------------------------------+ +------------------+
+--R          +-----------+ |    +-----------+               | +-----------+
+--R          |          2  |    |          2                | |          2
+--R       2c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3066
+
+--S 3067 of 3139
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3067
+
+--S 3068 of 3139
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         +------------------------------+
+--R           +-----------+ |    +-----------+
+--R           |          2  |    |          2
+--R         c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                      2 3       2 2
+--R                  (16a c  - 4a b c )
+--R               *
+--R                  ROOT
+--R                            2 2 6     2       5     2 2 2 4         2 3 3
+--R                         - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                       + 
+--R                             3 4 2    4 6
+--R                         6a c d e  - c d
+--R                    /
+--R                          3 5      2 2 4
+--R                       64a c  - 16a b c
+--R              + 
+--R                   2       2  3             2       2 2       2 3
+--R                (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R           /
+--R                2 3       2 2
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                               2   3       3 2           2 4       2 3
+--R                          ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                       *
+--R                          ROOT
+--R                                    2 2 6     2       5     2 2 2 4
+--R                                 - a b e  + 6a b c d e  - 9a c d e
+--R                               + 
+--R                                         2 3 3       3 4 2    4 6
+--R                                 - 2a b c d e  + 6a c d e  - c d
+--R                            /
+--R                                  3 5      2 2 4
+--R                               64a c  - 16a b c
+--R                      + 
+--R                                 2         3  4       2 2       2     3
+--R                            (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                          + 
+--R                                   3    2 2  3
+--R                            (- 4a c  + b c )d e
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                 2   3       3 2         2 4       2 3
+--R                          ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                       *
+--R                          ROOT
+--R                                    2 2 6     2       5     2 2 2 4
+--R                                 - a b e  + 6a b c d e  - 9a c d e
+--R                               + 
+--R                                         2 3 3       3 4 2    4 6
+--R                                 - 2a b c d e  + 6a c d e  - c d
+--R                            /
+--R                                  3 5      2 2 4
+--R                               64a c  - 16a b c
+--R                      + 
+--R                               2         3  4         2 2       2     3
+--R                            (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                          + 
+--R                                 3    2 2  3
+--R                            (4a c  - b c )d e
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               2 3       2 2
+--R                           (16a c  - 4a b c )
+--R                        *
+--R                           ROOT
+--R                                     2 2 6     2       5     2 2 2 4
+--R                                  - a b e  + 6a b c d e  - 9a c d e
+--R                                + 
+--R                                          2 3 3       3 4 2    4 6
+--R                                  - 2a b c d e  + 6a c d e  - c d
+--R                             /
+--R                                   3 5      2 2 4
+--R                                64a c  - 16a b c
+--R                       + 
+--R                            2       2  3             2       2 2       2 3
+--R                         (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                    /
+--R                         2 3       2 2
+--R                       8a c  - 2a b c
+--R              + 
+--R                        2   5      2        2    4           2 3       2 3 2
+--R                    - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                  + 
+--R                        2 4      3 5
+--R                    2b c d e - 2c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      2   6        2        2    5           2 4       2 3 3
+--R                    2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                  + 
+--R                          2 4 2     3 5
+--R                    - 2b c d e  + 2c d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  2     5        2        2  2 4           3 3       2 4 2
+--R                2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R              + 
+--R                      2 5      3 6
+--R                - 2b c d e + 2c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R              |          2  |    |          2
+--R            c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                           2 3       2 2
+--R                     (- 16a c  + 4a b c )
+--R                  *
+--R                     ROOT
+--R                               2 2 6     2       5     2 2 2 4         2 3 3
+--R                            - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                          + 
+--R                                3 4 2    4 6
+--R                            6a c d e  - c d
+--R                       /
+--R                             3 5      2 2 4
+--R                          64a c  - 16a b c
+--R                 + 
+--R                      2       2  3             2       2 2       2 3
+--R                   (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R              /
+--R                   2 3       2 2
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                  2   3       3 2           2 4       2 3
+--R                             ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                                  2         3  4         2 2       2     3
+--R                               (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                             + 
+--R                                    3    2 2  3
+--R                               (4a c  - b c )d e
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                    2   3       3 2         2 4       2 3
+--R                             ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                                    2         3  4       2 2       2     3
+--R                               (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                             + 
+--R                                      3    2 2  3
+--R                               (- 4a c  + b c )d e
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                    2 3       2 2
+--R                              (- 16a c  + 4a b c )
+--R                           *
+--R                              ROOT
+--R                                        2 2 6     2       5     2 2 2 4
+--R                                     - a b e  + 6a b c d e  - 9a c d e
+--R                                   + 
+--R                                             2 3 3       3 4 2    4 6
+--R                                     - 2a b c d e  + 6a c d e  - c d
+--R                                /
+--R                                      3 5      2 2 4
+--R                                   64a c  - 16a b c
+--R                          + 
+--R                               2       2  3             2       2 2       2 3
+--R                            (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                       /
+--R                            2 3       2 2
+--R                          8a c  - 2a b c
+--R                 + 
+--R                           2   5      2        2    4           2 3       2 3 2
+--R                       - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                     + 
+--R                           2 4      3 5
+--R                       2b c d e - 2c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                         2   6        2        2    5           2 4       2 3 3
+--R                       2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                     + 
+--R                             2 4 2     3 5
+--R                       - 2b c d e  + 2c d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     2     5        2        2  2 4           3 3       2 4 2
+--R                   2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                 + 
+--R                         2 5      3 6
+--R                   - 2b c d e + 2c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                         +------------------------------+
+--R           +-----------+ |    +-----------+
+--R           |          2  |    |          2
+--R         c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        2 3       2 2
+--R                  (- 16a c  + 4a b c )
+--R               *
+--R                  ROOT
+--R                            2 2 6     2       5     2 2 2 4         2 3 3
+--R                         - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                       + 
+--R                             3 4 2    4 6
+--R                         6a c d e  - c d
+--R                    /
+--R                          3 5      2 2 4
+--R                       64a c  - 16a b c
+--R              + 
+--R                   2       2  3             2       2 2       2 3
+--R                (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R           /
+--R                2 3       2 2
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                                 2   3       3 2         2 4       2 3
+--R                          ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                       *
+--R                          ROOT
+--R                                    2 2 6     2       5     2 2 2 4
+--R                                 - a b e  + 6a b c d e  - 9a c d e
+--R                               + 
+--R                                         2 3 3       3 4 2    4 6
+--R                                 - 2a b c d e  + 6a c d e  - c d
+--R                            /
+--R                                  3 5      2 2 4
+--R                               64a c  - 16a b c
+--R                      + 
+--R                                 2         3  4       2 2       2     3
+--R                            (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                          + 
+--R                                   3    2 2  3
+--R                            (- 4a c  + b c )d e
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                               2   3       3 2           2 4       2 3
+--R                          ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                       *
+--R                          ROOT
+--R                                    2 2 6     2       5     2 2 2 4
+--R                                 - a b e  + 6a b c d e  - 9a c d e
+--R                               + 
+--R                                         2 3 3       3 4 2    4 6
+--R                                 - 2a b c d e  + 6a c d e  - c d
+--R                            /
+--R                                  3 5      2 2 4
+--R                               64a c  - 16a b c
+--R                      + 
+--R                               2         3  4         2 2       2     3
+--R                            (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                          + 
+--R                                 3    2 2  3
+--R                            (4a c  - b c )d e
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 2 3       2 2
+--R                           (- 16a c  + 4a b c )
+--R                        *
+--R                           ROOT
+--R                                     2 2 6     2       5     2 2 2 4
+--R                                  - a b e  + 6a b c d e  - 9a c d e
+--R                                + 
+--R                                          2 3 3       3 4 2    4 6
+--R                                  - 2a b c d e  + 6a c d e  - c d
+--R                             /
+--R                                   3 5      2 2 4
+--R                                64a c  - 16a b c
+--R                       + 
+--R                            2       2  3             2       2 2       2 3
+--R                         (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                    /
+--R                         2 3       2 2
+--R                       8a c  - 2a b c
+--R              + 
+--R                        2   5      2        2    4           2 3       2 3 2
+--R                    - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                  + 
+--R                        2 4      3 5
+--R                    2b c d e - 2c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      2   6        2        2    5           2 4       2 3 3
+--R                    2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                  + 
+--R                          2 4 2     3 5
+--R                    - 2b c d e  + 2c d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  2     5        2        2  2 4           3 3       2 4 2
+--R                2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R              + 
+--R                      2 5      3 6
+--R                - 2b c d e + 2c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                            +------------------------------+
+--R              +-----------+ |    +-----------+
+--R              |          2  |    |          2
+--R            c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                         2 3       2 2
+--R                     (16a c  - 4a b c )
+--R                  *
+--R                     ROOT
+--R                               2 2 6     2       5     2 2 2 4         2 3 3
+--R                            - a b e  + 6a b c d e  - 9a c d e  - 2a b c d e
+--R                          + 
+--R                                3 4 2    4 6
+--R                            6a c d e  - c d
+--R                       /
+--R                             3 5      2 2 4
+--R                          64a c  - 16a b c
+--R                 + 
+--R                      2       2  3             2       2 2       2 3
+--R                   (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R              /
+--R                   2 3       2 2
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                    2   3       3 2         2 4       2 3
+--R                             ((- 16a b c  + 4a b c )e + (32a c  - 8a b c )d)x
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                                  2         3  4         2 2       2     3
+--R                               (4a b c - a b )e  + (- 12a c  + 3a b c)d e
+--R                             + 
+--R                                    3    2 2  3
+--R                               (4a c  - b c )d e
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                  2   3       3 2           2 4       2 3
+--R                             ((16a b c  - 4a b c )e + (- 32a c  + 8a b c )d)x
+--R                          *
+--R                             ROOT
+--R                                       2 2 6     2       5     2 2 2 4
+--R                                    - a b e  + 6a b c d e  - 9a c d e
+--R                                  + 
+--R                                            2 3 3       3 4 2    4 6
+--R                                    - 2a b c d e  + 6a c d e  - c d
+--R                               /
+--R                                     3 5      2 2 4
+--R                                  64a c  - 16a b c
+--R                         + 
+--R                                    2         3  4       2 2       2     3
+--R                               (- 4a b c + a b )e  + (12a c  - 3a b c)d e
+--R                             + 
+--R                                      3    2 2  3
+--R                               (- 4a c  + b c )d e
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                  2 3       2 2
+--R                              (16a c  - 4a b c )
+--R                           *
+--R                              ROOT
+--R                                        2 2 6     2       5     2 2 2 4
+--R                                     - a b e  + 6a b c d e  - 9a c d e
+--R                                   + 
+--R                                             2 3 3       3 4 2    4 6
+--R                                     - 2a b c d e  + 6a c d e  - c d
+--R                                /
+--R                                      3 5      2 2 4
+--R                                   64a c  - 16a b c
+--R                          + 
+--R                               2       2  3             2       2 2       2 3
+--R                            (2a c - a b )e  + 3a b c d e  - 6a c d e + b c d
+--R                       /
+--R                            2 3       2 2
+--R                          8a c  - 2a b c
+--R                 + 
+--R                           2   5      2        2    4           2 3       2 3 2
+--R                       - 2a b e  + (6a c + 2a b )d e  - 8a b c d e  + 4a c d e
+--R                     + 
+--R                           2 4      3 5
+--R                       2b c d e - 2c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                         2   6        2        2    5           2 4       2 3 3
+--R                       2a b e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                     + 
+--R                             2 4 2     3 5
+--R                       - 2b c d e  + 2c d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     2     5        2        2  2 4           3 3       2 4 2
+--R                   2a b d e  + (- 6a c - 2a b )d e  + 8a b c d e  - 4a c d e
+--R                 + 
+--R                         2 5      3 6
+--R                   - 2b c d e + 2c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                                +-----------+
+--R                    2           |          2                2  2
+--R             (- 2b e  + 4c d e)\|- 4a c + b   + (- 4a c + 2b )e  - 4b c d e
+--R           + 
+--R               2 2
+--R             4c d
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                           +-----------+
+--R               2           |          2                2  2                2 2
+--R         ((2b e  - 4c d e)\|- 4a c + b   + (- 4a c + 2b )e  - 4b c d e + 4c d )
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                +-----------+               +-+
+--R                |          2  +-+         x\|e
+--R           - 2e\|- 4a c + b  \|e atanh(-----------)
+--R                                        +--------+
+--R                                        |   2
+--R                                       \|e x  + d
+--R         + 
+--R                                       +--------+
+--R                    +-----------+      |   2         +-+
+--R              +---+ |          2      \|e x  + d  - \|d
+--R           4e\|- e \|- 4a c + b  atan(------------------)
+--R                                              +---+
+--R                                            x\|- e
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                        +------------------------------+ +------------------+
+--R          +-----------+ |    +-----------+               | +-----------+
+--R          |          2  |    |          2                | |          2
+--R       2c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3068
+
+--S 3069 of 3139
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 3069
+
+)clear all
+
+--S 3070 of 3139
+t0:=(d+e*x^2)^(3/2)/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R             5      3
+--R          c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3070
+
+--S 3071 of 3139
+r0:=-d^(3/2)*atanh(sqrt(d+e*x^2)/sqrt(d))/a+atanh(sqrt(2)*sqrt(c)*_
+   sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))*(c*d^2-a*e^2+_
+   (b*c*d^2-4*a*c*d*e+a*b*e^2)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(c)*_
+   sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))+atanh(sqrt(2)*sqrt(c)*_
+   sqrt(d+e*x^2)/sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*(c*d^2-a*e^2+_
+   (-b*c*d^2+4*a*c*d*e-a*b*e^2)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(c)*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R                2      2  |          2         2                   2
+--R         ((- a e  + c d )\|- 4a c + b   - a b e  + 4a c d e - b c d )
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                          +-----------+
+--R                2      2  |          2         2                   2
+--R         ((- a e  + c d )\|- 4a c + b   + a b e  - 4a c d e + b c d )
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R       -
+--R                                              +--------+
+--R                  +-----------+               |   2
+--R              +-+ |          2  +-+ +-+      \|e x  + d
+--R            d\|2 \|- 4a c + b  \|c \|d atanh(-----------)
+--R                                                  +-+
+--R                                                 \|d
+--R         *
+--R             +------------------------------+ +----------------------------+
+--R             |    +-----------+               |  +-----------+
+--R             |    |          2                |  |          2
+--R            \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                               +------------------------------+
+--R             +-----------+     |    +-----------+
+--R         +-+ |          2  +-+ |    |          2
+--R       a\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3071
+
+--S 3072 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         a
+--R      *
+--R         ROOT
+--R                      3 2     2 2
+--R                  (16a c  - 4a b c)
+--R               *
+--R                  ROOT
+--R                            4 6     3   2 4     2     3 3     2 2 4 2
+--R                         - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                       + 
+--R                               2 5     2 2 6
+--R                         6a b c d e - b c d
+--R                    /
+--R                          5 3      4 2 2
+--R                       64a c  - 16a b c
+--R              + 
+--R                 2   3     2     2           2         2    2   3
+--R                a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R           /
+--R                3 2     2 2
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                           4   2     3 3            4 3     3 2 2    2
+--R                      ((16a b c  - 4a b c)e + (- 32a c  + 8a b c )d)x
+--R                   *
+--R                      ROOT
+--R                                4 6     3   2 4     2     3 3     2 2 4 2
+--R                             - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                           + 
+--R                                   2 5     2 2 6
+--R                             6a b c d e - b c d
+--R                        /
+--R                              5 3      4 2 2
+--R                           64a c  - 16a b c
+--R                  + 
+--R                           4     3 2  4         3 2     2 2   2 2
+--R                        (4a c - a b )e  + (- 12a c  + 3a b c)d e
+--R                      + 
+--R                           2   2      3   3
+--R                        (4a b c  - a b c)d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|d
+--R               *
+--R                  ROOT
+--R                               3 2     2 2
+--R                           (16a c  - 4a b c)
+--R                        *
+--R                           ROOT
+--R                                     4 6     3   2 4     2     3 3     2 2 4 2
+--R                                  - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                                + 
+--R                                        2 5     2 2 6
+--R                                  6a b c d e - b c d
+--R                             /
+--R                                   5 3      4 2 2
+--R                                64a c  - 16a b c
+--R                       + 
+--R                          2   3     2     2           2         2    2   3
+--R                         a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R                    /
+--R                         3 2     2 2
+--R                       8a c  - 2a b c
+--R              + 
+--R                        4 5     3     4     3   2 3     2     3 2
+--R                    - 2a e  + 2a b d e  + 4a c d e  - 8a b c d e
+--R                  + 
+--R                       2 2       2   4          2 5
+--R                    (6a c  + 2a b c)d e - 2a b c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                          4 2     3 2     2       3   2     2 3   2
+--R                    (- 16a c  + 4a b c)d e  + (16a b c  - 4a b c)d e
+--R                  + 
+--R                          3 3     2 2 2  3
+--R                    (- 16a c  + 4a b c )d
+--R               *
+--R                   2
+--R                  x
+--R               *
+--R                  ROOT
+--R                            4 6     3   2 4     2     3 3     2 2 4 2
+--R                         - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                       + 
+--R                               2 5     2 2 6
+--R                         6a b c d e - b c d
+--R                    /
+--R                          5 3      4 2 2
+--R                       64a c  - 16a b c
+--R              + 
+--R                     3     5    2 2 2 4     2     3 3       2   4 2
+--R                    a b d e  - a b d e  - 2a b c d e  + 4a b c d e
+--R                  + 
+--R                             2    3   5     2 2 6
+--R                    (- 3a b c  - b c)d e + b c d
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  4   5     3   2 4     3   3 3     2     4 2
+--R                2a d e  - 2a b d e  - 4a c d e  + 8a b c d e
+--R              + 
+--R                     2 2       2   5          2 6
+--R                (- 6a c  - 2a b c)d e + 2a b c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R            a
+--R         *
+--R            ROOT
+--R                           3 2     2 2
+--R                     (- 16a c  + 4a b c)
+--R                  *
+--R                     ROOT
+--R                               4 6     3   2 4     2     3 3     2 2 4 2
+--R                            - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                          + 
+--R                                  2 5     2 2 6
+--R                            6a b c d e - b c d
+--R                       /
+--R                             5 3      4 2 2
+--R                          64a c  - 16a b c
+--R                 + 
+--R                    2   3     2     2           2         2    2   3
+--R                   a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R              /
+--R                   3 2     2 2
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                              4   2     3 3            4 3     3 2 2    2
+--R                         ((16a b c  - 4a b c)e + (- 32a c  + 8a b c )d)x
+--R                      *
+--R                         ROOT
+--R                                   4 6     3   2 4     2     3 3     2 2 4 2
+--R                                - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                              + 
+--R                                      2 5     2 2 6
+--R                                6a b c d e - b c d
+--R                           /
+--R                                 5 3      4 2 2
+--R                              64a c  - 16a b c
+--R                     + 
+--R                                4     3 2  4       3 2     2 2   2 2
+--R                           (- 4a c + a b )e  + (12a c  - 3a b c)d e
+--R                         + 
+--R                                2   2      3   3
+--R                           (- 4a b c  + a b c)d e
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|d
+--R                  *
+--R                     ROOT
+--R                                    3 2     2 2
+--R                              (- 16a c  + 4a b c)
+--R                           *
+--R                              ROOT
+--R                                        4 6     3   2 4     2     3 3
+--R                                     - a e  + 6a c d e  - 2a b c d e
+--R                                   + 
+--R                                         2 2 4 2         2 5     2 2 6
+--R                                     - 9a c d e  + 6a b c d e - b c d
+--R                                /
+--R                                      5 3      4 2 2
+--R                                   64a c  - 16a b c
+--R                          + 
+--R                             2   3     2     2           2         2    2   3
+--R                            a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R                       /
+--R                            3 2     2 2
+--R                          8a c  - 2a b c
+--R                 + 
+--R                           4 5     3     4     3   2 3     2     3 2
+--R                       - 2a e  + 2a b d e  + 4a c d e  - 8a b c d e
+--R                     + 
+--R                          2 2       2   4          2 5
+--R                       (6a c  + 2a b c)d e - 2a b c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                           4 2     3 2     2         3   2     2 3   2
+--R                       (16a c  - 4a b c)d e  + (- 16a b c  + 4a b c)d e
+--R                     + 
+--R                           3 3     2 2 2  3
+--R                       (16a c  - 4a b c )d
+--R                  *
+--R                      2
+--R                     x
+--R                  *
+--R                     ROOT
+--R                               4 6     3   2 4     2     3 3     2 2 4 2
+--R                            - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                          + 
+--R                                  2 5     2 2 6
+--R                            6a b c d e - b c d
+--R                       /
+--R                             5 3      4 2 2
+--R                          64a c  - 16a b c
+--R                 + 
+--R                        3     5    2 2 2 4     2     3 3       2   4 2
+--R                       a b d e  - a b d e  - 2a b c d e  + 4a b c d e
+--R                     + 
+--R                                2    3   5     2 2 6
+--R                       (- 3a b c  - b c)d e + b c d
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     4   5     3   2 4     3   3 3     2     4 2
+--R                   2a d e  - 2a b d e  - 4a c d e  + 8a b c d e
+--R                 + 
+--R                        2 2       2   5          2 6
+--R                   (- 6a c  - 2a b c)d e + 2a b c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R         a
+--R      *
+--R         ROOT
+--R                        3 2     2 2
+--R                  (- 16a c  + 4a b c)
+--R               *
+--R                  ROOT
+--R                            4 6     3   2 4     2     3 3     2 2 4 2
+--R                         - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                       + 
+--R                               2 5     2 2 6
+--R                         6a b c d e - b c d
+--R                    /
+--R                          5 3      4 2 2
+--R                       64a c  - 16a b c
+--R              + 
+--R                 2   3     2     2           2         2    2   3
+--R                a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R           /
+--R                3 2     2 2
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                             4   2     3 3          4 3     3 2 2    2
+--R                      ((- 16a b c  + 4a b c)e + (32a c  - 8a b c )d)x
+--R                   *
+--R                      ROOT
+--R                                4 6     3   2 4     2     3 3     2 2 4 2
+--R                             - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                           + 
+--R                                   2 5     2 2 6
+--R                             6a b c d e - b c d
+--R                        /
+--R                              5 3      4 2 2
+--R                           64a c  - 16a b c
+--R                  + 
+--R                           4     3 2  4         3 2     2 2   2 2
+--R                        (4a c - a b )e  + (- 12a c  + 3a b c)d e
+--R                      + 
+--R                           2   2      3   3
+--R                        (4a b c  - a b c)d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|d
+--R               *
+--R                  ROOT
+--R                                 3 2     2 2
+--R                           (- 16a c  + 4a b c)
+--R                        *
+--R                           ROOT
+--R                                     4 6     3   2 4     2     3 3     2 2 4 2
+--R                                  - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                                + 
+--R                                        2 5     2 2 6
+--R                                  6a b c d e - b c d
+--R                             /
+--R                                   5 3      4 2 2
+--R                                64a c  - 16a b c
+--R                       + 
+--R                          2   3     2     2           2         2    2   3
+--R                         a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R                    /
+--R                         3 2     2 2
+--R                       8a c  - 2a b c
+--R              + 
+--R                        4 5     3     4     3   2 3     2     3 2
+--R                    - 2a e  + 2a b d e  + 4a c d e  - 8a b c d e
+--R                  + 
+--R                       2 2       2   4          2 5
+--R                    (6a c  + 2a b c)d e - 2a b c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                        4 2     3 2     2         3   2     2 3   2
+--R                    (16a c  - 4a b c)d e  + (- 16a b c  + 4a b c)d e
+--R                  + 
+--R                        3 3     2 2 2  3
+--R                    (16a c  - 4a b c )d
+--R               *
+--R                   2
+--R                  x
+--R               *
+--R                  ROOT
+--R                            4 6     3   2 4     2     3 3     2 2 4 2
+--R                         - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                       + 
+--R                               2 5     2 2 6
+--R                         6a b c d e - b c d
+--R                    /
+--R                          5 3      4 2 2
+--R                       64a c  - 16a b c
+--R              + 
+--R                     3     5    2 2 2 4     2     3 3       2   4 2
+--R                    a b d e  - a b d e  - 2a b c d e  + 4a b c d e
+--R                  + 
+--R                             2    3   5     2 2 6
+--R                    (- 3a b c  - b c)d e + b c d
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  4   5     3   2 4     3   3 3     2     4 2
+--R                2a d e  - 2a b d e  - 4a c d e  + 8a b c d e
+--R              + 
+--R                     2 2       2   5          2 6
+--R                (- 6a c  - 2a b c)d e + 2a b c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R            a
+--R         *
+--R            ROOT
+--R                         3 2     2 2
+--R                     (16a c  - 4a b c)
+--R                  *
+--R                     ROOT
+--R                               4 6     3   2 4     2     3 3     2 2 4 2
+--R                            - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                          + 
+--R                                  2 5     2 2 6
+--R                            6a b c d e - b c d
+--R                       /
+--R                             5 3      4 2 2
+--R                          64a c  - 16a b c
+--R                 + 
+--R                    2   3     2     2           2         2    2   3
+--R                   a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R              /
+--R                   3 2     2 2
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                                4   2     3 3          4 3     3 2 2    2
+--R                         ((- 16a b c  + 4a b c)e + (32a c  - 8a b c )d)x
+--R                      *
+--R                         ROOT
+--R                                   4 6     3   2 4     2     3 3     2 2 4 2
+--R                                - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                              + 
+--R                                      2 5     2 2 6
+--R                                6a b c d e - b c d
+--R                           /
+--R                                 5 3      4 2 2
+--R                              64a c  - 16a b c
+--R                     + 
+--R                                4     3 2  4       3 2     2 2   2 2
+--R                           (- 4a c + a b )e  + (12a c  - 3a b c)d e
+--R                         + 
+--R                                2   2      3   3
+--R                           (- 4a b c  + a b c)d e
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|d
+--R                  *
+--R                     ROOT
+--R                                  3 2     2 2
+--R                              (16a c  - 4a b c)
+--R                           *
+--R                              ROOT
+--R                                        4 6     3   2 4     2     3 3
+--R                                     - a e  + 6a c d e  - 2a b c d e
+--R                                   + 
+--R                                         2 2 4 2         2 5     2 2 6
+--R                                     - 9a c d e  + 6a b c d e - b c d
+--R                                /
+--R                                      5 3      4 2 2
+--R                                   64a c  - 16a b c
+--R                          + 
+--R                             2   3     2     2           2         2    2   3
+--R                            a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R                       /
+--R                            3 2     2 2
+--R                          8a c  - 2a b c
+--R                 + 
+--R                           4 5     3     4     3   2 3     2     3 2
+--R                       - 2a e  + 2a b d e  + 4a c d e  - 8a b c d e
+--R                     + 
+--R                          2 2       2   4          2 5
+--R                       (6a c  + 2a b c)d e - 2a b c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                             4 2     3 2     2       3   2     2 3   2
+--R                       (- 16a c  + 4a b c)d e  + (16a b c  - 4a b c)d e
+--R                     + 
+--R                             3 3     2 2 2  3
+--R                       (- 16a c  + 4a b c )d
+--R                  *
+--R                      2
+--R                     x
+--R                  *
+--R                     ROOT
+--R                               4 6     3   2 4     2     3 3     2 2 4 2
+--R                            - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                          + 
+--R                                  2 5     2 2 6
+--R                            6a b c d e - b c d
+--R                       /
+--R                             5 3      4 2 2
+--R                          64a c  - 16a b c
+--R                 + 
+--R                        3     5    2 2 2 4     2     3 3       2   4 2
+--R                       a b d e  - a b d e  - 2a b c d e  + 4a b c d e
+--R                     + 
+--R                                2    3   5     2 2 6
+--R                       (- 3a b c  - b c)d e + b c d
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     4   5     3   2 4     3   3 3     2     4 2
+--R                   2a d e  - 2a b d e  - 4a c d e  + 8a b c d e
+--R                 + 
+--R                        2 2       2   5          2 6
+--R                   (- 6a c  - 2a b c)d e + 2a b c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                  +--------+
+--R                  |   2         +-+
+--R          +-+    \|e x  + d  - \|d
+--R       2d\|d log(------------------)
+--R                          x
+--R  /
+--R     2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 3072
+
+--S 3073 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +------------------------------+
+--R               +-----------+     |    +-----------+
+--R           +-+ |          2  +-+ |    |          2
+--R         a\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                      3 2     2 2
+--R                  (16a c  - 4a b c)
+--R               *
+--R                  ROOT
+--R                            4 6     3   2 4     2     3 3     2 2 4 2
+--R                         - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                       + 
+--R                               2 5     2 2 6
+--R                         6a b c d e - b c d
+--R                    /
+--R                          5 3      4 2 2
+--R                       64a c  - 16a b c
+--R              + 
+--R                 2   3     2     2           2         2    2   3
+--R                a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R           /
+--R                3 2     2 2
+--R              8a c  - 2a b c
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                           4   2     3 3            4 3     3 2 2    2
+--R                      ((16a b c  - 4a b c)e + (- 32a c  + 8a b c )d)x
+--R                   *
+--R                      ROOT
+--R                                4 6     3   2 4     2     3 3     2 2 4 2
+--R                             - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                           + 
+--R                                   2 5     2 2 6
+--R                             6a b c d e - b c d
+--R                        /
+--R                              5 3      4 2 2
+--R                           64a c  - 16a b c
+--R                  + 
+--R                           4     3 2  4         3 2     2 2   2 2
+--R                        (4a c - a b )e  + (- 12a c  + 3a b c)d e
+--R                      + 
+--R                           2   2      3   3
+--R                        (4a b c  - a b c)d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|d
+--R               *
+--R                  ROOT
+--R                               3 2     2 2
+--R                           (16a c  - 4a b c)
+--R                        *
+--R                           ROOT
+--R                                     4 6     3   2 4     2     3 3     2 2 4 2
+--R                                  - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                                + 
+--R                                        2 5     2 2 6
+--R                                  6a b c d e - b c d
+--R                             /
+--R                                   5 3      4 2 2
+--R                                64a c  - 16a b c
+--R                       + 
+--R                          2   3     2     2           2         2    2   3
+--R                         a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R                    /
+--R                         3 2     2 2
+--R                       8a c  - 2a b c
+--R              + 
+--R                        4 5     3     4     3   2 3     2     3 2
+--R                    - 2a e  + 2a b d e  + 4a c d e  - 8a b c d e
+--R                  + 
+--R                       2 2       2   4          2 5
+--R                    (6a c  + 2a b c)d e - 2a b c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                          4 2     3 2     2       3   2     2 3   2
+--R                    (- 16a c  + 4a b c)d e  + (16a b c  - 4a b c)d e
+--R                  + 
+--R                          3 3     2 2 2  3
+--R                    (- 16a c  + 4a b c )d
+--R               *
+--R                   2
+--R                  x
+--R               *
+--R                  ROOT
+--R                            4 6     3   2 4     2     3 3     2 2 4 2
+--R                         - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                       + 
+--R                               2 5     2 2 6
+--R                         6a b c d e - b c d
+--R                    /
+--R                          5 3      4 2 2
+--R                       64a c  - 16a b c
+--R              + 
+--R                     3     5    2 2 2 4     2     3 3       2   4 2
+--R                    a b d e  - a b d e  - 2a b c d e  + 4a b c d e
+--R                  + 
+--R                             2    3   5     2 2 6
+--R                    (- 3a b c  - b c)d e + b c d
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  4   5     3   2 4     3   3 3     2     4 2
+--R                2a d e  - 2a b d e  - 4a c d e  + 8a b c d e
+--R              + 
+--R                     2 2       2   5          2 6
+--R                (- 6a c  - 2a b c)d e + 2a b c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                                    +------------------------------+
+--R                  +-----------+     |    +-----------+
+--R              +-+ |          2  +-+ |    |          2
+--R            a\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                           3 2     2 2
+--R                     (- 16a c  + 4a b c)
+--R                  *
+--R                     ROOT
+--R                               4 6     3   2 4     2     3 3     2 2 4 2
+--R                            - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                          + 
+--R                                  2 5     2 2 6
+--R                            6a b c d e - b c d
+--R                       /
+--R                             5 3      4 2 2
+--R                          64a c  - 16a b c
+--R                 + 
+--R                    2   3     2     2           2         2    2   3
+--R                   a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R              /
+--R                   3 2     2 2
+--R                 8a c  - 2a b c
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                              4   2     3 3            4 3     3 2 2    2
+--R                         ((16a b c  - 4a b c)e + (- 32a c  + 8a b c )d)x
+--R                      *
+--R                         ROOT
+--R                                   4 6     3   2 4     2     3 3     2 2 4 2
+--R                                - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                              + 
+--R                                      2 5     2 2 6
+--R                                6a b c d e - b c d
+--R                           /
+--R                                 5 3      4 2 2
+--R                              64a c  - 16a b c
+--R                     + 
+--R                                4     3 2  4       3 2     2 2   2 2
+--R                           (- 4a c + a b )e  + (12a c  - 3a b c)d e
+--R                         + 
+--R                                2   2      3   3
+--R                           (- 4a b c  + a b c)d e
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|d
+--R                  *
+--R                     ROOT
+--R                                    3 2     2 2
+--R                              (- 16a c  + 4a b c)
+--R                           *
+--R                              ROOT
+--R                                        4 6     3   2 4     2     3 3
+--R                                     - a e  + 6a c d e  - 2a b c d e
+--R                                   + 
+--R                                         2 2 4 2         2 5     2 2 6
+--R                                     - 9a c d e  + 6a b c d e - b c d
+--R                                /
+--R                                      5 3      4 2 2
+--R                                   64a c  - 16a b c
+--R                          + 
+--R                             2   3     2     2           2         2    2   3
+--R                            a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R                       /
+--R                            3 2     2 2
+--R                          8a c  - 2a b c
+--R                 + 
+--R                           4 5     3     4     3   2 3     2     3 2
+--R                       - 2a e  + 2a b d e  + 4a c d e  - 8a b c d e
+--R                     + 
+--R                          2 2       2   4          2 5
+--R                       (6a c  + 2a b c)d e - 2a b c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                           4 2     3 2     2         3   2     2 3   2
+--R                       (16a c  - 4a b c)d e  + (- 16a b c  + 4a b c)d e
+--R                     + 
+--R                           3 3     2 2 2  3
+--R                       (16a c  - 4a b c )d
+--R                  *
+--R                      2
+--R                     x
+--R                  *
+--R                     ROOT
+--R                               4 6     3   2 4     2     3 3     2 2 4 2
+--R                            - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                          + 
+--R                                  2 5     2 2 6
+--R                            6a b c d e - b c d
+--R                       /
+--R                             5 3      4 2 2
+--R                          64a c  - 16a b c
+--R                 + 
+--R                        3     5    2 2 2 4     2     3 3       2   4 2
+--R                       a b d e  - a b d e  - 2a b c d e  + 4a b c d e
+--R                     + 
+--R                                2    3   5     2 2 6
+--R                       (- 3a b c  - b c)d e + b c d
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     4   5     3   2 4     3   3 3     2     4 2
+--R                   2a d e  - 2a b d e  - 4a c d e  + 8a b c d e
+--R                 + 
+--R                        2 2       2   5          2 6
+--R                   (- 6a c  - 2a b c)d e + 2a b c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                                 +------------------------------+
+--R               +-----------+     |    +-----------+
+--R           +-+ |          2  +-+ |    |          2
+--R         a\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         ROOT
+--R                        3 2     2 2
+--R                  (- 16a c  + 4a b c)
+--R               *
+--R                  ROOT
+--R                            4 6     3   2 4     2     3 3     2 2 4 2
+--R                         - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                       + 
+--R                               2 5     2 2 6
+--R                         6a b c d e - b c d
+--R                    /
+--R                          5 3      4 2 2
+--R                       64a c  - 16a b c
+--R              + 
+--R                 2   3     2     2           2         2    2   3
+--R                a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R           /
+--R                3 2     2 2
+--R              8a c  - 2a b c
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R         log
+--R                             4   2     3 3          4 3     3 2 2    2
+--R                      ((- 16a b c  + 4a b c)e + (32a c  - 8a b c )d)x
+--R                   *
+--R                      ROOT
+--R                                4 6     3   2 4     2     3 3     2 2 4 2
+--R                             - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                           + 
+--R                                   2 5     2 2 6
+--R                             6a b c d e - b c d
+--R                        /
+--R                              5 3      4 2 2
+--R                           64a c  - 16a b c
+--R                  + 
+--R                           4     3 2  4         3 2     2 2   2 2
+--R                        (4a c - a b )e  + (- 12a c  + 3a b c)d e
+--R                      + 
+--R                           2   2      3   3
+--R                        (4a b c  - a b c)d e
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|d
+--R               *
+--R                  ROOT
+--R                                 3 2     2 2
+--R                           (- 16a c  + 4a b c)
+--R                        *
+--R                           ROOT
+--R                                     4 6     3   2 4     2     3 3     2 2 4 2
+--R                                  - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                                + 
+--R                                        2 5     2 2 6
+--R                                  6a b c d e - b c d
+--R                             /
+--R                                   5 3      4 2 2
+--R                                64a c  - 16a b c
+--R                       + 
+--R                          2   3     2     2           2         2    2   3
+--R                         a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R                    /
+--R                         3 2     2 2
+--R                       8a c  - 2a b c
+--R              + 
+--R                        4 5     3     4     3   2 3     2     3 2
+--R                    - 2a e  + 2a b d e  + 4a c d e  - 8a b c d e
+--R                  + 
+--R                       2 2       2   4          2 5
+--R                    (6a c  + 2a b c)d e - 2a b c d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                        4 2     3 2     2         3   2     2 3   2
+--R                    (16a c  - 4a b c)d e  + (- 16a b c  + 4a b c)d e
+--R                  + 
+--R                        3 3     2 2 2  3
+--R                    (16a c  - 4a b c )d
+--R               *
+--R                   2
+--R                  x
+--R               *
+--R                  ROOT
+--R                            4 6     3   2 4     2     3 3     2 2 4 2
+--R                         - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                       + 
+--R                               2 5     2 2 6
+--R                         6a b c d e - b c d
+--R                    /
+--R                          5 3      4 2 2
+--R                       64a c  - 16a b c
+--R              + 
+--R                     3     5    2 2 2 4     2     3 3       2   4 2
+--R                    a b d e  - a b d e  - 2a b c d e  + 4a b c d e
+--R                  + 
+--R                             2    3   5     2 2 6
+--R                    (- 3a b c  - b c)d e + b c d
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  4   5     3   2 4     3   3 3     2     4 2
+--R                2a d e  - 2a b d e  - 4a c d e  + 8a b c d e
+--R              + 
+--R                     2 2       2   5          2 6
+--R                (- 6a c  - 2a b c)d e + 2a b c d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                                    +------------------------------+
+--R                  +-----------+     |    +-----------+
+--R              +-+ |          2  +-+ |    |          2
+--R            a\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            ROOT
+--R                         3 2     2 2
+--R                     (16a c  - 4a b c)
+--R                  *
+--R                     ROOT
+--R                               4 6     3   2 4     2     3 3     2 2 4 2
+--R                            - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                          + 
+--R                                  2 5     2 2 6
+--R                            6a b c d e - b c d
+--R                       /
+--R                             5 3      4 2 2
+--R                          64a c  - 16a b c
+--R                 + 
+--R                    2   3     2     2           2         2    2   3
+--R                   a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R              /
+--R                   3 2     2 2
+--R                 8a c  - 2a b c
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R            log
+--R                                4   2     3 3          4 3     3 2 2    2
+--R                         ((- 16a b c  + 4a b c)e + (32a c  - 8a b c )d)x
+--R                      *
+--R                         ROOT
+--R                                   4 6     3   2 4     2     3 3     2 2 4 2
+--R                                - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                              + 
+--R                                      2 5     2 2 6
+--R                                6a b c d e - b c d
+--R                           /
+--R                                 5 3      4 2 2
+--R                              64a c  - 16a b c
+--R                     + 
+--R                                4     3 2  4       3 2     2 2   2 2
+--R                           (- 4a c + a b )e  + (12a c  - 3a b c)d e
+--R                         + 
+--R                                2   2      3   3
+--R                           (- 4a b c  + a b c)d e
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                      +-+
+--R                     \|d
+--R                  *
+--R                     ROOT
+--R                                  3 2     2 2
+--R                              (16a c  - 4a b c)
+--R                           *
+--R                              ROOT
+--R                                        4 6     3   2 4     2     3 3
+--R                                     - a e  + 6a c d e  - 2a b c d e
+--R                                   + 
+--R                                         2 2 4 2         2 5     2 2 6
+--R                                     - 9a c d e  + 6a b c d e - b c d
+--R                                /
+--R                                      5 3      4 2 2
+--R                                   64a c  - 16a b c
+--R                          + 
+--R                             2   3     2     2           2         2    2   3
+--R                            a b e  - 6a c d e  + 3a b c d e + (2a c  - b c)d
+--R                       /
+--R                            3 2     2 2
+--R                          8a c  - 2a b c
+--R                 + 
+--R                           4 5     3     4     3   2 3     2     3 2
+--R                       - 2a e  + 2a b d e  + 4a c d e  - 8a b c d e
+--R                     + 
+--R                          2 2       2   4          2 5
+--R                       (6a c  + 2a b c)d e - 2a b c d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                             4 2     3 2     2       3   2     2 3   2
+--R                       (- 16a c  + 4a b c)d e  + (16a b c  - 4a b c)d e
+--R                     + 
+--R                             3 3     2 2 2  3
+--R                       (- 16a c  + 4a b c )d
+--R                  *
+--R                      2
+--R                     x
+--R                  *
+--R                     ROOT
+--R                               4 6     3   2 4     2     3 3     2 2 4 2
+--R                            - a e  + 6a c d e  - 2a b c d e  - 9a c d e
+--R                          + 
+--R                                  2 5     2 2 6
+--R                            6a b c d e - b c d
+--R                       /
+--R                             5 3      4 2 2
+--R                          64a c  - 16a b c
+--R                 + 
+--R                        3     5    2 2 2 4     2     3 3       2   4 2
+--R                       a b d e  - a b d e  - 2a b c d e  + 4a b c d e
+--R                     + 
+--R                                2    3   5     2 2 6
+--R                       (- 3a b c  - b c)d e + b c d
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     4   5     3   2 4     3   3 3     2     4 2
+--R                   2a d e  - 2a b d e  - 4a c d e  + 8a b c d e
+--R                 + 
+--R                        2 2       2   5          2 6
+--R                   (- 6a c  - 2a b c)d e + 2a b c d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                          +-----------+
+--R               2       2  |          2          2                    2
+--R         ((2a e  - 2c d )\|- 4a c + b   + 2a b e  - 8a c d e + 2b c d )
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                          +-----------+
+--R               2       2  |          2          2                    2
+--R         ((2a e  - 2c d )\|- 4a c + b   - 2a b e  + 8a c d e - 2b c d )
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                            +--------+
+--R                  +-----------+             |   2         +-+
+--R              +-+ |          2  +-+ +-+    \|e x  + d  - \|d
+--R           2d\|2 \|- 4a c + b  \|c \|d log(------------------)
+--R                                                    x
+--R         + 
+--R                                              +--------+
+--R                  +-----------+               |   2
+--R              +-+ |          2  +-+ +-+      \|e x  + d
+--R           2d\|2 \|- 4a c + b  \|c \|d atanh(-----------)
+--R                                                  +-+
+--R                                                 \|d
+--R      *
+--R          +------------------------------+ +----------------------------+
+--R          |    +-----------+               |  +-----------+
+--R          |    |          2                |  |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                                +------------------------------+
+--R              +-----------+     |    +-----------+
+--R          +-+ |          2  +-+ |    |          2
+--R       2a\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3073
+
+--S 3074 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3074
+
+)clear all
+
+--S 3075 of 3139
+t0:=(d+e*x^2)^(3/2)/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R             6      4      2
+--R          c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3075
+
+--S 3076 of 3139
+r0:=d*atanh(x*sqrt(e)/sqrt(d+e*x^2))*sqrt(e)/a-1/2*atanh(x*sqrt(e)/_
+   sqrt(d+e*x^2))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))*sqrt(e)/a-_
+   1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))*_
+   sqrt(e)/a-d*sqrt(d+e*x^2)/(a*x)+1/2*atanh(x*sqrt(2*c*d-e*(b-_
+   sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*(d+_
+   (b*d-2*a*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (a*sqrt(-b+sqrt(b^2-4*a*c)))-1/2*atan(x*sqrt(2*c*d-e*(b+_
+   sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(d+_
+   (-b*d+2*a*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/_
+   (a*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                               +------------------+
+--R              +-----------+                    | +-----------+
+--R              |          2                     | |          2
+--R         (d x\|- 4a c + b   + (- 2a e + b d)x)\|\|- 4a c + b   + b
+--R      *
+--R                                                +----------------------------+
+--R          +----------------------------+        |  +-----------+
+--R          |  +-----------+                      |  |          2
+--R          |  |          2                     x\|e\|- 4a c + b   - b e + 2c d
+--R         \|e\|- 4a c + b   - b e + 2c d atanh(--------------------------------)
+--R                                                          +------------------+
+--R                                               +--------+ | +-----------+
+--R                                               |   2      | |          2
+--R                                              \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                +-----------+
+--R                |          2
+--R         (- d x\|- 4a c + b   + (- 2a e + b d)x)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                     +------------------+ +------------------+
+--R            +-----------+ +--------+ | +-----------+      | +-----------+
+--R            |          2  |   2      | |          2       | |          2
+--R       - 2d\|- 4a c + b  \|e x  + d \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R  /
+--R                        +------------------+ +------------------+
+--R          +-----------+ | +-----------+      | +-----------+
+--R          |          2  | |          2       | |          2
+--R     2a x\|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3076
+
+--S 3077 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                +--------+
+--R                |   2            +-+
+--R         (- a x\|e x  + d  + a x\|d )
+--R      *
+--R         ROOT
+--R                      4      3 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                             4 2 4      3   3 3      3       2 2  4 2
+--R                         - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                       + 
+--R                              2          3  5        2 2       2     4  6
+--R                         (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                    /
+--R                          7       6 2
+--R                       64a c - 16a b
+--R              + 
+--R                    3 3     2     2      2        2  2                 3  3
+--R                - 2a e  + 3a b d e  + (6a c - 3a b )d e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                               5      4 2           4        3 3
+--R                          ((32a c - 8a b )e + (- 16a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                  3      2 2  2 2       2          3  3
+--R                            (- 12a c + 3a b )d e  + (12a b c - 3a b )d e
+--R                          + 
+--R                               2 2       2     4  4
+--R                            (4a c  - 5a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                 5      4 2         4        3 3
+--R                          ((- 32a c + 8a b )e + (16a b c - 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                3      2 2  2 2         2          3  3
+--R                            (12a c - 3a b )d e  + (- 12a b c + 3a b )d e
+--R                          + 
+--R                                 2 2       2     4  4
+--R                            (- 4a c  + 5a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               4      3 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                      4 2 4      3   3 3      3       2 2  4 2
+--R                                  - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                                + 
+--R                                     2          3  5        2 2       2     4  6
+--R                                (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             3 3     2     2      2        2  2
+--R                         - 2a e  + 3a b d e  + (6a c - 3a b )d e
+--R                       + 
+--R                                      3  3
+--R                         (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                        3   4      2   2 3        2        2  3 2
+--R                    - 6a d e  + 12a b d e  + (- 4a c - 8a b )d e
+--R                  + 
+--R                                3  4         2     2   5
+--R                    (4a b c + 2b )d e + (2a c  - 2b c)d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      3   5      2   2 4      2        2  3 3
+--R                    6a d e  - 12a b d e  + (4a c + 8a b )d e
+--R                  + 
+--R                                  3  4 2          2     2   5
+--R                    (- 4a b c - 2b )d e  + (- 2a c  + 2b c)d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  3 2 4      2   3 3      2        2  4 2                 3  5
+--R                6a d e  - 12a b d e  + (4a c + 8a b )d e  + (- 4a b c - 2b )d e
+--R              + 
+--R                       2     2   6
+--R                (- 2a c  + 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R              +--------+
+--R              |   2            +-+
+--R         (a x\|e x  + d  - a x\|d )
+--R      *
+--R         ROOT
+--R                        4      3 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                             4 2 4      3   3 3      3       2 2  4 2
+--R                         - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                       + 
+--R                              2          3  5        2 2       2     4  6
+--R                         (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                    /
+--R                          7       6 2
+--R                       64a c - 16a b
+--R              + 
+--R                    3 3     2     2      2        2  2                 3  3
+--R                - 2a e  + 3a b d e  + (6a c - 3a b )d e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                               5      4 2           4        3 3
+--R                          ((32a c - 8a b )e + (- 16a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                3      2 2  2 2         2          3  3
+--R                            (12a c - 3a b )d e  + (- 12a b c + 3a b )d e
+--R                          + 
+--R                                 2 2       2     4  4
+--R                            (- 4a c  + 5a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                 5      4 2         4        3 3
+--R                          ((- 32a c + 8a b )e + (16a b c - 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                  3      2 2  2 2       2          3  3
+--R                            (- 12a c + 3a b )d e  + (12a b c - 3a b )d e
+--R                          + 
+--R                               2 2       2     4  4
+--R                            (4a c  - 5a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 4      3 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                      4 2 4      3   3 3      3       2 2  4 2
+--R                                  - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                                + 
+--R                                     2          3  5        2 2       2     4  6
+--R                                (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             3 3     2     2      2        2  2
+--R                         - 2a e  + 3a b d e  + (6a c - 3a b )d e
+--R                       + 
+--R                                      3  3
+--R                         (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                        3   4      2   2 3        2        2  3 2
+--R                    - 6a d e  + 12a b d e  + (- 4a c - 8a b )d e
+--R                  + 
+--R                                3  4         2     2   5
+--R                    (4a b c + 2b )d e + (2a c  - 2b c)d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      3   5      2   2 4      2        2  3 3
+--R                    6a d e  - 12a b d e  + (4a c + 8a b )d e
+--R                  + 
+--R                                  3  4 2          2     2   5
+--R                    (- 4a b c - 2b )d e  + (- 2a c  + 2b c)d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  3 2 4      2   3 3      2        2  4 2                 3  5
+--R                6a d e  - 12a b d e  + (4a c + 8a b )d e  + (- 4a b c - 2b )d e
+--R              + 
+--R                       2     2   6
+--R                (- 2a c  + 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +--------+
+--R                |   2            +-+
+--R         (- a x\|e x  + d  + a x\|d )
+--R      *
+--R         ROOT
+--R                        4      3 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                             4 2 4      3   3 3      3       2 2  4 2
+--R                         - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                       + 
+--R                              2          3  5        2 2       2     4  6
+--R                         (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                    /
+--R                          7       6 2
+--R                       64a c - 16a b
+--R              + 
+--R                    3 3     2     2      2        2  2                 3  3
+--R                - 2a e  + 3a b d e  + (6a c - 3a b )d e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                                 5      4 2         4        3 3
+--R                          ((- 32a c + 8a b )e + (16a b c - 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                  3      2 2  2 2       2          3  3
+--R                            (- 12a c + 3a b )d e  + (12a b c - 3a b )d e
+--R                          + 
+--R                               2 2       2     4  4
+--R                            (4a c  - 5a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                               5      4 2           4        3 3
+--R                          ((32a c - 8a b )e + (- 16a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                3      2 2  2 2         2          3  3
+--R                            (12a c - 3a b )d e  + (- 12a b c + 3a b )d e
+--R                          + 
+--R                                 2 2       2     4  4
+--R                            (- 4a c  + 5a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 4      3 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                      4 2 4      3   3 3      3       2 2  4 2
+--R                                  - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                                + 
+--R                                     2          3  5        2 2       2     4  6
+--R                                (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             3 3     2     2      2        2  2
+--R                         - 2a e  + 3a b d e  + (6a c - 3a b )d e
+--R                       + 
+--R                                      3  3
+--R                         (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                        3   4      2   2 3        2        2  3 2
+--R                    - 6a d e  + 12a b d e  + (- 4a c - 8a b )d e
+--R                  + 
+--R                                3  4         2     2   5
+--R                    (4a b c + 2b )d e + (2a c  - 2b c)d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      3   5      2   2 4      2        2  3 3
+--R                    6a d e  - 12a b d e  + (4a c + 8a b )d e
+--R                  + 
+--R                                  3  4 2          2     2   5
+--R                    (- 4a b c - 2b )d e  + (- 2a c  + 2b c)d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  3 2 4      2   3 3      2        2  4 2                 3  5
+--R                6a d e  - 12a b d e  + (4a c + 8a b )d e  + (- 4a b c - 2b )d e
+--R              + 
+--R                       2     2   6
+--R                (- 2a c  + 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R              +--------+
+--R              |   2            +-+
+--R         (a x\|e x  + d  - a x\|d )
+--R      *
+--R         ROOT
+--R                      4      3 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                             4 2 4      3   3 3      3       2 2  4 2
+--R                         - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                       + 
+--R                              2          3  5        2 2       2     4  6
+--R                         (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                    /
+--R                          7       6 2
+--R                       64a c - 16a b
+--R              + 
+--R                    3 3     2     2      2        2  2                 3  3
+--R                - 2a e  + 3a b d e  + (6a c - 3a b )d e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                                 5      4 2         4        3 3
+--R                          ((- 32a c + 8a b )e + (16a b c - 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                3      2 2  2 2         2          3  3
+--R                            (12a c - 3a b )d e  + (- 12a b c + 3a b )d e
+--R                          + 
+--R                                 2 2       2     4  4
+--R                            (- 4a c  + 5a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                               5      4 2           4        3 3
+--R                          ((32a c - 8a b )e + (- 16a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                  3      2 2  2 2       2          3  3
+--R                            (- 12a c + 3a b )d e  + (12a b c - 3a b )d e
+--R                          + 
+--R                               2 2       2     4  4
+--R                            (4a c  - 5a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               4      3 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                      4 2 4      3   3 3      3       2 2  4 2
+--R                                  - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                                + 
+--R                                     2          3  5        2 2       2     4  6
+--R                                (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             3 3     2     2      2        2  2
+--R                         - 2a e  + 3a b d e  + (6a c - 3a b )d e
+--R                       + 
+--R                                      3  3
+--R                         (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                        3   4      2   2 3        2        2  3 2
+--R                    - 6a d e  + 12a b d e  + (- 4a c - 8a b )d e
+--R                  + 
+--R                                3  4         2     2   5
+--R                    (4a b c + 2b )d e + (2a c  - 2b c)d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      3   5      2   2 4      2        2  3 3
+--R                    6a d e  - 12a b d e  + (4a c + 8a b )d e
+--R                  + 
+--R                                  3  4 2          2     2   5
+--R                    (- 4a b c - 2b )d e  + (- 2a c  + 2b c)d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  3 2 4      2   3 3      2        2  4 2                 3  5
+--R                6a d e  - 12a b d e  + (4a c + 8a b )d e  + (- 4a b c - 2b )d e
+--R              + 
+--R                       2     2   6
+--R                (- 2a c  + 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R              +--------+
+--R          +-+ |   2              2     2
+--R       2d\|d \|e x  + d  - 2d e x  - 2d
+--R  /
+--R          +--------+
+--R          |   2             +-+
+--R     2a x\|e x  + d  - 2a x\|d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3077
+
+--S 3078 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R              +-----------+
+--R              |          2
+--R            a\|- 4a c + b
+--R         *
+--R            ROOT
+--R                         4      3 2
+--R                     (16a c - 4a b )
+--R                  *
+--R                     ROOT
+--R                                4 2 4      3   3 3      3       2 2  4 2
+--R                            - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                          + 
+--R                                 2          3  5        2 2       2     4  6
+--R                            (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                       /
+--R                             7       6 2
+--R                          64a c - 16a b
+--R                 + 
+--R                       3 3     2     2      2        2  2                 3  3
+--R                   - 2a e  + 3a b d e  + (6a c - 3a b )d e + (- 3a b c + b )d
+--R              /
+--R                   4      3 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                  5      4 2           4        3 3
+--R                             ((32a c - 8a b )e + (- 16a b c + 4a b )d)x
+--R                          *
+--R                             ROOT
+--R                                        4 2 4      3   3 3      3       2 2  4 2
+--R                                    - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                                  + 
+--R                                         2          3  5
+--R                                    (- 6a b c + 6a b )d e
+--R                                  + 
+--R                                        2 2       2     4  6
+--R                                    (- a c  + 2a b c - b )d
+--R                               /
+--R                                     7       6 2
+--R                                  64a c - 16a b
+--R                         + 
+--R                                     3      2 2  2 2       2          3  3
+--R                               (- 12a c + 3a b )d e  + (12a b c - 3a b )d e
+--R                             + 
+--R                                  2 2       2     4  4
+--R                               (4a c  - 5a b c + b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                    5      4 2         4        3 3
+--R                             ((- 32a c + 8a b )e + (16a b c - 4a b )d)x
+--R                          *
+--R                             ROOT
+--R                                        4 2 4      3   3 3      3       2 2  4 2
+--R                                    - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                                  + 
+--R                                         2          3  5
+--R                                    (- 6a b c + 6a b )d e
+--R                                  + 
+--R                                        2 2       2     4  6
+--R                                    (- a c  + 2a b c - b )d
+--R                               /
+--R                                     7       6 2
+--R                                  64a c - 16a b
+--R                         + 
+--R                                   3      2 2  2 2         2          3  3
+--R                               (12a c - 3a b )d e  + (- 12a b c + 3a b )d e
+--R                             + 
+--R                                    2 2       2     4  4
+--R                               (- 4a c  + 5a b c - b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                  4      3 2
+--R                              (16a c - 4a b )
+--R                           *
+--R                              ROOT
+--R                                         4 2 4      3   3 3
+--R                                     - 9a d e  + 18a b d e
+--R                                   + 
+--R                                        3       2 2  4 2        2          3  5
+--R                                     (6a c - 15a b )d e  + (- 6a b c + 6a b )d e
+--R                                   + 
+--R                                         2 2       2     4  6
+--R                                     (- a c  + 2a b c - b )d
+--R                                /
+--R                                      7       6 2
+--R                                   64a c - 16a b
+--R                          + 
+--R                                3 3     2     2      2        2  2
+--R                            - 2a e  + 3a b d e  + (6a c - 3a b )d e
+--R                          + 
+--R                                         3  3
+--R                            (- 3a b c + b )d
+--R                       /
+--R                            4      3 2
+--R                          8a c - 2a b
+--R                 + 
+--R                           3   4      2   2 3        2        2  3 2
+--R                       - 6a d e  + 12a b d e  + (- 4a c - 8a b )d e
+--R                     + 
+--R                                   3  4         2     2   5
+--R                       (4a b c + 2b )d e + (2a c  - 2b c)d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                         3   5      2   2 4      2        2  3 3
+--R                       6a d e  - 12a b d e  + (4a c + 8a b )d e
+--R                     + 
+--R                                     3  4 2          2     2   5
+--R                       (- 4a b c - 2b )d e  + (- 2a c  + 2b c)d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     3 2 4      2   3 3      2        2  4 2
+--R                   6a d e  - 12a b d e  + (4a c + 8a b )d e
+--R                 + 
+--R                                 3  5           2     2   6
+--R                   (- 4a b c - 2b )d e + (- 2a c  + 2b c)d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R           +-----------+
+--R           |          2
+--R         a\|- 4a c + b
+--R      *
+--R         ROOT
+--R                        4      3 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                             4 2 4      3   3 3      3       2 2  4 2
+--R                         - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                       + 
+--R                              2          3  5        2 2       2     4  6
+--R                         (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                    /
+--R                          7       6 2
+--R                       64a c - 16a b
+--R              + 
+--R                    3 3     2     2      2        2  2                 3  3
+--R                - 2a e  + 3a b d e  + (6a c - 3a b )d e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               5      4 2           4        3 3
+--R                          ((32a c - 8a b )e + (- 16a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                3      2 2  2 2         2          3  3
+--R                            (12a c - 3a b )d e  + (- 12a b c + 3a b )d e
+--R                          + 
+--R                                 2 2       2     4  4
+--R                            (- 4a c  + 5a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                 5      4 2         4        3 3
+--R                          ((- 32a c + 8a b )e + (16a b c - 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                  3      2 2  2 2       2          3  3
+--R                            (- 12a c + 3a b )d e  + (12a b c - 3a b )d e
+--R                          + 
+--R                               2 2       2     4  4
+--R                            (4a c  - 5a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 4      3 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                      4 2 4      3   3 3      3       2 2  4 2
+--R                                  - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                                + 
+--R                                     2          3  5        2 2       2     4  6
+--R                                (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             3 3     2     2      2        2  2
+--R                         - 2a e  + 3a b d e  + (6a c - 3a b )d e
+--R                       + 
+--R                                      3  3
+--R                         (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                        3   4      2   2 3        2        2  3 2
+--R                    - 6a d e  + 12a b d e  + (- 4a c - 8a b )d e
+--R                  + 
+--R                                3  4         2     2   5
+--R                    (4a b c + 2b )d e + (2a c  - 2b c)d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      3   5      2   2 4      2        2  3 3
+--R                    6a d e  - 12a b d e  + (4a c + 8a b )d e
+--R                  + 
+--R                                  3  4 2          2     2   5
+--R                    (- 4a b c - 2b )d e  + (- 2a c  + 2b c)d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  3 2 4      2   3 3      2        2  4 2                 3  5
+--R                6a d e  - 12a b d e  + (4a c + 8a b )d e  + (- 4a b c - 2b )d e
+--R              + 
+--R                       2     2   6
+--R                (- 2a c  + 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R              +-----------+
+--R              |          2
+--R            a\|- 4a c + b
+--R         *
+--R            ROOT
+--R                           4      3 2
+--R                     (- 16a c + 4a b )
+--R                  *
+--R                     ROOT
+--R                                4 2 4      3   3 3      3       2 2  4 2
+--R                            - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                          + 
+--R                                 2          3  5        2 2       2     4  6
+--R                            (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                       /
+--R                             7       6 2
+--R                          64a c - 16a b
+--R                 + 
+--R                       3 3     2     2      2        2  2                 3  3
+--R                   - 2a e  + 3a b d e  + (6a c - 3a b )d e + (- 3a b c + b )d
+--R              /
+--R                   4      3 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                    5      4 2         4        3 3
+--R                             ((- 32a c + 8a b )e + (16a b c - 4a b )d)x
+--R                          *
+--R                             ROOT
+--R                                        4 2 4      3   3 3      3       2 2  4 2
+--R                                    - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                                  + 
+--R                                         2          3  5
+--R                                    (- 6a b c + 6a b )d e
+--R                                  + 
+--R                                        2 2       2     4  6
+--R                                    (- a c  + 2a b c - b )d
+--R                               /
+--R                                     7       6 2
+--R                                  64a c - 16a b
+--R                         + 
+--R                                     3      2 2  2 2       2          3  3
+--R                               (- 12a c + 3a b )d e  + (12a b c - 3a b )d e
+--R                             + 
+--R                                  2 2       2     4  4
+--R                               (4a c  - 5a b c + b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                  5      4 2           4        3 3
+--R                             ((32a c - 8a b )e + (- 16a b c + 4a b )d)x
+--R                          *
+--R                             ROOT
+--R                                        4 2 4      3   3 3      3       2 2  4 2
+--R                                    - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                                  + 
+--R                                         2          3  5
+--R                                    (- 6a b c + 6a b )d e
+--R                                  + 
+--R                                        2 2       2     4  6
+--R                                    (- a c  + 2a b c - b )d
+--R                               /
+--R                                     7       6 2
+--R                                  64a c - 16a b
+--R                         + 
+--R                                   3      2 2  2 2         2          3  3
+--R                               (12a c - 3a b )d e  + (- 12a b c + 3a b )d e
+--R                             + 
+--R                                    2 2       2     4  4
+--R                               (- 4a c  + 5a b c - b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                    4      3 2
+--R                              (- 16a c + 4a b )
+--R                           *
+--R                              ROOT
+--R                                         4 2 4      3   3 3
+--R                                     - 9a d e  + 18a b d e
+--R                                   + 
+--R                                        3       2 2  4 2        2          3  5
+--R                                     (6a c - 15a b )d e  + (- 6a b c + 6a b )d e
+--R                                   + 
+--R                                         2 2       2     4  6
+--R                                     (- a c  + 2a b c - b )d
+--R                                /
+--R                                      7       6 2
+--R                                   64a c - 16a b
+--R                          + 
+--R                                3 3     2     2      2        2  2
+--R                            - 2a e  + 3a b d e  + (6a c - 3a b )d e
+--R                          + 
+--R                                         3  3
+--R                            (- 3a b c + b )d
+--R                       /
+--R                            4      3 2
+--R                          8a c - 2a b
+--R                 + 
+--R                           3   4      2   2 3        2        2  3 2
+--R                       - 6a d e  + 12a b d e  + (- 4a c - 8a b )d e
+--R                     + 
+--R                                   3  4         2     2   5
+--R                       (4a b c + 2b )d e + (2a c  - 2b c)d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                         3   5      2   2 4      2        2  3 3
+--R                       6a d e  - 12a b d e  + (4a c + 8a b )d e
+--R                     + 
+--R                                     3  4 2          2     2   5
+--R                       (- 4a b c - 2b )d e  + (- 2a c  + 2b c)d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     3 2 4      2   3 3      2        2  4 2
+--R                   6a d e  - 12a b d e  + (4a c + 8a b )d e
+--R                 + 
+--R                                 3  5           2     2   6
+--R                   (- 4a b c - 2b )d e + (- 2a c  + 2b c)d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R           +-----------+
+--R           |          2
+--R         a\|- 4a c + b
+--R      *
+--R         ROOT
+--R                      4      3 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                             4 2 4      3   3 3      3       2 2  4 2
+--R                         - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                       + 
+--R                              2          3  5        2 2       2     4  6
+--R                         (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                    /
+--R                          7       6 2
+--R                       64a c - 16a b
+--R              + 
+--R                    3 3     2     2      2        2  2                 3  3
+--R                - 2a e  + 3a b d e  + (6a c - 3a b )d e + (- 3a b c + b )d
+--R           /
+--R                4      3 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 5      4 2         4        3 3
+--R                          ((- 32a c + 8a b )e + (16a b c - 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                3      2 2  2 2         2          3  3
+--R                            (12a c - 3a b )d e  + (- 12a b c + 3a b )d e
+--R                          + 
+--R                                 2 2       2     4  4
+--R                            (- 4a c  + 5a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                               5      4 2           4        3 3
+--R                          ((32a c - 8a b )e + (- 16a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                     4 2 4      3   3 3      3       2 2  4 2
+--R                                 - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                               + 
+--R                                    2          3  5        2 2       2     4  6
+--R                               (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                            /
+--R                                  7       6 2
+--R                               64a c - 16a b
+--R                      + 
+--R                                  3      2 2  2 2       2          3  3
+--R                            (- 12a c + 3a b )d e  + (12a b c - 3a b )d e
+--R                          + 
+--R                               2 2       2     4  4
+--R                            (4a c  - 5a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               4      3 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                      4 2 4      3   3 3      3       2 2  4 2
+--R                                  - 9a d e  + 18a b d e  + (6a c - 15a b )d e
+--R                                + 
+--R                                     2          3  5        2 2       2     4  6
+--R                                (- 6a b c + 6a b )d e + (- a c  + 2a b c - b )d
+--R                             /
+--R                                   7       6 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             3 3     2     2      2        2  2
+--R                         - 2a e  + 3a b d e  + (6a c - 3a b )d e
+--R                       + 
+--R                                      3  3
+--R                         (- 3a b c + b )d
+--R                    /
+--R                         4      3 2
+--R                       8a c - 2a b
+--R              + 
+--R                        3   4      2   2 3        2        2  3 2
+--R                    - 6a d e  + 12a b d e  + (- 4a c - 8a b )d e
+--R                  + 
+--R                                3  4         2     2   5
+--R                    (4a b c + 2b )d e + (2a c  - 2b c)d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      3   5      2   2 4      2        2  3 3
+--R                    6a d e  - 12a b d e  + (4a c + 8a b )d e
+--R                  + 
+--R                                  3  4 2          2     2   5
+--R                    (- 4a b c - 2b )d e  + (- 2a c  + 2b c)d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  3 2 4      2   3 3      2        2  4 2                 3  5
+--R                6a d e  - 12a b d e  + (4a c + 8a b )d e  + (- 4a b c - 2b )d e
+--R              + 
+--R                       2     2   6
+--R                (- 2a c  + 2b c)d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                          +------------------+
+--R              +-----------+               | +-----------+
+--R              |          2                | |          2
+--R         (- d\|- 4a c + b   + 2a e - b d)\|\|- 4a c + b   + b
+--R      *
+--R                                                +----------------------------+
+--R          +----------------------------+        |  +-----------+
+--R          |  +-----------+                      |  |          2
+--R          |  |          2                     x\|e\|- 4a c + b   - b e + 2c d
+--R         \|e\|- 4a c + b   - b e + 2c d atanh(--------------------------------)
+--R                                                          +------------------+
+--R                                               +--------+ | +-----------+
+--R                                               |   2      | |          2
+--R                                              \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                        +------------------------------+
+--R            +-----------+               |    +-----------+
+--R            |          2                |    |          2
+--R         (d\|- 4a c + b   + 2a e - b d)\|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                                     +------------------------------+
+--R          +------------------+       |    +-----------+
+--R          | +-----------+            |    |          2
+--R          | |          2           x\|- e\|- 4a c + b   - b e + 2c d
+--R         \|\|- 4a c + b   - b atan(----------------------------------)
+--R                                                +------------------+
+--R                                     +--------+ | +-----------+
+--R                                     |   2      | |          2
+--R                                    \|e x  + d \|\|- 4a c + b   + b
+--R  /
+--R                      +------------------+ +------------------+
+--R        +-----------+ | +-----------+      | +-----------+
+--R        |          2  | |          2       | |          2
+--R     2a\|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3078
+
+--S 3079 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3079
+
+)clear all
+
+--S 3080 of 3139
+t0:=(d+e*x^2)^(3/2)/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R             7      5      3
+--R          c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3080
+
+--S 3081 of 3139
+r0:=1/2*e*atanh(sqrt(d+e*x^2)/sqrt(d))*sqrt(d)/a+(b*d-2*a*e)*_
+   atanh(sqrt(d+e*x^2)/sqrt(d))*sqrt(d)/a^2-1/2*d*sqrt(d+e*x^2)/_
+   (a*x^2)-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-_
+   sqrt(b^2-4*a*c))))*sqrt(c)*(b*d^2-2*a*d*e+(b^2*d^2-2*a*b*d*e-_
+   2*a*(c*d^2-a*e^2))/sqrt(b^2-4*a*c))/(a^2*sqrt(2)*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c))))-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*sqrt(c)*(b*d^2-2*a*d*e+_
+   (-b^2*d^2+2*a*b*d*e+2*a*(c*d^2-a*e^2))/sqrt(b^2-4*a*c))/(a^2*_
+   sqrt(2)*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                              +-----------+
+--R                         2  2 |          2
+--R           (4a d e - 2b d )x \|- 4a c + b
+--R         + 
+--R              2 2                          2  2  2
+--R           (4a e  - 4a b d e + (- 4a c + 2b )d )x
+--R      *
+--R              +----------------------------+
+--R              |  +-----------+
+--R          +-+ |  |          2
+--R         \|c \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                               +--------+
+--R                       +-+ +-+ |   2
+--R                      \|2 \|c \|e x  + d
+--R         atanh(---------------------------------)
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R               \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                              +-----------+
+--R                         2  2 |          2
+--R           (4a d e - 2b d )x \|- 4a c + b
+--R         + 
+--R                2 2                        2  2  2
+--R           (- 4a e  + 4a b d e + (4a c - 2b )d )x
+--R      *
+--R              +------------------------------+
+--R              |    +-----------+
+--R          +-+ |    |          2
+--R         \|c \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                              +--------+
+--R                      +-+ +-+ |   2
+--R                     \|2 \|c \|e x  + d
+--R         atanh(-------------------------------)
+--R                +----------------------------+
+--R                |  +-----------+
+--R                |  |          2
+--R               \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                                         +--------+
+--R                                 +-----------+           |   2
+--R                           2 +-+ |          2  +-+      \|e x  + d
+--R           (- 3a e + 2b d)x \|2 \|- 4a c + b  \|d atanh(-----------)
+--R                                                             +-+
+--R                                                            \|d
+--R         + 
+--R                     +-----------+ +--------+
+--R                 +-+ |          2  |   2
+--R           - a d\|2 \|- 4a c + b  \|e x  + d
+--R      *
+--R          +------------------------------+ +----------------------------+
+--R          |    +-----------+               |  +-----------+
+--R          |    |          2                |  |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                               +------------------------------+
+--R                 +-----------+ |    +-----------+
+--R         2 2 +-+ |          2  |    |          2
+--R       2a x \|2 \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 3081
+
+--S 3082 of 3139
+--a0:=integrate(t0,x)
+--E 3082
+
+--S 3083 of 3139
+--m0:=a0-r0
+--E 3083
+
+--S 3084 of 3139
+--d0:=D(m0,x)
+--E 3084
+
+)clear all
+
+--S 3085 of 3139
+t0:=(d+e*x^2)^(3/2)/(x^4*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R             8      6      4
+--R          c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3085
+
+--S 3086 of 3139
+r0:=-1/3*(d+e*x^2)^(3/2)/(a*x^3)-(b*d-a*e)*atanh(x*sqrt(e)/sqrt(d+e*x^2))*_
+   sqrt(e)/a^2+1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*(b*d-a*e+(-b^2*d+_
+   2*a*c*d+a*b*e)/sqrt(b^2-4*a*c))*sqrt(e)/a^2+1/2*atanh(x*sqrt(e)/_
+   sqrt(d+e*x^2))*(b*d-a*e+(b^2*d-2*a*c*d-a*b*e)/sqrt(b^2-4*a*c))*_
+   sqrt(e)/a^2+(b*d-a*e)*sqrt(d+e*x^2)/(a^2*x)-1/2*atanh(x*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*_
+   (b*d-a*e+(b^2*d-2*a*c*d-a*b*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b-_
+   sqrt(b^2-4*a*c)))/(a^2*sqrt(-b+sqrt(b^2-4*a*c)))+1/2*atan(x*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-_
+   4*a*c))))*(b*d-a*e+(-b^2*d+2*a*c*d+a*b*e)/sqrt(b^2-4*a*c))*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R                        3 |          2                        2    3
+--R         ((3a e - 3b d)x \|- 4a c + b   + (3a b e + (6a c - 3b )d)x )
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R                          3 |          2                        2    3
+--R         ((- 3a e + 3b d)x \|- 4a c + b   + (3a b e + (6a c - 3b )d)x )
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                    +-----------+ +--------+
+--R                          2         |          2  |   2
+--R         ((- 8a e + 6b d)x  - 2a d)\|- 4a c + b  \|e x  + d
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R  /
+--R                         +------------------+ +------------------+
+--R           +-----------+ | +-----------+      | +-----------+
+--R       2 3 |          2  | |          2       | |          2
+--R     6a x \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3086
+
+--S 3087 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 +--------+
+--R               2   5      2   3  |   2           2   5      2   3  +-+
+--R         ((- 3a e x  - 12a d x )\|e x  + d  + (9a e x  + 12a d x )\|d )
+--R      *
+--R         ROOT
+--R                      6      5 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                            6 2 6        6        5 3    5
+--R                         - a b e  + (- 6a b c + 6a b )d e
+--R                       + 
+--R                              6 2      5 2       4 4  2 4
+--R                         (- 9a c  + 30a b c - 15a b )d e
+--R                       + 
+--R                             5   2      4 3       3 5  3 3
+--R                         (38a b c  - 60a b c + 20a b )d e
+--R                       + 
+--R                            5 3      4 2 2      3 4       2 6  4 2
+--R                         (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                       + 
+--R                               4   3      3 3 2      2 5        7  5
+--R                         (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  6
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                   4     3 2  3        3        2 3    2
+--R                (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R              + 
+--R                     3 2      2 2        4  2       2   2       3     5  3
+--R                (- 6a c  + 12a b c - 3a b )d e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                               7        6 3         7 2      6 2      5 4
+--R                          ((16a b c - 4a b )e + (32a c  - 24a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 5       4 3  4
+--R                            (- 4a b c + a b )e
+--R                          + 
+--R                                  5 2      4 2      3 4    3
+--R                            (- 12a c  + 19a b c - 4a b )d e
+--R                          + 
+--R                                4   2      3 3      2 5  2 2
+--R                            (36a b c  - 33a b c + 6a b )d e
+--R                          + 
+--R                               4 3      3 2 2      2 4        6  3
+--R                            (4a c  - 37a b c  + 25a b c - 4a b )d e
+--R                          + 
+--R                                 3   3      2 3 2       5     7  4
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                 7        6 3           7 2      6 2      5 4
+--R                          ((- 16a b c + 4a b )e + (- 32a c  + 24a b c - 4a b )d)
+--R                       *
+--R                          x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               5       4 3  4       5 2      4 2      3 4    3
+--R                            (4a b c - a b )e  + (12a c  - 19a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 36a b c  + 33a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 4a c  + 37a b c  - 25a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               6      5 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                     6 2 6        6        5 3    5
+--R                                  - a b e  + (- 6a b c + 6a b )d e
+--R                                + 
+--R                                       6 2      5 2       4 4  2 4
+--R                                  (- 9a c  + 30a b c - 15a b )d e
+--R                                + 
+--R                                      5   2      4 3       3 5  3 3
+--R                                  (38a b c  - 60a b c + 20a b )d e
+--R                                + 
+--R                                     5 3      4 2 2      3 4       2 6  4 2
+--R                                  (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  5
+--R                                  (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  6
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                            4     3 2  3        3        2 3    2
+--R                         (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R                       + 
+--R                              3 2      2 2        4  2
+--R                         (- 6a c  + 12a b c - 3a b )d e
+--R                       + 
+--R                            2   2       3     5  3
+--R                         (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        4     5        4 2     3 2     4
+--R                    - 2a b c e  + (- 6a c  + 8a b c)d e
+--R                  + 
+--R                        3   2      2 3   2 3        3 3      2 2 2       4   3 2
+--R                    (16a b c  - 12a b c)d e  + (- 4a c  - 12a b c  + 8a b c)d e
+--R                  + 
+--R                        2   3     5   4       2 4       2 3     4 2  5
+--R                    (10a b c  - 2b c)d e + (2a c  - 6a b c  + 2b c )d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      4     6      4 2     3 2     5
+--R                    2a b c e  + (6a c  - 8a b c)d e
+--R                  + 
+--R                          3   2      2 3   2 4      3 3      2 2 2       4   3 3
+--R                    (- 16a b c  + 12a b c)d e  + (4a c  + 12a b c  - 8a b c)d e
+--R                  + 
+--R                          2   3     5   4 2        2 4       2 3     4 2  5
+--R                    (- 10a b c  + 2b c)d e  + (- 2a c  + 6a b c  - 2b c )d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  4       5      4 2     3 2   2 4         3   2      2 3   3 3
+--R                2a b c d e  + (6a c  - 8a b c)d e  + (- 16a b c  + 12a b c)d e
+--R              + 
+--R                   3 3      2 2 2       4   4 2         2   3     5   5
+--R                (4a c  + 12a b c  - 8a b c)d e  + (- 10a b c  + 2b c)d e
+--R              + 
+--R                     2 4       2 3     4 2  6
+--R                (- 2a c  + 6a b c  - 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                               +--------+
+--R             2   5      2   3  |   2             2   5      2   3  +-+
+--R         ((3a e x  + 12a d x )\|e x  + d  + (- 9a e x  - 12a d x )\|d )
+--R      *
+--R         ROOT
+--R                        6      5 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                            6 2 6        6        5 3    5
+--R                         - a b e  + (- 6a b c + 6a b )d e
+--R                       + 
+--R                              6 2      5 2       4 4  2 4
+--R                         (- 9a c  + 30a b c - 15a b )d e
+--R                       + 
+--R                             5   2      4 3       3 5  3 3
+--R                         (38a b c  - 60a b c + 20a b )d e
+--R                       + 
+--R                            5 3      4 2 2      3 4       2 6  4 2
+--R                         (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                       + 
+--R                               4   3      3 3 2      2 5        7  5
+--R                         (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  6
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                   4     3 2  3        3        2 3    2
+--R                (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R              + 
+--R                     3 2      2 2        4  2       2   2       3     5  3
+--R                (- 6a c  + 12a b c - 3a b )d e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                               7        6 3         7 2      6 2      5 4
+--R                          ((16a b c - 4a b )e + (32a c  - 24a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               5       4 3  4       5 2      4 2      3 4    3
+--R                            (4a b c - a b )e  + (12a c  - 19a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 36a b c  + 33a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 4a c  + 37a b c  - 25a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                 7        6 3           7 2      6 2      5 4
+--R                          ((- 16a b c + 4a b )e + (- 32a c  + 24a b c - 4a b )d)
+--R                       *
+--R                          x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 5       4 3  4
+--R                            (- 4a b c + a b )e
+--R                          + 
+--R                                  5 2      4 2      3 4    3
+--R                            (- 12a c  + 19a b c - 4a b )d e
+--R                          + 
+--R                                4   2      3 3      2 5  2 2
+--R                            (36a b c  - 33a b c + 6a b )d e
+--R                          + 
+--R                               4 3      3 2 2      2 4        6  3
+--R                            (4a c  - 37a b c  + 25a b c - 4a b )d e
+--R                          + 
+--R                                 3   3      2 3 2       5     7  4
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 6      5 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                     6 2 6        6        5 3    5
+--R                                  - a b e  + (- 6a b c + 6a b )d e
+--R                                + 
+--R                                       6 2      5 2       4 4  2 4
+--R                                  (- 9a c  + 30a b c - 15a b )d e
+--R                                + 
+--R                                      5   2      4 3       3 5  3 3
+--R                                  (38a b c  - 60a b c + 20a b )d e
+--R                                + 
+--R                                     5 3      4 2 2      3 4       2 6  4 2
+--R                                  (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  5
+--R                                  (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  6
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                            4     3 2  3        3        2 3    2
+--R                         (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R                       + 
+--R                              3 2      2 2        4  2
+--R                         (- 6a c  + 12a b c - 3a b )d e
+--R                       + 
+--R                            2   2       3     5  3
+--R                         (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        4     5        4 2     3 2     4
+--R                    - 2a b c e  + (- 6a c  + 8a b c)d e
+--R                  + 
+--R                        3   2      2 3   2 3        3 3      2 2 2       4   3 2
+--R                    (16a b c  - 12a b c)d e  + (- 4a c  - 12a b c  + 8a b c)d e
+--R                  + 
+--R                        2   3     5   4       2 4       2 3     4 2  5
+--R                    (10a b c  - 2b c)d e + (2a c  - 6a b c  + 2b c )d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      4     6      4 2     3 2     5
+--R                    2a b c e  + (6a c  - 8a b c)d e
+--R                  + 
+--R                          3   2      2 3   2 4      3 3      2 2 2       4   3 3
+--R                    (- 16a b c  + 12a b c)d e  + (4a c  + 12a b c  - 8a b c)d e
+--R                  + 
+--R                          2   3     5   4 2        2 4       2 3     4 2  5
+--R                    (- 10a b c  + 2b c)d e  + (- 2a c  + 6a b c  - 2b c )d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  4       5      4 2     3 2   2 4         3   2      2 3   3 3
+--R                2a b c d e  + (6a c  - 8a b c)d e  + (- 16a b c  + 12a b c)d e
+--R              + 
+--R                   3 3      2 2 2       4   4 2         2   3     5   5
+--R                (4a c  + 12a b c  - 8a b c)d e  + (- 10a b c  + 2b c)d e
+--R              + 
+--R                     2 4       2 3     4 2  6
+--R                (- 2a c  + 6a b c  - 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                 +--------+
+--R               2   5      2   3  |   2           2   5      2   3  +-+
+--R         ((- 3a e x  - 12a d x )\|e x  + d  + (9a e x  + 12a d x )\|d )
+--R      *
+--R         ROOT
+--R                        6      5 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                            6 2 6        6        5 3    5
+--R                         - a b e  + (- 6a b c + 6a b )d e
+--R                       + 
+--R                              6 2      5 2       4 4  2 4
+--R                         (- 9a c  + 30a b c - 15a b )d e
+--R                       + 
+--R                             5   2      4 3       3 5  3 3
+--R                         (38a b c  - 60a b c + 20a b )d e
+--R                       + 
+--R                            5 3      4 2 2      3 4       2 6  4 2
+--R                         (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                       + 
+--R                               4   3      3 3 2      2 5        7  5
+--R                         (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  6
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                   4     3 2  3        3        2 3    2
+--R                (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R              + 
+--R                     3 2      2 2        4  2       2   2       3     5  3
+--R                (- 6a c  + 12a b c - 3a b )d e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                                 7        6 3           7 2      6 2      5 4
+--R                          ((- 16a b c + 4a b )e + (- 32a c  + 24a b c - 4a b )d)
+--R                       *
+--R                          x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 5       4 3  4
+--R                            (- 4a b c + a b )e
+--R                          + 
+--R                                  5 2      4 2      3 4    3
+--R                            (- 12a c  + 19a b c - 4a b )d e
+--R                          + 
+--R                                4   2      3 3      2 5  2 2
+--R                            (36a b c  - 33a b c + 6a b )d e
+--R                          + 
+--R                               4 3      3 2 2      2 4        6  3
+--R                            (4a c  - 37a b c  + 25a b c - 4a b )d e
+--R                          + 
+--R                                 3   3      2 3 2       5     7  4
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                               7        6 3         7 2      6 2      5 4
+--R                          ((16a b c - 4a b )e + (32a c  - 24a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               5       4 3  4       5 2      4 2      3 4    3
+--R                            (4a b c - a b )e  + (12a c  - 19a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 36a b c  + 33a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 4a c  + 37a b c  - 25a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 6      5 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                     6 2 6        6        5 3    5
+--R                                  - a b e  + (- 6a b c + 6a b )d e
+--R                                + 
+--R                                       6 2      5 2       4 4  2 4
+--R                                  (- 9a c  + 30a b c - 15a b )d e
+--R                                + 
+--R                                      5   2      4 3       3 5  3 3
+--R                                  (38a b c  - 60a b c + 20a b )d e
+--R                                + 
+--R                                     5 3      4 2 2      3 4       2 6  4 2
+--R                                  (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  5
+--R                                  (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  6
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                            4     3 2  3        3        2 3    2
+--R                         (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R                       + 
+--R                              3 2      2 2        4  2
+--R                         (- 6a c  + 12a b c - 3a b )d e
+--R                       + 
+--R                            2   2       3     5  3
+--R                         (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        4     5        4 2     3 2     4
+--R                    - 2a b c e  + (- 6a c  + 8a b c)d e
+--R                  + 
+--R                        3   2      2 3   2 3        3 3      2 2 2       4   3 2
+--R                    (16a b c  - 12a b c)d e  + (- 4a c  - 12a b c  + 8a b c)d e
+--R                  + 
+--R                        2   3     5   4       2 4       2 3     4 2  5
+--R                    (10a b c  - 2b c)d e + (2a c  - 6a b c  + 2b c )d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      4     6      4 2     3 2     5
+--R                    2a b c e  + (6a c  - 8a b c)d e
+--R                  + 
+--R                          3   2      2 3   2 4      3 3      2 2 2       4   3 3
+--R                    (- 16a b c  + 12a b c)d e  + (4a c  + 12a b c  - 8a b c)d e
+--R                  + 
+--R                          2   3     5   4 2        2 4       2 3     4 2  5
+--R                    (- 10a b c  + 2b c)d e  + (- 2a c  + 6a b c  - 2b c )d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  4       5      4 2     3 2   2 4         3   2      2 3   3 3
+--R                2a b c d e  + (6a c  - 8a b c)d e  + (- 16a b c  + 12a b c)d e
+--R              + 
+--R                   3 3      2 2 2       4   4 2         2   3     5   5
+--R                (4a c  + 12a b c  - 8a b c)d e  + (- 10a b c  + 2b c)d e
+--R              + 
+--R                     2 4       2 3     4 2  6
+--R                (- 2a c  + 6a b c  - 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                               +--------+
+--R             2   5      2   3  |   2             2   5      2   3  +-+
+--R         ((3a e x  + 12a d x )\|e x  + d  + (- 9a e x  - 12a d x )\|d )
+--R      *
+--R         ROOT
+--R                      6      5 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                            6 2 6        6        5 3    5
+--R                         - a b e  + (- 6a b c + 6a b )d e
+--R                       + 
+--R                              6 2      5 2       4 4  2 4
+--R                         (- 9a c  + 30a b c - 15a b )d e
+--R                       + 
+--R                             5   2      4 3       3 5  3 3
+--R                         (38a b c  - 60a b c + 20a b )d e
+--R                       + 
+--R                            5 3      4 2 2      3 4       2 6  4 2
+--R                         (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                       + 
+--R                               4   3      3 3 2      2 5        7  5
+--R                         (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  6
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                   4     3 2  3        3        2 3    2
+--R                (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R              + 
+--R                     3 2      2 2        4  2       2   2       3     5  3
+--R                (- 6a c  + 12a b c - 3a b )d e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                                 7        6 3           7 2      6 2      5 4
+--R                          ((- 16a b c + 4a b )e + (- 32a c  + 24a b c - 4a b )d)
+--R                       *
+--R                          x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               5       4 3  4       5 2      4 2      3 4    3
+--R                            (4a b c - a b )e  + (12a c  - 19a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 36a b c  + 33a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 4a c  + 37a b c  - 25a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                               7        6 3         7 2      6 2      5 4
+--R                          ((16a b c - 4a b )e + (32a c  - 24a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 5       4 3  4
+--R                            (- 4a b c + a b )e
+--R                          + 
+--R                                  5 2      4 2      3 4    3
+--R                            (- 12a c  + 19a b c - 4a b )d e
+--R                          + 
+--R                                4   2      3 3      2 5  2 2
+--R                            (36a b c  - 33a b c + 6a b )d e
+--R                          + 
+--R                               4 3      3 2 2      2 4        6  3
+--R                            (4a c  - 37a b c  + 25a b c - 4a b )d e
+--R                          + 
+--R                                 3   3      2 3 2       5     7  4
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               6      5 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                     6 2 6        6        5 3    5
+--R                                  - a b e  + (- 6a b c + 6a b )d e
+--R                                + 
+--R                                       6 2      5 2       4 4  2 4
+--R                                  (- 9a c  + 30a b c - 15a b )d e
+--R                                + 
+--R                                      5   2      4 3       3 5  3 3
+--R                                  (38a b c  - 60a b c + 20a b )d e
+--R                                + 
+--R                                     5 3      4 2 2      3 4       2 6  4 2
+--R                                  (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  5
+--R                                  (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  6
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                            4     3 2  3        3        2 3    2
+--R                         (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R                       + 
+--R                              3 2      2 2        4  2
+--R                         (- 6a c  + 12a b c - 3a b )d e
+--R                       + 
+--R                            2   2       3     5  3
+--R                         (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        4     5        4 2     3 2     4
+--R                    - 2a b c e  + (- 6a c  + 8a b c)d e
+--R                  + 
+--R                        3   2      2 3   2 3        3 3      2 2 2       4   3 2
+--R                    (16a b c  - 12a b c)d e  + (- 4a c  - 12a b c  + 8a b c)d e
+--R                  + 
+--R                        2   3     5   4       2 4       2 3     4 2  5
+--R                    (10a b c  - 2b c)d e + (2a c  - 6a b c  + 2b c )d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      4     6      4 2     3 2     5
+--R                    2a b c e  + (6a c  - 8a b c)d e
+--R                  + 
+--R                          3   2      2 3   2 4      3 3      2 2 2       4   3 3
+--R                    (- 16a b c  + 12a b c)d e  + (4a c  + 12a b c  - 8a b c)d e
+--R                  + 
+--R                          2   3     5   4 2        2 4       2 3     4 2  5
+--R                    (- 10a b c  + 2b c)d e  + (- 2a c  + 6a b c  - 2b c )d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  4       5      4 2     3 2   2 4         3   2      2 3   3 3
+--R                2a b c d e  + (6a c  - 8a b c)d e  + (- 16a b c  + 12a b c)d e
+--R              + 
+--R                   3 3      2 2 2       4   4 2         2   3     5   5
+--R                (4a c  + 12a b c  - 8a b c)d e  + (- 10a b c  + 2b c)d e
+--R              + 
+--R                     2 4       2 3     4 2  6
+--R                (- 2a c  + 6a b c  - 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                                                 +--------+
+--R              2            4                   2  2       2  +-+ |   2
+--R       ((24a e  - 18b d e)x  + (38a d e - 24b d )x  + 8a d )\|d \|e x  + d
+--R     + 
+--R              3         2  6             2        2   4           2         3  2
+--R       (- 8a e  + 6b d e )x  + (- 42a d e  + 30b d e)x  + (- 42a d e + 24b d )x
+--R     + 
+--R             3
+--R       - 8a d
+--R  /
+--R                          +--------+
+--R        2   5      2   3  |   2              2   5      2   3  +-+
+--R     (6a e x  + 24a d x )\|e x  + d  + (- 18a e x  - 24a d x )\|d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3087
+
+--S 3088 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R               +-----------+
+--R             2 |          2
+--R            a \|- 4a c + b
+--R         *
+--R            ROOT
+--R                         6      5 2
+--R                     (16a c - 4a b )
+--R                  *
+--R                     ROOT
+--R                               6 2 6        6        5 3    5
+--R                            - a b e  + (- 6a b c + 6a b )d e
+--R                          + 
+--R                                 6 2      5 2       4 4  2 4
+--R                            (- 9a c  + 30a b c - 15a b )d e
+--R                          + 
+--R                                5   2      4 3       3 5  3 3
+--R                            (38a b c  - 60a b c + 20a b )d e
+--R                          + 
+--R                               5 3      4 2 2      3 4       2 6  4 2
+--R                            (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                          + 
+--R                                  4   3      3 3 2      2 5        7  5
+--R                            (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                          + 
+--R                                4 4     3 2 3      2 4 2       6     8  6
+--R                            (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                       /
+--R                             11       10 2
+--R                          64a  c - 16a  b
+--R                 + 
+--R                      4     3 2  3        3        2 3    2
+--R                   (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R                 + 
+--R                        3 2      2 2        4  2       2   2       3     5  3
+--R                   (- 6a c  + 12a b c - 3a b )d e + (5a b c  - 5a b c + b )d
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                  7        6 3         7 2      6 2      5 4
+--R                             ((16a b c - 4a b )e + (32a c  - 24a b c + 4a b )d)x
+--R                          *
+--R                             ROOT
+--R                                       6 2 6        6        5 3    5
+--R                                    - a b e  + (- 6a b c + 6a b )d e
+--R                                  + 
+--R                                         6 2      5 2       4 4  2 4
+--R                                    (- 9a c  + 30a b c - 15a b )d e
+--R                                  + 
+--R                                        5   2      4 3       3 5  3 3
+--R                                    (38a b c  - 60a b c + 20a b )d e
+--R                                  + 
+--R                                       5 3      4 2 2      3 4       2 6  4 2
+--R                                    (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                  + 
+--R                                          4   3      3 3 2      2 5        7  5
+--R                                    (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                                  + 
+--R                                      4 4     3 2 3      2 4 2       6     8  6
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                               /
+--R                                     11       10 2
+--R                                  64a  c - 16a  b
+--R                         + 
+--R                                    5       4 3  4
+--R                               (- 4a b c + a b )e
+--R                             + 
+--R                                     5 2      4 2      3 4    3
+--R                               (- 12a c  + 19a b c - 4a b )d e
+--R                             + 
+--R                                   4   2      3 3      2 5  2 2
+--R                               (36a b c  - 33a b c + 6a b )d e
+--R                             + 
+--R                                  4 3      3 2 2      2 4        6  3
+--R                               (4a c  - 37a b c  + 25a b c - 4a b )d e
+--R                             + 
+--R                                    3   3      2 3 2       5     7  4
+--R                               (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                     7        6 3
+--R                               (- 16a b c + 4a b )e
+--R                             + 
+--R                                     7 2      6 2      5 4
+--R                               (- 32a c  + 24a b c - 4a b )d
+--R                          *
+--R                             x
+--R                          *
+--R                             ROOT
+--R                                       6 2 6        6        5 3    5
+--R                                    - a b e  + (- 6a b c + 6a b )d e
+--R                                  + 
+--R                                         6 2      5 2       4 4  2 4
+--R                                    (- 9a c  + 30a b c - 15a b )d e
+--R                                  + 
+--R                                        5   2      4 3       3 5  3 3
+--R                                    (38a b c  - 60a b c + 20a b )d e
+--R                                  + 
+--R                                       5 3      4 2 2      3 4       2 6  4 2
+--R                                    (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                  + 
+--R                                          4   3      3 3 2      2 5        7  5
+--R                                    (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                                  + 
+--R                                      4 4     3 2 3      2 4 2       6     8  6
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                               /
+--R                                     11       10 2
+--R                                  64a  c - 16a  b
+--R                         + 
+--R                                  5       4 3  4
+--R                               (4a b c - a b )e
+--R                             + 
+--R                                   5 2      4 2      3 4    3
+--R                               (12a c  - 19a b c + 4a b )d e
+--R                             + 
+--R                                     4   2      3 3      2 5  2 2
+--R                               (- 36a b c  + 33a b c - 6a b )d e
+--R                             + 
+--R                                    4 3      3 2 2      2 4        6  3
+--R                               (- 4a c  + 37a b c  - 25a b c + 4a b )d e
+--R                             + 
+--R                                  3   3      2 3 2       5     7  4
+--R                               (4a b c  - 13a b c  + 7a b c - b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                  6      5 2
+--R                              (16a c - 4a b )
+--R                           *
+--R                              ROOT
+--R                                        6 2 6        6        5 3    5
+--R                                     - a b e  + (- 6a b c + 6a b )d e
+--R                                   + 
+--R                                          6 2      5 2       4 4  2 4
+--R                                     (- 9a c  + 30a b c - 15a b )d e
+--R                                   + 
+--R                                         5   2      4 3       3 5  3 3
+--R                                     (38a b c  - 60a b c + 20a b )d e
+--R                                   + 
+--R                                        5 3      4 2 2      3 4       2 6  4 2
+--R                                     (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 12a b c  + 42a b c  - 30a b c + 6a b )
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  6
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                      11       10 2
+--R                                   64a  c - 16a  b
+--R                          + 
+--R                               4     3 2  3        3        2 3    2
+--R                            (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R                          + 
+--R                                 3 2      2 2        4  2
+--R                            (- 6a c  + 12a b c - 3a b )d e
+--R                          + 
+--R                               2   2       3     5  3
+--R                            (5a b c  - 5a b c + b )d
+--R                       /
+--R                            6      5 2
+--R                          8a c - 2a b
+--R                 + 
+--R                           4     5        4 2     3 2     4
+--R                       - 2a b c e  + (- 6a c  + 8a b c)d e
+--R                     + 
+--R                           3   2      2 3   2 3
+--R                       (16a b c  - 12a b c)d e
+--R                     + 
+--R                            3 3      2 2 2       4   3 2       2   3     5   4
+--R                       (- 4a c  - 12a b c  + 8a b c)d e  + (10a b c  - 2b c)d e
+--R                     + 
+--R                          2 4       2 3     4 2  5
+--R                       (2a c  - 6a b c  + 2b c )d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                         4     6      4 2     3 2     5
+--R                       2a b c e  + (6a c  - 8a b c)d e
+--R                     + 
+--R                             3   2      2 3   2 4
+--R                       (- 16a b c  + 12a b c)d e
+--R                     + 
+--R                          3 3      2 2 2       4   3 3         2   3     5   4 2
+--R                       (4a c  + 12a b c  - 8a b c)d e  + (- 10a b c  + 2b c)d e
+--R                     + 
+--R                            2 4       2 3     4 2  5
+--R                       (- 2a c  + 6a b c  - 2b c )d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     4       5      4 2     3 2   2 4
+--R                   2a b c d e  + (6a c  - 8a b c)d e
+--R                 + 
+--R                         3   2      2 3   3 3      3 3      2 2 2       4   4 2
+--R                   (- 16a b c  + 12a b c)d e  + (4a c  + 12a b c  - 8a b c)d e
+--R                 + 
+--R                         2   3     5   5         2 4       2 3     4 2  6
+--R                   (- 10a b c  + 2b c)d e + (- 2a c  + 6a b c  - 2b c )d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R            +-----------+
+--R          2 |          2
+--R         a \|- 4a c + b
+--R      *
+--R         ROOT
+--R                        6      5 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                            6 2 6        6        5 3    5
+--R                         - a b e  + (- 6a b c + 6a b )d e
+--R                       + 
+--R                              6 2      5 2       4 4  2 4
+--R                         (- 9a c  + 30a b c - 15a b )d e
+--R                       + 
+--R                             5   2      4 3       3 5  3 3
+--R                         (38a b c  - 60a b c + 20a b )d e
+--R                       + 
+--R                            5 3      4 2 2      3 4       2 6  4 2
+--R                         (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                       + 
+--R                               4   3      3 3 2      2 5        7  5
+--R                         (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  6
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                   4     3 2  3        3        2 3    2
+--R                (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R              + 
+--R                     3 2      2 2        4  2       2   2       3     5  3
+--R                (- 6a c  + 12a b c - 3a b )d e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               7        6 3         7 2      6 2      5 4
+--R                          ((16a b c - 4a b )e + (32a c  - 24a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               5       4 3  4       5 2      4 2      3 4    3
+--R                            (4a b c - a b )e  + (12a c  - 19a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 36a b c  + 33a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 4a c  + 37a b c  - 25a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                                 7        6 3           7 2      6 2      5 4
+--R                          ((- 16a b c + 4a b )e + (- 32a c  + 24a b c - 4a b )d)
+--R                       *
+--R                          x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 5       4 3  4
+--R                            (- 4a b c + a b )e
+--R                          + 
+--R                                  5 2      4 2      3 4    3
+--R                            (- 12a c  + 19a b c - 4a b )d e
+--R                          + 
+--R                                4   2      3 3      2 5  2 2
+--R                            (36a b c  - 33a b c + 6a b )d e
+--R                          + 
+--R                               4 3      3 2 2      2 4        6  3
+--R                            (4a c  - 37a b c  + 25a b c - 4a b )d e
+--R                          + 
+--R                                 3   3      2 3 2       5     7  4
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                                 6      5 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                     6 2 6        6        5 3    5
+--R                                  - a b e  + (- 6a b c + 6a b )d e
+--R                                + 
+--R                                       6 2      5 2       4 4  2 4
+--R                                  (- 9a c  + 30a b c - 15a b )d e
+--R                                + 
+--R                                      5   2      4 3       3 5  3 3
+--R                                  (38a b c  - 60a b c + 20a b )d e
+--R                                + 
+--R                                     5 3      4 2 2      3 4       2 6  4 2
+--R                                  (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  5
+--R                                  (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  6
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                            4     3 2  3        3        2 3    2
+--R                         (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R                       + 
+--R                              3 2      2 2        4  2
+--R                         (- 6a c  + 12a b c - 3a b )d e
+--R                       + 
+--R                            2   2       3     5  3
+--R                         (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        4     5        4 2     3 2     4
+--R                    - 2a b c e  + (- 6a c  + 8a b c)d e
+--R                  + 
+--R                        3   2      2 3   2 3        3 3      2 2 2       4   3 2
+--R                    (16a b c  - 12a b c)d e  + (- 4a c  - 12a b c  + 8a b c)d e
+--R                  + 
+--R                        2   3     5   4       2 4       2 3     4 2  5
+--R                    (10a b c  - 2b c)d e + (2a c  - 6a b c  + 2b c )d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      4     6      4 2     3 2     5
+--R                    2a b c e  + (6a c  - 8a b c)d e
+--R                  + 
+--R                          3   2      2 3   2 4      3 3      2 2 2       4   3 3
+--R                    (- 16a b c  + 12a b c)d e  + (4a c  + 12a b c  - 8a b c)d e
+--R                  + 
+--R                          2   3     5   4 2        2 4       2 3     4 2  5
+--R                    (- 10a b c  + 2b c)d e  + (- 2a c  + 6a b c  - 2b c )d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  4       5      4 2     3 2   2 4         3   2      2 3   3 3
+--R                2a b c d e  + (6a c  - 8a b c)d e  + (- 16a b c  + 12a b c)d e
+--R              + 
+--R                   3 3      2 2 2       4   4 2         2   3     5   5
+--R                (4a c  + 12a b c  - 8a b c)d e  + (- 10a b c  + 2b c)d e
+--R              + 
+--R                     2 4       2 3     4 2  6
+--R                (- 2a c  + 6a b c  - 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R               +-----------+
+--R             2 |          2
+--R            a \|- 4a c + b
+--R         *
+--R            ROOT
+--R                           6      5 2
+--R                     (- 16a c + 4a b )
+--R                  *
+--R                     ROOT
+--R                               6 2 6        6        5 3    5
+--R                            - a b e  + (- 6a b c + 6a b )d e
+--R                          + 
+--R                                 6 2      5 2       4 4  2 4
+--R                            (- 9a c  + 30a b c - 15a b )d e
+--R                          + 
+--R                                5   2      4 3       3 5  3 3
+--R                            (38a b c  - 60a b c + 20a b )d e
+--R                          + 
+--R                               5 3      4 2 2      3 4       2 6  4 2
+--R                            (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                          + 
+--R                                  4   3      3 3 2      2 5        7  5
+--R                            (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                          + 
+--R                                4 4     3 2 3      2 4 2       6     8  6
+--R                            (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                       /
+--R                             11       10 2
+--R                          64a  c - 16a  b
+--R                 + 
+--R                      4     3 2  3        3        2 3    2
+--R                   (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R                 + 
+--R                        3 2      2 2        4  2       2   2       3     5  3
+--R                   (- 6a c  + 12a b c - 3a b )d e + (5a b c  - 5a b c + b )d
+--R              /
+--R                   6      5 2
+--R                 8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                     7        6 3
+--R                               (- 16a b c + 4a b )e
+--R                             + 
+--R                                     7 2      6 2      5 4
+--R                               (- 32a c  + 24a b c - 4a b )d
+--R                          *
+--R                             x
+--R                          *
+--R                             ROOT
+--R                                       6 2 6        6        5 3    5
+--R                                    - a b e  + (- 6a b c + 6a b )d e
+--R                                  + 
+--R                                         6 2      5 2       4 4  2 4
+--R                                    (- 9a c  + 30a b c - 15a b )d e
+--R                                  + 
+--R                                        5   2      4 3       3 5  3 3
+--R                                    (38a b c  - 60a b c + 20a b )d e
+--R                                  + 
+--R                                       5 3      4 2 2      3 4       2 6  4 2
+--R                                    (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                  + 
+--R                                          4   3      3 3 2      2 5        7  5
+--R                                    (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                                  + 
+--R                                      4 4     3 2 3      2 4 2       6     8  6
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                               /
+--R                                     11       10 2
+--R                                  64a  c - 16a  b
+--R                         + 
+--R                                    5       4 3  4
+--R                               (- 4a b c + a b )e
+--R                             + 
+--R                                     5 2      4 2      3 4    3
+--R                               (- 12a c  + 19a b c - 4a b )d e
+--R                             + 
+--R                                   4   2      3 3      2 5  2 2
+--R                               (36a b c  - 33a b c + 6a b )d e
+--R                             + 
+--R                                  4 3      3 2 2      2 4        6  3
+--R                               (4a c  - 37a b c  + 25a b c - 4a b )d e
+--R                             + 
+--R                                    3   3      2 3 2       5     7  4
+--R                               (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|e x  + d
+--R                     + 
+--R                                  7        6 3         7 2      6 2      5 4
+--R                             ((16a b c - 4a b )e + (32a c  - 24a b c + 4a b )d)x
+--R                          *
+--R                             ROOT
+--R                                       6 2 6        6        5 3    5
+--R                                    - a b e  + (- 6a b c + 6a b )d e
+--R                                  + 
+--R                                         6 2      5 2       4 4  2 4
+--R                                    (- 9a c  + 30a b c - 15a b )d e
+--R                                  + 
+--R                                        5   2      4 3       3 5  3 3
+--R                                    (38a b c  - 60a b c + 20a b )d e
+--R                                  + 
+--R                                       5 3      4 2 2      3 4       2 6  4 2
+--R                                    (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                  + 
+--R                                          4   3      3 3 2      2 5        7  5
+--R                                    (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                                  + 
+--R                                      4 4     3 2 3      2 4 2       6     8  6
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                               /
+--R                                     11       10 2
+--R                                  64a  c - 16a  b
+--R                         + 
+--R                                  5       4 3  4
+--R                               (4a b c - a b )e
+--R                             + 
+--R                                   5 2      4 2      3 4    3
+--R                               (12a c  - 19a b c + 4a b )d e
+--R                             + 
+--R                                     4   2      3 3      2 5  2 2
+--R                               (- 36a b c  + 33a b c - 6a b )d e
+--R                             + 
+--R                                    4 3      3 2 2      2 4        6  3
+--R                               (- 4a c  + 37a b c  - 25a b c + 4a b )d e
+--R                             + 
+--R                                  3   3      2 3 2       5     7  4
+--R                               (4a b c  - 13a b c  + 7a b c - b )d
+--R                          *
+--R                             x
+--R                      *
+--R                          +-+
+--R                         \|d
+--R                  *
+--R                     ROOT
+--R                                    6      5 2
+--R                              (- 16a c + 4a b )
+--R                           *
+--R                              ROOT
+--R                                        6 2 6        6        5 3    5
+--R                                     - a b e  + (- 6a b c + 6a b )d e
+--R                                   + 
+--R                                          6 2      5 2       4 4  2 4
+--R                                     (- 9a c  + 30a b c - 15a b )d e
+--R                                   + 
+--R                                         5   2      4 3       3 5  3 3
+--R                                     (38a b c  - 60a b c + 20a b )d e
+--R                                   + 
+--R                                        5 3      4 2 2      3 4       2 6  4 2
+--R                                     (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 12a b c  + 42a b c  - 30a b c + 6a b )
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  6
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                      11       10 2
+--R                                   64a  c - 16a  b
+--R                          + 
+--R                               4     3 2  3        3        2 3    2
+--R                            (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R                          + 
+--R                                 3 2      2 2        4  2
+--R                            (- 6a c  + 12a b c - 3a b )d e
+--R                          + 
+--R                               2   2       3     5  3
+--R                            (5a b c  - 5a b c + b )d
+--R                       /
+--R                            6      5 2
+--R                          8a c - 2a b
+--R                 + 
+--R                           4     5        4 2     3 2     4
+--R                       - 2a b c e  + (- 6a c  + 8a b c)d e
+--R                     + 
+--R                           3   2      2 3   2 3
+--R                       (16a b c  - 12a b c)d e
+--R                     + 
+--R                            3 3      2 2 2       4   3 2       2   3     5   4
+--R                       (- 4a c  - 12a b c  + 8a b c)d e  + (10a b c  - 2b c)d e
+--R                     + 
+--R                          2 4       2 3     4 2  5
+--R                       (2a c  - 6a b c  + 2b c )d
+--R                  *
+--R                          +--------+
+--R                      +-+ |   2
+--R                     \|d \|e x  + d
+--R                 + 
+--R                         4     6      4 2     3 2     5
+--R                       2a b c e  + (6a c  - 8a b c)d e
+--R                     + 
+--R                             3   2      2 3   2 4
+--R                       (- 16a b c  + 12a b c)d e
+--R                     + 
+--R                          3 3      2 2 2       4   3 3         2   3     5   4 2
+--R                       (4a c  + 12a b c  - 8a b c)d e  + (- 10a b c  + 2b c)d e
+--R                     + 
+--R                            2 4       2 3     4 2  5
+--R                       (- 2a c  + 6a b c  - 2b c )d e
+--R                  *
+--R                      2
+--R                     x
+--R                 + 
+--R                     4       5      4 2     3 2   2 4
+--R                   2a b c d e  + (6a c  - 8a b c)d e
+--R                 + 
+--R                         3   2      2 3   3 3      3 3      2 2 2       4   4 2
+--R                   (- 16a b c  + 12a b c)d e  + (4a c  + 12a b c  - 8a b c)d e
+--R                 + 
+--R                         2   3     5   5         2 4       2 3     4 2  6
+--R                   (- 10a b c  + 2b c)d e + (- 2a c  + 6a b c  - 2b c )d
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R            +-----------+
+--R          2 |          2
+--R         a \|- 4a c + b
+--R      *
+--R         ROOT
+--R                      6      5 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                            6 2 6        6        5 3    5
+--R                         - a b e  + (- 6a b c + 6a b )d e
+--R                       + 
+--R                              6 2      5 2       4 4  2 4
+--R                         (- 9a c  + 30a b c - 15a b )d e
+--R                       + 
+--R                             5   2      4 3       3 5  3 3
+--R                         (38a b c  - 60a b c + 20a b )d e
+--R                       + 
+--R                            5 3      4 2 2      3 4       2 6  4 2
+--R                         (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                       + 
+--R                               4   3      3 3 2      2 5        7  5
+--R                         (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             4 4     3 2 3      2 4 2       6     8  6
+--R                         (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                    /
+--R                          11       10 2
+--R                       64a  c - 16a  b
+--R              + 
+--R                   4     3 2  3        3        2 3    2
+--R                (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R              + 
+--R                     3 2      2 2        4  2       2   2       3     5  3
+--R                (- 6a c  + 12a b c - 3a b )d e + (5a b c  - 5a b c + b )d
+--R           /
+--R                6      5 2
+--R              8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 7        6 3           7 2      6 2      5 4
+--R                          ((- 16a b c + 4a b )e + (- 32a c  + 24a b c - 4a b )d)
+--R                       *
+--R                          x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                               5       4 3  4       5 2      4 2      3 4    3
+--R                            (4a b c - a b )e  + (12a c  - 19a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 36a b c  + 33a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 4a c  + 37a b c  - 25a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (4a b c  - 13a b c  + 7a b c - b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|e x  + d
+--R                  + 
+--R                               7        6 3         7 2      6 2      5 4
+--R                          ((16a b c - 4a b )e + (32a c  - 24a b c + 4a b )d)x
+--R                       *
+--R                          ROOT
+--R                                    6 2 6        6        5 3    5
+--R                                 - a b e  + (- 6a b c + 6a b )d e
+--R                               + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                 (- 9a c  + 30a b c - 15a b )d e
+--R                               + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                 (38a b c  - 60a b c + 20a b )d e
+--R                               + 
+--R                                    5 3      4 2 2      3 4       2 6  4 2
+--R                                 (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  5
+--R                                 (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  6
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                  11       10 2
+--R                               64a  c - 16a  b
+--R                      + 
+--R                                 5       4 3  4
+--R                            (- 4a b c + a b )e
+--R                          + 
+--R                                  5 2      4 2      3 4    3
+--R                            (- 12a c  + 19a b c - 4a b )d e
+--R                          + 
+--R                                4   2      3 3      2 5  2 2
+--R                            (36a b c  - 33a b c + 6a b )d e
+--R                          + 
+--R                               4 3      3 2 2      2 4        6  3
+--R                            (4a c  - 37a b c  + 25a b c - 4a b )d e
+--R                          + 
+--R                                 3   3      2 3 2       5     7  4
+--R                            (- 4a b c  + 13a b c  - 7a b c + b )d
+--R                       *
+--R                          x
+--R                   *
+--R                       +-+
+--R                      \|d
+--R               *
+--R                  ROOT
+--R                               6      5 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                     6 2 6        6        5 3    5
+--R                                  - a b e  + (- 6a b c + 6a b )d e
+--R                                + 
+--R                                       6 2      5 2       4 4  2 4
+--R                                  (- 9a c  + 30a b c - 15a b )d e
+--R                                + 
+--R                                      5   2      4 3       3 5  3 3
+--R                                  (38a b c  - 60a b c + 20a b )d e
+--R                                + 
+--R                                     5 3      4 2 2      3 4       2 6  4 2
+--R                                  (6a c  - 60a b c  + 60a b c - 15a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  5
+--R                                  (- 12a b c  + 42a b c  - 30a b c + 6a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  6
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                   11       10 2
+--R                                64a  c - 16a  b
+--R                       + 
+--R                            4     3 2  3        3        2 3    2
+--R                         (2a c - a b )e  + (- 9a b c + 3a b )d e
+--R                       + 
+--R                              3 2      2 2        4  2
+--R                         (- 6a c  + 12a b c - 3a b )d e
+--R                       + 
+--R                            2   2       3     5  3
+--R                         (5a b c  - 5a b c + b )d
+--R                    /
+--R                         6      5 2
+--R                       8a c - 2a b
+--R              + 
+--R                        4     5        4 2     3 2     4
+--R                    - 2a b c e  + (- 6a c  + 8a b c)d e
+--R                  + 
+--R                        3   2      2 3   2 3        3 3      2 2 2       4   3 2
+--R                    (16a b c  - 12a b c)d e  + (- 4a c  - 12a b c  + 8a b c)d e
+--R                  + 
+--R                        2   3     5   4       2 4       2 3     4 2  5
+--R                    (10a b c  - 2b c)d e + (2a c  - 6a b c  + 2b c )d
+--R               *
+--R                       +--------+
+--R                   +-+ |   2
+--R                  \|d \|e x  + d
+--R              + 
+--R                      4     6      4 2     3 2     5
+--R                    2a b c e  + (6a c  - 8a b c)d e
+--R                  + 
+--R                          3   2      2 3   2 4      3 3      2 2 2       4   3 3
+--R                    (- 16a b c  + 12a b c)d e  + (4a c  + 12a b c  - 8a b c)d e
+--R                  + 
+--R                          2   3     5   4 2        2 4       2 3     4 2  5
+--R                    (- 10a b c  + 2b c)d e  + (- 2a c  + 6a b c  - 2b c )d e
+--R               *
+--R                   2
+--R                  x
+--R              + 
+--R                  4       5      4 2     3 2   2 4         3   2      2 3   3 3
+--R                2a b c d e  + (6a c  - 8a b c)d e  + (- 16a b c  + 12a b c)d e
+--R              + 
+--R                   3 3      2 2 2       4   4 2         2   3     5   5
+--R                (4a c  + 12a b c  - 8a b c)d e  + (- 10a b c  + 2b c)d e
+--R              + 
+--R                     2 4       2 3     4 2  6
+--R                (- 2a c  + 6a b c  - 2b c )d
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                        +-----------+
+--R                        |          2                       2
+--R         ((- a e + b d)\|- 4a c + b   - a b e + (- 2a c + b )d)
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                      +-----------+
+--R                      |          2                       2
+--R         ((a e - b d)\|- 4a c + b   - a b e + (- 2a c + b )d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R  /
+--R                       +------------------+ +------------------+
+--R         +-----------+ | +-----------+      | +-----------+
+--R       2 |          2  | |          2       | |          2
+--R     2a \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3088
+
+--S 3089 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3089
+
+)clear all
+
+--S 3090 of 3139
+t0:=x^5*sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          5 |   2
+--R         x \|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3090
+
+--S 3091 of 3139
+r0:=-1/3*(1-x^2)^(3/2)/c-b*sqrt(1-x^2)/c^2+atanh(sqrt(2)*sqrt(c)*_
+   sqrt(1-x^2)/sqrt(b+2*c-sqrt(b^2-4*a*c)))*(b^2-a*c+b*c+(-b^3+_
+   3*a*b*c-b^2*c+2*a*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*_
+   sqrt(b+2*c-sqrt(b^2-4*a*c)))+atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/_
+   sqrt(b+2*c+sqrt(b^2-4*a*c)))*(b^2-a*c+b*c+(b^3-3*a*b*c+b^2*c-2*a*c^2)/_
+   sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                             +-----------+
+--R                          2  |          2        2        2              3
+--R         (((3b - 3a)c + 3b )\|- 4a c + b   + 6a c  + (- 3b  + 9a b)c - 3b )
+--R      *
+--R          +-----------------------+                +--------+
+--R          | +-----------+                      +-+ |   2      +-+
+--R          | |          2                      \|2 \|- x  + 1 \|c
+--R         \|\|- 4a c + b   + 2c + b atanh(----------------------------)
+--R                                          +-------------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                             +-----------+
+--R                          2  |          2        2      2              3
+--R         (((3b - 3a)c + 3b )\|- 4a c + b   - 6a c  + (3b  - 9a b)c + 3b )
+--R      *
+--R          +-------------------------+               +--------+
+--R          |   +-----------+                     +-+ |   2      +-+
+--R          |   |          2                     \|2 \|- x  + 1 \|c
+--R         \|- \|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            | +-----------+
+--R                                            | |          2
+--R                                           \|\|- 4a c + b   + 2c + b
+--R     + 
+--R                             +--------+ +-----------+
+--R             2           +-+ |   2      |          2  +-+
+--R         (c x  - c - 3b)\|2 \|- x  + 1 \|- 4a c + b  \|c
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                                 +-------------------------+
+--R               +-----------+     |   +-----------+
+--R         2 +-+ |          2  +-+ |   |          2
+--R       3c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R    *
+--R        +-----------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3091
+
+--S 3092 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                           +--------+
+--R               2 2      2  |   2          2 2      2
+--R         ((- 3c x  + 12c )\|- x  + 1  + 9c x  - 12c )
+--R      *
+--R         ROOT
+--R                        6     2 5
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                    2 3        2     2   2       4       3      5
+--R                - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                          2   7        3 6     5 5  2
+--R                      (48a b c  - 28a b c  + 4b c )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  4
+--R                             (- 4a b  + 4a b - a )c
+--R                           + 
+--R                                  4      2 3     3 2  3
+--R                             (4a b  - 14a b  + 6a b )c
+--R                           + 
+--R                                 6        5      2 4  2        7       6      8
+--R                             (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                        /
+--R                                11      2 10
+--R                           64a c   - 16b c
+--R                  + 
+--R                           3      4  4         2 3      3 2  3
+--R                        (8a b - 4a )c  + (- 14a b  + 17a b )c
+--R                      + 
+--R                             5      2 4  2       7       6      8
+--R                        (7a b  - 20a b )c  + (- b  + 8a b )c - b
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6     2 5
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  4
+--R                                  (- 4a b  + 4a b - a )c
+--R                                + 
+--R                                       4      2 3     3 2  3
+--R                                  (4a b  - 14a b  + 6a b )c
+--R                                + 
+--R                                      6        5      2 4  2        7       6
+--R                                  (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c
+--R                                + 
+--R                                     8
+--R                                  - b
+--R                             /
+--R                                     11      2 10
+--R                                64a c   - 16b c
+--R                       + 
+--R                             2 3        2     2   2       4       3      5
+--R                         - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R                    /
+--R                           6     2 5
+--R                       8a c  - 2b c
+--R              + 
+--R                        3 6     2 2 5  2
+--R                  (- 16a c  + 4a b c )x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                                                              +--------+
+--R                      4      5  2      3 3     4 2       3 4  |   2
+--R                ((- 4a b + 2a )c  + (2a b  - 6a b )c + 2a b )\|- x  + 1
+--R              + 
+--R                    3 2    4   2       2 4     3 3      2 5  2      4      5  2
+--R                ((2a b  - a b)c  + (- a b  + 3a b )c - a b )x  + (4a b - 2a )c
+--R              + 
+--R                     3 3     4 2       3 4
+--R                (- 2a b  + 6a b )c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                         +--------+
+--R             2 2      2  |   2          2 2      2
+--R         ((3c x  - 12c )\|- x  + 1  - 9c x  + 12c )
+--R      *
+--R         ROOT
+--R                          6     2 5
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                    2 3        2     2   2       4       3      5
+--R                - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                          2   7        3 6     5 5  2
+--R                      (48a b c  - 28a b c  + 4b c )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  4
+--R                             (- 4a b  + 4a b - a )c
+--R                           + 
+--R                                  4      2 3     3 2  3
+--R                             (4a b  - 14a b  + 6a b )c
+--R                           + 
+--R                                 6        5      2 4  2        7       6      8
+--R                             (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                        /
+--R                                11      2 10
+--R                           64a c   - 16b c
+--R                  + 
+--R                             3      4  4       2 3      3 2  3
+--R                        (- 8a b + 4a )c  + (14a b  - 17a b )c
+--R                      + 
+--R                               5      2 4  2     7       6      8
+--R                        (- 7a b  + 20a b )c  + (b  - 8a b )c + b
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                   6     2 5
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  4
+--R                                  (- 4a b  + 4a b - a )c
+--R                                + 
+--R                                       4      2 3     3 2  3
+--R                                  (4a b  - 14a b  + 6a b )c
+--R                                + 
+--R                                      6        5      2 4  2        7       6
+--R                                  (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c
+--R                                + 
+--R                                     8
+--R                                  - b
+--R                             /
+--R                                     11      2 10
+--R                                64a c   - 16b c
+--R                       + 
+--R                             2 3        2     2   2       4       3      5
+--R                         - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R                    /
+--R                           6     2 5
+--R                       8a c  - 2b c
+--R              + 
+--R                      3 6     2 2 5  2
+--R                  (16a c  - 4a b c )x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                                                              +--------+
+--R                      4      5  2      3 3     4 2       3 4  |   2
+--R                ((- 4a b + 2a )c  + (2a b  - 6a b )c + 2a b )\|- x  + 1
+--R              + 
+--R                    3 2    4   2       2 4     3 3      2 5  2      4      5  2
+--R                ((2a b  - a b)c  + (- a b  + 3a b )c - a b )x  + (4a b - 2a )c
+--R              + 
+--R                     3 3     4 2       3 4
+--R                (- 2a b  + 6a b )c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                           +--------+
+--R               2 2      2  |   2          2 2      2
+--R         ((- 3c x  + 12c )\|- x  + 1  + 9c x  - 12c )
+--R      *
+--R         ROOT
+--R                          6     2 5
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                    2 3        2     2   2       4       3      5
+--R                - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                            2   7        3 6     5 5  2
+--R                      (- 48a b c  + 28a b c  - 4b c )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  4
+--R                             (- 4a b  + 4a b - a )c
+--R                           + 
+--R                                  4      2 3     3 2  3
+--R                             (4a b  - 14a b  + 6a b )c
+--R                           + 
+--R                                 6        5      2 4  2        7       6      8
+--R                             (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                        /
+--R                                11      2 10
+--R                           64a c   - 16b c
+--R                  + 
+--R                           3      4  4         2 3      3 2  3
+--R                        (8a b - 4a )c  + (- 14a b  + 17a b )c
+--R                      + 
+--R                             5      2 4  2       7       6      8
+--R                        (7a b  - 20a b )c  + (- b  + 8a b )c - b
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                   6     2 5
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  4
+--R                                  (- 4a b  + 4a b - a )c
+--R                                + 
+--R                                       4      2 3     3 2  3
+--R                                  (4a b  - 14a b  + 6a b )c
+--R                                + 
+--R                                      6        5      2 4  2        7       6
+--R                                  (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c
+--R                                + 
+--R                                     8
+--R                                  - b
+--R                             /
+--R                                     11      2 10
+--R                                64a c   - 16b c
+--R                       + 
+--R                             2 3        2     2   2       4       3      5
+--R                         - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R                    /
+--R                           6     2 5
+--R                       8a c  - 2b c
+--R              + 
+--R                      3 6     2 2 5  2
+--R                  (16a c  - 4a b c )x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                                                              +--------+
+--R                      4      5  2      3 3     4 2       3 4  |   2
+--R                ((- 4a b + 2a )c  + (2a b  - 6a b )c + 2a b )\|- x  + 1
+--R              + 
+--R                    3 2    4   2       2 4     3 3      2 5  2      4      5  2
+--R                ((2a b  - a b)c  + (- a b  + 3a b )c - a b )x  + (4a b - 2a )c
+--R              + 
+--R                     3 3     4 2       3 4
+--R                (- 2a b  + 6a b )c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                         +--------+
+--R             2 2      2  |   2          2 2      2
+--R         ((3c x  - 12c )\|- x  + 1  - 9c x  + 12c )
+--R      *
+--R         ROOT
+--R                        6     2 5
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                    2 3        2     2   2       4       3      5
+--R                - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                            2   7        3 6     5 5  2
+--R                      (- 48a b c  + 28a b c  - 4b c )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  4
+--R                             (- 4a b  + 4a b - a )c
+--R                           + 
+--R                                  4      2 3     3 2  3
+--R                             (4a b  - 14a b  + 6a b )c
+--R                           + 
+--R                                 6        5      2 4  2        7       6      8
+--R                             (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                        /
+--R                                11      2 10
+--R                           64a c   - 16b c
+--R                  + 
+--R                             3      4  4       2 3      3 2  3
+--R                        (- 8a b + 4a )c  + (14a b  - 17a b )c
+--R                      + 
+--R                               5      2 4  2     7       6      8
+--R                        (- 7a b  + 20a b )c  + (b  - 8a b )c + b
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6     2 5
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  4
+--R                                  (- 4a b  + 4a b - a )c
+--R                                + 
+--R                                       4      2 3     3 2  3
+--R                                  (4a b  - 14a b  + 6a b )c
+--R                                + 
+--R                                      6        5      2 4  2        7       6
+--R                                  (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c
+--R                                + 
+--R                                     8
+--R                                  - b
+--R                             /
+--R                                     11      2 10
+--R                                64a c   - 16b c
+--R                       + 
+--R                             2 3        2     2   2       4       3      5
+--R                         - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R                    /
+--R                           6     2 5
+--R                       8a c  - 2b c
+--R              + 
+--R                        3 6     2 2 5  2
+--R                  (- 16a c  + 4a b c )x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                                                              +--------+
+--R                      4      5  2      3 3     4 2       3 4  |   2
+--R                ((- 4a b + 2a )c  + (2a b  - 6a b )c + 2a b )\|- x  + 1
+--R              + 
+--R                    3 2    4   2       2 4     3 3      2 5  2      4      5  2
+--R                ((2a b  - a b)c  + (- a b  + 3a b )c - a b )x  + (4a b - 2a )c
+--R              + 
+--R                     3 3     4 2       3 4
+--R                (- 2a b  + 6a b )c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                 +--------+
+--R              4               2  |   2            6              4
+--R       (- 6c x  + (12c + 12b)x )\|- x  + 1  - 2c x  + (12c + 6b)x
+--R     + 
+--R                     2
+--R       (- 12c - 12b)x
+--R  /
+--R                    +--------+
+--R        2 2      2  |   2           2 2      2
+--R     (6c x  - 24c )\|- x  + 1  - 18c x  + 24c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3092
+
+--S 3093 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                      +-------------------------+
+--R                    +-----------+     |   +-----------+
+--R              2 +-+ |          2  +-+ |   |          2
+--R            3c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R         *
+--R             +-----------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + 2c + b
+--R         *
+--R            ROOT
+--R                           6     2 5
+--R                     (16a c  - 4b c )
+--R                  *
+--R                     ROOT
+--R                                 2 2     3     4  4        4      2 3     3 2  3
+--R                            (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                          + 
+--R                                6        5      2 4  2        7       6      8
+--R                            (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                       /
+--R                               11      2 10
+--R                          64a c   - 16b c
+--R                 + 
+--R                       2 3        2     2   2       4       3      5
+--R                   - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R              /
+--R                     6     2 5
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                             2   7        3 6     5 5  2
+--R                         (48a b c  - 28a b c  + 4b c )x
+--R                      *
+--R                         ROOT
+--R                                     2 2     3     4  4
+--R                                (- 4a b  + 4a b - a )c
+--R                              + 
+--R                                     4      2 3     3 2  3
+--R                                (4a b  - 14a b  + 6a b )c
+--R                              + 
+--R                                  6        5      2 4  2        7       6      8
+--R                              (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                           /
+--R                                   11      2 10
+--R                              64a c   - 16b c
+--R                     + 
+--R                              3      4  4         2 3      3 2  3
+--R                           (8a b - 4a )c  + (- 14a b  + 17a b )c
+--R                         + 
+--R                                5      2 4  2       7       6      8
+--R                           (7a b  - 20a b )c  + (- b  + 8a b )c - b
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                     ROOT
+--R                                    6     2 5
+--R                              (16a c  - 4b c )
+--R                           *
+--R                              ROOT
+--R                                          2 2     3     4  4
+--R                                     (- 4a b  + 4a b - a )c
+--R                                   + 
+--R                                          4      2 3     3 2  3
+--R                                     (4a b  - 14a b  + 6a b )c
+--R                                   + 
+--R                                         6        5      2 4  2
+--R                                     (- b  + 10a b  - 11a b )c
+--R                                   + 
+--R                                          7       6      8
+--R                                     (- 2b  + 6a b )c - b
+--R                                /
+--R                                        11      2 10
+--R                                   64a c   - 16b c
+--R                          + 
+--R                                2 3        2     2   2       4       3      5
+--R                            - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R                       /
+--R                              6     2 5
+--R                          8a c  - 2b c
+--R                 + 
+--R                           3 6     2 2 5  2
+--R                     (- 16a c  + 4a b c )x
+--R                  *
+--R                     ROOT
+--R                                 2 2     3     4  4        4      2 3     3 2  3
+--R                            (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                          + 
+--R                                6        5      2 4  2        7       6      8
+--R                            (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                       /
+--R                               11      2 10
+--R                          64a c   - 16b c
+--R                 + 
+--R                                                                 +--------+
+--R                         4      5  2      3 3     4 2       3 4  |   2
+--R                   ((- 4a b + 2a )c  + (2a b  - 6a b )c + 2a b )\|- x  + 1
+--R                 + 
+--R                       3 2    4   2       2 4     3 3      2 5  2
+--R                   ((2a b  - a b)c  + (- a b  + 3a b )c - a b )x
+--R                 + 
+--R                      4      5  2        3 3     4 2       3 4
+--R                   (4a b - 2a )c  + (- 2a b  + 6a b )c - 2a b
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                 +-----------+
+--R           2 +-+ |          2  +-+
+--R         3c \|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          6     2 5
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                    2 3        2     2   2       4       3      5
+--R                - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R      *
+--R         log
+--R                          2   7        3 6     5 5  2
+--R                      (48a b c  - 28a b c  + 4b c )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  4
+--R                             (- 4a b  + 4a b - a )c
+--R                           + 
+--R                                  4      2 3     3 2  3
+--R                             (4a b  - 14a b  + 6a b )c
+--R                           + 
+--R                                 6        5      2 4  2        7       6      8
+--R                             (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                        /
+--R                                11      2 10
+--R                           64a c   - 16b c
+--R                  + 
+--R                             3      4  4       2 3      3 2  3
+--R                        (- 8a b + 4a )c  + (14a b  - 17a b )c
+--R                      + 
+--R                               5      2 4  2     7       6      8
+--R                        (- 7a b  + 20a b )c  + (b  - 8a b )c + b
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                   6     2 5
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  4
+--R                                  (- 4a b  + 4a b - a )c
+--R                                + 
+--R                                       4      2 3     3 2  3
+--R                                  (4a b  - 14a b  + 6a b )c
+--R                                + 
+--R                                      6        5      2 4  2        7       6
+--R                                  (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c
+--R                                + 
+--R                                     8
+--R                                  - b
+--R                             /
+--R                                     11      2 10
+--R                                64a c   - 16b c
+--R                       + 
+--R                             2 3        2     2   2       4       3      5
+--R                         - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R                    /
+--R                           6     2 5
+--R                       8a c  - 2b c
+--R              + 
+--R                      3 6     2 2 5  2
+--R                  (16a c  - 4a b c )x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                                                              +--------+
+--R                      4      5  2      3 3     4 2       3 4  |   2
+--R                ((- 4a b + 2a )c  + (2a b  - 6a b )c + 2a b )\|- x  + 1
+--R              + 
+--R                    3 2    4   2       2 4     3 3      2 5  2      4      5  2
+--R                ((2a b  - a b)c  + (- a b  + 3a b )c - a b )x  + (4a b - 2a )c
+--R              + 
+--R                     3 3     4 2       3 4
+--R                (- 2a b  + 6a b )c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                    +-----------+
+--R              2 +-+ |          2  +-+
+--R            3c \|2 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                             6     2 5
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                     ROOT
+--R                                 2 2     3     4  4        4      2 3     3 2  3
+--R                            (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                          + 
+--R                                6        5      2 4  2        7       6      8
+--R                            (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                       /
+--R                               11      2 10
+--R                          64a c   - 16b c
+--R                 + 
+--R                       2 3        2     2   2       4       3      5
+--R                   - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R              /
+--R                     6     2 5
+--R                 8a c  - 2b c
+--R         *
+--R             +-------------------------+ +-----------------------+
+--R             |   +-----------+           | +-----------+
+--R             |   |          2            | |          2
+--R            \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R         *
+--R            log
+--R                               2   7        3 6     5 5  2
+--R                         (- 48a b c  + 28a b c  - 4b c )x
+--R                      *
+--R                         ROOT
+--R                                     2 2     3     4  4
+--R                                (- 4a b  + 4a b - a )c
+--R                              + 
+--R                                     4      2 3     3 2  3
+--R                                (4a b  - 14a b  + 6a b )c
+--R                              + 
+--R                                  6        5      2 4  2        7       6      8
+--R                              (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                           /
+--R                                   11      2 10
+--R                              64a c   - 16b c
+--R                     + 
+--R                              3      4  4         2 3      3 2  3
+--R                           (8a b - 4a )c  + (- 14a b  + 17a b )c
+--R                         + 
+--R                                5      2 4  2       7       6      8
+--R                           (7a b  - 20a b )c  + (- b  + 8a b )c - b
+--R                      *
+--R                          2
+--R                         x
+--R                  *
+--R                     ROOT
+--R                                      6     2 5
+--R                              (- 16a c  + 4b c )
+--R                           *
+--R                              ROOT
+--R                                          2 2     3     4  4
+--R                                     (- 4a b  + 4a b - a )c
+--R                                   + 
+--R                                          4      2 3     3 2  3
+--R                                     (4a b  - 14a b  + 6a b )c
+--R                                   + 
+--R                                         6        5      2 4  2
+--R                                     (- b  + 10a b  - 11a b )c
+--R                                   + 
+--R                                          7       6      8
+--R                                     (- 2b  + 6a b )c - b
+--R                                /
+--R                                        11      2 10
+--R                                   64a c   - 16b c
+--R                          + 
+--R                                2 3        2     2   2       4       3      5
+--R                            - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R                       /
+--R                              6     2 5
+--R                          8a c  - 2b c
+--R                 + 
+--R                         3 6     2 2 5  2
+--R                     (16a c  - 4a b c )x
+--R                  *
+--R                     ROOT
+--R                                 2 2     3     4  4        4      2 3     3 2  3
+--R                            (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                          + 
+--R                                6        5      2 4  2        7       6      8
+--R                            (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                       /
+--R                               11      2 10
+--R                          64a c   - 16b c
+--R                 + 
+--R                                                                 +--------+
+--R                         4      5  2      3 3     4 2       3 4  |   2
+--R                   ((- 4a b + 2a )c  + (2a b  - 6a b )c + 2a b )\|- x  + 1
+--R                 + 
+--R                       3 2    4   2       2 4     3 3      2 5  2
+--R                   ((2a b  - a b)c  + (- a b  + 3a b )c - a b )x
+--R                 + 
+--R                      4      5  2        3 3     4 2       3 4
+--R                   (4a b - 2a )c  + (- 2a b  + 6a b )c - 2a b
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                                   +-------------------------+
+--R                 +-----------+     |   +-----------+
+--R           2 +-+ |          2  +-+ |   |          2
+--R         3c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R      *
+--R         ROOT
+--R                        6     2 5
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                    2 3        2     2   2       4       3      5
+--R                - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                            2   7        3 6     5 5  2
+--R                      (- 48a b c  + 28a b c  - 4b c )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  4
+--R                             (- 4a b  + 4a b - a )c
+--R                           + 
+--R                                  4      2 3     3 2  3
+--R                             (4a b  - 14a b  + 6a b )c
+--R                           + 
+--R                                 6        5      2 4  2        7       6      8
+--R                             (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                        /
+--R                                11      2 10
+--R                           64a c   - 16b c
+--R                  + 
+--R                             3      4  4       2 3      3 2  3
+--R                        (- 8a b + 4a )c  + (14a b  - 17a b )c
+--R                      + 
+--R                               5      2 4  2     7       6      8
+--R                        (- 7a b  + 20a b )c  + (b  - 8a b )c + b
+--R                   *
+--R                       2
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6     2 5
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  4
+--R                                  (- 4a b  + 4a b - a )c
+--R                                + 
+--R                                       4      2 3     3 2  3
+--R                                  (4a b  - 14a b  + 6a b )c
+--R                                + 
+--R                                      6        5      2 4  2        7       6
+--R                                  (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c
+--R                                + 
+--R                                     8
+--R                                  - b
+--R                             /
+--R                                     11      2 10
+--R                                64a c   - 16b c
+--R                       + 
+--R                             2 3        2     2   2       4       3      5
+--R                         - 2a c  + (4a b  - 5a b)c  + (- b  + 5a b )c - b
+--R                    /
+--R                           6     2 5
+--R                       8a c  - 2b c
+--R              + 
+--R                        3 6     2 2 5  2
+--R                  (- 16a c  + 4a b c )x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  4        4      2 3     3 2  3
+--R                         (- 4a b  + 4a b - a )c  + (4a b  - 14a b  + 6a b )c
+--R                       + 
+--R                             6        5      2 4  2        7       6      8
+--R                         (- b  + 10a b  - 11a b )c  + (- 2b  + 6a b )c - b
+--R                    /
+--R                            11      2 10
+--R                       64a c   - 16b c
+--R              + 
+--R                                                              +--------+
+--R                      4      5  2      3 3     4 2       3 4  |   2
+--R                ((- 4a b + 2a )c  + (2a b  - 6a b )c + 2a b )\|- x  + 1
+--R              + 
+--R                    3 2    4   2       2 4     3 3      2 5  2      4      5  2
+--R                ((2a b  - a b)c  + (- a b  + 3a b )c - a b )x  + (4a b - 2a )c
+--R              + 
+--R                     3 3     4 2       3 4
+--R                (- 2a b  + 6a b )c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                               +-----------+
+--R                            2  |          2         2      2               3
+--R         (((- 6b + 6a)c - 6b )\|- 4a c + b   - 12a c  + (6b  - 18a b)c + 6b )
+--R      *
+--R          +-----------------------+                +--------+
+--R          | +-----------+                      +-+ |   2      +-+
+--R          | |          2                      \|2 \|- x  + 1 \|c
+--R         \|\|- 4a c + b   + 2c + b atanh(----------------------------)
+--R                                          +-------------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                               +-----------+
+--R                            2  |          2         2        2               3
+--R         (((- 6b + 6a)c - 6b )\|- 4a c + b   + 12a c  + (- 6b  + 18a b)c - 6b )
+--R      *
+--R          +-------------------------+               +--------+
+--R          |   +-----------+                     +-+ |   2      +-+
+--R          |   |          2                     \|2 \|- x  + 1 \|c
+--R         \|- \|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            | +-----------+
+--R                                            | |          2
+--R                                           \|\|- 4a c + b   + 2c + b
+--R     + 
+--R                                           +-------------------------+
+--R                         +-----------+     |   +-----------+
+--R                     +-+ |          2  +-+ |   |          2
+--R         (- 2c - 6b)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R  /
+--R                                 +-------------------------+
+--R               +-----------+     |   +-----------+
+--R         2 +-+ |          2  +-+ |   |          2
+--R       6c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R    *
+--R        +-----------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3093
+
+--S 3094 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3094
+
+)clear all
+
+--S 3095 of 3139
+t0:=x^4*sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          4 |   2
+--R         x \|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3095
+
+--S 3096 of 3139
+r0:=1/2*(2*b+c)*asin(x)/c^2+1/2*x*sqrt(1-x^2)/c+atanh(x*sqrt(b+2*c-_
+   sqrt(b^2-4*a*c))/(sqrt(1-x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*(b^2-_
+   a*c+b*c+(-b^3+3*a*b*c-b^2*c+2*a*c^2)/sqrt(b^2-4*a*c))/(c^2*_
+   sqrt(b+2*c-sqrt(b^2-4*a*c))*sqrt(-b+sqrt(b^2-4*a*c)))-atan(x*_
+   sqrt(b+2*c+sqrt(b^2-4*a*c))/(sqrt(1-x^2)*sqrt(b+sqrt(b^2-4*a*c))))*_
+   (b^2-a*c+b*c+(b^3-3*a*b*c+b^2*c-2*a*c^2)/sqrt(b^2-4*a*c))/_
+   (c^2*sqrt(b+sqrt(b^2-4*a*c))*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                             +-----------+
+--R                          2  |          2        2        2              3
+--R         (((2b - 2a)c + 2b )\|- 4a c + b   + 4a c  + (- 2b  + 6a b)c - 2b )
+--R      *
+--R          +------------------+ +-----------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R      *
+--R                   +-------------------------+
+--R                   |   +-----------+
+--R                   |   |          2
+--R                 x\|- \|- 4a c + b   + 2c + b
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R                               +-----------+
+--R                            2  |          2        2        2              3
+--R         (((- 2b + 2a)c - 2b )\|- 4a c + b   + 4a c  + (- 2b  + 6a b)c - 2b )
+--R      *
+--R          +-------------------------+ +------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R      *
+--R                   +-----------------------+
+--R                   | +-----------+
+--R                   | |          2
+--R                 x\|\|- 4a c + b   + 2c + b
+--R         atan(--------------------------------)
+--R                          +------------------+
+--R               +--------+ | +-----------+
+--R               |   2      | |          2
+--R              \|- x  + 1 \|\|- 4a c + b   + b
+--R     + 
+--R              +--------+                    +-----------+
+--R              |   2                         |          2
+--R         (c x\|- x  + 1  + (c + 2b)asin(x))\|- 4a c + b
+--R      *
+--R          +-------------------------+ +------------------+ +------------------+
+--R          |   +-----------+           | +-----------+      | +-----------+
+--R          |   |          2            | |          2       | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R  /
+--R                         +-------------------------+ +------------------+
+--R           +-----------+ |   +-----------+           | +-----------+
+--R         2 |          2  |   |          2            | |          2
+--R       2c \|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +-----------------------+
+--R        | +-----------+      | +-----------+
+--R        | |          2       | |          2
+--R       \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3096
+
+--S 3097 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +--------+
+--R            2 |   2         2 2     2
+--R         (2c \|- x  + 1  + c x  - 2c )
+--R      *
+--R         ROOT
+--R                        5     2 4
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                            2 4        2     2   3       4       3     2 2  2
+--R                         - a c  + (2a b  - 4a b)c  + (- b  + 6a b  - 4a b )c
+--R                       + 
+--R                              5       4      6
+--R                         (- 2b  + 4a b )c - b
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                            2  2     3       2      4
+--R                (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                                                     +--------+
+--R                            2 6        2 5     4 4   |   2
+--R                        (32a c  - 24a b c  + 4b c )x\|- x  + 1
+--R                      + 
+--R                              2 6        2 5     4 4
+--R                        (- 32a c  + 24a b c  - 4b c )x
+--R                   *
+--R                      ROOT
+--R                                2 4        2     2   3
+--R                             - a c  + (2a b  - 4a b)c
+--R                           + 
+--R                                 4       3     2 2  2        5       4      6
+--R                             (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                        /
+--R                                9      2 8
+--R                           64a c  - 16b c
+--R                  + 
+--R                         2   3          3     2 2  2     5       4      6
+--R                      (4a b c  + (- 5a b  + 8a b )c  + (b  - 6a b )c + b )x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|- x  + 1
+--R                  + 
+--R                         2   3        3     2 2  2       5       4      6
+--R                    (- 4a b c  + (5a b  - 8a b )c  + (- b  + 6a b )c - b )x
+--R               *
+--R                  ROOT
+--R                                 5     2 4
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                     2 4        2     2   3
+--R                                  - a c  + (2a b  - 4a b)c
+--R                                + 
+--R                                    4       3     2 2  2        5       4      6
+--R                                (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                                     2  2     3       2      4
+--R                         (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                                                    +--------+
+--R                     3 2      2 2     3        2 3  |   2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )\|- x  + 1
+--R              + 
+--R                     3 2      2 2     3        2 3  2     3 2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )x  + 2a c
+--R              + 
+--R                     2 2     3        2 3
+--R                (- 2a b  + 4a b)c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +--------+
+--R              2 |   2         2 2     2
+--R         (- 2c \|- x  + 1  - c x  + 2c )
+--R      *
+--R         ROOT
+--R                          5     2 4
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                            2 4        2     2   3       4       3     2 2  2
+--R                         - a c  + (2a b  - 4a b)c  + (- b  + 6a b  - 4a b )c
+--R                       + 
+--R                              5       4      6
+--R                         (- 2b  + 4a b )c - b
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                            2  2     3       2      4
+--R                (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                                                     +--------+
+--R                            2 6        2 5     4 4   |   2
+--R                        (32a c  - 24a b c  + 4b c )x\|- x  + 1
+--R                      + 
+--R                              2 6        2 5     4 4
+--R                        (- 32a c  + 24a b c  - 4b c )x
+--R                   *
+--R                      ROOT
+--R                                2 4        2     2   3
+--R                             - a c  + (2a b  - 4a b)c
+--R                           + 
+--R                                 4       3     2 2  2        5       4      6
+--R                             (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                        /
+--R                                9      2 8
+--R                           64a c  - 16b c
+--R                  + 
+--R                           2   3        3     2 2  2       5       4      6
+--R                      (- 4a b c  + (5a b  - 8a b )c  + (- b  + 6a b )c - b )x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|- x  + 1
+--R                  + 
+--R                       2   3          3     2 2  2     5       4      6
+--R                    (4a b c  + (- 5a b  + 8a b )c  + (b  - 6a b )c + b )x
+--R               *
+--R                  ROOT
+--R                                   5     2 4
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                     2 4        2     2   3
+--R                                  - a c  + (2a b  - 4a b)c
+--R                                + 
+--R                                    4       3     2 2  2        5       4      6
+--R                                (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                                     2  2     3       2      4
+--R                         (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                                                    +--------+
+--R                     3 2      2 2     3        2 3  |   2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )\|- x  + 1
+--R              + 
+--R                     3 2      2 2     3        2 3  2     3 2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )x  + 2a c
+--R              + 
+--R                     2 2     3        2 3
+--R                (- 2a b  + 4a b)c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R              +--------+
+--R            2 |   2         2 2     2
+--R         (2c \|- x  + 1  + c x  - 2c )
+--R      *
+--R         ROOT
+--R                          5     2 4
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                            2 4        2     2   3       4       3     2 2  2
+--R                         - a c  + (2a b  - 4a b)c  + (- b  + 6a b  - 4a b )c
+--R                       + 
+--R                              5       4      6
+--R                         (- 2b  + 4a b )c - b
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                            2  2     3       2      4
+--R                (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                                                       +--------+
+--R                              2 6        2 5     4 4   |   2
+--R                        (- 32a c  + 24a b c  - 4b c )x\|- x  + 1
+--R                      + 
+--R                            2 6        2 5     4 4
+--R                        (32a c  - 24a b c  + 4b c )x
+--R                   *
+--R                      ROOT
+--R                                2 4        2     2   3
+--R                             - a c  + (2a b  - 4a b)c
+--R                           + 
+--R                                 4       3     2 2  2        5       4      6
+--R                             (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                        /
+--R                                9      2 8
+--R                           64a c  - 16b c
+--R                  + 
+--R                         2   3          3     2 2  2     5       4      6
+--R                      (4a b c  + (- 5a b  + 8a b )c  + (b  - 6a b )c + b )x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|- x  + 1
+--R                  + 
+--R                         2   3        3     2 2  2       5       4      6
+--R                    (- 4a b c  + (5a b  - 8a b )c  + (- b  + 6a b )c - b )x
+--R               *
+--R                  ROOT
+--R                                   5     2 4
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                     2 4        2     2   3
+--R                                  - a c  + (2a b  - 4a b)c
+--R                                + 
+--R                                    4       3     2 2  2        5       4      6
+--R                                (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                                     2  2     3       2      4
+--R                         (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                                                    +--------+
+--R                     3 2      2 2     3        2 3  |   2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )\|- x  + 1
+--R              + 
+--R                     3 2      2 2     3        2 3  2     3 2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )x  + 2a c
+--R              + 
+--R                     2 2     3        2 3
+--R                (- 2a b  + 4a b)c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +--------+
+--R              2 |   2         2 2     2
+--R         (- 2c \|- x  + 1  - c x  + 2c )
+--R      *
+--R         ROOT
+--R                        5     2 4
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                            2 4        2     2   3       4       3     2 2  2
+--R                         - a c  + (2a b  - 4a b)c  + (- b  + 6a b  - 4a b )c
+--R                       + 
+--R                              5       4      6
+--R                         (- 2b  + 4a b )c - b
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                            2  2     3       2      4
+--R                (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                                                       +--------+
+--R                              2 6        2 5     4 4   |   2
+--R                        (- 32a c  + 24a b c  - 4b c )x\|- x  + 1
+--R                      + 
+--R                            2 6        2 5     4 4
+--R                        (32a c  - 24a b c  + 4b c )x
+--R                   *
+--R                      ROOT
+--R                                2 4        2     2   3
+--R                             - a c  + (2a b  - 4a b)c
+--R                           + 
+--R                                 4       3     2 2  2        5       4      6
+--R                             (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                        /
+--R                                9      2 8
+--R                           64a c  - 16b c
+--R                  + 
+--R                           2   3        3     2 2  2       5       4      6
+--R                      (- 4a b c  + (5a b  - 8a b )c  + (- b  + 6a b )c - b )x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|- x  + 1
+--R                  + 
+--R                       2   3          3     2 2  2     5       4      6
+--R                    (4a b c  + (- 5a b  + 8a b )c  + (b  - 6a b )c + b )x
+--R               *
+--R                  ROOT
+--R                                 5     2 4
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                     2 4        2     2   3
+--R                                  - a c  + (2a b  - 4a b)c
+--R                                + 
+--R                                    4       3     2 2  2        5       4      6
+--R                                (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                                     2  2     3       2      4
+--R                         (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                                                    +--------+
+--R                     3 2      2 2     3        2 3  |   2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )\|- x  + 1
+--R              + 
+--R                     3 2      2 2     3        2 3  2     3 2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )x  + 2a c
+--R              + 
+--R                     2 2     3        2 3
+--R                (- 2a b  + 4a b)c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                                               +--------+
+--R                    +--------+                                 |   2
+--R                    |   2                    2                \|- x  + 1  - 1
+--R       ((- 4c - 8b)\|- x  + 1  + (- 2c - 4b)x  + 4c + 8b)atan(---------------)
+--R                                                                     x
+--R     + 
+--R                     +--------+
+--R           3         |   2            3
+--R       (c x  - 2c x)\|- x  + 1  - 2c x  + 2c x
+--R  /
+--R         +--------+
+--R       2 |   2          2 2     2
+--R     4c \|- x  + 1  + 2c x  - 4c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3097
+
+--S 3098 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +-------------------------+ +------------------+
+--R            +-----------+ |   +-----------+           | +-----------+
+--R          2 |          2  |   |          2            | |          2
+--R         c \|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +-----------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R      *
+--R         ROOT
+--R                        5     2 4
+--R                  (16a c  - 4b c )
+--R               *
+--R                  ROOT
+--R                            2 4        2     2   3       4       3     2 2  2
+--R                         - a c  + (2a b  - 4a b)c  + (- b  + 6a b  - 4a b )c
+--R                       + 
+--R                              5       4      6
+--R                         (- 2b  + 4a b )c - b
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                            2  2     3       2      4
+--R                (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                                                     +--------+
+--R                            2 6        2 5     4 4   |   2
+--R                        (32a c  - 24a b c  + 4b c )x\|- x  + 1
+--R                      + 
+--R                              2 6        2 5     4 4
+--R                        (- 32a c  + 24a b c  - 4b c )x
+--R                   *
+--R                      ROOT
+--R                                2 4        2     2   3
+--R                             - a c  + (2a b  - 4a b)c
+--R                           + 
+--R                                 4       3     2 2  2        5       4      6
+--R                             (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                        /
+--R                                9      2 8
+--R                           64a c  - 16b c
+--R                  + 
+--R                         2   3          3     2 2  2     5       4      6
+--R                      (4a b c  + (- 5a b  + 8a b )c  + (b  - 6a b )c + b )x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|- x  + 1
+--R                  + 
+--R                         2   3        3     2 2  2       5       4      6
+--R                    (- 4a b c  + (5a b  - 8a b )c  + (- b  + 6a b )c - b )x
+--R               *
+--R                  ROOT
+--R                                 5     2 4
+--R                           (16a c  - 4b c )
+--R                        *
+--R                           ROOT
+--R                                     2 4        2     2   3
+--R                                  - a c  + (2a b  - 4a b)c
+--R                                + 
+--R                                    4       3     2 2  2        5       4      6
+--R                                (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                                     2  2     3       2      4
+--R                         (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                                                    +--------+
+--R                     3 2      2 2     3        2 3  |   2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )\|- x  + 1
+--R              + 
+--R                     3 2      2 2     3        2 3  2     3 2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )x  + 2a c
+--R              + 
+--R                     2 2     3        2 3
+--R                (- 2a b  + 4a b)c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R               +-----------+
+--R             2 |          2
+--R            c \|- 4a c + b
+--R         *
+--R            ROOT
+--R                             5     2 4
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                     ROOT
+--R                               2 4        2     2   3       4       3     2 2  2
+--R                            - a c  + (2a b  - 4a b)c  + (- b  + 6a b  - 4a b )c
+--R                          + 
+--R                                 5       4      6
+--R                            (- 2b  + 4a b )c - b
+--R                       /
+--R                               9      2 8
+--R                          64a c  - 16b c
+--R                 + 
+--R                               2  2     3       2      4
+--R                   (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R              /
+--R                     5     2 4
+--R                 8a c  - 2b c
+--R         *
+--R             +-------------------------+ +------------------+
+--R             |   +-----------+           | +-----------+
+--R             |   |          2            | |          2
+--R            \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R         *
+--R             +------------------+ +-----------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R         *
+--R            log
+--R                                                        +--------+
+--R                               2 6        2 5     4 4   |   2
+--R                           (32a c  - 24a b c  + 4b c )x\|- x  + 1
+--R                         + 
+--R                                 2 6        2 5     4 4
+--R                           (- 32a c  + 24a b c  - 4b c )x
+--R                      *
+--R                         ROOT
+--R                                   2 4        2     2   3
+--R                                - a c  + (2a b  - 4a b)c
+--R                              + 
+--R                                  4       3     2 2  2        5       4      6
+--R                              (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                           /
+--R                                   9      2 8
+--R                              64a c  - 16b c
+--R                     + 
+--R                              2   3        3     2 2  2       5       4      6
+--R                         (- 4a b c  + (5a b  - 8a b )c  + (- b  + 6a b )c - b )x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|- x  + 1
+--R                     + 
+--R                          2   3          3     2 2  2     5       4      6
+--R                       (4a b c  + (- 5a b  + 8a b )c  + (b  - 6a b )c + b )x
+--R                  *
+--R                     ROOT
+--R                                      5     2 4
+--R                              (- 16a c  + 4b c )
+--R                           *
+--R                              ROOT
+--R                                        2 4        2     2   3
+--R                                     - a c  + (2a b  - 4a b)c
+--R                                   + 
+--R                                         4       3     2 2  2        5       4
+--R                                     (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c
+--R                                   + 
+--R                                        6
+--R                                     - b
+--R                                /
+--R                                        9      2 8
+--R                                   64a c  - 16b c
+--R                          + 
+--R                                        2  2     3       2      4
+--R                            (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R                       /
+--R                              5     2 4
+--R                          8a c  - 2b c
+--R                 + 
+--R                                                       +--------+
+--R                        3 2      2 2     3        2 3  |   2
+--R                   (- 2a c  + (2a b  - 4a b)c + 2a b )\|- x  + 1
+--R                 + 
+--R                        3 2      2 2     3        2 3  2     3 2
+--R                   (- 2a c  + (2a b  - 4a b)c + 2a b )x  + 2a c
+--R                 + 
+--R                        2 2     3        2 3
+--R                   (- 2a b  + 4a b)c - 2a b
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R            +-----------+
+--R          2 |          2
+--R         c \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          5     2 4
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                  ROOT
+--R                            2 4        2     2   3       4       3     2 2  2
+--R                         - a c  + (2a b  - 4a b)c  + (- b  + 6a b  - 4a b )c
+--R                       + 
+--R                              5       4      6
+--R                         (- 2b  + 4a b )c - b
+--R                    /
+--R                            9      2 8
+--R                       64a c  - 16b c
+--R              + 
+--R                            2  2     3       2      4
+--R                (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R           /
+--R                  5     2 4
+--R              8a c  - 2b c
+--R      *
+--R          +-------------------------+ +------------------+ +------------------+
+--R          |   +-----------+           | +-----------+      | +-----------+
+--R          |   |          2            | |          2       | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R      *
+--R         log
+--R                                                       +--------+
+--R                              2 6        2 5     4 4   |   2
+--R                        (- 32a c  + 24a b c  - 4b c )x\|- x  + 1
+--R                      + 
+--R                            2 6        2 5     4 4
+--R                        (32a c  - 24a b c  + 4b c )x
+--R                   *
+--R                      ROOT
+--R                                2 4        2     2   3
+--R                             - a c  + (2a b  - 4a b)c
+--R                           + 
+--R                                 4       3     2 2  2        5       4      6
+--R                             (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                        /
+--R                                9      2 8
+--R                           64a c  - 16b c
+--R                  + 
+--R                         2   3          3     2 2  2     5       4      6
+--R                      (4a b c  + (- 5a b  + 8a b )c  + (b  - 6a b )c + b )x
+--R                   *
+--R                       +--------+
+--R                       |   2
+--R                      \|- x  + 1
+--R                  + 
+--R                         2   3        3     2 2  2       5       4      6
+--R                    (- 4a b c  + (5a b  - 8a b )c  + (- b  + 6a b )c - b )x
+--R               *
+--R                  ROOT
+--R                                   5     2 4
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                           ROOT
+--R                                     2 4        2     2   3
+--R                                  - a c  + (2a b  - 4a b)c
+--R                                + 
+--R                                    4       3     2 2  2        5       4      6
+--R                                (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                             /
+--R                                     9      2 8
+--R                                64a c  - 16b c
+--R                       + 
+--R                                     2  2     3       2      4
+--R                         (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R                    /
+--R                           5     2 4
+--R                       8a c  - 2b c
+--R              + 
+--R                                                    +--------+
+--R                     3 2      2 2     3        2 3  |   2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )\|- x  + 1
+--R              + 
+--R                     3 2      2 2     3        2 3  2     3 2
+--R                (- 2a c  + (2a b  - 4a b)c + 2a b )x  + 2a c
+--R              + 
+--R                     2 2     3        2 3
+--R                (- 2a b  + 4a b)c - 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                             +-------------------------+ +------------------+
+--R               +-----------+ |   +-----------+           | +-----------+
+--R             2 |          2  |   |          2            | |          2
+--R            c \|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R         *
+--R             +------------------+ +-----------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R         *
+--R            ROOT
+--R                           5     2 4
+--R                     (16a c  - 4b c )
+--R                  *
+--R                     ROOT
+--R                               2 4        2     2   3       4       3     2 2  2
+--R                            - a c  + (2a b  - 4a b)c  + (- b  + 6a b  - 4a b )c
+--R                          + 
+--R                                 5       4      6
+--R                            (- 2b  + 4a b )c - b
+--R                       /
+--R                               9      2 8
+--R                          64a c  - 16b c
+--R                 + 
+--R                               2  2     3       2      4
+--R                   (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R              /
+--R                     5     2 4
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                                                          +--------+
+--R                                 2 6        2 5     4 4   |   2
+--R                           (- 32a c  + 24a b c  - 4b c )x\|- x  + 1
+--R                         + 
+--R                               2 6        2 5     4 4
+--R                           (32a c  - 24a b c  + 4b c )x
+--R                      *
+--R                         ROOT
+--R                                   2 4        2     2   3
+--R                                - a c  + (2a b  - 4a b)c
+--R                              + 
+--R                                  4       3     2 2  2        5       4      6
+--R                              (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c - b
+--R                           /
+--R                                   9      2 8
+--R                              64a c  - 16b c
+--R                     + 
+--R                              2   3        3     2 2  2       5       4      6
+--R                         (- 4a b c  + (5a b  - 8a b )c  + (- b  + 6a b )c - b )x
+--R                      *
+--R                          +--------+
+--R                          |   2
+--R                         \|- x  + 1
+--R                     + 
+--R                          2   3          3     2 2  2     5       4      6
+--R                       (4a b c  + (- 5a b  + 8a b )c  + (b  - 6a b )c + b )x
+--R                  *
+--R                     ROOT
+--R                                    5     2 4
+--R                              (16a c  - 4b c )
+--R                           *
+--R                              ROOT
+--R                                        2 4        2     2   3
+--R                                     - a c  + (2a b  - 4a b)c
+--R                                   + 
+--R                                         4       3     2 2  2        5       4
+--R                                     (- b  + 6a b  - 4a b )c  + (- 2b  + 4a b )c
+--R                                   + 
+--R                                        6
+--R                                     - b
+--R                                /
+--R                                        9      2 8
+--R                                   64a c  - 16b c
+--R                          + 
+--R                                        2  2     3       2      4
+--R                            (- 3a b + 2a )c  + (b  - 4a b )c + b
+--R                       /
+--R                              5     2 4
+--R                          8a c  - 2b c
+--R                 + 
+--R                                                       +--------+
+--R                        3 2      2 2     3        2 3  |   2
+--R                   (- 2a c  + (2a b  - 4a b)c + 2a b )\|- x  + 1
+--R                 + 
+--R                        3 2      2 2     3        2 3  2     3 2
+--R                   (- 2a c  + (2a b  - 4a b)c + 2a b )x  + 2a c
+--R                 + 
+--R                        2 2     3        2 3
+--R                   (- 2a b  + 4a b)c - 2a b
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                               +-----------+
+--R                            2  |          2        2      2              3
+--R         (((- 2b + 2a)c - 2b )\|- 4a c + b   - 4a c  + (2b  - 6a b)c + 2b )
+--R      *
+--R          +------------------+ +-----------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R      *
+--R                   +-------------------------+
+--R                   |   +-----------+
+--R                   |   |          2
+--R                 x\|- \|- 4a c + b   + 2c + b
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R                             +-----------+
+--R                          2  |          2        2      2              3
+--R         (((2b - 2a)c + 2b )\|- 4a c + b   - 4a c  + (2b  - 6a b)c + 2b )
+--R      *
+--R          +-------------------------+ +------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R      *
+--R                   +-----------------------+
+--R                   | +-----------+
+--R                   | |          2
+--R                 x\|\|- 4a c + b   + 2c + b
+--R         atan(--------------------------------)
+--R                          +------------------+
+--R               +--------+ | +-----------+
+--R               |   2      | |          2
+--R              \|- x  + 1 \|\|- 4a c + b   + b
+--R     + 
+--R                                          +--------+
+--R                       +-----------+      |   2
+--R                       |          2      \|- x  + 1  - 1
+--R           (- 2c - 4b)\|- 4a c + b  atan(---------------)
+--R                                                x
+--R         + 
+--R                             +-----------+
+--R                             |          2
+--R           (- c - 2b)asin(x)\|- 4a c + b
+--R      *
+--R          +-------------------------+ +------------------+ +------------------+
+--R          |   +-----------+           | +-----------+      | +-----------+
+--R          |   |          2            | |          2       | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R  /
+--R                         +-------------------------+ +------------------+
+--R           +-----------+ |   +-----------+           | +-----------+
+--R         2 |          2  |   |          2            | |          2
+--R       2c \|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +-----------------------+
+--R        | +-----------+      | +-----------+
+--R        | |          2       | |          2
+--R       \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3098
+
+--S 3099 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3099
+
+)clear all
+
+--S 3100 of 3139
+t0:=x^3*sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          3 |   2
+--R         x \|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3100
+
+--S 3101 of 3139
+r0:=sqrt(1-x^2)/c-atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/sqrt(b+2*c-_
+   sqrt(b^2-4*a*c)))*(b+c+(2*a*c-b*(b+c))/sqrt(b^2-4*a*c))/(c^(3/2)*_
+   sqrt(2)*sqrt(b+2*c-sqrt(b^2-4*a*c)))-atanh(sqrt(2)*sqrt(c)*_
+   sqrt(1-x^2)/sqrt(b+2*c+sqrt(b^2-4*a*c)))*(b+c+(b^2-2*a*c+b*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                    +-----------------------+
+--R                    +-----------+                   | +-----------+
+--R                    |          2                 2  | |          2
+--R         ((- c - b)\|- 4a c + b   + (b - 2a)c + b )\|\|- 4a c + b   + 2c + b
+--R      *
+--R                         +--------+
+--R                     +-+ |   2      +-+
+--R                    \|2 \|- x  + 1 \|c
+--R         atanh(----------------------------)
+--R                +-------------------------+
+--R                |   +-----------+
+--R                |   |          2
+--R               \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                    +-----------+
+--R                    |          2                   2
+--R         ((- c - b)\|- 4a c + b   + (- b + 2a)c - b )
+--R      *
+--R          +-------------------------+               +--------+
+--R          |   +-----------+                     +-+ |   2      +-+
+--R          |   |          2                     \|2 \|- x  + 1 \|c
+--R         \|- \|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            | +-----------+
+--R                                            | |          2
+--R                                           \|\|- 4a c + b   + 2c + b
+--R     + 
+--R                                           +-------------------------+
+--R              +--------+ +-----------+     |   +-----------+
+--R          +-+ |   2      |          2  +-+ |   |          2
+--R         \|2 \|- x  + 1 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R  /
+--R                               +-------------------------+
+--R             +-----------+     |   +-----------+
+--R         +-+ |          2  +-+ |   |          2
+--R       c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R    *
+--R        +-----------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3101
+
+--S 3102 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +--------+
+--R              |   2
+--R         (- c\|- x  + 1  + c)
+--R      *
+--R         ROOT
+--R                                 +--------------------------------------------+
+--R                                 |    2           2  2        3       2      4
+--R                      4     2 3  |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                (16a c  - 4b c ) |--------------------------------------------
+--R                                 |                    7      2 6
+--R                                \|               64a c  - 16b c
+--R              + 
+--R                    2       2             3
+--R                2a c  + (- b  + 3a b)c - b
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                          2 5        2 4     4 3  2
+--R                      (32a c  - 24a b c  + 4b c )x
+--R                   *
+--R                       +--------------------------------------------+
+--R                       |    2           2  2        3       2      4
+--R                       |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                       |--------------------------------------------
+--R                       |                    7      2 6
+--R                      \|               64a c  - 16b c
+--R                  + 
+--R                          2     2   2       4       3      5  2
+--R                    ((4a b  - 4a b)c  + (- b  + 5a b )c - b )x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                            +--------------------------------------------+
+--R                            |    2           2  2        3       2      4
+--R                            |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                            |--------------------------------------------
+--R                            |                    7      2 6
+--R                           \|               64a c  - 16b c
+--R                       + 
+--R                             2       2             3
+--R                         2a c  + (- b  + 3a b)c - b
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                      2 4       2 3  2
+--R                  (16a c  - 4a b c )x
+--R               *
+--R                   +--------------------------------------------+
+--R                   |    2           2  2        3       2      4
+--R                   |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                   |--------------------------------------------
+--R                   |                    7      2 6
+--R                  \|               64a c  - 16b c
+--R              + 
+--R                                          +--------+
+--R                      2      3       2 2  |   2             2    2         3  2
+--R                ((- 2a b + 2a )c - 2a b )\|- x  + 1  + ((a b  - a b)c + a b )x
+--R              + 
+--R                   2      3       2 2
+--R                (2a b - 2a )c + 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R            +--------+
+--R            |   2
+--R         (c\|- x  + 1  - c)
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                   +--------------------------------------------+
+--R                   |    2           2  2        3       2      4
+--R                   |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                   |--------------------------------------------
+--R                   |                    7      2 6
+--R                  \|               64a c  - 16b c
+--R              + 
+--R                    2       2             3
+--R                2a c  + (- b  + 3a b)c - b
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                          2 5        2 4     4 3  2
+--R                      (32a c  - 24a b c  + 4b c )x
+--R                   *
+--R                       +--------------------------------------------+
+--R                       |    2           2  2        3       2      4
+--R                       |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                       |--------------------------------------------
+--R                       |                    7      2 6
+--R                      \|               64a c  - 16b c
+--R                  + 
+--R                            2     2   2     4       3      5  2
+--R                    ((- 4a b  + 4a b)c  + (b  - 5a b )c + b )x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                            +--------------------------------------------+
+--R                            |    2           2  2        3       2      4
+--R                            |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                            |--------------------------------------------
+--R                            |                    7      2 6
+--R                           \|               64a c  - 16b c
+--R                       + 
+--R                             2       2             3
+--R                         2a c  + (- b  + 3a b)c - b
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                        2 4       2 3  2
+--R                  (- 16a c  + 4a b c )x
+--R               *
+--R                   +--------------------------------------------+
+--R                   |    2           2  2        3       2      4
+--R                   |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                   |--------------------------------------------
+--R                   |                    7      2 6
+--R                  \|               64a c  - 16b c
+--R              + 
+--R                                          +--------+
+--R                      2      3       2 2  |   2             2    2         3  2
+--R                ((- 2a b + 2a )c - 2a b )\|- x  + 1  + ((a b  - a b)c + a b )x
+--R              + 
+--R                   2      3       2 2
+--R                (2a b - 2a )c + 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R              +--------+
+--R              |   2
+--R         (- c\|- x  + 1  + c)
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                   +--------------------------------------------+
+--R                   |    2           2  2        3       2      4
+--R                   |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                   |--------------------------------------------
+--R                   |                    7      2 6
+--R                  \|               64a c  - 16b c
+--R              + 
+--R                    2       2             3
+--R                2a c  + (- b  + 3a b)c - b
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                            2 5        2 4     4 3  2
+--R                      (- 32a c  + 24a b c  - 4b c )x
+--R                   *
+--R                       +--------------------------------------------+
+--R                       |    2           2  2        3       2      4
+--R                       |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                       |--------------------------------------------
+--R                       |                    7      2 6
+--R                      \|               64a c  - 16b c
+--R                  + 
+--R                          2     2   2       4       3      5  2
+--R                    ((4a b  - 4a b)c  + (- b  + 5a b )c - b )x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                            +--------------------------------------------+
+--R                            |    2           2  2        3       2      4
+--R                            |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                            |--------------------------------------------
+--R                            |                    7      2 6
+--R                           \|               64a c  - 16b c
+--R                       + 
+--R                             2       2             3
+--R                         2a c  + (- b  + 3a b)c - b
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                        2 4       2 3  2
+--R                  (- 16a c  + 4a b c )x
+--R               *
+--R                   +--------------------------------------------+
+--R                   |    2           2  2        3       2      4
+--R                   |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                   |--------------------------------------------
+--R                   |                    7      2 6
+--R                  \|               64a c  - 16b c
+--R              + 
+--R                                          +--------+
+--R                      2      3       2 2  |   2             2    2         3  2
+--R                ((- 2a b + 2a )c - 2a b )\|- x  + 1  + ((a b  - a b)c + a b )x
+--R              + 
+--R                   2      3       2 2
+--R                (2a b - 2a )c + 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R            +--------+
+--R            |   2
+--R         (c\|- x  + 1  - c)
+--R      *
+--R         ROOT
+--R                                 +--------------------------------------------+
+--R                                 |    2           2  2        3       2      4
+--R                      4     2 3  |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                (16a c  - 4b c ) |--------------------------------------------
+--R                                 |                    7      2 6
+--R                                \|               64a c  - 16b c
+--R              + 
+--R                    2       2             3
+--R                2a c  + (- b  + 3a b)c - b
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                            2 5        2 4     4 3  2
+--R                      (- 32a c  + 24a b c  - 4b c )x
+--R                   *
+--R                       +--------------------------------------------+
+--R                       |    2           2  2        3       2      4
+--R                       |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                       |--------------------------------------------
+--R                       |                    7      2 6
+--R                      \|               64a c  - 16b c
+--R                  + 
+--R                            2     2   2     4       3      5  2
+--R                    ((- 4a b  + 4a b)c  + (b  - 5a b )c + b )x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                            +--------------------------------------------+
+--R                            |    2           2  2        3       2      4
+--R                            |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                            |--------------------------------------------
+--R                            |                    7      2 6
+--R                           \|               64a c  - 16b c
+--R                       + 
+--R                             2       2             3
+--R                         2a c  + (- b  + 3a b)c - b
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                      2 4       2 3  2
+--R                  (16a c  - 4a b c )x
+--R               *
+--R                   +--------------------------------------------+
+--R                   |    2           2  2        3       2      4
+--R                   |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                   |--------------------------------------------
+--R                   |                    7      2 6
+--R                  \|               64a c  - 16b c
+--R              + 
+--R                                          +--------+
+--R                      2      3       2 2  |   2             2    2         3  2
+--R                ((- 2a b + 2a )c - 2a b )\|- x  + 1  + ((a b  - a b)c + a b )x
+--R              + 
+--R                   2      3       2 2
+--R                (2a b - 2a )c + 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R           2
+--R       - 2x
+--R  /
+--R        +--------+
+--R        |   2
+--R     2c\|- x  + 1  - 2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3102
+
+--S 3103 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                    +-------------------------+
+--R                  +-----------+     |   +-----------+
+--R              +-+ |          2  +-+ |   |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R         *
+--R             +-----------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + 2c + b
+--R         *
+--R            ROOT
+--R                           4     2 3
+--R                     (16a c  - 4b c )
+--R                  *
+--R                      +--------------------------------------------+
+--R                      |    2           2  2        3       2      4
+--R                      |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                      |--------------------------------------------
+--R                      |                    7      2 6
+--R                     \|               64a c  - 16b c
+--R                 + 
+--R                       2       2             3
+--R                   2a c  + (- b  + 3a b)c - b
+--R              /
+--R                     4     2 3
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                             2 5        2 4     4 3  2
+--R                         (32a c  - 24a b c  + 4b c )x
+--R                      *
+--R                          +--------------------------------------------+
+--R                          |    2           2  2        3       2      4
+--R                          |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                          |--------------------------------------------
+--R                          |                    7      2 6
+--R                         \|               64a c  - 16b c
+--R                     + 
+--R                             2     2   2       4       3      5  2
+--R                       ((4a b  - 4a b)c  + (- b  + 5a b )c - b )x
+--R                  *
+--R                     ROOT
+--R                                    4     2 3
+--R                              (16a c  - 4b c )
+--R                           *
+--R                               +--------------------------------------------+
+--R                               |    2           2  2        3       2      4
+--R                               |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                               |--------------------------------------------
+--R                               |                    7      2 6
+--R                              \|               64a c  - 16b c
+--R                          + 
+--R                                2       2             3
+--R                            2a c  + (- b  + 3a b)c - b
+--R                       /
+--R                              4     2 3
+--R                          8a c  - 2b c
+--R                 + 
+--R                         2 4       2 3  2
+--R                     (16a c  - 4a b c )x
+--R                  *
+--R                      +--------------------------------------------+
+--R                      |    2           2  2        3       2      4
+--R                      |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                      |--------------------------------------------
+--R                      |                    7      2 6
+--R                     \|               64a c  - 16b c
+--R                 + 
+--R                                             +--------+
+--R                         2      3       2 2  |   2
+--R                   ((- 2a b + 2a )c - 2a b )\|- x  + 1
+--R                 + 
+--R                        2    2         3  2      2      3       2 2
+--R                   ((a b  - a b)c + a b )x  + (2a b - 2a )c + 2a b
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2  +-+
+--R         c\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          4     2 3
+--R                  (- 16a c  + 4b c )
+--R               *
+--R                   +--------------------------------------------+
+--R                   |    2           2  2        3       2      4
+--R                   |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                   |--------------------------------------------
+--R                   |                    7      2 6
+--R                  \|               64a c  - 16b c
+--R              + 
+--R                    2       2             3
+--R                2a c  + (- b  + 3a b)c - b
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R      *
+--R         log
+--R                          2 5        2 4     4 3  2
+--R                      (32a c  - 24a b c  + 4b c )x
+--R                   *
+--R                       +--------------------------------------------+
+--R                       |    2           2  2        3       2      4
+--R                       |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                       |--------------------------------------------
+--R                       |                    7      2 6
+--R                      \|               64a c  - 16b c
+--R                  + 
+--R                            2     2   2     4       3      5  2
+--R                    ((- 4a b  + 4a b)c  + (b  - 5a b )c + b )x
+--R               *
+--R                  ROOT
+--R                                   4     2 3
+--R                           (- 16a c  + 4b c )
+--R                        *
+--R                            +--------------------------------------------+
+--R                            |    2           2  2        3       2      4
+--R                            |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                            |--------------------------------------------
+--R                            |                    7      2 6
+--R                           \|               64a c  - 16b c
+--R                       + 
+--R                             2       2             3
+--R                         2a c  + (- b  + 3a b)c - b
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                        2 4       2 3  2
+--R                  (- 16a c  + 4a b c )x
+--R               *
+--R                   +--------------------------------------------+
+--R                   |    2           2  2        3       2      4
+--R                   |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                   |--------------------------------------------
+--R                   |                    7      2 6
+--R                  \|               64a c  - 16b c
+--R              + 
+--R                                          +--------+
+--R                      2      3       2 2  |   2             2    2         3  2
+--R                ((- 2a b + 2a )c - 2a b )\|- x  + 1  + ((a b  - a b)c + a b )x
+--R              + 
+--R                   2      3       2 2
+--R                (2a b - 2a )c + 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            c\|2 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                             4     2 3
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                      +--------------------------------------------+
+--R                      |    2           2  2        3       2      4
+--R                      |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                      |--------------------------------------------
+--R                      |                    7      2 6
+--R                     \|               64a c  - 16b c
+--R                 + 
+--R                       2       2             3
+--R                   2a c  + (- b  + 3a b)c - b
+--R              /
+--R                     4     2 3
+--R                 8a c  - 2b c
+--R         *
+--R             +-------------------------+ +-----------------------+
+--R             |   +-----------+           | +-----------+
+--R             |   |          2            | |          2
+--R            \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R         *
+--R            log
+--R                               2 5        2 4     4 3  2
+--R                         (- 32a c  + 24a b c  - 4b c )x
+--R                      *
+--R                          +--------------------------------------------+
+--R                          |    2           2  2        3       2      4
+--R                          |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                          |--------------------------------------------
+--R                          |                    7      2 6
+--R                         \|               64a c  - 16b c
+--R                     + 
+--R                             2     2   2       4       3      5  2
+--R                       ((4a b  - 4a b)c  + (- b  + 5a b )c - b )x
+--R                  *
+--R                     ROOT
+--R                                      4     2 3
+--R                              (- 16a c  + 4b c )
+--R                           *
+--R                               +--------------------------------------------+
+--R                               |    2           2  2        3       2      4
+--R                               |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                               |--------------------------------------------
+--R                               |                    7      2 6
+--R                              \|               64a c  - 16b c
+--R                          + 
+--R                                2       2             3
+--R                            2a c  + (- b  + 3a b)c - b
+--R                       /
+--R                              4     2 3
+--R                          8a c  - 2b c
+--R                 + 
+--R                           2 4       2 3  2
+--R                     (- 16a c  + 4a b c )x
+--R                  *
+--R                      +--------------------------------------------+
+--R                      |    2           2  2        3       2      4
+--R                      |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                      |--------------------------------------------
+--R                      |                    7      2 6
+--R                     \|               64a c  - 16b c
+--R                 + 
+--R                                             +--------+
+--R                         2      3       2 2  |   2
+--R                   ((- 2a b + 2a )c - 2a b )\|- x  + 1
+--R                 + 
+--R                        2    2         3  2      2      3       2 2
+--R                   ((a b  - a b)c + a b )x  + (2a b - 2a )c + 2a b
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                                 +-------------------------+
+--R               +-----------+     |   +-----------+
+--R           +-+ |          2  +-+ |   |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R      *
+--R         ROOT
+--R                                 +--------------------------------------------+
+--R                                 |    2           2  2        3       2      4
+--R                      4     2 3  |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                (16a c  - 4b c ) |--------------------------------------------
+--R                                 |                    7      2 6
+--R                                \|               64a c  - 16b c
+--R              + 
+--R                    2       2             3
+--R                2a c  + (- b  + 3a b)c - b
+--R           /
+--R                  4     2 3
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                            2 5        2 4     4 3  2
+--R                      (- 32a c  + 24a b c  - 4b c )x
+--R                   *
+--R                       +--------------------------------------------+
+--R                       |    2           2  2        3       2      4
+--R                       |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                       |--------------------------------------------
+--R                       |                    7      2 6
+--R                      \|               64a c  - 16b c
+--R                  + 
+--R                            2     2   2     4       3      5  2
+--R                    ((- 4a b  + 4a b)c  + (b  - 5a b )c + b )x
+--R               *
+--R                  ROOT
+--R                                 4     2 3
+--R                           (16a c  - 4b c )
+--R                        *
+--R                            +--------------------------------------------+
+--R                            |    2           2  2        3       2      4
+--R                            |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                            |--------------------------------------------
+--R                            |                    7      2 6
+--R                           \|               64a c  - 16b c
+--R                       + 
+--R                             2       2             3
+--R                         2a c  + (- b  + 3a b)c - b
+--R                    /
+--R                           4     2 3
+--R                       8a c  - 2b c
+--R              + 
+--R                      2 4       2 3  2
+--R                  (16a c  - 4a b c )x
+--R               *
+--R                   +--------------------------------------------+
+--R                   |    2           2  2        3       2      4
+--R                   |(- b  + 2a b - a )c  + (- 2b  + 2a b )c - b
+--R                   |--------------------------------------------
+--R                   |                    7      2 6
+--R                  \|               64a c  - 16b c
+--R              + 
+--R                                          +--------+
+--R                      2      3       2 2  |   2             2    2         3  2
+--R                ((- 2a b + 2a )c - 2a b )\|- x  + 1  + ((a b  - a b)c + a b )x
+--R              + 
+--R                   2      3       2 2
+--R                (2a b - 2a )c + 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                    +-----------+
+--R                    |          2                     2
+--R         ((2c + 2b)\|- 4a c + b   + (- 2b + 4a)c - 2b )
+--R      *
+--R          +-----------------------+                +--------+
+--R          | +-----------+                      +-+ |   2      +-+
+--R          | |          2                      \|2 \|- x  + 1 \|c
+--R         \|\|- 4a c + b   + 2c + b atanh(----------------------------)
+--R                                          +-------------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                    +-----------+
+--R                    |          2                   2
+--R         ((2c + 2b)\|- 4a c + b   + (2b - 4a)c + 2b )
+--R      *
+--R          +-------------------------+               +--------+
+--R          |   +-----------+                     +-+ |   2      +-+
+--R          |   |          2                     \|2 \|- x  + 1 \|c
+--R         \|- \|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            | +-----------+
+--R                                            | |          2
+--R                                           \|\|- 4a c + b   + 2c + b
+--R     + 
+--R                                 +-------------------------+
+--R               +-----------+     |   +-----------+
+--R           +-+ |          2  +-+ |   |          2
+--R         2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R  /
+--R                                +-------------------------+
+--R              +-----------+     |   +-----------+
+--R          +-+ |          2  +-+ |   |          2
+--R       2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R    *
+--R        +-----------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3103
+
+--S 3104 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3104
+
+)clear all
+
+--S 3105 of 3139
+t0:=x^2*sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          2 |   2
+--R         x \|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3105
+
+--S 3106 of 3139
+r0:=-asin(x)/c-atanh(x*sqrt(b+2*c-sqrt(b^2-4*a*c))/(sqrt(1-x^2)*_
+   sqrt(-b+sqrt(b^2-4*a*c))))*(b+c+(-b^2+2*a*c-b*c)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b+2*c-sqrt(b^2-4*a*c))*sqrt(-b+sqrt(b^2-4*a*c)))+atan(x*_
+   sqrt(b+2*c+sqrt(b^2-4*a*c))/(sqrt(1-x^2)*sqrt(b+sqrt(b^2-4*a*c))))*_
+   (b+c+(b^2-2*a*c+b*c)/sqrt(b^2-4*a*c))/(c*sqrt(b+sqrt(b^2-4*a*c))*_
+   sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                    +------------------+
+--R                    +-----------+                   | +-----------+
+--R                    |          2                 2  | |          2
+--R         ((- c - b)\|- 4a c + b   + (b - 2a)c + b )\|\|- 4a c + b   + b
+--R      *
+--R                                             +-------------------------+
+--R          +-----------------------+          |   +-----------+
+--R          | +-----------+                    |   |          2
+--R          | |          2                   x\|- \|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   + 2c + b atanh(--------------------------------)
+--R                                                     +------------------+
+--R                                          +--------+ | +-----------+
+--R                                          |   2      | |          2
+--R                                         \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R                                                  +-------------------------+
+--R                  +-----------+                   |   +-----------+
+--R                  |          2                 2  |   |          2
+--R         ((c + b)\|- 4a c + b   + (b - 2a)c + b )\|- \|- 4a c + b   + 2c + b
+--R      *
+--R                                        +-----------------------+
+--R          +------------------+          | +-----------+
+--R          | +-----------+               | |          2
+--R          | |          2              x\|\|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   - b atan(--------------------------------)
+--R                                               +------------------+
+--R                                    +--------+ | +-----------+
+--R                                    |   2      | |          2
+--R                                   \|- x  + 1 \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                                  +-------------------------+
+--R                    +-----------+ |   +-----------+
+--R                    |          2  |   |          2
+--R            asin(x)\|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R         *
+--R           +------------------+ +------------------+ +-----------------------+
+--R           | +-----------+      | +-----------+      | +-----------+
+--R           | |          2       | |          2       | |          2
+--R          \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                       +-------------------------+ +------------------+
+--R         +-----------+ |   +-----------+           | +-----------+
+--R         |          2  |   |          2            | |          2
+--R       c\|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +-----------------------+
+--R        | +-----------+      | +-----------+
+--R        | |          2       | |          2
+--R       \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3106
+
+--S 3107 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R              +----------------------------------------------------+
+--R              |                 +----------------+
+--R              |                 |   2           2
+--R              |      3     2 2  |- c  - 2b c - b                  2
+--R              |(16a c  - 4b c ) |----------------  + (b - 2a)c + b
+--R              |                 |      5      2 4
+--R              |                \| 64a c  - 16b c
+--R            c |----------------------------------------------------
+--R              |                        3     2 2
+--R             \|                    8a c  - 2b c
+--R         *
+--R            log
+--R                                                 +--------+
+--R                                     3     3 2   |   2
+--R                             (16a b c  - 4b c )x\|- x  + 1
+--R                           + 
+--R                                       3     3 2
+--R                             (- 16a b c  + 4b c )x
+--R                      *
+--R                          +----------------+
+--R                          |   2           2
+--R                          |- c  - 2b c - b
+--R                          |----------------
+--R                          |      5      2 4
+--R                         \| 64a c  - 16b c
+--R                     + 
+--R                                                      +--------+
+--R                            2       2             3   |   2
+--R                       (4a c  + (- b  + 4a b)c - b )x\|- x  + 1
+--R                     + 
+--R                              2     2             3
+--R                       (- 4a c  + (b  - 4a b)c + b )x
+--R                  *
+--R                      +----------------------------------------------------+
+--R                      |                 +----------------+
+--R                      |                 |   2           2
+--R                      |      3     2 2  |- c  - 2b c - b                  2
+--R                      |(16a c  - 4b c ) |----------------  + (b - 2a)c + b
+--R                      |                 |      5      2 4
+--R                      |                \| 64a c  - 16b c
+--R                      |----------------------------------------------------
+--R                      |                        3     2 2
+--R                     \|                    8a c  - 2b c
+--R                 + 
+--R                                   +--------+
+--R                                   |   2                        2
+--R                   (- 2a c - 2a b)\|- x  + 1  + (- 2a c - 2a b)x  + 2a c + 2a b
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R           +------------------------------------------------------+
+--R           |                   +----------------+
+--R           |                   |   2           2
+--R           |        3     2 2  |- c  - 2b c - b                  2
+--R           |(- 16a c  + 4b c ) |----------------  + (b - 2a)c + b
+--R           |                   |      5      2 4
+--R           |                  \| 64a c  - 16b c
+--R         c |------------------------------------------------------
+--R           |                         3     2 2
+--R          \|                     8a c  - 2b c
+--R      *
+--R         log
+--R                                           +--------+
+--R                               3     3 2   |   2                  3     3 2
+--R                      ((16a b c  - 4b c )x\|- x  + 1  + (- 16a b c  + 4b c )x)
+--R                   *
+--R                       +----------------+
+--R                       |   2           2
+--R                       |- c  - 2b c - b
+--R                       |----------------
+--R                       |      5      2 4
+--R                      \| 64a c  - 16b c
+--R                  + 
+--R                                                   +--------+
+--R                           2     2             3   |   2
+--R                    (- 4a c  + (b  - 4a b)c + b )x\|- x  + 1
+--R                  + 
+--R                         2       2             3
+--R                    (4a c  + (- b  + 4a b)c - b )x
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                   +----------------+
+--R                   |                   |   2           2
+--R                   |        3     2 2  |- c  - 2b c - b                  2
+--R                   |(- 16a c  + 4b c ) |----------------  + (b - 2a)c + b
+--R                   |                   |      5      2 4
+--R                   |                  \| 64a c  - 16b c
+--R                   |------------------------------------------------------
+--R                   |                         3     2 2
+--R                  \|                     8a c  - 2b c
+--R              + 
+--R                                +--------+
+--R                                |   2                        2
+--R                (- 2a c - 2a b)\|- x  + 1  + (- 2a c - 2a b)x  + 2a c + 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R              +------------------------------------------------------+
+--R              |                   +----------------+
+--R              |                   |   2           2
+--R              |        3     2 2  |- c  - 2b c - b                  2
+--R              |(- 16a c  + 4b c ) |----------------  + (b - 2a)c + b
+--R              |                   |      5      2 4
+--R              |                  \| 64a c  - 16b c
+--R            c |------------------------------------------------------
+--R              |                         3     2 2
+--R             \|                     8a c  - 2b c
+--R         *
+--R            log
+--R                                                   +--------+
+--R                                       3     3 2   |   2
+--R                             (- 16a b c  + 4b c )x\|- x  + 1
+--R                           + 
+--R                                     3     3 2
+--R                             (16a b c  - 4b c )x
+--R                      *
+--R                          +----------------+
+--R                          |   2           2
+--R                          |- c  - 2b c - b
+--R                          |----------------
+--R                          |      5      2 4
+--R                         \| 64a c  - 16b c
+--R                     + 
+--R                                                      +--------+
+--R                            2       2             3   |   2
+--R                       (4a c  + (- b  + 4a b)c - b )x\|- x  + 1
+--R                     + 
+--R                              2     2             3
+--R                       (- 4a c  + (b  - 4a b)c + b )x
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                   +----------------+
+--R                      |                   |   2           2
+--R                      |        3     2 2  |- c  - 2b c - b                  2
+--R                      |(- 16a c  + 4b c ) |----------------  + (b - 2a)c + b
+--R                      |                   |      5      2 4
+--R                      |                  \| 64a c  - 16b c
+--R                      |------------------------------------------------------
+--R                      |                         3     2 2
+--R                     \|                     8a c  - 2b c
+--R                 + 
+--R                                   +--------+
+--R                                   |   2                        2
+--R                   (- 2a c - 2a b)\|- x  + 1  + (- 2a c - 2a b)x  + 2a c + 2a b
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R           +----------------------------------------------------+
+--R           |                 +----------------+
+--R           |                 |   2           2
+--R           |      3     2 2  |- c  - 2b c - b                  2
+--R           |(16a c  - 4b c ) |----------------  + (b - 2a)c + b
+--R           |                 |      5      2 4
+--R           |                \| 64a c  - 16b c
+--R         c |----------------------------------------------------
+--R           |                        3     2 2
+--R          \|                    8a c  - 2b c
+--R      *
+--R         log
+--R                                             +--------+
+--R                                 3     3 2   |   2                3     3 2
+--R                      ((- 16a b c  + 4b c )x\|- x  + 1  + (16a b c  - 4b c )x)
+--R                   *
+--R                       +----------------+
+--R                       |   2           2
+--R                       |- c  - 2b c - b
+--R                       |----------------
+--R                       |      5      2 4
+--R                      \| 64a c  - 16b c
+--R                  + 
+--R                                                   +--------+
+--R                           2     2             3   |   2
+--R                    (- 4a c  + (b  - 4a b)c + b )x\|- x  + 1
+--R                  + 
+--R                         2       2             3
+--R                    (4a c  + (- b  + 4a b)c - b )x
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                 +----------------+
+--R                   |                 |   2           2
+--R                   |      3     2 2  |- c  - 2b c - b                  2
+--R                   |(16a c  - 4b c ) |----------------  + (b - 2a)c + b
+--R                   |                 |      5      2 4
+--R                   |                \| 64a c  - 16b c
+--R                   |----------------------------------------------------
+--R                   |                        3     2 2
+--R                  \|                    8a c  - 2b c
+--R              + 
+--R                                +--------+
+--R                                |   2                        2
+--R                (- 2a c - 2a b)\|- x  + 1  + (- 2a c - 2a b)x  + 2a c + 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R              +--------+
+--R              |   2
+--R             \|- x  + 1  - 1
+--R       4atan(---------------)
+--R                    x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3107
+
+--S 3108 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                            +-------------------------+ +------------------+
+--R              +-----------+ |   +-----------+           | +-----------+
+--R              |          2  |   |          2            | |          2
+--R            c\|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R         *
+--R             +------------------+ +-----------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R         *
+--R             +----------------------------------------------------+
+--R             |                 +----------------+
+--R             |                 |   2           2
+--R             |      3     2 2  |- c  - 2b c - b                  2
+--R             |(16a c  - 4b c ) |----------------  + (b - 2a)c + b
+--R             |                 |      5      2 4
+--R             |                \| 64a c  - 16b c
+--R             |----------------------------------------------------
+--R             |                        3     2 2
+--R            \|                    8a c  - 2b c
+--R         *
+--R            log
+--R                                                 +--------+
+--R                                     3     3 2   |   2
+--R                             (16a b c  - 4b c )x\|- x  + 1
+--R                           + 
+--R                                       3     3 2
+--R                             (- 16a b c  + 4b c )x
+--R                      *
+--R                          +----------------+
+--R                          |   2           2
+--R                          |- c  - 2b c - b
+--R                          |----------------
+--R                          |      5      2 4
+--R                         \| 64a c  - 16b c
+--R                     + 
+--R                                                      +--------+
+--R                            2       2             3   |   2
+--R                       (4a c  + (- b  + 4a b)c - b )x\|- x  + 1
+--R                     + 
+--R                              2     2             3
+--R                       (- 4a c  + (b  - 4a b)c + b )x
+--R                  *
+--R                      +----------------------------------------------------+
+--R                      |                 +----------------+
+--R                      |                 |   2           2
+--R                      |      3     2 2  |- c  - 2b c - b                  2
+--R                      |(16a c  - 4b c ) |----------------  + (b - 2a)c + b
+--R                      |                 |      5      2 4
+--R                      |                \| 64a c  - 16b c
+--R                      |----------------------------------------------------
+--R                      |                        3     2 2
+--R                     \|                    8a c  - 2b c
+--R                 + 
+--R                                   +--------+
+--R                                   |   2                        2
+--R                   (- 2a c - 2a b)\|- x  + 1  + (- 2a c - 2a b)x  + 2a c + 2a b
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R           +-----------+
+--R           |          2
+--R         c\|- 4a c + b
+--R      *
+--R          +------------------------------------------------------+
+--R          |                   +----------------+
+--R          |                   |   2           2
+--R          |        3     2 2  |- c  - 2b c - b                  2
+--R          |(- 16a c  + 4b c ) |----------------  + (b - 2a)c + b
+--R          |                   |      5      2 4
+--R          |                  \| 64a c  - 16b c
+--R          |------------------------------------------------------
+--R          |                         3     2 2
+--R         \|                     8a c  - 2b c
+--R      *
+--R          +-------------------------+ +------------------+ +------------------+
+--R          |   +-----------+           | +-----------+      | +-----------+
+--R          |   |          2            | |          2       | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R      *
+--R         log
+--R                                           +--------+
+--R                               3     3 2   |   2                  3     3 2
+--R                      ((16a b c  - 4b c )x\|- x  + 1  + (- 16a b c  + 4b c )x)
+--R                   *
+--R                       +----------------+
+--R                       |   2           2
+--R                       |- c  - 2b c - b
+--R                       |----------------
+--R                       |      5      2 4
+--R                      \| 64a c  - 16b c
+--R                  + 
+--R                                                   +--------+
+--R                           2     2             3   |   2
+--R                    (- 4a c  + (b  - 4a b)c + b )x\|- x  + 1
+--R                  + 
+--R                         2       2             3
+--R                    (4a c  + (- b  + 4a b)c - b )x
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                   +----------------+
+--R                   |                   |   2           2
+--R                   |        3     2 2  |- c  - 2b c - b                  2
+--R                   |(- 16a c  + 4b c ) |----------------  + (b - 2a)c + b
+--R                   |                   |      5      2 4
+--R                   |                  \| 64a c  - 16b c
+--R                   |------------------------------------------------------
+--R                   |                         3     2 2
+--R                  \|                     8a c  - 2b c
+--R              + 
+--R                                +--------+
+--R                                |   2                        2
+--R                (- 2a c - 2a b)\|- x  + 1  + (- 2a c - 2a b)x  + 2a c + 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R              +-----------+
+--R              |          2
+--R            c\|- 4a c + b
+--R         *
+--R             +------------------------------------------------------+
+--R             |                   +----------------+
+--R             |                   |   2           2
+--R             |        3     2 2  |- c  - 2b c - b                  2
+--R             |(- 16a c  + 4b c ) |----------------  + (b - 2a)c + b
+--R             |                   |      5      2 4
+--R             |                  \| 64a c  - 16b c
+--R             |------------------------------------------------------
+--R             |                         3     2 2
+--R            \|                     8a c  - 2b c
+--R         *
+--R             +-------------------------+ +------------------+
+--R             |   +-----------+           | +-----------+
+--R             |   |          2            | |          2
+--R            \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R         *
+--R             +------------------+ +-----------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R         *
+--R            log
+--R                                                   +--------+
+--R                                       3     3 2   |   2
+--R                             (- 16a b c  + 4b c )x\|- x  + 1
+--R                           + 
+--R                                     3     3 2
+--R                             (16a b c  - 4b c )x
+--R                      *
+--R                          +----------------+
+--R                          |   2           2
+--R                          |- c  - 2b c - b
+--R                          |----------------
+--R                          |      5      2 4
+--R                         \| 64a c  - 16b c
+--R                     + 
+--R                                                      +--------+
+--R                            2       2             3   |   2
+--R                       (4a c  + (- b  + 4a b)c - b )x\|- x  + 1
+--R                     + 
+--R                              2     2             3
+--R                       (- 4a c  + (b  - 4a b)c + b )x
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                   +----------------+
+--R                      |                   |   2           2
+--R                      |        3     2 2  |- c  - 2b c - b                  2
+--R                      |(- 16a c  + 4b c ) |----------------  + (b - 2a)c + b
+--R                      |                   |      5      2 4
+--R                      |                  \| 64a c  - 16b c
+--R                      |------------------------------------------------------
+--R                      |                         3     2 2
+--R                     \|                     8a c  - 2b c
+--R                 + 
+--R                                   +--------+
+--R                                   |   2                        2
+--R                   (- 2a c - 2a b)\|- x  + 1  + (- 2a c - 2a b)x  + 2a c + 2a b
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                         +-------------------------+ +------------------+
+--R           +-----------+ |   +-----------+           | +-----------+
+--R           |          2  |   |          2            | |          2
+--R         c\|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +-----------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R      *
+--R          +----------------------------------------------------+
+--R          |                 +----------------+
+--R          |                 |   2           2
+--R          |      3     2 2  |- c  - 2b c - b                  2
+--R          |(16a c  - 4b c ) |----------------  + (b - 2a)c + b
+--R          |                 |      5      2 4
+--R          |                \| 64a c  - 16b c
+--R          |----------------------------------------------------
+--R          |                        3     2 2
+--R         \|                    8a c  - 2b c
+--R      *
+--R         log
+--R                                             +--------+
+--R                                 3     3 2   |   2                3     3 2
+--R                      ((- 16a b c  + 4b c )x\|- x  + 1  + (16a b c  - 4b c )x)
+--R                   *
+--R                       +----------------+
+--R                       |   2           2
+--R                       |- c  - 2b c - b
+--R                       |----------------
+--R                       |      5      2 4
+--R                      \| 64a c  - 16b c
+--R                  + 
+--R                                                   +--------+
+--R                           2     2             3   |   2
+--R                    (- 4a c  + (b  - 4a b)c + b )x\|- x  + 1
+--R                  + 
+--R                         2       2             3
+--R                    (4a c  + (- b  + 4a b)c - b )x
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                 +----------------+
+--R                   |                 |   2           2
+--R                   |      3     2 2  |- c  - 2b c - b                  2
+--R                   |(16a c  - 4b c ) |----------------  + (b - 2a)c + b
+--R                   |                 |      5      2 4
+--R                   |                \| 64a c  - 16b c
+--R                   |----------------------------------------------------
+--R                   |                        3     2 2
+--R                  \|                    8a c  - 2b c
+--R              + 
+--R                                +--------+
+--R                                |   2                        2
+--R                (- 2a c - 2a b)\|- x  + 1  + (- 2a c - 2a b)x  + 2a c + 2a b
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                                        +------------------+
+--R                    +-----------+                       | +-----------+
+--R                    |          2                     2  | |          2
+--R         ((2c + 2b)\|- 4a c + b   + (- 2b + 4a)c - 2b )\|\|- 4a c + b   + b
+--R      *
+--R                                             +-------------------------+
+--R          +-----------------------+          |   +-----------+
+--R          | +-----------+                    |   |          2
+--R          | |          2                   x\|- \|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   + 2c + b atanh(--------------------------------)
+--R                                                     +------------------+
+--R                                          +--------+ | +-----------+
+--R                                          |   2      | |          2
+--R                                         \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R                      +-----------+
+--R                      |          2                     2
+--R         ((- 2c - 2b)\|- 4a c + b   + (- 2b + 4a)c - 2b )
+--R      *
+--R          +-------------------------+ +------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R      *
+--R                   +-----------------------+
+--R                   | +-----------+
+--R                   | |          2
+--R                 x\|\|- 4a c + b   + 2c + b
+--R         atan(--------------------------------)
+--R                          +------------------+
+--R               +--------+ | +-----------+
+--R               |   2      | |          2
+--R              \|- x  + 1 \|\|- 4a c + b   + b
+--R     + 
+--R                               +--------+
+--R            +-----------+      |   2                      +-----------+
+--R            |          2      \|- x  + 1  - 1             |          2
+--R         (4\|- 4a c + b  atan(---------------) + 2asin(x)\|- 4a c + b  )
+--R                                     x
+--R      *
+--R          +-------------------------+ +------------------+ +------------------+
+--R          |   +-----------+           | +-----------+      | +-----------+
+--R          |   |          2            | |          2       | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R  /
+--R                        +-------------------------+ +------------------+
+--R          +-----------+ |   +-----------+           | +-----------+
+--R          |          2  |   |          2            | |          2
+--R       2c\|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +-----------------------+
+--R        | +-----------+      | +-----------+
+--R        | |          2       | |          2
+--R       \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3108
+
+--S 3109 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3109
+
+)clear all
+
+--S 3110 of 3139
+t0:=x*sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R          x\|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3110
+
+--S 3111 of 3139
+r0:=-atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/sqrt(b+2*c-sqrt(b^2-4*a*c)))*_
+   sqrt(b+2*c-sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+_
+   atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/sqrt(b+2*c+sqrt(b^2-4*a*c)))*_
+   sqrt(b+2*c+sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +-------------------------+                +--------+
+--R          |   +-----------+                      +-+ |   2      +-+
+--R          |   |          2                      \|2 \|- x  + 1 \|c
+--R       - \|- \|- 4a c + b   + 2c + b atanh(----------------------------)
+--R                                            +-------------------------+
+--R                                            |   +-----------+
+--R                                            |   |          2
+--R                                           \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R        +-----------------------+               +--------+
+--R        | +-----------+                     +-+ |   2      +-+
+--R        | |          2                     \|2 \|- x  + 1 \|c
+--R       \|\|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                        +-----------------------+
+--R                                        | +-----------+
+--R                                        | |          2
+--R                                       \|\|- 4a c + b   + 2c + b
+--R  /
+--R          +-----------+
+--R      +-+ |          2  +-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 3111
+
+--S 3112 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +--------------------------------------------+
+--R             |                +-----------------+
+--R             |      2     2   |         1
+--R             |(16a c  - 4b c) |- ---------------  - 2c - b
+--R             |                |       3      2 2
+--R             |               \|  64a c  - 16b c
+--R             |--------------------------------------------
+--R             |                    2     2
+--R            \|                8a c  - 2b c
+--R         *
+--R            log
+--R                                          +-----------------+
+--R                              2     3   2 |         1                      2  2
+--R                     ((16a b c  - 4b c)x  |- ---------------  + (- 4a c + b )x )
+--R                                          |       3      2 2
+--R                                         \|  64a c  - 16b c
+--R                  *
+--R                      +--------------------------------------------+
+--R                      |                +-----------------+
+--R                      |      2     2   |         1
+--R                      |(16a c  - 4b c) |- ---------------  - 2c - b
+--R                      |                |       3      2 2
+--R                      |               \|  64a c  - 16b c
+--R                      |--------------------------------------------
+--R                      |                    2     2
+--R                     \|                8a c  - 2b c
+--R                 + 
+--R                                     +-----------------+      +--------+
+--R                         2     2   2 |         1              |   2           2
+--R                   (16a c  - 4b c)x  |- ---------------  - 2a\|- x  + 1  + b x
+--R                                     |       3      2 2
+--R                                    \|  64a c  - 16b c
+--R                 + 
+--R                   2a
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R          +----------------------------------------------+
+--R          |                  +-----------------+
+--R          |        2     2   |         1
+--R          |(- 16a c  + 4b c) |- ---------------  - 2c - b
+--R          |                  |       3      2 2
+--R          |                 \|  64a c  - 16b c
+--R          |----------------------------------------------
+--R          |                     2     2
+--R         \|                 8a c  - 2b c
+--R      *
+--R         log
+--R                                       +-----------------+
+--R                           2     3   2 |         1                    2  2
+--R                  ((16a b c  - 4b c)x  |- ---------------  + (4a c - b )x )
+--R                                       |       3      2 2
+--R                                      \|  64a c  - 16b c
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                  +-----------------+
+--R                   |        2     2   |         1
+--R                   |(- 16a c  + 4b c) |- ---------------  - 2c - b
+--R                   |                  |       3      2 2
+--R                   |                 \|  64a c  - 16b c
+--R                   |----------------------------------------------
+--R                   |                     2     2
+--R                  \|                 8a c  - 2b c
+--R              + 
+--R                                    +-----------------+      +--------+
+--R                        2     2   2 |         1              |   2           2
+--R                (- 16a c  + 4b c)x  |- ---------------  - 2a\|- x  + 1  + b x
+--R                                    |       3      2 2
+--R                                   \|  64a c  - 16b c
+--R              + 
+--R                2a
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R             +----------------------------------------------+
+--R             |                  +-----------------+
+--R             |        2     2   |         1
+--R             |(- 16a c  + 4b c) |- ---------------  - 2c - b
+--R             |                  |       3      2 2
+--R             |                 \|  64a c  - 16b c
+--R             |----------------------------------------------
+--R             |                     2     2
+--R            \|                 8a c  - 2b c
+--R         *
+--R            log
+--R                                               +-----------------+
+--R                                   2     3   2 |         1
+--R                         (- 16a b c  + 4b c)x  |- ---------------
+--R                                               |       3      2 2
+--R                                              \|  64a c  - 16b c
+--R                       + 
+--R                                    2  2
+--R                         (- 4a c + b )x
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                  +-----------------+
+--R                      |        2     2   |         1
+--R                      |(- 16a c  + 4b c) |- ---------------  - 2c - b
+--R                      |                  |       3      2 2
+--R                      |                 \|  64a c  - 16b c
+--R                      |----------------------------------------------
+--R                      |                     2     2
+--R                     \|                 8a c  - 2b c
+--R                 + 
+--R                                       +-----------------+      +--------+
+--R                           2     2   2 |         1              |   2
+--R                   (- 16a c  + 4b c)x  |- ---------------  - 2a\|- x  + 1
+--R                                       |       3      2 2
+--R                                      \|  64a c  - 16b c
+--R                 + 
+--R                      2
+--R                   b x  + 2a
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R          +--------------------------------------------+
+--R          |                +-----------------+
+--R          |      2     2   |         1
+--R          |(16a c  - 4b c) |- ---------------  - 2c - b
+--R          |                |       3      2 2
+--R          |               \|  64a c  - 16b c
+--R          |--------------------------------------------
+--R          |                    2     2
+--R         \|                8a c  - 2b c
+--R      *
+--R         log
+--R                                         +-----------------+
+--R                             2     3   2 |         1                    2  2
+--R                  ((- 16a b c  + 4b c)x  |- ---------------  + (4a c - b )x )
+--R                                         |       3      2 2
+--R                                        \|  64a c  - 16b c
+--R               *
+--R                   +--------------------------------------------+
+--R                   |                +-----------------+
+--R                   |      2     2   |         1
+--R                   |(16a c  - 4b c) |- ---------------  - 2c - b
+--R                   |                |       3      2 2
+--R                   |               \|  64a c  - 16b c
+--R                   |--------------------------------------------
+--R                   |                    2     2
+--R                  \|                8a c  - 2b c
+--R              + 
+--R                                +-----------------+      +--------+
+--R                    2     2   2 |         1              |   2           2
+--R              (16a c  - 4b c)x  |- ---------------  - 2a\|- x  + 1  + b x  + 2a
+--R                                |       3      2 2
+--R                               \|  64a c  - 16b c
+--R           /
+--R               2
+--R              x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 3112
+
+--S 3113 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                 +-----------+
+--R             +-+ |          2  +-+
+--R            \|2 \|- 4a c + b  \|c
+--R         *
+--R             +--------------------------------------------+
+--R             |                +-----------------+
+--R             |      2     2   |         1
+--R             |(16a c  - 4b c) |- ---------------  - 2c - b
+--R             |                |       3      2 2
+--R             |               \|  64a c  - 16b c
+--R             |--------------------------------------------
+--R             |                    2     2
+--R            \|                8a c  - 2b c
+--R         *
+--R            log
+--R                                          +-----------------+
+--R                              2     3   2 |         1                      2  2
+--R                     ((16a b c  - 4b c)x  |- ---------------  + (- 4a c + b )x )
+--R                                          |       3      2 2
+--R                                         \|  64a c  - 16b c
+--R                  *
+--R                      +--------------------------------------------+
+--R                      |                +-----------------+
+--R                      |      2     2   |         1
+--R                      |(16a c  - 4b c) |- ---------------  - 2c - b
+--R                      |                |       3      2 2
+--R                      |               \|  64a c  - 16b c
+--R                      |--------------------------------------------
+--R                      |                    2     2
+--R                     \|                8a c  - 2b c
+--R                 + 
+--R                                     +-----------------+      +--------+
+--R                         2     2   2 |         1              |   2           2
+--R                   (16a c  - 4b c)x  |- ---------------  - 2a\|- x  + 1  + b x
+--R                                     |       3      2 2
+--R                                    \|  64a c  - 16b c
+--R                 + 
+--R                   2a
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                                +----------------------------------------------+
+--R                                |                  +-----------------+
+--R                                |        2     2   |         1
+--R                                |(- 16a c  + 4b c) |- ---------------  - 2c - b
+--R              +-----------+     |                  |       3      2 2
+--R          +-+ |          2  +-+ |                 \|  64a c  - 16b c
+--R         \|2 \|- 4a c + b  \|c  |----------------------------------------------
+--R                                |                     2     2
+--R                               \|                 8a c  - 2b c
+--R      *
+--R         log
+--R                                       +-----------------+
+--R                           2     3   2 |         1                    2  2
+--R                  ((16a b c  - 4b c)x  |- ---------------  + (4a c - b )x )
+--R                                       |       3      2 2
+--R                                      \|  64a c  - 16b c
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                  +-----------------+
+--R                   |        2     2   |         1
+--R                   |(- 16a c  + 4b c) |- ---------------  - 2c - b
+--R                   |                  |       3      2 2
+--R                   |                 \|  64a c  - 16b c
+--R                   |----------------------------------------------
+--R                   |                     2     2
+--R                  \|                 8a c  - 2b c
+--R              + 
+--R                                    +-----------------+      +--------+
+--R                        2     2   2 |         1              |   2           2
+--R                (- 16a c  + 4b c)x  |- ---------------  - 2a\|- x  + 1  + b x
+--R                                    |       3      2 2
+--R                                   \|  64a c  - 16b c
+--R              + 
+--R                2a
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2  +-+
+--R            \|2 \|- 4a c + b  \|c
+--R         *
+--R             +----------------------------------------------+
+--R             |                  +-----------------+
+--R             |        2     2   |         1
+--R             |(- 16a c  + 4b c) |- ---------------  - 2c - b
+--R             |                  |       3      2 2
+--R             |                 \|  64a c  - 16b c
+--R             |----------------------------------------------
+--R             |                     2     2
+--R            \|                 8a c  - 2b c
+--R         *
+--R            log
+--R                                               +-----------------+
+--R                                   2     3   2 |         1
+--R                         (- 16a b c  + 4b c)x  |- ---------------
+--R                                               |       3      2 2
+--R                                              \|  64a c  - 16b c
+--R                       + 
+--R                                    2  2
+--R                         (- 4a c + b )x
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                  +-----------------+
+--R                      |        2     2   |         1
+--R                      |(- 16a c  + 4b c) |- ---------------  - 2c - b
+--R                      |                  |       3      2 2
+--R                      |                 \|  64a c  - 16b c
+--R                      |----------------------------------------------
+--R                      |                     2     2
+--R                     \|                 8a c  - 2b c
+--R                 + 
+--R                                       +-----------------+      +--------+
+--R                           2     2   2 |         1              |   2
+--R                   (- 16a c  + 4b c)x  |- ---------------  - 2a\|- x  + 1
+--R                                       |       3      2 2
+--R                                      \|  64a c  - 16b c
+--R                 + 
+--R                      2
+--R                   b x  + 2a
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                                +--------------------------------------------+
+--R                                |                +-----------------+
+--R                                |      2     2   |         1
+--R                                |(16a c  - 4b c) |- ---------------  - 2c - b
+--R              +-----------+     |                |       3      2 2
+--R          +-+ |          2  +-+ |               \|  64a c  - 16b c
+--R         \|2 \|- 4a c + b  \|c  |--------------------------------------------
+--R                                |                    2     2
+--R                               \|                8a c  - 2b c
+--R      *
+--R         log
+--R                                         +-----------------+
+--R                             2     3   2 |         1                    2  2
+--R                  ((- 16a b c  + 4b c)x  |- ---------------  + (4a c - b )x )
+--R                                         |       3      2 2
+--R                                        \|  64a c  - 16b c
+--R               *
+--R                   +--------------------------------------------+
+--R                   |                +-----------------+
+--R                   |      2     2   |         1
+--R                   |(16a c  - 4b c) |- ---------------  - 2c - b
+--R                   |                |       3      2 2
+--R                   |               \|  64a c  - 16b c
+--R                   |--------------------------------------------
+--R                   |                    2     2
+--R                  \|                8a c  - 2b c
+--R              + 
+--R                                +-----------------+      +--------+
+--R                    2     2   2 |         1              |   2           2
+--R              (16a c  - 4b c)x  |- ---------------  - 2a\|- x  + 1  + b x  + 2a
+--R                                |       3      2 2
+--R                               \|  64a c  - 16b c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R         +-------------------------+                +--------+
+--R         |   +-----------+                      +-+ |   2      +-+
+--R         |   |          2                      \|2 \|- x  + 1 \|c
+--R       2\|- \|- 4a c + b   + 2c + b atanh(----------------------------)
+--R                                           +-------------------------+
+--R                                           |   +-----------+
+--R                                           |   |          2
+--R                                          \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R           +-----------------------+               +--------+
+--R           | +-----------+                     +-+ |   2      +-+
+--R           | |          2                     \|2 \|- x  + 1 \|c
+--R       - 2\|\|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                           +-----------------------+
+--R                                           | +-----------+
+--R                                           | |          2
+--R                                          \|\|- 4a c + b   + 2c + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 3113
+
+--S 3114 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3114
+
+)clear all
+
+--S 3115 of 3139
+t0:=sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R          \|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3115
+
+--S 3116 of 3139
+r0:=-atanh(x*sqrt(b+2*c-sqrt(b^2-4*a*c))/(sqrt(1-x^2)*sqrt(-b+_
+   sqrt(b^2-4*a*c))))*sqrt(b+2*c-sqrt(b^2-4*a*c))/(sqrt(b^2-4*a*c)*_
+   sqrt(-b+sqrt(b^2-4*a*c)))-atan(x*sqrt(b+2*c+sqrt(b^2-4*a*c))/_
+   (sqrt(1-x^2)*sqrt(b+sqrt(b^2-4*a*c))))*sqrt(b+2*c+sqrt(b^2-4*a*c))/_
+   (sqrt(b^2-4*a*c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +-------------------------+ +------------------+
+--R             |   +-----------+           | +-----------+
+--R             |   |          2            | |          2
+--R            \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + b
+--R         *
+--R                      +-------------------------+
+--R                      |   +-----------+
+--R                      |   |          2
+--R                    x\|- \|- 4a c + b   + 2c + b
+--R            atanh(--------------------------------)
+--R                              +------------------+
+--R                   +--------+ | +-----------+
+--R                   |   2      | |          2
+--R                  \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R       -
+--R             +------------------+ +-----------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + 2c + b
+--R         *
+--R                      +-----------------------+
+--R                      | +-----------+
+--R                      | |          2
+--R                    x\|\|- 4a c + b   + 2c + b
+--R            atan(--------------------------------)
+--R                             +------------------+
+--R                  +--------+ | +-----------+
+--R                  |   2      | |          2
+--R                 \|- x  + 1 \|\|- 4a c + b   + b
+--R  /
+--R                    +------------------+ +------------------+
+--R      +-----------+ | +-----------+      | +-----------+
+--R      |          2  | |          2       | |          2
+--R     \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3116
+
+--S 3117 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +-------------------------------------------+
+--R             |                +----------------+
+--R             |    2        2  |         1
+--R             |(16a c - 4a b ) |- --------------  + b + 2a
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |-------------------------------------------
+--R             |                  2        2
+--R            \|                8a c - 2a b
+--R         *
+--R            log
+--R                                       +--------+
+--R                          2        2   |   2              2        2
+--R                     ((16a c - 4a b )x\|- x  + 1  + (- 16a c + 4a b )x)
+--R                  *
+--R                      +----------------+
+--R                      |         1
+--R                      |- --------------
+--R                      |     3       2 2
+--R                     \|  64a c - 16a b
+--R                  *
+--R                      +-------------------------------------------+
+--R                      |                +----------------+
+--R                      |    2        2  |         1
+--R                      |(16a c - 4a b ) |- --------------  + b + 2a
+--R                      |                |     3       2 2
+--R                      |               \|  64a c - 16a b
+--R                      |-------------------------------------------
+--R                      |                  2        2
+--R                     \|                8a c - 2a b
+--R                 + 
+--R                      +--------+
+--R                      |   2         2
+--R                   - \|- x  + 1  - x  + 1
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R          +---------------------------------------------+
+--R          |                  +----------------+
+--R          |      2        2  |         1
+--R          |(- 16a c + 4a b ) |- --------------  + b + 2a
+--R          |                  |     3       2 2
+--R          |                 \|  64a c - 16a b
+--R          |---------------------------------------------
+--R          |                   2        2
+--R         \|                 8a c - 2a b
+--R      *
+--R         log
+--R                                    +--------+
+--R                       2        2   |   2              2        2
+--R                  ((16a c - 4a b )x\|- x  + 1  + (- 16a c + 4a b )x)
+--R               *
+--R                   +----------------+
+--R                   |         1
+--R                   |- --------------
+--R                   |     3       2 2
+--R                  \|  64a c - 16a b
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                  +----------------+
+--R                   |      2        2  |         1
+--R                   |(- 16a c + 4a b ) |- --------------  + b + 2a
+--R                   |                  |     3       2 2
+--R                   |                 \|  64a c - 16a b
+--R                   |---------------------------------------------
+--R                   |                   2        2
+--R                  \|                 8a c - 2a b
+--R              + 
+--R                   +--------+
+--R                   |   2         2
+--R                - \|- x  + 1  - x  + 1
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R             +---------------------------------------------+
+--R             |                  +----------------+
+--R             |      2        2  |         1
+--R             |(- 16a c + 4a b ) |- --------------  + b + 2a
+--R             |                  |     3       2 2
+--R             |                 \|  64a c - 16a b
+--R             |---------------------------------------------
+--R             |                   2        2
+--R            \|                 8a c - 2a b
+--R         *
+--R            log
+--R                                         +--------+
+--R                            2        2   |   2            2        2
+--R                     ((- 16a c + 4a b )x\|- x  + 1  + (16a c - 4a b )x)
+--R                  *
+--R                      +----------------+
+--R                      |         1
+--R                      |- --------------
+--R                      |     3       2 2
+--R                     \|  64a c - 16a b
+--R                  *
+--R                      +---------------------------------------------+
+--R                      |                  +----------------+
+--R                      |      2        2  |         1
+--R                      |(- 16a c + 4a b ) |- --------------  + b + 2a
+--R                      |                  |     3       2 2
+--R                      |                 \|  64a c - 16a b
+--R                      |---------------------------------------------
+--R                      |                   2        2
+--R                     \|                 8a c - 2a b
+--R                 + 
+--R                      +--------+
+--R                      |   2         2
+--R                   - \|- x  + 1  - x  + 1
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R          +-------------------------------------------+
+--R          |                +----------------+
+--R          |    2        2  |         1
+--R          |(16a c - 4a b ) |- --------------  + b + 2a
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |-------------------------------------------
+--R          |                  2        2
+--R         \|                8a c - 2a b
+--R      *
+--R         log
+--R                                      +--------+
+--R                         2        2   |   2            2        2
+--R                  ((- 16a c + 4a b )x\|- x  + 1  + (16a c - 4a b )x)
+--R               *
+--R                   +----------------+
+--R                   |         1
+--R                   |- --------------
+--R                   |     3       2 2
+--R                  \|  64a c - 16a b
+--R               *
+--R                   +-------------------------------------------+
+--R                   |                +----------------+
+--R                   |    2        2  |         1
+--R                   |(16a c - 4a b ) |- --------------  + b + 2a
+--R                   |                |     3       2 2
+--R                   |               \|  64a c - 16a b
+--R                   |-------------------------------------------
+--R                   |                  2        2
+--R                  \|                8a c - 2a b
+--R              + 
+--R                   +--------+
+--R                   |   2         2
+--R                - \|- x  + 1  - x  + 1
+--R           /
+--R               2
+--R              x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 3117
+
+--S 3118 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                           +------------------+ +------------------+
+--R             +-----------+ | +-----------+      | +-----------+
+--R             |          2  | |          2       | |          2
+--R            \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +-------------------------------------------+
+--R             |                +----------------+
+--R             |    2        2  |         1
+--R             |(16a c - 4a b ) |- --------------  + b + 2a
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |-------------------------------------------
+--R             |                  2        2
+--R            \|                8a c - 2a b
+--R         *
+--R            log
+--R                                       +--------+
+--R                          2        2   |   2              2        2
+--R                     ((16a c - 4a b )x\|- x  + 1  + (- 16a c + 4a b )x)
+--R                  *
+--R                      +----------------+
+--R                      |         1
+--R                      |- --------------
+--R                      |     3       2 2
+--R                     \|  64a c - 16a b
+--R                  *
+--R                      +-------------------------------------------+
+--R                      |                +----------------+
+--R                      |    2        2  |         1
+--R                      |(16a c - 4a b ) |- --------------  + b + 2a
+--R                      |                |     3       2 2
+--R                      |               \|  64a c - 16a b
+--R                      |-------------------------------------------
+--R                      |                  2        2
+--R                     \|                8a c - 2a b
+--R                 + 
+--R                      +--------+
+--R                      |   2         2
+--R                   - \|- x  + 1  - x  + 1
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                        +---------------------------------------------+
+--R                        |                  +----------------+
+--R                        |      2        2  |         1
+--R                        |(- 16a c + 4a b ) |- --------------  + b + 2a
+--R          +-----------+ |                  |     3       2 2
+--R          |          2  |                 \|  64a c - 16a b
+--R         \|- 4a c + b   |---------------------------------------------
+--R                        |                   2        2
+--R                       \|                 8a c - 2a b
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                    +--------+
+--R                       2        2   |   2              2        2
+--R                  ((16a c - 4a b )x\|- x  + 1  + (- 16a c + 4a b )x)
+--R               *
+--R                   +----------------+
+--R                   |         1
+--R                   |- --------------
+--R                   |     3       2 2
+--R                  \|  64a c - 16a b
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                  +----------------+
+--R                   |      2        2  |         1
+--R                   |(- 16a c + 4a b ) |- --------------  + b + 2a
+--R                   |                  |     3       2 2
+--R                   |                 \|  64a c - 16a b
+--R                   |---------------------------------------------
+--R                   |                   2        2
+--R                  \|                 8a c - 2a b
+--R              + 
+--R                   +--------+
+--R                   |   2         2
+--R                - \|- x  + 1  - x  + 1
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                           +---------------------------------------------+
+--R                           |                  +----------------+
+--R                           |      2        2  |         1
+--R                           |(- 16a c + 4a b ) |- --------------  + b + 2a
+--R             +-----------+ |                  |     3       2 2
+--R             |          2  |                 \|  64a c - 16a b
+--R            \|- 4a c + b   |---------------------------------------------
+--R                           |                   2        2
+--R                          \|                 8a c - 2a b
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                         +--------+
+--R                            2        2   |   2            2        2
+--R                     ((- 16a c + 4a b )x\|- x  + 1  + (16a c - 4a b )x)
+--R                  *
+--R                      +----------------+
+--R                      |         1
+--R                      |- --------------
+--R                      |     3       2 2
+--R                     \|  64a c - 16a b
+--R                  *
+--R                      +---------------------------------------------+
+--R                      |                  +----------------+
+--R                      |      2        2  |         1
+--R                      |(- 16a c + 4a b ) |- --------------  + b + 2a
+--R                      |                  |     3       2 2
+--R                      |                 \|  64a c - 16a b
+--R                      |---------------------------------------------
+--R                      |                   2        2
+--R                     \|                 8a c - 2a b
+--R                 + 
+--R                      +--------+
+--R                      |   2         2
+--R                   - \|- x  + 1  - x  + 1
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                        +------------------+ +------------------+
+--R          +-----------+ | +-----------+      | +-----------+
+--R          |          2  | |          2       | |          2
+--R         \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +-------------------------------------------+
+--R          |                +----------------+
+--R          |    2        2  |         1
+--R          |(16a c - 4a b ) |- --------------  + b + 2a
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |-------------------------------------------
+--R          |                  2        2
+--R         \|                8a c - 2a b
+--R      *
+--R         log
+--R                                      +--------+
+--R                         2        2   |   2            2        2
+--R                  ((- 16a c + 4a b )x\|- x  + 1  + (16a c - 4a b )x)
+--R               *
+--R                   +----------------+
+--R                   |         1
+--R                   |- --------------
+--R                   |     3       2 2
+--R                  \|  64a c - 16a b
+--R               *
+--R                   +-------------------------------------------+
+--R                   |                +----------------+
+--R                   |    2        2  |         1
+--R                   |(16a c - 4a b ) |- --------------  + b + 2a
+--R                   |                |     3       2 2
+--R                   |               \|  64a c - 16a b
+--R                   |-------------------------------------------
+--R                   |                  2        2
+--R                  \|                8a c - 2a b
+--R              + 
+--R                   +--------+
+--R                   |   2         2
+--R                - \|- x  + 1  - x  + 1
+--R           /
+--R               2
+--R              x
+--R     + 
+--R           +-------------------------+ +------------------+
+--R           |   +-----------+           | +-----------+
+--R           |   |          2            | |          2
+--R         2\|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + b
+--R      *
+--R                   +-------------------------+
+--R                   |   +-----------+
+--R                   |   |          2
+--R                 x\|- \|- 4a c + b   + 2c + b
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R           +------------------+ +-----------------------+
+--R           | +-----------+      | +-----------+
+--R           | |          2       | |          2
+--R         2\|\|- 4a c + b   - b \|\|- 4a c + b   + 2c + b
+--R      *
+--R                   +-----------------------+
+--R                   | +-----------+
+--R                   | |          2
+--R                 x\|\|- 4a c + b   + 2c + b
+--R         atan(--------------------------------)
+--R                          +------------------+
+--R               +--------+ | +-----------+
+--R               |   2      | |          2
+--R              \|- x  + 1 \|\|- 4a c + b   + b
+--R  /
+--R                     +------------------+ +------------------+
+--R       +-----------+ | +-----------+      | +-----------+
+--R       |          2  | |          2       | |          2
+--R     2\|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 3118
+
+--S 3119 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3119
+
+)clear all
+
+--S 3120 of 3139
+t0:=sqrt(1-x^2)/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R           \|- x  + 1
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3120
+
+--S 3121 of 3139
+r0:=-atanh(sqrt(1-x^2))/a+atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/sqrt(b+2*c-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(1+(2*a+b)/sqrt(b^2-4*a*c))/(a*sqrt(2)*_
+   sqrt(b+2*c-sqrt(b^2-4*a*c)))+atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/_
+   sqrt(b+2*c+sqrt(b^2-4*a*c)))*sqrt(c)*(1+(-2*a-b)/sqrt(b^2-4*a*c))/_
+   (a*sqrt(2)*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                       +-----------------------+
+--R           +-----------+               | +-----------+
+--R           |          2            +-+ | |          2
+--R         (\|- 4a c + b   + b + 2a)\|c \|\|- 4a c + b   + 2c + b
+--R      *
+--R                         +--------+
+--R                     +-+ |   2      +-+
+--R                    \|2 \|- x  + 1 \|c
+--R         atanh(----------------------------)
+--R                +-------------------------+
+--R                |   +-----------+
+--R                |   |          2
+--R               \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                                       +-------------------------+
+--R           +-----------+               |   +-----------+
+--R           |          2            +-+ |   |          2
+--R         (\|- 4a c + b   - b - 2a)\|c \|- \|- 4a c + b   + 2c + b
+--R      *
+--R                        +--------+
+--R                    +-+ |   2      +-+
+--R                   \|2 \|- x  + 1 \|c
+--R         atanh(--------------------------)
+--R                +-----------------------+
+--R                | +-----------+
+--R                | |          2
+--R               \|\|- 4a c + b   + 2c + b
+--R     + 
+--R       -
+--R                                                 +-------------------------+
+--R                 +-----------+       +--------+  |   +-----------+
+--R             +-+ |          2        |   2       |   |          2
+--R            \|2 \|- 4a c + b  atanh(\|- x  + 1 )\|- \|- 4a c + b   + 2c + b
+--R         *
+--R             +-----------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + 2c + b
+--R  /
+--R                         +-------------------------+ +-----------------------+
+--R           +-----------+ |   +-----------+           | +-----------+
+--R       +-+ |          2  |   |          2            | |          2
+--R     a\|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3121
+
+--S 3122 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R              +----------------------------------------------------+
+--R              |                +----------------+
+--R              |                |   2           2
+--R              |    3      2 2  |- b  - 2a b - a             2
+--R              |(16a c - 4a b ) |----------------  + 2a c - b  - a b
+--R              |                |    5       4 2
+--R              |               \| 64a c - 16a b
+--R            a |----------------------------------------------------
+--R              |                      3      2 2
+--R             \|                    8a c - 2a b
+--R         *
+--R            log
+--R                                       +----------------+
+--R                                       |   2           2
+--R                         4      3 2  2 |- b  - 2a b - a
+--R                     (32a c - 8a b )x  |----------------
+--R                                       |    5       4 2
+--R                                      \| 64a c - 16a b
+--R                  *
+--R                      +----------------------------------------------------+
+--R                      |                +----------------+
+--R                      |                |   2           2
+--R                      |    3      2 2  |- b  - 2a b - a             2
+--R                      |(16a c - 4a b ) |----------------  + 2a c - b  - a b
+--R                      |                |    5       4 2
+--R                      |               \| 64a c - 16a b
+--R                      |----------------------------------------------------
+--R                      |                      3      2 2
+--R                     \|                    8a c - 2a b
+--R                 + 
+--R                                       +----------------+
+--R                                       |   2           2
+--R                         3      2 2  2 |- b  - 2a b - a
+--R                   (- 16a c + 4a b )x  |----------------
+--R                                       |    5       4 2
+--R                                      \| 64a c - 16a b
+--R                 + 
+--R                                  +--------+
+--R                               2  |   2          2        2            2
+--R                   (- 2a b - 2a )\|- x  + 1  + (b  + a b)x  + 2a b + 2a
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R           +------------------------------------------------------+
+--R           |                  +----------------+
+--R           |                  |   2           2
+--R           |      3      2 2  |- b  - 2a b - a             2
+--R           |(- 16a c + 4a b ) |----------------  + 2a c - b  - a b
+--R           |                  |    5       4 2
+--R           |                 \| 64a c - 16a b
+--R         a |------------------------------------------------------
+--R           |                       3      2 2
+--R          \|                     8a c - 2a b
+--R      *
+--R         log
+--R                                    +----------------+
+--R                                    |   2           2
+--R                      4      3 2  2 |- b  - 2a b - a
+--R                  (32a c - 8a b )x  |----------------
+--R                                    |    5       4 2
+--R                                   \| 64a c - 16a b
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                  +----------------+
+--R                   |                  |   2           2
+--R                   |      3      2 2  |- b  - 2a b - a             2
+--R                   |(- 16a c + 4a b ) |----------------  + 2a c - b  - a b
+--R                   |                  |    5       4 2
+--R                   |                 \| 64a c - 16a b
+--R                   |------------------------------------------------------
+--R                   |                       3      2 2
+--R                  \|                     8a c - 2a b
+--R              + 
+--R                                  +----------------+
+--R                                  |   2           2                   +--------+
+--R                    3      2 2  2 |- b  - 2a b - a                 2  |   2
+--R                (16a c - 4a b )x  |----------------  + (- 2a b - 2a )\|- x  + 1
+--R                                  |    5       4 2
+--R                                 \| 64a c - 16a b
+--R              + 
+--R                  2        2            2
+--R                (b  + a b)x  + 2a b + 2a
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R              +------------------------------------------------------+
+--R              |                  +----------------+
+--R              |                  |   2           2
+--R              |      3      2 2  |- b  - 2a b - a             2
+--R              |(- 16a c + 4a b ) |----------------  + 2a c - b  - a b
+--R              |                  |    5       4 2
+--R              |                 \| 64a c - 16a b
+--R            a |------------------------------------------------------
+--R              |                       3      2 2
+--R             \|                     8a c - 2a b
+--R         *
+--R            log
+--R                                         +----------------+
+--R                                         |   2           2
+--R                           4      3 2  2 |- b  - 2a b - a
+--R                     (- 32a c + 8a b )x  |----------------
+--R                                         |    5       4 2
+--R                                        \| 64a c - 16a b
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                  +----------------+
+--R                      |                  |   2           2
+--R                      |      3      2 2  |- b  - 2a b - a             2
+--R                      |(- 16a c + 4a b ) |----------------  + 2a c - b  - a b
+--R                      |                  |    5       4 2
+--R                      |                 \| 64a c - 16a b
+--R                      |------------------------------------------------------
+--R                      |                       3      2 2
+--R                     \|                     8a c - 2a b
+--R                 + 
+--R                                     +----------------+
+--R                                     |   2           2
+--R                       3      2 2  2 |- b  - 2a b - a
+--R                   (16a c - 4a b )x  |----------------
+--R                                     |    5       4 2
+--R                                    \| 64a c - 16a b
+--R                 + 
+--R                                  +--------+
+--R                               2  |   2          2        2            2
+--R                   (- 2a b - 2a )\|- x  + 1  + (b  + a b)x  + 2a b + 2a
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R           +----------------------------------------------------+
+--R           |                +----------------+
+--R           |                |   2           2
+--R           |    3      2 2  |- b  - 2a b - a             2
+--R           |(16a c - 4a b ) |----------------  + 2a c - b  - a b
+--R           |                |    5       4 2
+--R           |               \| 64a c - 16a b
+--R         a |----------------------------------------------------
+--R           |                      3      2 2
+--R          \|                    8a c - 2a b
+--R      *
+--R         log
+--R                                      +----------------+
+--R                                      |   2           2
+--R                        4      3 2  2 |- b  - 2a b - a
+--R                  (- 32a c + 8a b )x  |----------------
+--R                                      |    5       4 2
+--R                                     \| 64a c - 16a b
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                +----------------+
+--R                   |                |   2           2
+--R                   |    3      2 2  |- b  - 2a b - a             2
+--R                   |(16a c - 4a b ) |----------------  + 2a c - b  - a b
+--R                   |                |    5       4 2
+--R                   |               \| 64a c - 16a b
+--R                   |----------------------------------------------------
+--R                   |                      3      2 2
+--R                  \|                    8a c - 2a b
+--R              + 
+--R                                    +----------------+
+--R                                    |   2           2
+--R                      3      2 2  2 |- b  - 2a b - a
+--R                (- 16a c + 4a b )x  |----------------
+--R                                    |    5       4 2
+--R                                   \| 64a c - 16a b
+--R              + 
+--R                               +--------+
+--R                            2  |   2          2        2            2
+--R                (- 2a b - 2a )\|- x  + 1  + (b  + a b)x  + 2a b + 2a
+--R           /
+--R               2
+--R              x
+--R     + 
+--R             +--------+
+--R             |   2
+--R            \|- x  + 1  - 1
+--R       2log(---------------)
+--R                   x
+--R  /
+--R     2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 3122
+
+--S 3123 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                +-------------------------+
+--R                  +-----------+ |   +-----------+
+--R              +-+ |          2  |   |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R         *
+--R             +-----------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + 2c + b
+--R         *
+--R             +----------------------------------------------------+
+--R             |                +----------------+
+--R             |                |   2           2
+--R             |    3      2 2  |- b  - 2a b - a             2
+--R             |(16a c - 4a b ) |----------------  + 2a c - b  - a b
+--R             |                |    5       4 2
+--R             |               \| 64a c - 16a b
+--R             |----------------------------------------------------
+--R             |                      3      2 2
+--R            \|                    8a c - 2a b
+--R         *
+--R            log
+--R                                       +----------------+
+--R                                       |   2           2
+--R                         4      3 2  2 |- b  - 2a b - a
+--R                     (32a c - 8a b )x  |----------------
+--R                                       |    5       4 2
+--R                                      \| 64a c - 16a b
+--R                  *
+--R                      +----------------------------------------------------+
+--R                      |                +----------------+
+--R                      |                |   2           2
+--R                      |    3      2 2  |- b  - 2a b - a             2
+--R                      |(16a c - 4a b ) |----------------  + 2a c - b  - a b
+--R                      |                |    5       4 2
+--R                      |               \| 64a c - 16a b
+--R                      |----------------------------------------------------
+--R                      |                      3      2 2
+--R                     \|                    8a c - 2a b
+--R                 + 
+--R                                       +----------------+
+--R                                       |   2           2
+--R                         3      2 2  2 |- b  - 2a b - a
+--R                   (- 16a c + 4a b )x  |----------------
+--R                                       |    5       4 2
+--R                                      \| 64a c - 16a b
+--R                 + 
+--R                                  +--------+
+--R                               2  |   2          2        2            2
+--R                   (- 2a b - 2a )\|- x  + 1  + (b  + a b)x  + 2a b + 2a
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2
+--R         a\|2 \|- 4a c + b
+--R      *
+--R          +------------------------------------------------------+
+--R          |                  +----------------+
+--R          |                  |   2           2
+--R          |      3      2 2  |- b  - 2a b - a             2
+--R          |(- 16a c + 4a b ) |----------------  + 2a c - b  - a b
+--R          |                  |    5       4 2
+--R          |                 \| 64a c - 16a b
+--R          |------------------------------------------------------
+--R          |                       3      2 2
+--R         \|                     8a c - 2a b
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R      *
+--R         log
+--R                                    +----------------+
+--R                                    |   2           2
+--R                      4      3 2  2 |- b  - 2a b - a
+--R                  (32a c - 8a b )x  |----------------
+--R                                    |    5       4 2
+--R                                   \| 64a c - 16a b
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                  +----------------+
+--R                   |                  |   2           2
+--R                   |      3      2 2  |- b  - 2a b - a             2
+--R                   |(- 16a c + 4a b ) |----------------  + 2a c - b  - a b
+--R                   |                  |    5       4 2
+--R                   |                 \| 64a c - 16a b
+--R                   |------------------------------------------------------
+--R                   |                       3      2 2
+--R                  \|                     8a c - 2a b
+--R              + 
+--R                                  +----------------+
+--R                                  |   2           2                   +--------+
+--R                    3      2 2  2 |- b  - 2a b - a                 2  |   2
+--R                (16a c - 4a b )x  |----------------  + (- 2a b - 2a )\|- x  + 1
+--R                                  |    5       4 2
+--R                                 \| 64a c - 16a b
+--R              + 
+--R                  2        2            2
+--R                (b  + a b)x  + 2a b + 2a
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2
+--R            a\|2 \|- 4a c + b
+--R         *
+--R             +------------------------------------------------------+
+--R             |                  +----------------+
+--R             |                  |   2           2
+--R             |      3      2 2  |- b  - 2a b - a             2
+--R             |(- 16a c + 4a b ) |----------------  + 2a c - b  - a b
+--R             |                  |    5       4 2
+--R             |                 \| 64a c - 16a b
+--R             |------------------------------------------------------
+--R             |                       3      2 2
+--R            \|                     8a c - 2a b
+--R         *
+--R             +-------------------------+ +-----------------------+
+--R             |   +-----------+           | +-----------+
+--R             |   |          2            | |          2
+--R            \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R         *
+--R            log
+--R                                         +----------------+
+--R                                         |   2           2
+--R                           4      3 2  2 |- b  - 2a b - a
+--R                     (- 32a c + 8a b )x  |----------------
+--R                                         |    5       4 2
+--R                                        \| 64a c - 16a b
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                  +----------------+
+--R                      |                  |   2           2
+--R                      |      3      2 2  |- b  - 2a b - a             2
+--R                      |(- 16a c + 4a b ) |----------------  + 2a c - b  - a b
+--R                      |                  |    5       4 2
+--R                      |                 \| 64a c - 16a b
+--R                      |------------------------------------------------------
+--R                      |                       3      2 2
+--R                     \|                     8a c - 2a b
+--R                 + 
+--R                                     +----------------+
+--R                                     |   2           2
+--R                       3      2 2  2 |- b  - 2a b - a
+--R                   (16a c - 4a b )x  |----------------
+--R                                     |    5       4 2
+--R                                    \| 64a c - 16a b
+--R                 + 
+--R                                  +--------+
+--R                               2  |   2          2        2            2
+--R                   (- 2a b - 2a )\|- x  + 1  + (b  + a b)x  + 2a b + 2a
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                             +-------------------------+
+--R               +-----------+ |   +-----------+
+--R           +-+ |          2  |   |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R      *
+--R          +----------------------------------------------------+
+--R          |                +----------------+
+--R          |                |   2           2
+--R          |    3      2 2  |- b  - 2a b - a             2
+--R          |(16a c - 4a b ) |----------------  + 2a c - b  - a b
+--R          |                |    5       4 2
+--R          |               \| 64a c - 16a b
+--R          |----------------------------------------------------
+--R          |                      3      2 2
+--R         \|                    8a c - 2a b
+--R      *
+--R         log
+--R                                      +----------------+
+--R                                      |   2           2
+--R                        4      3 2  2 |- b  - 2a b - a
+--R                  (- 32a c + 8a b )x  |----------------
+--R                                      |    5       4 2
+--R                                     \| 64a c - 16a b
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |                +----------------+
+--R                   |                |   2           2
+--R                   |    3      2 2  |- b  - 2a b - a             2
+--R                   |(16a c - 4a b ) |----------------  + 2a c - b  - a b
+--R                   |                |    5       4 2
+--R                   |               \| 64a c - 16a b
+--R                   |----------------------------------------------------
+--R                   |                      3      2 2
+--R                  \|                    8a c - 2a b
+--R              + 
+--R                                    +----------------+
+--R                                    |   2           2
+--R                      3      2 2  2 |- b  - 2a b - a
+--R                (- 16a c + 4a b )x  |----------------
+--R                                    |    5       4 2
+--R                                   \| 64a c - 16a b
+--R              + 
+--R                               +--------+
+--R                            2  |   2          2        2            2
+--R                (- 2a b - 2a )\|- x  + 1  + (b  + a b)x  + 2a b + 2a
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                           +-----------------------+
+--R              +-----------+                | +-----------+
+--R              |          2             +-+ | |          2
+--R         (- 2\|- 4a c + b   - 2b - 4a)\|c \|\|- 4a c + b   + 2c + b
+--R      *
+--R                         +--------+
+--R                     +-+ |   2      +-+
+--R                    \|2 \|- x  + 1 \|c
+--R         atanh(----------------------------)
+--R                +-------------------------+
+--R                |   +-----------+
+--R                |   |          2
+--R               \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                                           +-------------------------+
+--R              +-----------+                |   +-----------+
+--R              |          2             +-+ |   |          2
+--R         (- 2\|- 4a c + b   + 2b + 4a)\|c \|- \|- 4a c + b   + 2c + b
+--R      *
+--R                        +--------+
+--R                    +-+ |   2      +-+
+--R                   \|2 \|- x  + 1 \|c
+--R         atanh(--------------------------)
+--R                +-----------------------+
+--R                | +-----------+
+--R                | |          2
+--R               \|\|- 4a c + b   + 2c + b
+--R     + 
+--R                                   +--------+
+--R                 +-----------+     |   2
+--R             +-+ |          2     \|- x  + 1  - 1
+--R           2\|2 \|- 4a c + b  log(---------------)
+--R                                         x
+--R         + 
+--R                 +-----------+       +--------+
+--R             +-+ |          2        |   2
+--R           2\|2 \|- 4a c + b  atanh(\|- x  + 1 )
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                          +-------------------------+ +-----------------------+
+--R            +-----------+ |   +-----------+           | +-----------+
+--R        +-+ |          2  |   |          2            | |          2
+--R     2a\|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3123
+
+--S 3124 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3124
+
+)clear all
+
+--S 3125 of 3139
+t0:=sqrt(1-x^2)/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|- x  + 1
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3125
+
+--S 3126 of 3139
+r0:=-sqrt(1-x^2)/(a*x)+c*atanh(x*sqrt(b+2*c-sqrt(b^2-4*a*c))/(sqrt(1-x^2)*_
+   sqrt(-b+sqrt(b^2-4*a*c))))*(1+(2*a+b)/sqrt(b^2-4*a*c))/(a*sqrt(b+2*c-_
+   sqrt(b^2-4*a*c))*sqrt(-b+sqrt(b^2-4*a*c)))-c*atan(x*sqrt(b+2*c+_
+   sqrt(b^2-4*a*c))/(sqrt(1-x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(1+(-2*a-b)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b+sqrt(b^2-4*a*c))*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                           +------------------+
+--R              +-----------+                | +-----------+
+--R              |          2                 | |          2
+--R         (c x\|- 4a c + b   + (b + 2a)c x)\|\|- 4a c + b   + b
+--R      *
+--R                                             +-------------------------+
+--R          +-----------------------+          |   +-----------+
+--R          | +-----------+                    |   |          2
+--R          | |          2                   x\|- \|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   + 2c + b atanh(--------------------------------)
+--R                                                     +------------------+
+--R                                          +--------+ | +-----------+
+--R                                          |   2      | |          2
+--R                                         \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R                                             +-------------------------+
+--R                +-----------+                |   +-----------+
+--R                |          2                 |   |          2
+--R         (- c x\|- 4a c + b   + (b + 2a)c x)\|- \|- 4a c + b   + 2c + b
+--R      *
+--R                                        +-----------------------+
+--R          +------------------+          | +-----------+
+--R          | +-----------+               | |          2
+--R          | |          2              x\|\|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   - b atan(--------------------------------)
+--R                                               +------------------+
+--R                                    +--------+ | +-----------+
+--R                                    |   2      | |          2
+--R                                   \|- x  + 1 \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                                      +-------------------------+
+--R             +--------+ +-----------+ |   +-----------+
+--R             |   2      |          2  |   |          2
+--R            \|- x  + 1 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R         *
+--R           +------------------+ +------------------+ +-----------------------+
+--R           | +-----------+      | +-----------+      | +-----------+
+--R           | |          2       | |          2       | |          2
+--R          \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                         +-------------------------+ +------------------+
+--R           +-----------+ |   +-----------+           | +-----------+
+--R           |          2  |   |          2            | |          2
+--R       a x\|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +-----------------------+
+--R        | +-----------+      | +-----------+
+--R        | |          2       | |          2
+--R       \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3126
+
+--S 3127 of 3139
+a0:=integrate(t0,x)
+--R 
+--R 
+--R   >> Error detected within library code:
+--R   (1 . failed) cannot be coerced to mode (SparseUnivariatePolynomial (Integer))
+--R
+--R   Continuing to read the file...
+--R
+--E 3127
+
+--S 3128 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (3)
+--R                                               +------------------+
+--R                +-----------+                  | +-----------+
+--R                |          2                   | |          2
+--R         (- c x\|- 4a c + b   + (- b - 2a)c x)\|\|- 4a c + b   + b
+--R      *
+--R                                             +-------------------------+
+--R          +-----------------------+          |   +-----------+
+--R          | +-----------+                    |   |          2
+--R          | |          2                   x\|- \|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   + 2c + b atanh(--------------------------------)
+--R                                                     +------------------+
+--R                                          +--------+ | +-----------+
+--R                                          |   2      | |          2
+--R                                         \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R                                             +-------------------------+
+--R              +-----------+                  |   +-----------+
+--R              |          2                   |   |          2
+--R         (c x\|- 4a c + b   + (- b - 2a)c x)\|- \|- 4a c + b   + 2c + b
+--R      *
+--R                                        +-----------------------+
+--R          +------------------+          | +-----------+
+--R          | +-----------+               | |          2
+--R          | |          2              x\|\|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   - b atan(--------------------------------)
+--R                                               +------------------+
+--R                                    +--------+ | +-----------+
+--R                                    |   2      | |          2
+--R                                   \|- x  + 1 \|\|- 4a c + b   + b
+--R     + 
+--R                                              +-------------------------+
+--R           +--------+           +-----------+ |   +-----------+
+--R           |   2                |          2  |   |          2
+--R         (\|- x  + 1  + a a0 x)\|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R      *
+--R          +------------------+ +------------------+ +-----------------------+
+--R          | +-----------+      | +-----------+      | +-----------+
+--R          | |          2       | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                         +-------------------------+ +------------------+
+--R           +-----------+ |   +-----------+           | +-----------+
+--R           |          2  |   |          2            | |          2
+--R       a x\|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +-----------------------+
+--R        | +-----------+      | +-----------+
+--R        | |          2       | |          2
+--R       \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3128
+
+--S 3129 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R                      2
+--R                     x  - 1
+--R   (4)  -------------------------------
+--R                             +--------+
+--R            6      4      2  |   2
+--R        (c x  + b x  + a x )\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 3129
+
+)clear all
+
+--S 3130 of 3139
+t0:=sqrt(1-x^2)/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|- x  + 1
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3130
+
+--S 3131 of 3139
+r0:=1/2*(a+2*b)*atanh(sqrt(1-x^2))/a^2+(-1/4)/(a*(1-sqrt(1-x^2)))+_
+   1/4/(a*(1+sqrt(1-x^2)))-atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/sqrt(b+2*c-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(a+b+(b^2+a*(b-2*c))/sqrt(b^2-4*a*c))/_
+   (a^2*sqrt(2)*sqrt(b+2*c-sqrt(b^2-4*a*c)))-atanh(sqrt(2)*sqrt(c)*_
+   sqrt(1-x^2)/sqrt(b+2*c+sqrt(b^2-4*a*c)))*sqrt(c)*(a+b+(-b^2-a*(b-2*c))/_
+   sqrt(b^2-4*a*c))/(a^2*sqrt(2)*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                        +-----------+
+--R                      2 |          2              2         2  +-+
+--R         ((- 2b - 2a)x \|- 4a c + b   + (4a c - 2b  - 2a b)x )\|c
+--R      *
+--R          +-----------------------+                +--------+
+--R          | +-----------+                      +-+ |   2      +-+
+--R          | |          2                      \|2 \|- x  + 1 \|c
+--R         \|\|- 4a c + b   + 2c + b atanh(----------------------------)
+--R                                          +-------------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                        +-----------+
+--R                      2 |          2                2         2  +-+
+--R         ((- 2b - 2a)x \|- 4a c + b   + (- 4a c + 2b  + 2a b)x )\|c
+--R      *
+--R          +-------------------------+               +--------+
+--R          |   +-----------+                     +-+ |   2      +-+
+--R          |   |          2                     \|2 \|- x  + 1 \|c
+--R         \|- \|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            | +-----------+
+--R                                            | |          2
+--R                                           \|\|- 4a c + b   + 2c + b
+--R     + 
+--R                          +-----------+       +--------+
+--R                    2 +-+ |          2        |   2
+--R           (2b + a)x \|2 \|- 4a c + b  atanh(\|- x  + 1 )
+--R         + 
+--R                   +--------+ +-----------+
+--R               +-+ |   2      |          2
+--R           - a\|2 \|- x  + 1 \|- 4a c + b
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                               +-------------------------+
+--R                 +-----------+ |   +-----------+
+--R         2 2 +-+ |          2  |   |          2
+--R       2a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R    *
+--R        +-----------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3131
+
+--S 3132 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  +--------+
+--R              2 2 |   2         2 4     2 2
+--R         (- 2a x \|- x  + 1  - a x  + 2a x )
+--R      *
+--R         ROOT
+--R                      5      4 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                    2 2        2     2       4      3
+--R                - 2a c  + (4a b  + 3a b)c - b  - a b
+--R           /
+--R                5      4 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                          6        5 3  2
+--R                      (16a b c - 4a b )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  2        4     2 3     3 2
+--R                             (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c
+--R                           + 
+--R                                6       5    2 4
+--R                             - b  - 2a b  - a b
+--R                        /
+--R                              9       8 2
+--R                           64a c - 16a b
+--R                  + 
+--R                        3      4  2        2 3     3 2        5    2 4  2
+--R                    ((8a b + 4a )c  + (- 6a b  - 5a b )c + a b  + a b )x
+--R               *
+--R                  ROOT
+--R                               5      4 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  2
+--R                                  (- 4a b  - 4a b - a )c
+--R                                + 
+--R                                       4     2 3     3 2      6       5    2 4
+--R                                  (4a b  + 6a b  + 2a b )c - b  - 2a b  - a b
+--R                             /
+--R                                   9       8 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             2 2        2     2       4      3
+--R                         - 2a c  + (4a b  + 3a b)c - b  - a b
+--R                    /
+--R                         5      4 2
+--R                       8a c - 2a b
+--R              + 
+--R                      5 2     4 2   2
+--R                  (16a c  - 4a b c)x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                                                      +--------+
+--R                      2      3  2        3     2 2    |   2
+--R                ((- 4a b - 2a )c  + (2a b  + 2a b )c)\|- x  + 1
+--R              + 
+--R                      2    2   2       4      3    2      2      3  2
+--R                ((2a b  + a b)c  + (- b  - a b )c)x  + (4a b + 2a )c
+--R              + 
+--R                       3     2 2
+--R                (- 2a b  - 2a b )c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +--------+
+--R            2 2 |   2         2 4     2 2
+--R         (2a x \|- x  + 1  + a x  - 2a x )
+--R      *
+--R         ROOT
+--R                        5      4 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                    2 2        2     2       4      3
+--R                - 2a c  + (4a b  + 3a b)c - b  - a b
+--R           /
+--R                5      4 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                          6        5 3  2
+--R                      (16a b c - 4a b )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  2        4     2 3     3 2
+--R                             (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c
+--R                           + 
+--R                                6       5    2 4
+--R                             - b  - 2a b  - a b
+--R                        /
+--R                              9       8 2
+--R                           64a c - 16a b
+--R                  + 
+--R                          3      4  2      2 3     3 2        5    2 4  2
+--R                    ((- 8a b - 4a )c  + (6a b  + 5a b )c - a b  - a b )x
+--R               *
+--R                  ROOT
+--R                                 5      4 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  2
+--R                                  (- 4a b  - 4a b - a )c
+--R                                + 
+--R                                       4     2 3     3 2      6       5    2 4
+--R                                  (4a b  + 6a b  + 2a b )c - b  - 2a b  - a b
+--R                             /
+--R                                   9       8 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             2 2        2     2       4      3
+--R                         - 2a c  + (4a b  + 3a b)c - b  - a b
+--R                    /
+--R                         5      4 2
+--R                       8a c - 2a b
+--R              + 
+--R                        5 2     4 2   2
+--R                  (- 16a c  + 4a b c)x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                                                      +--------+
+--R                      2      3  2        3     2 2    |   2
+--R                ((- 4a b - 2a )c  + (2a b  + 2a b )c)\|- x  + 1
+--R              + 
+--R                      2    2   2       4      3    2      2      3  2
+--R                ((2a b  + a b)c  + (- b  - a b )c)x  + (4a b + 2a )c
+--R              + 
+--R                       3     2 2
+--R                (- 2a b  - 2a b )c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                  +--------+
+--R              2 2 |   2         2 4     2 2
+--R         (- 2a x \|- x  + 1  - a x  + 2a x )
+--R      *
+--R         ROOT
+--R                        5      4 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                    2 2        2     2       4      3
+--R                - 2a c  + (4a b  + 3a b)c - b  - a b
+--R           /
+--R                5      4 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                            6        5 3  2
+--R                      (- 16a b c + 4a b )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  2        4     2 3     3 2
+--R                             (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c
+--R                           + 
+--R                                6       5    2 4
+--R                             - b  - 2a b  - a b
+--R                        /
+--R                              9       8 2
+--R                           64a c - 16a b
+--R                  + 
+--R                        3      4  2        2 3     3 2        5    2 4  2
+--R                    ((8a b + 4a )c  + (- 6a b  - 5a b )c + a b  + a b )x
+--R               *
+--R                  ROOT
+--R                                 5      4 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  2
+--R                                  (- 4a b  - 4a b - a )c
+--R                                + 
+--R                                       4     2 3     3 2      6       5    2 4
+--R                                  (4a b  + 6a b  + 2a b )c - b  - 2a b  - a b
+--R                             /
+--R                                   9       8 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             2 2        2     2       4      3
+--R                         - 2a c  + (4a b  + 3a b)c - b  - a b
+--R                    /
+--R                         5      4 2
+--R                       8a c - 2a b
+--R              + 
+--R                        5 2     4 2   2
+--R                  (- 16a c  + 4a b c)x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                                                      +--------+
+--R                      2      3  2        3     2 2    |   2
+--R                ((- 4a b - 2a )c  + (2a b  + 2a b )c)\|- x  + 1
+--R              + 
+--R                      2    2   2       4      3    2      2      3  2
+--R                ((2a b  + a b)c  + (- b  - a b )c)x  + (4a b + 2a )c
+--R              + 
+--R                       3     2 2
+--R                (- 2a b  - 2a b )c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                +--------+
+--R            2 2 |   2         2 4     2 2
+--R         (2a x \|- x  + 1  + a x  - 2a x )
+--R      *
+--R         ROOT
+--R                      5      4 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                    2 2        2     2       4      3
+--R                - 2a c  + (4a b  + 3a b)c - b  - a b
+--R           /
+--R                5      4 2
+--R              8a c - 2a b
+--R      *
+--R         log
+--R                            6        5 3  2
+--R                      (- 16a b c + 4a b )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  2        4     2 3     3 2
+--R                             (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c
+--R                           + 
+--R                                6       5    2 4
+--R                             - b  - 2a b  - a b
+--R                        /
+--R                              9       8 2
+--R                           64a c - 16a b
+--R                  + 
+--R                          3      4  2      2 3     3 2        5    2 4  2
+--R                    ((- 8a b - 4a )c  + (6a b  + 5a b )c - a b  - a b )x
+--R               *
+--R                  ROOT
+--R                               5      4 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  2
+--R                                  (- 4a b  - 4a b - a )c
+--R                                + 
+--R                                       4     2 3     3 2      6       5    2 4
+--R                                  (4a b  + 6a b  + 2a b )c - b  - 2a b  - a b
+--R                             /
+--R                                   9       8 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             2 2        2     2       4      3
+--R                         - 2a c  + (4a b  + 3a b)c - b  - a b
+--R                    /
+--R                         5      4 2
+--R                       8a c - 2a b
+--R              + 
+--R                      5 2     4 2   2
+--R                  (16a c  - 4a b c)x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                                                      +--------+
+--R                      2      3  2        3     2 2    |   2
+--R                ((- 4a b - 2a )c  + (2a b  + 2a b )c)\|- x  + 1
+--R              + 
+--R                      2    2   2       4      3    2      2      3  2
+--R                ((2a b  + a b)c  + (- b  - a b )c)x  + (4a b + 2a )c
+--R              + 
+--R                       3     2 2
+--R                (- 2a b  - 2a b )c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                        +--------+
+--R                      2 |   2                   4             2
+--R         ((- 4b - 2a)x \|- x  + 1  + (- 2b - a)x  + (4b + 2a)x )
+--R      *
+--R              +--------+
+--R              |   2
+--R             \|- x  + 1  - 1
+--R         log(---------------)
+--R                    x
+--R     + 
+--R                     +--------+
+--R             2       |   2            2
+--R       (- a x  + 2a)\|- x  + 1  + 2a x  - 2a
+--R  /
+--R           +--------+
+--R       2 2 |   2          2 4     2 2
+--R     4a x \|- x  + 1  + 2a x  - 4a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 3132
+
+--S 3133 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                 +-------------------------+
+--R                   +-----------+ |   +-----------+
+--R             2 +-+ |          2  |   |          2
+--R            a \|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R         *
+--R            ROOT
+--R                         5      4 2
+--R                     (16a c - 4a b )
+--R                  *
+--R                     ROOT
+--R                                 2 2     3     4  2        4     2 3     3 2
+--R                            (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c
+--R                          + 
+--R                               6       5    2 4
+--R                            - b  - 2a b  - a b
+--R                       /
+--R                             9       8 2
+--R                          64a c - 16a b
+--R                 + 
+--R                       2 2        2     2       4      3
+--R                   - 2a c  + (4a b  + 3a b)c - b  - a b
+--R              /
+--R                   5      4 2
+--R                 8a c - 2a b
+--R         *
+--R             +-----------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + 2c + b
+--R         *
+--R            log
+--R                             6        5 3  2
+--R                         (16a b c - 4a b )x
+--R                      *
+--R                         ROOT
+--R                                     2 2     3     4  2
+--R                                (- 4a b  - 4a b - a )c
+--R                              + 
+--R                                     4     2 3     3 2      6       5    2 4
+--R                                (4a b  + 6a b  + 2a b )c - b  - 2a b  - a b
+--R                           /
+--R                                 9       8 2
+--R                              64a c - 16a b
+--R                     + 
+--R                           3      4  2        2 3     3 2        5    2 4  2
+--R                       ((8a b + 4a )c  + (- 6a b  - 5a b )c + a b  + a b )x
+--R                  *
+--R                     ROOT
+--R                                  5      4 2
+--R                              (16a c - 4a b )
+--R                           *
+--R                              ROOT
+--R                                          2 2     3     4  2
+--R                                     (- 4a b  - 4a b - a )c
+--R                                   + 
+--R                                        4     2 3     3 2      6       5    2 4
+--R                                   (4a b  + 6a b  + 2a b )c - b  - 2a b  - a b
+--R                                /
+--R                                      9       8 2
+--R                                   64a c - 16a b
+--R                          + 
+--R                                2 2        2     2       4      3
+--R                            - 2a c  + (4a b  + 3a b)c - b  - a b
+--R                       /
+--R                            5      4 2
+--R                          8a c - 2a b
+--R                 + 
+--R                         5 2     4 2   2
+--R                     (16a c  - 4a b c)x
+--R                  *
+--R                     ROOT
+--R                                 2 2     3     4  2        4     2 3     3 2
+--R                            (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c
+--R                          + 
+--R                               6       5    2 4
+--R                            - b  - 2a b  - a b
+--R                       /
+--R                             9       8 2
+--R                          64a c - 16a b
+--R                 + 
+--R                                                         +--------+
+--R                         2      3  2        3     2 2    |   2
+--R                   ((- 4a b - 2a )c  + (2a b  + 2a b )c)\|- x  + 1
+--R                 + 
+--R                         2    2   2       4      3    2      2      3  2
+--R                   ((2a b  + a b)c  + (- b  - a b )c)x  + (4a b + 2a )c
+--R                 + 
+--R                          3     2 2
+--R                   (- 2a b  - 2a b )c
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                              +-------------------------+
+--R                +-----------+ |   +-----------+
+--R          2 +-+ |          2  |   |          2
+--R         a \|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R      *
+--R         ROOT
+--R                        5      4 2
+--R                  (- 16a c + 4a b )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                    2 2        2     2       4      3
+--R                - 2a c  + (4a b  + 3a b)c - b  - a b
+--R           /
+--R                5      4 2
+--R              8a c - 2a b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R      *
+--R         log
+--R                          6        5 3  2
+--R                      (16a b c - 4a b )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  2        4     2 3     3 2
+--R                             (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c
+--R                           + 
+--R                                6       5    2 4
+--R                             - b  - 2a b  - a b
+--R                        /
+--R                              9       8 2
+--R                           64a c - 16a b
+--R                  + 
+--R                          3      4  2      2 3     3 2        5    2 4  2
+--R                    ((- 8a b - 4a )c  + (6a b  + 5a b )c - a b  - a b )x
+--R               *
+--R                  ROOT
+--R                                 5      4 2
+--R                           (- 16a c + 4a b )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  2
+--R                                  (- 4a b  - 4a b - a )c
+--R                                + 
+--R                                       4     2 3     3 2      6       5    2 4
+--R                                  (4a b  + 6a b  + 2a b )c - b  - 2a b  - a b
+--R                             /
+--R                                   9       8 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             2 2        2     2       4      3
+--R                         - 2a c  + (4a b  + 3a b)c - b  - a b
+--R                    /
+--R                         5      4 2
+--R                       8a c - 2a b
+--R              + 
+--R                        5 2     4 2   2
+--R                  (- 16a c  + 4a b c)x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                                                      +--------+
+--R                      2      3  2        3     2 2    |   2
+--R                ((- 4a b - 2a )c  + (2a b  + 2a b )c)\|- x  + 1
+--R              + 
+--R                      2    2   2       4      3    2      2      3  2
+--R                ((2a b  + a b)c  + (- b  - a b )c)x  + (4a b + 2a )c
+--R              + 
+--R                       3     2 2
+--R                (- 2a b  - 2a b )c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                                 +-------------------------+
+--R                   +-----------+ |   +-----------+
+--R             2 +-+ |          2  |   |          2
+--R            a \|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R         *
+--R            ROOT
+--R                           5      4 2
+--R                     (- 16a c + 4a b )
+--R                  *
+--R                     ROOT
+--R                                 2 2     3     4  2        4     2 3     3 2
+--R                            (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c
+--R                          + 
+--R                               6       5    2 4
+--R                            - b  - 2a b  - a b
+--R                       /
+--R                             9       8 2
+--R                          64a c - 16a b
+--R                 + 
+--R                       2 2        2     2       4      3
+--R                   - 2a c  + (4a b  + 3a b)c - b  - a b
+--R              /
+--R                   5      4 2
+--R                 8a c - 2a b
+--R         *
+--R             +-----------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + 2c + b
+--R         *
+--R            log
+--R                               6        5 3  2
+--R                         (- 16a b c + 4a b )x
+--R                      *
+--R                         ROOT
+--R                                     2 2     3     4  2
+--R                                (- 4a b  - 4a b - a )c
+--R                              + 
+--R                                     4     2 3     3 2      6       5    2 4
+--R                                (4a b  + 6a b  + 2a b )c - b  - 2a b  - a b
+--R                           /
+--R                                 9       8 2
+--R                              64a c - 16a b
+--R                     + 
+--R                           3      4  2        2 3     3 2        5    2 4  2
+--R                       ((8a b + 4a )c  + (- 6a b  - 5a b )c + a b  + a b )x
+--R                  *
+--R                     ROOT
+--R                                    5      4 2
+--R                              (- 16a c + 4a b )
+--R                           *
+--R                              ROOT
+--R                                          2 2     3     4  2
+--R                                     (- 4a b  - 4a b - a )c
+--R                                   + 
+--R                                        4     2 3     3 2      6       5    2 4
+--R                                   (4a b  + 6a b  + 2a b )c - b  - 2a b  - a b
+--R                                /
+--R                                      9       8 2
+--R                                   64a c - 16a b
+--R                          + 
+--R                                2 2        2     2       4      3
+--R                            - 2a c  + (4a b  + 3a b)c - b  - a b
+--R                       /
+--R                            5      4 2
+--R                          8a c - 2a b
+--R                 + 
+--R                           5 2     4 2   2
+--R                     (- 16a c  + 4a b c)x
+--R                  *
+--R                     ROOT
+--R                                 2 2     3     4  2        4     2 3     3 2
+--R                            (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c
+--R                          + 
+--R                               6       5    2 4
+--R                            - b  - 2a b  - a b
+--R                       /
+--R                             9       8 2
+--R                          64a c - 16a b
+--R                 + 
+--R                                                         +--------+
+--R                         2      3  2        3     2 2    |   2
+--R                   ((- 4a b - 2a )c  + (2a b  + 2a b )c)\|- x  + 1
+--R                 + 
+--R                         2    2   2       4      3    2      2      3  2
+--R                   ((2a b  + a b)c  + (- b  - a b )c)x  + (4a b + 2a )c
+--R                 + 
+--R                          3     2 2
+--R                   (- 2a b  - 2a b )c
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                              +-------------------------+
+--R                +-----------+ |   +-----------+
+--R          2 +-+ |          2  |   |          2
+--R         a \|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R      *
+--R         ROOT
+--R                      5      4 2
+--R                  (16a c - 4a b )
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                    2 2        2     2       4      3
+--R                - 2a c  + (4a b  + 3a b)c - b  - a b
+--R           /
+--R                5      4 2
+--R              8a c - 2a b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R      *
+--R         log
+--R                            6        5 3  2
+--R                      (- 16a b c + 4a b )x
+--R                   *
+--R                      ROOT
+--R                                  2 2     3     4  2        4     2 3     3 2
+--R                             (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c
+--R                           + 
+--R                                6       5    2 4
+--R                             - b  - 2a b  - a b
+--R                        /
+--R                              9       8 2
+--R                           64a c - 16a b
+--R                  + 
+--R                          3      4  2      2 3     3 2        5    2 4  2
+--R                    ((- 8a b - 4a )c  + (6a b  + 5a b )c - a b  - a b )x
+--R               *
+--R                  ROOT
+--R                               5      4 2
+--R                           (16a c - 4a b )
+--R                        *
+--R                           ROOT
+--R                                       2 2     3     4  2
+--R                                  (- 4a b  - 4a b - a )c
+--R                                + 
+--R                                       4     2 3     3 2      6       5    2 4
+--R                                  (4a b  + 6a b  + 2a b )c - b  - 2a b  - a b
+--R                             /
+--R                                   9       8 2
+--R                                64a c - 16a b
+--R                       + 
+--R                             2 2        2     2       4      3
+--R                         - 2a c  + (4a b  + 3a b)c - b  - a b
+--R                    /
+--R                         5      4 2
+--R                       8a c - 2a b
+--R              + 
+--R                      5 2     4 2   2
+--R                  (16a c  - 4a b c)x
+--R               *
+--R                  ROOT
+--R                              2 2     3     4  2        4     2 3     3 2      6
+--R                         (- 4a b  - 4a b - a )c  + (4a b  + 6a b  + 2a b )c - b
+--R                       + 
+--R                               5    2 4
+--R                         - 2a b  - a b
+--R                    /
+--R                          9       8 2
+--R                       64a c - 16a b
+--R              + 
+--R                                                      +--------+
+--R                      2      3  2        3     2 2    |   2
+--R                ((- 4a b - 2a )c  + (2a b  + 2a b )c)\|- x  + 1
+--R              + 
+--R                      2    2   2       4      3    2      2      3  2
+--R                ((2a b  + a b)c  + (- b  - a b )c)x  + (4a b + 2a )c
+--R              + 
+--R                       3     2 2
+--R                (- 2a b  - 2a b )c
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                    +-----------+
+--R                    |          2             2         +-+
+--R         ((2b + 2a)\|- 4a c + b   - 4a c + 2b  + 2a b)\|c
+--R      *
+--R          +-----------------------+                +--------+
+--R          | +-----------+                      +-+ |   2      +-+
+--R          | |          2                      \|2 \|- x  + 1 \|c
+--R         \|\|- 4a c + b   + 2c + b atanh(----------------------------)
+--R                                          +-------------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                    +-----------+
+--R                    |          2             2         +-+
+--R         ((2b + 2a)\|- 4a c + b   + 4a c - 2b  - 2a b)\|c
+--R      *
+--R          +-------------------------+               +--------+
+--R          |   +-----------+                     +-+ |   2      +-+
+--R          |   |          2                     \|2 \|- x  + 1 \|c
+--R         \|- \|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            | +-----------+
+--R                                            | |          2
+--R                                           \|\|- 4a c + b   + 2c + b
+--R     + 
+--R                                            +--------+
+--R                          +-----------+     |   2
+--R                      +-+ |          2     \|- x  + 1  - 1
+--R           (- 2b - a)\|2 \|- 4a c + b  log(---------------)
+--R                                                  x
+--R         + 
+--R                          +-----------+       +--------+
+--R                      +-+ |          2        |   2
+--R           (- 2b - a)\|2 \|- 4a c + b  atanh(\|- x  + 1 )
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                           +-------------------------+ +-----------------------+
+--R             +-----------+ |   +-----------+           | +-----------+
+--R       2 +-+ |          2  |   |          2            | |          2
+--R     2a \|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 3133
+
+--S 3134 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3134
+
+)clear all
+
+--S 3135 of 3139
+t0:=x^2*sqrt(1-x^2)/(-1+x^2+x^4)
+--R 
+--R
+--R           +--------+
+--R         2 |   2
+--R        x \|- x  + 1
+--R   (1)  -------------
+--R          4    2
+--R         x  + x  - 1
+--R                                                    Type: Expression(Integer)
+--E 3135
+
+--S 3136 of 3139
+r0:=-asin(x)-atanh(x*sqrt(1/2*(-1+sqrt(5)))/sqrt(1-x^2))*_
+   sqrt(1/5*(-2+sqrt(5)))+atan(x*sqrt(1/2*(1+sqrt(5)))/sqrt(1-x^2))*_
+   sqrt(1/5*(2+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                              +--------+                         +--------+
+--R          +--------+          | +-+           +--------+         | +-+
+--R          | +-+             x\|\|5  - 1       | +-+            x\|\|5  + 1
+--R       - \|\|5  - 2 atanh(---------------) + \|\|5  + 2 atan(---------------)
+--R                               +--------+                         +--------+
+--R                           +-+ |   2                          +-+ |   2
+--R                          \|2 \|- x  + 1                     \|2 \|- x  + 1
+--R     + 
+--R          +-+
+--R       - \|5 asin(x)
+--R  /
+--R      +-+
+--R     \|5
+--R                                                    Type: Expression(Integer)
+--E 3136
+
+--S 3137 of 3139
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +-----------+
+--R             |    +-+
+--R             |- 2\|5  + 5
+--R             |-----------
+--R             |     +-+
+--R            \|   5\|5
+--R         *
+--R            log
+--R                                                            +-----------+
+--R                                  +--------+                |    +-+
+--R                        +-+       |   2           +-+       |- 2\|5  + 5
+--R                   ((5x\|5  + 5x)\|- x  + 1  - 5x\|5  - 5x) |-----------
+--R                                                            |     +-+
+--R                                                           \|   5\|5
+--R                 + 
+--R                           +--------+
+--R                       +-+ |   2             2      +-+
+--R                   - 2\|5 \|- x  + 1  + (- 2x  + 2)\|5
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R          +-----------+
+--R          |    +-+
+--R          |- 2\|5  + 5
+--R          |-----------
+--R          |     +-+
+--R         \|   5\|5
+--R      *
+--R         log
+--R                                                           +-----------+
+--R                                 +--------+                |    +-+
+--R                       +-+       |   2           +-+       |- 2\|5  + 5
+--R                ((- 5x\|5  - 5x)\|- x  + 1  + 5x\|5  + 5x) |-----------
+--R                                                           |     +-+
+--R                                                          \|   5\|5
+--R              + 
+--R                        +--------+
+--R                    +-+ |   2             2      +-+
+--R                - 2\|5 \|- x  + 1  + (- 2x  + 2)\|5
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                                                                    +---------+
+--R                                          +--------+                |  +-+
+--R                                +-+       |   2           +-+       |2\|5  + 5
+--R           +---------+     ((5x\|5  - 5x)\|- x  + 1  - 5x\|5  + 5x) |---------
+--R           |  +-+                                                   |    +-+
+--R           |2\|5  + 5                                              \|  5\|5
+--R       - 2 |--------- atan(----------------------------------------------------)
+--R           |    +-+                        +--------+
+--R          \|  5\|5                     +-+ |   2           2      +-+
+--R                                     2\|5 \|- x  + 1  + (2x  - 2)\|5
+--R     + 
+--R                 +--------+
+--R                 |   2
+--R               x\|- x  + 1  - x
+--R       2atan(--------------------)
+--R              +--------+
+--R              |   2         2
+--R             \|- x  + 1  + x  - 1
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 3137
+
+--S 3138 of 3139
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                 +-----------+
+--R                 |    +-+
+--R             +-+ |- 2\|5  + 5
+--R            \|5  |-----------
+--R                 |     +-+
+--R                \|   5\|5
+--R         *
+--R            log
+--R                                                            +-----------+
+--R                                  +--------+                |    +-+
+--R                        +-+       |   2           +-+       |- 2\|5  + 5
+--R                   ((5x\|5  + 5x)\|- x  + 1  - 5x\|5  - 5x) |-----------
+--R                                                            |     +-+
+--R                                                           \|   5\|5
+--R                 + 
+--R                           +--------+
+--R                       +-+ |   2             2      +-+
+--R                   - 2\|5 \|- x  + 1  + (- 2x  + 2)\|5
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R              +-----------+
+--R              |    +-+
+--R          +-+ |- 2\|5  + 5
+--R         \|5  |-----------
+--R              |     +-+
+--R             \|   5\|5
+--R      *
+--R         log
+--R                                                           +-----------+
+--R                                 +--------+                |    +-+
+--R                       +-+       |   2           +-+       |- 2\|5  + 5
+--R                ((- 5x\|5  - 5x)\|- x  + 1  + 5x\|5  + 5x) |-----------
+--R                                                           |     +-+
+--R                                                          \|   5\|5
+--R              + 
+--R                        +--------+
+--R                    +-+ |   2             2      +-+
+--R                - 2\|5 \|- x  + 1  + (- 2x  + 2)\|5
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                             +--------+                          +--------+
+--R         +--------+          | +-+            +--------+         | +-+
+--R         | +-+             x\|\|5  - 1        | +-+            x\|\|5  + 1
+--R       2\|\|5  - 2 atanh(---------------) - 2\|\|5  + 2 atan(---------------)
+--R                              +--------+                          +--------+
+--R                          +-+ |   2                           +-+ |   2
+--R                         \|2 \|- x  + 1                      \|2 \|- x  + 1
+--R     + 
+--R       -
+--R                  +---------+
+--R                  |  +-+
+--R              +-+ |2\|5  + 5
+--R            2\|5  |---------
+--R                  |    +-+
+--R                 \|  5\|5
+--R         *
+--R                                                          +---------+
+--R                                +--------+                |  +-+
+--R                      +-+       |   2           +-+       |2\|5  + 5
+--R                 ((5x\|5  - 5x)\|- x  + 1  - 5x\|5  + 5x) |---------
+--R                                                          |    +-+
+--R                                                         \|  5\|5
+--R            atan(----------------------------------------------------)
+--R                                 +--------+
+--R                             +-+ |   2           2      +-+
+--R                           2\|5 \|- x  + 1  + (2x  - 2)\|5
+--R     + 
+--R                     +--------+
+--R                     |   2
+--R         +-+       x\|- x  + 1  - x        +-+
+--R       2\|5 atan(--------------------) + 2\|5 asin(x)
+--R                  +--------+
+--R                  |   2         2
+--R                 \|- x  + 1  + x  - 1
+--R  /
+--R       +-+
+--R     2\|5
+--R                                                    Type: Expression(Integer)
+--E 3138
+
+--S 3139 of 3139
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                            +--------+
+--R                 2      +-+ +-+      2 +-+  |   2
+--R           ((- 2x  + 4)\|2 \|5  - 10x \|2 )\|- x  + 1
+--R         + 
+--R               4     2      +-+ +-+        4      2  +-+
+--R           (- x  + 4x  - 4)\|2 \|5  + (- 5x  + 10x )\|2
+--R      *
+--R          +--------+ +--------+
+--R          | +-+      | +-+
+--R         \|\|5  + 1 \|\|5  + 2
+--R     + 
+--R                                          +--------+
+--R               2      +-+ +-+      2 +-+  |   2          4     2      +-+ +-+
+--R           ((2x  - 4)\|2 \|5  - 10x \|2 )\|- x  + 1  + (x  - 4x  + 4)\|2 \|5
+--R         + 
+--R                4      2  +-+
+--R           (- 5x  + 10x )\|2
+--R      *
+--R          +--------+ +--------+
+--R          | +-+      | +-+
+--R         \|\|5  - 2 \|\|5  - 1
+--R     + 
+--R                   +--------+
+--R           2       |   2           4       2
+--R       (80x  - 40)\|- x  + 1  + 40x  - 100x  + 40
+--R  /
+--R                               +--------+
+--R         6      4      2       |   2           6      2
+--R     (20x  - 20x  - 60x  + 40)\|- x  + 1  - 40x  + 80x  - 40
+--R                                                    Type: Expression(Integer)
+--E 3139
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich16.input.pamphlet b/src/input/rich16.input.pamphlet
new file mode 100644
index 0000000..3eec595
--- /dev/null
+++ b/src/input/rich16.input.pamphlet
@@ -0,0 +1,139355 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich16.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a+b x^n+c x^(2n))^p|
+There are:
+\begin{itemize}
+\item 255 integrals in this file.
+\item 255 supplied "optimal results".
+\item 307 matching answers.
+\item 0 cases where Axiom answer differs from Rubi
+\item 91 cases where Axiom supplied 2 results.
+\item 12 cases that Axiom failed to integrate.
+\item 31 that contain expressions Axiom does not recognize.
+\end{itemize}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich16.output
+)spool rich16.output
+)set message test on
+)set message auto off
+)clear all
+ 
+--S 1 of 2282
+t0:=(a*x^3+b*x^6)^(5/3)
+--R 
+--R
+--R                      +-----------+2
+--R            6      3 3|   6      3
+--R   (1)  (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 2282
+r0:=-3/88*a*(a*x^3+b*x^6)^(8/3)/(b^2*x^8)+1/11*(a*x^3+b*x^6)^(8/3)/(b*x^5)
+--R 
+--R
+--R                                           +-----------+2
+--R           3 9        2 6     2   3     3 3|   6      3
+--R        (8b x  + 13a b x  + 2a b x  - 3a )\|b x  + a x
+--R   (2)  -------------------------------------------------
+--R                                 2 2
+--R                              88b x
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                           +--------+2
+--R           3 9        2 6     2   3     3 3|   3
+--R        (8b x  + 13a b x  + 2a b x  - 3a )\|b x  + a
+--R   (3)  ----------------------------------------------
+--R                                2
+--R                             88b
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +-----------+2
+--R            3 9        2 6     2   3     3 3|   6      3
+--R       (- 8b x  - 13a b x  - 2a b x  + 3a )\|b x  + a x
+--R     + 
+--R                                             +--------+2
+--R          3 11        2 8     2   5     3 2 3|   3
+--R       (8b x   + 13a b x  + 2a b x  - 3a x )\|b x  + a
+--R  /
+--R        2 2
+--R     88b x
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                +-----------+
+--R         2 11         8    2 5 3|   6      3
+--R       (b x   + 2a b x  + a x )\|b x  + a x
+--R     + 
+--R                                  +--------+
+--R           2 12         9    2 6 3|   3
+--R       (- b x   - 2a b x  - a x )\|b x  + a
+--R  /
+--R      +--------+ +-----------+
+--R     3|   3     3|   6      3
+--R     \|b x  + a \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 2282
+t0:=(a*x^3+b*x^6)^(2/3)
+--R 
+--R
+--R         +-----------+2
+--R        3|   6      3
+--R   (1)  \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 2282
+r0:=1/5*(a*x^3+b*x^6)^(5/3)/(b*x^5)
+--R 
+--R
+--R                   +-----------+2
+--R            3     3|   6      3
+--R        (b x  + a)\|b x  + a x
+--R   (2)  -------------------------
+--R                      2
+--R                  5b x
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +--------+2
+--R            3     3|   3
+--R        (b x  + a)\|b x  + a
+--R   (3)  ----------------------
+--R                  5b
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                     +-----------+2                 +--------+2
+--R              3     3|   6      3         5      2 3|   3
+--R        (- b x  - a)\|b x  + a x    + (b x  + a x )\|b x  + a
+--R   (4)  -------------------------------------------------------
+--R                                     2
+--R                                 5b x
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-----------+                   +--------+
+--R            5      2 3|   6      3          6      3 3|   3
+--R        (b x  + a x )\|b x  + a x   + (- b x  - a x )\|b x  + a
+--R   (5)  --------------------------------------------------------
+--R                         +--------+ +-----------+
+--R                        3|   3     3|   6      3
+--R                        \|b x  + a \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 2282
+t0:=1/(a*x^3+b*x^6)^(2/3)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         +-----------+2
+--R        3|   6      3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 2282
+r0:=-(a*x^3+b*x^6)^(1/3)/(a*x^2)
+--R 
+--R
+--R           +-----------+
+--R          3|   6      3
+--R          \|b x  + a x
+--R   (2)  - --------------
+--R                  2
+--R               a x
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           +--------+
+--R          3|   3
+--R          \|b x  + a
+--R   (3)  - -----------
+--R              a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 13
+
+--S 14 of 2282
+m0:=a0-r0
+--R 
+--R
+--R         +-----------+     +--------+
+--R        3|   6      3     3|   3
+--R        \|b x  + a x   - x\|b x  + a
+--R   (4)  -----------------------------
+--R                        2
+--R                     a x
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R         +-----------+2       +--------+2
+--R        3|   6      3      2 3|   3
+--R        \|b x  + a x    - x  \|b x  + a
+--R   (5)  --------------------------------
+--R              +--------+2  +-----------+2
+--R           2 3|   3       3|   6      3
+--R          x  \|b x  + a   \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 2282
+t0:=1/(a*x^3+b*x^6)^(5/3)
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R                      +-----------+2
+--R            6      3 3|   6      3
+--R        (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 2282
+r0:=1/2/(a*x^2*(a*x^3+b*x^6)^(2/3))-3/4*(a*x^3+b*x^6)^(1/3)/(a^2*x^5)+_
+   9/4*b*(a*x^3+b*x^6)^(1/3)/(a^3*x^2)
+--R 
+--R
+--R          2 6         3    2
+--R        9b x  + 6a b x  - a
+--R   (2)  --------------------
+--R               +-----------+2
+--R          3 2 3|   6      3
+--R        4a x  \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               +--------+
+--R           2 6         3    2 3|   3
+--R        (9b x  + 6a b x  - a )\|b x  + a
+--R   (3)  ---------------------------------
+--R                   3   7     4 4
+--R                 4a b x  + 4a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              +--------+ +-----------+2
+--R          2 6         3    2 3|   3     3|   6      3       3 11        2 8
+--R       (9b x  + 6a b x  - a )\|b x  + a \|b x  + a x    - 9b x   - 15a b x
+--R     + 
+--R           2   5    3 2
+--R       - 5a b x  + a x
+--R  /
+--R                       +-----------+2
+--R        3   7     4 4 3|   6      3
+--R     (4a b x  + 4a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +-----------+2       +--------+2
+--R            3|   6      3      2 3|   3
+--R            \|b x  + a x    - x  \|b x  + a
+--R   (5)  ----------------------------------------
+--R                      +--------+2  +-----------+2
+--R            8      5 3|   3       3|   6      3
+--R        (b x  + a x )\|b x  + a   \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 2282
+t0:=x^m*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R           +-------------------+
+--R         m | 2 6         3    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 2282
+r0:=x^(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(4+m)+3*a*x^(1+m)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/((4+5*m+m^2)*(a+b*x^3))
+--R 
+--R
+--R                                       +-------------------+
+--R                   3             m + 1 | 2 6         3    2
+--R        ((b m + b)x  + a m + 4a)x     \|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------
+--R                   2              3      2
+--R               (b m  + 5b m + 4b)x  + a m  + 5a m + 4a
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   4                 m log(x)
+--R        ((b m + b)x  + (a m + 4a)x)%e
+--R   (3)  -------------------------------------
+--R                      2
+--R                     m  + 5m + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 23
+
+--S 24 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          2     2  7                   4     2      2     m log(x)
+--R       ((b m + b )x  + (2a b m + 5a b)x  + (a m + 4a )x)%e
+--R     + 
+--R                                        +-------------------+
+--R                    3             m + 1 | 2 6         3    2
+--R       ((- b m - b)x  - a m - 4a)x     \|b x  + 2a b x  + a
+--R  /
+--R         2              3      2
+--R     (b m  + 5b m + 4b)x  + a m  + 5a m + 4a
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R               +-------------------+
+--R        3      | 2 6         3    2     2 6         3    2   (m + 1)log(x)
+--R   ((b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a )%e
+--R   -----------------------------------------------------------------------
+--R                             +-------------------+
+--R                             | 2 6         3    2
+--R                           x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 25
+
+)clear all
+
+--S 26 of 2282
+t0:=x^5*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R           +-------------------+
+--R         5 | 2 6         3    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 2282
+r0:=1/9*x^6*sqrt(a^2+2*a*b*x^3+b^2*x^6)+1/18*a*x^6*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                        +-------------------+
+--R             9       6  | 2 6         3    2
+--R        (2b x  + 3a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          3
+--R                     18b x  + 18a
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            9       6
+--R        2b x  + 3a x
+--R   (3)  -------------
+--R              18
+--R                                         Type: Union(Expression(Integer),...)
+--E 28
+
+--S 29 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                          +-------------------+
+--R               9       6  | 2 6         3    2      2 12         9     2 6
+--R        (- 2b x  - 3a x )\|b x  + 2a b x  + a   + 2b x   + 5a b x  + 3a x
+--R   (4)  ------------------------------------------------------------------
+--R                                        3
+--R                                   18b x  + 18a
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-------------------+
+--R            8      5  | 2 6         3    2     2 11         8    2 5
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x   - 2a b x  - a x
+--R   (5)  ------------------------------------------------------------
+--R                            +-------------------+
+--R                            | 2 6         3    2
+--R                           \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 2282
+t0:=x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R           +-------------------+
+--R         4 | 2 6         3    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 2282
+r0:=1/8*x^5*sqrt(a^2+2*a*b*x^3+b^2*x^6)+3/40*a*x^5*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                        +-------------------+
+--R             8       5  | 2 6         3    2
+--R        (5b x  + 8a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          3
+--R                     40b x  + 40a
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            8       5
+--R        5b x  + 8a x
+--R   (3)  -------------
+--R              40
+--R                                         Type: Union(Expression(Integer),...)
+--E 33
+
+--S 34 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                          +-------------------+
+--R               8       5  | 2 6         3    2      2 11          8     2 5
+--R        (- 5b x  - 8a x )\|b x  + 2a b x  + a   + 5b x   + 13a b x  + 8a x
+--R   (4)  -------------------------------------------------------------------
+--R                                         3
+--R                                    40b x  + 40a
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-------------------+
+--R            7      4  | 2 6         3    2     2 10         7    2 4
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x   - 2a b x  - a x
+--R   (5)  ------------------------------------------------------------
+--R                            +-------------------+
+--R                            | 2 6         3    2
+--R                           \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 35
+
+)clear all
+
+--S 36 of 2282
+t0:=x^3*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R           +-------------------+
+--R         3 | 2 6         3    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 2282
+r0:=1/7*x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)+3/28*a*x^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                        +-------------------+
+--R             7       4  | 2 6         3    2
+--R        (4b x  + 7a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          3
+--R                     28b x  + 28a
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            7       4
+--R        4b x  + 7a x
+--R   (3)  -------------
+--R              28
+--R                                         Type: Union(Expression(Integer),...)
+--E 38
+
+--S 39 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                          +-------------------+
+--R               7       4  | 2 6         3    2      2 10          7     2 4
+--R        (- 4b x  - 7a x )\|b x  + 2a b x  + a   + 4b x   + 11a b x  + 7a x
+--R   (4)  -------------------------------------------------------------------
+--R                                         3
+--R                                    28b x  + 28a
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-------------------+
+--R            6      3  | 2 6         3    2     2 9         6    2 3
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  -----------------------------------------------------------
+--R                            +-------------------+
+--R                            | 2 6         3    2
+--R                           \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 40
+
+)clear all
+
+--S 41 of 2282
+t0:=x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R           +-------------------+
+--R         2 | 2 6         3    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 2282
+r0:=1/6*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/b
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a
+--R   (2)  --------------------------------
+--R                       6b
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           6       3
+--R        b x  + 2a x
+--R   (3)  ------------
+--R              6
+--R                                         Type: Union(Expression(Integer),...)
+--E 43
+
+--S 44 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R              3      | 2 6         3    2     2 6         3
+--R        (- b x  - a)\|b x  + 2a b x  + a   + b x  + 2a b x
+--R   (4)  ---------------------------------------------------
+--R                                 6b
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +-------------------+
+--R            5      2  | 2 6         3    2     2 8         5    2 2
+--R        (b x  + a x )\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  -----------------------------------------------------------
+--R                            +-------------------+
+--R                            | 2 6         3    2
+--R                           \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 2282
+t0:=x*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 6         3    2
+--R   (1)  x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 2282
+r0:=1/5*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+3/10*a*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                        +-------------------+
+--R             5       2  | 2 6         3    2
+--R        (2b x  + 5a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          3
+--R                     10b x  + 10a
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5       2
+--R        2b x  + 5a x
+--R   (3)  -------------
+--R              10
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                          +-------------------+
+--R               5       2  | 2 6         3    2      2 8         5     2 2
+--R        (- 2b x  - 5a x )\|b x  + 2a b x  + a   + 2b x  + 7a b x  + 5a x
+--R   (4)  -----------------------------------------------------------------
+--R                                        3
+--R                                   10b x  + 10a
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R            4        | 2 6         3    2     2 7         4    2
+--R        (b x  + a x)\|b x  + 2a b x  + a   - b x  - 2a b x  - a x
+--R   (5)  ---------------------------------------------------------
+--R                           +-------------------+
+--R                           | 2 6         3    2
+--R                          \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R   (1)  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 2282
+r0:=1/4*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)+3/4*a*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                      +-------------------+
+--R            4         | 2 6         3    2
+--R        (b x  + 4a x)\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------
+--R                         3
+--R                     4b x  + 4a
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4
+--R        b x  + 4a x
+--R   (3)  -----------
+--R             4
+--R                                         Type: Union(Expression(Integer),...)
+--E 53
+
+--S 54 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                        +-------------------+
+--R              4         | 2 6         3    2     2 7         4     2
+--R        (- b x  - 4a x)\|b x  + 2a b x  + a   + b x  + 5a b x  + 4a x
+--R   (4)  -------------------------------------------------------------
+--R                                      3
+--R                                  4b x  + 4a
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                         +-------------------+
+--R                         | 2 6         3    2
+--R                        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 55
+
+)clear all
+
+--S 56 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 2282
+r0:=1/3*sqrt(a^2+2*a*b*x^3+b^2*x^6)+a*log(x)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                               +-------------------+
+--R                        3      | 2 6         3    2
+--R        (3a log(x) + b x  + a)\|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------
+--R                             3
+--R                         3b x  + 3a
+--R                                                    Type: Expression(Integer)
+--E 57
+
+--S 58 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       3
+--R        3a log(x) + b x
+--R   (3)  ----------------
+--R                3
+--R                                         Type: Union(Expression(Integer),...)
+--E 58
+
+--S 59 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +-------------------+
+--R                         3      | 2 6         3    2           3     2
+--R       (- 3a log(x) - b x  - a)\|b x  + 2a b x  + a   + (3a b x  + 3a )log(x)
+--R     + 
+--R        2 6        3
+--R       b x  + a b x
+--R  /
+--R         3
+--R     3b x  + 3a
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                          | 2 6         3    2
+--R                        x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   2
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 2282
+r0:=1/2*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x-_
+   3/2*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x*(a+b*x^3))
+--R 
+--R
+--R                    +-------------------+
+--R            3       | 2 6         3    2
+--R        (b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------
+--R                       4
+--R                   2b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3
+--R        b x  - 2a
+--R   (3)  ---------
+--R            2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 63
+
+--S 64 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                      +-------------------+
+--R              3       | 2 6         3    2     2 6        3     2
+--R        (- b x  + 2a)\|b x  + 2a b x  + a   + b x  - a b x  - 2a
+--R   (4)  ---------------------------------------------------------
+--R                                   4
+--R                               2b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        2 | 2 6         3    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 65
+
+)clear all
+
+--S 66 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^3
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   3
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 2282
+r0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2-3/2*a*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^2*(a+b*x^3))
+--R 
+--R
+--R                    +-------------------+
+--R             3      | 2 6         3    2
+--R        (2b x  - a)\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------
+--R                      5       2
+--R                  2b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3
+--R        2b x  - a
+--R   (3)  ---------
+--R             2
+--R           2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 68
+
+--S 69 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                      +-------------------+
+--R               3      | 2 6         3    2      2 6        3    2
+--R        (- 2b x  + a)\|b x  + 2a b x  + a   + 2b x  + a b x  - a
+--R   (4)  ---------------------------------------------------------
+--R                                  5       2
+--R                              2b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        3 | 2 6         3    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 70
+
+)clear all
+
+--S 71 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   4
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 2282
+r0:=-1/3*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^3*(a+b*x^3))+_
+   b*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                          +-------------------+
+--R             3            | 2 6         3    2
+--R        (3b x log(x) - a)\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------
+--R                         6       3
+--R                     3b x  + 3a x
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3
+--R        3b x log(x) - a
+--R   (3)  ---------------
+--R                3
+--R              3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 73
+
+--S 74 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           +-------------------+
+--R              3            | 2 6         3    2       2 6         3
+--R       (- 3b x log(x) + a)\|b x  + 2a b x  + a   + (3b x  + 3a b x )log(x)
+--R     + 
+--R              3    2
+--R       - a b x  - a
+--R  /
+--R         6       3
+--R     3b x  + 3a x
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        4 | 2 6         3    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   5
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 2282
+r0:=-sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4+3/4*a*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^4*(a+b*x^3))
+--R 
+--R
+--R                      +-------------------+
+--R               3      | 2 6         3    2
+--R        (- 4b x  - a)\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------
+--R                       7       4
+--R                   4b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3
+--R        - 4b x  - a
+--R   (3)  -----------
+--R              4
+--R            4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 78
+
+--S 79 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                    +-------------------+
+--R             3      | 2 6         3    2      2 6         3    2
+--R        (4b x  + a)\|b x  + 2a b x  + a   - 4b x  - 5a b x  - a
+--R   (4)  --------------------------------------------------------
+--R                                  7       4
+--R                              4b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        5 | 2 6         3    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 80
+
+)clear all
+
+--S 81 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^6
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   6
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 2282
+r0:=-1/2*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5+_
+   3/10*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^5*(a+b*x^3))
+--R 
+--R
+--R                       +-------------------+
+--R               3       | 2 6         3    2
+--R        (- 5b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                        8        5
+--R                   10b x  + 10a x
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3
+--R        - 5b x  - 2a
+--R   (3)  ------------
+--R               5
+--R            10x
+--R                                         Type: Union(Expression(Integer),...)
+--E 83
+
+--S 84 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R             3       | 2 6         3    2      2 6         3     2
+--R        (5b x  + 2a)\|b x  + 2a b x  + a   - 5b x  - 7a b x  - 2a
+--R   (4)  ----------------------------------------------------------
+--R                                   8        5
+--R                              10b x  + 10a x
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        6 | 2 6         3    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   7
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 2282
+r0:=-1/6*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a*x^6)
+--R 
+--R
+--R                     +-------------------+
+--R              3      | 2 6         3    2
+--R        (- b x  - a)\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------
+--R                           6
+--R                       6a x
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3
+--R        - 2b x  - a
+--R   (3)  -----------
+--R              6
+--R            6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 88
+
+--S 89 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2          3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - 2a b x  - a
+--R   (4)  -----------------------------------------------
+--R                                 6
+--R                             6a x
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        7 | 2 6         3    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   8
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 2282
+r0:=-1/4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7+_
+   3/28*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^7*(a+b*x^3))
+--R 
+--R
+--R                       +-------------------+
+--R               3       | 2 6         3    2
+--R        (- 7b x  - 4a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       10        7
+--R                  28b x   + 28a x
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3
+--R        - 7b x  - 4a
+--R   (3)  ------------
+--R               7
+--R            28x
+--R                                         Type: Union(Expression(Integer),...)
+--E 93
+
+--S 94 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R             3       | 2 6         3    2      2 6          3     2
+--R        (7b x  + 4a)\|b x  + 2a b x  + a   - 7b x  - 11a b x  - 4a
+--R   (4)  -----------------------------------------------------------
+--R                                   10        7
+--R                              28b x   + 28a x
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        8 | 2 6         3    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 95
+
+)clear all
+
+--S 96 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^9
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   9
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 2282
+r0:=-1/5*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8+_
+   3/40*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^8*(a+b*x^3))
+--R 
+--R
+--R                       +-------------------+
+--R               3       | 2 6         3    2
+--R        (- 8b x  - 5a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       11        8
+--R                  40b x   + 40a x
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3
+--R        - 8b x  - 5a
+--R   (3)  ------------
+--R               8
+--R            40x
+--R                                         Type: Union(Expression(Integer),...)
+--E 98
+
+--S 99 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R             3       | 2 6         3    2      2 6          3     2
+--R        (8b x  + 5a)\|b x  + 2a b x  + a   - 8b x  - 13a b x  - 5a
+--R   (4)  -----------------------------------------------------------
+--R                                   11        8
+--R                              40b x   + 40a x
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                          +-------------------+
+--R                        9 | 2 6         3    2
+--R                       x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 100
+
+)clear all
+
+--S 101 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   10
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 2282
+r0:=-1/6*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^9+_
+   1/18*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^9*(a+b*x^3))
+--R 
+--R
+--R                       +-------------------+
+--R               3       | 2 6         3    2
+--R        (- 3b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       12        9
+--R                  18b x   + 18a x
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3
+--R        - 3b x  - 2a
+--R   (3)  ------------
+--R               9
+--R            18x
+--R                                         Type: Union(Expression(Integer),...)
+--E 103
+
+--S 104 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                     +-------------------+
+--R             3       | 2 6         3    2      2 6         3     2
+--R        (3b x  + 2a)\|b x  + 2a b x  + a   - 3b x  - 5a b x  - 2a
+--R   (4)  ----------------------------------------------------------
+--R                                  12        9
+--R                             18b x   + 18a x
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                           +-------------------+
+--R                        10 | 2 6         3    2
+--R                       x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 2282
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^11
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   11
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 2282
+r0:=-1/7*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10+_
+   3/70*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^10*(a+b*x^3))
+--R 
+--R
+--R                        +-------------------+
+--R                3       | 2 6         3    2
+--R        (- 10b x  - 7a)\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                       13        10
+--R                  70b x   + 70a x
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3
+--R        - 10b x  - 7a
+--R   (3)  -------------
+--R               10
+--R            70x
+--R                                         Type: Union(Expression(Integer),...)
+--E 108
+
+--S 109 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                      +-------------------+
+--R              3       | 2 6         3    2       2 6          3     2
+--R        (10b x  + 7a)\|b x  + 2a b x  + a   - 10b x  - 17a b x  - 7a
+--R   (4)  -------------------------------------------------------------
+--R                                   13        10
+--R                              70b x   + 70a x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2     2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a   - b x  - 2a b x  - a
+--R   (5)  ------------------------------------------------------
+--R                           +-------------------+
+--R                        11 | 2 6         3    2
+--R                       x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 110
+
+)clear all
+
+--S 111 of 2282
+t0:=x^m*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 6         3    2  m | 2 6         3    2
+--R   (1)  (b x  + 2a b x  + a )x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 2282
+r0:=x^(1+m)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/(10+m)+_
+   54*a^2*x^(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/((4+m)*(7+m)*(10+m))+_
+   162*a^3*x^(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/((7+m)*(10+m)*_
+   (4+5*m+m^2)*(a+b*x^3))+9*a*x^(1+m)*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(70+17*m+m^2)
+--R 
+--R
+--R   (2)
+--R           3 3      3 2      3       3  9
+--R         (b m  + 12b m  + 39b m + 28b )x
+--R       + 
+--R              2 3        2 2         2          2  6
+--R         (3a b m  + 45a b m  + 162a b m + 120a b )x
+--R       + 
+--R            2   3      2   2       2          2   3    3 3      3 2       3
+--R         (3a b m  + 54a b m  + 261a b m + 210a b)x  + a m  + 21a m  + 138a m
+--R       + 
+--R             3
+--R         280a
+--R    *
+--R              +-------------------+
+--R        m + 1 | 2 6         3    2
+--R       x     \|b x  + 2a b x  + a
+--R  /
+--R           4        3         2                  3      4        3         2
+--R       (b m  + 22b m  + 159b m  + 418b m + 280b)x  + a m  + 22a m  + 159a m
+--R     + 
+--R       418a m + 280a
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 3      3 2      3       3  10
+--R         (b m  + 12b m  + 39b m + 28b )x
+--R       + 
+--R              2 3        2 2         2          2  7
+--R         (3a b m  + 45a b m  + 162a b m + 120a b )x
+--R       + 
+--R            2   3      2   2       2          2   4
+--R         (3a b m  + 54a b m  + 261a b m + 210a b)x
+--R       + 
+--R           3 3      3 2       3        3
+--R         (a m  + 21a m  + 138a m + 280a )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      4      3       2
+--R     m  + 22m  + 159m  + 418m + 280
+--R                                         Type: Union(Expression(Integer),...)
+--E 113
+
+--S 114 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4 3      4 2      4       4  13
+--R           (b m  + 12b m  + 39b m + 28b )x
+--R         + 
+--R                3 3        3 2         3          3  10
+--R           (4a b m  + 57a b m  + 201a b m + 148a b )x
+--R         + 
+--R              2 2 3      2 2 2       2 2        2 2  7
+--R           (6a b m  + 99a b m  + 423a b m + 330a b )x
+--R         + 
+--R              3   3      3   2       3          3   4
+--R           (4a b m  + 75a b m  + 399a b m + 490a b)x
+--R         + 
+--R             4 3      4 2       4        4
+--R           (a m  + 21a m  + 138a m + 280a )x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R               3 3      3 2      3       3  9
+--R           (- b m  - 12b m  - 39b m - 28b )x
+--R         + 
+--R                  2 3        2 2         2          2  6
+--R           (- 3a b m  - 45a b m  - 162a b m - 120a b )x
+--R         + 
+--R                2   3      2   2       2          2   3    3 3      3 2       3
+--R           (- 3a b m  - 54a b m  - 261a b m - 210a b)x  - a m  - 21a m  - 138a m
+--R         + 
+--R                 3
+--R           - 280a
+--R      *
+--R                +-------------------+
+--R          m + 1 | 2 6         3    2
+--R         x     \|b x  + 2a b x  + a
+--R  /
+--R           4        3         2                  3      4        3         2
+--R       (b m  + 22b m  + 159b m  + 418b m + 280b)x  + a m  + 22a m  + 159a m
+--R     + 
+--R       418a m + 280a
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                         +-------------------+
+--R           3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R         (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R       + 
+--R             2 2 6     3   3    4
+--R         - 6a b x  - 4a b x  - a
+--R    *
+--R         (m + 1)log(x)
+--R       %e
+--R  /
+--R       +-------------------+
+--R       | 2 6         3    2
+--R     x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 115
+
+)clear all
+
+--S 116 of 2282
+t0:=x^9*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 15         12    2 9  | 2 6         3    2
+--R   (1)  (b x   + 2a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 2282
+r0:=1/19*x^10*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/1976*a^2*x^10*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/19760*a^3*x^10*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/304*a*x^10*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R                                                       +-------------------+
+--R         3 19          2 16        2   13        3 10  | 2 6         3    2
+--R   (1040b x   + 3705a b x   + 4560a b x   + 1976a x  )\|b x  + 2a b x  + a
+--R   -------------------------------------------------------------------------
+--R                                       3
+--R                               19760b x  + 19760a
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 19          2 16        2   13        3 10
+--R        1040b x   + 3705a b x   + 4560a b x   + 1976a x
+--R   (3)  -------------------------------------------------
+--R                              19760
+--R                                         Type: Union(Expression(Integer),...)
+--E 118
+
+--S 119 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3 19          2 16        2   13        3 10
+--R         (- 1040b x   - 3705a b x   - 4560a b x   - 1976a x  )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 22          3 19        2 2 16        3   13        4 10
+--R       1040b x   + 4745a b x   + 8265a b x   + 6536a b x   + 1976a x
+--R  /
+--R             3
+--R     19760b x  + 19760a
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                            +-------------------+
+--R         3 18       2 15     2   12    3 9  | 2 6         3    2     4 21
+--R       (b x   + 3a b x   + 3a b x   + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 18     2 2 15     3   12    4 9
+--R       - 4a b x   - 6a b x   - 4a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 2282
+t0:=x^8*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 14         11    2 8  | 2 6         3    2
+--R   (1)  (b x   + 2a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 2282
+r0:=1/36*a^2*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/b^3+_
+   1/18*x^6*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/b-_
+   1/45*a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^3
+--R 
+--R
+--R   (2)
+--R                                                           +-------------------+
+--R       5 15        4 12      2 3 9    3 2 6    4   3    5  | 2 6         3    2
+--R   (10b x   + 26a b x   + 19a b x  + a b x  - a b x  + a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------------
+--R                                           3
+--R                                       180b
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 18        2 15      2   12      3 9
+--R        10b x   + 36a b x   + 45a b x   + 20a x
+--R   (3)  ----------------------------------------
+--R                           180
+--R                                         Type: Union(Expression(Integer),...)
+--E 123
+
+--S 124 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 15        4 12      2 3 9    3 2 6    4   3    5
+--R         (- 10b x   - 26a b x   - 19a b x  - a b x  + a b x  - a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18        5 15      2 4 12      3 3 9
+--R       10b x   + 36a b x   + 45a b x   + 20a b x
+--R  /
+--R         3
+--R     180b
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                            +-------------------+
+--R         3 17       2 14     2   11    3 8  | 2 6         3    2     4 20
+--R       (b x   + 3a b x   + 3a b x   + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 17     2 2 14     3   11    4 8
+--R       - 4a b x   - 6a b x   - 4a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 125
+
+)clear all
+
+--S 126 of 2282
+t0:=x^7*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 13         10    2 7  | 2 6         3    2
+--R   (1)  (b x   + 2a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 2282
+r0:=1/17*x^8*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/1309*a^2*x^8*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/10472*a^3*x^8*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+9/238*a*x^8*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R        3 17          2 14        2   11        3 8  | 2 6         3    2
+--R   (616b x   + 2244a b x   + 2856a b x   + 1309a x )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                      3
+--R                              10472b x  + 10472a
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 17          2 14        2   11        3 8
+--R        616b x   + 2244a b x   + 2856a b x   + 1309a x
+--R   (3)  -----------------------------------------------
+--R                             10472
+--R                                         Type: Union(Expression(Integer),...)
+--E 128
+
+--S 129 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                           +-------------------+
+--R              3 17          2 14        2   11        3 8  | 2 6         3    2
+--R       (- 616b x   - 2244a b x   - 2856a b x   - 1309a x )\|b x  + 2a b x  + a
+--R     + 
+--R           4 20          3 17        2 2 14        3   11        4 8
+--R       616b x   + 2860a b x   + 5100a b x   + 4165a b x   + 1309a x
+--R  /
+--R             3
+--R     10472b x  + 10472a
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                            +-------------------+
+--R         3 16       2 13     2   10    3 7  | 2 6         3    2     4 19
+--R       (b x   + 3a b x   + 3a b x   + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 16     2 2 13     3   10    4 7
+--R       - 4a b x   - 6a b x   - 4a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 130
+
+)clear all
+
+--S 131 of 2282
+t0:=x^6*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                 +-------------------+
+--R          2 12         9    2 6  | 2 6         3    2
+--R   (1)  (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 2282
+r0:=1/16*x^7*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/1040*a^2*x^7*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/7280*a^3*x^7*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/208*a*x^7*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R        3 16          2 13        2   10        3 7  | 2 6         3    2
+--R   (455b x   + 1680a b x   + 2184a b x   + 1040a x )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                      3
+--R                               7280b x  + 7280a
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 16          2 13        2   10        3 7
+--R        455b x   + 1680a b x   + 2184a b x   + 1040a x
+--R   (3)  -----------------------------------------------
+--R                              7280
+--R                                         Type: Union(Expression(Integer),...)
+--E 133
+
+--S 134 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                           +-------------------+
+--R              3 16          2 13        2   10        3 7  | 2 6         3    2
+--R       (- 455b x   - 1680a b x   - 2184a b x   - 1040a x )\|b x  + 2a b x  + a
+--R     + 
+--R           4 19          3 16        2 2 13        3   10        4 7
+--R       455b x   + 2135a b x   + 3864a b x   + 3224a b x   + 1040a x
+--R  /
+--R            3
+--R     7280b x  + 7280a
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                           +-------------------+
+--R         3 15       2 12     2   9    3 6  | 2 6         3    2     4 18
+--R       (b x   + 3a b x   + 3a b x  + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 15     2 2 12     3   9    4 6
+--R       - 4a b x   - 6a b x   - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 2282
+t0:=x^5*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                 +-------------------+
+--R          2 11         8    2 5  | 2 6         3    2
+--R   (1)  (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 2282
+r0:=-1/12*a*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/b^2+_
+   1/15*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^2
+--R 
+--R
+--R                                                    +-------------------+
+--R           4 12        3 9     2 2 6    3   3    4  | 2 6         3    2
+--R        (4b x   + 11a b x  + 9a b x  + a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------------
+--R                                          2
+--R                                       60b
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3 15        2 12      2   9      3 6
+--R        4b x   + 15a b x   + 20a b x  + 10a x
+--R   (3)  --------------------------------------
+--R                          60
+--R                                         Type: Union(Expression(Integer),...)
+--E 138
+
+--S 139 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                     +-------------------+
+--R            4 12        3 9     2 2 6    3   3    4  | 2 6         3    2
+--R       (- 4b x   - 11a b x  - 9a b x  - a b x  + a )\|b x  + 2a b x  + a
+--R     + 
+--R         5 15        4 12      2 3 9      3 2 6
+--R       4b x   + 15a b x   + 20a b x  + 10a b x
+--R  /
+--R        2
+--R     60b
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                           +-------------------+
+--R         3 14       2 11     2   8    3 5  | 2 6         3    2     4 17
+--R       (b x   + 3a b x   + 3a b x  + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 14     2 2 11     3   8    4 5
+--R       - 4a b x   - 6a b x   - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 140
+
+)clear all
+
+--S 141 of 2282
+t0:=x^4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                 +-------------------+
+--R          2 10         7    2 4  | 2 6         3    2
+--R   (1)  (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 2282
+r0:=1/14*x^5*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/616*a^2*x^5*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/3080*a^3*x^5*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/154*a*x^5*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                                                       +-------------------+
+--R             3 14         2 11        2   8       3 5  | 2 6         3    2
+--R        (220b x   + 840a b x   + 1155a b x  + 616a x )\|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------------------------------
+--R                                         3
+--R                                  3080b x  + 3080a
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 14         2 11        2   8       3 5
+--R        220b x   + 840a b x   + 1155a b x  + 616a x
+--R   (3)  --------------------------------------------
+--R                            3080
+--R                                         Type: Union(Expression(Integer),...)
+--E 143
+
+--S 144 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                        +-------------------+
+--R              3 14         2 11        2   8       3 5  | 2 6         3    2
+--R       (- 220b x   - 840a b x   - 1155a b x  - 616a x )\|b x  + 2a b x  + a
+--R     + 
+--R           4 17          3 14        2 2 11        3   8       4 5
+--R       220b x   + 1060a b x   + 1995a b x   + 1771a b x  + 616a x
+--R  /
+--R            3
+--R     3080b x  + 3080a
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                           +-------------------+
+--R         3 13       2 10     2   7    3 4  | 2 6         3    2     4 16
+--R       (b x   + 3a b x   + 3a b x  + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 13     2 2 10     3   7    4 4
+--R       - 4a b x   - 6a b x   - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 145
+
+)clear all
+
+--S 146 of 2282
+t0:=x^3*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 9         6    2 3  | 2 6         3    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 2282
+r0:=1/13*x^4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/455*a^2*x^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/1820*a^3*x^4*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/130*a*x^4*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                                                      +-------------------+
+--R             3 13         2 10       2   7       3 4  | 2 6         3    2
+--R        (140b x   + 546a b x   + 780a b x  + 455a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------------------
+--R                                         3
+--R                                  1820b x  + 1820a
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 13         2 10       2   7       3 4
+--R        140b x   + 546a b x   + 780a b x  + 455a x
+--R   (3)  -------------------------------------------
+--R                            1820
+--R                                         Type: Union(Expression(Integer),...)
+--E 148
+
+--S 149 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                       +-------------------+
+--R              3 13         2 10       2   7       3 4  | 2 6         3    2
+--R       (- 140b x   - 546a b x   - 780a b x  - 455a x )\|b x  + 2a b x  + a
+--R     + 
+--R           4 16         3 13        2 2 10        3   7       4 4
+--R       140b x   + 686a b x   + 1326a b x   + 1235a b x  + 455a x
+--R  /
+--R            3
+--R     1820b x  + 1820a
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                          +-------------------+
+--R         3 12       2 9     2   6    3 3  | 2 6         3    2     4 15
+--R       (b x   + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 12     2 2 9     3   6    4 3
+--R       - 4a b x   - 6a b x  - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 2282
+t0:=x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 8         5    2 2  | 2 6         3    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 2282
+r0:=1/12*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/b
+--R 
+--R
+--R                                        +-------------------+
+--R          3 9       2 6     2   3    3  | 2 6         3    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------
+--R                                 12b
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3 12       2 9     2   6     3 3
+--R        b x   + 4a b x  + 6a b x  + 4a x
+--R   (3)  ---------------------------------
+--R                        12
+--R                                         Type: Union(Expression(Integer),...)
+--E 153
+
+--S 154 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +-------------------+
+--R           3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (- b x  - 3a b x  - 3a b x  - a )\|b x  + 2a b x  + a   + b x   + 4a b x
+--R     + 
+--R         2 2 6     3   3
+--R       6a b x  + 4a b x
+--R  /
+--R     12b
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                          +-------------------+
+--R         3 11       2 8     2   5    3 2  | 2 6         3    2     4 14
+--R       (b x   + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 11     2 2 8     3   5    4 2
+--R       - 4a b x   - 6a b x  - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 155
+
+)clear all
+
+--S 156 of 2282
+t0:=x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                               +-------------------+
+--R          2 7         4    2   | 2 6         3    2
+--R   (1)  (b x  + 2a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 2282
+r0:=1/11*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/220*a^2*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/440*a^3*x^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/88*a*x^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                                                    +-------------------+
+--R            3 11         2 8       2   5       3 2  | 2 6         3    2
+--R        (40b x   + 165a b x  + 264a b x  + 220a x )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------------
+--R                                        3
+--R                                  440b x  + 440a
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 11         2 8       2   5       3 2
+--R        40b x   + 165a b x  + 264a b x  + 220a x
+--R   (3)  -----------------------------------------
+--R                           440
+--R                                         Type: Union(Expression(Integer),...)
+--E 158
+
+--S 159 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                     +-------------------+
+--R             3 11         2 8       2   5       3 2  | 2 6         3    2
+--R       (- 40b x   - 165a b x  - 264a b x  - 220a x )\|b x  + 2a b x  + a
+--R     + 
+--R          4 14         3 11       2 2 8       3   5       4 2
+--R       40b x   + 205a b x   + 429a b x  + 484a b x  + 220a x
+--R  /
+--R           3
+--R     440b x  + 440a
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                         +-------------------+
+--R         3 10       2 7     2   4    3   | 2 6         3    2     4 13
+--R       (b x   + 3a b x  + 3a b x  + a x)\|b x  + 2a b x  + a   - b x
+--R     + 
+--R             3 10     2 2 7     3   4    4
+--R       - 4a b x   - 6a b x  - 4a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 160
+
+)clear all
+
+--S 161 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R   (1)  (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 2282
+r0:=1/10*x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/140*a^2*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/140*a^3*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)/_
+   (a+b*x^3)+9/70*a*x*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                                                  +-------------------+
+--R            3 10        2 7       2   4       3   | 2 6         3    2
+--R        (14b x   + 60a b x  + 105a b x  + 140a x)\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------------------------------
+--R                                       3
+--R                                 140b x  + 140a
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 10        2 7       2   4       3
+--R        14b x   + 60a b x  + 105a b x  + 140a x
+--R   (3)  ---------------------------------------
+--R                          140
+--R                                         Type: Union(Expression(Integer),...)
+--E 163
+
+--S 164 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                   +-------------------+
+--R             3 10        2 7       2   4       3   | 2 6         3    2
+--R       (- 14b x   - 60a b x  - 105a b x  - 140a x)\|b x  + 2a b x  + a
+--R     + 
+--R          4 13        3 10       2 2 7       3   4       4
+--R       14b x   + 74a b x   + 165a b x  + 245a b x  + 140a x
+--R  /
+--R           3
+--R     140b x  + 140a
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 2282
+r0:=1/9*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/3*a^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+_
+   1/6*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)+a^3*log(x)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                                                         +-------------------+
+--R            3           3 9       2 6      2   3      3  | 2 6         3    2
+--R        (18a log(x) + 2b x  + 9a b x  + 18a b x  + 11a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------------
+--R                                          3
+--R                                     18b x  + 18a
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3           3 9       2 6      2   3
+--R        18a log(x) + 2b x  + 9a b x  + 18a b x
+--R   (3)  ---------------------------------------
+--R                           18
+--R                                         Type: Union(Expression(Integer),...)
+--E 168
+
+--S 169 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +-------------------+
+--R             3           3 9       2 6      2   3      3  | 2 6         3    2
+--R       (- 18a log(x) - 2b x  - 9a b x  - 18a b x  - 11a )\|b x  + 2a b x  + a
+--R     + 
+--R           3   3      4            4 12        3 9      2 2 6      3   3
+--R       (18a b x  + 18a )log(x) + 2b x   + 11a b x  + 27a b x  + 18a b x
+--R  /
+--R          3
+--R     18b x  + 18a
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R       +-------------------+
+--R       | 2 6         3    2
+--R     x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 170
+
+)clear all
+
+--S 171 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^2
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              2
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 2282
+r0:=1/8*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x+27/20*a*b*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/40*a^2*b*x^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)-9/8*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x
+--R 
+--R
+--R                                             +-------------------+
+--R           3 9        2 6      2   3      3  | 2 6         3    2
+--R        (5b x  + 24a b x  + 60a b x  - 40a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------
+--R                                   4
+--R                              40b x  + 40a x
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3 9        2 6      2   3      3
+--R        5b x  + 24a b x  + 60a b x  - 40a
+--R   (3)  ----------------------------------
+--R                        40x
+--R                                         Type: Union(Expression(Integer),...)
+--E 173
+
+--S 174 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +-------------------+
+--R            3 9        2 6      2   3      3  | 2 6         3    2      4 12
+--R       (- 5b x  - 24a b x  - 60a b x  + 40a )\|b x  + 2a b x  + a   + 5b x
+--R     + 
+--R            3 9      2 2 6      3   3      4
+--R       29a b x  + 84a b x  + 20a b x  - 40a
+--R  /
+--R          4
+--R     40b x  + 40a x
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      2 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 175
+
+)clear all
+
+--S 176 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^3
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              3
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 2282
+r0:=4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^2-27/7*b^2*x^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)-81/28*a*b^2*x^4*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)-9/2*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2
+--R 
+--R
+--R                                             +-------------------+
+--R           3 9        2 6      2   3      3  | 2 6         3    2
+--R        (4b x  + 21a b x  + 84a b x  - 14a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------
+--R                                   5        2
+--R                              28b x  + 28a x
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3 9        2 6      2   3      3
+--R        4b x  + 21a b x  + 84a b x  - 14a
+--R   (3)  ----------------------------------
+--R                          2
+--R                       28x
+--R                                         Type: Union(Expression(Integer),...)
+--E 178
+
+--S 179 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +-------------------+
+--R            3 9        2 6      2   3      3  | 2 6         3    2      4 12
+--R       (- 4b x  - 21a b x  - 84a b x  + 14a )\|b x  + 2a b x  + a   + 4b x
+--R     + 
+--R            3 9       2 2 6      3   3      4
+--R       25a b x  + 105a b x  + 70a b x  - 14a
+--R  /
+--R          5        2
+--R     28b x  + 28a x
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      3 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^4
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              4
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 2282
+r0:=1/6*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^3-a^3*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^3*(a+b*x^3))+1/2*a*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^3+3*a^2*b*log(x)*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R       2   3          3 9       2 6     2   3     3  | 2 6         3    2
+--R   (18a b x log(x) + b x  + 6a b x  + 9a b x  - 2a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    6       3
+--R                                6b x  + 6a x
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2   3          3 9       2 6     3
+--R        18a b x log(x) + b x  + 6a b x  - 2a
+--R   (3)  -------------------------------------
+--R                           3
+--R                         6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 183
+
+--S 184 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                           +-------------------+
+--R             2   3          3 9       2 6     2   3     3  | 2 6         3    2
+--R       (- 18a b x log(x) - b x  - 6a b x  - 9a b x  + 2a )\|b x  + 2a b x  + a
+--R     + 
+--R           2 2 6      3   3           4 12       3 9     2 2 6     3   3     4
+--R       (18a b x  + 18a b x )log(x) + b x   + 7a b x  + 6a b x  - 2a b x  - 2a
+--R  /
+--R         6       3
+--R     6b x  + 6a x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      4 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 185
+
+)clear all
+
+--S 186 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^5
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              5
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 2282
+r0:=-5/2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^4+27/10*b^2*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/20*a*b^2*x^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/4*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4
+--R 
+--R
+--R                                            +-------------------+
+--R           3 9        2 6      2   3     3  | 2 6         3    2
+--R        (4b x  + 30a b x  - 60a b x  - 5a )\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------------------------
+--R                                  7        4
+--R                             20b x  + 20a x
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3 9        2 6      2   3     3
+--R        4b x  + 30a b x  - 60a b x  - 5a
+--R   (3)  ---------------------------------
+--R                          4
+--R                       20x
+--R                                         Type: Union(Expression(Integer),...)
+--E 188
+
+--S 189 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +-------------------+
+--R            3 9        2 6      2   3     3  | 2 6         3    2      4 12
+--R       (- 4b x  - 30a b x  + 60a b x  + 5a )\|b x  + 2a b x  + a   + 4b x
+--R     + 
+--R            3 9      2 2 6      3   3     4
+--R       34a b x  - 30a b x  - 65a b x  - 5a
+--R  /
+--R          7        4
+--R     20b x  + 20a x
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      5 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 190
+
+)clear all
+
+--S 191 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^6
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              6
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 2282
+r0:=-11/10*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^5+27/20*b^2*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/20*a*b^2*x*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/10*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5
+--R 
+--R
+--R                                            +-------------------+
+--R           3 9        2 6      2   3     3  | 2 6         3    2
+--R        (5b x  + 60a b x  - 30a b x  - 4a )\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------------------------
+--R                                  8        5
+--R                             20b x  + 20a x
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3 9        2 6      2   3     3
+--R        5b x  + 60a b x  - 30a b x  - 4a
+--R   (3)  ---------------------------------
+--R                          5
+--R                       20x
+--R                                         Type: Union(Expression(Integer),...)
+--E 193
+
+--S 194 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +-------------------+
+--R            3 9        2 6      2   3     3  | 2 6         3    2      4 12
+--R       (- 5b x  - 60a b x  + 30a b x  + 4a )\|b x  + 2a b x  + a   + 5b x
+--R     + 
+--R            3 9      2 2 6      3   3     4
+--R       65a b x  + 30a b x  - 34a b x  - 4a
+--R  /
+--R          8        5
+--R     20b x  + 20a x
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      6 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^7
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              7
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 2282
+r0:=-2/3*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^6+b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)+1/2*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^6+_
+   3*a*b^2*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R         2 6           3 9       2 6     2   3    3  | 2 6         3    2
+--R   (18a b x log(x) + 2b x  - 3a b x  - 6a b x  - a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    9       6
+--R                                6b x  + 6a x
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 6           3 9     2   3    3
+--R        18a b x log(x) + 2b x  - 6a b x  - a
+--R   (3)  -------------------------------------
+--R                           6
+--R                         6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 198
+
+--S 199 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                           +-------------------+
+--R               2 6           3 9       2 6     2   3    3  | 2 6         3    2
+--R       (- 18a b x log(x) - 2b x  + 3a b x  + 6a b x  + a )\|b x  + 2a b x  + a
+--R     + 
+--R             3 9      2 2 6            4 12       3 9     2 2 6     3   3    4
+--R       (18a b x  + 18a b x )log(x) + 2b x   + 2a b x  - 6a b x  - 7a b x  - a
+--R  /
+--R         9       6
+--R     6b x  + 6a x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      7 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 200
+
+)clear all
+
+--S 201 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^8
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              8
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 2282
+r0:=-13/28*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^7+27/28*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x-81/28*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x*(a+b*x^3))+9/28*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7
+--R 
+--R
+--R                                             +-------------------+
+--R            3 9        2 6      2   3     3  | 2 6         3    2
+--R        (14b x  - 84a b x  - 21a b x  - 4a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------
+--R                                  10        7
+--R                             28b x   + 28a x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 9        2 6      2   3     3
+--R        14b x  - 84a b x  - 21a b x  - 4a
+--R   (3)  ----------------------------------
+--R                          7
+--R                       28x
+--R                                         Type: Union(Expression(Integer),...)
+--E 203
+
+--S 204 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +-------------------+
+--R             3 9        2 6      2   3     3  | 2 6         3    2       4 12
+--R       (- 14b x  + 84a b x  + 21a b x  + 4a )\|b x  + 2a b x  + a   + 14b x
+--R     + 
+--R              3 9       2 2 6      3   3     4
+--R       - 70a b x  - 105a b x  - 25a b x  - 4a
+--R  /
+--R          10        7
+--R     28b x   + 28a x
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      8 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 205
+
+)clear all
+
+--S 206 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^9
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              9
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 2282
+r0:=-7/20*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^8+27/20*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2-81/40*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^2*(a+b*x^3))+9/40*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8
+--R 
+--R
+--R                                             +-------------------+
+--R            3 9        2 6      2   3     3  | 2 6         3    2
+--R        (40b x  - 60a b x  - 24a b x  - 5a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------
+--R                                  11        8
+--R                             40b x   + 40a x
+--R                                                    Type: Expression(Integer)
+--E 207
+
+--S 208 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 9        2 6      2   3     3
+--R        40b x  - 60a b x  - 24a b x  - 5a
+--R   (3)  ----------------------------------
+--R                          8
+--R                       40x
+--R                                         Type: Union(Expression(Integer),...)
+--E 208
+
+--S 209 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +-------------------+
+--R             3 9        2 6      2   3     3  | 2 6         3    2       4 12
+--R       (- 40b x  + 60a b x  + 24a b x  + 5a )\|b x  + 2a b x  + a   + 40b x
+--R     + 
+--R              3 9      2 2 6      3   3     4
+--R       - 20a b x  - 84a b x  - 29a b x  - 5a
+--R  /
+--R          11        8
+--R     40b x   + 40a x
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R        +-------------------+
+--R      9 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^10
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             10
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 2282
+r0:=-5/18*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^9-1/3*a*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^3*(a+b*x^3))+1/6*a*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^9+b^3*log(x)*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R       3 9           3 9        2 6     2   3     3  | 2 6         3    2
+--R   (18b x log(x) - 5b x  - 18a b x  - 9a b x  - 2a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    12        9
+--R                               18b x   + 18a x
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 9              2 6     2   3     3
+--R        18b x log(x) - 18a b x  - 9a b x  - 2a
+--R   (3)  ---------------------------------------
+--R                             9
+--R                          18x
+--R                                         Type: Union(Expression(Integer),...)
+--E 213
+
+--S 214 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                           +-------------------+
+--R             3 9           3 9        2 6     2   3     3  | 2 6         3    2
+--R       (- 18b x log(x) + 5b x  + 18a b x  + 9a b x  + 2a )\|b x  + 2a b x  + a
+--R     + 
+--R           4 12        3 9               3 9      2 2 6      3   3     4
+--R       (18b x   + 18a b x )log(x) - 18a b x  - 27a b x  - 11a b x  - 2a
+--R  /
+--R          12        9
+--R     18b x   + 18a x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      10 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 215
+
+)clear all
+
+--S 216 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^11
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             11
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 2282
+r0:=-8/35*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^10-27/35*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4+81/140*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^4*(a+b*x^3))+9/70*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10
+--R 
+--R
+--R                                                  +-------------------+
+--R               3 9         2 6      2   3      3  | 2 6         3    2
+--R        (- 140b x  - 105a b x  - 60a b x  - 14a )\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------------------------------
+--R                                    13         10
+--R                              140b x   + 140a x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3 9         2 6      2   3      3
+--R        - 140b x  - 105a b x  - 60a b x  - 14a
+--R   (3)  ---------------------------------------
+--R                             10
+--R                         140x
+--R                                         Type: Union(Expression(Integer),...)
+--E 218
+
+--S 219 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +-------------------+
+--R            3 9         2 6      2   3      3  | 2 6         3    2        4 12
+--R       (140b x  + 105a b x  + 60a b x  + 14a )\|b x  + 2a b x  + a   - 140b x
+--R     + 
+--R               3 9       2 2 6      3   3      4
+--R       - 245a b x  - 165a b x  - 74a b x  - 14a
+--R  /
+--R           13         10
+--R     140b x   + 140a x
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      11 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 220
+
+)clear all
+
+--S 221 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^12
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             12
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 2282
+r0:=-17/88*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^11-27/88*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5+81/440*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^5*(a+b*x^3))+9/88*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^11
+--R 
+--R
+--R                                                   +-------------------+
+--R               3 9         2 6       2   3      3  | 2 6         3    2
+--R        (- 220b x  - 264a b x  - 165a b x  - 40a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                     14         11
+--R                               440b x   + 440a x
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3 9         2 6       2   3      3
+--R        - 220b x  - 264a b x  - 165a b x  - 40a
+--R   (3)  ----------------------------------------
+--R                             11
+--R                         440x
+--R                                         Type: Union(Expression(Integer),...)
+--E 223
+
+--S 224 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                +-------------------+
+--R            3 9         2 6       2   3      3  | 2 6         3    2        4 12
+--R       (220b x  + 264a b x  + 165a b x  + 40a )\|b x  + 2a b x  + a   - 220b x
+--R     + 
+--R               3 9       2 2 6       3   3      4
+--R       - 484a b x  - 429a b x  - 205a b x  - 40a
+--R  /
+--R           14         11
+--R     440b x   + 440a x
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      12 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^13
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             13
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 2282
+r0:=-1/12*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/(a*x^12)
+--R 
+--R
+--R                                          +-------------------+
+--R            3 9       2 6     2   3    3  | 2 6         3    2
+--R        (- b x  - 3a b x  - 3a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------
+--R                                     12
+--R                                12a x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 9       2 6     2   3    3
+--R        - 4b x  - 6a b x  - 4a b x  - a
+--R   (3)  --------------------------------
+--R                         12
+--R                      12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 228
+
+--S 229 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2        3 9     2 2 6
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - 4a b x  - 6a b x
+--R     + 
+--R           3   3    4
+--R       - 4a b x  - a
+--R  /
+--R          12
+--R     12a x
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      13 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 230
+
+)clear all
+
+--S 231 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^14
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             14
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 2282
+r0:=-19/130*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^13-27/260*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7+81/1820*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^7*(a+b*x^3))+9/130*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^13
+--R 
+--R
+--R                                                    +-------------------+
+--R               3 9         2 6       2   3       3  | 2 6         3    2
+--R        (- 455b x  - 780a b x  - 546a b x  - 140a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------------
+--R                                     16          13
+--R                              1820b x   + 1820a x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3 9         2 6       2   3       3
+--R        - 455b x  - 780a b x  - 546a b x  - 140a
+--R   (3)  -----------------------------------------
+--R                              13
+--R                         1820x
+--R                                         Type: Union(Expression(Integer),...)
+--E 233
+
+--S 234 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +-------------------+
+--R            3 9         2 6       2   3       3  | 2 6         3    2
+--R       (455b x  + 780a b x  + 546a b x  + 140a )\|b x  + 2a b x  + a
+--R     + 
+--R             4 12          3 9        2 2 6       3   3       4
+--R       - 455b x   - 1235a b x  - 1326a b x  - 686a b x  - 140a
+--R  /
+--R            16          13
+--R     1820b x   + 1820a x
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      14 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 235
+
+)clear all
+
+--S 236 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^15
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             15
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 2282
+r0:=-10/77*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^14-27/385*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8+81/3080*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^8*(a+b*x^3))+9/154*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^14
+--R 
+--R
+--R                                                     +-------------------+
+--R               3 9          2 6       2   3       3  | 2 6         3    2
+--R        (- 616b x  - 1155a b x  - 840a b x  - 220a )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------------
+--R                                      17          14
+--R                               3080b x   + 3080a x
+--R                                                    Type: Expression(Integer)
+--E 237
+
+--S 238 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3 9          2 6       2   3       3
+--R        - 616b x  - 1155a b x  - 840a b x  - 220a
+--R   (3)  ------------------------------------------
+--R                               14
+--R                          3080x
+--R                                         Type: Union(Expression(Integer),...)
+--E 238
+
+--S 239 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                  +-------------------+
+--R            3 9          2 6       2   3       3  | 2 6         3    2
+--R       (616b x  + 1155a b x  + 840a b x  + 220a )\|b x  + 2a b x  + a
+--R     + 
+--R             4 12          3 9        2 2 6        3   3       4
+--R       - 616b x   - 1771a b x  - 1995a b x  - 1060a b x  - 220a
+--R  /
+--R            17          14
+--R     3080b x   + 3080a x
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      15 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^16
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             16
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 2282
+r0:=-1/12*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/(a*x^15)+_
+   1/60*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(a^2*x^15)
+--R 
+--R
+--R                                                    +-------------------+
+--R          4 12      3 9     2 2 6      3   3     4  | 2 6         3    2
+--R        (b x   - a b x  - 9a b x  - 11a b x  - 4a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------------
+--R                                        2 15
+--R                                     60a x
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 9        2 6      2   3     3
+--R        - 10b x  - 20a b x  - 15a b x  - 4a
+--R   (3)  ------------------------------------
+--R                           15
+--R                        60x
+--R                                         Type: Union(Expression(Integer),...)
+--E 243
+
+--S 244 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                     +-------------------+
+--R           4 12      3 9     2 2 6      3   3     4  | 2 6         3    2
+--R       (- b x   + a b x  + 9a b x  + 11a b x  + 4a )\|b x  + 2a b x  + a
+--R     + 
+--R            2 3 9      3 2 6      4   3     5
+--R       - 10a b x  - 20a b x  - 15a b x  - 4a
+--R  /
+--R        2 15
+--R     60a x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      16 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 245
+
+)clear all
+
+--S 246 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^17
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             17
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 2282
+r0:=-11/104*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^16-27/728*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10+81/7280*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^10*(a+b*x^3))+9/208*a*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^16
+--R 
+--R
+--R                                                       +-------------------+
+--R                3 9          2 6        2   3       3  | 2 6         3    2
+--R        (- 1040b x  - 2184a b x  - 1680a b x  - 455a )\|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------------------------------
+--R                                       19          16
+--R                                7280b x   + 7280a x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3 9          2 6        2   3       3
+--R        - 1040b x  - 2184a b x  - 1680a b x  - 455a
+--R   (3)  --------------------------------------------
+--R                                16
+--R                           7280x
+--R                                         Type: Union(Expression(Integer),...)
+--E 248
+
+--S 249 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +-------------------+
+--R             3 9          2 6        2   3       3  | 2 6         3    2
+--R       (1040b x  + 2184a b x  + 1680a b x  + 455a )\|b x  + 2a b x  + a
+--R     + 
+--R              4 12          3 9        2 2 6        3   3       4
+--R       - 1040b x   - 3224a b x  - 3864a b x  - 2135a b x  - 455a
+--R  /
+--R            19          16
+--R     7280b x   + 7280a x
+--R                                                    Type: Expression(Integer)
+--E 249
+
+--S 250 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +-------------------+
+--R         3 9       2 6     2   3    3  | 2 6         3    2     4 12       3 9
+--R       (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a   - b x   - 4a b x
+--R     + 
+--R           2 2 6     3   3    4
+--R       - 6a b x  - 4a b x  - a
+--R  /
+--R         +-------------------+
+--R      17 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 250
+
+)clear all
+
+--S 251 of 2282
+t0:=x^m*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                     +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  m | 2 6         3    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a )x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 2282
+r0:=180*a^2*x^(1+m)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/((10+m)*(13+m)*(16+m))+_
+   15*a*x^(1+m)*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/(208+29*m+m^2)+_
+   x^(1+m)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(16+m)+9720*a^4*x^(1+m)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/((4+m)*(7+m)*(10+m)*(13+m)*(16+m))+29160*_
+   a^5*x^(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/((7+m)*(10+m)*(13+m)*(16+m)*_
+   (4+5*m+m^2)*(a+b*x^3))+1620*a^3*x^(1+m)*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/((13+m)*(16+m)*(70+17*m+m^2))
+--R 
+--R
+--R   (2)
+--R           5 5      5 4       5 3        5 2        5         5  15
+--R         (b m  + 35b m  + 445b m  + 2485b m  + 5714b m + 3640b )x
+--R       + 
+--R                 4 5         4 4          4 3           4 2           4
+--R             5a b m  + 190a b m  + 2555a b m  + 14810a b m  + 34840a b m
+--R           + 
+--R                     4
+--R             22400a b
+--R        *
+--R            12
+--R           x
+--R       + 
+--R                2 3 5       2 3 4        2 3 3         2 3 2         2 3
+--R             10a b m  + 410a b m  + 5950a b m  + 36550a b m  + 89240a b m
+--R           + 
+--R                   2 3
+--R             58240a b
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                3 2 5       3 2 4        3 2 3         3 2 2          3 2
+--R             10a b m  + 440a b m  + 6970a b m  + 47260a b m  + 123920a b m
+--R           + 
+--R                   3 2
+--R             83200a b
+--R        *
+--R            6
+--R           x
+--R       + 
+--R               4   5       4   4        4   3         4   2          4
+--R             5a b m  + 235a b m  + 4085a b m  + 31685a b m  + 100630a b m
+--R           + 
+--R                   4
+--R             72800a b
+--R        *
+--R            3
+--R           x
+--R       + 
+--R          5 5      5 4       5 3        5 2         5          5
+--R         a m  + 50a m  + 955a m  + 8650a m  + 36824a m + 58240a
+--R    *
+--R              +-------------------+
+--R        m + 1 | 2 6         3    2
+--R       x     \|b x  + 2a b x  + a
+--R  /
+--R           6        5          4          3           2                      3
+--R       (b m  + 51b m  + 1005b m  + 9605b m  + 45474b m  + 95064b m + 58240b)x
+--R     + 
+--R          6        5          4          3           2
+--R       a m  + 51a m  + 1005a m  + 9605a m  + 45474a m  + 95064a m + 58240a
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           5 5      5 4       5 3        5 2        5         5  16
+--R         (b m  + 35b m  + 445b m  + 2485b m  + 5714b m + 3640b )x
+--R       + 
+--R                 4 5         4 4          4 3           4 2           4
+--R             5a b m  + 190a b m  + 2555a b m  + 14810a b m  + 34840a b m
+--R           + 
+--R                     4
+--R             22400a b
+--R        *
+--R            13
+--R           x
+--R       + 
+--R                2 3 5       2 3 4        2 3 3         2 3 2         2 3
+--R             10a b m  + 410a b m  + 5950a b m  + 36550a b m  + 89240a b m
+--R           + 
+--R                   2 3
+--R             58240a b
+--R        *
+--R            10
+--R           x
+--R       + 
+--R                3 2 5       3 2 4        3 2 3         3 2 2          3 2
+--R             10a b m  + 440a b m  + 6970a b m  + 47260a b m  + 123920a b m
+--R           + 
+--R                   3 2
+--R             83200a b
+--R        *
+--R            7
+--R           x
+--R       + 
+--R               4   5       4   4        4   3         4   2          4
+--R             5a b m  + 235a b m  + 4085a b m  + 31685a b m  + 100630a b m
+--R           + 
+--R                   4
+--R             72800a b
+--R        *
+--R            4
+--R           x
+--R       + 
+--R           5 5      5 4       5 3        5 2         5          5
+--R         (a m  + 50a m  + 955a m  + 8650a m  + 36824a m + 58240a )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      6      5        4        3         2
+--R     m  + 51m  + 1005m  + 9605m  + 45474m  + 95064m + 58240
+--R                                         Type: Union(Expression(Integer),...)
+--E 253
+
+--S 254 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             6 5      6 4       6 3        6 2        6         6  19
+--R           (b m  + 35b m  + 445b m  + 2485b m  + 5714b m + 3640b )x
+--R         + 
+--R                   5 5         5 4          5 3           5 2           5
+--R               6a b m  + 225a b m  + 3000a b m  + 17295a b m  + 40554a b m
+--R             + 
+--R                       5
+--R               26040a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                  2 4 5       2 4 4        2 4 3         2 4 2          2 4
+--R               15a b m  + 600a b m  + 8505a b m  + 51360a b m  + 124080a b m
+--R             + 
+--R                     2 4
+--R               80640a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                  3 3 5       3 3 4         3 3 3         3 3 2          3 3
+--R               20a b m  + 850a b m  + 12920a b m  + 83810a b m  + 213160a b m
+--R             + 
+--R                      3 3
+--R               141440a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                  4 2 5       4 2 4         4 2 3         4 2 2          4 2
+--R               15a b m  + 675a b m  + 11055a b m  + 78945a b m  + 224550a b m
+--R             + 
+--R                      4 2
+--R               156000a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                 5   5       5   4        5   3         5   2          5
+--R               6a b m  + 285a b m  + 5040a b m  + 40335a b m  + 137454a b m
+--R             + 
+--R                      5
+--R               131040a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R             6 5      6 4       6 3        6 2         6          6
+--R           (a m  + 50a m  + 955a m  + 8650a m  + 36824a m + 58240a )x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R               5 5      5 4       5 3        5 2        5         5  15
+--R           (- b m  - 35b m  - 445b m  - 2485b m  - 5714b m - 3640b )x
+--R         + 
+--R                     4 5         4 4          4 3           4 2           4
+--R               - 5a b m  - 190a b m  - 2555a b m  - 14810a b m  - 34840a b m
+--R             + 
+--R                         4
+--R               - 22400a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                    2 3 5       2 3 4        2 3 3         2 3 2         2 3
+--R               - 10a b m  - 410a b m  - 5950a b m  - 36550a b m  - 89240a b m
+--R             + 
+--R                       2 3
+--R               - 58240a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                    3 2 5       3 2 4        3 2 3         3 2 2          3 2
+--R               - 10a b m  - 440a b m  - 6970a b m  - 47260a b m  - 123920a b m
+--R             + 
+--R                       3 2
+--R               - 83200a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                   4   5       4   4        4   3         4   2          4
+--R               - 5a b m  - 235a b m  - 4085a b m  - 31685a b m  - 100630a b m
+--R             + 
+--R                       4
+--R               - 72800a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R              5 5      5 4       5 3        5 2         5          5
+--R           - a m  - 50a m  - 955a m  - 8650a m  - 36824a m - 58240a
+--R      *
+--R                +-------------------+
+--R          m + 1 | 2 6         3    2
+--R         x     \|b x  + 2a b x  + a
+--R  /
+--R           6        5          4          3           2                      3
+--R       (b m  + 51b m  + 1005b m  + 9605b m  + 45474b m  + 95064b m + 58240b)x
+--R     + 
+--R          6        5          4          3           2
+--R       a m  + 51a m  + 1005a m  + 9605a m  + 45474a m  + 95064a m + 58240a
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R             5 15       4 12      2 3 9      3 2 6     4   3    5
+--R           (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R        *
+--R            +-------------------+
+--R            | 2 6         3    2
+--R           \|b x  + 2a b x  + a
+--R       + 
+--R            6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R         - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R    *
+--R         (m + 1)log(x)
+--R       %e
+--R  /
+--R       +-------------------+
+--R       | 2 6         3    2
+--R     x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 2282
+t0:=x^13*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 25       3 22     2 2 19     3   16    4 13  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 2282
+r0:=90/8671*a^2*x^14*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/754*a*x^14*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/29*x^14*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/147407*a^4*x^14*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/2063698*_
+   a^5*x^14*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/17342*a^3*x^14*_
+   (a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 29            4 26          2 3 23           3 2 20
+--R         71162b x   + 396865a b x   + 897260a b x   + 1031849a b x
+--R       + 
+--R                4   17          5 14
+--R         606970a b x   + 147407a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R               3
+--R     2063698b x  + 2063698a
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 29            4 26          2 3 23           3 2 20
+--R       71162b x   + 396865a b x   + 897260a b x   + 1031849a b x
+--R     + 
+--R              4   17          5 14
+--R       606970a b x   + 147407a x
+--R  /
+--R     2063698
+--R                                         Type: Union(Expression(Integer),...)
+--E 258
+
+--S 259 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 29            4 26          2 3 23           3 2 20
+--R           - 71162b x   - 396865a b x   - 897260a b x   - 1031849a b x
+--R         + 
+--R                    4   17          5 14
+--R           - 606970a b x   - 147407a x
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 32            5 29           2 4 26           3 3 23
+--R       71162b x   + 468027a b x   + 1294125a b x   + 1929109a b x
+--R     + 
+--R               4 2 20          5   17          6 14
+--R       1638819a b x   + 754377a b x   + 147407a x
+--R  /
+--R               3
+--R     2063698b x  + 2063698a
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 28       4 25      2 3 22      3 2 19     4   16    5 13
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x  )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 31       5 28      2 4 25      3 3 22      4 2 19     5   16    6 13
+--R     - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 260
+
+)clear all
+
+--S 261 of 2282
+t0:=x^12*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 24       3 21     2 2 18     3   15    4 12  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 2282
+r0:=9/770*a^2*x^13*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+3/140*a*x^13*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/28*x^13*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/117040*a^4*x^13*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/1521520*a^5*_
+   x^13*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/14630*a^3*_
+   x^13*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 28            4 25          2 3 22          3 2 19
+--R         54340b x   + 304304a b x   + 691600a b x   + 800800a b x
+--R       + 
+--R                4   16          5 13
+--R         475475a b x   + 117040a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R               3
+--R     1521520b x  + 1521520a
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 28            4 25          2 3 22          3 2 19
+--R       54340b x   + 304304a b x   + 691600a b x   + 800800a b x
+--R     + 
+--R              4   16          5 13
+--R       475475a b x   + 117040a x
+--R  /
+--R     1521520
+--R                                         Type: Union(Expression(Integer),...)
+--E 263
+
+--S 264 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 28            4 25          2 3 22          3 2 19
+--R           - 54340b x   - 304304a b x   - 691600a b x   - 800800a b x
+--R         + 
+--R                    4   16          5 13
+--R           - 475475a b x   - 117040a x
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 31            5 28          2 4 25           3 3 22
+--R       54340b x   + 358644a b x   + 995904a b x   + 1492400a b x
+--R     + 
+--R               4 2 19          5   16          6 13
+--R       1276275a b x   + 592515a b x   + 117040a x
+--R  /
+--R               3
+--R     1521520b x  + 1521520a
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 27       4 24      2 3 21      3 2 18     4   15    5 12
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x  )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 30       5 27      2 4 24      3 3 21      4 2 18     5   15    6 12
+--R     - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 265
+
+)clear all
+
+--S 266 of 2282
+t0:=x^11*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 23       3 20     2 2 17     3   14    4 11  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 2282
+r0:=-1/216*a^3*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^4-1/72*a*x^6*_
+   (a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^2+1/27*x^9*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b+1/252*a^2*(a^2+2*a*b*x^3+b^2*x^6)^(7/2)/b^4
+--R 
+--R
+--R   (2)
+--R            8 24         7 21       2 6 18       3 5 15       4 4 12    5 3 9
+--R         56b x   + 259a b x   + 461a b x   + 379a b x   + 125a b x   + a b x
+--R       + 
+--R            6 2 6    7   3    8
+--R         - a b x  + a b x  - a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          4
+--R     1512b
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 27         4 24       2 3 21       3 2 18       4   15       5 12
+--R        56b x   + 315a b x   + 720a b x   + 840a b x   + 504a b x   + 126a x
+--R   (3)  ----------------------------------------------------------------------
+--R                                         1512
+--R                                         Type: Union(Expression(Integer),...)
+--E 268
+
+--S 269 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                8 24         7 21       2 6 18       3 5 15       4 4 12
+--R           - 56b x   - 259a b x   - 461a b x   - 379a b x   - 125a b x
+--R         + 
+--R              5 3 9    6 2 6    7   3    8
+--R           - a b x  + a b x  - a b x  + a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          9 27         8 24       2 7 21       3 6 18       4 5 15       5 4 12
+--R       56b x   + 315a b x   + 720a b x   + 840a b x   + 504a b x   + 126a b x
+--R  /
+--R          4
+--R     1512b
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 26       4 23      2 3 20      3 2 17     4   14    5 11
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x  )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 29       5 26      2 4 23      3 3 20      4 2 17     5   14    6 11
+--R     - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 2282
+t0:=x^10*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 22       3 19     2 2 16     3   13    4 10  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 2282
+r0:=9/598*a^2*x^11*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/598*a*x^11*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/26*x^11*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/71162*a^4*x^11*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/782782*a^5*_
+   x^11*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/10166*a^3*x^11*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 26            4 23          2 3 20          3 2 17
+--R         30107b x   + 170170a b x   + 391391a b x   + 460460a b x
+--R       + 
+--R                4   14         5 11
+--R         279565a b x   + 71162a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              3
+--R     782782b x  + 782782a
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 26            4 23          2 3 20          3 2 17
+--R       30107b x   + 170170a b x   + 391391a b x   + 460460a b x
+--R     + 
+--R              4   14         5 11
+--R       279565a b x   + 71162a x
+--R  /
+--R     782782
+--R                                         Type: Union(Expression(Integer),...)
+--E 273
+
+--S 274 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 26            4 23          2 3 20          3 2 17
+--R           - 30107b x   - 170170a b x   - 391391a b x   - 460460a b x
+--R         + 
+--R                    4   14         5 11
+--R           - 279565a b x   - 71162a x
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 29            5 26          2 4 23          3 3 20
+--R       30107b x   + 200277a b x   + 561561a b x   + 851851a b x
+--R     + 
+--R              4 2 17          5   14         6 11
+--R       740025a b x   + 350727a b x   + 71162a x
+--R  /
+--R              3
+--R     782782b x  + 782782a
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 25       4 22      2 3 19      3 2 16     4   13    5 10
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x  )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 28       5 25      2 4 22      3 3 19      4 2 16     5   13    6 10
+--R     - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 275
+
+)clear all
+
+--S 276 of 2282
+t0:=x^9*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                        +-------------------+
+--R          4 21       3 18     2 2 15     3   12    4 9  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 2282
+r0:=18/1045*a^2*x^10*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+3/110*a*x^10*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/25*x^10*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/54340*a^4*x^10*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/543400*a^5*x^10*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/8360*a^3*x^10*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 25            4 22          2 3 19          3 2 16
+--R         21736b x   + 123500a b x   + 286000a b x   + 339625a b x
+--R       + 
+--R                4   13         5 10
+--R         209000a b x   + 54340a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              3
+--R     543400b x  + 543400a
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 25            4 22          2 3 19          3 2 16
+--R       21736b x   + 123500a b x   + 286000a b x   + 339625a b x
+--R     + 
+--R              4   13         5 10
+--R       209000a b x   + 54340a x
+--R  /
+--R     543400
+--R                                         Type: Union(Expression(Integer),...)
+--E 278
+
+--S 279 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 25            4 22          2 3 19          3 2 16
+--R           - 21736b x   - 123500a b x   - 286000a b x   - 339625a b x
+--R         + 
+--R                    4   13         5 10
+--R           - 209000a b x   - 54340a x
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 28            5 25          2 4 22          3 3 19
+--R       21736b x   + 145236a b x   + 409500a b x   + 625625a b x
+--R     + 
+--R              4 2 16          5   13         6 10
+--R       548625a b x   + 263340a b x   + 54340a x
+--R  /
+--R              3
+--R     543400b x  + 543400a
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 24       4 21      2 3 18      3 2 15     4   12    5 9
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 27       5 24      2 4 21      3 3 18      4 2 15     5   12    6 9
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 2282
+t0:=x^8*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                        +-------------------+
+--R          4 20       3 17     2 2 14     3   11    4 8  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 2282
+r0:=1/72*a^2*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^3+1/24*x^6*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b-1/84*a*(a^2+2*a*b*x^3+b^2*x^6)^(7/2)/b^3
+--R 
+--R
+--R   (2)
+--R            7 21        6 18       2 5 15       3 4 12      4 3 9    5 2 6
+--R         21b x   + 99a b x   + 181a b x   + 155a b x   + 55a b x  + a b x
+--R       + 
+--R            6   3    7
+--R         - a b x  + a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         3
+--R     504b
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 24         4 21       2 3 18       3 2 15       4   12      5 9
+--R        21b x   + 120a b x   + 280a b x   + 336a b x   + 210a b x   + 56a x
+--R   (3)  --------------------------------------------------------------------
+--R                                         504
+--R                                         Type: Union(Expression(Integer),...)
+--E 283
+
+--S 284 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                7 21        6 18       2 5 15       3 4 12      4 3 9    5 2 6
+--R           - 21b x   - 99a b x   - 181a b x   - 155a b x   - 55a b x  - a b x
+--R         + 
+--R            6   3    7
+--R           a b x  - a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          8 24         7 21       2 6 18       3 5 15       4 4 12      5 3 9
+--R       21b x   + 120a b x   + 280a b x   + 336a b x   + 210a b x   + 56a b x
+--R  /
+--R         3
+--R     504b
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 23       4 20      2 3 17      3 2 14     4   11    5 8
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 26       5 23      2 4 20      3 3 17      4 2 14     5   11    6 8
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 2282
+t0:=x^7*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                        +-------------------+
+--R          4 19       3 16     2 2 13     3   10    4 7  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 2282
+r0:=9/391*a^2*x^8*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+3/92*a*x^8*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/23*x^8*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/30107*a^4*x^8*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/240856*a^5*x^8*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/5474*a^3*x^8*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 23           4 20          2 3 17          3 2 14
+--R         10472b x   + 60214a b x   + 141680a b x   + 172040a b x
+--R       + 
+--R                4   11         5 8
+--R         109480a b x   + 30107a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              3
+--R     240856b x  + 240856a
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             5 23           4 20          2 3 17          3 2 14          4   11
+--R       10472b x   + 60214a b x   + 141680a b x   + 172040a b x   + 109480a b x
+--R     + 
+--R             5 8
+--R       30107a x
+--R  /
+--R     240856
+--R                                         Type: Union(Expression(Integer),...)
+--E 288
+
+--S 289 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5 23           4 20          2 3 17          3 2 14
+--R           - 10472b x   - 60214a b x   - 141680a b x   - 172040a b x
+--R         + 
+--R                    4   11         5 8
+--R           - 109480a b x   - 30107a x
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             6 26           5 23          2 4 20          3 3 17          4 2 14
+--R       10472b x   + 70686a b x   + 201894a b x   + 313720a b x   + 281520a b x
+--R     + 
+--R              5   11         6 8
+--R       139587a b x   + 30107a x
+--R  /
+--R              3
+--R     240856b x  + 240856a
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 22       4 19      2 3 16      3 2 13     4   10    5 7
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x   + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 25       5 22      2 4 19      3 3 16      4 2 13     5   10    6 7
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x   - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 290
+
+)clear all
+
+--S 291 of 2282
+t0:=x^6*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 18       3 15     2 2 12     3   9    4 6  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 2282
+r0:=45/1672*a^2*x^7*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/418*a*x^7*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/22*x^7*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/21736*a^4*x^7*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/152152*a^5*x^7*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+405/21736*a^3*x^7*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R              5 22           4 19         2 3 16          3 2 13         4   10
+--R         6916b x   + 40040a b x   + 95095a b x   + 117040a b x   + 76076a b x
+--R       + 
+--R               5 7
+--R         21736a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              3
+--R     152152b x  + 152152a
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            5 22           4 19         2 3 16          3 2 13         4   10
+--R       6916b x   + 40040a b x   + 95095a b x   + 117040a b x   + 76076a b x
+--R     + 
+--R             5 7
+--R       21736a x
+--R  /
+--R     152152
+--R                                         Type: Union(Expression(Integer),...)
+--E 293
+
+--S 294 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 22           4 19         2 3 16          3 2 13
+--R           - 6916b x   - 40040a b x   - 95095a b x   - 117040a b x
+--R         + 
+--R                   4   10         5 7
+--R           - 76076a b x   - 21736a x
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            6 25           5 22          2 4 19          3 3 16          4 2 13
+--R       6916b x   + 46956a b x   + 135135a b x   + 212135a b x   + 193116a b x
+--R     + 
+--R             5   10         6 7
+--R       97812a b x   + 21736a x
+--R  /
+--R              3
+--R     152152b x  + 152152a
+--R                                                    Type: Expression(Integer)
+--E 294
+
+--S 295 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 21       4 18      2 3 15      3 2 12     4   9    5 6
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 24       5 21      2 4 18      3 3 15      4 2 12     5   9    6 6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 295
+
+)clear all
+
+--S 296 of 2282
+t0:=x^5*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 17       3 14     2 2 11     3   8    4 5  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 2282
+r0:=-1/18*a*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^2+_
+   1/21*(a^2+2*a*b*x^3+b^2*x^6)^(7/2)/b^2
+--R 
+--R
+--R   (2)
+--R          6 18        5 15      2 4 12      3 3 9      4 2 6    5   3    6
+--R       (6b x   + 29a b x   + 55a b x   + 50a b x  + 20a b x  + a b x  - a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         2
+--R     126b
+--R                                                    Type: Expression(Integer)
+--E 297
+
+--S 298 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          5 21        4 18      2 3 15       3 2 12      4   9      5 6
+--R        6b x   + 35a b x   + 84a b x   + 105a b x   + 70a b x  + 21a x
+--R   (3)  ---------------------------------------------------------------
+--R                                      126
+--R                                         Type: Union(Expression(Integer),...)
+--E 298
+
+--S 299 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              6 18        5 15      2 4 12      3 3 9      4 2 6    5   3    6
+--R         (- 6b x   - 29a b x   - 55a b x   - 50a b x  - 20a b x  - a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R         7 21        6 18      2 5 15       3 4 12      4 3 9      5 2 6
+--R       6b x   + 35a b x   + 84a b x   + 105a b x   + 70a b x  + 21a b x
+--R  /
+--R         2
+--R     126b
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 20       4 17      2 3 14      3 2 11     4   8    5 5
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 23       5 20      2 4 17      3 3 14      4 2 11     5   8    6 5
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 2282
+t0:=x^4*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 16       3 13     2 2 10     3   7    4 4  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 2282
+r0:=9/238*a^2*x^5*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+3/68*a*x^5*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/20*x^5*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/10472*a^4*x^5*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/52360*a^5*x^5*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/2618*a^3*x^5*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R              5 20           4 17         2 3 14         3 2 11         4   8
+--R         2618b x   + 15400a b x   + 37400a b x   + 47600a b x   + 32725a b x
+--R       + 
+--R               5 5
+--R         10472a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             3
+--R     52360b x  + 52360a
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            5 20           4 17         2 3 14         3 2 11         4   8
+--R       2618b x   + 15400a b x   + 37400a b x   + 47600a b x   + 32725a b x
+--R     + 
+--R             5 5
+--R       10472a x
+--R  /
+--R     52360
+--R                                         Type: Union(Expression(Integer),...)
+--E 303
+
+--S 304 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 20           4 17         2 3 14         3 2 11
+--R           - 2618b x   - 15400a b x   - 37400a b x   - 47600a b x
+--R         + 
+--R                   4   8         5 5
+--R           - 32725a b x  - 10472a x
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            6 23           5 20         2 4 17         3 3 14         4 2 11
+--R       2618b x   + 18018a b x   + 52800a b x   + 85000a b x   + 80325a b x
+--R     + 
+--R             5   8         6 5
+--R       43197a b x  + 10472a x
+--R  /
+--R             3
+--R     52360b x  + 52360a
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 19       4 16      2 3 13      3 2 10     4   7    5 4
+--R         (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 22       5 19      2 4 16      3 3 13      4 2 10     5   7    6 4
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x   - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 305
+
+)clear all
+
+--S 306 of 2282
+t0:=x^3*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                      +-------------------+
+--R          4 15       3 12     2 2 9     3   6    4 3  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 2282
+r0:=45/988*a^2*x^4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/304*a*x^4*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/19*x^4*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/6916*a^4*x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/27664*a^5*x^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/1976*a^3*x^4*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R              5 19          4 16         2 3 13         3 2 10         4   7
+--R         1456b x   + 8645a b x   + 21280a b x   + 27664a b x   + 19760a b x
+--R       + 
+--R              5 4
+--R         6916a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             3
+--R     27664b x  + 27664a
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            5 19          4 16         2 3 13         3 2 10         4   7
+--R       1456b x   + 8645a b x   + 21280a b x   + 27664a b x   + 19760a b x
+--R     + 
+--R            5 4
+--R       6916a x
+--R  /
+--R     27664
+--R                                         Type: Union(Expression(Integer),...)
+--E 308
+
+--S 309 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 19          4 16         2 3 13         3 2 10         4   7
+--R           - 1456b x   - 8645a b x   - 21280a b x   - 27664a b x   - 19760a b x
+--R         + 
+--R                  5 4
+--R           - 6916a x
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            6 22           5 19         2 4 16         3 3 13         4 2 10
+--R       1456b x   + 10101a b x   + 29925a b x   + 48944a b x   + 47424a b x
+--R     + 
+--R             5   7        6 4
+--R       26676a b x  + 6916a x
+--R  /
+--R             3
+--R     27664b x  + 27664a
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 18       4 15      2 3 12      3 2 9     4   6    5 3
+--R         (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 21       5 18      2 4 15      3 3 12      4 2 9     5   6    6 3
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x  - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 310
+
+)clear all
+
+--S 311 of 2282
+t0:=x^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                      +-------------------+
+--R          4 14       3 11     2 2 8     3   5    4 2  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 2282
+r0:=1/18*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b
+--R 
+--R
+--R   (2)
+--R                                                           +-------------------+
+--R     5 15       4 12      2 3 9      3 2 6     4   3    5  | 2 6         3    2
+--R   (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------------
+--R                                        18b
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R         5 18       4 15      2 3 12      3 2 9      4   6     5 3
+--R        b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a x
+--R   (3)  ----------------------------------------------------------
+--R                                    18
+--R                                         Type: Union(Expression(Integer),...)
+--E 313
+
+--S 314 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (- b x   - 5a b x   - 10a b x  - 10a b x  - 5a b x  - a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 18       5 15      2 4 12      3 3 9      4 2 6     5   3
+--R       b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x
+--R  /
+--R     18b
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 17       4 14      2 3 11      3 2 8     4   5    5 2
+--R         (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 20       5 17      2 4 14      3 3 11      4 2 8     5   5    6 2
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x  - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 2282
+t0:=x*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                     +-------------------+
+--R          4 13       3 10     2 2 7     3   4    4   | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 2282
+r0:=90/1309*a^2*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/238*a*x^2*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/17*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/2618*a^4*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/5236*a^5*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+405/5236*a^3*x^2*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 17          4 14        2 3 11        3 2 8        4   5
+--R           308b x   + 1870a b x   + 4760a b x   + 6545a b x  + 5236a b x
+--R         + 
+--R                5 2
+--R           2618a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            3
+--R     5236b x  + 5236a
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       5 17          4 14        2 3 11        3 2 8        4   5        5 2
+--R   308b x   + 1870a b x   + 4760a b x   + 6545a b x  + 5236a b x  + 2618a x
+--R   -------------------------------------------------------------------------
+--R                                      5236
+--R                                         Type: Union(Expression(Integer),...)
+--E 318
+
+--S 319 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 17          4 14        2 3 11        3 2 8        4   5
+--R           - 308b x   - 1870a b x   - 4760a b x   - 6545a b x  - 5236a b x
+--R         + 
+--R                  5 2
+--R           - 2618a x
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R           6 20          5 17        2 4 14         3 3 11         4 2 8
+--R       308b x   + 2178a b x   + 6630a b x   + 11305a b x   + 11781a b x
+--R     + 
+--R            5   5        6 2
+--R       7854a b x  + 2618a x
+--R  /
+--R            3
+--R     5236b x  + 5236a
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 16       4 13      2 3 10      3 2 7     4   4    5
+--R         (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x)
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 19       5 16      2 4 13      3 3 10      4 2 7     5   4    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x   - 15a b x  - 6a b x  - a x
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 320
+
+)clear all
+
+--S 321 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 2282
+r0:=9/104*a^2*x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/208*a*x*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/16*x*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/1456*a^4*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/1456*a^5*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/728*a^3*x*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R           5 16         4 13        2 3 10        3 2 7        4   4        5
+--R       (91b x   + 560a b x   + 1456a b x   + 2080a b x  + 1820a b x  + 1456a x)
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            3
+--R     1456b x  + 1456a
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 16         4 13        2 3 10        3 2 7        4   4        5
+--R        91b x   + 560a b x   + 1456a b x   + 2080a b x  + 1820a b x  + 1456a x
+--R   (3)  ----------------------------------------------------------------------
+--R                                         1456
+--R                                         Type: Union(Expression(Integer),...)
+--E 323
+
+--S 324 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                5 16         4 13        2 3 10        3 2 7        4   4
+--R           - 91b x   - 560a b x   - 1456a b x   - 2080a b x  - 1820a b x
+--R         + 
+--R                  5
+--R           - 1456a x
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 19         5 16        2 4 13        3 3 10        4 2 7
+--R       91b x   + 651a b x   + 2016a b x   + 3536a b x   + 3900a b x
+--R     + 
+--R            5   4        6
+--R       3276a b x  + 1456a x
+--R  /
+--R            3
+--R     1456b x  + 1456a
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R      +-------------------+
+--R      | 2 6         3    2
+--R     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 325
+
+)clear all
+
+--S 326 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        x
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 2282
+r0:=1/9*a^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/12*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/15*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   1/3*a^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)+1/6*a^3*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+a^5*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R             5            5 15        4 12       2 3 9       3 2 6       4   3
+--R         180a log(x) + 12b x   + 75a b x   + 200a b x  + 300a b x  + 300a b x
+--R       + 
+--R             5
+--R         137a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           3
+--R     180b x  + 180a
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5            5 15        4 12       2 3 9       3 2 6       4   3
+--R        180a log(x) + 12b x   + 75a b x   + 200a b x  + 300a b x  + 300a b x
+--R   (3)  ---------------------------------------------------------------------
+--R                                         180
+--R                                         Type: Union(Expression(Integer),...)
+--E 328
+
+--S 329 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5            5 15        4 12       2 3 9       3 2 6
+--R           - 180a log(x) - 12b x   - 75a b x   - 200a b x  - 300a b x
+--R         + 
+--R                 4   3       5
+--R           - 300a b x  - 137a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            5   3       6             6 18        5 15       2 4 12       3 3 9
+--R       (180a b x  + 180a )log(x) + 12b x   + 87a b x   + 275a b x   + 500a b x
+--R     + 
+--R           4 2 6       5   3
+--R       600a b x  + 300a b x
+--R  /
+--R           3
+--R     180b x  + 180a
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R       +-------------------+
+--R       | 2 6         3    2
+--R     x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^2
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        2
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 2282
+r0:=90/77*a*b*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)-15/14*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x+1/14*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x+_
+   243/154*a^3*b*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/308*a^4*b*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+405/308*a^2*b*x^2*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R           5 15         4 12       2 3 9       3 2 6       4   3       5
+--R       (22b x   + 140a b x   + 385a b x  + 616a b x  + 770a b x  - 308a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           4
+--R     308b x  + 308a x
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 15         4 12       2 3 9       3 2 6       4   3       5
+--R        22b x   + 140a b x   + 385a b x  + 616a b x  + 770a b x  - 308a
+--R   (3)  ----------------------------------------------------------------
+--R                                      308x
+--R                                         Type: Union(Expression(Integer),...)
+--E 333
+
+--S 334 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 15         4 12       2 3 9       3 2 6       4   3       5
+--R         (- 22b x   - 140a b x   - 385a b x  - 616a b x  - 770a b x  + 308a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18         5 15       2 4 12        3 3 9        4 2 6       5   3
+--R       22b x   + 162a b x   + 525a b x   + 1001a b x  + 1386a b x  + 462a b x
+--R     + 
+--R             6
+--R       - 308a
+--R  /
+--R           4
+--R     308b x  + 308a x
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      2 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 335
+
+)clear all
+
+--S 336 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^3
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        3
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 2282
+r0:=-90/13*b^2*x^4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)-15/2*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^2+7*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^2-_
+   486/91*a^2*b^2*x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)-729/182*a^3*b^2*x^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)-81/13*a*b^2*x^4*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R           5 15        4 12       2 3 9       3 2 6       4   3      5
+--R       (14b x   + 91a b x   + 260a b x  + 455a b x  + 910a b x  - 91a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           5         2
+--R     182b x  + 182a x
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 15        4 12       2 3 9       3 2 6       4   3      5
+--R        14b x   + 91a b x   + 260a b x  + 455a b x  + 910a b x  - 91a
+--R   (3)  --------------------------------------------------------------
+--R                                         2
+--R                                     182x
+--R                                         Type: Union(Expression(Integer),...)
+--E 338
+
+--S 339 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 15        4 12       2 3 9       3 2 6       4   3      5
+--R         (- 14b x   - 91a b x   - 260a b x  - 455a b x  - 910a b x  + 91a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18         5 15       2 4 12       3 3 9        4 2 6       5   3
+--R       14b x   + 105a b x   + 351a b x   + 715a b x  + 1365a b x  + 819a b x
+--R     + 
+--R            6
+--R       - 91a
+--R  /
+--R           5         2
+--R     182b x  + 182a x
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      3 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 340
+
+)clear all
+
+--S 341 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^4
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        4
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 2282
+r0:=5/18*a^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^3+5/36*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^3+1/12*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^3-_
+   5/3*a^5*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^3*(a+b*x^3))+5/6*a^3*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^3+5*a^4*b*log(x)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R             4   3           5 15        4 12      2 3 9       3 2 6       4   3
+--R         180a b x log(x) + 3b x   + 20a b x   + 60a b x  + 120a b x  + 125a b x
+--R       + 
+--R              5
+--R         - 12a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          6        3
+--R     36b x  + 36a x
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4   3           5 15        4 12      2 3 9       3 2 6      5
+--R        180a b x log(x) + 3b x   + 20a b x   + 60a b x  + 120a b x  - 12a
+--R   (3)  ------------------------------------------------------------------
+--R                                          3
+--R                                       36x
+--R                                         Type: Union(Expression(Integer),...)
+--E 343
+
+--S 344 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 4   3           5 15        4 12      2 3 9       3 2 6
+--R           - 180a b x log(x) - 3b x   - 20a b x   - 60a b x  - 120a b x
+--R         + 
+--R                 4   3      5
+--R           - 125a b x  + 12a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 2 6       5   3            6 18        5 15      2 4 12
+--R       (180a b x  + 180a b x )log(x) + 3b x   + 23a b x   + 80a b x
+--R     + 
+--R           3 3 9       4 2 6      5   3      6
+--R       180a b x  + 120a b x  - 12a b x  - 12a
+--R  /
+--R          6        3
+--R     36b x  + 36a x
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      4 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^5
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        5
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 2282
+r0:=45/11*b^2*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/4*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^4-4*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^4+_
+   243/44*a^2*b^2*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/88*a^3*b^2*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+405/88*a*b^2*x^2*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R          5 15        4 12       2 3 9       3 2 6       4   3      5
+--R       (8b x   + 55a b x   + 176a b x  + 440a b x  - 440a b x  - 22a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          7        4
+--R     88b x  + 88a x
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          5 15        4 12       2 3 9       3 2 6       4   3      5
+--R        8b x   + 55a b x   + 176a b x  + 440a b x  - 440a b x  - 22a
+--R   (3)  -------------------------------------------------------------
+--R                                        4
+--R                                     88x
+--R                                         Type: Union(Expression(Integer),...)
+--E 348
+
+--S 349 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 15        4 12       2 3 9       3 2 6       4   3      5
+--R         (- 8b x   - 55a b x   - 176a b x  - 440a b x  + 440a b x  + 22a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R         6 18        5 15       2 4 12       3 3 9       5   3      6
+--R       8b x   + 63a b x   + 231a b x   + 616a b x  - 462a b x  - 22a
+--R  /
+--R          7        4
+--R     88b x  + 88a x
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      5 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 350
+
+)clear all
+
+--S 351 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^6
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        6
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 2282
+r0:=9/5*b^2*x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+3/2*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^5-17/10*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^5+_
+   243/70*a^2*b^2*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/70*a^3*b^2*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/35*a*b^2*x*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R          5 15        4 12       2 3 9       3 2 6       4   3      5
+--R       (7b x   + 50a b x   + 175a b x  + 700a b x  - 175a b x  - 14a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          8        5
+--R     70b x  + 70a x
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          5 15        4 12       2 3 9       3 2 6       4   3      5
+--R        7b x   + 50a b x   + 175a b x  + 700a b x  - 175a b x  - 14a
+--R   (3)  -------------------------------------------------------------
+--R                                        5
+--R                                     70x
+--R                                         Type: Union(Expression(Integer),...)
+--E 353
+
+--S 354 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 15        4 12       2 3 9       3 2 6       4   3      5
+--R         (- 7b x   - 50a b x   - 175a b x  - 700a b x  + 175a b x  + 14a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R       6 18        5 15       2 4 12       3 3 9       4 2 6       5   3      6
+--R     7b x   + 57a b x   + 225a b x   + 875a b x  + 525a b x  - 189a b x  - 14a
+--R  /
+--R          8        5
+--R     70b x  + 70a x
+--R                                                    Type: Expression(Integer)
+--E 354
+
+--S 355 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      6 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 355
+
+)clear all
+
+--S 356 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^7
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        7
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 2282
+r0:=10/9*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+5/6*a*(a+b*x^3)*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(3/2)/x^6-(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^6+10/3*a^2*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+5/3*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)+10*a^3*b^2*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R             3 2 6           5 15        4 12      2 3 9      3 2 6      4   3
+--R         180a b x log(x) + 2b x   + 15a b x   + 60a b x  + 20a b x  - 30a b x
+--R       + 
+--R             5
+--R         - 3a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          9        6
+--R     18b x  + 18a x
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 2 6           5 15        4 12      2 3 9      4   3     5
+--R        180a b x log(x) + 2b x   + 15a b x   + 60a b x  - 30a b x  - 3a
+--R   (3)  ----------------------------------------------------------------
+--R                                         6
+--R                                      18x
+--R                                         Type: Union(Expression(Integer),...)
+--E 358
+
+--S 359 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3 2 6           5 15        4 12      2 3 9      3 2 6
+--R           - 180a b x log(x) - 2b x   - 15a b x   - 60a b x  - 20a b x
+--R         + 
+--R              4   3     5
+--R           30a b x  + 3a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            3 3 9       4 2 6            6 18        5 15      2 4 12      3 3 9
+--R       (180a b x  + 180a b x )log(x) + 2b x   + 17a b x   + 75a b x   + 60a b x
+--R     + 
+--R            4 2 6      5   3     6
+--R       - 30a b x  - 33a b x  - 3a
+--R  /
+--R          9        6
+--R     18b x  + 18a x
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      7 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^8
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        8
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 2282
+r0:=45/56*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x+15/28*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^7-19/28*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/_
+   x^7+243/28*a*b^3*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/56*a^2*b^3*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)-405/56*a*b^2*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x
+--R 
+--R
+--R   (2)
+--R          5 15        4 12       2 3 9       3 2 6      4   3     5
+--R       (7b x   + 56a b x   + 280a b x  - 560a b x  - 70a b x  - 8a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          10        7
+--R     56b x   + 56a x
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          5 15        4 12       2 3 9       3 2 6      4   3     5
+--R        7b x   + 56a b x   + 280a b x  - 560a b x  - 70a b x  - 8a
+--R   (3)  -----------------------------------------------------------
+--R                                       7
+--R                                    56x
+--R                                         Type: Union(Expression(Integer),...)
+--E 363
+
+--S 364 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 15        4 12       2 3 9       3 2 6      4   3     5
+--R         (- 7b x   - 56a b x   - 280a b x  + 560a b x  + 70a b x  + 8a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R         6 18        5 15       2 4 12       3 3 9       4 2 6      5   3     6
+--R       7b x   + 63a b x   + 336a b x   - 280a b x  - 630a b x  - 78a b x  - 8a
+--R  /
+--R          10        7
+--R     56b x   + 56a x
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      8 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 365
+
+)clear all
+
+--S 366 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^9
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        9
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 2282
+r0:=18*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^2+3/8*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^8-1/2*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^8-243/14*b^4*x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)-_
+   729/56*a*b^4*x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)-81/4*a*_
+   b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2
+--R 
+--R
+--R   (2)
+--R          5 15        4 12       2 3 9       3 2 6      4   3     5
+--R       (8b x   + 70a b x   + 560a b x  - 280a b x  - 56a b x  - 7a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          11        8
+--R     56b x   + 56a x
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          5 15        4 12       2 3 9       3 2 6      4   3     5
+--R        8b x   + 70a b x   + 560a b x  - 280a b x  - 56a b x  - 7a
+--R   (3)  -----------------------------------------------------------
+--R                                       8
+--R                                    56x
+--R                                         Type: Union(Expression(Integer),...)
+--E 368
+
+--S 369 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 15        4 12       2 3 9       3 2 6      4   3     5
+--R         (- 8b x   - 70a b x   - 560a b x  + 280a b x  + 56a b x  + 7a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R         6 18        5 15       2 4 12       3 3 9       4 2 6      5   3     6
+--R       8b x   + 78a b x   + 630a b x   + 280a b x  - 336a b x  - 63a b x  - 7a
+--R  /
+--R          11        8
+--R     56b x   + 56a x
+--R                                                    Type: Expression(Integer)
+--E 369
+
+--S 370 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R        +-------------------+
+--R      9 | 2 6         3    2
+--R     x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 370
+
+)clear all
+
+--S 371 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^10
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        10
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 2282
+r0:=5/9*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^3+5/18*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^9-7/18*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^9-10/3*a^3*b^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)/_
+   (x^3*(a+b*x^3))+5/3*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^3+_
+   10*a^2*b^3*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R             2 3 9           5 15        4 12      2 3 9      3 2 6      4   3
+--R         180a b x log(x) + 3b x   + 30a b x   + 40a b x  - 60a b x  - 15a b x
+--R       + 
+--R             5
+--R         - 2a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          12        9
+--R     18b x   + 18a x
+--R                                                    Type: Expression(Integer)
+--E 372
+
+--S 373 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 3 9           5 15        4 12      3 2 6      4   3     5
+--R        180a b x log(x) + 3b x   + 30a b x   - 60a b x  - 15a b x  - 2a
+--R   (3)  ----------------------------------------------------------------
+--R                                         9
+--R                                      18x
+--R                                         Type: Union(Expression(Integer),...)
+--E 373
+
+--S 374 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 2 3 9           5 15        4 12      2 3 9      3 2 6
+--R           - 180a b x log(x) - 3b x   - 30a b x   - 40a b x  + 60a b x
+--R         + 
+--R              4   3     5
+--R           15a b x  + 2a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            2 4 12       3 3 9            6 18        5 15      2 4 12
+--R       (180a b x   + 180a b x )log(x) + 3b x   + 33a b x   + 30a b x
+--R     + 
+--R            3 3 9      4 2 6      5   3     6
+--R       - 60a b x  - 75a b x  - 17a b x  - 2a
+--R  /
+--R          12        9
+--R     18b x   + 18a x
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      10 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^11
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        11
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 2282
+r0:=-45/7*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^4+3/14*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^10-11/35*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^10+243/35*b^4*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+_
+   729/70*a*b^4*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+_
+   81/14*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4
+--R 
+--R
+--R   (2)
+--R           5 15         4 12       2 3 9       3 2 6      4   3     5
+--R       (14b x   + 175a b x   - 700a b x  - 175a b x  - 50a b x  - 7a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          13        10
+--R     70b x   + 70a x
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 15         4 12       2 3 9       3 2 6      4   3     5
+--R        14b x   + 175a b x   - 700a b x  - 175a b x  - 50a b x  - 7a
+--R   (3)  -------------------------------------------------------------
+--R                                       10
+--R                                    70x
+--R                                         Type: Union(Expression(Integer),...)
+--E 378
+
+--S 379 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 15         4 12       2 3 9       3 2 6      4   3     5
+--R         (- 14b x   - 175a b x   + 700a b x  + 175a b x  + 50a b x  + 7a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R        6 18         5 15       2 4 12       3 3 9       4 2 6      5   3     6
+--R     14b x   + 189a b x   - 525a b x   - 875a b x  - 225a b x  - 57a b x  - 7a
+--R  /
+--R          13        10
+--R     70b x   + 70a x
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      11 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 380
+
+)clear all
+
+--S 381 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^12
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        12
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 2282
+r0:=-9/4*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^5+15/88*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^11-23/88*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^11+243/88*b^4*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)+_
+   729/88*a*b^4*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+_
+   81/44*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5
+--R 
+--R
+--R   (2)
+--R           5 15         4 12       2 3 9       3 2 6      4   3     5
+--R       (22b x   + 440a b x   - 440a b x  - 176a b x  - 55a b x  - 8a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          14        11
+--R     88b x   + 88a x
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 15         4 12       2 3 9       3 2 6      4   3     5
+--R        22b x   + 440a b x   - 440a b x  - 176a b x  - 55a b x  - 8a
+--R   (3)  -------------------------------------------------------------
+--R                                       11
+--R                                    88x
+--R                                         Type: Union(Expression(Integer),...)
+--E 383
+
+--S 384 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 15         4 12       2 3 9       3 2 6      4   3     5
+--R         (- 22b x   - 440a b x   + 440a b x  + 176a b x  + 55a b x  + 8a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18         5 15       3 3 9       4 2 6      5   3     6
+--R       22b x   + 462a b x   - 616a b x  - 231a b x  - 63a b x  - 8a
+--R  /
+--R          14        11
+--R     88b x   + 88a x
+--R                                                    Type: Expression(Integer)
+--E 384
+
+--S 385 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      12 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 385
+
+)clear all
+
+--S 386 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^13
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        13
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 2282
+r0:=-10/9*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^6+5/36*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^12-2/9*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^12+5/3*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)+_
+   5/6*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^6+_
+   5*a*b^4*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R               4 12            5 15        4 12       2 3 9      3 2 6
+--R         180a b x  log(x) + 12b x   - 65a b x   - 120a b x  - 60a b x
+--R       + 
+--R              4   3     5
+--R         - 20a b x  - 3a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          15        12
+--R     36b x   + 36a x
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4 12            5 15       2 3 9      3 2 6      4   3     5
+--R        180a b x  log(x) + 12b x   - 120a b x  - 60a b x  - 20a b x  - 3a
+--R   (3)  ------------------------------------------------------------------
+--R                                          12
+--R                                       36x
+--R                                         Type: Union(Expression(Integer),...)
+--E 388
+
+--S 389 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   4 12            5 15        4 12       2 3 9      3 2 6
+--R           - 180a b x  log(x) - 12b x   + 65a b x   + 120a b x  + 60a b x
+--R         + 
+--R              4   3     5
+--R           20a b x  + 3a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              5 15       2 4 12             6 18        5 15       2 4 12
+--R       (180a b x   + 180a b x  )log(x) + 12b x   + 12a b x   - 120a b x
+--R     + 
+--R             3 3 9      4 2 6      5   3     6
+--R       - 180a b x  - 80a b x  - 23a b x  - 3a
+--R  /
+--R          15        12
+--R     36b x   + 36a x
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      13 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^14
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        14
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 2282
+r0:=-9/14*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^7+3/26*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^13-5/26*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^13+243/182*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x-_
+   729/182*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x*(a+b*x^3))+_
+   81/182*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7
+--R 
+--R
+--R   (2)
+--R           5 15         4 12       2 3 9       3 2 6      4   3      5
+--R       (91b x   - 910a b x   - 455a b x  - 260a b x  - 91a b x  - 14a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           16         13
+--R     182b x   + 182a x
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           5 15         4 12       2 3 9       3 2 6      4   3      5
+--R        91b x   - 910a b x   - 455a b x  - 260a b x  - 91a b x  - 14a
+--R   (3)  --------------------------------------------------------------
+--R                                        13
+--R                                    182x
+--R                                         Type: Union(Expression(Integer),...)
+--E 393
+
+--S 394 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 15         4 12       2 3 9       3 2 6      4   3      5
+--R         (- 91b x   + 910a b x   + 455a b x  + 260a b x  + 91a b x  + 14a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18         5 15        2 4 12       3 3 9       4 2 6       5   3
+--R       91b x   - 819a b x   - 1365a b x   - 715a b x  - 351a b x  - 105a b x
+--R     + 
+--R            6
+--R       - 14a
+--R  /
+--R           16         13
+--R     182b x   + 182a x
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      14 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 395
+
+)clear all
+
+--S 396 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^15
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        15
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 396
+
+--S 397 of 2282
+r0:=-9/22*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^8+15/154*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^14-13/77*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^14+243/154*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2-_
+   729/308*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^2*(a+b*x^3))+_
+   81/308*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8
+--R 
+--R
+--R   (2)
+--R            5 15         4 12       2 3 9       3 2 6       4   3      5
+--R       (308b x   - 770a b x   - 616a b x  - 385a b x  - 140a b x  - 22a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           17         14
+--R     308b x   + 308a x
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5 15         4 12       2 3 9       3 2 6       4   3      5
+--R        308b x   - 770a b x   - 616a b x  - 385a b x  - 140a b x  - 22a
+--R   (3)  ----------------------------------------------------------------
+--R                                         14
+--R                                     308x
+--R                                         Type: Union(Expression(Integer),...)
+--E 398
+
+--S 399 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                5 15         4 12       2 3 9       3 2 6       4   3      5
+--R         (- 308b x   + 770a b x   + 616a b x  + 385a b x  + 140a b x  + 22a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R           6 18         5 15        2 4 12        3 3 9       4 2 6       5   3
+--R       308b x   - 462a b x   - 1386a b x   - 1001a b x  - 525a b x  - 162a b x
+--R     + 
+--R            6
+--R       - 22a
+--R  /
+--R           17         14
+--R     308b x   + 308a x
+--R                                                    Type: Expression(Integer)
+--E 399
+
+--S 400 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      15 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 400
+
+)clear all
+
+--S 401 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^16
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        16
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 2282
+r0:=-5/18*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^9+1/12*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^15-3/20*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^15-1/3*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/_
+   (x^3*(a+b*x^3))+1/6*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^9+_
+   b^5*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R             5 15            5 15         4 12       2 3 9       3 2 6
+--R         180b x  log(x) - 77b x   - 300a b x   - 300a b x  - 200a b x
+--R       + 
+--R              4   3      5
+--R         - 75a b x  - 12a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           18         15
+--R     180b x   + 180a x
+--R                                                    Type: Expression(Integer)
+--E 402
+
+--S 403 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5 15               4 12       2 3 9       3 2 6      4   3      5
+--R        180b x  log(x) - 300a b x   - 300a b x  - 200a b x  - 75a b x  - 12a
+--R   (3)  ---------------------------------------------------------------------
+--R                                            15
+--R                                        180x
+--R                                         Type: Union(Expression(Integer),...)
+--E 403
+
+--S 404 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 15            5 15         4 12       2 3 9       3 2 6
+--R           - 180b x  log(x) + 77b x   + 300a b x   + 300a b x  + 200a b x
+--R         + 
+--R              4   3      5
+--R           75a b x  + 12a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            6 18         5 15                5 15       2 4 12       3 3 9
+--R       (180b x   + 180a b x  )log(x) - 300a b x   - 600a b x   - 500a b x
+--R     + 
+--R             4 2 6      5   3      6
+--R       - 275a b x  - 87a b x  - 12a
+--R  /
+--R           18         15
+--R     180b x   + 180a x
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      16 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^17
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        17
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 2282
+r0:=-18/91*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^10+15/208*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^16-7/52*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^16-243/364*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4+_
+   729/1456*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^4*(a+b*x^3))+_
+   81/728*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10
+--R 
+--R
+--R   (2)
+--R               5 15          4 12        2 3 9        3 2 6       4   3      5
+--R       (- 1456b x   - 1820a b x   - 2080a b x  - 1456a b x  - 560a b x  - 91a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            19          16
+--R     1456b x   + 1456a x
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               5 15          4 12        2 3 9        3 2 6       4   3      5
+--R        - 1456b x   - 1820a b x   - 2080a b x  - 1456a b x  - 560a b x  - 91a
+--R   (3)  ----------------------------------------------------------------------
+--R                                             16
+--R                                        1456x
+--R                                         Type: Union(Expression(Integer),...)
+--E 408
+
+--S 409 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 15          4 12        2 3 9        3 2 6       4   3      5
+--R         (1456b x   + 1820a b x   + 2080a b x  + 1456a b x  + 560a b x  + 91a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              6 18          5 15        2 4 12        3 3 9        4 2 6
+--R       - 1456b x   - 3276a b x   - 3900a b x   - 3536a b x  - 2016a b x
+--R     + 
+--R             5   3      6
+--R       - 651a b x  - 91a
+--R  /
+--R            19          16
+--R     1456b x   + 1456a x
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      17 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 410
+
+)clear all
+
+--S 411 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^18
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        18
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 2282
+r0:=-45/308*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^11+15/238*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^17-29/238*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^17-1215/5236*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5+_
+   729/5236*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^5*(a+b*x^3))+_
+   405/5236*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^11
+--R 
+--R
+--R   (2)
+--R                  5 15          4 12        2 3 9        3 2 6        4   3
+--R           - 2618b x   - 5236a b x   - 6545a b x  - 4760a b x  - 1870a b x
+--R         + 
+--R                 5
+--R           - 308a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            20          17
+--R     5236b x   + 5236a x
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          5 15          4 12        2 3 9        3 2 6        4   3       5
+--R   - 2618b x   - 5236a b x   - 6545a b x  - 4760a b x  - 1870a b x  - 308a
+--R   ------------------------------------------------------------------------
+--R                                         17
+--R                                    5236x
+--R                                         Type: Union(Expression(Integer),...)
+--E 413
+
+--S 414 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 15          4 12        2 3 9        3 2 6        4   3
+--R             2618b x   + 5236a b x   + 6545a b x  + 4760a b x  + 1870a b x
+--R           + 
+--R                 5
+--R             308a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              6 18          5 15         2 4 12         3 3 9        4 2 6
+--R       - 2618b x   - 7854a b x   - 11781a b x   - 11305a b x  - 6630a b x
+--R     + 
+--R              5   3       6
+--R       - 2178a b x  - 308a
+--R  /
+--R            20          17
+--R     5236b x   + 5236a x
+--R                                                    Type: Expression(Integer)
+--E 414
+
+--S 415 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      18 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 415
+
+)clear all
+
+--S 416 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^19
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        19
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 2282
+r0:=-1/18*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(a*x^18)
+--R 
+--R
+--R   (2)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R       (- b x   - 5a b x   - 10a b x  - 10a b x  - 5a b x  - a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          18
+--R     18a x
+--R                                                    Type: Expression(Integer)
+--E 417
+
+--S 418 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5 15        4 12      2 3 9      3 2 6     4   3    5
+--R        - 6b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R   (3)  ---------------------------------------------------------
+--R                                     18
+--R                                  18x
+--R                                         Type: Union(Expression(Integer),...)
+--E 418
+
+--S 419 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R          18
+--R     18a x
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      19 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^20
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        20
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 2282
+r0:=-9/104*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^13+15/304*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^19-31/304*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^19-243/3952*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7+_
+   729/27664*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^7*(a+b*x^3))+_
+   81/1976*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^13
+--R 
+--R
+--R   (2)
+--R                5 15           4 12         2 3 9         3 2 6        4   3
+--R         - 6916b x   - 19760a b x   - 27664a b x  - 21280a b x  - 8645a b x
+--R       + 
+--R                5
+--R         - 1456a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             22           19
+--R     27664b x   + 27664a x
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          5 15           4 12         2 3 9         3 2 6        4   3        5
+--R   - 6916b x   - 19760a b x   - 27664a b x  - 21280a b x  - 8645a b x  - 1456a
+--R   ----------------------------------------------------------------------------
+--R                                           19
+--R                                     27664x
+--R                                         Type: Union(Expression(Integer),...)
+--E 423
+
+--S 424 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                5 15           4 12         2 3 9         3 2 6        4   3
+--R           6916b x   + 19760a b x   + 27664a b x  + 21280a b x  + 8645a b x
+--R         + 
+--R                5
+--R           1456a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R              6 18           5 15         2 4 12         3 3 9         4 2 6
+--R       - 6916b x   - 26676a b x   - 47424a b x   - 48944a b x  - 29925a b x
+--R     + 
+--R               5   3        6
+--R       - 10101a b x  - 1456a
+--R  /
+--R             22           19
+--R     27664b x   + 27664a x
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      20 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 425
+
+)clear all
+
+--S 426 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^21
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        21
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 2282
+r0:=-90/1309*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^14+3/68*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^20-8/85*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^20-243/6545*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8+_
+   729/52360*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^8*(a+b*x^3))+_
+   81/2618*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^14
+--R 
+--R
+--R   (2)
+--R                 5 15           4 12         2 3 9         3 2 6         4   3
+--R         - 10472b x   - 32725a b x   - 47600a b x  - 37400a b x  - 15400a b x
+--R       + 
+--R                5
+--R         - 2618a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             23           20
+--R     52360b x   + 52360a x
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               5 15           4 12         2 3 9         3 2 6         4   3
+--R       - 10472b x   - 32725a b x   - 47600a b x  - 37400a b x  - 15400a b x
+--R     + 
+--R              5
+--R       - 2618a
+--R  /
+--R           20
+--R     52360x
+--R                                         Type: Union(Expression(Integer),...)
+--E 428
+
+--S 429 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 15           4 12         2 3 9         3 2 6         4   3
+--R           10472b x   + 32725a b x   + 47600a b x  + 37400a b x  + 15400a b x
+--R         + 
+--R                5
+--R           2618a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               6 18           5 15         2 4 12         3 3 9         4 2 6
+--R       - 10472b x   - 43197a b x   - 80325a b x   - 85000a b x  - 52800a b x
+--R     + 
+--R               5   3        6
+--R       - 18018a b x  - 2618a
+--R  /
+--R             23           20
+--R     52360b x   + 52360a x
+--R                                                    Type: Expression(Integer)
+--E 429
+
+--S 430 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      21 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 430
+
+)clear all
+
+--S 431 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^22
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        22
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 2282
+r0:=-1/18*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(a*x^21)+_
+   1/126*(a^2+2*a*b*x^3+b^2*x^6)^(7/2)/(a^2*x^21)
+--R 
+--R
+--R   (2)
+--R         6 18      5 15      2 4 12      3 3 9      4 2 6      5   3     6
+--R       (b x   - a b x   - 20a b x   - 50a b x  - 55a b x  - 29a b x  - 6a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         2 21
+--R     126a x
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             5 15        4 12       2 3 9      3 2 6      4   3     5
+--R        - 21b x   - 70a b x   - 105a b x  - 84a b x  - 35a b x  - 6a
+--R   (3)  -------------------------------------------------------------
+--R                                        21
+--R                                    126x
+--R                                         Type: Union(Expression(Integer),...)
+--E 433
+
+--S 434 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             6 18      5 15      2 4 12      3 3 9      4 2 6      5   3     6
+--R         (- b x   + a b x   + 20a b x   + 50a b x  + 55a b x  + 29a b x  + 6a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            2 5 15      3 4 12       4 3 9      5 2 6      6   3     7
+--R       - 21a b x   - 70a b x   - 105a b x  - 84a b x  - 35a b x  - 6a
+--R  /
+--R         2 21
+--R     126a x
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      22 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^23
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        23
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 2282
+r0:=-45/988*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^16+15/418*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^22-17/209*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^22-1215/76076*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10+_
+   729/152152*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^10*(a+b*x^3))+_
+   405/21736*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^16
+--R 
+--R
+--R   (2)
+--R                 5 15           4 12          2 3 9         3 2 6         4   3
+--R         - 21736b x   - 76076a b x   - 117040a b x  - 95095a b x  - 40040a b x
+--R       + 
+--R                5
+--R         - 6916a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              25            22
+--R     152152b x   + 152152a x
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               5 15           4 12          2 3 9         3 2 6         4   3
+--R       - 21736b x   - 76076a b x   - 117040a b x  - 95095a b x  - 40040a b x
+--R     + 
+--R              5
+--R       - 6916a
+--R  /
+--R            22
+--R     152152x
+--R                                         Type: Union(Expression(Integer),...)
+--E 438
+
+--S 439 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 15           4 12          2 3 9         3 2 6         4   3
+--R           21736b x   + 76076a b x   + 117040a b x  + 95095a b x  + 40040a b x
+--R         + 
+--R                5
+--R           6916a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               6 18           5 15          2 4 12          3 3 9          4 2 6
+--R       - 21736b x   - 97812a b x   - 193116a b x   - 212135a b x  - 135135a b x
+--R     + 
+--R               5   3        6
+--R       - 46956a b x  - 6916a
+--R  /
+--R              25            22
+--R     152152b x   + 152152a x
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      23 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 440
+
+)clear all
+
+--S 441 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^24
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        24
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 2282
+r0:=-9/238*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^17+3/92*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^23-7/92*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^23-243/21896*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^11+_
+   729/240856*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^11*(a+b*x^3))+_
+   81/5474*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^17
+--R 
+--R
+--R   (2)
+--R                 5 15            4 12          2 3 9          3 2 6
+--R         - 30107b x   - 109480a b x   - 172040a b x  - 141680a b x
+--R       + 
+--R                 4   3         5
+--R         - 60214a b x  - 10472a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              26            23
+--R     240856b x   + 240856a x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               5 15            4 12          2 3 9          3 2 6         4   3
+--R       - 30107b x   - 109480a b x   - 172040a b x  - 141680a b x  - 60214a b x
+--R     + 
+--R               5
+--R       - 10472a
+--R  /
+--R            23
+--R     240856x
+--R                                         Type: Union(Expression(Integer),...)
+--E 443
+
+--S 444 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 15            4 12          2 3 9          3 2 6
+--R           30107b x   + 109480a b x   + 172040a b x  + 141680a b x
+--R         + 
+--R                 4   3         5
+--R           60214a b x  + 10472a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               6 18            5 15          2 4 12          3 3 9
+--R       - 30107b x   - 139587a b x   - 281520a b x   - 313720a b x
+--R     + 
+--R                4 2 6         5   3         6
+--R       - 201894a b x  - 70686a b x  - 10472a
+--R  /
+--R              26            23
+--R     240856b x   + 240856a x
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      24 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 445
+
+)clear all
+
+--S 446 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^25
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        25
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 2282
+r0:=-1/24*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(a*x^24)+_
+   1/72*b*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(a^2*x^21)-_
+   1/504*b*(a^2+2*a*b*x^3+b^2*x^6)^(7/2)/(a^3*x^21)
+--R 
+--R
+--R   (2)
+--R            7 21      6 18    2 5 15      3 4 12       4 3 9       5 2 6
+--R         - b x   + a b x   - a b x   - 55a b x   - 155a b x  - 181a b x
+--R       + 
+--R              6   3      7
+--R         - 99a b x  - 21a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         3 24
+--R     504a x
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             5 15         4 12       2 3 9       3 2 6       4   3      5
+--R        - 56b x   - 210a b x   - 336a b x  - 280a b x  - 120a b x  - 21a
+--R   (3)  -----------------------------------------------------------------
+--R                                          24
+--R                                      504x
+--R                                         Type: Union(Expression(Integer),...)
+--E 448
+
+--S 449 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            7 21      6 18    2 5 15      3 4 12       4 3 9       5 2 6
+--R           b x   - a b x   + a b x   + 55a b x   + 155a b x  + 181a b x
+--R         + 
+--R              6   3      7
+--R           99a b x  + 21a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            3 5 15       4 4 12       5 3 9       6 2 6       7   3      8
+--R       - 56a b x   - 210a b x   - 336a b x  - 280a b x  - 120a b x  - 21a
+--R  /
+--R         3 24
+--R     504a x
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R         (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          6 18       5 15      2 4 12      3 3 9      4 2 6     5   3    6
+--R       - b x   - 6a b x   - 15a b x   - 20a b x  - 15a b x  - 6a b x  - a
+--R  /
+--R         +-------------------+
+--R      25 | 2 6         3    2
+--R     x  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 2282
+t0:=x^m/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   m
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 2282
+--r0:=x^(1+m)*(a+b*x^3)*hypergeometric(1,1/3*(1+m),1/3*(4+m),_
+--   -b*x^3/a)/(a*(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--E 452
+
+--S 453 of 2282
+--a0:=integrate(t0,x)
+--E 453
+
+--S 454 of 2282
+--m0:=a0-r0
+--E 454
+
+--S 455 of 2282
+--d0:=normalize(D(m0,x))
+--E 455
+
+)clear all
+
+--S 456 of 2282
+t0:=x^4/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   4
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 2282
+r0:=1/2*x^2*(a+b*x^3)/(b*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   1/3*a^(2/3)*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(b^(5/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/6*a^(2/3)*(a+b*x^3)*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(b^(5/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   a^(2/3)*(a+b*x^3)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/_
+   (b^(5/3)*sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             3      +-+3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - a)\|3 \|a  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            3       +-+3+-+2     3+-+   3+-+
+--R       (2b x  + 2a)\|3 \|a  log(x\|b  + \|a )
+--R     + 
+--R                                 3+-+   3+-+
+--R              3      3+-+2     2x\|b  - \|a          5       2  +-+3+-+2
+--R       (- 6b x  - 6a)\|a  atan(-------------) + (3b x  + 3a x )\|3 \|b
+--R                                   +-+3+-+
+--R                                  \|3 \|a
+--R  /
+--R                 +-------------------+
+--R        +-+3+-+2 | 2 6         3    2
+--R     6b\|3 \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +--+       +--+2
+--R              | 2        | 2
+--R         +-+  |a         |a
+--R       2\|3   |-- log(b  |--   + a x)
+--R             3| 2       3| 2
+--R             \|b        \|b
+--R     + 
+--R               +--+           +--+2      +--+
+--R               | 2            | 2        | 2
+--R          +-+  |a             |a         |a       2
+--R       - \|3   |-- log(- b x  |--   + a  |-- + a x )
+--R              3| 2           3| 2       3| 2
+--R              \|b            \|b        \|b
+--R     + 
+--R                          +--+2
+--R                          | 2
+--R                     +-+  |a          +-+
+--R          +--+     b\|3   |--  - 2a x\|3
+--R          | 2            3| 2
+--R          |a             \|b                  2 +-+
+--R       6  |-- atan(---------------------- + 3x \|3
+--R         3| 2                 +--+2
+--R         \|b                  | 2
+--R                              |a
+--R                          3b  |--
+--R                             3| 2
+--R                             \|b
+--R  /
+--R        +-+
+--R     6b\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 458
+
+--S 459 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3      +-+3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + a)\|3 \|a  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              3       +-+3+-+2     3+-+   3+-+
+--R       (- 2b x  - 2a)\|3 \|a  log(x\|b  + \|a )
+--R     + 
+--R              +--+                                  +--+2
+--R              | 2       +-------------------+       | 2
+--R         +-+  |a  3+-+2 | 2 6         3    2        |a
+--R       2\|3   |-- \|b  \|b x  + 2a b x  + a  log(b  |--   + a x)
+--R             3| 2                                  3| 2
+--R             \|b                                   \|b
+--R     + 
+--R               +--+                                      +--+2      +--+
+--R               | 2       +-------------------+           | 2        | 2
+--R          +-+  |a  3+-+2 | 2 6         3    2            |a         |a       2
+--R       - \|3   |-- \|b  \|b x  + 2a b x  + a  log(- b x  |--   + a  |-- + a x )
+--R              3| 2                                      3| 2       3| 2
+--R              \|b                                       \|b        \|b
+--R     + 
+--R                               3+-+   3+-+
+--R            3      3+-+2     2x\|b  - \|a
+--R       (6b x  + 6a)\|a  atan(-------------)
+--R                                 +-+3+-+
+--R                                \|3 \|a
+--R     + 
+--R                                                     +--+2
+--R                                                     | 2
+--R                                                +-+  |a          +-+
+--R          +--+                                b\|3   |--  - 2a x\|3
+--R          | 2       +-------------------+           3| 2
+--R          |a  3+-+2 | 2 6         3    2            \|b
+--R       6  |-- \|b  \|b x  + 2a b x  + a  atan(----------------------)
+--R         3| 2                                            +--+2
+--R         \|b                                             | 2
+--R                                                         |a
+--R                                                     3b  |--
+--R                                                        3| 2
+--R                                                        \|b
+--R     + 
+--R                    +-------------------+
+--R         2 +-+3+-+2 | 2 6         3    2           5       2  +-+3+-+2
+--R       3x \|3 \|b  \|b x  + 2a b x  + a   + (- 3b x  - 3a x )\|3 \|b
+--R  /
+--R                 +-------------------+
+--R        +-+3+-+2 | 2 6         3    2
+--R     6b\|3 \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +-------------------+
+--R         4 | 2 6         3    2       7      4
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  --------------------------------------
+--R                      +-------------------+
+--R               3      | 2 6         3    2
+--R           (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 460
+
+)clear all
+
+--S 461 of 2282
+t0:=x^3/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   3
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 2282
+r0:=x*(a+b*x^3)/(b*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*a^(1/3)*(a+b*x^3)*_
+   log(a^(1/3)+b^(1/3)*x)/(b^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   1/6*a^(1/3)*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (b^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+a^(1/3)*(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(b^(4/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R           3      +-+3+-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + a)\|3 \|a log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              3       +-+3+-+     3+-+   3+-+
+--R       (- 2b x  - 2a)\|3 \|a log(x\|b  + \|a )
+--R     + 
+--R                                3+-+   3+-+
+--R              3      3+-+     2x\|b  - \|a          4         +-+3+-+
+--R       (- 6b x  - 6a)\|a atan(-------------) + (6b x  + 6a x)\|3 \|b
+--R                                  +-+3+-+
+--R                                 \|3 \|a
+--R  /
+--R                +-------------------+
+--R        +-+3+-+ | 2 6         3    2
+--R     6b\|3 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +---+     +---+2      +---+              +---+       +---+
+--R          +-+  |  a      |  a        |  a    2     +-+  |  a        |  a
+--R       - \|3  3|- - log(3|- -   + x 3|- - + x  + 2\|3  3|- - log(- 3|- -  + x)
+--R              \|  b     \|  b       \|  b              \|  b       \|  b
+--R     + 
+--R                            +---+
+--R                       +-+  |  a      +-+
+--R            +---+     \|3  3|- - + 2x\|3
+--R            |  a           \|  b               +-+
+--R       - 6 3|- - atan(------------------- + 6x\|3
+--R           \|  b               +---+
+--R                               |  a
+--R                            3 3|- -
+--R                              \|  b
+--R  /
+--R        +-+
+--R     6b\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 463
+
+--S 464 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3      +-+3+-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - a)\|3 \|a log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            3       +-+3+-+     3+-+   3+-+
+--R       (2b x  + 2a)\|3 \|a log(x\|b  + \|a )
+--R     + 
+--R               +---+     +-------------------+     +---+2      +---+
+--R          +-+  |  a 3+-+ | 2 6         3    2      |  a        |  a    2
+--R       - \|3  3|- - \|b \|b x  + 2a b x  + a  log(3|- -   + x 3|- - + x )
+--R              \|  b                               \|  b       \|  b
+--R     + 
+--R              +---+     +-------------------+       +---+
+--R         +-+  |  a 3+-+ | 2 6         3    2        |  a
+--R       2\|3  3|- - \|b \|b x  + 2a b x  + a  log(- 3|- -  + x)
+--R             \|  b                                 \|  b
+--R     + 
+--R                              3+-+   3+-+
+--R            3      3+-+     2x\|b  - \|a
+--R       (6b x  + 6a)\|a atan(-------------)
+--R                                +-+3+-+
+--R                               \|3 \|a
+--R     + 
+--R                                                      +---+
+--R                                                 +-+  |  a      +-+
+--R            +---+     +-------------------+     \|3  3|- - + 2x\|3
+--R            |  a 3+-+ | 2 6         3    2           \|  b
+--R       - 6 3|- - \|b \|b x  + 2a b x  + a  atan(-------------------)
+--R           \|  b                                         +---+
+--R                                                         |  a
+--R                                                      3 3|- -
+--R                                                        \|  b
+--R     + 
+--R                  +-------------------+
+--R          +-+3+-+ | 2 6         3    2           4         +-+3+-+
+--R       6x\|3 \|b \|b x  + 2a b x  + a   + (- 6b x  - 6a x)\|3 \|b
+--R  /
+--R                +-------------------+
+--R        +-+3+-+ | 2 6         3    2
+--R     6b\|3 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +-------------------+
+--R         3 | 2 6         3    2       6      3
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  --------------------------------------
+--R                      +-------------------+
+--R               3      | 2 6         3    2
+--R           (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 2282
+t0:=x^2/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   2
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 2282
+r0:=1/3*(a+b*x^3)*log(a+b*x^3)/(b*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R             3            3
+--R         (b x  + a)log(b x  + a)
+--R   (2)  ------------------------
+--R           +-------------------+
+--R           | 2 6         3    2
+--R        3b\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3
+--R        log(b x  + a)
+--R   (3)  -------------
+--R              3b
+--R                                         Type: Union(Expression(Integer),...)
+--E 468
+
+--S 469 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                      +-------------------+
+--R               3      | 2 6         3    2          3            3
+--R        log(b x  + a)\|b x  + 2a b x  + a   + (- b x  - a)log(b x  + a)
+--R   (4)  ---------------------------------------------------------------
+--R                               +-------------------+
+--R                               | 2 6         3    2
+--R                            3b\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +-------------------+
+--R         2 | 2 6         3    2       5      2
+--R        x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  --------------------------------------
+--R                      +-------------------+
+--R               3      | 2 6         3    2
+--R           (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 470
+
+)clear all
+
+--S 471 of 2282
+t0:=x/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 2282
+r0:=-1/3*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(1/3)*b^(2/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/6*(a+b*x^3)*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(1/3)*b^(2/3)*sqrt(a^2+_
+   2*a*b*x^3+b^2*x^6))-(a+b*x^3)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(1/3)*b^(2/3)*sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R           3      +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + a)\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                                                                3+-+   3+-+
+--R              3       +-+     3+-+   3+-+         3           2x\|b  - \|a
+--R       (- 2b x  - 2a)\|3 log(x\|b  + \|a ) + (6b x  + 6a)atan(-------------)
+--R                                                                  +-+3+-+
+--R                                                                 \|3 \|a
+--R  /
+--R                    +-------------------+
+--R       +-+3+-+3+-+2 | 2 6         3    2
+--R     6\|3 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +------+2         +------+
+--R          +-+      3|     2        2 3|     2
+--R       - \|3 log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R                                                   +------+2
+--R                   +------+2                   +-+3|     2         +-+
+--R         +-+      3|     2                  2x\|3 \|- a b    - a b\|3
+--R       2\|3 log(x \|- a b    + a b) - 6atan(--------------------------)
+--R                                                       3a b
+--R  /
+--R           +------+
+--R       +-+3|     2
+--R     6\|3 \|- a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 473
+
+--S 474 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        +------+
+--R             3      +-+3|     2      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - a)\|3 \|- a b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                        +------+
+--R            3       +-+3|     2      3+-+   3+-+
+--R       (2b x  + 2a)\|3 \|- a b  log(x\|b  + \|a )
+--R     + 
+--R       -
+--R                          +-------------------+
+--R             +-+3+-+3+-+2 | 2 6         3    2
+--R            \|3 \|a \|b  \|b x  + 2a b x  + a
+--R         *
+--R                   +------+2         +------+
+--R                  3|     2        2 3|     2
+--R            log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R                      +-------------------+       +------+2
+--R         +-+3+-+3+-+2 | 2 6         3    2       3|     2
+--R       2\|3 \|a \|b  \|b x  + 2a b x  + a  log(x \|- a b    + a b)
+--R     + 
+--R                      +------+       3+-+   3+-+
+--R              3      3|     2      2x\|b  - \|a
+--R       (- 6b x  - 6a)\|- a b  atan(-------------)
+--R                                       +-+3+-+
+--R                                      \|3 \|a
+--R     + 
+--R                                                     +------+2
+--R                    +-------------------+        +-+3|     2         +-+
+--R          3+-+3+-+2 | 2 6         3    2      2x\|3 \|- a b    - a b\|3
+--R       - 6\|a \|b  \|b x  + 2a b x  + a  atan(--------------------------)
+--R                                                         3a b
+--R  /
+--R           +------+          +-------------------+
+--R       +-+3|     2 3+-+3+-+2 | 2 6         3    2
+--R     6\|3 \|- a b  \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 474
+
+--S 475 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          +-------------------+
+--R          | 2 6         3    2       4
+--R        x\|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  ------------------------------------
+--R                     +-------------------+
+--R              3      | 2 6         3    2
+--R          (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 475
+
+)clear all
+
+--S 476 of 2282
+t0:=1/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 2282
+r0:=1/3*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*b^(1/3)*sqrt(a^2+_
+   2*a*b*x^3+b^2*x^6))-1/6*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+_
+   b^(2/3)*x^2)/(a^(2/3)*b^(1/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(1/3)*_
+   sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             3      +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - a)\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                                                              3+-+   3+-+
+--R            3       +-+     3+-+   3+-+         3           2x\|b  - \|a
+--R       (2b x  + 2a)\|3 log(x\|b  + \|a ) + (6b x  + 6a)atan(-------------)
+--R                                                                +-+3+-+
+--R                                                               \|3 \|a
+--R  /
+--R                     +-------------------+
+--R       +-+3+-+2 3+-+ | 2 6         3    2
+--R     6\|3 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +---+2      +---+                    +---+
+--R          +-+     2 3| 2        3| 2      2      +-+     3| 2
+--R       - \|3 log(x  \|a b  - a x\|a b  + a ) + 2\|3 log(x\|a b  + a)
+--R     + 
+--R                    +---+
+--R                +-+3| 2       +-+
+--R             2x\|3 \|a b  - a\|3
+--R       6atan(--------------------)
+--R                      3a
+--R  /
+--R           +---+
+--R       +-+3| 2
+--R     6\|3 \|a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 478
+
+--S 479 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        +-------------------+        +---+2      +---+
+--R          +-+3+-+2 3+-+ | 2 6         3    2      2 3| 2        3| 2      2
+--R       - \|3 \|a   \|b \|b x  + 2a b x  + a  log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R                       +-------------------+      +---+
+--R         +-+3+-+2 3+-+ | 2 6         3    2      3| 2
+--R       2\|3 \|a   \|b \|b x  + 2a b x  + a  log(x\|a b  + a)
+--R     + 
+--R                      +---+
+--R           3      +-+3| 2       2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + a)\|3 \|a b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                          +---+
+--R              3       +-+3| 2       3+-+   3+-+
+--R       (- 2b x  - 2a)\|3 \|a b log(x\|b  + \|a )
+--R     + 
+--R                                                    +---+
+--R                   +-------------------+        +-+3| 2       +-+
+--R        3+-+2 3+-+ | 2 6         3    2      2x\|3 \|a b  - a\|3
+--R       6\|a   \|b \|b x  + 2a b x  + a  atan(--------------------)
+--R                                                      3a
+--R     + 
+--R                      +---+       3+-+   3+-+
+--R              3      3| 2       2x\|b  - \|a
+--R       (- 6b x  - 6a)\|a b atan(-------------)
+--R                                    +-+3+-+
+--R                                   \|3 \|a
+--R  /
+--R                     +---+ +-------------------+
+--R       +-+3+-+2 3+-+3| 2   | 2 6         3    2
+--R     6\|3 \|a   \|b \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2       3
+--R        \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ---------------------------------
+--R                    +-------------------+
+--R             3      | 2 6         3    2
+--R         (b x  + a)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 2282
+t0:=1/(x*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R          +-------------------+
+--R          | 2 6         3    2
+--R        x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 2282
+r0:=(a+b*x^3)*log(x)/(a*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*(a+b*x^3)*_
+   log(a+b*x^3)/(a*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R              3            3             3
+--R        (- b x  - a)log(b x  + a) + (3b x  + 3a)log(x)
+--R   (2)  ----------------------------------------------
+--R                      +-------------------+
+--R                      | 2 6         3    2
+--R                   3a\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 3
+--R        - log(b x  + a) + 3log(x)
+--R   (3)  -------------------------
+--R                    3a
+--R                                         Type: Union(Expression(Integer),...)
+--E 483
+
+--S 484 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   +-------------------+
+--R                 3                 | 2 6         3    2
+--R       (- log(b x  + a) + 3log(x))\|b x  + 2a b x  + a
+--R     + 
+--R           3            3               3
+--R       (b x  + a)log(b x  + a) + (- 3b x  - 3a)log(x)
+--R  /
+--R        +-------------------+
+--R        | 2 6         3    2
+--R     3a\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          +-------------------+
+--R          | 2 6         3    2       3
+--R         \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ----------------------------------
+--R                     +-------------------+
+--R            4        | 2 6         3    2
+--R        (b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 485
+
+)clear all
+
+--S 486 of 2282
+t0:=1/(x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         2 | 2 6         3    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 2282
+r0:=(-a-b*x^3)/(a*x*sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/3*b^(1/3)*(a+b*x^3)*_
+   log(a^(1/3)+b^(1/3)*x)/(a^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   1/6*b^(1/3)*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+b^(1/3)*(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(4/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             4        +-+3+-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - a x)\|3 \|b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            4         +-+3+-+     3+-+   3+-+
+--R       (2b x  + 2a x)\|3 \|b log(x\|b  + \|a )
+--R     + 
+--R                                  3+-+   3+-+
+--R              4        3+-+     2x\|b  - \|a            3       +-+3+-+
+--R       (- 6b x  - 6a x)\|b atan(-------------) + (- 6b x  - 6a)\|3 \|a
+--R                                    +-+3+-+
+--R                                   \|3 \|a
+--R  /
+--R                  +-------------------+
+--R          +-+3+-+ | 2 6         3    2
+--R     6a x\|3 \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +-+       +-+2                +-+           +-+2      +-+
+--R          +-+  |b        |b             +-+  |b            |b        |b      2
+--R       2x\|3  3|- log(a 3|-   + b x - x\|3  3|- log(- a x 3|-   + a 3|- + b x )
+--R              \|a       \|a                 \|a           \|a       \|a
+--R     + 
+--R                          +-+2
+--R                     +-+  |b         +-+
+--R           +-+     a\|3  3|-  - 2b x\|3
+--R           |b            \|a                 +-+
+--R       6x 3|- atan(--------------------- - 6\|3
+--R          \|a                 +-+2
+--R                              |b
+--R                          3a 3|-
+--R                             \|a
+--R  /
+--R          +-+
+--R     6a x\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 488
+
+--S 489 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           4        +-+3+-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + a x)\|3 \|b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              4         +-+3+-+     3+-+   3+-+
+--R       (- 2b x  - 2a x)\|3 \|b log(x\|b  + \|a )
+--R     + 
+--R                   +-+ +-------------------+       +-+2
+--R          +-+3+-+  |b  | 2 6         3    2        |b
+--R       2x\|3 \|a  3|- \|b x  + 2a b x  + a  log(a 3|-   + b x)
+--R                  \|a                             \|a
+--R     + 
+--R                    +-+ +-------------------+           +-+2      +-+
+--R           +-+3+-+  |b  | 2 6         3    2            |b        |b      2
+--R       - x\|3 \|a  3|- \|b x  + 2a b x  + a  log(- a x 3|-   + a 3|- + b x )
+--R                   \|a                                 \|a       \|a
+--R     + 
+--R                                3+-+   3+-+
+--R            4        3+-+     2x\|b  - \|a
+--R       (6b x  + 6a x)\|b atan(-------------)
+--R                                  +-+3+-+
+--R                                 \|3 \|a
+--R     + 
+--R                                                    +-+2
+--R                                               +-+  |b         +-+
+--R               +-+ +-------------------+     a\|3  3|-  - 2b x\|3
+--R         3+-+  |b  | 2 6         3    2            \|a
+--R       6x\|a  3|- \|b x  + 2a b x  + a  atan(---------------------)
+--R              \|a                                       +-+2
+--R                                                        |b
+--R                                                    3a 3|-
+--R                                                       \|a
+--R     + 
+--R                   +-------------------+
+--R           +-+3+-+ | 2 6         3    2         3       +-+3+-+
+--R       - 6\|3 \|a \|b x  + 2a b x  + a   + (6b x  + 6a)\|3 \|a
+--R  /
+--R                  +-------------------+
+--R          +-+3+-+ | 2 6         3    2
+--R     6a x\|3 \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          +-------------------+
+--R          | 2 6         3    2       3
+--R         \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -----------------------------------
+--R                      +-------------------+
+--R            5      2  | 2 6         3    2
+--R        (b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 490
+
+)clear all
+
+--S 491 of 2282
+t0:=1/(x^3*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         3 | 2 6         3    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 2282
+r0:=1/2*(-a-b*x^3)/(a*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*b^(2/3)*_
+   (a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(5/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   1/6*b^(2/3)*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(5/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+b^(2/3)*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(5/3)*sqrt(3)*sqrt(a^2+_
+   2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R           5      2  +-+3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + a x )\|3 \|b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              5       2  +-+3+-+2     3+-+   3+-+
+--R       (- 2b x  - 2a x )\|3 \|b  log(x\|b  + \|a )
+--R     + 
+--R                                    3+-+   3+-+
+--R              5       2 3+-+2     2x\|b  - \|a            3       +-+3+-+2
+--R       (- 6b x  - 6a x )\|b  atan(-------------) + (- 3b x  - 3a)\|3 \|a
+--R                                      +-+3+-+
+--R                                     \|3 \|a
+--R  /
+--R                    +-------------------+
+--R         2 +-+3+-+2 | 2 6         3    2
+--R     6a x \|3 \|a  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 492
+
+--S 493 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 +----+        +----+2         +----+
+--R                 |   2         |   2           |   2
+--R          2 +-+  |  b       2  |  b            |  b     2 2
+--R       - x \|3   |- -- log(a   |- --  + a b x  |- -- + b x )
+--R                3|   2        3|   2          3|   2
+--R                \|  a         \|  a           \|  a
+--R     + 
+--R                +----+         +----+
+--R                |   2          |   2
+--R         2 +-+  |  b           |  b
+--R       2x \|3   |- -- log(- a  |- -- + b x)
+--R               3|   2         3|   2
+--R               \|  a          \|  a
+--R     + 
+--R                                +----+
+--R                                |   2
+--R                           +-+  |  b         +-+
+--R              +----+     a\|3   |- -- + 2b x\|3
+--R              |   2            3|   2
+--R           2  |  b             \|  a                 +-+
+--R       - 6x   |- -- atan(----------------------- - 3\|3
+--R             3|   2                 +----+
+--R             \|  a                  |   2
+--R                                    |  b
+--R                                3a  |- --
+--R                                   3|   2
+--R                                   \|  a
+--R  /
+--R         2 +-+
+--R     6a x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 493
+
+--S 494 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             5      2  +-+3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - a x )\|3 \|b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            5       2  +-+3+-+2     3+-+   3+-+
+--R       (2b x  + 2a x )\|3 \|b  log(x\|b  + \|a )
+--R     + 
+--R       -
+--R                    +----+
+--R                    |   2       +-------------------+
+--R             2 +-+  |  b  3+-+2 | 2 6         3    2
+--R            x \|3   |- -- \|a  \|b x  + 2a b x  + a
+--R                   3|   2
+--R                   \|  a
+--R         *
+--R                    +----+2         +----+
+--R                    |   2           |   2
+--R                 2  |  b            |  b     2 2
+--R            log(a   |- --  + a b x  |- -- + b x )
+--R                   3|   2          3|   2
+--R                   \|  a           \|  a
+--R     + 
+--R                +----+                                    +----+
+--R                |   2       +-------------------+         |   2
+--R         2 +-+  |  b  3+-+2 | 2 6         3    2          |  b
+--R       2x \|3   |- -- \|a  \|b x  + 2a b x  + a  log(- a  |- -- + b x)
+--R               3|   2                                    3|   2
+--R               \|  a                                     \|  a
+--R     + 
+--R                                  3+-+   3+-+
+--R            5       2 3+-+2     2x\|b  - \|a
+--R       (6b x  + 6a x )\|b  atan(-------------)
+--R                                    +-+3+-+
+--R                                   \|3 \|a
+--R     + 
+--R                                                           +----+
+--R                                                           |   2
+--R                                                      +-+  |  b         +-+
+--R              +----+                                a\|3   |- -- + 2b x\|3
+--R              |   2       +-------------------+           3|   2
+--R           2  |  b  3+-+2 | 2 6         3    2            \|  a
+--R       - 6x   |- -- \|a  \|b x  + 2a b x  + a  atan(-----------------------)
+--R             3|   2                                            +----+
+--R             \|  a                                             |   2
+--R                                                               |  b
+--R                                                           3a  |- --
+--R                                                              3|   2
+--R                                                              \|  a
+--R     + 
+--R                    +-------------------+
+--R           +-+3+-+2 | 2 6         3    2         3       +-+3+-+2
+--R       - 3\|3 \|a  \|b x  + 2a b x  + a   + (3b x  + 3a)\|3 \|a
+--R  /
+--R                    +-------------------+
+--R         2 +-+3+-+2 | 2 6         3    2
+--R     6a x \|3 \|a  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          +-------------------+
+--R          | 2 6         3    2       3
+--R         \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -----------------------------------
+--R                      +-------------------+
+--R            6      3  | 2 6         3    2
+--R        (b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 2282
+t0:=1/(x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         4 | 2 6         3    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 2282
+r0:=-b*(a+b*x^3)*log(x)/(a^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/3*b*(a+b*x^3)*_
+   log(a+b*x^3)/(a^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a^2*x^3)
+--R 
+--R
+--R   (2)
+--R         2 6        3        3             2 6         3           2 6         3
+--R       (b x  + a b x )log(b x  + a) + (- 3b x  - 3a b x )log(x) - b x  - 2a b x
+--R     + 
+--R          2
+--R       - a
+--R  /
+--R           +-------------------+
+--R       2 3 | 2 6         3    2
+--R     3a x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3       3            3
+--R        b x log(b x  + a) - 3b x log(x) - a
+--R   (3)  -----------------------------------
+--R                         2 3
+--R                       3a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 498
+
+--S 499 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +-------------------+
+--R           3       3            3            | 2 6         3    2
+--R       (b x log(b x  + a) - 3b x log(x) - a)\|b x  + 2a b x  + a
+--R     + 
+--R           2 6        3        3           2 6         3           2 6         3
+--R       (- b x  - a b x )log(b x  + a) + (3b x  + 3a b x )log(x) + b x  + 2a b x
+--R     + 
+--R        2
+--R       a
+--R  /
+--R           +-------------------+
+--R       2 3 | 2 6         3    2
+--R     3a x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          +-------------------+
+--R          | 2 6         3    2       3
+--R         \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -----------------------------------
+--R                      +-------------------+
+--R            7      4  | 2 6         3    2
+--R        (b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 500
+
+)clear all
+
+--S 501 of 2282
+t0:=x^m/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                              m
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 2282
+--r0:=1/6*x^(1+m)*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+_
+--   1/18*(5-m)*x^(1+m)/(a^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+--   1/18*(2-m)*(5-m)*x^(1+m)*(a+b*x^3)*hypergeometric(1,1/3*(1+m),_
+--   1/3*(4+m),-b*x^3/a)/(a^3*(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--E 502
+
+--S 503 of 2282
+--a0:=integrate(t0,x)
+--E 503
+
+--S 504 of 2282
+--m0:=a0-r0
+--E 504
+
+--S 505 of 2282
+--d0:=normalize(D(m0,x))
+--E 505
+
+)clear all
+
+--S 506 of 2282
+t0:=x^4/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                              4
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 2282
+r0:=1/6*x^5*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))-1/18*x^2/_
+   (a*b*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/27*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/_
+   (a^(4/3)*b^(5/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/54*(a+b*x^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(4/3)*b^(5/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/9*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(4/3)*b^(5/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R         2 6         3    2  +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + 2a b x  + a )\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            2 6         3     2  +-+     3+-+   3+-+
+--R       (- 2b x  - 4a b x  - 2a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                    3+-+   3+-+
+--R        2 6          3     2      2x\|b  - \|a          5       2  +-+3+-+3+-+2
+--R     (6b x  + 12a b x  + 6a )atan(-------------) + (6b x  - 3a x )\|3 \|a \|b
+--R                                      +-+3+-+
+--R                                     \|3 \|a
+--R  /
+--R                                     +-------------------+
+--R           2 3      2   +-+3+-+3+-+2 | 2 6         3    2
+--R     (54a b x  + 54a b)\|3 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         +------+2         +------+
+--R           2 6         3    2  +-+      3|     2        2 3|     2
+--R       (- b x  - 2a b x  - a )\|3 log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R                                         +------+2
+--R          2 6         3     2  +-+      3|     2
+--R       (2b x  + 4a b x  + 2a )\|3 log(x \|- a b    + a b)
+--R     + 
+--R                                             +------+2
+--R                                         +-+3|     2         +-+
+--R            2 6          3     2      2x\|3 \|- a b    - a b\|3
+--R       (- 6b x  - 12a b x  - 6a )atan(--------------------------)
+--R                                                 3a b
+--R     + 
+--R                           +------+
+--R            5       2  +-+3|     2
+--R       (6b x  - 3a x )\|3 \|- a b
+--R  /
+--R                                        +------+
+--R           3 6       2 2 3      3   +-+3|     2
+--R     (54a b x  + 108a b x  + 54a b)\|3 \|- a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 508
+
+--S 509 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +------+
+--R             3 9       2 6     2   3    3  +-+3|     2
+--R         (- b x  - 3a b x  - 3a b x  - a )\|3 \|- a b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                                             +------+
+--R          3 9       2 6     2   3     3  +-+3|     2      3+-+   3+-+
+--R       (2b x  + 6a b x  + 6a b x  + 2a )\|3 \|- a b  log(x\|b  + \|a )
+--R     + 
+--R                                              +-------------------+
+--R             2 6         3    2  +-+3+-+3+-+2 | 2 6         3    2
+--R         (- b x  - 2a b x  - a )\|3 \|a \|b  \|b x  + 2a b x  + a
+--R      *
+--R                +------+2         +------+
+--R               3|     2        2 3|     2
+--R         log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R                                              +-------------------+
+--R            2 6         3     2  +-+3+-+3+-+2 | 2 6         3    2
+--R         (2b x  + 4a b x  + 2a )\|3 \|a \|b  \|b x  + 2a b x  + a
+--R      *
+--R                +------+2
+--R               3|     2
+--R         log(x \|- a b    + a b)
+--R     + 
+--R                                             +------+       3+-+   3+-+
+--R            3 9        2 6      2   3     3 3|     2      2x\|b  - \|a
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )\|- a b  atan(-------------)
+--R                                                              +-+3+-+
+--R                                                             \|3 \|a
+--R     + 
+--R                                             +-------------------+
+--R              2 6          3     2 3+-+3+-+2 | 2 6         3    2
+--R         (- 6b x  - 12a b x  - 6a )\|a \|b  \|b x  + 2a b x  + a
+--R      *
+--R                     +------+2
+--R                 +-+3|     2         +-+
+--R              2x\|3 \|- a b    - a b\|3
+--R         atan(--------------------------)
+--R                         3a b
+--R     + 
+--R                           +------+          +-------------------+
+--R            5       2  +-+3|     2 3+-+3+-+2 | 2 6         3    2
+--R       (6b x  - 3a x )\|3 \|- a b  \|a \|b  \|b x  + 2a b x  + a
+--R     + 
+--R                                       +------+
+--R            2 8         5     2 2  +-+3|     2 3+-+3+-+2
+--R       (- 6b x  - 3a b x  + 3a x )\|3 \|- a b  \|a \|b
+--R  /
+--R                                        +------+          +-------------------+
+--R           3 6       2 2 3      3   +-+3|     2 3+-+3+-+2 | 2 6         3    2
+--R     (54a b x  + 108a b x  + 54a b)\|3 \|- a b  \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R                 4 | 2 6         3    2       7      4
+--R                x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 9       2 6     2   3    3  | 2 6         3    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 2282
+t0:=x^3/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                              3
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 2282
+r0:=1/6*x^4*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))-_
+   1/9*x/(a*b*sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/27*(a+b*x^3)*log(a^(1/3)+_
+   b^(1/3)*x)/(a^(5/3)*b^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   1/54*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(5/3)*b^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/9*(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(5/3)*b^(4/3)*_
+   sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R           2 6         3    2  +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - 2a b x  - a )\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R          2 6         3     2  +-+     3+-+   3+-+
+--R       (2b x  + 4a b x  + 2a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                    3+-+   3+-+
+--R        2 6          3     2      2x\|b  - \|a          4         +-+3+-+2 3+-+
+--R     (6b x  + 12a b x  + 6a )atan(-------------) + (3b x  - 6a x)\|3 \|a   \|b
+--R                                      +-+3+-+
+--R                                     \|3 \|a
+--R  /
+--R                                      +-------------------+
+--R           2 3      2   +-+3+-+2 3+-+ | 2 6         3    2
+--R     (54a b x  + 54a b)\|3 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                          +---+2      +---+
+--R           2 6         3    2  +-+     2 3| 2        3| 2      2
+--R       (- b x  - 2a b x  - a )\|3 log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R                                        +---+
+--R          2 6         3     2  +-+     3| 2
+--R       (2b x  + 4a b x  + 2a )\|3 log(x\|a b  + a)
+--R     + 
+--R                                           +---+
+--R                                       +-+3| 2       +-+
+--R          2 6          3     2      2x\|3 \|a b  - a\|3
+--R       (6b x  + 12a b x  + 6a )atan(--------------------)
+--R                                             3a
+--R     + 
+--R                          +---+
+--R            4         +-+3| 2
+--R       (3b x  - 6a x)\|3 \|a b
+--R  /
+--R                                        +---+
+--R           3 6       2 2 3      3   +-+3| 2
+--R     (54a b x  + 108a b x  + 54a b)\|3 \|a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 513
+
+--S 514 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +-------------------+
+--R             2 6         3    2  +-+3+-+2 3+-+ | 2 6         3    2
+--R         (- b x  - 2a b x  - a )\|3 \|a   \|b \|b x  + 2a b x  + a
+--R      *
+--R                 +---+2      +---+
+--R              2 3| 2        3| 2      2
+--R         log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R                                               +-------------------+
+--R            2 6         3     2  +-+3+-+2 3+-+ | 2 6         3    2
+--R         (2b x  + 4a b x  + 2a )\|3 \|a   \|b \|b x  + 2a b x  + a
+--R      *
+--R               +---+
+--R              3| 2
+--R         log(x\|a b  + a)
+--R     + 
+--R                                           +---+
+--R         3 9       2 6     2   3    3  +-+3| 2       2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + 3a b x  + 3a b x  + a )\|3 \|a b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                                               +---+
+--R            3 9       2 6     2   3     3  +-+3| 2       3+-+   3+-+
+--R       (- 2b x  - 6a b x  - 6a b x  - 2a )\|3 \|a b log(x\|b  + \|a )
+--R     + 
+--R                                            +-------------------+
+--R            2 6          3     2 3+-+2 3+-+ | 2 6         3    2
+--R         (6b x  + 12a b x  + 6a )\|a   \|b \|b x  + 2a b x  + a
+--R      *
+--R                     +---+
+--R                 +-+3| 2       +-+
+--R              2x\|3 \|a b  - a\|3
+--R         atan(--------------------)
+--R                       3a
+--R     + 
+--R                                             +---+       3+-+   3+-+
+--R            3 9        2 6      2   3     3 3| 2       2x\|b  - \|a
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )\|a b atan(-------------)
+--R                                                           +-+3+-+
+--R                                                          \|3 \|a
+--R     + 
+--R                                    +---+ +-------------------+
+--R            4         +-+3+-+2 3+-+3| 2   | 2 6         3    2
+--R       (3b x  - 6a x)\|3 \|a   \|b \|a b \|b x  + 2a b x  + a
+--R     + 
+--R                                                +---+
+--R            2 7         4     2   +-+3+-+2 3+-+3| 2
+--R       (- 3b x  + 3a b x  + 6a x)\|3 \|a   \|b \|a b
+--R  /
+--R                                                  +---+ +-------------------+
+--R           3 6       2 2 3      3   +-+3+-+2 3+-+3| 2   | 2 6         3    2
+--R     (54a b x  + 108a b x  + 54a b)\|3 \|a   \|b \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R                 3 | 2 6         3    2       6      3
+--R                x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 9       2 6     2   3    3  | 2 6         3    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 515
+
+)clear all
+
+--S 516 of 2282
+t0:=x^2/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                              2
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 2282
+r0:=1/6*(-a-b*x^3)/(b*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                            1
+--R   (2)  - ------------------------------------
+--R                         +-------------------+
+--R             2 3         | 2 6         3    2
+--R          (6b x  + 6a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     1
+--R   (3)  - -----------------------
+--R            3 6        2 3     2
+--R          6b x  + 12a b x  + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 518
+
+--S 519 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                 +-------------------+
+--R                 | 2 6         3    2       3
+--R              - \|b x  + 2a b x  + a   + b x  + a
+--R   (4)  -----------------------------------------------
+--R                                  +-------------------+
+--R           3 6        2 3     2   | 2 6         3    2
+--R        (6b x  + 12a b x  + 6a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R                 2 | 2 6         3    2       5      2
+--R                x \|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 9       2 6     2   3    3  | 2 6         3    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 520
+
+)clear all
+
+--S 521 of 2282
+t0:=x/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 2282
+r0:=1/6*x^2*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+2/9*x^2/(a^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-2/27*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/_
+   (a^(7/3)*b^(2/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/27*(a+b*x^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(7/3)*b^(2/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-2/9*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(7/3)*b^(2/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R          2 6         3     2  +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (2b x  + 4a b x  + 2a )\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            2 6         3     2  +-+     3+-+   3+-+
+--R       (- 4b x  - 8a b x  - 4a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                        3+-+   3+-+
+--R           2 6          3      2      2x\|b  - \|a
+--R       (12b x  + 24a b x  + 12a )atan(-------------)
+--R                                          +-+3+-+
+--R                                         \|3 \|a
+--R     + 
+--R             5        2  +-+3+-+3+-+2
+--R       (12b x  + 21a x )\|3 \|a \|b
+--R  /
+--R                                    +-------------------+
+--R         2   3      3  +-+3+-+3+-+2 | 2 6         3    2
+--R     (54a b x  + 54a )\|3 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                           +------+2         +------+
+--R            2 6         3     2  +-+      3|     2        2 3|     2
+--R       (- 2b x  - 4a b x  - 2a )\|3 log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R                                         +------+2
+--R          2 6         3     2  +-+      3|     2
+--R       (4b x  + 8a b x  + 4a )\|3 log(x \|- a b    + a b)
+--R     + 
+--R                                               +------+2
+--R                                           +-+3|     2         +-+
+--R             2 6          3      2      2x\|3 \|- a b    - a b\|3
+--R       (- 12b x  - 24a b x  - 12a )atan(--------------------------)
+--R                                                   3a b
+--R     + 
+--R                             +------+
+--R             5        2  +-+3|     2
+--R       (12b x  + 21a x )\|3 \|- a b
+--R  /
+--R                                       +------+
+--R         2 2 6       3   3      4  +-+3|     2
+--R     (54a b x  + 108a b x  + 54a )\|3 \|- a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 523
+
+--S 524 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +------+
+--R              3 9       2 6     2   3     3  +-+3|     2
+--R         (- 2b x  - 6a b x  - 6a b x  - 2a )\|3 \|- a b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                                               +------+
+--R          3 9        2 6      2   3     3  +-+3|     2      3+-+   3+-+
+--R       (4b x  + 12a b x  + 12a b x  + 4a )\|3 \|- a b  log(x\|b  + \|a )
+--R     + 
+--R                                                +-------------------+
+--R              2 6         3     2  +-+3+-+3+-+2 | 2 6         3    2
+--R         (- 2b x  - 4a b x  - 2a )\|3 \|a \|b  \|b x  + 2a b x  + a
+--R      *
+--R                +------+2         +------+
+--R               3|     2        2 3|     2
+--R         log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R                                              +-------------------+
+--R            2 6         3     2  +-+3+-+3+-+2 | 2 6         3    2
+--R         (4b x  + 8a b x  + 4a )\|3 \|a \|b  \|b x  + 2a b x  + a
+--R      *
+--R                +------+2
+--R               3|     2
+--R         log(x \|- a b    + a b)
+--R     + 
+--R                                               +------+       3+-+   3+-+
+--R             3 9        2 6      2   3      3 3|     2      2x\|b  - \|a
+--R       (- 12b x  - 36a b x  - 36a b x  - 12a )\|- a b  atan(-------------)
+--R                                                                +-+3+-+
+--R                                                               \|3 \|a
+--R     + 
+--R                                               +-------------------+
+--R               2 6          3      2 3+-+3+-+2 | 2 6         3    2
+--R         (- 12b x  - 24a b x  - 12a )\|a \|b  \|b x  + 2a b x  + a
+--R      *
+--R                     +------+2
+--R                 +-+3|     2         +-+
+--R              2x\|3 \|- a b    - a b\|3
+--R         atan(--------------------------)
+--R                         3a b
+--R     + 
+--R                             +------+          +-------------------+
+--R             5        2  +-+3|     2 3+-+3+-+2 | 2 6         3    2
+--R       (12b x  + 21a x )\|3 \|- a b  \|a \|b  \|b x  + 2a b x  + a
+--R     + 
+--R                                          +------+
+--R             2 8          5      2 2  +-+3|     2 3+-+3+-+2
+--R       (- 12b x  - 33a b x  - 21a x )\|3 \|- a b  \|a \|b
+--R  /
+--R                                       +------+          +-------------------+
+--R         2 2 6       3   3      4  +-+3|     2 3+-+3+-+2 | 2 6         3    2
+--R     (54a b x  + 108a b x  + 54a )\|3 \|- a b  \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R                   | 2 6         3    2       4
+--R                 x\|b x  + 2a b x  + a   - b x  - a x
+--R   (5)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 9       2 6     2   3    3  | 2 6         3    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 2282
+t0:=1/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 2282
+r0:=1/6*x*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+5/18*x/(a^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+5/27*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/_
+   (a^(8/3)*b^(1/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-5/54*(a+b*x^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(8/3)*b^(1/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-5/9*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(8/3)*b^(1/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R            2 6          3     2  +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- 5b x  - 10a b x  - 5a )\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           2 6          3      2  +-+     3+-+   3+-+
+--R       (10b x  + 20a b x  + 10a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                        3+-+   3+-+
+--R           2 6          3      2      2x\|b  - \|a
+--R       (30b x  + 60a b x  + 30a )atan(-------------)
+--R                                          +-+3+-+
+--R                                         \|3 \|a
+--R     + 
+--R             4          +-+3+-+2 3+-+
+--R       (15b x  + 24a x)\|3 \|a   \|b
+--R  /
+--R                                     +-------------------+
+--R         2   3      3  +-+3+-+2 3+-+ | 2 6         3    2
+--R     (54a b x  + 54a )\|3 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                             +---+2      +---+
+--R            2 6          3     2  +-+     2 3| 2        3| 2      2
+--R       (- 5b x  - 10a b x  - 5a )\|3 log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R                                           +---+
+--R           2 6          3      2  +-+     3| 2
+--R       (10b x  + 20a b x  + 10a )\|3 log(x\|a b  + a)
+--R     + 
+--R                                             +---+
+--R                                         +-+3| 2       +-+
+--R           2 6          3      2      2x\|3 \|a b  - a\|3
+--R       (30b x  + 60a b x  + 30a )atan(--------------------)
+--R                                               3a
+--R     + 
+--R                            +---+
+--R             4          +-+3| 2
+--R       (15b x  + 24a x)\|3 \|a b
+--R  /
+--R                                       +---+
+--R         2 2 6       3   3      4  +-+3| 2
+--R     (54a b x  + 108a b x  + 54a )\|3 \|a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 528
+
+--S 529 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                  +-------------------+
+--R              2 6          3     2  +-+3+-+2 3+-+ | 2 6         3    2
+--R         (- 5b x  - 10a b x  - 5a )\|3 \|a   \|b \|b x  + 2a b x  + a
+--R      *
+--R                 +---+2      +---+
+--R              2 3| 2        3| 2      2
+--R         log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R                                                  +-------------------+
+--R             2 6          3      2  +-+3+-+2 3+-+ | 2 6         3    2
+--R         (10b x  + 20a b x  + 10a )\|3 \|a   \|b \|b x  + 2a b x  + a
+--R      *
+--R               +---+
+--R              3| 2
+--R         log(x\|a b  + a)
+--R     + 
+--R                                                 +---+
+--R            3 9        2 6      2   3     3  +-+3| 2
+--R         (5b x  + 15a b x  + 15a b x  + 5a )\|3 \|a b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                                                   +---+
+--R             3 9        2 6      2   3      3  +-+3| 2       3+-+   3+-+
+--R       (- 10b x  - 30a b x  - 30a b x  - 10a )\|3 \|a b log(x\|b  + \|a )
+--R     + 
+--R                                              +-------------------+
+--R             2 6          3      2 3+-+2 3+-+ | 2 6         3    2
+--R         (30b x  + 60a b x  + 30a )\|a   \|b \|b x  + 2a b x  + a
+--R      *
+--R                     +---+
+--R                 +-+3| 2       +-+
+--R              2x\|3 \|a b  - a\|3
+--R         atan(--------------------)
+--R                       3a
+--R     + 
+--R                                               +---+       3+-+   3+-+
+--R             3 9        2 6      2   3      3 3| 2       2x\|b  - \|a
+--R       (- 30b x  - 90a b x  - 90a b x  - 30a )\|a b atan(-------------)
+--R                                                             +-+3+-+
+--R                                                            \|3 \|a
+--R     + 
+--R                                      +---+ +-------------------+
+--R             4          +-+3+-+2 3+-+3| 2   | 2 6         3    2
+--R       (15b x  + 24a x)\|3 \|a   \|b \|a b \|b x  + 2a b x  + a
+--R     + 
+--R                                                   +---+
+--R             2 7          4      2   +-+3+-+2 3+-+3| 2
+--R       (- 15b x  - 39a b x  - 24a x)\|3 \|a   \|b \|a b
+--R  /
+--R                                                 +---+ +-------------------+
+--R         2 2 6       3   3      4  +-+3+-+2 3+-+3| 2   | 2 6         3    2
+--R     (54a b x  + 108a b x  + 54a )\|3 \|a   \|b \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +-------------------+
+--R                   | 2 6         3    2       3
+--R                  \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -----------------------------------------------------
+--R                                        +-------------------+
+--R          3 9       2 6     2   3    3  | 2 6         3    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 530
+
+)clear all
+
+--S 531 of 2282
+t0:=1/(x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R                               +-------------------+
+--R          2 7         4    2   | 2 6         3    2
+--R        (b x  + 2a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 2282
+r0:=1/6*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+_
+   1/3/(a^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))+(a+b*x^3)*log(x)/_
+   (a^3*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*(a+b*x^3)*log(a+b*x^3)/_
+   (a^3*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R            2 6         3     2        3           2 6          3     2
+--R       (- 2b x  - 4a b x  - 2a )log(b x  + a) + (6b x  + 12a b x  + 6a )log(x)
+--R     + 
+--R             3     2
+--R       2a b x  + 3a
+--R  /
+--R                     +-------------------+
+--R        3   3     4  | 2 6         3    2
+--R     (6a b x  + 6a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2 6         3     2        3           2 6          3     2
+--R       (- 2b x  - 4a b x  - 2a )log(b x  + a) + (6b x  + 12a b x  + 6a )log(x)
+--R     + 
+--R             3     2
+--R       2a b x  + 3a
+--R  /
+--R       3 2 6      4   3     5
+--R     6a b x  + 12a b x  + 6a
+--R                                         Type: Union(Expression(Integer),...)
+--E 533
+
+--S 534 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2 6         3     2        3
+--R           (- 2b x  - 4a b x  - 2a )log(b x  + a)
+--R         + 
+--R              2 6          3     2                3     2
+--R           (6b x  + 12a b x  + 6a )log(x) + 2a b x  + 3a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R          3 9       2 6     2   3     3        3
+--R       (2b x  + 6a b x  + 6a b x  + 2a )log(b x  + a)
+--R     + 
+--R            3 9        2 6      2   3     3              2 6     2   3     3
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )log(x) - 2a b x  - 5a b x  - 3a
+--R  /
+--R                                +-------------------+
+--R        3 2 6      4   3     5  | 2 6         3    2
+--R     (6a b x  + 12a b x  + 6a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +-------------------+
+--R                    | 2 6         3    2       3
+--R                   \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  -------------------------------------------------------
+--R                                          +-------------------+
+--R          3 10       2 7     2   4    3   | 2 6         3    2
+--R        (b x   + 3a b x  + 3a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 535
+
+)clear all
+
+--S 536 of 2282
+t0:=1/(x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                +-------------------+
+--R          2 8         5    2 2  | 2 6         3    2
+--R        (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 2282
+r0:=1/6*(a+b*x^3)/(a*x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+_
+   7/18/(a^2*x*sqrt(a^2+2*a*b*x^3+b^2*x^6))-14/9*(a+b*x^3)/(a^3*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+14/27*b^(1/3)*(a+b*x^3)*log(a^(1/3)+_
+   b^(1/3)*x)/(a^(10/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-7/27*b^(1/3)*_
+   (a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(10/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+14/9*b^(1/3)*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(10/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             2 7          4      2   +-+3+-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- 14b x  - 28a b x  - 14a x)\|3 \|b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           2 7          4      2   +-+3+-+     3+-+   3+-+
+--R       (28b x  + 56a b x  + 28a x)\|3 \|b log(x\|b  + \|a )
+--R     + 
+--R                                                3+-+   3+-+
+--R             2 7           4      2  3+-+     2x\|b  - \|a
+--R       (- 84b x  - 168a b x  - 84a x)\|b atan(-------------)
+--R                                                  +-+3+-+
+--R                                                 \|3 \|a
+--R     + 
+--R             2 6           3      2  +-+3+-+
+--R       (- 84b x  - 147a b x  - 54a )\|3 \|a
+--R  /
+--R                                +-------------------+
+--R         3   4      4   +-+3+-+ | 2 6         3    2
+--R     (54a b x  + 54a x)\|3 \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                        +-+       +-+2
+--R           2 7          4      2   +-+  |b        |b
+--R       (28b x  + 56a b x  + 28a x)\|3  3|- log(a 3|-   + b x)
+--R                                       \|a       \|a
+--R     + 
+--R                                          +-+           +-+2      +-+
+--R             2 7          4      2   +-+  |b            |b        |b      2
+--R       (- 14b x  - 28a b x  - 14a x)\|3  3|- log(- a x 3|-   + a 3|- + b x )
+--R                                         \|a           \|a       \|a
+--R     + 
+--R                                                    +-+2
+--R                                               +-+  |b         +-+
+--R                                     +-+     a\|3  3|-  - 2b x\|3
+--R           2 7           4      2    |b            \|a
+--R       (84b x  + 168a b x  + 84a x) 3|- atan(---------------------)
+--R                                    \|a                 +-+2
+--R                                                        |b
+--R                                                    3a 3|-
+--R                                                       \|a
+--R     + 
+--R             2 6           3      2  +-+
+--R       (- 84b x  - 147a b x  - 54a )\|3
+--R  /
+--R         3 2 7       4   4      5   +-+
+--R     (54a b x  + 108a b x  + 54a x)\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 538
+
+--S 539 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3 10        2 7      2   4      3   +-+3+-+
+--R         (14b x   + 42a b x  + 42a b x  + 14a x)\|3 \|b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             3 10        2 7      2   4      3   +-+3+-+     3+-+   3+-+
+--R       (- 28b x   - 84a b x  - 84a b x  - 28a x)\|3 \|b log(x\|b  + \|a )
+--R     + 
+--R                                              +-+ +-------------------+
+--R             2 7          4      2   +-+3+-+  |b  | 2 6         3    2
+--R         (28b x  + 56a b x  + 28a x)\|3 \|a  3|- \|b x  + 2a b x  + a
+--R                                             \|a
+--R      *
+--R                +-+2
+--R                |b
+--R         log(a 3|-   + b x)
+--R               \|a
+--R     + 
+--R                                                +-+ +-------------------+
+--R               2 7          4      2   +-+3+-+  |b  | 2 6         3    2
+--R         (- 14b x  - 28a b x  - 14a x)\|3 \|a  3|- \|b x  + 2a b x  + a
+--R                                               \|a
+--R      *
+--R                    +-+2      +-+
+--R                    |b        |b      2
+--R         log(- a x 3|-   + a 3|- + b x )
+--R                   \|a       \|a
+--R     + 
+--R                                                           3+-+   3+-+
+--R           3 10         2 7       2   4      3  3+-+     2x\|b  - \|a
+--R       (84b x   + 252a b x  + 252a b x  + 84a x)\|b atan(-------------)
+--R                                                             +-+3+-+
+--R                                                            \|3 \|a
+--R     + 
+--R                                           +-+ +-------------------+
+--R             2 7           4      2  3+-+  |b  | 2 6         3    2
+--R         (84b x  + 168a b x  + 84a x)\|a  3|- \|b x  + 2a b x  + a
+--R                                          \|a
+--R      *
+--R                     +-+2
+--R                +-+  |b         +-+
+--R              a\|3  3|-  - 2b x\|3
+--R                    \|a
+--R         atan(---------------------)
+--R                         +-+2
+--R                         |b
+--R                     3a 3|-
+--R                        \|a
+--R     + 
+--R                                             +-------------------+
+--R             2 6           3      2  +-+3+-+ | 2 6         3    2
+--R       (- 84b x  - 147a b x  - 54a )\|3 \|a \|b x  + 2a b x  + a
+--R     + 
+--R           3 9         2 6       2   3      3  +-+3+-+
+--R       (84b x  + 231a b x  + 201a b x  + 54a )\|3 \|a
+--R  /
+--R                                            +-------------------+
+--R         3 2 7       4   4      5   +-+3+-+ | 2 6         3    2
+--R     (54a b x  + 108a b x  + 54a x)\|3 \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                     | 2 6         3    2       3
+--R                    \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  --------------------------------------------------------
+--R                                           +-------------------+
+--R          3 11       2 8     2   5    3 2  | 2 6         3    2
+--R        (b x   + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 2282
+t0:=1/(x^3*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                +-------------------+
+--R          2 9         6    2 3  | 2 6         3    2
+--R        (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 2282
+r0:=1/6*(a+b*x^3)/(a*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+4/9/(a^2*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-10/9*(a+b*x^3)/(a^3*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-20/27*b^(2/3)*(a+b*x^3)*log(a^(1/3)+_
+   b^(1/3)*x)/(a^(11/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+10/27*b^(2/3)*_
+   (a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(11/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+20/9*b^(2/3)*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(11/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R           2 8          5      2 2  +-+3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       (20b x  + 40a b x  + 20a x )\|3 \|b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             2 8          5      2 2  +-+3+-+2     3+-+   3+-+
+--R       (- 40b x  - 80a b x  - 40a x )\|3 \|b  log(x\|b  + \|a )
+--R     + 
+--R                                                    3+-+   3+-+
+--R              2 8           5       2 2 3+-+2     2x\|b  - \|a
+--R       (- 120b x  - 240a b x  - 120a x )\|b  atan(-------------)
+--R                                                      +-+3+-+
+--R                                                     \|3 \|a
+--R     + 
+--R             2 6          3      2  +-+3+-+2
+--R       (- 60b x  - 96a b x  - 27a )\|3 \|a
+--R  /
+--R                                  +-------------------+
+--R         3   5      4 2  +-+3+-+2 | 2 6         3    2
+--R     (54a b x  + 54a x )\|3 \|a  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                             +----+
+--R                                             |   2
+--R               2 8          5      2 2  +-+  |  b
+--R         (- 20b x  - 40a b x  - 20a x )\|3   |- --
+--R                                            3|   2
+--R                                            \|  a
+--R      *
+--R                 +----+2         +----+
+--R                 |   2           |   2
+--R              2  |  b            |  b     2 2
+--R         log(a   |- --  + a b x  |- -- + b x )
+--R                3|   2          3|   2
+--R                \|  a           \|  a
+--R     + 
+--R                                         +----+         +----+
+--R                                         |   2          |   2
+--R           2 8          5      2 2  +-+  |  b           |  b
+--R       (40b x  + 80a b x  + 40a x )\|3   |- -- log(- a  |- -- + b x)
+--R                                        3|   2         3|   2
+--R                                        \|  a          \|  a
+--R     + 
+--R                                                            +----+
+--R                                                            |   2
+--R                                                       +-+  |  b         +-+
+--R                                          +----+     a\|3   |- -- + 2b x\|3
+--R                                          |   2            3|   2
+--R              2 8           5       2 2   |  b             \|  a
+--R       (- 120b x  - 240a b x  - 120a x )  |- -- atan(-----------------------)
+--R                                         3|   2                 +----+
+--R                                         \|  a                  |   2
+--R                                                                |  b
+--R                                                            3a  |- --
+--R                                                               3|   2
+--R                                                               \|  a
+--R     + 
+--R             2 6          3      2  +-+
+--R       (- 60b x  - 96a b x  - 27a )\|3
+--R  /
+--R         3 2 8       4   5      5 2  +-+
+--R     (54a b x  + 108a b x  + 54a x )\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 543
+
+--S 544 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               3 11        2 8      2   5      3 2  +-+3+-+2
+--R         (- 20b x   - 60a b x  - 60a b x  - 20a x )\|3 \|b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           3 11         2 8       2   5      3 2  +-+3+-+2     3+-+   3+-+
+--R       (40b x   + 120a b x  + 120a b x  + 40a x )\|3 \|b  log(x\|b  + \|a )
+--R     + 
+--R                                             +----+
+--R                                             |   2       +-------------------+
+--R               2 8          5      2 2  +-+  |  b  3+-+2 | 2 6         3    2
+--R         (- 20b x  - 40a b x  - 20a x )\|3   |- -- \|a  \|b x  + 2a b x  + a
+--R                                            3|   2
+--R                                            \|  a
+--R      *
+--R                 +----+2         +----+
+--R                 |   2           |   2
+--R              2  |  b            |  b     2 2
+--R         log(a   |- --  + a b x  |- -- + b x )
+--R                3|   2          3|   2
+--R                \|  a           \|  a
+--R     + 
+--R                                           +----+
+--R                                           |   2       +-------------------+
+--R             2 8          5      2 2  +-+  |  b  3+-+2 | 2 6         3    2
+--R         (40b x  + 80a b x  + 40a x )\|3   |- -- \|a  \|b x  + 2a b x  + a
+--R                                          3|   2
+--R                                          \|  a
+--R      *
+--R                  +----+
+--R                  |   2
+--R                  |  b
+--R         log(- a  |- -- + b x)
+--R                 3|   2
+--R                 \|  a
+--R     + 
+--R                                                               3+-+   3+-+
+--R            3 11         2 8       2   5       3 2 3+-+2     2x\|b  - \|a
+--R       (120b x   + 360a b x  + 360a b x  + 120a x )\|b  atan(-------------)
+--R                                                                 +-+3+-+
+--R                                                                \|3 \|a
+--R     + 
+--R                                            +----+
+--R                                            |   2       +-------------------+
+--R                2 8           5       2 2   |  b  3+-+2 | 2 6         3    2
+--R         (- 120b x  - 240a b x  - 120a x )  |- -- \|a  \|b x  + 2a b x  + a
+--R                                           3|   2
+--R                                           \|  a
+--R      *
+--R                     +----+
+--R                     |   2
+--R                +-+  |  b         +-+
+--R              a\|3   |- -- + 2b x\|3
+--R                    3|   2
+--R                    \|  a
+--R         atan(-----------------------)
+--R                         +----+
+--R                         |   2
+--R                         |  b
+--R                     3a  |- --
+--R                        3|   2
+--R                        \|  a
+--R     + 
+--R                                             +-------------------+
+--R             2 6          3      2  +-+3+-+2 | 2 6         3    2
+--R       (- 60b x  - 96a b x  - 27a )\|3 \|a  \|b x  + 2a b x  + a
+--R     + 
+--R           3 9         2 6       2   3      3  +-+3+-+2
+--R       (60b x  + 156a b x  + 123a b x  + 27a )\|3 \|a
+--R  /
+--R                                              +-------------------+
+--R         3 2 8       4   5      5 2  +-+3+-+2 | 2 6         3    2
+--R     (54a b x  + 108a b x  + 54a x )\|3 \|a  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                     | 2 6         3    2       3
+--R                    \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  --------------------------------------------------------
+--R                                           +-------------------+
+--R          3 12       2 9     2   6    3 3  | 2 6         3    2
+--R        (b x   + 3a b x  + 3a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 545
+
+)clear all
+
+--S 546 of 2282
+t0:=1/(x^4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R                                 +-------------------+
+--R          2 10         7    2 4  | 2 6         3    2
+--R        (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 2282
+r0:=1/6*(a+b*x^3)/(a*x^3*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+1/2/(a^2*x^3*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-3*b*(a+b*x^3)*log(x)/(a^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+b*(a+b*x^3)*log(a+b*x^3)/(a^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a^4*x^3)
+--R 
+--R
+--R   (2)
+--R          3 9        2 6     2   3        3
+--R       (6b x  + 12a b x  + 6a b x )log(b x  + a)
+--R     + 
+--R           3 9        2 6      2   3            3 9        2 6      2   3     3
+--R     (- 18b x  - 36a b x  - 18a b x )log(x) - 6b x  - 18a b x  - 15a b x  - 2a
+--R  /
+--R                       +-------------------+
+--R        4   6     5 3  | 2 6         3    2
+--R     (6a b x  + 6a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3 9        2 6     2   3        3
+--R       (6b x  + 12a b x  + 6a b x )log(b x  + a)
+--R     + 
+--R             3 9        2 6      2   3              2 6     2   3     3
+--R       (- 18b x  - 36a b x  - 18a b x )log(x) - 6a b x  - 9a b x  - 2a
+--R  /
+--R       4 2 9      5   6     6 3
+--R     6a b x  + 12a b x  + 6a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 548
+
+--S 549 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3 9        2 6     2   3        3
+--R           (6b x  + 12a b x  + 6a b x )log(b x  + a)
+--R         + 
+--R                 3 9        2 6      2   3              2 6     2   3     3
+--R           (- 18b x  - 36a b x  - 18a b x )log(x) - 6a b x  - 9a b x  - 2a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R            4 12        3 9      2 2 6     3   3        3
+--R       (- 6b x   - 18a b x  - 18a b x  - 6a b x )log(b x  + a)
+--R     + 
+--R           4 12        3 9      2 2 6      3   3            4 12        3 9
+--R       (18b x   + 54a b x  + 54a b x  + 18a b x )log(x) + 6b x   + 24a b x
+--R     + 
+--R          2 2 6      3   3     4
+--R       33a b x  + 17a b x  + 2a
+--R  /
+--R                                  +-------------------+
+--R        4 2 9      5   6     6 3  | 2 6         3    2
+--R     (6a b x  + 12a b x  + 6a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +-------------------+
+--R                     | 2 6         3    2       3
+--R                    \|b x  + 2a b x  + a   - b x  - a
+--R   (5)  ---------------------------------------------------------
+--R                                            +-------------------+
+--R          3 13       2 10     2   7    3 4  | 2 6         3    2
+--R        (b x   + 3a b x   + 3a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 550
+
+)clear all
+
+--S 551 of 2282
+t0:=x^m/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        m
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 2282
+--r0:=1/12*x^(1+m)*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+_
+--   1/108*(11-m)*x^(1+m)/(a^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+_
+--   1/648*(8-m)*(11-m)*x^(1+m)*(a+b*x^3)/(a^3*(a^2+2*a*b*x^3+_
+--   b^2*x^6)^(3/2))+1/1944*(5-m)*(8-m)*(11-m)*x^(1+m)/(a^4*_
+--   sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/1944*(2-m)*(5-m)*(8-m)*(11-m)*_
+--   x^(1+m)*(a+b*x^3)*hypergeometric(1,1/3*(1+m),1/3*(4+m),_
+--   -b*x^3/a)/(a^5*(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--E 552
+
+--S 553 of 2282
+--a0:=integrate(t0,x)
+--E 553
+
+--S 554 of 2282
+--m0:=a0-r0
+--E 554
+
+--S 555 of 2282
+--d0:=normalize(D(m0,x))
+--E 555
+
+)clear all
+
+--S 556 of 2282
+t0:=x^6/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        6
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 2282
+r0:=1/12*a*x*(a+b*x^3)/(b^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))-_
+   13/108*x/(b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+1/162*x*(a+b*x^3)/_
+   (a*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+5/486*x/(a^2*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+5/729*(a+b*x^3)*log(a^(1/3)+_
+   b^(1/3)*x)/(a^(8/3)*b^(7/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   5/1458*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(8/3)*b^(7/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-5/243*(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(8/3)*b^(7/3)*_
+   sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R               4 12        3 9      2 2 6      3   3      4  +-+
+--R         (- 10b x   - 40a b x  - 60a b x  - 40a b x  - 10a )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           4 12        3 9       2 2 6      3   3      4  +-+     3+-+   3+-+
+--R       (20b x   + 80a b x  + 120a b x  + 80a b x  + 20a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                                                  3+-+   3+-+
+--R           4 12         3 9       2 2 6       3   3      4      2x\|b  - \|a
+--R       (60b x   + 240a b x  + 360a b x  + 240a b x  + 60a )atan(-------------)
+--R                                                                    +-+3+-+
+--R                                                                   \|3 \|a
+--R     + 
+--R           3 10         2 7       2   4      3   +-+3+-+2 3+-+
+--R       (30b x   + 108a b x  - 225a b x  - 60a x)\|3 \|a   \|b
+--R  /
+--R             2 5 9        3 4 6        4 3 3        5 2  +-+3+-+2 3+-+
+--R       (2916a b x  + 8748a b x  + 8748a b x  + 2916a b )\|3 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 12        3 9      2 2 6      3   3      4  +-+
+--R         (- 10b x   - 40a b x  - 60a b x  - 40a b x  - 10a )\|3
+--R      *
+--R                 +---+2      +---+
+--R              2 3| 2        3| 2      2
+--R         log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R                                                                   +---+
+--R           4 12        3 9       2 2 6      3   3      4  +-+     3| 2
+--R       (20b x   + 80a b x  + 120a b x  + 80a b x  + 20a )\|3 log(x\|a b  + a)
+--R     + 
+--R             4 12         3 9       2 2 6       3   3      4
+--R         (60b x   + 240a b x  + 360a b x  + 240a b x  + 60a )
+--R      *
+--R                     +---+
+--R                 +-+3| 2       +-+
+--R              2x\|3 \|a b  - a\|3
+--R         atan(--------------------)
+--R                       3a
+--R     + 
+--R                                                     +---+
+--R           3 10         2 7       2   4      3   +-+3| 2
+--R       (30b x   + 108a b x  - 225a b x  - 60a x)\|3 \|a b
+--R  /
+--R             2 6 12         3 5 9         4 4 6         5 3 3        6 2  +-+
+--R       (2916a b x   + 11664a b x  + 17496a b x  + 11664a b x  + 2916a b )\|3
+--R    *
+--R        +---+
+--R       3| 2
+--R       \|a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 558
+
+--S 559 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               4 12        3 9      2 2 6      3   3      4  +-+3+-+2 3+-+
+--R         (- 10b x   - 40a b x  - 60a b x  - 40a b x  - 10a )\|3 \|a   \|b
+--R      *
+--R          +-------------------+        +---+2      +---+
+--R          | 2 6         3    2      2 3| 2        3| 2      2
+--R         \|b x  + 2a b x  + a  log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R             4 12        3 9       2 2 6      3   3      4  +-+3+-+2 3+-+
+--R         (20b x   + 80a b x  + 120a b x  + 80a b x  + 20a )\|3 \|a   \|b
+--R      *
+--R          +-------------------+      +---+
+--R          | 2 6         3    2      3| 2
+--R         \|b x  + 2a b x  + a  log(x\|a b  + a)
+--R     + 
+--R             5 15        4 12       2 3 9       3 2 6      4   3      5  +-+
+--R         (10b x   + 50a b x   + 100a b x  + 100a b x  + 50a b x  + 10a )\|3
+--R      *
+--R          +---+
+--R         3| 2       2 3+-+2   3+-+3+-+   3+-+2
+--R         \|a b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               5 15         4 12       2 3 9       3 2 6       4   3      5  +-+
+--R         (- 20b x   - 100a b x   - 200a b x  - 200a b x  - 100a b x  - 20a )\|3
+--R      *
+--R          +---+
+--R         3| 2       3+-+   3+-+
+--R         \|a b log(x\|b  + \|a )
+--R     + 
+--R             4 12         3 9       2 2 6       3   3      4 3+-+2 3+-+
+--R         (60b x   + 240a b x  + 360a b x  + 240a b x  + 60a )\|a   \|b
+--R      *
+--R                                           +---+
+--R          +-------------------+        +-+3| 2       +-+
+--R          | 2 6         3    2      2x\|3 \|a b  - a\|3
+--R         \|b x  + 2a b x  + a  atan(--------------------)
+--R                                             3a
+--R     + 
+--R               5 15         4 12       2 3 9       3 2 6       4   3      5
+--R         (- 60b x   - 300a b x   - 600a b x  - 600a b x  - 300a b x  - 60a )
+--R      *
+--R          +---+       3+-+   3+-+
+--R         3| 2       2x\|b  - \|a
+--R         \|a b atan(-------------)
+--R                        +-+3+-+
+--R                       \|3 \|a
+--R     + 
+--R                                                                 +---+
+--R             3 10         2 7       2   4      3   +-+3+-+2 3+-+3| 2
+--R         (30b x   + 108a b x  - 225a b x  - 60a x)\|3 \|a   \|b \|a b
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                                                                            +---+
+--R           4 13         3 10       2 2 7       3   4      4   +-+3+-+2 3+-+3| 2
+--R     (- 30b x   - 138a b x   + 117a b x  + 285a b x  + 60a x)\|3 \|a   \|b \|a b
+--R  /
+--R             2 6 12         3 5 9         4 4 6         5 3 3        6 2  +-+
+--R       (2916a b x   + 11664a b x  + 17496a b x  + 11664a b x  + 2916a b )\|3
+--R    *
+--R                  +---+ +-------------------+
+--R       3+-+2 3+-+3| 2   | 2 6         3    2
+--R       \|a   \|b \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                          +-------------------+
+--R                        6 | 2 6         3    2       9      6
+--R                       x \|b x  + 2a b x  + a   - b x  - a x
+--R   -----------------------------------------------------------------------------
+--R                                                           +-------------------+
+--R     5 15       4 12      2 3 9      3 2 6     4   3    5  | 2 6         3    2
+--R   (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 560
+
+)clear all
+
+--S 561 of 2282
+t0:=x^5/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        5
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 2282
+r0:=1/12*a*(a+b*x^3)/(b^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+(-1/9)/_
+   (b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                                        3
+--R                                  - 4b x  - a
+--R   (2)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R            5 9         4 6       2 3 3      3 2  | 2 6         3    2
+--R        (36b x  + 108a b x  + 108a b x  + 36a b )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   3
+--R                             - 4b x  - a
+--R   (3)  ----------------------------------------------------
+--R           6 12         5 9       2 4 6       3 3 3      4 2
+--R        36b x   + 144a b x  + 216a b x  + 144a b x  + 36a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 563
+
+--S 564 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +-------------------+
+--R                   3      | 2 6         3    2      2 6         3    2
+--R            (- 4b x  - a)\|b x  + 2a b x  + a   + 4b x  + 5a b x  + a
+--R   ----------------------------------------------------------------------------
+--R                                                          +-------------------+
+--R       6 12         5 9       2 4 6       3 3 3      4 2  | 2 6         3    2
+--R   (36b x   + 144a b x  + 216a b x  + 144a b x  + 36a b )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 564
+
+--S 565 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                          +-------------------+
+--R                        5 | 2 6         3    2       8      5
+--R                       x \|b x  + 2a b x  + a   - b x  - a x
+--R   -----------------------------------------------------------------------------
+--R                                                           +-------------------+
+--R     5 15       4 12      2 3 9      3 2 6     4   3    5  | 2 6         3    2
+--R   (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 565
+
+)clear all
+
+--S 566 of 2282
+t0:=x^4/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        4
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 2282
+r0:=1/12*x^5*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))-_
+   7/108*x^2/(a*b*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+7/324*x^2*(a+b*x^3)/_
+   (a^2*b*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+7/243*x^2/(a^3*b*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-7/729*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/_
+   (a^(10/3)*b^(5/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+7/1458*(a+b*x^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(10/3)*b^(5/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-7/243*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(10/3)*b^(5/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             4 12        3 9      2 2 6      3   3      4  +-+
+--R         (14b x   + 56a b x  + 84a b x  + 56a b x  + 14a )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               4 12         3 9       2 2 6       3   3      4  +-+
+--R         (- 28b x   - 112a b x  - 168a b x  - 112a b x  - 28a )\|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                                                                  3+-+   3+-+
+--R           4 12         3 9       2 2 6       3   3      4      2x\|b  - \|a
+--R       (84b x   + 336a b x  + 504a b x  + 336a b x  + 84a )atan(-------------)
+--R                                                                    +-+3+-+
+--R                                                                   \|3 \|a
+--R     + 
+--R           3 11         2 8       2   5      3 2  +-+3+-+3+-+2
+--R       (84b x   + 315a b x  + 432a b x  - 42a x )\|3 \|a \|b
+--R  /
+--R             3 4 9        4 3 6        5 2 3        6   +-+3+-+3+-+2
+--R       (2916a b x  + 8748a b x  + 8748a b x  + 2916a b)\|3 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 12        3 9      2 2 6      3   3      4  +-+
+--R         (- 14b x   - 56a b x  - 84a b x  - 56a b x  - 14a )\|3
+--R      *
+--R                +------+2         +------+
+--R               3|     2        2 3|     2
+--R         log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R             4 12         3 9       2 2 6       3   3      4  +-+
+--R         (28b x   + 112a b x  + 168a b x  + 112a b x  + 28a )\|3
+--R      *
+--R                +------+2
+--R               3|     2
+--R         log(x \|- a b    + a b)
+--R     + 
+--R               4 12         3 9       2 2 6       3   3      4
+--R         (- 84b x   - 336a b x  - 504a b x  - 336a b x  - 84a )
+--R      *
+--R                     +------+2
+--R                 +-+3|     2         +-+
+--R              2x\|3 \|- a b    - a b\|3
+--R         atan(--------------------------)
+--R                         3a b
+--R     + 
+--R                                                      +------+
+--R           3 11         2 8       2   5      3 2  +-+3|     2
+--R       (84b x   + 315a b x  + 432a b x  - 42a x )\|3 \|- a b
+--R  /
+--R             3 5 12         4 4 9         5 3 6         6 2 3        7   +-+
+--R       (2916a b x   + 11664a b x  + 17496a b x  + 11664a b x  + 2916a b)\|3
+--R    *
+--R        +------+
+--R       3|     2
+--R       \|- a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 568
+
+--S 569 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 15        4 12       2 3 9       3 2 6      4   3      5  +-+
+--R         (- 14b x   - 70a b x   - 140a b x  - 140a b x  - 70a b x  - 14a )\|3
+--R      *
+--R          +------+
+--R         3|     2      2 3+-+2   3+-+3+-+   3+-+2
+--R         \|- a b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             5 15         4 12       2 3 9       3 2 6       4   3      5  +-+
+--R         (28b x   + 140a b x   + 280a b x  + 280a b x  + 140a b x  + 28a )\|3
+--R      *
+--R          +------+
+--R         3|     2      3+-+   3+-+
+--R         \|- a b  log(x\|b  + \|a )
+--R     + 
+--R               4 12        3 9      2 2 6      3   3      4  +-+3+-+3+-+2
+--R         (- 14b x   - 56a b x  - 84a b x  - 56a b x  - 14a )\|3 \|a \|b
+--R      *
+--R          +-------------------+       +------+2         +------+
+--R          | 2 6         3    2       3|     2        2 3|     2
+--R         \|b x  + 2a b x  + a  log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R             4 12         3 9       2 2 6       3   3      4  +-+3+-+3+-+2
+--R         (28b x   + 112a b x  + 168a b x  + 112a b x  + 28a )\|3 \|a \|b
+--R      *
+--R          +-------------------+       +------+2
+--R          | 2 6         3    2       3|     2
+--R         \|b x  + 2a b x  + a  log(x \|- a b    + a b)
+--R     + 
+--R               5 15         4 12       2 3 9       3 2 6       4   3      5
+--R         (- 84b x   - 420a b x   - 840a b x  - 840a b x  - 420a b x  - 84a )
+--R      *
+--R          +------+       3+-+   3+-+
+--R         3|     2      2x\|b  - \|a
+--R         \|- a b  atan(-------------)
+--R                           +-+3+-+
+--R                          \|3 \|a
+--R     + 
+--R               4 12         3 9       2 2 6       3   3      4 3+-+3+-+2
+--R         (- 84b x   - 336a b x  - 504a b x  - 336a b x  - 84a )\|a \|b
+--R      *
+--R                                           +------+2
+--R          +-------------------+        +-+3|     2         +-+
+--R          | 2 6         3    2      2x\|3 \|- a b    - a b\|3
+--R         \|b x  + 2a b x  + a  atan(--------------------------)
+--R                                               3a b
+--R     + 
+--R                                                        +------+
+--R             3 11         2 8       2   5      3 2  +-+3|     2 3+-+3+-+2
+--R         (84b x   + 315a b x  + 432a b x  - 42a x )\|3 \|- a b  \|a \|b
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                                                                       +------+
+--R               4 14         3 11       2 2 8       3   5      4 2  +-+3|     2
+--R         (- 84b x   - 399a b x   - 747a b x  - 390a b x  + 42a x )\|3 \|- a b
+--R      *
+--R         3+-+3+-+2
+--R         \|a \|b
+--R  /
+--R             3 5 12         4 4 9         5 3 6         6 2 3        7   +-+
+--R       (2916a b x   + 11664a b x  + 17496a b x  + 11664a b x  + 2916a b)\|3
+--R    *
+--R        +------+          +-------------------+
+--R       3|     2 3+-+3+-+2 | 2 6         3    2
+--R       \|- a b  \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                          +-------------------+
+--R                        4 | 2 6         3    2       7      4
+--R                       x \|b x  + 2a b x  + a   - b x  - a x
+--R   -----------------------------------------------------------------------------
+--R                                                           +-------------------+
+--R     5 15       4 12      2 3 9      3 2 6     4   3    5  | 2 6         3    2
+--R   (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 2282
+t0:=x^3/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        3
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 2282
+r0:=1/12*x^4*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))-_
+   2/27*x/(a*b*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+1/81*x*(a+b*x^3)/_
+   (a^2*b*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+5/243*x/(a^3*b*sqrt(a^2+_
+   2*a*b*x^3+b^2*x^6))+10/729*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/_
+   (a^(11/3)*b^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-5/729*(a+b*x^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(11/3)*b^(4/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-10/243*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(11/3)*b^(4/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R               4 12        3 9       2 2 6      3   3      4  +-+
+--R         (- 20b x   - 80a b x  - 120a b x  - 80a b x  - 20a )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           4 12         3 9       2 2 6       3   3      4  +-+     3+-+   3+-+
+--R       (40b x   + 160a b x  + 240a b x  + 160a b x  + 40a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                                                    3+-+   3+-+
+--R            4 12         3 9       2 2 6       3   3       4      2x\|b  - \|a
+--R       (120b x   + 480a b x  + 720a b x  + 480a b x  + 120a )atan(-------------)
+--R                                                                      +-+3+-+
+--R                                                                     \|3 \|a
+--R     + 
+--R           3 10         2 7       2   4       3   +-+3+-+2 3+-+
+--R       (60b x   + 216a b x  + 279a b x  - 120a x)\|3 \|a   \|b
+--R  /
+--R             3 4 9        4 3 6        5 2 3        6   +-+3+-+2 3+-+
+--R       (2916a b x  + 8748a b x  + 8748a b x  + 2916a b)\|3 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 12        3 9       2 2 6      3   3      4  +-+
+--R         (- 20b x   - 80a b x  - 120a b x  - 80a b x  - 20a )\|3
+--R      *
+--R                 +---+2      +---+
+--R              2 3| 2        3| 2      2
+--R         log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R                                                                     +---+
+--R           4 12         3 9       2 2 6       3   3      4  +-+     3| 2
+--R       (40b x   + 160a b x  + 240a b x  + 160a b x  + 40a )\|3 log(x\|a b  + a)
+--R     + 
+--R              4 12         3 9       2 2 6       3   3       4
+--R         (120b x   + 480a b x  + 720a b x  + 480a b x  + 120a )
+--R      *
+--R                     +---+
+--R                 +-+3| 2       +-+
+--R              2x\|3 \|a b  - a\|3
+--R         atan(--------------------)
+--R                       3a
+--R     + 
+--R                                                      +---+
+--R           3 10         2 7       2   4       3   +-+3| 2
+--R       (60b x   + 216a b x  + 279a b x  - 120a x)\|3 \|a b
+--R  /
+--R                                                                           +---+
+--R           3 5 12         4 4 9         5 3 6         6 2 3        7   +-+3| 2
+--R     (2916a b x   + 11664a b x  + 17496a b x  + 11664a b x  + 2916a b)\|3 \|a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 573
+
+--S 574 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               4 12        3 9       2 2 6      3   3      4  +-+3+-+2 3+-+
+--R         (- 20b x   - 80a b x  - 120a b x  - 80a b x  - 20a )\|3 \|a   \|b
+--R      *
+--R          +-------------------+        +---+2      +---+
+--R          | 2 6         3    2      2 3| 2        3| 2      2
+--R         \|b x  + 2a b x  + a  log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R             4 12         3 9       2 2 6       3   3      4  +-+3+-+2 3+-+
+--R         (40b x   + 160a b x  + 240a b x  + 160a b x  + 40a )\|3 \|a   \|b
+--R      *
+--R          +-------------------+      +---+
+--R          | 2 6         3    2      3| 2
+--R         \|b x  + 2a b x  + a  log(x\|a b  + a)
+--R     + 
+--R             5 15         4 12       2 3 9       3 2 6       4   3      5  +-+
+--R         (20b x   + 100a b x   + 200a b x  + 200a b x  + 100a b x  + 20a )\|3
+--R      *
+--R          +---+
+--R         3| 2       2 3+-+2   3+-+3+-+   3+-+2
+--R         \|a b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               5 15         4 12       2 3 9       3 2 6       4   3      5  +-+
+--R         (- 40b x   - 200a b x   - 400a b x  - 400a b x  - 200a b x  - 40a )\|3
+--R      *
+--R          +---+
+--R         3| 2       3+-+   3+-+
+--R         \|a b log(x\|b  + \|a )
+--R     + 
+--R              4 12         3 9       2 2 6       3   3       4 3+-+2 3+-+
+--R         (120b x   + 480a b x  + 720a b x  + 480a b x  + 120a )\|a   \|b
+--R      *
+--R                                           +---+
+--R          +-------------------+        +-+3| 2       +-+
+--R          | 2 6         3    2      2x\|3 \|a b  - a\|3
+--R         \|b x  + 2a b x  + a  atan(--------------------)
+--R                                             3a
+--R     + 
+--R                5 15         4 12        2 3 9        3 2 6       4   3       5
+--R         (- 120b x   - 600a b x   - 1200a b x  - 1200a b x  - 600a b x  - 120a )
+--R      *
+--R          +---+       3+-+   3+-+
+--R         3| 2       2x\|b  - \|a
+--R         \|a b atan(-------------)
+--R                        +-+3+-+
+--R                       \|3 \|a
+--R     + 
+--R                                                                  +---+
+--R             3 10         2 7       2   4       3   +-+3+-+2 3+-+3| 2
+--R         (60b x   + 216a b x  + 279a b x  - 120a x)\|3 \|a   \|b \|a b
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R               4 13         3 10       2 2 7       3   4       4   +-+3+-+2 3+-+
+--R         (- 60b x   - 276a b x   - 495a b x  - 159a b x  + 120a x)\|3 \|a   \|b
+--R      *
+--R          +---+
+--R         3| 2
+--R         \|a b
+--R  /
+--R             3 5 12         4 4 9         5 3 6         6 2 3        7   +-+
+--R       (2916a b x   + 11664a b x  + 17496a b x  + 11664a b x  + 2916a b)\|3
+--R    *
+--R                  +---+ +-------------------+
+--R       3+-+2 3+-+3| 2   | 2 6         3    2
+--R       \|a   \|b \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                          +-------------------+
+--R                        3 | 2 6         3    2       6      3
+--R                       x \|b x  + 2a b x  + a   - b x  - a x
+--R   -----------------------------------------------------------------------------
+--R                                                           +-------------------+
+--R     5 15       4 12      2 3 9      3 2 6     4   3    5  | 2 6         3    2
+--R   (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 575
+
+)clear all
+
+--S 576 of 2282
+t0:=x^2/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        2
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 2282
+r0:=1/12*(-a-b*x^3)/(b*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))
+--R 
+--R
+--R                                        1
+--R   (2)  - ------------------------------------------------------------
+--R                                                 +-------------------+
+--R              4 9        3 6      2 2 3      3   | 2 6         3    2
+--R          (12b x  + 36a b x  + 36a b x  + 12a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                  1
+--R   (3)  - ------------------------------------------------
+--R             5 12        4 9      2 3 6      3 2 3      4
+--R          12b x   + 48a b x  + 72a b x  + 48a b x  + 12a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 578
+
+--S 579 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +-------------------+
+--R                         | 2 6         3    2       3
+--R                      - \|b x  + 2a b x  + a   + b x  + a
+--R   ------------------------------------------------------------------------
+--R                                                      +-------------------+
+--R       5 12        4 9      2 3 6      3 2 3      4   | 2 6         3    2
+--R   (12b x   + 48a b x  + 72a b x  + 48a b x  + 12a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                          +-------------------+
+--R                        2 | 2 6         3    2       5      2
+--R                       x \|b x  + 2a b x  + a   - b x  - a x
+--R   -----------------------------------------------------------------------------
+--R                                                           +-------------------+
+--R     5 15       4 12      2 3 9      3 2 6     4   3    5  | 2 6         3    2
+--R   (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 580
+
+)clear all
+
+--S 581 of 2282
+t0:=x/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 2282
+r0:=1/12*x^2*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+5/54*x^2/_
+   (a^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+35/324*x^2*(a+b*x^3)/_
+   (a^3*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+35/243*x^2/(a^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-35/729*(a+b*x^3)*log(a^(1/3)+_
+   b^(1/3)*x)/(a^(13/3)*b^(2/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   35/1458*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(13/3)*b^(2/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-35/243*(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(13/3)*b^(2/3)*_
+   sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             4 12         3 9       2 2 6       3   3      4  +-+
+--R         (70b x   + 280a b x  + 420a b x  + 280a b x  + 70a )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                4 12         3 9       2 2 6       3   3       4  +-+
+--R         (- 140b x   - 560a b x  - 840a b x  - 560a b x  - 140a )\|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R              4 12          3 9        2 2 6        3   3       4
+--R         (420b x   + 1680a b x  + 2520a b x  + 1680a b x  + 420a )
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R            3 11          2 8        2   5        3 2  +-+3+-+3+-+2
+--R       (420b x   + 1575a b x  + 2160a b x  + 1248a x )\|3 \|a \|b
+--R  /
+--R             4 3 9        5 2 6        6   3        7  +-+3+-+3+-+2
+--R       (2916a b x  + 8748a b x  + 8748a b x  + 2916a )\|3 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 12         3 9       2 2 6       3   3      4  +-+
+--R         (- 70b x   - 280a b x  - 420a b x  - 280a b x  - 70a )\|3
+--R      *
+--R                +------+2         +------+
+--R               3|     2        2 3|     2
+--R         log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R              4 12         3 9       2 2 6       3   3       4  +-+
+--R         (140b x   + 560a b x  + 840a b x  + 560a b x  + 140a )\|3
+--R      *
+--R                +------+2
+--R               3|     2
+--R         log(x \|- a b    + a b)
+--R     + 
+--R                4 12          3 9        2 2 6        3   3       4
+--R         (- 420b x   - 1680a b x  - 2520a b x  - 1680a b x  - 420a )
+--R      *
+--R                     +------+2
+--R                 +-+3|     2         +-+
+--R              2x\|3 \|- a b    - a b\|3
+--R         atan(--------------------------)
+--R                         3a b
+--R     + 
+--R                                                           +------+
+--R            3 11          2 8        2   5        3 2  +-+3|     2
+--R       (420b x   + 1575a b x  + 2160a b x  + 1248a x )\|3 \|- a b
+--R  /
+--R             4 4 12         5 3 9         6 2 6         7   3        8  +-+
+--R       (2916a b x   + 11664a b x  + 17496a b x  + 11664a b x  + 2916a )\|3
+--R    *
+--R        +------+
+--R       3|     2
+--R       \|- a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 583
+
+--S 584 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               5 15         4 12       2 3 9       3 2 6       4   3      5  +-+
+--R         (- 70b x   - 350a b x   - 700a b x  - 700a b x  - 350a b x  - 70a )\|3
+--R      *
+--R          +------+
+--R         3|     2      2 3+-+2   3+-+3+-+   3+-+2
+--R         \|- a b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              5 15         4 12        2 3 9        3 2 6       4   3       5
+--R         (140b x   + 700a b x   + 1400a b x  + 1400a b x  + 700a b x  + 140a )
+--R      *
+--R              +------+
+--R          +-+3|     2      3+-+   3+-+
+--R         \|3 \|- a b  log(x\|b  + \|a )
+--R     + 
+--R               4 12         3 9       2 2 6       3   3      4  +-+3+-+3+-+2
+--R         (- 70b x   - 280a b x  - 420a b x  - 280a b x  - 70a )\|3 \|a \|b
+--R      *
+--R          +-------------------+       +------+2         +------+
+--R          | 2 6         3    2       3|     2        2 3|     2
+--R         \|b x  + 2a b x  + a  log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R              4 12         3 9       2 2 6       3   3       4  +-+3+-+3+-+2
+--R         (140b x   + 560a b x  + 840a b x  + 560a b x  + 140a )\|3 \|a \|b
+--R      *
+--R          +-------------------+       +------+2
+--R          | 2 6         3    2       3|     2
+--R         \|b x  + 2a b x  + a  log(x \|- a b    + a b)
+--R     + 
+--R                   5 15          4 12        2 3 9        3 2 6        4   3
+--R             - 420b x   - 2100a b x   - 4200a b x  - 4200a b x  - 2100a b x
+--R           + 
+--R                   5
+--R             - 420a
+--R      *
+--R          +------+       3+-+   3+-+
+--R         3|     2      2x\|b  - \|a
+--R         \|- a b  atan(-------------)
+--R                           +-+3+-+
+--R                          \|3 \|a
+--R     + 
+--R                4 12          3 9        2 2 6        3   3       4 3+-+3+-+2
+--R         (- 420b x   - 1680a b x  - 2520a b x  - 1680a b x  - 420a )\|a \|b
+--R      *
+--R                                           +------+2
+--R          +-------------------+        +-+3|     2         +-+
+--R          | 2 6         3    2      2x\|3 \|- a b    - a b\|3
+--R         \|b x  + 2a b x  + a  atan(--------------------------)
+--R                                               3a b
+--R     + 
+--R                                                             +------+
+--R              3 11          2 8        2   5        3 2  +-+3|     2 3+-+3+-+2
+--R         (420b x   + 1575a b x  + 2160a b x  + 1248a x )\|3 \|- a b  \|a \|b
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                4 14          3 11        2 2 8        3   5        4 2  +-+
+--R         (- 420b x   - 1995a b x   - 3735a b x  - 3408a b x  - 1248a x )\|3
+--R      *
+--R          +------+
+--R         3|     2 3+-+3+-+2
+--R         \|- a b  \|a \|b
+--R  /
+--R             4 4 12         5 3 9         6 2 6         7   3        8  +-+
+--R       (2916a b x   + 11664a b x  + 17496a b x  + 11664a b x  + 2916a )\|3
+--R    *
+--R        +------+          +-------------------+
+--R       3|     2 3+-+3+-+2 | 2 6         3    2
+--R       \|- a b  \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                          +-------------------+
+--R                          | 2 6         3    2       4
+--R                        x\|b x  + 2a b x  + a   - b x  - a x
+--R   -----------------------------------------------------------------------------
+--R                                                           +-------------------+
+--R     5 15       4 12      2 3 9      3 2 6     4   3    5  | 2 6         3    2
+--R   (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 2282
+t0:=1/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        1
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 2282
+r0:=1/12*x*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+11/108*x/(a^2*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2))+11/81*x*(a+b*x^3)/(a^3*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(3/2))+55/243*x/(a^4*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   110/729*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(14/3)*b^(1/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-55/729*(a+b*x^3)*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(14/3)*b^(1/3)*sqrt(a^2+2*a*b*_
+   x^3+b^2*x^6))-110/243*(a+b*x^3)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(14/3)*b^(1/3)*sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R                4 12         3 9        2 2 6       3   3       4  +-+
+--R         (- 220b x   - 880a b x  - 1320a b x  - 880a b x  - 220a )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              4 12          3 9        2 2 6        3   3       4  +-+
+--R         (440b x   + 1760a b x  + 2640a b x  + 1760a b x  + 440a )\|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R               4 12          3 9        2 2 6        3   3        4
+--R         (1320b x   + 5280a b x  + 7920a b x  + 5280a b x  + 1320a )
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R            3 10          2 7        2   4        3   +-+3+-+2 3+-+
+--R       (660b x   + 2376a b x  + 3069a b x  + 1596a x)\|3 \|a   \|b
+--R  /
+--R             4 3 9        5 2 6        6   3        7  +-+3+-+2 3+-+
+--R       (2916a b x  + 8748a b x  + 8748a b x  + 2916a )\|3 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4 12         3 9        2 2 6       3   3       4  +-+
+--R         (- 220b x   - 880a b x  - 1320a b x  - 880a b x  - 220a )\|3
+--R      *
+--R                 +---+2      +---+
+--R              2 3| 2        3| 2      2
+--R         log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R              4 12          3 9        2 2 6        3   3       4  +-+
+--R         (440b x   + 1760a b x  + 2640a b x  + 1760a b x  + 440a )\|3
+--R      *
+--R               +---+
+--R              3| 2
+--R         log(x\|a b  + a)
+--R     + 
+--R               4 12          3 9        2 2 6        3   3        4
+--R         (1320b x   + 5280a b x  + 7920a b x  + 5280a b x  + 1320a )
+--R      *
+--R                     +---+
+--R                 +-+3| 2       +-+
+--R              2x\|3 \|a b  - a\|3
+--R         atan(--------------------)
+--R                       3a
+--R     + 
+--R                                                          +---+
+--R            3 10          2 7        2   4        3   +-+3| 2
+--R       (660b x   + 2376a b x  + 3069a b x  + 1596a x)\|3 \|a b
+--R  /
+--R                                                                          +---+
+--R           4 4 12         5 3 9         6 2 6         7   3        8  +-+3| 2
+--R     (2916a b x   + 11664a b x  + 17496a b x  + 11664a b x  + 2916a )\|3 \|a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 588
+
+--S 589 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                4 12         3 9        2 2 6       3   3       4  +-+3+-+2 3+-+
+--R         (- 220b x   - 880a b x  - 1320a b x  - 880a b x  - 220a )\|3 \|a   \|b
+--R      *
+--R          +-------------------+        +---+2      +---+
+--R          | 2 6         3    2      2 3| 2        3| 2      2
+--R         \|b x  + 2a b x  + a  log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R              4 12          3 9        2 2 6        3   3       4  +-+3+-+2 3+-+
+--R         (440b x   + 1760a b x  + 2640a b x  + 1760a b x  + 440a )\|3 \|a   \|b
+--R      *
+--R          +-------------------+      +---+
+--R          | 2 6         3    2      3| 2
+--R         \|b x  + 2a b x  + a  log(x\|a b  + a)
+--R     + 
+--R              5 15          4 12        2 3 9        3 2 6        4   3       5
+--R         (220b x   + 1100a b x   + 2200a b x  + 2200a b x  + 1100a b x  + 220a )
+--R      *
+--R              +---+
+--R          +-+3| 2       2 3+-+2   3+-+3+-+   3+-+2
+--R         \|3 \|a b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                   5 15          4 12        2 3 9        3 2 6        4   3
+--R             - 440b x   - 2200a b x   - 4400a b x  - 4400a b x  - 2200a b x
+--R           + 
+--R                   5
+--R             - 440a
+--R      *
+--R              +---+
+--R          +-+3| 2       3+-+   3+-+
+--R         \|3 \|a b log(x\|b  + \|a )
+--R     + 
+--R               4 12          3 9        2 2 6        3   3        4 3+-+2 3+-+
+--R         (1320b x   + 5280a b x  + 7920a b x  + 5280a b x  + 1320a )\|a   \|b
+--R      *
+--R                                           +---+
+--R          +-------------------+        +-+3| 2       +-+
+--R          | 2 6         3    2      2x\|3 \|a b  - a\|3
+--R         \|b x  + 2a b x  + a  atan(--------------------)
+--R                                             3a
+--R     + 
+--R                  5 15          4 12         2 3 9         3 2 6        4   3
+--R           - 1320b x   - 6600a b x   - 13200a b x  - 13200a b x  - 6600a b x
+--R         + 
+--R                  5
+--R           - 1320a
+--R      *
+--R          +---+       3+-+   3+-+
+--R         3| 2       2x\|b  - \|a
+--R         \|a b atan(-------------)
+--R                        +-+3+-+
+--R                       \|3 \|a
+--R     + 
+--R                                                                      +---+
+--R              3 10          2 7        2   4        3   +-+3+-+2 3+-+3| 2
+--R         (660b x   + 2376a b x  + 3069a b x  + 1596a x)\|3 \|a   \|b \|a b
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                4 13          3 10        2 2 7        3   4        4   +-+3+-+2
+--R         (- 660b x   - 3036a b x   - 5445a b x  - 4665a b x  - 1596a x)\|3 \|a
+--R      *
+--R              +---+
+--R         3+-+3| 2
+--R         \|b \|a b
+--R  /
+--R             4 4 12         5 3 9         6 2 6         7   3        8  +-+3+-+2
+--R       (2916a b x   + 11664a b x  + 17496a b x  + 11664a b x  + 2916a )\|3 \|a
+--R    *
+--R            +---+ +-------------------+
+--R       3+-+3| 2   | 2 6         3    2
+--R       \|b \|a b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                          +-------------------+
+--R                          | 2 6         3    2       3
+--R                         \|b x  + 2a b x  + a   - b x  - a
+--R   -----------------------------------------------------------------------------
+--R                                                           +-------------------+
+--R     5 15       4 12      2 3 9      3 2 6     4   3    5  | 2 6         3    2
+--R   (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 590
+
+)clear all
+
+--S 591 of 2282
+t0:=1/(x*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  ------------------------------------------------------------------
+--R                                                     +-------------------+
+--R          4 13       3 10     2 2 7     3   4    4   | 2 6         3    2
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 2282
+r0:=1/12*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+1/9/(a^2*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2))+1/6*(a+b*x^3)/(a^3*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(3/2))+1/3/(a^4*sqrt(a^2+2*a*b*x^3+b^2*x^6))+(a+b*x^3)*_
+   log(x)/(a^5*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*(a+b*x^3)*_
+   log(a+b*x^3)/(a^5*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             4 12        3 9      2 2 6      3   3      4        3
+--R       (- 12b x   - 48a b x  - 72a b x  - 48a b x  - 12a )log(b x  + a)
+--R     + 
+--R           4 12         3 9       2 2 6       3   3      4               3 9
+--R       (36b x   + 144a b x  + 216a b x  + 144a b x  + 36a )log(x) + 12a b x
+--R     + 
+--R          2 2 6      3   3      4
+--R       42a b x  + 52a b x  + 25a
+--R  /
+--R                                               +-------------------+
+--R         5 3 9       6 2 6       7   3      8  | 2 6         3    2
+--R     (36a b x  + 108a b x  + 108a b x  + 36a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             4 12        3 9      2 2 6      3   3      4        3
+--R       (- 12b x   - 48a b x  - 72a b x  - 48a b x  - 12a )log(b x  + a)
+--R     + 
+--R           4 12         3 9       2 2 6       3   3      4               3 9
+--R       (36b x   + 144a b x  + 216a b x  + 144a b x  + 36a )log(x) + 12a b x
+--R     + 
+--R          2 2 6      3   3      4
+--R       42a b x  + 52a b x  + 25a
+--R  /
+--R        5 4 12       6 3 9       7 2 6       8   3      9
+--R     36a b x   + 144a b x  + 216a b x  + 144a b x  + 36a
+--R                                         Type: Union(Expression(Integer),...)
+--E 593
+
+--S 594 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 4 12        3 9      2 2 6      3   3      4        3
+--R           (- 12b x   - 48a b x  - 72a b x  - 48a b x  - 12a )log(b x  + a)
+--R         + 
+--R               4 12         3 9       2 2 6       3   3      4               3 9
+--R           (36b x   + 144a b x  + 216a b x  + 144a b x  + 36a )log(x) + 12a b x
+--R         + 
+--R              2 2 6      3   3      4
+--R           42a b x  + 52a b x  + 25a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R             5 15        4 12       2 3 9       3 2 6      4   3      5
+--R         (12b x   + 60a b x   + 120a b x  + 120a b x  + 60a b x  + 12a )
+--R      *
+--R                3
+--R         log(b x  + a)
+--R     + 
+--R             5 15         4 12       2 3 9       3 2 6       4   3      5
+--R       (- 36b x   - 180a b x   - 360a b x  - 360a b x  - 180a b x  - 36a )log(x)
+--R     + 
+--R              4 12      2 3 9      3 2 6      4   3      5
+--R       - 12a b x   - 54a b x  - 94a b x  - 77a b x  - 25a
+--R  /
+--R           5 4 12       6 3 9       7 2 6       8   3      9
+--R       (36a b x   + 144a b x  + 216a b x  + 144a b x  + 36a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 6         3    2       3
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 16       4 13      2 3 10      3 2 7     4   4    5
+--R       (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x)
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 595
+
+)clear all
+
+--S 596 of 2282
+t0:=1/(x^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R                                                      +-------------------+
+--R          4 14       3 11     2 2 8     3   5    4 2  | 2 6         3    2
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 2282
+r0:=1/12*(a+b*x^3)/(a*x*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+13/108/(a^2*x*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2))+65/324*(a+b*x^3)/(a^3*x*(a^2+_
+   2*a*b*x^3+b^2*x^6)^(3/2))+455/972/(a^4*x*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6))-455/243*(a+b*x^3)/(a^5*x*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   455/729*b^(1/3)*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(16/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-455/1458*b^(1/3)*(a+b*x^3)*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(16/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   455/243*b^(1/3)*(a+b*x^3)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(16/3)*sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R                4 13          3 10        2 2 7        3   4       4   +-+3+-+
+--R         (- 910b x   - 3640a b x   - 5460a b x  - 3640a b x  - 910a x)\|3 \|b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               4 13          3 10         2 2 7        3   4        4   +-+3+-+
+--R         (1820b x   + 7280a b x   + 10920a b x  + 7280a b x  + 1820a x)\|3 \|b
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                 4 13           3 10         2 2 7         3   4        4  3+-+
+--R         (- 5460b x   - 21840a b x   - 32760a b x  - 21840a b x  - 5460a x)\|b
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R               4 12           3 9         2 2 6         3   3        4  +-+3+-+
+--R       (- 5460b x   - 20475a b x  - 28080a b x  - 16224a b x  - 2916a )\|3 \|a
+--R  /
+--R             5 3 10        6 2 7        7   4        8   +-+3+-+
+--R       (2916a b x   + 8748a b x  + 8748a b x  + 2916a x)\|3 \|a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                             +-+
+--R               4 13          3 10         2 2 7        3   4        4   +-+  |b
+--R         (1820b x   + 7280a b x   + 10920a b x  + 7280a b x  + 1820a x)\|3  3|-
+--R                                                                            \|a
+--R      *
+--R                +-+2
+--R                |b
+--R         log(a 3|-   + b x)
+--R               \|a
+--R     + 
+--R                                                                            +-+
+--R                4 13          3 10        2 2 7        3   4       4   +-+  |b
+--R         (- 910b x   - 3640a b x   - 5460a b x  - 3640a b x  - 910a x)\|3  3|-
+--R                                                                           \|a
+--R      *
+--R                    +-+2      +-+
+--R                    |b        |b      2
+--R         log(- a x 3|-   + a 3|- + b x )
+--R                   \|a       \|a
+--R     + 
+--R                                                                           +-+
+--R               4 13           3 10         2 2 7         3   4        4    |b
+--R         (5460b x   + 21840a b x   + 32760a b x  + 21840a b x  + 5460a x) 3|-
+--R                                                                          \|a
+--R      *
+--R                     +-+2
+--R                +-+  |b         +-+
+--R              a\|3  3|-  - 2b x\|3
+--R                    \|a
+--R         atan(---------------------)
+--R                         +-+2
+--R                         |b
+--R                     3a 3|-
+--R                        \|a
+--R     + 
+--R               4 12           3 9         2 2 6         3   3        4  +-+
+--R       (- 5460b x   - 20475a b x  - 28080a b x  - 16224a b x  - 2916a )\|3
+--R  /
+--R           5 4 13         6 3 10         7 2 7         8   4        9   +-+
+--R     (2916a b x   + 11664a b x   + 17496a b x  + 11664a b x  + 2916a x)\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 598
+
+--S 599 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 16          4 13        2 3 10        3 2 7        4   4
+--R             910b x   + 4550a b x   + 9100a b x   + 9100a b x  + 4550a b x
+--R           + 
+--R                 5
+--R             910a x
+--R      *
+--R          +-+3+-+     2 3+-+2   3+-+3+-+   3+-+2
+--R         \|3 \|b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                  5 16          4 13         2 3 10         3 2 7        4   4
+--R           - 1820b x   - 9100a b x   - 18200a b x   - 18200a b x  - 9100a b x
+--R         + 
+--R                  5
+--R           - 1820a x
+--R      *
+--R          +-+3+-+     3+-+   3+-+
+--R         \|3 \|b log(x\|b  + \|a )
+--R     + 
+--R               4 13          3 10         2 2 7        3   4        4   +-+3+-+
+--R         (1820b x   + 7280a b x   + 10920a b x  + 7280a b x  + 1820a x)\|3 \|a
+--R      *
+--R          +-+ +-------------------+       +-+2
+--R          |b  | 2 6         3    2        |b
+--R         3|- \|b x  + 2a b x  + a  log(a 3|-   + b x)
+--R         \|a                             \|a
+--R     + 
+--R                4 13          3 10        2 2 7        3   4       4   +-+3+-+
+--R         (- 910b x   - 3640a b x   - 5460a b x  - 3640a b x  - 910a x)\|3 \|a
+--R      *
+--R          +-+ +-------------------+           +-+2      +-+
+--R          |b  | 2 6         3    2            |b        |b      2
+--R         3|- \|b x  + 2a b x  + a  log(- a x 3|-   + a 3|- + b x )
+--R         \|a                                 \|a       \|a
+--R     + 
+--R                5 16           4 13         2 3 10         3 2 7         4   4
+--R           5460b x   + 27300a b x   + 54600a b x   + 54600a b x  + 27300a b x
+--R         + 
+--R                5
+--R           5460a x
+--R      *
+--R                    3+-+   3+-+
+--R         3+-+     2x\|b  - \|a
+--R         \|b atan(-------------)
+--R                      +-+3+-+
+--R                     \|3 \|a
+--R     + 
+--R               4 13           3 10         2 2 7         3   4        4  3+-+
+--R         (5460b x   + 21840a b x   + 32760a b x  + 21840a b x  + 5460a x)\|a
+--R      *
+--R                                               +-+2
+--R                                          +-+  |b         +-+
+--R          +-+ +-------------------+     a\|3  3|-  - 2b x\|3
+--R          |b  | 2 6         3    2            \|a
+--R         3|- \|b x  + 2a b x  + a  atan(---------------------)
+--R         \|a                                       +-+2
+--R                                                   |b
+--R                                               3a 3|-
+--R                                                  \|a
+--R     + 
+--R                 4 12           3 9         2 2 6         3   3        4  +-+
+--R         (- 5460b x   - 20475a b x  - 28080a b x  - 16224a b x  - 2916a )\|3
+--R      *
+--R              +-------------------+
+--R         3+-+ | 2 6         3    2
+--R         \|a \|b x  + 2a b x  + a
+--R     + 
+--R                5 15           4 12         2 3 9         3 2 6         4   3
+--R           5460b x   + 25935a b x   + 48555a b x  + 44304a b x  + 19140a b x
+--R         + 
+--R                5
+--R           2916a
+--R      *
+--R          +-+3+-+
+--R         \|3 \|a
+--R  /
+--R             5 4 13         6 3 10         7 2 7         8   4        9   +-+
+--R       (2916a b x   + 11664a b x   + 17496a b x  + 11664a b x  + 2916a x)\|3
+--R    *
+--R            +-------------------+
+--R       3+-+ | 2 6         3    2
+--R       \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 6         3    2       3
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 17       4 14      2 3 11      3 2 8     4   5    5 2
+--R       (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)clear all
+
+--S 601 of 2282
+t0:=1/(x^3*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R                                                      +-------------------+
+--R          4 15       3 12     2 2 9     3   6    4 3  | 2 6         3    2
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 2282
+r0:=1/12*(a+b*x^3)/(a*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+7/54/(a^2*x^2*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2))+77/324*(a+b*x^3)/(a^3*x^2*(a^2+_
+   2*a*b*x^3+b^2*x^6)^(3/2))+154/243/(a^4*x^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6))-385/243*(a+b*x^3)/(a^5*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   770/729*b^(2/3)*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(17/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+385/729*b^(2/3)*(a+b*x^3)*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(17/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   770/243*b^(2/3)*(a+b*x^3)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(17/3)*sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R               4 14          3 11        2 2 8        3   5        4 2  +-+3+-+2
+--R         (1540b x   + 6160a b x   + 9240a b x  + 6160a b x  + 1540a x )\|3 \|b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                 4 14           3 11         2 2 8         3   5        4 2  +-+
+--R         (- 3080b x   - 12320a b x   - 18480a b x  - 12320a b x  - 3080a x )\|3
+--R      *
+--R         3+-+2     3+-+   3+-+
+--R         \|b  log(x\|b  + \|a )
+--R     + 
+--R                 4 14           3 11         2 2 8         3   5        4 2
+--R         (- 9240b x   - 36960a b x   - 55440a b x  - 36960a b x  - 9240a x )
+--R      *
+--R                     3+-+   3+-+
+--R         3+-+2     2x\|b  - \|a
+--R         \|b  atan(-------------)
+--R                       +-+3+-+
+--R                      \|3 \|a
+--R     + 
+--R             4 12           3 9         2 2 6         3   3        4  +-+3+-+2
+--R     (- 4620b x   - 16632a b x  - 21483a b x  - 11172a b x  - 1458a )\|3 \|a
+--R  /
+--R             5 3 11        6 2 8        7   5        8 2  +-+3+-+2
+--R       (2916a b x   + 8748a b x  + 8748a b x  + 2916a x )\|3 \|a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 4 14          3 11        2 2 8        3   5        4 2  +-+
+--R         (- 1540b x   - 6160a b x   - 9240a b x  - 6160a b x  - 1540a x )\|3
+--R      *
+--R          +----+        +----+2         +----+
+--R          |   2         |   2           |   2
+--R          |  b       2  |  b            |  b     2 2
+--R          |- -- log(a   |- --  + a b x  |- -- + b x )
+--R         3|   2        3|   2          3|   2
+--R         \|  a         \|  a           \|  a
+--R     + 
+--R               4 14           3 11         2 2 8         3   5        4 2  +-+
+--R         (3080b x   + 12320a b x   + 18480a b x  + 12320a b x  + 3080a x )\|3
+--R      *
+--R          +----+         +----+
+--R          |   2          |   2
+--R          |  b           |  b
+--R          |- -- log(- a  |- -- + b x)
+--R         3|   2         3|   2
+--R         \|  a          \|  a
+--R     + 
+--R                 4 14           3 11         2 2 8         3   5        4 2
+--R         (- 9240b x   - 36960a b x   - 55440a b x  - 36960a b x  - 9240a x )
+--R      *
+--R                            +----+
+--R                            |   2
+--R                       +-+  |  b         +-+
+--R          +----+     a\|3   |- -- + 2b x\|3
+--R          |   2            3|   2
+--R          |  b             \|  a
+--R          |- -- atan(-----------------------)
+--R         3|   2                 +----+
+--R         \|  a                  |   2
+--R                                |  b
+--R                            3a  |- --
+--R                               3|   2
+--R                               \|  a
+--R     + 
+--R               4 12           3 9         2 2 6         3   3        4  +-+
+--R       (- 4620b x   - 16632a b x  - 21483a b x  - 11172a b x  - 1458a )\|3
+--R  /
+--R           5 4 14         6 3 11         7 2 8         8   5        9 2  +-+
+--R     (2916a b x   + 11664a b x   + 17496a b x  + 11664a b x  + 2916a x )\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 603
+
+--S 604 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  5 17          4 14         2 3 11         3 2 8        4   5
+--R           - 1540b x   - 7700a b x   - 15400a b x   - 15400a b x  - 7700a b x
+--R         + 
+--R                  5 2
+--R           - 1540a x
+--R      *
+--R          +-+3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R         \|3 \|b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                5 17           4 14         2 3 11         3 2 8         4   5
+--R           3080b x   + 15400a b x   + 30800a b x   + 30800a b x  + 15400a b x
+--R         + 
+--R                5 2
+--R           3080a x
+--R      *
+--R          +-+3+-+2     3+-+   3+-+
+--R         \|3 \|b  log(x\|b  + \|a )
+--R     + 
+--R                 4 14          3 11        2 2 8        3   5        4 2  +-+
+--R         (- 1540b x   - 6160a b x   - 9240a b x  - 6160a b x  - 1540a x )\|3
+--R      *
+--R        +----+                                   +----+2         +----+
+--R        |   2       +-------------------+        |   2           |   2
+--R        |  b  3+-+2 | 2 6         3    2      2  |  b            |  b     2 2
+--R        |- -- \|a  \|b x  + 2a b x  + a  log(a   |- --  + a b x  |- -- + b x )
+--R       3|   2                                   3|   2          3|   2
+--R       \|  a                                    \|  a           \|  a
+--R     + 
+--R               4 14           3 11         2 2 8         3   5        4 2  +-+
+--R         (3080b x   + 12320a b x   + 18480a b x  + 12320a b x  + 3080a x )\|3
+--R      *
+--R          +----+                                    +----+
+--R          |   2       +-------------------+         |   2
+--R          |  b  3+-+2 | 2 6         3    2          |  b
+--R          |- -- \|a  \|b x  + 2a b x  + a  log(- a  |- -- + b x)
+--R         3|   2                                    3|   2
+--R         \|  a                                     \|  a
+--R     + 
+--R                5 17           4 14         2 3 11         3 2 8         4   5
+--R           9240b x   + 46200a b x   + 92400a b x   + 92400a b x  + 46200a b x
+--R         + 
+--R                5 2
+--R           9240a x
+--R      *
+--R                     3+-+   3+-+
+--R         3+-+2     2x\|b  - \|a
+--R         \|b  atan(-------------)
+--R                       +-+3+-+
+--R                      \|3 \|a
+--R     + 
+--R                 4 14           3 11         2 2 8         3   5        4 2
+--R         (- 9240b x   - 36960a b x   - 55440a b x  - 36960a b x  - 9240a x )
+--R      *
+--R                                                       +----+
+--R                                                       |   2
+--R                                                  +-+  |  b         +-+
+--R          +----+                                a\|3   |- -- + 2b x\|3
+--R          |   2       +-------------------+           3|   2
+--R          |  b  3+-+2 | 2 6         3    2            \|  a
+--R          |- -- \|a  \|b x  + 2a b x  + a  atan(-----------------------)
+--R         3|   2                                            +----+
+--R         \|  a                                             |   2
+--R                                                           |  b
+--R                                                       3a  |- --
+--R                                                          3|   2
+--R                                                          \|  a
+--R     + 
+--R                 4 12           3 9         2 2 6         3   3        4  +-+
+--R         (- 4620b x   - 16632a b x  - 21483a b x  - 11172a b x  - 1458a )\|3
+--R      *
+--R               +-------------------+
+--R         3+-+2 | 2 6         3    2
+--R         \|a  \|b x  + 2a b x  + a
+--R     + 
+--R                5 15           4 12         2 3 9         3 2 6         4   3
+--R           4620b x   + 21252a b x   + 38115a b x  + 32655a b x  + 12630a b x
+--R         + 
+--R                5
+--R           1458a
+--R      *
+--R          +-+3+-+2
+--R         \|3 \|a
+--R  /
+--R             5 4 14         6 3 11         7 2 8         8   5        9 2  +-+
+--R       (2916a b x   + 11664a b x   + 17496a b x  + 11664a b x  + 2916a x )\|3
+--R    *
+--R             +-------------------+
+--R       3+-+2 | 2 6         3    2
+--R       \|a  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 6         3    2       3
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 18       4 15      2 3 12      3 2 9     4   6    5 3
+--R       (b x   + 5a b x   + 10a b x   + 10a b x  + 5a b x  + a x )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 605
+
+)clear all
+
+--S 606 of 2282
+t0:=1/(x^4*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R                                                       +-------------------+
+--R          4 16       3 13     2 2 10     3   7    4 4  | 2 6         3    2
+--R        (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 2282
+r0:=1/12*(a+b*x^3)/(a*x^3*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+5/36/(a^2*x^3*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2))+5/18*(a+b*x^3)/(a^3*x^3*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(3/2))+5/6/(a^4*x^3*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   5*b*(a+b*x^3)*log(x)/(a^6*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   5/3*b*(a+b*x^3)*log(a+b*x^3)/(a^6*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   5/3*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a^6*x^3)
+--R 
+--R
+--R   (2)
+--R           5 15         4 12       2 3 9       3 2 6      4   3        3
+--R       (60b x   + 240a b x   + 360a b x  + 240a b x  + 60a b x )log(b x  + a)
+--R     + 
+--R              5 15         4 12        2 3 9       3 2 6       4   3
+--R       (- 180b x   - 720a b x   - 1080a b x  - 720a b x  - 180a b x )log(x)
+--R     + 
+--R            5 15         4 12       2 3 9       3 2 6       4   3      5
+--R       - 60b x   - 300a b x   - 570a b x  - 500a b x  - 185a b x  - 12a
+--R  /
+--R                                                  +-------------------+
+--R         6 3 12       7 2 9       8   6      9 3  | 2 6         3    2
+--R     (36a b x   + 108a b x  + 108a b x  + 36a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           5 15         4 12       2 3 9       3 2 6      4   3        3
+--R       (60b x   + 240a b x   + 360a b x  + 240a b x  + 60a b x )log(b x  + a)
+--R     + 
+--R              5 15         4 12        2 3 9       3 2 6       4   3
+--R       (- 180b x   - 720a b x   - 1080a b x  - 720a b x  - 180a b x )log(x)
+--R     + 
+--R              4 12       2 3 9       3 2 6       4   3      5
+--R       - 60a b x   - 210a b x  - 260a b x  - 125a b x  - 12a
+--R  /
+--R        6 4 15       7 3 12       8 2 9       9   6      10 3
+--R     36a b x   + 144a b x   + 216a b x  + 144a b x  + 36a  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 608
+
+--S 609 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 5 15         4 12       2 3 9       3 2 6      4   3
+--R             (60b x   + 240a b x   + 360a b x  + 240a b x  + 60a b x )
+--R          *
+--R                    3
+--R             log(b x  + a)
+--R         + 
+--R                  5 15         4 12        2 3 9       3 2 6       4   3
+--R           (- 180b x   - 720a b x   - 1080a b x  - 720a b x  - 180a b x )log(x)
+--R         + 
+--R                  4 12       2 3 9       3 2 6       4   3      5
+--R           - 60a b x   - 210a b x  - 260a b x  - 125a b x  - 12a
+--R      *
+--R          +-------------------+
+--R          | 2 6         3    2
+--R         \|b x  + 2a b x  + a
+--R     + 
+--R                  6 18         5 15       2 4 12       3 3 9       4 2 6
+--R             - 60b x   - 300a b x   - 600a b x   - 600a b x  - 300a b x
+--R           + 
+--R                  5   3
+--R             - 60a b x
+--R      *
+--R                3
+--R         log(b x  + a)
+--R     + 
+--R               6 18         5 15        2 4 12        3 3 9       4 2 6
+--R           180b x   + 900a b x   + 1800a b x   + 1800a b x  + 900a b x
+--R         + 
+--R               5   3
+--R           180a b x
+--R      *
+--R         log(x)
+--R     + 
+--R          6 18         5 15       2 4 12        3 3 9       4 2 6       5   3
+--R       60b x   + 360a b x   + 870a b x   + 1070a b x  + 685a b x  + 197a b x
+--R     + 
+--R          6
+--R       12a
+--R  /
+--R           6 4 15       7 3 12       8 2 9       9   6      10 3
+--R       (36a b x   + 144a b x   + 216a b x  + 144a b x  + 36a  x )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      +-------------------+
+--R      | 2 6         3    2       3
+--R     \|b x  + 2a b x  + a   - b x  - a
+--R  /
+--R         5 19       4 16      2 3 13      3 2 10     4   7    5 4
+--R       (b x   + 5a b x   + 10a b x   + 10a b x   + 5a b x  + a x )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 610
+
+)clear all
+
+--S 611 of 2282
+t0:=x^m*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         m  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 2282
+--r0:=x^(1+m)*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(1/3*(1+m),_
+--   -2*p,1/3*(4+m),-b*x^3/a)/((1+m)*((a+b*x^3)/a)^(2*p))
+--E 612
+
+--S 613 of 2282
+--a0:=integrate(t0,x)
+--E 613
+
+--S 614 of 2282
+--m0:=a0-r0
+--E 614
+
+--S 615 of 2282
+--d0:=normalize(D(m0,x))
+--E 615
+
+)clear all
+
+--S 616 of 2282
+t0:=x^11*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         11  2 6         3    2 p
+--R   (1)  x  (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 2282
+r0:=-a^3*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b^4*(2+p)*(1+2*p)*(3+2*p))-_
+   1/2*a*x^6*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b^2*(2+p)*(3+2*p))+_
+   1/6*x^9*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b*(2+p))+_
+   1/2*a^2*(a^2+2*a*b*x^3+b^2*x^6)^(1+p)/(b^4*(1+p)*(2+p)*(3+2*p))
+--R 
+--R
+--R   (2)
+--R          2      2   2 6         3    2 p + 1
+--R       (6a p + 3a )(b x  + 2a b x  + a )
+--R     + 
+--R              4 3      4 2      4      4  12        3 3       3 2       3   9
+--R           (4b p  + 12b p  + 11b p + 3b )x   + (4a b p  + 6a b p  + 2a b p)x
+--R         + 
+--R                2 2 2     2 2      2 2  6        3        3   3     4      4
+--R           (- 6a b p  - 9a b p - 3a b )x  + (- 6a b p - 6a b)x  - 6a p - 6a
+--R      *
+--R           2 6         3    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        4 4       4 3       4 2       4       4
+--R     24b p  + 120b p  + 210b p  + 150b p + 36b
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4 3      4 2      4      4  12        3 3       3 2       3   9
+--R         (4b p  + 12b p  + 11b p + 3b )x   + (4a b p  + 6a b p  + 2a b p)x
+--R       + 
+--R              2 2 2     2 2   6     3     3     4
+--R         (- 6a b p  - 3a b p)x  + 6a b p x  - 3a
+--R    *
+--R                2 6         3    2
+--R         p log(b x  + 2a b x  + a )
+--R       %e
+--R  /
+--R        4 4       4 3       4 2       4       4
+--R     24b p  + 120b p  + 210b p  + 150b p + 36b
+--R                                         Type: Union(Expression(Integer),...)
+--E 618
+
+--S 619 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              4 3      4 2      4      4  12        3 3       3 2       3   9
+--R           (4b p  + 12b p  + 11b p + 3b )x   + (4a b p  + 6a b p  + 2a b p)x
+--R         + 
+--R                2 2 2     2 2   6     3     3     4
+--R           (- 6a b p  - 3a b p)x  + 6a b p x  - 3a
+--R      *
+--R                  2 6         3    2
+--R           p log(b x  + 2a b x  + a )
+--R         %e
+--R     + 
+--R            2      2   2 6         3    2 p + 1
+--R       (- 6a p - 3a )(b x  + 2a b x  + a )
+--R     + 
+--R                4 3      4 2      4      4  12
+--R           (- 4b p  - 12b p  - 11b p - 3b )x
+--R         + 
+--R                  3 3       3 2       3   9      2 2 2     2 2      2 2  6
+--R           (- 4a b p  - 6a b p  - 2a b p)x  + (6a b p  + 9a b p + 3a b )x
+--R         + 
+--R              3        3   3     4      4
+--R           (6a b p + 6a b)x  + 6a p + 6a
+--R      *
+--R           2 6         3    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        4 4       4 3       4 2       4       4
+--R     24b p  + 120b p  + 210b p  + 150b p + 36b
+--R                                                    Type: Expression(Integer)
+--E 619
+
+--S 620 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 620
+
+)clear all
+
+--S 621 of 2282
+t0:=x^8*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         8  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 2282
+r0:=2/3*a^2*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b^3*(1+2*p)*(3+2*p))+_
+   1/3*x^6*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b*(3+2*p))-_
+   1/3*a*(a^2+2*a*b*x^3+b^2*x^6)^(1+p)/(b^3*(1+p)*(3+2*p))
+--R 
+--R
+--R   (2)
+--R                     2 6         3    2 p + 1
+--R       (- 2a p - a)(b x  + 2a b x  + a )
+--R     + 
+--R              3 2     3     3  9        2 2       2       2  6
+--R           (2b p  + 3b p + b )x  + (2a b p  + 3a b p + a b )x
+--R         + 
+--R              2        2   3     3      3
+--R           (2a b p + 2a b)x  + 2a p + 2a
+--R      *
+--R           2 6         3    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        3 3      3 2      3      3
+--R     12b p  + 36b p  + 33b p + 9b
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 2     3     3  9        2 2      2   6     2     3    3
+--R       ((2b p  + 3b p + b )x  + (2a b p  + a b p)x  - 2a b p x  + a )
+--R    *
+--R                2 6         3    2
+--R         p log(b x  + 2a b x  + a )
+--R       %e
+--R  /
+--R        3 3      3 2      3      3
+--R     12b p  + 36b p  + 33b p + 9b
+--R                                         Type: Union(Expression(Integer),...)
+--E 623
+
+--S 624 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3 2     3     3  9        2 2      2   6     2     3    3
+--R         ((2b p  + 3b p + b )x  + (2a b p  + a b p)x  - 2a b p x  + a )
+--R      *
+--R                  2 6         3    2
+--R           p log(b x  + 2a b x  + a )
+--R         %e
+--R     + 
+--R                   2 6         3    2 p + 1
+--R       (2a p + a)(b x  + 2a b x  + a )
+--R     + 
+--R                3 2     3     3  9          2 2       2       2  6
+--R           (- 2b p  - 3b p - b )x  + (- 2a b p  - 3a b p - a b )x
+--R         + 
+--R                2        2   3     3      3
+--R           (- 2a b p - 2a b)x  - 2a p - 2a
+--R      *
+--R           2 6         3    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        3 3      3 2      3      3
+--R     12b p  + 36b p  + 33b p + 9b
+--R                                                    Type: Expression(Integer)
+--E 624
+
+--S 625 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 625
+
+)clear all
+
+--S 626 of 2282
+t0:=x^5*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         5  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 2282
+r0:=-1/3*a*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b^2*(1+2*p))+_
+   1/6*(a^2+2*a*b*x^3+b^2*x^6)^(1+p)/(b^2*(1+p))
+--R 
+--R
+--R   (2)
+--R                 2 6         3    2 p + 1
+--R       (2p + 1)(b x  + 2a b x  + a )
+--R     + 
+--R                          3     2      2   2 6         3    2 p
+--R       ((- 2a b p - 2a b)x  - 2a p - 2a )(b x  + 2a b x  + a )
+--R  /
+--R        2 2      2      2
+--R     12b p  + 18b p + 6b
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                 2 6         3    2
+--R            2     2  6           3    2   p log(b x  + 2a b x  + a )
+--R        ((2b p + b )x  + 2a b p x  - a )%e
+--R   (3)  ------------------------------------------------------------
+--R                               2 2      2      2
+--R                            12b p  + 18b p + 6b
+--R                                         Type: Union(Expression(Integer),...)
+--E 628
+
+--S 629 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                2 6         3    2
+--R           2     2  6           3    2   p log(b x  + 2a b x  + a )
+--R       ((2b p + b )x  + 2a b p x  - a )%e
+--R     + 
+--R                   2 6         3    2 p + 1
+--R       (- 2p - 1)(b x  + 2a b x  + a )
+--R     + 
+--R                        3     2      2   2 6         3    2 p
+--R       ((2a b p + 2a b)x  + 2a p + 2a )(b x  + 2a b x  + a )
+--R  /
+--R        2 2      2      2
+--R     12b p  + 18b p + 6b
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 630
+
+)clear all
+
+--S 631 of 2282
+t0:=x^4*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         4  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 2282
+--r0:=x^2*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b*(5+6*p))-_
+--   a*x^2*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(2/3,-2*p,_
+--   5/3,-b*x^3/a)/(b*(5+6*p)*((a+b*x^3)/a)^(2*p))
+--E 632
+
+--S 633 of 2282
+--a0:=integrate(t0,x)
+--E 633
+
+--S 634 of 2282
+--m0:=a0-r0
+--E 634
+
+--S 635 of 2282
+--d0:=normalize(D(m0,x))
+--E 635
+
+)clear all
+
+--S 636 of 2282
+t0:=x^3*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         3  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 2282
+--r0:=1/2*x*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b*(2+3*p))-_
+--   1/2*a*x*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(1/3,-2*p,4/3,_
+--   -b*x^3/a)/(b*(2+3*p)*((a+b*x^3)/a)^(2*p))
+--E 637
+
+--S 638 of 2282
+--a0:=integrate(t0,x)
+--E 638
+
+--S 639 of 2282
+--m0:=a0-r0
+--E 639
+
+--S 640 of 2282
+--d0:=normalize(D(m0,x))
+--E 640
+
+)clear all
+
+--S 641 of 2282
+t0:=x^2*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         2  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 2282
+r0:=1/3*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b*(1+2*p))
+--R 
+--R
+--R            3       2 6         3    2 p
+--R        (b x  + a)(b x  + 2a b x  + a )
+--R   (2)  --------------------------------
+--R                    6b p + 3b
+--R                                                    Type: Expression(Integer)
+--E 642
+
+--S 643 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           2 6         3    2
+--R            3       p log(b x  + 2a b x  + a )
+--R        (b x  + a)%e
+--R   (3)  --------------------------------------
+--R                       6b p + 3b
+--R                                         Type: Union(Expression(Integer),...)
+--E 643
+
+--S 644 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      2 6         3    2
+--R       3       p log(b x  + 2a b x  + a )         3       2 6         3    2 p
+--R   (b x  + a)%e                           + (- b x  - a)(b x  + 2a b x  + a )
+--R   ---------------------------------------------------------------------------
+--R                                    6b p + 3b
+--R                                                    Type: Expression(Integer)
+--E 644
+
+--S 645 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 645
+
+)clear all
+
+--S 646 of 2282
+t0:=x*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R            2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 2282
+--r0:=1/2*x^2*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(2/3,-2*p,5/3,_
+--   -b*x^3/a)/((a+b*x^3)/a)^(2*p)
+--E 647
+
+--S 648 of 2282
+--a0:=integrate(t0,x)
+--E 648
+
+--S 649 of 2282
+--m0:=a0-r0
+--E 649
+
+--S 650 of 2282
+--d0:=normalize(D(m0,x))
+--E 650
+
+)clear all
+
+--S 651 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R          2 6         3    2 p
+--R   (1)  (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 2282
+--r0:=x*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(1/3,-2*p,4/3,_
+--   -b*x^3/a)/((a+b*x^3)/a)^(2*p)
+--E 652
+
+--S 653 of 2282
+--a0:=integrate(t0,x)
+--E 653
+
+--S 654 of 2282
+--m0:=a0-r0
+--E 654
+
+--S 655 of 2282
+--d0:=normalize(D(m0,x))
+--E 655
+
+)clear all
+
+--S 656 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^p/x
+--R 
+--R
+--R          2 6         3    2 p
+--R        (b x  + 2a b x  + a )
+--R   (1)  ----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 2282
+--r0:=1/6*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(-2*p,-2*p,1-2*p,_
+--   -a/(b*x^3))/(p*((a+b*x^3)/(b*x^3))^(2*p))
+--E 657
+
+--S 658 of 2282
+--a0:=integrate(t0,x)
+--E 658
+
+--S 659 of 2282
+--m0:=a0-r0
+--E 659
+
+--S 660 of 2282
+--d0:=normalize(D(m0,x))
+--E 660
+
+)clear all
+
+--S 661 of 2282
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^p/x^2
+--R 
+--R
+--R          2 6         3    2 p
+--R        (b x  + 2a b x  + a )
+--R   (1)  ----------------------
+--R                   2
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 2282
+--r0:=-(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(a*x)+b*(1+3*p)*x^2*_
+--   (a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(2/3,-2*p,5/3,_
+--   -b*x^3/a)/(a*((a+b*x^3)/a)^(2*p))
+--E 662
+
+--S 663 of 2282
+--a0:=integrate(t0,x)
+--E 663
+
+--S 664 of 2282
+--m0:=a0-r0
+--E 664
+
+--S 665 of 2282
+--d0:=normalize(D(m0,x))
+--E 665
+
+)clear all
+
+--S 666 of 2282
+t0:=x^m/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 2282
+--r0:=2*c*x^(1+m)*hypergeometric(1,1/3*(1+m),1/3*(4+m),_
+--   -2*c*x^3/(b-sqrt(b^2-4*a*c)))/((1+m)*(b-sqrt(b^2-4*a*c))*_
+--   sqrt(b^2-4*a*c))-2*c*x^(1+m)*hypergeometric(1,1/3*(1+m),_
+--   1/3*(4+m),-2*c*x^3/(b+sqrt(b^2-4*a*c)))/((1+m)*sqrt(b^2-4*a*c)*_
+--   (b+sqrt(b^2-4*a*c)))
+--E 667
+
+--S 668 of 2282
+--a0:=integrate(t0,x)
+--E 668
+
+--S 669 of 2282
+--m0:=a0-r0
+--E 669
+
+--S 670 of 2282
+--d0:=normalize(D(m0,x))
+--E 670
+
+)clear all
+
+--S 671 of 2282
+t0:=x^8/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                8
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 671
+
+--S 672 of 2282
+r0:=1/3*x^3/c-1/6*b*log(a+b*x^3+c*x^6)/c^2-1/3*(b^2-2*a*c)*_
+   atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                3
+--R                 2          2c x  + b
+--R       (4a c - 2b )atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                          +-----------+
+--R                   6      3            3  |          2
+--R       (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     6c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2
+--R           (2a c - b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 6         3           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   3             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   6      3
+--R                c x  + b x  + a
+--R       + 
+--R                                            +-----------+
+--R                     6      3            3  |          2
+--R         (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         2 |          2
+--R       6c \|- 4a c + b
+--R     ,
+--R
+--R                                        +---------+
+--R                                 3      |        2
+--R                     2      (2c x  + b)\|4a c - b
+--R         (- 4a c + 2b )atan(-----------------------)
+--R                                           2
+--R                                   4a c - b
+--R       + 
+--R                                            +---------+
+--R                     6      3            3  |        2
+--R         (- b log(c x  + b x  + a) + 2c x )\|4a c - b
+--R    /
+--R           +---------+
+--R         2 |        2
+--R       6c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 673
+
+--S 674 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 6         3           2  |          2           2     2   3
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 6      3
+--R              c x  + b x  + a
+--R     + 
+--R                                  3
+--R                   2          2c x  + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     6c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+             3
+--R                  2  |        2          2c x  + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                     +-----------+          3      |        2
+--R                  2  |          2      (2c x  + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     3c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 677
+
+)clear all
+
+--S 678 of 2282
+t0:=x^7/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                7
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 678
+
+--S 679 of 2282
+r0:=1/2*x^2/c+1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*_
+   (b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*(b-_
+   sqrt(b^2-4*a*c))^(1/3))-1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*_
+   x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(b+(-b^2+2*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*(b-sqrt(b^2-4*a*c))^(1/3))+_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(2/3)*c^(5/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3))+1/3*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(2/3)*c^(5/3)*(b+sqrt(b^2-4*a*c))^(1/3))-1/6*log(2^(2/3)*c^(2/3)*_
+   x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-_
+   4*a*c))^(2/3))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*_
+   (b+sqrt(b^2-4*a*c))^(1/3))+atan((-4*c^(1/3)*x+2^(2/3)*(b+_
+   sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*sqrt(3)*_
+   (b+sqrt(b^2-4*a*c))^(1/3))
+--R 
+--R
+--R   (2)
+--R                                                   +--------------------+
+--R                  +-----------+                    |   +-----------+
+--R              +-+ |          2             2  +-+ 3|   |          2
+--R         (- b\|3 \|- 4a c + b   + (2a c - b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                     +--------------------+
+--R                 +-----------+                       |   +-----------+
+--R             +-+ |          2                2  +-+ 3|   |          2
+--R         (2b\|3 \|- 4a c + b   + (- 4a c + 2b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                     +------------------+
+--R                  +-----------+                      | +-----------+
+--R              +-+ |          2               2  +-+ 3| |          2
+--R         (- b\|3 \|- 4a c + b   + (- 2a c + b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                   +------------------+
+--R                 +-----------+                     | +-----------+
+--R             +-+ |          2              2  +-+ 3| |          2
+--R         (2b\|3 \|- 4a c + b   + (4a c - 2b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                          +--------------------+
+--R             +-----------+                |   +-----------+
+--R             |          2              2 3|   |          2
+--R         (6b\|- 4a c + b   - 12a c + 6b )\|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                          +------------------+
+--R             +-----------+                | +-----------+
+--R             |          2              2 3| |          2
+--R         (6b\|- 4a c + b   + 12a c - 6b )\|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                       +--------------------+ +------------------+
+--R                   +-----------+       |   +-----------+      | +-----------+
+--R       2 3+-+2 +-+ |          2 3+-+2 3|   |          2      3| |          2
+--R     3x  \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R        3+-+2 +-+ |          2 3+-+2 3|   |          2      3| |          2
+--R     6c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 679
+
+--S 680 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                            6      2 5
+--R                     (108a c  - 27b c )
+--R                  *
+--R                      +--------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |--------------------------------------------------
+--R                      |      3 13         2 2 12          4 11       6 10
+--R                     \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                      2 2       2     4
+--R                   - a c  + 3a b c - b
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                               4 9         3 2 8         2 4 7          6 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             8 5
+--R                         243b c
+--R                    *
+--R                         +--------------------------------------------------+
+--R                         |      4 2 4      3 4 3      2 6 2        8     10
+--R                         | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                       x |--------------------------------------------------
+--R                         |      3 13         2 2 12          4 11       6 10
+--R                        \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                            4 2 4       3 4 3       2 6 2         8      10
+--R                     (- 540a b c  + 855a b c  - 468a b c  + 108a b c - 9b  )x
+--R                *
+--R                     ROOT
+--R                                     6      2 5
+--R                              (108a c  - 27b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2 4      3 4 3      2 6 2        8
+--R                                     - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                   + 
+--R                                        10
+--R                                     - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                               2 2       2     4
+--R                            - a c  + 3a b c - b
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             4   7       3 3 6      2 5 5
+--R                       (1296a b c  - 648a b c  + 81a b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                        5   3      4 3 2      3 5      2 7
+--R                     60a b c  - 75a b c  + 27a b c - 3a b
+--R                *
+--R                   ROOT
+--R                                   6      2 5
+--R                            (108a c  - 27b c )
+--R                         *
+--R                           +--------------------------------------------------+
+--R                           |      4 2 4      3 4 3      2 6 2        8     10
+--R                           | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                           |--------------------------------------------------
+--R                           |      3 13         2 2 12          4 11       6 10
+--R                          \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                        + 
+--R                             2 2       2     4
+--R                          - a c  + 3a b c - b
+--R                     /
+--R                              6      2 5
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                     5   2      4 3      3 5  2
+--R                 (10a b c  - 10a b c + 2a b )x
+--R     + 
+--R         2c
+--R      *
+--R         ROOT
+--R                           6      2 5
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                   +--------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |--------------------------------------------------
+--R                   |      3 13         2 2 12          4 11       6 10
+--R                  \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R              + 
+--R                   2 2       2     4
+--R                - a c  + 3a b c - b
+--R           /
+--R                    6      2 5
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                              4 9         3 2 8         2 4 7          6 6
+--R                        15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                      + 
+--R                            8 5
+--R                        243b c
+--R                 *
+--R                     +--------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |--------------------------------------------------
+--R                     |      3 13         2 2 12          4 11       6 10
+--R                    \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                + 
+--R                      4 2 4       3 4 3       2 6 2         8      10
+--R                  540a b c  - 855a b c  + 468a b c  - 108a b c + 9b
+--R             *
+--R                  ROOT
+--R                                    6      2 5
+--R                           (- 108a c  + 27b c )
+--R                        *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                       + 
+--R                            2 2       2     4
+--R                         - a c  + 3a b c - b
+--R                    /
+--R                             6      2 5
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                  5   2      4 3      3 5
+--R              (10a b c  - 10a b c + 2a b )x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                              6      2 5
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                      +--------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |--------------------------------------------------
+--R                      |      3 13         2 2 12          4 11       6 10
+--R                     \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                      2 2       2     4
+--R                   - a c  + 3a b c - b
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                 4 9         3 2 8         2 4 7          6 6
+--R                         - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                       + 
+--R                               8 5
+--R                         - 243b c
+--R                    *
+--R                         +--------------------------------------------------+
+--R                         |      4 2 4      3 4 3      2 6 2        8     10
+--R                         | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                       x |--------------------------------------------------
+--R                         |      3 13         2 2 12          4 11       6 10
+--R                        \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                            4 2 4       3 4 3       2 6 2         8      10
+--R                     (- 540a b c  + 855a b c  - 468a b c  + 108a b c - 9b  )x
+--R                *
+--R                     ROOT
+--R                                       6      2 5
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2 4      3 4 3      2 6 2        8
+--R                                     - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                   + 
+--R                                        10
+--R                                     - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                               2 2       2     4
+--R                            - a c  + 3a b c - b
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               4   7       3 3 6      2 5 5
+--R                       (- 1296a b c  + 648a b c  - 81a b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                        5   3      4 3 2      3 5      2 7
+--R                     60a b c  - 75a b c  + 27a b c - 3a b
+--R                *
+--R                   ROOT
+--R                                     6      2 5
+--R                            (- 108a c  + 27b c )
+--R                         *
+--R                           +--------------------------------------------------+
+--R                           |      4 2 4      3 4 3      2 6 2        8     10
+--R                           | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                           |--------------------------------------------------
+--R                           |      3 13         2 2 12          4 11       6 10
+--R                          \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                        + 
+--R                             2 2       2     4
+--R                          - a c  + 3a b c - b
+--R                     /
+--R                              6      2 5
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                     5   2      4 3      3 5  2
+--R                 (10a b c  - 10a b c + 2a b )x
+--R     + 
+--R         2c
+--R      *
+--R         ROOT
+--R                         6      2 5
+--R                  (108a c  - 27b c )
+--R               *
+--R                   +--------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |--------------------------------------------------
+--R                   |      3 13         2 2 12          4 11       6 10
+--R                  \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R              + 
+--R                   2 2       2     4
+--R                - a c  + 3a b c - b
+--R           /
+--R                    6      2 5
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                              4 9         3 2 8         2 4 7          6 6
+--R                      - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                    + 
+--R                            8 5
+--R                      - 243b c
+--R                 *
+--R                     +--------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |--------------------------------------------------
+--R                     |      3 13         2 2 12          4 11       6 10
+--R                    \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                + 
+--R                      4 2 4       3 4 3       2 6 2         8      10
+--R                  540a b c  - 855a b c  + 468a b c  - 108a b c + 9b
+--R             *
+--R                  ROOT
+--R                                  6      2 5
+--R                           (108a c  - 27b c )
+--R                        *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                       + 
+--R                            2 2       2     4
+--R                         - a c  + 3a b c - b
+--R                    /
+--R                             6      2 5
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                  5   2      4 3      3 5
+--R              (10a b c  - 10a b c + 2a b )x
+--R     + 
+--R       -
+--R               +-+
+--R            2c\|3
+--R         *
+--R            ROOT
+--R                              6      2 5
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                      +--------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |--------------------------------------------------
+--R                      |      3 13         2 2 12          4 11       6 10
+--R                     \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                      2 2       2     4
+--R                   - a c  + 3a b c - b
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                               4 9         3 2 8         2 4 7          6 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             8 5
+--R                         243b c
+--R                    *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                      +-+ | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     \|3  |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                          4 2 4       3 4 3       2 6 2         8      10  +-+
+--R                     (540a b c  - 855a b c  + 468a b c  - 108a b c + 9b  )\|3
+--R                *
+--R                     ROOT
+--R                                       6      2 5
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2 4      3 4 3      2 6 2        8
+--R                                     - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                   + 
+--R                                        10
+--R                                     - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                               2 2       2     4
+--R                            - a c  + 3a b c - b
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                 4 9         3 2 8         2 4 7          6 6
+--R                           15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                         + 
+--R                               8 5
+--R                           243b c
+--R                      *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                     + 
+--R                           4 2 4       3 4 3       2 6 2         8      10
+--R                       540a b c  - 855a b c  + 468a b c  - 108a b c + 9b
+--R                  *
+--R                       ROOT
+--R                                         6      2 5
+--R                                (- 108a c  + 27b c )
+--R                             *
+--R                                ROOT
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  /
+--R                                             3 13         2 2 12          4 11
+--R                                       46656a c   - 34992a b c   + 8748a b c
+--R                                     + 
+--R                                             6 10
+--R                                       - 729b c
+--R                            + 
+--R                                 2 2       2     4
+--R                              - a c  + 3a b c - b
+--R                         /
+--R                                  6      2 5
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                         5   2      4 3      3 5
+--R                   (- 20a b c  + 20a b c - 4a b )x
+--R     + 
+--R       -
+--R               +-+
+--R            2c\|3
+--R         *
+--R            ROOT
+--R                            6      2 5
+--R                     (108a c  - 27b c )
+--R                  *
+--R                      +--------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |--------------------------------------------------
+--R                      |      3 13         2 2 12          4 11       6 10
+--R                     \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                      2 2       2     4
+--R                   - a c  + 3a b c - b
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                               4 9         3 2 8         2 4 7          6 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             8 5
+--R                         243b c
+--R                    *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                      +-+ | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     \|3  |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                          4 2 4       3 4 3       2 6 2         8      10  +-+
+--R                   (- 540a b c  + 855a b c  - 468a b c  + 108a b c - 9b  )\|3
+--R                *
+--R                     ROOT
+--R                                     6      2 5
+--R                              (108a c  - 27b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2 4      3 4 3      2 6 2        8
+--R                                     - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                   + 
+--R                                        10
+--R                                     - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                               2 2       2     4
+--R                            - a c  + 3a b c - b
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                 4 9         3 2 8         2 4 7          6 6
+--R                           15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                         + 
+--R                               8 5
+--R                           243b c
+--R                      *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                     + 
+--R                             4 2 4       3 4 3       2 6 2         8      10
+--R                       - 540a b c  + 855a b c  - 468a b c  + 108a b c - 9b
+--R                  *
+--R                       ROOT
+--R                                       6      2 5
+--R                                (108a c  - 27b c )
+--R                             *
+--R                                ROOT
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  /
+--R                                             3 13         2 2 12          4 11
+--R                                       46656a c   - 34992a b c   + 8748a b c
+--R                                     + 
+--R                                             6 10
+--R                                       - 729b c
+--R                            + 
+--R                                 2 2       2     4
+--R                              - a c  + 3a b c - b
+--R                         /
+--R                                  6      2 5
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                       5   2      4 3      3 5
+--R                   (20a b c  - 20a b c + 4a b )x
+--R     + 
+--R        2
+--R       x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 680
+
+--S 681 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                             +--------------------+
+--R                         +-----------+       |   +-----------+
+--R               3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R            3c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            6      2 5
+--R                     (108a c  - 27b c )
+--R                  *
+--R                      +--------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |--------------------------------------------------
+--R                      |      3 13         2 2 12          4 11       6 10
+--R                     \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                      2 2       2     4
+--R                   - a c  + 3a b c - b
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                               4 9         3 2 8         2 4 7          6 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             8 5
+--R                         243b c
+--R                    *
+--R                         +--------------------------------------------------+
+--R                         |      4 2 4      3 4 3      2 6 2        8     10
+--R                         | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                       x |--------------------------------------------------
+--R                         |      3 13         2 2 12          4 11       6 10
+--R                        \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                            4 2 4       3 4 3       2 6 2         8      10
+--R                     (- 540a b c  + 855a b c  - 468a b c  + 108a b c - 9b  )x
+--R                *
+--R                     ROOT
+--R                                     6      2 5
+--R                              (108a c  - 27b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2 4      3 4 3      2 6 2        8
+--R                                     - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                   + 
+--R                                        10
+--R                                     - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                               2 2       2     4
+--R                            - a c  + 3a b c - b
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             4   7       3 3 6      2 5 5
+--R                       (1296a b c  - 648a b c  + 81a b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                        5   3      4 3 2      3 5      2 7
+--R                     60a b c  - 75a b c  + 27a b c - 3a b
+--R                *
+--R                   ROOT
+--R                                   6      2 5
+--R                            (108a c  - 27b c )
+--R                         *
+--R                           +--------------------------------------------------+
+--R                           |      4 2 4      3 4 3      2 6 2        8     10
+--R                           | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                           |--------------------------------------------------
+--R                           |      3 13         2 2 12          4 11       6 10
+--R                          \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                        + 
+--R                             2 2       2     4
+--R                          - a c  + 3a b c - b
+--R                     /
+--R                              6      2 5
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                     5   2      4 3      3 5  2
+--R                 (10a b c  - 10a b c + 2a b )x
+--R     + 
+--R                                                   +--------------------+
+--R                +-----------+                      |   +-----------+
+--R            +-+ |          2               2  +-+ 3|   |          2
+--R         (b\|3 \|- 4a c + b   + (- 2a c + b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                     +--------------------+
+--R                   +-----------+                     |   +-----------+
+--R               +-+ |          2              2  +-+ 3|   |          2
+--R         (- 2b\|3 \|- 4a c + b   + (4a c - 2b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                 +------------------+
+--R                +-----------+                    | +-----------+
+--R            +-+ |          2             2  +-+ 3| |          2
+--R         (b\|3 \|- 4a c + b   + (2a c - b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                       +------------------+
+--R                   +-----------+                       | +-----------+
+--R               +-+ |          2                2  +-+ 3| |          2
+--R         (- 2b\|3 \|- 4a c + b   + (- 4a c + 2b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                      +-----------+
+--R            3+-+2 +-+ |          2 3+-+2
+--R         6c \|2  \|3 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                           6      2 5
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                   +--------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |--------------------------------------------------
+--R                   |      3 13         2 2 12          4 11       6 10
+--R                  \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R              + 
+--R                   2 2       2     4
+--R                - a c  + 3a b c - b
+--R           /
+--R                    6      2 5
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         3|   |          2      3| |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              4 9         3 2 8         2 4 7          6 6
+--R                        15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                      + 
+--R                            8 5
+--R                        243b c
+--R                 *
+--R                     +--------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |--------------------------------------------------
+--R                     |      3 13         2 2 12          4 11       6 10
+--R                    \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                + 
+--R                      4 2 4       3 4 3       2 6 2         8      10
+--R                  540a b c  - 855a b c  + 468a b c  - 108a b c + 9b
+--R             *
+--R                  ROOT
+--R                                    6      2 5
+--R                           (- 108a c  + 27b c )
+--R                        *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                       + 
+--R                            2 2       2     4
+--R                         - a c  + 3a b c - b
+--R                    /
+--R                             6      2 5
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                  5   2      4 3      3 5
+--R              (10a b c  - 10a b c + 2a b )x
+--R     + 
+--R       -
+--R                         +-----------+
+--R               3+-+2 +-+ |          2 3+-+2
+--R            3c \|2  \|3 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                              6      2 5
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                      +--------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |--------------------------------------------------
+--R                      |      3 13         2 2 12          4 11       6 10
+--R                     \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                      2 2       2     4
+--R                   - a c  + 3a b c - b
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R            3|   |          2      3| |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                 4 9         3 2 8         2 4 7          6 6
+--R                         - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                       + 
+--R                               8 5
+--R                         - 243b c
+--R                    *
+--R                         +--------------------------------------------------+
+--R                         |      4 2 4      3 4 3      2 6 2        8     10
+--R                         | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                       x |--------------------------------------------------
+--R                         |      3 13         2 2 12          4 11       6 10
+--R                        \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                            4 2 4       3 4 3       2 6 2         8      10
+--R                     (- 540a b c  + 855a b c  - 468a b c  + 108a b c - 9b  )x
+--R                *
+--R                     ROOT
+--R                                       6      2 5
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2 4      3 4 3      2 6 2        8
+--R                                     - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                   + 
+--R                                        10
+--R                                     - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                               2 2       2     4
+--R                            - a c  + 3a b c - b
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               4   7       3 3 6      2 5 5
+--R                       (- 1296a b c  + 648a b c  - 81a b c )
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |--------------------------------------------------
+--R                        |      3 13         2 2 12          4 11       6 10
+--R                       \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                        5   3      4 3 2      3 5      2 7
+--R                     60a b c  - 75a b c  + 27a b c - 3a b
+--R                *
+--R                   ROOT
+--R                                     6      2 5
+--R                            (- 108a c  + 27b c )
+--R                         *
+--R                           +--------------------------------------------------+
+--R                           |      4 2 4      3 4 3      2 6 2        8     10
+--R                           | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                           |--------------------------------------------------
+--R                           |      3 13         2 2 12          4 11       6 10
+--R                          \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                        + 
+--R                             2 2       2     4
+--R                          - a c  + 3a b c - b
+--R                     /
+--R                              6      2 5
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                     5   2      4 3      3 5  2
+--R                 (10a b c  - 10a b c + 2a b )x
+--R     + 
+--R                                          +--------------------+
+--R                      +-----------+       |   +-----------+
+--R            3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R         6c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         6      2 5
+--R                  (108a c  - 27b c )
+--R               *
+--R                   +--------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |--------------------------------------------------
+--R                   |      3 13         2 2 12          4 11       6 10
+--R                  \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R              + 
+--R                   2 2       2     4
+--R                - a c  + 3a b c - b
+--R           /
+--R                    6      2 5
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                              4 9         3 2 8         2 4 7          6 6
+--R                      - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                    + 
+--R                            8 5
+--R                      - 243b c
+--R                 *
+--R                     +--------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |--------------------------------------------------
+--R                     |      3 13         2 2 12          4 11       6 10
+--R                    \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                + 
+--R                      4 2 4       3 4 3       2 6 2         8      10
+--R                  540a b c  - 855a b c  + 468a b c  - 108a b c + 9b
+--R             *
+--R                  ROOT
+--R                                  6      2 5
+--R                           (108a c  - 27b c )
+--R                        *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                       + 
+--R                            2 2       2     4
+--R                         - a c  + 3a b c - b
+--R                    /
+--R                             6      2 5
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                  5   2      4 3      3 5
+--R              (10a b c  - 10a b c + 2a b )x
+--R     + 
+--R       -
+--R                      +-----------+
+--R                3+-+2 |          2 3+-+2
+--R            18c \|2  \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                              6      2 5
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                      +--------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |--------------------------------------------------
+--R                      |      3 13         2 2 12          4 11       6 10
+--R                     \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                      2 2       2     4
+--R                   - a c  + 3a b c - b
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R            3|   |          2      3| |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            atan
+--R                               4 9         3 2 8         2 4 7          6 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             8 5
+--R                         243b c
+--R                    *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                      +-+ | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     \|3  |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                          4 2 4       3 4 3       2 6 2         8      10  +-+
+--R                     (540a b c  - 855a b c  + 468a b c  - 108a b c + 9b  )\|3
+--R                *
+--R                     ROOT
+--R                                       6      2 5
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2 4      3 4 3      2 6 2        8
+--R                                     - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                   + 
+--R                                        10
+--R                                     - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                               2 2       2     4
+--R                            - a c  + 3a b c - b
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                 4 9         3 2 8         2 4 7          6 6
+--R                           15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                         + 
+--R                               8 5
+--R                           243b c
+--R                      *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                     + 
+--R                           4 2 4       3 4 3       2 6 2         8      10
+--R                       540a b c  - 855a b c  + 468a b c  - 108a b c + 9b
+--R                  *
+--R                       ROOT
+--R                                         6      2 5
+--R                                (- 108a c  + 27b c )
+--R                             *
+--R                                ROOT
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  /
+--R                                             3 13         2 2 12          4 11
+--R                                       46656a c   - 34992a b c   + 8748a b c
+--R                                     + 
+--R                                             6 10
+--R                                       - 729b c
+--R                            + 
+--R                                 2 2       2     4
+--R                              - a c  + 3a b c - b
+--R                         /
+--R                                  6      2 5
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                         5   2      4 3      3 5
+--R                   (- 20a b c  + 20a b c - 4a b )x
+--R     + 
+--R       -
+--R                                          +--------------------+
+--R                      +-----------+       |   +-----------+
+--R                3+-+2 |          2 3+-+2 3|   |          2
+--R            18c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            6      2 5
+--R                     (108a c  - 27b c )
+--R                  *
+--R                      +--------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |--------------------------------------------------
+--R                      |      3 13         2 2 12          4 11       6 10
+--R                     \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                      2 2       2     4
+--R                   - a c  + 3a b c - b
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                               4 9         3 2 8         2 4 7          6 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             8 5
+--R                         243b c
+--R                    *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                      +-+ | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     \|3  |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                          4 2 4       3 4 3       2 6 2         8      10  +-+
+--R                   (- 540a b c  + 855a b c  - 468a b c  + 108a b c - 9b  )\|3
+--R                *
+--R                     ROOT
+--R                                     6      2 5
+--R                              (108a c  - 27b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2 4      3 4 3      2 6 2        8
+--R                                     - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                   + 
+--R                                        10
+--R                                     - b
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                               2 2       2     4
+--R                            - a c  + 3a b c - b
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                 4 9         3 2 8         2 4 7          6 6
+--R                           15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                         + 
+--R                               8 5
+--R                           243b c
+--R                      *
+--R                          +--------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |--------------------------------------------------
+--R                          |      3 13         2 2 12          4 11       6 10
+--R                         \|46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                     + 
+--R                             4 2 4       3 4 3       2 6 2         8      10
+--R                       - 540a b c  + 855a b c  - 468a b c  + 108a b c - 9b
+--R                  *
+--R                       ROOT
+--R                                       6      2 5
+--R                                (108a c  - 27b c )
+--R                             *
+--R                                ROOT
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  /
+--R                                             3 13         2 2 12          4 11
+--R                                       46656a c   - 34992a b c   + 8748a b c
+--R                                     + 
+--R                                             6 10
+--R                                       - 729b c
+--R                            + 
+--R                                 2 2       2     4
+--R                              - a c  + 3a b c - b
+--R                         /
+--R                                  6      2 5
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                       5   2      4 3      3 5
+--R                   (20a b c  - 20a b c + 4a b )x
+--R     + 
+--R                                            +--------------------+
+--R               +-----------+                |   +-----------+
+--R               |          2              2 3|   |          2
+--R         (- 6b\|- 4a c + b   + 12a c - 6b )\|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                            +------------------+
+--R               +-----------+                | +-----------+
+--R               |          2              2 3| |          2
+--R         (- 6b\|- 4a c + b   - 12a c + 6b )\|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R        3+-+2 +-+ |          2 3+-+2 3|   |          2      3| |          2
+--R     6c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 682
+
+)clear all
+
+--S 683 of 2282
+t0:=x^6/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                6
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 683
+
+--S 684 of 2282
+r0:=x/c-1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(b+_
+   (-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b-sqrt(b^2-_
+   4*a*c))^(2/3))+1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*_
+   (b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(b+(-b^2+2*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b-sqrt(b^2-4*a*c))^(2/3))+_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*c^(4/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(2/3))-1/3*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*c^(4/3)*(b+sqrt(b^2-4*a*c))^(2/3))+1/6*log(2^(2/3)*c^(2/3)*x^2-_
+   2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b+sqrt(b^2-_
+   4*a*c))^(2/3))+atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                                                   +--------------------+2
+--R                +-----------+                      |   +-----------+
+--R            +-+ |          2               2  +-+ 3|   |          2
+--R         (b\|3 \|- 4a c + b   + (- 2a c + b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                     +--------------------+2
+--R                   +-----------+                     |   +-----------+
+--R               +-+ |          2              2  +-+ 3|   |          2
+--R         (- 2b\|3 \|- 4a c + b   + (4a c - 2b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                 +------------------+2
+--R                +-----------+                    | +-----------+
+--R            +-+ |          2             2  +-+ 3| |          2
+--R         (b\|3 \|- 4a c + b   + (2a c - b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                       +------------------+2
+--R                   +-----------+                       | +-----------+
+--R               +-+ |          2                2  +-+ 3| |          2
+--R         (- 2b\|3 \|- 4a c + b   + (- 4a c + 2b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                          +--------------------+2
+--R             +-----------+                |   +-----------+
+--R             |          2              2 3|   |          2
+--R         (6b\|- 4a c + b   - 12a c + 6b )\|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                          +------------------+2
+--R             +-----------+                | +-----------+
+--R             |          2              2 3| |          2
+--R         (6b\|- 4a c + b   + 12a c - 6b )\|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                  +--------------------+2  +------------------+2
+--R                +-----------+     |   +-----------+        | +-----------+
+--R       3+-+ +-+ |          2 3+-+3|   |          2        3| |          2
+--R     6x\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+2  +------------------+2
+--R                +-----------+     |   +-----------+        | +-----------+
+--R       3+-+ +-+ |          2 3+-+3|   |          2        3| |          2
+--R     6c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 684
+
+--S 685 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2c
+--R      *
+--R         ROOT
+--R                         5      2 4
+--R                  (108a c  - 27b c )
+--R               *
+--R                   +------------------------------------------------+
+--R                   |       4 4      3 2 3      2 4 2       6     8
+--R                   |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |------------------------------------------------
+--R                   |      3 11         2 2 10          4 9       6 8
+--R                  \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                            3
+--R                - 2a b c + b
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                          2   6         3 5      5 4
+--R                    (1296a b c  - 648a b c  + 81b c )
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |       4 4      3 2 3      2 4 2       6     8
+--R                     |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |------------------------------------------------
+--R                     |      3 11         2 2 10          4 9       6 8
+--R                    \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                       3 3      2 2 2        4      6
+--R                  - 24a c  + 54a b c  - 24a b c + 3b
+--R             *
+--R                ROOT
+--R                                5      2 4
+--R                         (108a c  - 27b c )
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |       4 4      3 2 3      2 4 2       6     8
+--R                          |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |------------------------------------------------
+--R                          |      3 11         2 2 10          4 9       6 8
+--R                         \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                   3
+--R                       - 2a b c + b
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R                 3 2     2 2        4
+--R              (4a c  - 8a b c + 2a b )x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                              5      2 4
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                      +------------------------------------------------+
+--R                      |       4 4      3 2 3      2 4 2       6     8
+--R                      |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |------------------------------------------------
+--R                      |      3 11         2 2 10          4 9       6 8
+--R                     \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                 + 
+--R                               3
+--R                   - 2a b c + b
+--R              /
+--R                       5      2 4
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                              3   7         2 3 6          5 5       7 4
+--R                       (15552a b c  - 11664a b c  + 2916a b c  - 243b c )
+--R                    *
+--R                        +------------------------------------------------+
+--R                        |       4 4      3 2 3      2 4 2       6     8
+--R                        |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |------------------------------------------------
+--R                        |      3 11         2 2 10          4 9       6 8
+--R                       \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                         4 4       3 2 3       2 4 2        6      8
+--R                     144a c  - 396a b c  + 306a b c  - 90a b c + 9b
+--R                *
+--R                     ROOT
+--R                                       5      2 4
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                             +------------------------------------------------+
+--R                             |       4 4      3 2 3      2 4 2       6     8
+--R                             |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |------------------------------------------------
+--R                             |      3 11         2 2 10          4 9       6 8
+--R                            \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                          + 
+--R                                        3
+--R                            - 2a b c + b
+--R                       /
+--R                                5      2 4
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             3   6       2 3 5        5 4
+--R                       (1296a b c  - 648a b c  + 81a b c )x
+--R                    *
+--R                        +------------------------------------------------+
+--R                        |       4 4      3 2 3      2 4 2       6     8
+--R                        |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |------------------------------------------------
+--R                        |      3 11         2 2 10          4 9       6 8
+--R                       \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                         4 3      3 2 2      2 4        6
+--R                     (24a c  - 54a b c  + 24a b c - 3a b )x
+--R                *
+--R                   ROOT
+--R                                     5      2 4
+--R                            (- 108a c  + 27b c )
+--R                         *
+--R                             +------------------------------------------------+
+--R                             |       4 4      3 2 3      2 4 2       6     8
+--R                             |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |------------------------------------------------
+--R                             |      3 11         2 2 10          4 9       6 8
+--R                            \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                        + 
+--R                                      3
+--R                          - 2a b c + b
+--R                     /
+--R                              5      2 4
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    4 2     3 2      2 4  2
+--R                 (4a c  - 8a b c + 2a b )x
+--R     + 
+--R         2c
+--R      *
+--R         ROOT
+--R                           5      2 4
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                   +------------------------------------------------+
+--R                   |       4 4      3 2 3      2 4 2       6     8
+--R                   |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |------------------------------------------------
+--R                   |      3 11         2 2 10          4 9       6 8
+--R                  \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                            3
+--R                - 2a b c + b
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                            2   6         3 5      5 4
+--R                    (- 1296a b c  + 648a b c  - 81b c )
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |       4 4      3 2 3      2 4 2       6     8
+--R                     |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |------------------------------------------------
+--R                     |      3 11         2 2 10          4 9       6 8
+--R                    \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                       3 3      2 2 2        4      6
+--R                  - 24a c  + 54a b c  - 24a b c + 3b
+--R             *
+--R                ROOT
+--R                                  5      2 4
+--R                         (- 108a c  + 27b c )
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |       4 4      3 2 3      2 4 2       6     8
+--R                          |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |------------------------------------------------
+--R                          |      3 11         2 2 10          4 9       6 8
+--R                         \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                   3
+--R                       - 2a b c + b
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R                 3 2     2 2        4
+--R              (4a c  - 8a b c + 2a b )x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                            5      2 4
+--R                     (108a c  - 27b c )
+--R                  *
+--R                      +------------------------------------------------+
+--R                      |       4 4      3 2 3      2 4 2       6     8
+--R                      |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |------------------------------------------------
+--R                      |      3 11         2 2 10          4 9       6 8
+--R                     \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                 + 
+--R                               3
+--R                   - 2a b c + b
+--R              /
+--R                       5      2 4
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                3   7         2 3 6          5 5       7 4
+--R                       (- 15552a b c  + 11664a b c  - 2916a b c  + 243b c )
+--R                    *
+--R                        +------------------------------------------------+
+--R                        |       4 4      3 2 3      2 4 2       6     8
+--R                        |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |------------------------------------------------
+--R                        |      3 11         2 2 10          4 9       6 8
+--R                       \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                         4 4       3 2 3       2 4 2        6      8
+--R                     144a c  - 396a b c  + 306a b c  - 90a b c + 9b
+--R                *
+--R                     ROOT
+--R                                     5      2 4
+--R                              (108a c  - 27b c )
+--R                           *
+--R                             +------------------------------------------------+
+--R                             |       4 4      3 2 3      2 4 2       6     8
+--R                             |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |------------------------------------------------
+--R                             |      3 11         2 2 10          4 9       6 8
+--R                            \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                          + 
+--R                                        3
+--R                            - 2a b c + b
+--R                       /
+--R                                5      2 4
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               3   6       2 3 5        5 4
+--R                       (- 1296a b c  + 648a b c  - 81a b c )x
+--R                    *
+--R                        +------------------------------------------------+
+--R                        |       4 4      3 2 3      2 4 2       6     8
+--R                        |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |------------------------------------------------
+--R                        |      3 11         2 2 10          4 9       6 8
+--R                       \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                         4 3      3 2 2      2 4        6
+--R                     (24a c  - 54a b c  + 24a b c - 3a b )x
+--R                *
+--R                   ROOT
+--R                                   5      2 4
+--R                            (108a c  - 27b c )
+--R                         *
+--R                             +------------------------------------------------+
+--R                             |       4 4      3 2 3      2 4 2       6     8
+--R                             |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |------------------------------------------------
+--R                             |      3 11         2 2 10          4 9       6 8
+--R                            \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                        + 
+--R                                      3
+--R                          - 2a b c + b
+--R                     /
+--R                              5      2 4
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    4 2     3 2      2 4  2
+--R                 (4a c  - 8a b c + 2a b )x
+--R     + 
+--R            +-+
+--R         2c\|3
+--R      *
+--R         ROOT
+--R                         5      2 4
+--R                  (108a c  - 27b c )
+--R               *
+--R                   +------------------------------------------------+
+--R                   |       4 4      3 2 3      2 4 2       6     8
+--R                   |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |------------------------------------------------
+--R                   |      3 11         2 2 10          4 9       6 8
+--R                  \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                            3
+--R                - 2a b c + b
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                          2   6         3 5      5 4  +-+
+--R                    (1296a b c  - 648a b c  + 81b c )\|3
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |       4 4      3 2 3      2 4 2       6     8
+--R                     |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |------------------------------------------------
+--R                     |      3 11         2 2 10          4 9       6 8
+--R                    \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                        3 3      2 2 2        4      6  +-+
+--R                  (- 24a c  + 54a b c  - 24a b c + 3b )\|3
+--R             *
+--R                ROOT
+--R                                5      2 4
+--R                         (108a c  - 27b c )
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |       4 4      3 2 3      2 4 2       6     8
+--R                          |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |------------------------------------------------
+--R                          |      3 11         2 2 10          4 9       6 8
+--R                         \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                   3
+--R                       - 2a b c + b
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                            2   6         3 5      5 4
+--R                      (1296a b c  - 648a b c  + 81b c )
+--R                   *
+--R                       +------------------------------------------------+
+--R                       |       4 4      3 2 3      2 4 2       6     8
+--R                       |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |------------------------------------------------
+--R                       |      3 11         2 2 10          4 9       6 8
+--R                      \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                  + 
+--R                         3 3      2 2 2        4      6
+--R                    - 24a c  + 54a b c  - 24a b c + 3b
+--R               *
+--R                  ROOT
+--R                                  5      2 4
+--R                           (108a c  - 27b c )
+--R                        *
+--R                            +------------------------------------------------+
+--R                            |       4 4      3 2 3      2 4 2       6     8
+--R                            |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |------------------------------------------------
+--R                            |      3 11         2 2 10          4 9       6 8
+--R                           \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                       + 
+--R                                     3
+--R                         - 2a b c + b
+--R                    /
+--R                             5      2 4
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                     3 2      2 2        4
+--R                (- 8a c  + 16a b c - 4a b )x
+--R     + 
+--R            +-+
+--R         2c\|3
+--R      *
+--R         ROOT
+--R                           5      2 4
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                   +------------------------------------------------+
+--R                   |       4 4      3 2 3      2 4 2       6     8
+--R                   |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |------------------------------------------------
+--R                   |      3 11         2 2 10          4 9       6 8
+--R                  \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                            3
+--R                - 2a b c + b
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                          2   6         3 5      5 4  +-+
+--R                    (1296a b c  - 648a b c  + 81b c )\|3
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |       4 4      3 2 3      2 4 2       6     8
+--R                     |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |------------------------------------------------
+--R                     |      3 11         2 2 10          4 9       6 8
+--R                    \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                      3 3      2 2 2        4      6  +-+
+--R                  (24a c  - 54a b c  + 24a b c - 3b )\|3
+--R             *
+--R                ROOT
+--R                                  5      2 4
+--R                         (- 108a c  + 27b c )
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |       4 4      3 2 3      2 4 2       6     8
+--R                          |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |------------------------------------------------
+--R                          |      3 11         2 2 10          4 9       6 8
+--R                         \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                   3
+--R                       - 2a b c + b
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                            2   6         3 5      5 4
+--R                      (1296a b c  - 648a b c  + 81b c )
+--R                   *
+--R                       +------------------------------------------------+
+--R                       |       4 4      3 2 3      2 4 2       6     8
+--R                       |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |------------------------------------------------
+--R                       |      3 11         2 2 10          4 9       6 8
+--R                      \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                  + 
+--R                       3 3      2 2 2        4      6
+--R                    24a c  - 54a b c  + 24a b c - 3b
+--R               *
+--R                  ROOT
+--R                                    5      2 4
+--R                           (- 108a c  + 27b c )
+--R                        *
+--R                            +------------------------------------------------+
+--R                            |       4 4      3 2 3      2 4 2       6     8
+--R                            |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |------------------------------------------------
+--R                            |      3 11         2 2 10          4 9       6 8
+--R                           \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                       + 
+--R                                     3
+--R                         - 2a b c + b
+--R                    /
+--R                             5      2 4
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                   3 2      2 2        4
+--R                (8a c  - 16a b c + 4a b )x
+--R     + 
+--R       2x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 685
+
+--S 686 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +--------------------+2
+--R                    +-----------+     |   +-----------+
+--R           3+-+ +-+ |          2 3+-+3|   |          2
+--R         6c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         5      2 4
+--R                  (108a c  - 27b c )
+--R               *
+--R                   +------------------------------------------------+
+--R                   |       4 4      3 2 3      2 4 2       6     8
+--R                   |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |------------------------------------------------
+--R                   |      3 11         2 2 10          4 9       6 8
+--R                  \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                            3
+--R                - 2a b c + b
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                          2   6         3 5      5 4
+--R                    (1296a b c  - 648a b c  + 81b c )
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |       4 4      3 2 3      2 4 2       6     8
+--R                     |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |------------------------------------------------
+--R                     |      3 11         2 2 10          4 9       6 8
+--R                    \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                       3 3      2 2 2        4      6
+--R                  - 24a c  + 54a b c  - 24a b c + 3b
+--R             *
+--R                ROOT
+--R                                5      2 4
+--R                         (108a c  - 27b c )
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |       4 4      3 2 3      2 4 2       6     8
+--R                          |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |------------------------------------------------
+--R                          |      3 11         2 2 10          4 9       6 8
+--R                         \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                   3
+--R                       - 2a b c + b
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R                 3 2     2 2        4
+--R              (4a c  - 8a b c + 2a b )x
+--R     + 
+--R                                                   +--------------------+2
+--R                  +-----------+                    |   +-----------+
+--R              +-+ |          2             2  +-+ 3|   |          2
+--R         (- b\|3 \|- 4a c + b   + (2a c - b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                     +--------------------+2
+--R                 +-----------+                       |   +-----------+
+--R             +-+ |          2                2  +-+ 3|   |          2
+--R         (2b\|3 \|- 4a c + b   + (- 4a c + 2b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                     +------------------+2
+--R                  +-----------+                      | +-----------+
+--R              +-+ |          2               2  +-+ 3| |          2
+--R         (- b\|3 \|- 4a c + b   + (- 2a c + b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                   +------------------+2
+--R                 +-----------+                     | +-----------+
+--R             +-+ |          2              2  +-+ 3| |          2
+--R         (2b\|3 \|- 4a c + b   + (4a c - 2b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                       +-----------+
+--R              3+-+ +-+ |          2 3+-+
+--R            3c\|2 \|3 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                              5      2 4
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                      +------------------------------------------------+
+--R                      |       4 4      3 2 3      2 4 2       6     8
+--R                      |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |------------------------------------------------
+--R                      |      3 11         2 2 10          4 9       6 8
+--R                     \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                 + 
+--R                               3
+--R                   - 2a b c + b
+--R              /
+--R                       5      2 4
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R             +--------------------+2  +------------------+2
+--R             |   +-----------+        | +-----------+
+--R            3|   |          2        3| |          2
+--R            \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                              3   7         2 3 6          5 5       7 4
+--R                       (15552a b c  - 11664a b c  + 2916a b c  - 243b c )
+--R                    *
+--R                        +------------------------------------------------+
+--R                        |       4 4      3 2 3      2 4 2       6     8
+--R                        |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |------------------------------------------------
+--R                        |      3 11         2 2 10          4 9       6 8
+--R                       \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                         4 4       3 2 3       2 4 2        6      8
+--R                     144a c  - 396a b c  + 306a b c  - 90a b c + 9b
+--R                *
+--R                     ROOT
+--R                                       5      2 4
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                             +------------------------------------------------+
+--R                             |       4 4      3 2 3      2 4 2       6     8
+--R                             |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |------------------------------------------------
+--R                             |      3 11         2 2 10          4 9       6 8
+--R                            \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                          + 
+--R                                        3
+--R                            - 2a b c + b
+--R                       /
+--R                                5      2 4
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             3   6       2 3 5        5 4
+--R                       (1296a b c  - 648a b c  + 81a b c )x
+--R                    *
+--R                        +------------------------------------------------+
+--R                        |       4 4      3 2 3      2 4 2       6     8
+--R                        |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |------------------------------------------------
+--R                        |      3 11         2 2 10          4 9       6 8
+--R                       \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                         4 3      3 2 2      2 4        6
+--R                     (24a c  - 54a b c  + 24a b c - 3a b )x
+--R                *
+--R                   ROOT
+--R                                     5      2 4
+--R                            (- 108a c  + 27b c )
+--R                         *
+--R                             +------------------------------------------------+
+--R                             |       4 4      3 2 3      2 4 2       6     8
+--R                             |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |------------------------------------------------
+--R                             |      3 11         2 2 10          4 9       6 8
+--R                            \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                        + 
+--R                                      3
+--R                          - 2a b c + b
+--R                     /
+--R                              5      2 4
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    4 2     3 2      2 4  2
+--R                 (4a c  - 8a b c + 2a b )x
+--R     + 
+--R                    +-----------+
+--R           3+-+ +-+ |          2 3+-+
+--R         6c\|2 \|3 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                           5      2 4
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                   +------------------------------------------------+
+--R                   |       4 4      3 2 3      2 4 2       6     8
+--R                   |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |------------------------------------------------
+--R                   |      3 11         2 2 10          4 9       6 8
+--R                  \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                            3
+--R                - 2a b c + b
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R          +--------------------+2  +------------------+2
+--R          |   +-----------+        | +-----------+
+--R         3|   |          2        3| |          2
+--R         \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            2   6         3 5      5 4
+--R                    (- 1296a b c  + 648a b c  - 81b c )
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |       4 4      3 2 3      2 4 2       6     8
+--R                     |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |------------------------------------------------
+--R                     |      3 11         2 2 10          4 9       6 8
+--R                    \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                       3 3      2 2 2        4      6
+--R                  - 24a c  + 54a b c  - 24a b c + 3b
+--R             *
+--R                ROOT
+--R                                  5      2 4
+--R                         (- 108a c  + 27b c )
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |       4 4      3 2 3      2 4 2       6     8
+--R                          |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |------------------------------------------------
+--R                          |      3 11         2 2 10          4 9       6 8
+--R                         \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                   3
+--R                       - 2a b c + b
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R                 3 2     2 2        4
+--R              (4a c  - 8a b c + 2a b )x
+--R     + 
+--R       -
+--R                                         +--------------------+2
+--R                       +-----------+     |   +-----------+
+--R              3+-+ +-+ |          2 3+-+3|   |          2
+--R            3c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R             +------------------+2
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            5      2 4
+--R                     (108a c  - 27b c )
+--R                  *
+--R                      +------------------------------------------------+
+--R                      |       4 4      3 2 3      2 4 2       6     8
+--R                      |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |------------------------------------------------
+--R                      |      3 11         2 2 10          4 9       6 8
+--R                     \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                 + 
+--R                               3
+--R                   - 2a b c + b
+--R              /
+--R                       5      2 4
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                3   7         2 3 6          5 5       7 4
+--R                       (- 15552a b c  + 11664a b c  - 2916a b c  + 243b c )
+--R                    *
+--R                        +------------------------------------------------+
+--R                        |       4 4      3 2 3      2 4 2       6     8
+--R                        |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |------------------------------------------------
+--R                        |      3 11         2 2 10          4 9       6 8
+--R                       \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                         4 4       3 2 3       2 4 2        6      8
+--R                     144a c  - 396a b c  + 306a b c  - 90a b c + 9b
+--R                *
+--R                     ROOT
+--R                                     5      2 4
+--R                              (108a c  - 27b c )
+--R                           *
+--R                             +------------------------------------------------+
+--R                             |       4 4      3 2 3      2 4 2       6     8
+--R                             |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |------------------------------------------------
+--R                             |      3 11         2 2 10          4 9       6 8
+--R                            \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                          + 
+--R                                        3
+--R                            - 2a b c + b
+--R                       /
+--R                                5      2 4
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               3   6       2 3 5        5 4
+--R                       (- 1296a b c  + 648a b c  - 81a b c )x
+--R                    *
+--R                        +------------------------------------------------+
+--R                        |       4 4      3 2 3      2 4 2       6     8
+--R                        |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |------------------------------------------------
+--R                        |      3 11         2 2 10          4 9       6 8
+--R                       \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                         4 3      3 2 2      2 4        6
+--R                     (24a c  - 54a b c  + 24a b c - 3a b )x
+--R                *
+--R                   ROOT
+--R                                   5      2 4
+--R                            (108a c  - 27b c )
+--R                         *
+--R                             +------------------------------------------------+
+--R                             |       4 4      3 2 3      2 4 2       6     8
+--R                             |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |------------------------------------------------
+--R                             |      3 11         2 2 10          4 9       6 8
+--R                            \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                        + 
+--R                                      3
+--R                          - 2a b c + b
+--R                     /
+--R                              5      2 4
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    4 2     3 2      2 4  2
+--R                 (4a c  - 8a b c + 2a b )x
+--R     + 
+--R                                   +--------------------+2  +------------------+2
+--R                 +-----------+     |   +-----------+        | +-----------+
+--R            3+-+ |          2 3+-+3|   |          2        3| |          2
+--R         18c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         5      2 4
+--R                  (108a c  - 27b c )
+--R               *
+--R                   +------------------------------------------------+
+--R                   |       4 4      3 2 3      2 4 2       6     8
+--R                   |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |------------------------------------------------
+--R                   |      3 11         2 2 10          4 9       6 8
+--R                  \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                            3
+--R                - 2a b c + b
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                          2   6         3 5      5 4  +-+
+--R                    (1296a b c  - 648a b c  + 81b c )\|3
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |       4 4      3 2 3      2 4 2       6     8
+--R                     |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |------------------------------------------------
+--R                     |      3 11         2 2 10          4 9       6 8
+--R                    \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                        3 3      2 2 2        4      6  +-+
+--R                  (- 24a c  + 54a b c  - 24a b c + 3b )\|3
+--R             *
+--R                ROOT
+--R                                5      2 4
+--R                         (108a c  - 27b c )
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |       4 4      3 2 3      2 4 2       6     8
+--R                          |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |------------------------------------------------
+--R                          |      3 11         2 2 10          4 9       6 8
+--R                         \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                   3
+--R                       - 2a b c + b
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                            2   6         3 5      5 4
+--R                      (1296a b c  - 648a b c  + 81b c )
+--R                   *
+--R                       +------------------------------------------------+
+--R                       |       4 4      3 2 3      2 4 2       6     8
+--R                       |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |------------------------------------------------
+--R                       |      3 11         2 2 10          4 9       6 8
+--R                      \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                  + 
+--R                         3 3      2 2 2        4      6
+--R                    - 24a c  + 54a b c  - 24a b c + 3b
+--R               *
+--R                  ROOT
+--R                                  5      2 4
+--R                           (108a c  - 27b c )
+--R                        *
+--R                            +------------------------------------------------+
+--R                            |       4 4      3 2 3      2 4 2       6     8
+--R                            |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |------------------------------------------------
+--R                            |      3 11         2 2 10          4 9       6 8
+--R                           \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                       + 
+--R                                     3
+--R                         - 2a b c + b
+--R                    /
+--R                             5      2 4
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                     3 2      2 2        4
+--R                (- 8a c  + 16a b c - 4a b )x
+--R     + 
+--R                 +-----------+
+--R            3+-+ |          2 3+-+
+--R         18c\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                           5      2 4
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                   +------------------------------------------------+
+--R                   |       4 4      3 2 3      2 4 2       6     8
+--R                   |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |------------------------------------------------
+--R                   |      3 11         2 2 10          4 9       6 8
+--R                  \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                            3
+--R                - 2a b c + b
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R          +--------------------+2  +------------------+2
+--R          |   +-----------+        | +-----------+
+--R         3|   |          2        3| |          2
+--R         \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                          2   6         3 5      5 4  +-+
+--R                    (1296a b c  - 648a b c  + 81b c )\|3
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |       4 4      3 2 3      2 4 2       6     8
+--R                     |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |------------------------------------------------
+--R                     |      3 11         2 2 10          4 9       6 8
+--R                    \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                      3 3      2 2 2        4      6  +-+
+--R                  (24a c  - 54a b c  + 24a b c - 3b )\|3
+--R             *
+--R                ROOT
+--R                                  5      2 4
+--R                         (- 108a c  + 27b c )
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |       4 4      3 2 3      2 4 2       6     8
+--R                          |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |------------------------------------------------
+--R                          |      3 11         2 2 10          4 9       6 8
+--R                         \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                   3
+--R                       - 2a b c + b
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                            2   6         3 5      5 4
+--R                      (1296a b c  - 648a b c  + 81b c )
+--R                   *
+--R                       +------------------------------------------------+
+--R                       |       4 4      3 2 3      2 4 2       6     8
+--R                       |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |------------------------------------------------
+--R                       |      3 11         2 2 10          4 9       6 8
+--R                      \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                  + 
+--R                       3 3      2 2 2        4      6
+--R                    24a c  - 54a b c  + 24a b c - 3b
+--R               *
+--R                  ROOT
+--R                                    5      2 4
+--R                           (- 108a c  + 27b c )
+--R                        *
+--R                            +------------------------------------------------+
+--R                            |       4 4      3 2 3      2 4 2       6     8
+--R                            |   - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |------------------------------------------------
+--R                            |      3 11         2 2 10          4 9       6 8
+--R                           \|46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                       + 
+--R                                     3
+--R                         - 2a b c + b
+--R                    /
+--R                             5      2 4
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                   3 2      2 2        4
+--R                (8a c  - 16a b c + 4a b )x
+--R     + 
+--R                                            +--------------------+2
+--R               +-----------+                |   +-----------+
+--R               |          2              2 3|   |          2
+--R         (- 6b\|- 4a c + b   + 12a c - 6b )\|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                            +------------------+2
+--R               +-----------+                | +-----------+
+--R               |          2              2 3| |          2
+--R         (- 6b\|- 4a c + b   - 12a c + 6b )\|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+2  +------------------+2
+--R                +-----------+     |   +-----------+        | +-----------+
+--R       3+-+ +-+ |          2 3+-+3|   |          2        3| |          2
+--R     6c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 687
+
+)clear all
+
+--S 688 of 2282
+t0:=x^5/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                5
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 688
+
+--S 689 of 2282
+r0:=1/6*log(a+b*x^3+c*x^6)/c+1/3*b*atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                        3                               +-----------+
+--R                    2c x  + b             6      3      |          2
+--R        2b atanh(--------------) + log(c x  + b x  + a)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  -------------------------------------------------------------
+--R                                  +-----------+
+--R                                  |          2
+--R                               6c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 6         3           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   3             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   6      3
+--R                c x  + b x  + a
+--R       + 
+--R                              +-----------+
+--R                6      3      |          2
+--R         log(c x  + b x  + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       6c\|- 4a c + b
+--R     ,
+--R                          +---------+
+--R                   3      |        2                          +---------+
+--R              (2c x  + b)\|4a c - b             6      3      |        2
+--R    - 2b atan(-----------------------) + log(c x  + b x  + a)\|4a c - b
+--R                             2
+--R                     4a c - b
+--R    ---------------------------------------------------------------------]
+--R                                   +---------+
+--R                                   |        2
+--R                                6c\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 690
+
+--S 691 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 6         3           2  |          2           2     2   3
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 6      3
+--R              c x  + b x  + a
+--R     + 
+--R                         3
+--R                     2c x  + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     6c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 691
+
+--S 692 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             3
+--R           |        2          2c x  + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          3      |        2
+--R           |          2      (2c x  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     3c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 693
+
+--S 694 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 694
+
+)clear all
+
+--S 695 of 2282
+t0:=x^4/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 695
+
+--S 696 of 2282
+r0:=1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(b-sqrt(b^2-_
+   4*a*c))^(2/3)/(2^(2/3)*c^(2/3)*sqrt(b^2-4*a*c))-1/6*log(2^(2/3)*_
+   c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-_
+   sqrt(b^2-4*a*c))^(2/3))*(b-sqrt(b^2-4*a*c))^(2/3)/(2^(2/3)*c^(2/3)*_
+   sqrt(b^2-4*a*c))+atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(b-sqrt(b^2-4*a*c))^(2/3)/_
+   (2^(2/3)*c^(2/3)*sqrt(3)*sqrt(b^2-4*a*c))-1/3*log(2^(1/3)*c^(1/3)*x+_
+   (b+sqrt(b^2-4*a*c))^(1/3))*(b+sqrt(b^2-4*a*c))^(2/3)/(2^(2/3)*c^(2/3)*_
+   sqrt(b^2-4*a*c))+1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*_
+   (b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*(b+_
+   sqrt(b^2-4*a*c))^(2/3)/(2^(2/3)*c^(2/3)*sqrt(b^2-4*a*c))-_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(b+sqrt(b^2-4*a*c))^(2/3)/_
+   (2^(2/3)*c^(2/3)*sqrt(3)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R              +------------------+2
+--R              | +-----------+
+--R          +-+3| |          2
+--R         \|3 \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R               +------------------+2     +------------------+
+--R               | +-----------+           | +-----------+
+--R           +-+3| |          2           3| |          2          3+-+3+-+
+--R       - 2\|3 \|\|- 4a c + b   + b  log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                 +--------------------+2
+--R                 |   +-----------+
+--R             +-+3|   |          2
+--R            \|3 \|- \|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +--------------------+2             +--------------------+
+--R                  |   +-----------+                   |   +-----------+
+--R                 3|   |          2           3+-+3+-+3|   |          2
+--R                 \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R             +--------------------+2     +--------------------+
+--R             |   +-----------+           |   +-----------+
+--R         +-+3|   |          2           3|   |          2          3+-+3+-+
+--R       2\|3 \|- \|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                            +------------------+
+--R           +------------------+2            | +-----------+
+--R           | +-----------+           3+-+2 3| |          2          3+-+
+--R          3| |          2            \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       - 6\|\|- 4a c + b   + b  atan(-----------------------------------)
+--R                                                  +------------------+
+--R                                                  | +-----------+
+--R                                        3+-+2 +-+3| |          2
+--R                                        \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R         +--------------------+2            |   +-----------+
+--R         |   +-----------+           3+-+2 3|   |          2          3+-+
+--R        3|   |          2            \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R       6\|- \|- 4a c + b   + b  atan(-------------------------------------)
+--R                                                  +--------------------+
+--R                                                  |   +-----------+
+--R                                        3+-+2 +-+3|   |          2
+--R                                        \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                +-----------+
+--R      3+-+2 +-+ |          2 3+-+2
+--R     6\|2  \|3 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2
+--R      *
+--R         ROOT
+--R                         3      2 2
+--R                  (108a c  - 27b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2       2     4
+--R                   |             - 4a c  + 4a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 7         2 2 6          4 5       6 4
+--R                  \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                b
+--R           /
+--R                    3      2 2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                           3 5         2 2 4          4 3       6 2
+--R                    (15552a c  - 11664a b c  + 2916a b c  - 243b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2       2     4
+--R                     |             - 4a c  + 4a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 7         2 2 6          4 5       6 4
+--R                    \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                + 
+--R                       2   2        3      5
+--R                  - 72a b c  + 54a b c - 9b
+--R             *
+--R                  ROOT
+--R                                  3      2 2
+--R                           (108a c  - 27b c )
+--R                        *
+--R                            +----------------------------------------------+
+--R                            |                 2 2       2     4
+--R                            |             - 4a c  + 4a b c - b
+--R                            |----------------------------------------------
+--R                            |      3 7         2 2 6          4 5       6 4
+--R                           \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                       + 
+--R                         b
+--R                    /
+--R                             3      2 2
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                 2        2
+--R              (4a c - 2a b )x
+--R     + 
+--R       -
+--R            ROOT
+--R                              3      2 2
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                 2 2       2     4
+--R                      |             - 4a c  + 4a b c - b
+--R                      |----------------------------------------------
+--R                      |      3 7         2 2 6          4 5       6 4
+--R                     \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   b
+--R              /
+--R                       3      2 2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                              3 5         2 2 4          4 3       6 2
+--R                       (15552a c  - 11664a b c  + 2916a b c  - 243b c )x
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                 2 2       2     4
+--R                        |             - 4a c  + 4a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 7         2 2 6          4 5       6 4
+--R                       \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                   + 
+--R                         2   2        3      5
+--R                     (72a b c  - 54a b c + 9b )x
+--R                *
+--R                     ROOT
+--R                                       3      2 2
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            b
+--R                       /
+--R                                3      2 2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                         3 4        2 2 3         4 2
+--R                   (2592a c  - 1296a b c  + 162a b c )
+--R                *
+--R                    +----------------------------------------------+
+--R                    |                 2 2       2     4
+--R                    |             - 4a c  + 4a b c - b
+--R                    |----------------------------------------------
+--R                    |      3 7         2 2 6          4 5       6 4
+--R                   \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                *
+--R                   ROOT
+--R                                     3      2 2
+--R                            (- 108a c  + 27b c )
+--R                         *
+--R                             +----------------------------------------------+
+--R                             |                 2 2       2     4
+--R                             |             - 4a c  + 4a b c - b
+--R                             |----------------------------------------------
+--R                             |      3 7         2 2 6          4 5       6 4
+--R                            \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                        + 
+--R                          b
+--R                     /
+--R                              3      2 2
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    2        2  2
+--R                 (4a c - 2a b )x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                           3      2 2
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2       2     4
+--R                   |             - 4a c  + 4a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 7         2 2 6          4 5       6 4
+--R                  \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                b
+--R           /
+--R                    3      2 2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                             3 5         2 2 4          4 3       6 2
+--R                    (- 15552a c  + 11664a b c  - 2916a b c  + 243b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2       2     4
+--R                     |             - 4a c  + 4a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 7         2 2 6          4 5       6 4
+--R                    \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                + 
+--R                       2   2        3      5
+--R                  - 72a b c  + 54a b c - 9b
+--R             *
+--R                  ROOT
+--R                                    3      2 2
+--R                           (- 108a c  + 27b c )
+--R                        *
+--R                            +----------------------------------------------+
+--R                            |                 2 2       2     4
+--R                            |             - 4a c  + 4a b c - b
+--R                            |----------------------------------------------
+--R                            |      3 7         2 2 6          4 5       6 4
+--R                           \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                       + 
+--R                         b
+--R                    /
+--R                             3      2 2
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                 2        2
+--R              (4a c - 2a b )x
+--R     + 
+--R       -
+--R            ROOT
+--R                            3      2 2
+--R                     (108a c  - 27b c )
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                 2 2       2     4
+--R                      |             - 4a c  + 4a b c - b
+--R                      |----------------------------------------------
+--R                      |      3 7         2 2 6          4 5       6 4
+--R                     \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   b
+--R              /
+--R                       3      2 2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                3 5         2 2 4          4 3       6 2
+--R                       (- 15552a c  + 11664a b c  - 2916a b c  + 243b c )x
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                 2 2       2     4
+--R                        |             - 4a c  + 4a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 7         2 2 6          4 5       6 4
+--R                       \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                   + 
+--R                         2   2        3      5
+--R                     (72a b c  - 54a b c + 9b )x
+--R                *
+--R                     ROOT
+--R                                     3      2 2
+--R                              (108a c  - 27b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            b
+--R                       /
+--R                                3      2 2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                           3 4        2 2 3         4 2
+--R                   (- 2592a c  + 1296a b c  - 162a b c )
+--R                *
+--R                    +----------------------------------------------+
+--R                    |                 2 2       2     4
+--R                    |             - 4a c  + 4a b c - b
+--R                    |----------------------------------------------
+--R                    |      3 7         2 2 6          4 5       6 4
+--R                   \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                *
+--R                   ROOT
+--R                                   3      2 2
+--R                            (108a c  - 27b c )
+--R                         *
+--R                             +----------------------------------------------+
+--R                             |                 2 2       2     4
+--R                             |             - 4a c  + 4a b c - b
+--R                             |----------------------------------------------
+--R                             |      3 7         2 2 6          4 5       6 4
+--R                            \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                        + 
+--R                          b
+--R                     /
+--R                              3      2 2
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    2        2  2
+--R                 (4a c - 2a b )x
+--R     + 
+--R       -
+--R              +-+
+--R            2\|3
+--R         *
+--R            ROOT
+--R                            3      2 2
+--R                     (108a c  - 27b c )
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                 2 2       2     4
+--R                      |             - 4a c  + 4a b c - b
+--R                      |----------------------------------------------
+--R                      |      3 7         2 2 6          4 5       6 4
+--R                     \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   b
+--R              /
+--R                       3      2 2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                              3 5         2 2 4          4 3       6 2  +-+
+--R                       (15552a c  - 11664a b c  + 2916a b c  - 243b c )\|3
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                 2 2       2     4
+--R                        |             - 4a c  + 4a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 7         2 2 6          4 5       6 4
+--R                       \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                   + 
+--R                           2   2        3      5  +-+
+--R                     (- 72a b c  + 54a b c - 9b )\|3
+--R                *
+--R                     ROOT
+--R                                     3      2 2
+--R                              (108a c  - 27b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            b
+--R                       /
+--R                                3      2 2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                3 5         2 2 4          4 3       6 2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2       2     4
+--R                          |             - 4a c  + 4a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 7         2 2 6          4 5       6 4
+--R                         \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                            2   2        3      5
+--R                       - 72a b c  + 54a b c - 9b
+--R                  *
+--R                       ROOT
+--R                                       3      2 2
+--R                                (108a c  - 27b c )
+--R                             *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                            + 
+--R                              b
+--R                         /
+--R                                  3      2 2
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                        2        2
+--R                   (- 8a c + 4a b )x
+--R     + 
+--R       -
+--R              +-+
+--R            2\|3
+--R         *
+--R            ROOT
+--R                              3      2 2
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                 2 2       2     4
+--R                      |             - 4a c  + 4a b c - b
+--R                      |----------------------------------------------
+--R                      |      3 7         2 2 6          4 5       6 4
+--R                     \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   b
+--R              /
+--R                       3      2 2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                              3 5         2 2 4          4 3       6 2  +-+
+--R                       (15552a c  - 11664a b c  + 2916a b c  - 243b c )\|3
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                 2 2       2     4
+--R                        |             - 4a c  + 4a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 7         2 2 6          4 5       6 4
+--R                       \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                   + 
+--R                         2   2        3      5  +-+
+--R                     (72a b c  - 54a b c + 9b )\|3
+--R                *
+--R                     ROOT
+--R                                       3      2 2
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            b
+--R                       /
+--R                                3      2 2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                3 5         2 2 4          4 3       6 2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2       2     4
+--R                          |             - 4a c  + 4a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 7         2 2 6          4 5       6 4
+--R                         \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                          2   2        3      5
+--R                       72a b c  - 54a b c + 9b
+--R                  *
+--R                       ROOT
+--R                                         3      2 2
+--R                                (- 108a c  + 27b c )
+--R                             *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                            + 
+--R                              b
+--R                         /
+--R                                  3      2 2
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                      2        2
+--R                   (8a c - 4a b )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 697
+
+--S 698 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    +-----------+
+--R          3+-+2 +-+ |          2 3+-+2
+--R         6\|2  \|3 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                         3      2 2
+--R                  (108a c  - 27b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2       2     4
+--R                   |             - 4a c  + 4a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 7         2 2 6          4 5       6 4
+--R                  \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                b
+--R           /
+--R                    3      2 2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                           3 5         2 2 4          4 3       6 2
+--R                    (15552a c  - 11664a b c  + 2916a b c  - 243b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2       2     4
+--R                     |             - 4a c  + 4a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 7         2 2 6          4 5       6 4
+--R                    \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                + 
+--R                       2   2        3      5
+--R                  - 72a b c  + 54a b c - 9b
+--R             *
+--R                  ROOT
+--R                                  3      2 2
+--R                           (108a c  - 27b c )
+--R                        *
+--R                            +----------------------------------------------+
+--R                            |                 2 2       2     4
+--R                            |             - 4a c  + 4a b c - b
+--R                            |----------------------------------------------
+--R                            |      3 7         2 2 6          4 5       6 4
+--R                           \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                       + 
+--R                         b
+--R                    /
+--R                             3      2 2
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                 2        2
+--R              (4a c - 2a b )x
+--R     + 
+--R       -
+--R                 +------------------+2
+--R                 | +-----------+
+--R             +-+3| |          2
+--R            \|3 \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +------------------+2             +------------------+
+--R                  | +-----------+                   | +-----------+
+--R                 3| |          2           3+-+3+-+3| |          2
+--R                 \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R             +------------------+2     +------------------+
+--R             | +-----------+           | +-----------+
+--R         +-+3| |          2           3| |          2          3+-+3+-+
+--R       2\|3 \|\|- 4a c + b   + b  log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R              +--------------------+2
+--R              |   +-----------+
+--R          +-+3|   |          2
+--R         \|3 \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R               +--------------------+2     +--------------------+
+--R               |   +-----------+           |   +-----------+
+--R           +-+3|   |          2           3|   |          2          3+-+3+-+
+--R       - 2\|3 \|- \|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                       +-----------+
+--R             3+-+2 +-+ |          2 3+-+2
+--R            3\|2  \|3 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                              3      2 2
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                 2 2       2     4
+--R                      |             - 4a c  + 4a b c - b
+--R                      |----------------------------------------------
+--R                      |      3 7         2 2 6          4 5       6 4
+--R                     \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   b
+--R              /
+--R                       3      2 2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                              3 5         2 2 4          4 3       6 2
+--R                       (15552a c  - 11664a b c  + 2916a b c  - 243b c )x
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                 2 2       2     4
+--R                        |             - 4a c  + 4a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 7         2 2 6          4 5       6 4
+--R                       \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                   + 
+--R                         2   2        3      5
+--R                     (72a b c  - 54a b c + 9b )x
+--R                *
+--R                     ROOT
+--R                                       3      2 2
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            b
+--R                       /
+--R                                3      2 2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                         3 4        2 2 3         4 2
+--R                   (2592a c  - 1296a b c  + 162a b c )
+--R                *
+--R                    +----------------------------------------------+
+--R                    |                 2 2       2     4
+--R                    |             - 4a c  + 4a b c - b
+--R                    |----------------------------------------------
+--R                    |      3 7         2 2 6          4 5       6 4
+--R                   \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                *
+--R                   ROOT
+--R                                     3      2 2
+--R                            (- 108a c  + 27b c )
+--R                         *
+--R                             +----------------------------------------------+
+--R                             |                 2 2       2     4
+--R                             |             - 4a c  + 4a b c - b
+--R                             |----------------------------------------------
+--R                             |      3 7         2 2 6          4 5       6 4
+--R                            \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                        + 
+--R                          b
+--R                     /
+--R                              3      2 2
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    2        2  2
+--R                 (4a c - 2a b )x
+--R     + 
+--R                    +-----------+
+--R          3+-+2 +-+ |          2 3+-+2
+--R         6\|2  \|3 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                           3      2 2
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2       2     4
+--R                   |             - 4a c  + 4a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 7         2 2 6          4 5       6 4
+--R                  \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                b
+--R           /
+--R                    3      2 2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                             3 5         2 2 4          4 3       6 2
+--R                    (- 15552a c  + 11664a b c  - 2916a b c  + 243b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2       2     4
+--R                     |             - 4a c  + 4a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 7         2 2 6          4 5       6 4
+--R                    \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                + 
+--R                       2   2        3      5
+--R                  - 72a b c  + 54a b c - 9b
+--R             *
+--R                  ROOT
+--R                                    3      2 2
+--R                           (- 108a c  + 27b c )
+--R                        *
+--R                            +----------------------------------------------+
+--R                            |                 2 2       2     4
+--R                            |             - 4a c  + 4a b c - b
+--R                            |----------------------------------------------
+--R                            |      3 7         2 2 6          4 5       6 4
+--R                           \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                       + 
+--R                         b
+--R                    /
+--R                             3      2 2
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                 2        2
+--R              (4a c - 2a b )x
+--R     + 
+--R       -
+--R                       +-----------+
+--R             3+-+2 +-+ |          2 3+-+2
+--R            3\|2  \|3 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                            3      2 2
+--R                     (108a c  - 27b c )
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                 2 2       2     4
+--R                      |             - 4a c  + 4a b c - b
+--R                      |----------------------------------------------
+--R                      |      3 7         2 2 6          4 5       6 4
+--R                     \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   b
+--R              /
+--R                       3      2 2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                3 5         2 2 4          4 3       6 2
+--R                       (- 15552a c  + 11664a b c  - 2916a b c  + 243b c )x
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                 2 2       2     4
+--R                        |             - 4a c  + 4a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 7         2 2 6          4 5       6 4
+--R                       \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                   + 
+--R                         2   2        3      5
+--R                     (72a b c  - 54a b c + 9b )x
+--R                *
+--R                     ROOT
+--R                                     3      2 2
+--R                              (108a c  - 27b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            b
+--R                       /
+--R                                3      2 2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                           3 4        2 2 3         4 2
+--R                   (- 2592a c  + 1296a b c  - 162a b c )
+--R                *
+--R                    +----------------------------------------------+
+--R                    |                 2 2       2     4
+--R                    |             - 4a c  + 4a b c - b
+--R                    |----------------------------------------------
+--R                    |      3 7         2 2 6          4 5       6 4
+--R                   \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                *
+--R                   ROOT
+--R                                   3      2 2
+--R                            (108a c  - 27b c )
+--R                         *
+--R                             +----------------------------------------------+
+--R                             |                 2 2       2     4
+--R                             |             - 4a c  + 4a b c - b
+--R                             |----------------------------------------------
+--R                             |      3 7         2 2 6          4 5       6 4
+--R                            \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                        + 
+--R                          b
+--R                     /
+--R                              3      2 2
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    2        2  2
+--R                 (4a c - 2a b )x
+--R     + 
+--R       -
+--R                    +-----------+
+--R              3+-+2 |          2 3+-+2
+--R            18\|2  \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                            3      2 2
+--R                     (108a c  - 27b c )
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                 2 2       2     4
+--R                      |             - 4a c  + 4a b c - b
+--R                      |----------------------------------------------
+--R                      |      3 7         2 2 6          4 5       6 4
+--R                     \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   b
+--R              /
+--R                       3      2 2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                              3 5         2 2 4          4 3       6 2  +-+
+--R                       (15552a c  - 11664a b c  + 2916a b c  - 243b c )\|3
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                 2 2       2     4
+--R                        |             - 4a c  + 4a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 7         2 2 6          4 5       6 4
+--R                       \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                   + 
+--R                           2   2        3      5  +-+
+--R                     (- 72a b c  + 54a b c - 9b )\|3
+--R                *
+--R                     ROOT
+--R                                     3      2 2
+--R                              (108a c  - 27b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            b
+--R                       /
+--R                                3      2 2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                3 5         2 2 4          4 3       6 2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2       2     4
+--R                          |             - 4a c  + 4a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 7         2 2 6          4 5       6 4
+--R                         \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                            2   2        3      5
+--R                       - 72a b c  + 54a b c - 9b
+--R                  *
+--R                       ROOT
+--R                                       3      2 2
+--R                                (108a c  - 27b c )
+--R                             *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                            + 
+--R                              b
+--R                         /
+--R                                  3      2 2
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                        2        2
+--R                   (- 8a c + 4a b )x
+--R     + 
+--R       -
+--R                    +-----------+
+--R              3+-+2 |          2 3+-+2
+--R            18\|2  \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                              3      2 2
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                      +----------------------------------------------+
+--R                      |                 2 2       2     4
+--R                      |             - 4a c  + 4a b c - b
+--R                      |----------------------------------------------
+--R                      |      3 7         2 2 6          4 5       6 4
+--R                     \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   b
+--R              /
+--R                       3      2 2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                              3 5         2 2 4          4 3       6 2  +-+
+--R                       (15552a c  - 11664a b c  + 2916a b c  - 243b c )\|3
+--R                    *
+--R                        +----------------------------------------------+
+--R                        |                 2 2       2     4
+--R                        |             - 4a c  + 4a b c - b
+--R                        |----------------------------------------------
+--R                        |      3 7         2 2 6          4 5       6 4
+--R                       \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                   + 
+--R                         2   2        3      5  +-+
+--R                     (72a b c  - 54a b c + 9b )\|3
+--R                *
+--R                     ROOT
+--R                                       3      2 2
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            b
+--R                       /
+--R                                3      2 2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                3 5         2 2 4          4 3       6 2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2       2     4
+--R                          |             - 4a c  + 4a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 7         2 2 6          4 5       6 4
+--R                         \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                          2   2        3      5
+--R                       72a b c  - 54a b c + 9b
+--R                  *
+--R                       ROOT
+--R                                         3      2 2
+--R                                (- 108a c  + 27b c )
+--R                             *
+--R                               +----------------------------------------------+
+--R                               |                 2 2       2     4
+--R                               |             - 4a c  + 4a b c - b
+--R                               |----------------------------------------------
+--R                               |      3 7         2 2 6          4 5       6 4
+--R                              \|46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                            + 
+--R                              b
+--R                         /
+--R                                  3      2 2
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                      2        2
+--R                   (8a c - 4a b )x
+--R     + 
+--R                                          +------------------+
+--R         +------------------+2            | +-----------+
+--R         | +-----------+           3+-+2 3| |          2          3+-+
+--R        3| |          2            \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       6\|\|- 4a c + b   + b  atan(-----------------------------------)
+--R                                                +------------------+
+--R                                                | +-----------+
+--R                                      3+-+2 +-+3| |          2
+--R                                      \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                              +--------------------+
+--R           +--------------------+2            |   +-----------+
+--R           |   +-----------+           3+-+2 3|   |          2          3+-+
+--R          3|   |          2            \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R       - 6\|- \|- 4a c + b   + b  atan(-------------------------------------)
+--R                                                    +--------------------+
+--R                                                    |   +-----------+
+--R                                          3+-+2 +-+3|   |          2
+--R                                          \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                +-----------+
+--R      3+-+2 +-+ |          2 3+-+2
+--R     6\|2  \|3 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 698
+
+--S 699 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 699
+
+)clear all
+
+--S 700 of 2282
+t0:=x^3/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 700
+
+--S 701 of 2282
+r0:=-1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(b-_
+   sqrt(b^2-4*a*c))^(1/3)/(2^(1/3)*c^(1/3)*sqrt(b^2-4*a*c))+_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-_
+   4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(b-sqrt(b^2-4*a*c))^(1/3)/_
+   (2^(1/3)*c^(1/3)*sqrt(b^2-4*a*c))+atan((-4*c^(1/3)*x+2^(2/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*_
+   (b-sqrt(b^2-4*a*c))^(1/3)/(2^(1/3)*c^(1/3)*sqrt(3)*sqrt(b^2-4*a*c))+_
+   1/3*log(2^(1/3)*c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(b+_
+   sqrt(b^2-4*a*c))^(1/3)/(2^(1/3)*c^(1/3)*sqrt(b^2-4*a*c))-_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+_
+   (b+sqrt(b^2-4*a*c))^(2/3))*(b+sqrt(b^2-4*a*c))^(1/3)/(2^(1/3)*c^(1/3)*_
+   sqrt(b^2-4*a*c))-atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(b+sqrt(b^2-4*a*c))^(1/3)/_
+   (2^(1/3)*c^(1/3)*sqrt(3)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R       -
+--R                 +------------------+
+--R                 | +-----------+
+--R             +-+3| |          2
+--R            \|3 \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +------------------+2             +------------------+
+--R                  | +-----------+                   | +-----------+
+--R                 3| |          2           3+-+3+-+3| |          2
+--R                 \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R             +------------------+     +------------------+
+--R             | +-----------+          | +-----------+
+--R         +-+3| |          2          3| |          2          3+-+3+-+
+--R       2\|3 \|\|- 4a c + b   + b log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R              +--------------------+
+--R              |   +-----------+
+--R          +-+3|   |          2
+--R         \|3 \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R               +--------------------+     +--------------------+
+--R               |   +-----------+          |   +-----------+
+--R           +-+3|   |          2          3|   |          2          3+-+3+-+
+--R       - 2\|3 \|- \|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                           +------------------+
+--R           +------------------+            | +-----------+
+--R           | +-----------+          3+-+2 3| |          2          3+-+
+--R          3| |          2           \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       - 6\|\|- 4a c + b   + b atan(-----------------------------------)
+--R                                                 +------------------+
+--R                                                 | +-----------+
+--R                                       3+-+2 +-+3| |          2
+--R                                       \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                           +--------------------+
+--R         +--------------------+            |   +-----------+
+--R         |   +-----------+          3+-+2 3|   |          2          3+-+
+--R        3|   |          2           \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R       6\|- \|- 4a c + b   + b atan(-------------------------------------)
+--R                                                 +--------------------+
+--R                                                 |   +-----------+
+--R                                       3+-+2 +-+3|   |          2
+--R                                       \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R               +-----------+
+--R      3+-+ +-+ |          2 3+-+
+--R     6\|2 \|3 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2
+--R      *
+--R         ROOT
+--R                         2      2
+--R                  (108a c  - 27b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                - 1
+--R           /
+--R                    2      2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                      2 3         2 2      4
+--R                (1296a c  - 648a b c  + 81b c)
+--R             *
+--R                 +------------------------------------------------+
+--R                 |                         2
+--R                 |                        b
+--R                 |- ----------------------------------------------
+--R                 |        3 5         2 2 4          4 3       6 2
+--R                \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R             *
+--R                ROOT
+--R                                2      2
+--R                         (108a c  - 27b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                       - 1
+--R                  /
+--R                           2      2
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R              b x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                           2      2
+--R                  (- 108a c  + 27b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                - 1
+--R           /
+--R                    2      2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                        2 3         2 2      4
+--R                (- 1296a c  + 648a b c  - 81b c)
+--R             *
+--R                 +------------------------------------------------+
+--R                 |                         2
+--R                 |                        b
+--R                 |- ----------------------------------------------
+--R                 |        3 5         2 2 4          4 3       6 2
+--R                \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R             *
+--R                ROOT
+--R                                  2      2
+--R                         (- 108a c  + 27b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                       - 1
+--R                  /
+--R                           2      2
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R              b x
+--R     + 
+--R       -
+--R            ROOT
+--R                              2      2
+--R                     (- 108a c  + 27b c)
+--R                  *
+--R                      +------------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ----------------------------------------------
+--R                      |        3 5         2 2 4          4 3       6 2
+--R                     \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   - 1
+--R              /
+--R                       2      2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                  3
+--R                   (- 36a b c + 9b )
+--R                *
+--R                     ROOT
+--R                                       2      2
+--R                              (- 108a c  + 27b c)
+--R                           *
+--R                             +------------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ----------------------------------------------
+--R                             |        3 5         2 2 4          4 3       6 2
+--R                            \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            - 1
+--R                       /
+--R                                2      2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                         2 3         2 2      4
+--R                   (1296a c  - 648a b c  + 81b c)x
+--R                *
+--R                    +------------------------------------------------+
+--R                    |                         2
+--R                    |                        b
+--R                    |- ----------------------------------------------
+--R                    |        3 5         2 2 4          4 3       6 2
+--R                   \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                *
+--R                   ROOT
+--R                                     2      2
+--R                            (- 108a c  + 27b c)
+--R                         *
+--R                             +------------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ----------------------------------------------
+--R                             |        3 5         2 2 4          4 3       6 2
+--R                            \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                        + 
+--R                          - 1
+--R                     /
+--R                              2      2
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    2
+--R                 b x
+--R     + 
+--R       -
+--R            ROOT
+--R                            2      2
+--R                     (108a c  - 27b c)
+--R                  *
+--R                      +------------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ----------------------------------------------
+--R                      |        3 5         2 2 4          4 3       6 2
+--R                     \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   - 1
+--R              /
+--R                       2      2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                  3
+--R                   (- 36a b c + 9b )
+--R                *
+--R                     ROOT
+--R                                     2      2
+--R                              (108a c  - 27b c)
+--R                           *
+--R                             +------------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ----------------------------------------------
+--R                             |        3 5         2 2 4          4 3       6 2
+--R                            \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            - 1
+--R                       /
+--R                                2      2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                           2 3         2 2      4
+--R                   (- 1296a c  + 648a b c  - 81b c)x
+--R                *
+--R                    +------------------------------------------------+
+--R                    |                         2
+--R                    |                        b
+--R                    |- ----------------------------------------------
+--R                    |        3 5         2 2 4          4 3       6 2
+--R                   \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                *
+--R                   ROOT
+--R                                   2      2
+--R                            (108a c  - 27b c)
+--R                         *
+--R                             +------------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ----------------------------------------------
+--R                             |        3 5         2 2 4          4 3       6 2
+--R                            \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                        + 
+--R                          - 1
+--R                     /
+--R                              2      2
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    2
+--R                 b x
+--R     + 
+--R           +-+
+--R         2\|3
+--R      *
+--R         ROOT
+--R                         2      2
+--R                  (108a c  - 27b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                - 1
+--R           /
+--R                    2      2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                      2 3         2 2      4   +-+
+--R                (1296a c  - 648a b c  + 81b c)\|3
+--R             *
+--R                 +------------------------------------------------+
+--R                 |                         2
+--R                 |                        b
+--R                 |- ----------------------------------------------
+--R                 |        3 5         2 2 4          4 3       6 2
+--R                \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R             *
+--R                ROOT
+--R                                2      2
+--R                         (108a c  - 27b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                       - 1
+--R                  /
+--R                           2      2
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                        2 3         2 2      4
+--R                  (1296a c  - 648a b c  + 81b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R               *
+--R                  ROOT
+--R                                  2      2
+--R                           (108a c  - 27b c)
+--R                        *
+--R                            +------------------------------------------------+
+--R                            |                         2
+--R                            |                        b
+--R                            |- ----------------------------------------------
+--R                            |        3 5         2 2 4          4 3       6 2
+--R                           \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                       + 
+--R                         - 1
+--R                    /
+--R                             2      2
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                - 2b x
+--R     + 
+--R           +-+
+--R         2\|3
+--R      *
+--R         ROOT
+--R                           2      2
+--R                  (- 108a c  + 27b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                - 1
+--R           /
+--R                    2      2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                      2 3         2 2      4   +-+
+--R                (1296a c  - 648a b c  + 81b c)\|3
+--R             *
+--R                 +------------------------------------------------+
+--R                 |                         2
+--R                 |                        b
+--R                 |- ----------------------------------------------
+--R                 |        3 5         2 2 4          4 3       6 2
+--R                \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R             *
+--R                ROOT
+--R                                  2      2
+--R                         (- 108a c  + 27b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                       - 1
+--R                  /
+--R                           2      2
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                        2 3         2 2      4
+--R                  (1296a c  - 648a b c  + 81b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R               *
+--R                  ROOT
+--R                                    2      2
+--R                           (- 108a c  + 27b c)
+--R                        *
+--R                            +------------------------------------------------+
+--R                            |                         2
+--R                            |                        b
+--R                            |- ----------------------------------------------
+--R                            |        3 5         2 2 4          4 3       6 2
+--R                           \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                       + 
+--R                         - 1
+--R                    /
+--R                             2      2
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                2b x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 702
+
+--S 703 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +-----------+
+--R          3+-+ +-+ |          2 3+-+
+--R         6\|2 \|3 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                         2      2
+--R                  (108a c  - 27b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                - 1
+--R           /
+--R                    2      2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                      2 3         2 2      4
+--R                (1296a c  - 648a b c  + 81b c)
+--R             *
+--R                 +------------------------------------------------+
+--R                 |                         2
+--R                 |                        b
+--R                 |- ----------------------------------------------
+--R                 |        3 5         2 2 4          4 3       6 2
+--R                \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R             *
+--R                ROOT
+--R                                2      2
+--R                         (108a c  - 27b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                       - 1
+--R                  /
+--R                           2      2
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R              b x
+--R     + 
+--R              +------------------+
+--R              | +-----------+
+--R          +-+3| |          2
+--R         \|3 \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R               +------------------+     +------------------+
+--R               | +-----------+          | +-----------+
+--R           +-+3| |          2          3| |          2          3+-+3+-+
+--R       - 2\|3 \|\|- 4a c + b   + b log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                 +--------------------+
+--R                 |   +-----------+
+--R             +-+3|   |          2
+--R            \|3 \|- \|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +--------------------+2             +--------------------+
+--R                  |   +-----------+                   |   +-----------+
+--R                 3|   |          2           3+-+3+-+3|   |          2
+--R                 \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R             +--------------------+     +--------------------+
+--R             |   +-----------+          |   +-----------+
+--R         +-+3|   |          2          3|   |          2          3+-+3+-+
+--R       2\|3 \|- \|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                   +-----------+
+--R          3+-+ +-+ |          2 3+-+
+--R         6\|2 \|3 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                           2      2
+--R                  (- 108a c  + 27b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                - 1
+--R           /
+--R                    2      2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                        2 3         2 2      4
+--R                (- 1296a c  + 648a b c  - 81b c)
+--R             *
+--R                 +------------------------------------------------+
+--R                 |                         2
+--R                 |                        b
+--R                 |- ----------------------------------------------
+--R                 |        3 5         2 2 4          4 3       6 2
+--R                \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R             *
+--R                ROOT
+--R                                  2      2
+--R                         (- 108a c  + 27b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                       - 1
+--R                  /
+--R                           2      2
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R              b x
+--R     + 
+--R       -
+--R                      +-----------+
+--R             3+-+ +-+ |          2 3+-+
+--R            3\|2 \|3 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                              2      2
+--R                     (- 108a c  + 27b c)
+--R                  *
+--R                      +------------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ----------------------------------------------
+--R                      |        3 5         2 2 4          4 3       6 2
+--R                     \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   - 1
+--R              /
+--R                       2      2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                  3
+--R                   (- 36a b c + 9b )
+--R                *
+--R                     ROOT
+--R                                       2      2
+--R                              (- 108a c  + 27b c)
+--R                           *
+--R                             +------------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ----------------------------------------------
+--R                             |        3 5         2 2 4          4 3       6 2
+--R                            \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            - 1
+--R                       /
+--R                                2      2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                         2 3         2 2      4
+--R                   (1296a c  - 648a b c  + 81b c)x
+--R                *
+--R                    +------------------------------------------------+
+--R                    |                         2
+--R                    |                        b
+--R                    |- ----------------------------------------------
+--R                    |        3 5         2 2 4          4 3       6 2
+--R                   \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                *
+--R                   ROOT
+--R                                     2      2
+--R                            (- 108a c  + 27b c)
+--R                         *
+--R                             +------------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ----------------------------------------------
+--R                             |        3 5         2 2 4          4 3       6 2
+--R                            \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                        + 
+--R                          - 1
+--R                     /
+--R                              2      2
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    2
+--R                 b x
+--R     + 
+--R       -
+--R                      +-----------+
+--R             3+-+ +-+ |          2 3+-+
+--R            3\|2 \|3 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                            2      2
+--R                     (108a c  - 27b c)
+--R                  *
+--R                      +------------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ----------------------------------------------
+--R                      |        3 5         2 2 4          4 3       6 2
+--R                     \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                 + 
+--R                   - 1
+--R              /
+--R                       2      2
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                  3
+--R                   (- 36a b c + 9b )
+--R                *
+--R                     ROOT
+--R                                     2      2
+--R                              (108a c  - 27b c)
+--R                           *
+--R                             +------------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ----------------------------------------------
+--R                             |        3 5         2 2 4          4 3       6 2
+--R                            \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                          + 
+--R                            - 1
+--R                       /
+--R                                2      2
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                           2 3         2 2      4
+--R                   (- 1296a c  + 648a b c  - 81b c)x
+--R                *
+--R                    +------------------------------------------------+
+--R                    |                         2
+--R                    |                        b
+--R                    |- ----------------------------------------------
+--R                    |        3 5         2 2 4          4 3       6 2
+--R                   \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                *
+--R                   ROOT
+--R                                   2      2
+--R                            (108a c  - 27b c)
+--R                         *
+--R                             +------------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ----------------------------------------------
+--R                             |        3 5         2 2 4          4 3       6 2
+--R                            \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                        + 
+--R                          - 1
+--R                     /
+--R                              2      2
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                    2
+--R                 b x
+--R     + 
+--R                +-----------+
+--R           3+-+ |          2 3+-+
+--R         18\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                         2      2
+--R                  (108a c  - 27b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                - 1
+--R           /
+--R                    2      2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                      2 3         2 2      4   +-+
+--R                (1296a c  - 648a b c  + 81b c)\|3
+--R             *
+--R                 +------------------------------------------------+
+--R                 |                         2
+--R                 |                        b
+--R                 |- ----------------------------------------------
+--R                 |        3 5         2 2 4          4 3       6 2
+--R                \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R             *
+--R                ROOT
+--R                                2      2
+--R                         (108a c  - 27b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                       - 1
+--R                  /
+--R                           2      2
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                        2 3         2 2      4
+--R                  (1296a c  - 648a b c  + 81b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R               *
+--R                  ROOT
+--R                                  2      2
+--R                           (108a c  - 27b c)
+--R                        *
+--R                            +------------------------------------------------+
+--R                            |                         2
+--R                            |                        b
+--R                            |- ----------------------------------------------
+--R                            |        3 5         2 2 4          4 3       6 2
+--R                           \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                       + 
+--R                         - 1
+--R                    /
+--R                             2      2
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                - 2b x
+--R     + 
+--R                +-----------+
+--R           3+-+ |          2 3+-+
+--R         18\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                           2      2
+--R                  (- 108a c  + 27b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R              + 
+--R                - 1
+--R           /
+--R                    2      2
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                      2 3         2 2      4   +-+
+--R                (1296a c  - 648a b c  + 81b c)\|3
+--R             *
+--R                 +------------------------------------------------+
+--R                 |                         2
+--R                 |                        b
+--R                 |- ----------------------------------------------
+--R                 |        3 5         2 2 4          4 3       6 2
+--R                \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R             *
+--R                ROOT
+--R                                  2      2
+--R                         (- 108a c  + 27b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                     + 
+--R                       - 1
+--R                  /
+--R                           2      2
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                        2 3         2 2      4
+--R                  (1296a c  - 648a b c  + 81b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R               *
+--R                  ROOT
+--R                                    2      2
+--R                           (- 108a c  + 27b c)
+--R                        *
+--R                            +------------------------------------------------+
+--R                            |                         2
+--R                            |                        b
+--R                            |- ----------------------------------------------
+--R                            |        3 5         2 2 4          4 3       6 2
+--R                           \|  46656a c  - 34992a b c  + 8748a b c  - 729b c
+--R                       + 
+--R                         - 1
+--R                    /
+--R                             2      2
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                2b x
+--R     + 
+--R                                         +------------------+
+--R         +------------------+            | +-----------+
+--R         | +-----------+          3+-+2 3| |          2          3+-+
+--R        3| |          2           \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       6\|\|- 4a c + b   + b atan(-----------------------------------)
+--R                                               +------------------+
+--R                                               | +-----------+
+--R                                     3+-+2 +-+3| |          2
+--R                                     \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                             +--------------------+
+--R           +--------------------+            |   +-----------+
+--R           |   +-----------+          3+-+2 3|   |          2          3+-+
+--R          3|   |          2           \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R       - 6\|- \|- 4a c + b   + b atan(-------------------------------------)
+--R                                                   +--------------------+
+--R                                                   |   +-----------+
+--R                                         3+-+2 +-+3|   |          2
+--R                                         \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R               +-----------+
+--R      3+-+ +-+ |          2 3+-+
+--R     6\|2 \|3 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 703
+
+--S 704 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 704
+
+)clear all
+
+--S 705 of 2282
+t0:=x^2/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 705
+
+--S 706 of 2282
+r0:=-2/3*atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                        3
+--R                    2c x  + b
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  - ----------------------
+--R                +-----------+
+--R                |          2
+--R              3\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                            +-----------+
+--R                 2 6         3           2  |          2         2     2   3
+--R              (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               6      3
+--R            c x  + b x  + a
+--R    /
+--R         +-----------+
+--R         |          2
+--R       3\|- 4a c + b
+--R     ,
+--R                      +---------+
+--R               3      |        2
+--R          (2c x  + b)\|4a c - b
+--R    2atan(-----------------------)
+--R                         2
+--R                 4a c - b
+--R    ------------------------------]
+--R               +---------+
+--R               |        2
+--R             3\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 707
+
+--S 708 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                            +-----------+
+--R                 2 6         3           2  |          2         2     2   3
+--R              (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               6      3
+--R            c x  + b x  + a
+--R     + 
+--R                     3
+--R                 2c x  + b
+--R       2atanh(--------------)
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R  /
+--R       +-----------+
+--R       |          2
+--R     3\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 708
+
+--S 709 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R         +---------+             3
+--R         |        2          2c x  + b
+--R       2\|4a c - b  atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R     + 
+--R                                       +---------+
+--R         +-----------+          3      |        2
+--R         |          2      (2c x  + b)\|4a c - b
+--R       2\|- 4a c + b  atan(-----------------------)
+--R                                          2
+--R                                  4a c - b
+--R  /
+--R       +-----------+ +---------+
+--R       |          2  |        2
+--R     3\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 711
+
+)clear all
+
+--S 712 of 2282
+t0:=x/(a+b*x^3+c*x^6)
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 712
+
+--S 713 of 2282
+r0:=-1/3*2^(1/3)*c^(1/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-_
+   4*a*c))^(1/3))/((b-sqrt(b^2-4*a*c))^(1/3)*sqrt(b^2-4*a*c))+_
+   1/3*c^(1/3)*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-_
+   sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))/(2^(2/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3)*sqrt(b^2-4*a*c))-2^(1/3)*c^(1/3)*_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))/(sqrt(3)*(b-sqrt(b^2-_
+   4*a*c))^(1/3)*sqrt(b^2-4*a*c))+1/3*2^(1/3)*c^(1/3)*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))/(sqrt(b^2-4*a*c)*(b+_
+   sqrt(b^2-4*a*c))^(1/3))-1/3*c^(1/3)*log(2^(2/3)*c^(2/3)*x^2-_
+   2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-_
+   4*a*c))^(2/3))/(2^(2/3)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(1/3))+_
+   2^(1/3)*c^(1/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))/_
+   (sqrt(3)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(1/3))
+--R 
+--R
+--R   (2)
+--R       -
+--R                     +--------------------+
+--R                     |   +-----------+
+--R             +-+3+-+3|   |          2
+--R            \|3 \|c \|- \|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +------------------+2             +------------------+
+--R                  | +-----------+                   | +-----------+
+--R                 3| |          2           3+-+3+-+3| |          2
+--R                 \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R                 +--------------------+     +------------------+
+--R                 |   +-----------+          | +-----------+
+--R         +-+3+-+3|   |          2          3| |          2          3+-+3+-+
+--R       2\|3 \|c \|- \|- 4a c + b   + b log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                  +------------------+
+--R                  | +-----------+
+--R          +-+3+-+3| |          2
+--R         \|3 \|c \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                   +------------------+     +--------------------+
+--R                   | +-----------+          |   +-----------+
+--R           +-+3+-+3| |          2          3|   |          2          3+-+3+-+
+--R       - 2\|3 \|c \|\|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                               +------------------+
+--R             +--------------------+            | +-----------+
+--R             |   +-----------+          3+-+2 3| |          2          3+-+
+--R        3+-+3|   |          2           \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       6\|c \|- \|- 4a c + b   + b atan(-----------------------------------)
+--R                                                     +------------------+
+--R                                                     | +-----------+
+--R                                           3+-+2 +-+3| |          2
+--R                                           \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                               +--------------------+
+--R               +------------------+            |   +-----------+
+--R               | +-----------+          3+-+2 3|   |          2          3+-+
+--R          3+-+3| |          2           \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R       - 6\|c \|\|- 4a c + b   + b atan(-------------------------------------)
+--R                                                     +--------------------+
+--R                                                     |   +-----------+
+--R                                           3+-+2 +-+3|   |          2
+--R                                           \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R      3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R     3\|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                          2         2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ---------------------------------------------
+--R                      |        5 3         4 2 2        3 4        2 6
+--R                     \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   1
+--R              /
+--R                     2         2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                              4 3         3 2 2        2 4          6
+--R                       (15552a c  - 11664a b c  + 2916a b c - 243a b )x
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                           2      4
+--R                     (36a b c - 9b )x
+--R                *
+--R                     ROOT
+--R                                   2         2
+--R                              (108a c - 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            1
+--R                       /
+--R                              2         2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             3   2       2 3         5
+--R                       (1296a b c  - 648a b c + 81a b )
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                                   3
+--R                     - 12a b c + 3b
+--R                *
+--R                   ROOT
+--R                                 2         2
+--R                            (108a c - 27a b )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                        + 
+--R                          1
+--R                     /
+--R                            2         2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                       2
+--R                 2b c x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                         2         2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                1
+--R           /
+--R                  2         2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                           4 3         3 2 2        2 4          6
+--R                    (15552a c  - 11664a b c  + 2916a b c - 243a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                         2
+--R                     |                        b
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                         2      4
+--R                  - 36a b c + 9b
+--R             *
+--R                  ROOT
+--R                                  2         2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                            +-----------------------------------------------+
+--R                            |                         2
+--R                            |                        b
+--R                            |- ---------------------------------------------
+--R                            |        5 3         4 2 2        3 4        2 6
+--R                           \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                       + 
+--R                         1
+--R                    /
+--R                           2         2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R              2b c x
+--R     + 
+--R       -
+--R            ROOT
+--R                            2         2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ---------------------------------------------
+--R                      |        5 3         4 2 2        3 4        2 6
+--R                     \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   1
+--R              /
+--R                     2         2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                4 3         3 2 2        2 4          6
+--R                       (- 15552a c  + 11664a b c  - 2916a b c + 243a b )x
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                           2      4
+--R                     (36a b c - 9b )x
+--R                *
+--R                     ROOT
+--R                                     2         2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            1
+--R                       /
+--R                              2         2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               3   2       2 3         5
+--R                       (- 1296a b c  + 648a b c - 81a b )
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                                   3
+--R                     - 12a b c + 3b
+--R                *
+--R                   ROOT
+--R                                   2         2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                        + 
+--R                          1
+--R                     /
+--R                            2         2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                       2
+--R                 2b c x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                       2         2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                1
+--R           /
+--R                  2         2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                             4 3         3 2 2        2 4          6
+--R                    (- 15552a c  + 11664a b c  - 2916a b c + 243a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                         2
+--R                     |                        b
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                         2      4
+--R                  - 36a b c + 9b
+--R             *
+--R                  ROOT
+--R                                2         2
+--R                           (108a c - 27a b )
+--R                        *
+--R                            +-----------------------------------------------+
+--R                            |                         2
+--R                            |                        b
+--R                            |- ---------------------------------------------
+--R                            |        5 3         4 2 2        3 4        2 6
+--R                           \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                       + 
+--R                         1
+--R                    /
+--R                           2         2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R              2b c x
+--R     + 
+--R       -
+--R              +-+
+--R            2\|3
+--R         *
+--R            ROOT
+--R                            2         2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ---------------------------------------------
+--R                      |        5 3         4 2 2        3 4        2 6
+--R                     \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   1
+--R              /
+--R                     2         2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                              4 3         3 2 2        2 4          6  +-+
+--R                       (15552a c  - 11664a b c  + 2916a b c - 243a b )\|3
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                             2      4  +-+
+--R                     (- 36a b c + 9b )\|3
+--R                *
+--R                     ROOT
+--R                                     2         2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            1
+--R                       /
+--R                              2         2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                4 3         3 2 2        2 4          6
+--R                         (15552a c  - 11664a b c  + 2916a b c - 243a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                              2      4
+--R                       - 36a b c + 9b
+--R                  *
+--R                       ROOT
+--R                                       2         2
+--R                                (- 108a c + 27a b )
+--R                             *
+--R                               +-----------------------------------------------+
+--R                               |                         2
+--R                               |                        b
+--R                               |- ---------------------------------------------
+--R                               |        5 3         4 2 2        3 4        2 6
+--R                              \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                            + 
+--R                              1
+--R                         /
+--R                                2         2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                   - 4b c x
+--R     + 
+--R       -
+--R              +-+
+--R            2\|3
+--R         *
+--R            ROOT
+--R                          2         2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ---------------------------------------------
+--R                      |        5 3         4 2 2        3 4        2 6
+--R                     \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   1
+--R              /
+--R                     2         2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                              4 3         3 2 2        2 4          6  +-+
+--R                       (15552a c  - 11664a b c  + 2916a b c - 243a b )\|3
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                           2      4  +-+
+--R                     (36a b c - 9b )\|3
+--R                *
+--R                     ROOT
+--R                                   2         2
+--R                              (108a c - 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            1
+--R                       /
+--R                              2         2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                4 3         3 2 2        2 4          6
+--R                         (15552a c  - 11664a b c  + 2916a b c - 243a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                            2      4
+--R                       36a b c - 9b
+--R                  *
+--R                       ROOT
+--R                                     2         2
+--R                                (108a c - 27a b )
+--R                             *
+--R                               +-----------------------------------------------+
+--R                               |                         2
+--R                               |                        b
+--R                               |- ---------------------------------------------
+--R                               |        5 3         4 2 2        3 4        2 6
+--R                              \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                            + 
+--R                              1
+--R                         /
+--R                                2         2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                   4b c x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 714
+
+--S 715 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                     +--------------------+ +------------------+
+--R                       +-----------+ |   +-----------+      | +-----------+
+--R             3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R            3\|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          2         2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ---------------------------------------------
+--R                      |        5 3         4 2 2        3 4        2 6
+--R                     \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   1
+--R              /
+--R                     2         2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                              4 3         3 2 2        2 4          6
+--R                       (15552a c  - 11664a b c  + 2916a b c - 243a b )x
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                           2      4
+--R                     (36a b c - 9b )x
+--R                *
+--R                     ROOT
+--R                                   2         2
+--R                              (108a c - 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            1
+--R                       /
+--R                              2         2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             3   2       2 3         5
+--R                       (1296a b c  - 648a b c + 81a b )
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                                   3
+--R                     - 12a b c + 3b
+--R                *
+--R                   ROOT
+--R                                 2         2
+--R                            (108a c - 27a b )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                        + 
+--R                          1
+--R                     /
+--R                            2         2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                       2
+--R                 2b c x
+--R     + 
+--R                   +--------------------+
+--R                   |   +-----------+
+--R           +-+3+-+3|   |          2
+--R         2\|3 \|c \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                   +--------------------+     +------------------+
+--R                   |   +-----------+          | +-----------+
+--R           +-+3+-+3|   |          2          3| |          2          3+-+3+-+
+--R       - 4\|3 \|c \|- \|- 4a c + b   + b log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                      +------------------+
+--R                      | +-----------+
+--R              +-+3+-+3| |          2
+--R            2\|3 \|c \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +--------------------+2             +--------------------+
+--R                  |   +-----------+                   |   +-----------+
+--R                 3|   |          2           3+-+3+-+3|   |          2
+--R                 \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R                 +------------------+     +--------------------+
+--R                 | +-----------+          |   +-----------+
+--R         +-+3+-+3| |          2          3|   |          2          3+-+3+-+
+--R       4\|3 \|c \|\|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                    +-----------+
+--R          3+-+2 +-+ |          2
+--R         6\|2  \|3 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                         2         2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                1
+--R           /
+--R                  2         2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         3|   |          2      3| |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                           4 3         3 2 2        2 4          6
+--R                    (15552a c  - 11664a b c  + 2916a b c - 243a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                         2
+--R                     |                        b
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                         2      4
+--R                  - 36a b c + 9b
+--R             *
+--R                  ROOT
+--R                                  2         2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                            +-----------------------------------------------+
+--R                            |                         2
+--R                            |                        b
+--R                            |- ---------------------------------------------
+--R                            |        5 3         4 2 2        3 4        2 6
+--R                           \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                       + 
+--R                         1
+--R                    /
+--R                           2         2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R              2b c x
+--R     + 
+--R       -
+--R                       +-----------+
+--R             3+-+2 +-+ |          2
+--R            3\|2  \|3 \|- 4a c + b
+--R         *
+--R            ROOT
+--R                            2         2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ---------------------------------------------
+--R                      |        5 3         4 2 2        3 4        2 6
+--R                     \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   1
+--R              /
+--R                     2         2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R            3|   |          2      3| |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                4 3         3 2 2        2 4          6
+--R                       (- 15552a c  + 11664a b c  - 2916a b c + 243a b )x
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                           2      4
+--R                     (36a b c - 9b )x
+--R                *
+--R                     ROOT
+--R                                     2         2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            1
+--R                       /
+--R                              2         2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               3   2       2 3         5
+--R                       (- 1296a b c  + 648a b c - 81a b )
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                                   3
+--R                     - 12a b c + 3b
+--R                *
+--R                   ROOT
+--R                                   2         2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                        + 
+--R                          1
+--R                     /
+--R                            2         2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                       2
+--R                 2b c x
+--R     + 
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R          3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R         6\|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       2         2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                         2
+--R                   |                        b
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                1
+--R           /
+--R                  2         2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                             4 3         3 2 2        2 4          6
+--R                    (- 15552a c  + 11664a b c  - 2916a b c + 243a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                         2
+--R                     |                        b
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                         2      4
+--R                  - 36a b c + 9b
+--R             *
+--R                  ROOT
+--R                                2         2
+--R                           (108a c - 27a b )
+--R                        *
+--R                            +-----------------------------------------------+
+--R                            |                         2
+--R                            |                        b
+--R                            |- ---------------------------------------------
+--R                            |        5 3         4 2 2        3 4        2 6
+--R                           \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                       + 
+--R                         1
+--R                    /
+--R                           2         2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R              2b c x
+--R     + 
+--R       -
+--R                    +-----------+
+--R              3+-+2 |          2
+--R            18\|2  \|- 4a c + b
+--R         *
+--R            ROOT
+--R                            2         2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ---------------------------------------------
+--R                      |        5 3         4 2 2        3 4        2 6
+--R                     \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   1
+--R              /
+--R                     2         2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R            3|   |          2      3| |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            atan
+--R                              4 3         3 2 2        2 4          6  +-+
+--R                       (15552a c  - 11664a b c  + 2916a b c - 243a b )\|3
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                             2      4  +-+
+--R                     (- 36a b c + 9b )\|3
+--R                *
+--R                     ROOT
+--R                                     2         2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            1
+--R                       /
+--R                              2         2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                4 3         3 2 2        2 4          6
+--R                         (15552a c  - 11664a b c  + 2916a b c - 243a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                              2      4
+--R                       - 36a b c + 9b
+--R                  *
+--R                       ROOT
+--R                                       2         2
+--R                                (- 108a c + 27a b )
+--R                             *
+--R                               +-----------------------------------------------+
+--R                               |                         2
+--R                               |                        b
+--R                               |- ---------------------------------------------
+--R                               |        5 3         4 2 2        3 4        2 6
+--R                              \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                            + 
+--R                              1
+--R                         /
+--R                                2         2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                   - 4b c x
+--R     + 
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              3+-+2 |          2 3|   |          2      3| |          2
+--R            18\|2  \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          2         2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                         2
+--R                      |                        b
+--R                      |- ---------------------------------------------
+--R                      |        5 3         4 2 2        3 4        2 6
+--R                     \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   1
+--R              /
+--R                     2         2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                              4 3         3 2 2        2 4          6  +-+
+--R                       (15552a c  - 11664a b c  + 2916a b c - 243a b )\|3
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                         2
+--R                        |                        b
+--R                        |- ---------------------------------------------
+--R                        |        5 3         4 2 2        3 4        2 6
+--R                       \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                           2      4  +-+
+--R                     (36a b c - 9b )\|3
+--R                *
+--R                     ROOT
+--R                                   2         2
+--R                              (108a c - 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |                         2
+--R                             |                        b
+--R                             |- ---------------------------------------------
+--R                             |        5 3         4 2 2        3 4        2 6
+--R                            \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            1
+--R                       /
+--R                              2         2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                4 3         3 2 2        2 4          6
+--R                         (15552a c  - 11664a b c  + 2916a b c - 243a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                         2
+--R                          |                        b
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                            2      4
+--R                       36a b c - 9b
+--R                  *
+--R                       ROOT
+--R                                     2         2
+--R                                (108a c - 27a b )
+--R                             *
+--R                               +-----------------------------------------------+
+--R                               |                         2
+--R                               |                        b
+--R                               |- ---------------------------------------------
+--R                               |        5 3         4 2 2        3 4        2 6
+--R                              \|  46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                            + 
+--R                              1
+--R                         /
+--R                                2         2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                   4b c x
+--R     + 
+--R                                                  +------------------+
+--R                +--------------------+            | +-----------+
+--R                |   +-----------+          3+-+2 3| |          2          3+-+
+--R           3+-+3|   |          2           \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       - 12\|c \|- \|- 4a c + b   + b atan(-----------------------------------)
+--R                                                        +------------------+
+--R                                                        | +-----------+
+--R                                              3+-+2 +-+3| |          2
+--R                                              \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                              +--------------------+
+--R              +------------------+            |   +-----------+
+--R              | +-----------+          3+-+2 3|   |          2          3+-+
+--R         3+-+3| |          2           \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R       12\|c \|\|- 4a c + b   + b atan(-------------------------------------)
+--R                                                    +--------------------+
+--R                                                    |   +-----------+
+--R                                          3+-+2 +-+3|   |          2
+--R                                          \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R      3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R     6\|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 715
+
+--S 716 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 716
+
+)clear all
+
+--S 717 of 2282
+t0:=1/(a+b*x^3+c*x^6)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 717
+
+--S 718 of 2282
+r0:=1/3*2^(2/3)*c^(2/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))/_
+   ((b-sqrt(b^2-4*a*c))^(2/3)*sqrt(b^2-4*a*c))-1/3*c^(2/3)*log(2^(2/3)*_
+   c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-_
+   sqrt(b^2-4*a*c))^(2/3))/(2^(1/3)*(b-sqrt(b^2-4*a*c))^(2/3)*_
+   sqrt(b^2-4*a*c))-2^(2/3)*c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b-_
+   sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))/_
+   (sqrt(3)*(b-sqrt(b^2-4*a*c))^(2/3)*sqrt(b^2-4*a*c))-_
+   1/3*2^(2/3)*c^(2/3)*log(2^(1/3)*c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(2/3))+1/3*c^(2/3)*_
+   log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+_
+   (b+sqrt(b^2-4*a*c))^(2/3))/(2^(1/3)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-_
+   4*a*c))^(2/3))+2^(2/3)*c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b+_
+   sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))/_
+   (sqrt(3)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                    +--------------------+2
+--R                    |   +-----------+
+--R          +-+3+-+2 3|   |          2
+--R         \|3 \|c   \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R       -
+--R                        +--------------------+2
+--R                        |   +-----------+
+--R              +-+3+-+2 3|   |          2
+--R            2\|3 \|c   \|- \|- 4a c + b   + b
+--R         *
+--R                 +------------------+
+--R                 | +-----------+
+--R                3| |          2          3+-+3+-+
+--R            log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                       +------------------+2
+--R                       | +-----------+
+--R             +-+3+-+2 3| |          2
+--R            \|3 \|c   \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +--------------------+2             +--------------------+
+--R                  |   +-----------+                   |   +-----------+
+--R                 3|   |          2           3+-+3+-+3|   |          2
+--R                 \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R                   +------------------+2     +--------------------+
+--R                   | +-----------+           |   +-----------+
+--R         +-+3+-+2 3| |          2           3|   |          2          3+-+3+-+
+--R       2\|3 \|c   \|\|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                  +------------------+
+--R               +--------------------+2            | +-----------+
+--R               |   +-----------+           3+-+2 3| |          2          3+-+
+--R        3+-+2 3|   |          2            \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       6\|c   \|- \|- 4a c + b   + b  atan(-----------------------------------)
+--R                                                        +------------------+
+--R                                                        | +-----------+
+--R                                              3+-+2 +-+3| |          2
+--R                                              \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                                +--------------------+
+--R               +------------------+2            |   +-----------+
+--R               | +-----------+           3+-+2 3|   |          2          3+-+
+--R        3+-+2 3| |          2            \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R     - 6\|c   \|\|- 4a c + b   + b  atan(-------------------------------------)
+--R                                                      +--------------------+
+--R                                                      |   +-----------+
+--R                                            3+-+2 +-+3|   |          2
+--R                                            \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                             +--------------------+2  +------------------+2
+--R               +-----------+ |   +-----------+        | +-----------+
+--R      3+-+ +-+ |          2 3|   |          2        3| |          2
+--R     3\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                            3       2 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +---------------------------------------------+
+--R                      |                2 2       2     4
+--R                      |            - 4a c  + 4a b c - b
+--R                      |---------------------------------------------
+--R                      |      7 3         6 2 2        5 4        4 6
+--R                     \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   - b
+--R              /
+--R                     3       2 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                              5   3         4 3 2        3 5        2 7
+--R                       (15552a b c  - 11664a b c  + 2916a b c - 243a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |            - 4a c  + 4a b c - b
+--R                        |---------------------------------------------
+--R                        |      7 3         6 2 2        5 4        4 6
+--R                       \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                         3 3       2 2 2        4      6
+--R                     144a c  - 180a b c  + 72a b c - 9b
+--R                *
+--R                     ROOT
+--R                                     3       2 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |            - 4a c  + 4a b c - b
+--R                               |---------------------------------------------
+--R                               |      7 3         6 2 2        5 4        4 6
+--R                              \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            - b
+--R                       /
+--R                              3       2 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               4   3       3 3 2      2 5
+--R                       (- 1296a b c  + 648a b c  - 81a b c)x
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |            - 4a c  + 4a b c - b
+--R                        |---------------------------------------------
+--R                        |      7 3         6 2 2        5 4        4 6
+--R                       \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                           2 3        2 2     4
+--R                     (- 24a c  + 18a b c  - 3b c)x
+--R                *
+--R                   ROOT
+--R                                   3       2 2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                             +---------------------------------------------+
+--R                             |                2 2       2     4
+--R                             |            - 4a c  + 4a b c - b
+--R                             |---------------------------------------------
+--R                             |      7 3         6 2 2        5 4        4 6
+--R                            \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                        + 
+--R                          - b
+--R                     /
+--R                            3       2 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                      3     2 2  2
+--R                 (4a c  - 2b c )x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                         3       2 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2       2     4
+--R                   |            - 4a c  + 4a b c - b
+--R                   |---------------------------------------------
+--R                   |      7 3         6 2 2        5 4        4 6
+--R                  \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                - b
+--R           /
+--R                  3       2 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                          4   2       3 3       2 5
+--R                    (1296a b c  - 648a b c + 81a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |            - 4a c  + 4a b c - b
+--R                     |---------------------------------------------
+--R                     |      7 3         6 2 2        5 4        4 6
+--R                    \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                     2 2        2      4
+--R                  24a c  - 18a b c + 3b
+--R             *
+--R                ROOT
+--R                                3       2 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |            - 4a c  + 4a b c - b
+--R                          |---------------------------------------------
+--R                          |      7 3         6 2 2        5 4        4 6
+--R                         \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                       - b
+--R                  /
+--R                         3       2 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                   2     2
+--R              (4a c  - 2b c)x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                       3       2 2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2       2     4
+--R                   |            - 4a c  + 4a b c - b
+--R                   |---------------------------------------------
+--R                   |      7 3         6 2 2        5 4        4 6
+--R                  \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                - b
+--R           /
+--R                  3       2 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                            4   2       3 3       2 5
+--R                    (- 1296a b c  + 648a b c - 81a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |            - 4a c  + 4a b c - b
+--R                     |---------------------------------------------
+--R                     |      7 3         6 2 2        5 4        4 6
+--R                    \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                     2 2        2      4
+--R                  24a c  - 18a b c + 3b
+--R             *
+--R                ROOT
+--R                              3       2 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |            - 4a c  + 4a b c - b
+--R                          |---------------------------------------------
+--R                          |      7 3         6 2 2        5 4        4 6
+--R                         \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                       - b
+--R                  /
+--R                         3       2 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                   2     2
+--R              (4a c  - 2b c)x
+--R     + 
+--R       -
+--R            ROOT
+--R                          3       2 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +---------------------------------------------+
+--R                      |                2 2       2     4
+--R                      |            - 4a c  + 4a b c - b
+--R                      |---------------------------------------------
+--R                      |      7 3         6 2 2        5 4        4 6
+--R                     \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   - b
+--R              /
+--R                     3       2 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                5   3         4 3 2        3 5        2 7
+--R                       (- 15552a b c  + 11664a b c  - 2916a b c + 243a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |            - 4a c  + 4a b c - b
+--R                        |---------------------------------------------
+--R                        |      7 3         6 2 2        5 4        4 6
+--R                       \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                         3 3       2 2 2        4      6
+--R                     144a c  - 180a b c  + 72a b c - 9b
+--R                *
+--R                     ROOT
+--R                                   3       2 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |            - 4a c  + 4a b c - b
+--R                               |---------------------------------------------
+--R                               |      7 3         6 2 2        5 4        4 6
+--R                              \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            - b
+--R                       /
+--R                              3       2 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             4   3       3 3 2      2 5
+--R                       (1296a b c  - 648a b c  + 81a b c)x
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |            - 4a c  + 4a b c - b
+--R                        |---------------------------------------------
+--R                        |      7 3         6 2 2        5 4        4 6
+--R                       \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                           2 3        2 2     4
+--R                     (- 24a c  + 18a b c  - 3b c)x
+--R                *
+--R                   ROOT
+--R                                 3       2 2
+--R                            (108a c - 27a b )
+--R                         *
+--R                             +---------------------------------------------+
+--R                             |                2 2       2     4
+--R                             |            - 4a c  + 4a b c - b
+--R                             |---------------------------------------------
+--R                             |      7 3         6 2 2        5 4        4 6
+--R                            \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                        + 
+--R                          - b
+--R                     /
+--R                            3       2 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                      3     2 2  2
+--R                 (4a c  - 2b c )x
+--R     + 
+--R           +-+
+--R         2\|3
+--R      *
+--R         ROOT
+--R                         3       2 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2       2     4
+--R                   |            - 4a c  + 4a b c - b
+--R                   |---------------------------------------------
+--R                   |      7 3         6 2 2        5 4        4 6
+--R                  \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                - b
+--R           /
+--R                  3       2 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                          4   2       3 3       2 5  +-+
+--R                    (1296a b c  - 648a b c + 81a b )\|3
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |            - 4a c  + 4a b c - b
+--R                     |---------------------------------------------
+--R                     |      7 3         6 2 2        5 4        4 6
+--R                    \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                      2 2        2      4  +-+
+--R                  (24a c  - 18a b c + 3b )\|3
+--R             *
+--R                ROOT
+--R                                3       2 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |            - 4a c  + 4a b c - b
+--R                          |---------------------------------------------
+--R                          |      7 3         6 2 2        5 4        4 6
+--R                         \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                       - b
+--R                  /
+--R                         3       2 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                            4   2       3 3       2 5
+--R                      (1296a b c  - 648a b c + 81a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                2 2       2     4
+--R                       |            - 4a c  + 4a b c - b
+--R                       |---------------------------------------------
+--R                       |      7 3         6 2 2        5 4        4 6
+--R                      \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                  + 
+--R                       2 2        2      4
+--R                    24a c  - 18a b c + 3b
+--R               *
+--R                  ROOT
+--R                                  3       2 2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                            +---------------------------------------------+
+--R                            |                2 2       2     4
+--R                            |            - 4a c  + 4a b c - b
+--R                            |---------------------------------------------
+--R                            |      7 3         6 2 2        5 4        4 6
+--R                           \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                       + 
+--R                         - b
+--R                    /
+--R                           3       2 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                       2     2
+--R                (- 8a c  + 4b c)x
+--R     + 
+--R           +-+
+--R         2\|3
+--R      *
+--R         ROOT
+--R                       3       2 2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2       2     4
+--R                   |            - 4a c  + 4a b c - b
+--R                   |---------------------------------------------
+--R                   |      7 3         6 2 2        5 4        4 6
+--R                  \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                - b
+--R           /
+--R                  3       2 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                          4   2       3 3       2 5  +-+
+--R                    (1296a b c  - 648a b c + 81a b )\|3
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |            - 4a c  + 4a b c - b
+--R                     |---------------------------------------------
+--R                     |      7 3         6 2 2        5 4        4 6
+--R                    \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                        2 2        2      4  +-+
+--R                  (- 24a c  + 18a b c - 3b )\|3
+--R             *
+--R                ROOT
+--R                              3       2 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |            - 4a c  + 4a b c - b
+--R                          |---------------------------------------------
+--R                          |      7 3         6 2 2        5 4        4 6
+--R                         \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                       - b
+--R                  /
+--R                         3       2 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                            4   2       3 3       2 5
+--R                      (1296a b c  - 648a b c + 81a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                2 2       2     4
+--R                       |            - 4a c  + 4a b c - b
+--R                       |---------------------------------------------
+--R                       |      7 3         6 2 2        5 4        4 6
+--R                      \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                  + 
+--R                         2 2        2      4
+--R                    - 24a c  + 18a b c - 3b
+--R               *
+--R                  ROOT
+--R                                3       2 2
+--R                           (108a c - 27a b )
+--R                        *
+--R                            +---------------------------------------------+
+--R                            |                2 2       2     4
+--R                            |            - 4a c  + 4a b c - b
+--R                            |---------------------------------------------
+--R                            |      7 3         6 2 2        5 4        4 6
+--R                           \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                       + 
+--R                         - b
+--R                    /
+--R                           3       2 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                     2     2
+--R                (8a c  - 4b c)x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 719
+
+--S 720 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        +--------------------+2
+--R                        |   +-----------+
+--R              +-+3+-+2 3|   |          2
+--R            2\|3 \|c   \|- \|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +------------------+2             +------------------+
+--R                  | +-----------+                   | +-----------+
+--R                 3| |          2           3+-+3+-+3| |          2
+--R                 \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R                   +--------------------+2     +------------------+
+--R                   |   +-----------+           | +-----------+
+--R         +-+3+-+2 3|   |          2           3| |          2          3+-+3+-+
+--R       4\|3 \|c   \|- \|- 4a c + b   + b  log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                     +------------------+2
+--R                     | +-----------+
+--R           +-+3+-+2 3| |          2
+--R         2\|3 \|c   \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R       -
+--R                        +------------------+2
+--R                        | +-----------+
+--R              +-+3+-+2 3| |          2
+--R            4\|3 \|c   \|\|- 4a c + b   + b
+--R         *
+--R                 +--------------------+
+--R                 |   +-----------+
+--R                3|   |          2          3+-+3+-+
+--R            log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                      +-----------+
+--R             3+-+ +-+ |          2
+--R            3\|2 \|3 \|- 4a c + b
+--R         *
+--R            ROOT
+--R                            3       2 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +---------------------------------------------+
+--R                      |                2 2       2     4
+--R                      |            - 4a c  + 4a b c - b
+--R                      |---------------------------------------------
+--R                      |      7 3         6 2 2        5 4        4 6
+--R                     \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   - b
+--R              /
+--R                     3       2 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +--------------------+2  +------------------+2
+--R             |   +-----------+        | +-----------+
+--R            3|   |          2        3| |          2
+--R            \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                              5   3         4 3 2        3 5        2 7
+--R                       (15552a b c  - 11664a b c  + 2916a b c - 243a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |            - 4a c  + 4a b c - b
+--R                        |---------------------------------------------
+--R                        |      7 3         6 2 2        5 4        4 6
+--R                       \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                         3 3       2 2 2        4      6
+--R                     144a c  - 180a b c  + 72a b c - 9b
+--R                *
+--R                     ROOT
+--R                                     3       2 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |            - 4a c  + 4a b c - b
+--R                               |---------------------------------------------
+--R                               |      7 3         6 2 2        5 4        4 6
+--R                              \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            - b
+--R                       /
+--R                              3       2 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               4   3       3 3 2      2 5
+--R                       (- 1296a b c  + 648a b c  - 81a b c)x
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |            - 4a c  + 4a b c - b
+--R                        |---------------------------------------------
+--R                        |      7 3         6 2 2        5 4        4 6
+--R                       \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                           2 3        2 2     4
+--R                     (- 24a c  + 18a b c  - 3b c)x
+--R                *
+--R                   ROOT
+--R                                   3       2 2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                             +---------------------------------------------+
+--R                             |                2 2       2     4
+--R                             |            - 4a c  + 4a b c - b
+--R                             |---------------------------------------------
+--R                             |      7 3         6 2 2        5 4        4 6
+--R                            \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                        + 
+--R                          - b
+--R                     /
+--R                            3       2 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                      3     2 2  2
+--R                 (4a c  - 2b c )x
+--R     + 
+--R                   +-----------+
+--R          3+-+ +-+ |          2
+--R         6\|2 \|3 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                         3       2 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2       2     4
+--R                   |            - 4a c  + 4a b c - b
+--R                   |---------------------------------------------
+--R                   |      7 3         6 2 2        5 4        4 6
+--R                  \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                - b
+--R           /
+--R                  3       2 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +--------------------+2  +------------------+2
+--R          |   +-----------+        | +-----------+
+--R         3|   |          2        3| |          2
+--R         \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          4   2       3 3       2 5
+--R                    (1296a b c  - 648a b c + 81a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |            - 4a c  + 4a b c - b
+--R                     |---------------------------------------------
+--R                     |      7 3         6 2 2        5 4        4 6
+--R                    \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                     2 2        2      4
+--R                  24a c  - 18a b c + 3b
+--R             *
+--R                ROOT
+--R                                3       2 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |            - 4a c  + 4a b c - b
+--R                          |---------------------------------------------
+--R                          |      7 3         6 2 2        5 4        4 6
+--R                         \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                       - b
+--R                  /
+--R                         3       2 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                   2     2
+--R              (4a c  - 2b c)x
+--R     + 
+--R                                 +--------------------+2  +------------------+2
+--R                   +-----------+ |   +-----------+        | +-----------+
+--R          3+-+ +-+ |          2 3|   |          2        3| |          2
+--R         6\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       3       2 2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2       2     4
+--R                   |            - 4a c  + 4a b c - b
+--R                   |---------------------------------------------
+--R                   |      7 3         6 2 2        5 4        4 6
+--R                  \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                - b
+--R           /
+--R                  3       2 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                            4   2       3 3       2 5
+--R                    (- 1296a b c  + 648a b c - 81a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |            - 4a c  + 4a b c - b
+--R                     |---------------------------------------------
+--R                     |      7 3         6 2 2        5 4        4 6
+--R                    \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                     2 2        2      4
+--R                  24a c  - 18a b c + 3b
+--R             *
+--R                ROOT
+--R                              3       2 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |            - 4a c  + 4a b c - b
+--R                          |---------------------------------------------
+--R                          |      7 3         6 2 2        5 4        4 6
+--R                         \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                       - b
+--R                  /
+--R                         3       2 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                   2     2
+--R              (4a c  - 2b c)x
+--R     + 
+--R       -
+--R                                    +--------------------+2
+--R                      +-----------+ |   +-----------+
+--R             3+-+ +-+ |          2 3|   |          2
+--R            3\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R             +------------------+2
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          3       2 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +---------------------------------------------+
+--R                      |                2 2       2     4
+--R                      |            - 4a c  + 4a b c - b
+--R                      |---------------------------------------------
+--R                      |      7 3         6 2 2        5 4        4 6
+--R                     \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                 + 
+--R                   - b
+--R              /
+--R                     3       2 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                5   3         4 3 2        3 5        2 7
+--R                       (- 15552a b c  + 11664a b c  - 2916a b c + 243a b )
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |            - 4a c  + 4a b c - b
+--R                        |---------------------------------------------
+--R                        |      7 3         6 2 2        5 4        4 6
+--R                       \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                         3 3       2 2 2        4      6
+--R                     144a c  - 180a b c  + 72a b c - 9b
+--R                *
+--R                     ROOT
+--R                                   3       2 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                               +---------------------------------------------+
+--R                               |                2 2       2     4
+--R                               |            - 4a c  + 4a b c - b
+--R                               |---------------------------------------------
+--R                               |      7 3         6 2 2        5 4        4 6
+--R                              \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                          + 
+--R                            - b
+--R                       /
+--R                              3       2 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             4   3       3 3 2      2 5
+--R                       (1296a b c  - 648a b c  + 81a b c)x
+--R                    *
+--R                        +---------------------------------------------+
+--R                        |                2 2       2     4
+--R                        |            - 4a c  + 4a b c - b
+--R                        |---------------------------------------------
+--R                        |      7 3         6 2 2        5 4        4 6
+--R                       \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                   + 
+--R                           2 3        2 2     4
+--R                     (- 24a c  + 18a b c  - 3b c)x
+--R                *
+--R                   ROOT
+--R                                 3       2 2
+--R                            (108a c - 27a b )
+--R                         *
+--R                             +---------------------------------------------+
+--R                             |                2 2       2     4
+--R                             |            - 4a c  + 4a b c - b
+--R                             |---------------------------------------------
+--R                             |      7 3         6 2 2        5 4        4 6
+--R                            \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                        + 
+--R                          - b
+--R                     /
+--R                            3       2 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                      3     2 2  2
+--R                 (4a c  - 2b c )x
+--R     + 
+--R                +-----------+
+--R           3+-+ |          2
+--R         18\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                         3       2 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2       2     4
+--R                   |            - 4a c  + 4a b c - b
+--R                   |---------------------------------------------
+--R                   |      7 3         6 2 2        5 4        4 6
+--R                  \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                - b
+--R           /
+--R                  3       2 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +--------------------+2  +------------------+2
+--R          |   +-----------+        | +-----------+
+--R         3|   |          2        3| |          2
+--R         \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                          4   2       3 3       2 5  +-+
+--R                    (1296a b c  - 648a b c + 81a b )\|3
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |            - 4a c  + 4a b c - b
+--R                     |---------------------------------------------
+--R                     |      7 3         6 2 2        5 4        4 6
+--R                    \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                      2 2        2      4  +-+
+--R                  (24a c  - 18a b c + 3b )\|3
+--R             *
+--R                ROOT
+--R                                3       2 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |            - 4a c  + 4a b c - b
+--R                          |---------------------------------------------
+--R                          |      7 3         6 2 2        5 4        4 6
+--R                         \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                       - b
+--R                  /
+--R                         3       2 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                            4   2       3 3       2 5
+--R                      (1296a b c  - 648a b c + 81a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                2 2       2     4
+--R                       |            - 4a c  + 4a b c - b
+--R                       |---------------------------------------------
+--R                       |      7 3         6 2 2        5 4        4 6
+--R                      \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                  + 
+--R                       2 2        2      4
+--R                    24a c  - 18a b c + 3b
+--R               *
+--R                  ROOT
+--R                                  3       2 2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                            +---------------------------------------------+
+--R                            |                2 2       2     4
+--R                            |            - 4a c  + 4a b c - b
+--R                            |---------------------------------------------
+--R                            |      7 3         6 2 2        5 4        4 6
+--R                           \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                       + 
+--R                         - b
+--R                    /
+--R                           3       2 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                       2     2
+--R                (- 8a c  + 4b c)x
+--R     + 
+--R                              +--------------------+2  +------------------+2
+--R                +-----------+ |   +-----------+        | +-----------+
+--R           3+-+ |          2 3|   |          2        3| |          2
+--R         18\|2 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       3       2 2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2       2     4
+--R                   |            - 4a c  + 4a b c - b
+--R                   |---------------------------------------------
+--R                   |      7 3         6 2 2        5 4        4 6
+--R                  \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R              + 
+--R                - b
+--R           /
+--R                  3       2 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                          4   2       3 3       2 5  +-+
+--R                    (1296a b c  - 648a b c + 81a b )\|3
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2       2     4
+--R                     |            - 4a c  + 4a b c - b
+--R                     |---------------------------------------------
+--R                     |      7 3         6 2 2        5 4        4 6
+--R                    \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                + 
+--R                        2 2        2      4  +-+
+--R                  (- 24a c  + 18a b c - 3b )\|3
+--R             *
+--R                ROOT
+--R                              3       2 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2       2     4
+--R                          |            - 4a c  + 4a b c - b
+--R                          |---------------------------------------------
+--R                          |      7 3         6 2 2        5 4        4 6
+--R                         \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                     + 
+--R                       - b
+--R                  /
+--R                         3       2 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                            4   2       3 3       2 5
+--R                      (1296a b c  - 648a b c + 81a b )
+--R                   *
+--R                       +---------------------------------------------+
+--R                       |                2 2       2     4
+--R                       |            - 4a c  + 4a b c - b
+--R                       |---------------------------------------------
+--R                       |      7 3         6 2 2        5 4        4 6
+--R                      \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                  + 
+--R                         2 2        2      4
+--R                    - 24a c  + 18a b c - 3b
+--R               *
+--R                  ROOT
+--R                                3       2 2
+--R                           (108a c - 27a b )
+--R                        *
+--R                            +---------------------------------------------+
+--R                            |                2 2       2     4
+--R                            |            - 4a c  + 4a b c - b
+--R                            |---------------------------------------------
+--R                            |      7 3         6 2 2        5 4        4 6
+--R                           \|46656a c  - 34992a b c  + 8748a b c - 729a b
+--R                       + 
+--R                         - b
+--R                    /
+--R                           3       2 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                     2     2
+--R                (8a c  - 4b c)x
+--R     + 
+--R       -
+--R                     +--------------------+2
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2
+--R            12\|c   \|- \|- 4a c + b   + b
+--R         *
+--R                        +------------------+
+--R                        | +-----------+
+--R                 3+-+2 3| |          2          3+-+
+--R                 \|2   \|\|- 4a c + b   + b - 4x\|c
+--R            atan(-----------------------------------)
+--R                              +------------------+
+--R                              | +-----------+
+--R                    3+-+2 +-+3| |          2
+--R                    \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                                 +--------------------+
+--R                +------------------+2            |   +-----------+
+--R                | +-----------+           3+-+2 3|   |          2          3+-+
+--R         3+-+2 3| |          2            \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R       12\|c   \|\|- 4a c + b   + b  atan(-------------------------------------)
+--R                                                       +--------------------+
+--R                                                       |   +-----------+
+--R                                             3+-+2 +-+3|   |          2
+--R                                             \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                             +--------------------+2  +------------------+2
+--R               +-----------+ |   +-----------+        | +-----------+
+--R      3+-+ +-+ |          2 3|   |          2        3| |          2
+--R     6\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 720
+
+--S 721 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 721
+
+)clear all
+
+--S 722 of 2282
+t0:=1/(x*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           7      4
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 722
+
+--S 723 of 2282
+r0:=log(x)/a-1/6*log(a+b*x^3+c*x^6)/a+1/3*b*atanh((b+2*c*x^3)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                   3                                             +-----------+
+--R               2c x  + b                6      3                 |          2
+--R   2b atanh(--------------) + (- log(c x  + b x  + a) + 6log(x))\|- 4a c + b
+--R             +-----------+
+--R             |          2
+--R            \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                    +-----------+
+--R                                    |          2
+--R                                 6a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 723
+
+--S 724 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 6         3           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   3             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   6      3
+--R                c x  + b x  + a
+--R       + 
+--R                                            +-----------+
+--R                   6      3                 |          2
+--R         (- log(c x  + b x  + a) + 6log(x))\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       6a\|- 4a c + b
+--R     ,
+--R
+--R                               +---------+
+--R                        3      |        2
+--R                   (2c x  + b)\|4a c - b
+--R         - 2b atan(-----------------------)
+--R                                  2
+--R                          4a c - b
+--R       + 
+--R                                            +---------+
+--R                   6      3                 |        2
+--R         (- log(c x  + b x  + a) + 6log(x))\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       6a\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 724
+
+--S 725 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 6         3           2  |          2           2     2   3
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 6      3
+--R              c x  + b x  + a
+--R     + 
+--R                         3
+--R                     2c x  + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     6a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 726
+
+--S 727 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             3
+--R           |        2          2c x  + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          3      |        2
+--R           |          2      (2c x  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     3a\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 727
+
+--S 728 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 728
+
+)clear all
+
+--S 729 of 2282
+t0:=1/(x^2*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           8      5      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 729
+
+--S 730 of 2282
+r0:=(-1)/(a*x)+1/3*c^(1/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*_
+   (1+b/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b-sqrt(b^2-4*a*c))^(1/3))-_
+   1/6*c^(1/3)*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-_
+   sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(1+_
+   b/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b-sqrt(b^2-4*a*c))^(1/3))+c^(1/3)*_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(1+b/sqrt(b^2-4*a*c))/(2^(2/3)*_
+   a*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3))+1/3*c^(1/3)*log(2^(1/3)*c^(1/3)*x+_
+   (b+sqrt(b^2-4*a*c))^(1/3))*(1-b/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b+_
+   sqrt(b^2-4*a*c))^(1/3))-1/6*c^(1/3)*log(2^(2/3)*c^(2/3)*x^2-_
+   2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-_
+   4*a*c))^(2/3))*(1-b/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b+sqrt(b^2-_
+   4*a*c))^(1/3))+c^(1/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*_
+   (1-b/sqrt(b^2-4*a*c))/(2^(2/3)*a*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3))
+--R 
+--R
+--R   (2)
+--R                                               +--------------------+
+--R                  +-----------+                |   +-----------+
+--R              +-+ |          2        +-+ 3+-+3|   |          2
+--R         (- x\|3 \|- 4a c + b   + b x\|3 )\|c \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                               +--------------------+
+--R                 +-----------+                 |   +-----------+
+--R             +-+ |          2         +-+ 3+-+3|   |          2
+--R         (2x\|3 \|- 4a c + b   - 2b x\|3 )\|c \|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                               +------------------+
+--R                  +-----------+                | +-----------+
+--R              +-+ |          2        +-+ 3+-+3| |          2
+--R         (- x\|3 \|- 4a c + b   - b x\|3 )\|c \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                               +------------------+
+--R                 +-----------+                 | +-----------+
+--R             +-+ |          2         +-+ 3+-+3| |          2
+--R         (2x\|3 \|- 4a c + b   + 2b x\|3 )\|c \|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                       +--------------------+
+--R             +-----------+             |   +-----------+
+--R             |          2         3+-+3|   |          2
+--R         (6x\|- 4a c + b   - 6b x)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                       +------------------+
+--R             +-----------+             | +-----------+
+--R             |          2         3+-+3| |          2
+--R         (6x\|- 4a c + b   + 6b x)\|c \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R          3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R       - 6\|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R          3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R     6a x \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 730
+
+--S 731 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                          5       4 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |      4 4      3 2 3      2 4 2       6     8
+--R                      |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |-----------------------------------------------
+--R                      |      11 3         10 2 2        9 4        8 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                             3
+--R                   2a b c - b
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                               8 4         7 2 3         6 4 2        5 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             4 8
+--R                         243a b
+--R                    *
+--R                         +-----------------------------------------------+
+--R                         |      4 4      3 2 3      2 4 2       6     8
+--R                         |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       x |-----------------------------------------------
+--R                         |      11 3         10 2 2        9 4        8 6
+--R                        \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                            4   4       3 3 3       2 5 2        7      9
+--R                     (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )x
+--R                *
+--R                     ROOT
+--R                                   5       4 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                          + 
+--R                                      3
+--R                            2a b c - b
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               7 4        6 2 3       5 4 2      4 6
+--R                       (- 2592a c  + 2592a b c  - 810a b c  + 81a b c)
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |      4 4      3 2 3      2 4 2       6     8
+--R                        |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |-----------------------------------------------
+--R                        |      11 3         10 2 2        9 4        8 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                        3   4      2 3 3        5 2     7
+--R                     24a b c  - 54a b c  + 24a b c  - 3b c
+--R                *
+--R                   ROOT
+--R                                 5       4 2
+--R                            (108a c - 27a b )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                        + 
+--R                                    3
+--R                          2a b c - b
+--R                     /
+--R                            5       4 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                    2 5       2 4     4 3  2
+--R                 (4a c  - 8a b c  + 2b c )x
+--R     + 
+--R         2a x
+--R      *
+--R         ROOT
+--R                         5       4 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |      4 4      3 2 3      2 4 2       6     8
+--R                   |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |-----------------------------------------------
+--R                   |      11 3         10 2 2        9 4        8 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                  5       4 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                              8 4         7 2 3         6 4 2        5 6
+--R                        15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                      + 
+--R                            4 8
+--R                        243a b
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |      4 4      3 2 3      2 4 2       6     8
+--R                     |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |-----------------------------------------------
+--R                     |      11 3         10 2 2        9 4        8 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                + 
+--R                      4   4       3 3 3       2 5 2        7      9
+--R                  216a b c  - 558a b c  + 378a b c  - 99a b c + 9b
+--R             *
+--R                  ROOT
+--R                                  5       4 2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                            +-----------------------------------------------+
+--R                            |      4 4      3 2 3      2 4 2       6     8
+--R                            |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-----------------------------------------------
+--R                            |      11 3         10 2 2        9 4        8 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                           5       4 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                 2 5       2 4     4 3
+--R              (4a c  - 8a b c  + 2b c )x
+--R     + 
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                            5       4 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |      4 4      3 2 3      2 4 2       6     8
+--R                      |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |-----------------------------------------------
+--R                      |      11 3         10 2 2        9 4        8 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                             3
+--R                   2a b c - b
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                 8 4         7 2 3         6 4 2        5 6
+--R                         - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                       + 
+--R                               4 8
+--R                         - 243a b
+--R                    *
+--R                         +-----------------------------------------------+
+--R                         |      4 4      3 2 3      2 4 2       6     8
+--R                         |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       x |-----------------------------------------------
+--R                         |      11 3         10 2 2        9 4        8 6
+--R                        \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                            4   4       3 3 3       2 5 2        7      9
+--R                     (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )x
+--R                *
+--R                     ROOT
+--R                                     5       4 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                          + 
+--R                                      3
+--R                            2a b c - b
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             7 4        6 2 3       5 4 2      4 6
+--R                       (2592a c  - 2592a b c  + 810a b c  - 81a b c)
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |      4 4      3 2 3      2 4 2       6     8
+--R                        |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |-----------------------------------------------
+--R                        |      11 3         10 2 2        9 4        8 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                        3   4      2 3 3        5 2     7
+--R                     24a b c  - 54a b c  + 24a b c  - 3b c
+--R                *
+--R                   ROOT
+--R                                   5       4 2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                        + 
+--R                                    3
+--R                          2a b c - b
+--R                     /
+--R                            5       4 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                    2 5       2 4     4 3  2
+--R                 (4a c  - 8a b c  + 2b c )x
+--R     + 
+--R         2a x
+--R      *
+--R         ROOT
+--R                       5       4 2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |      4 4      3 2 3      2 4 2       6     8
+--R                   |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |-----------------------------------------------
+--R                   |      11 3         10 2 2        9 4        8 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                  5       4 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                              8 4         7 2 3         6 4 2        5 6
+--R                      - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                    + 
+--R                            4 8
+--R                      - 243a b
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |      4 4      3 2 3      2 4 2       6     8
+--R                     |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |-----------------------------------------------
+--R                     |      11 3         10 2 2        9 4        8 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                + 
+--R                      4   4       3 3 3       2 5 2        7      9
+--R                  216a b c  - 558a b c  + 378a b c  - 99a b c + 9b
+--R             *
+--R                  ROOT
+--R                                5       4 2
+--R                           (108a c - 27a b )
+--R                        *
+--R                            +-----------------------------------------------+
+--R                            |      4 4      3 2 3      2 4 2       6     8
+--R                            |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-----------------------------------------------
+--R                            |      11 3         10 2 2        9 4        8 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                           5       4 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                 2 5       2 4     4 3
+--R              (4a c  - 8a b c  + 2b c )x
+--R     + 
+--R       -
+--R                 +-+
+--R            2a x\|3
+--R         *
+--R            ROOT
+--R                            5       4 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |      4 4      3 2 3      2 4 2       6     8
+--R                      |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |-----------------------------------------------
+--R                      |      11 3         10 2 2        9 4        8 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                             3
+--R                   2a b c - b
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                               8 4         7 2 3         6 4 2        5 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             4 8
+--R                         243a b
+--R                    *
+--R                            +-----------------------------------------------+
+--R                            |      4 4      3 2 3      2 4 2       6     8
+--R                        +-+ |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       \|3  |-----------------------------------------------
+--R                            |      11 3         10 2 2        9 4        8 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                          4   4       3 3 3       2 5 2        7      9  +-+
+--R                     (216a b c  - 558a b c  + 378a b c  - 99a b c + 9b )\|3
+--R                *
+--R                     ROOT
+--R                                     5       4 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                          + 
+--R                                      3
+--R                            2a b c - b
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                 8 4         7 2 3         6 4 2        5 6
+--R                           15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                         + 
+--R                               4 8
+--R                           243a b
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |      4 4      3 2 3      2 4 2       6     8
+--R                          |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-----------------------------------------------
+--R                          |      11 3         10 2 2        9 4        8 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                     + 
+--R                           4   4       3 3 3       2 5 2        7      9
+--R                       216a b c  - 558a b c  + 378a b c  - 99a b c + 9b
+--R                  *
+--R                       ROOT
+--R                                       5       4 2
+--R                                (- 108a c + 27a b )
+--R                             *
+--R                               +-----------------------------------------------+
+--R                               |      4 4      3 2 3      2 4 2       6     8
+--R                               |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                               |-----------------------------------------------
+--R                               |      11 3         10 2 2        9 4        8 6
+--R                              \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                            + 
+--R                                        3
+--R                              2a b c - b
+--R                         /
+--R                                5       4 2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                        2 5        2 4     4 3
+--R                   (- 8a c  + 16a b c  - 4b c )x
+--R     + 
+--R       -
+--R                 +-+
+--R            2a x\|3
+--R         *
+--R            ROOT
+--R                          5       4 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |      4 4      3 2 3      2 4 2       6     8
+--R                      |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |-----------------------------------------------
+--R                      |      11 3         10 2 2        9 4        8 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                             3
+--R                   2a b c - b
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                               8 4         7 2 3         6 4 2        5 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             4 8
+--R                         243a b
+--R                    *
+--R                            +-----------------------------------------------+
+--R                            |      4 4      3 2 3      2 4 2       6     8
+--R                        +-+ |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       \|3  |-----------------------------------------------
+--R                            |      11 3         10 2 2        9 4        8 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                            4   4       3 3 3       2 5 2        7      9  +-+
+--R                     (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )\|3
+--R                *
+--R                     ROOT
+--R                                   5       4 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                          + 
+--R                                      3
+--R                            2a b c - b
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                 8 4         7 2 3         6 4 2        5 6
+--R                           15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                         + 
+--R                               4 8
+--R                           243a b
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |      4 4      3 2 3      2 4 2       6     8
+--R                          |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-----------------------------------------------
+--R                          |      11 3         10 2 2        9 4        8 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                     + 
+--R                             4   4       3 3 3       2 5 2        7      9
+--R                       - 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b
+--R                  *
+--R                       ROOT
+--R                                     5       4 2
+--R                                (108a c - 27a b )
+--R                             *
+--R                               +-----------------------------------------------+
+--R                               |      4 4      3 2 3      2 4 2       6     8
+--R                               |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                               |-----------------------------------------------
+--R                               |      11 3         10 2 2        9 4        8 6
+--R                              \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                            + 
+--R                                        3
+--R                              2a b c - b
+--R                         /
+--R                                5       4 2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                      2 5        2 4     4 3
+--R                   (8a c  - 16a b c  + 4b c )x
+--R     + 
+--R       - 2
+--R  /
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 731
+
+--S 732 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                       +--------------------+
+--R                         +-----------+ |   +-----------+
+--R               3+-+2 +-+ |          2 3|   |          2
+--R            3a \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          5       4 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |      4 4      3 2 3      2 4 2       6     8
+--R                      |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |-----------------------------------------------
+--R                      |      11 3         10 2 2        9 4        8 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                             3
+--R                   2a b c - b
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                               8 4         7 2 3         6 4 2        5 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             4 8
+--R                         243a b
+--R                    *
+--R                         +-----------------------------------------------+
+--R                         |      4 4      3 2 3      2 4 2       6     8
+--R                         |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       x |-----------------------------------------------
+--R                         |      11 3         10 2 2        9 4        8 6
+--R                        \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                            4   4       3 3 3       2 5 2        7      9
+--R                     (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )x
+--R                *
+--R                     ROOT
+--R                                   5       4 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                          + 
+--R                                      3
+--R                            2a b c - b
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               7 4        6 2 3       5 4 2      4 6
+--R                       (- 2592a c  + 2592a b c  - 810a b c  + 81a b c)
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |      4 4      3 2 3      2 4 2       6     8
+--R                        |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |-----------------------------------------------
+--R                        |      11 3         10 2 2        9 4        8 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                        3   4      2 3 3        5 2     7
+--R                     24a b c  - 54a b c  + 24a b c  - 3b c
+--R                *
+--R                   ROOT
+--R                                 5       4 2
+--R                            (108a c - 27a b )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                        + 
+--R                                    3
+--R                          2a b c - b
+--R                     /
+--R                            5       4 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                    2 5       2 4     4 3  2
+--R                 (4a c  - 8a b c  + 2b c )x
+--R     + 
+--R                                          +--------------------+
+--R               +-----------+              |   +-----------+
+--R           +-+ |          2      +-+ 3+-+3|   |          2
+--R         (\|3 \|- 4a c + b   - b\|3 )\|c \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                              +--------------------+
+--R                  +-----------+               |   +-----------+
+--R              +-+ |          2       +-+ 3+-+3|   |          2
+--R         (- 2\|3 \|- 4a c + b   + 2b\|3 )\|c \|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                          +------------------+
+--R               +-----------+              | +-----------+
+--R           +-+ |          2      +-+ 3+-+3| |          2
+--R         (\|3 \|- 4a c + b   + b\|3 )\|c \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                              +------------------+
+--R                  +-----------+               | +-----------+
+--R              +-+ |          2       +-+ 3+-+3| |          2
+--R         (- 2\|3 \|- 4a c + b   - 2b\|3 )\|c \|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                      +-----------+
+--R            3+-+2 +-+ |          2
+--R         6a \|2  \|3 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                         5       4 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |      4 4      3 2 3      2 4 2       6     8
+--R                   |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |-----------------------------------------------
+--R                   |      11 3         10 2 2        9 4        8 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                  5       4 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         3|   |          2      3| |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              8 4         7 2 3         6 4 2        5 6
+--R                        15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                      + 
+--R                            4 8
+--R                        243a b
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |      4 4      3 2 3      2 4 2       6     8
+--R                     |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |-----------------------------------------------
+--R                     |      11 3         10 2 2        9 4        8 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                + 
+--R                      4   4       3 3 3       2 5 2        7      9
+--R                  216a b c  - 558a b c  + 378a b c  - 99a b c + 9b
+--R             *
+--R                  ROOT
+--R                                  5       4 2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                            +-----------------------------------------------+
+--R                            |      4 4      3 2 3      2 4 2       6     8
+--R                            |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-----------------------------------------------
+--R                            |      11 3         10 2 2        9 4        8 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                           5       4 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                 2 5       2 4     4 3
+--R              (4a c  - 8a b c  + 2b c )x
+--R     + 
+--R       -
+--R                         +-----------+
+--R               3+-+2 +-+ |          2
+--R            3a \|2  \|3 \|- 4a c + b
+--R         *
+--R            ROOT
+--R                            5       4 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |      4 4      3 2 3      2 4 2       6     8
+--R                      |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |-----------------------------------------------
+--R                      |      11 3         10 2 2        9 4        8 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                             3
+--R                   2a b c - b
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R            3|   |          2      3| |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                 8 4         7 2 3         6 4 2        5 6
+--R                         - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                       + 
+--R                               4 8
+--R                         - 243a b
+--R                    *
+--R                         +-----------------------------------------------+
+--R                         |      4 4      3 2 3      2 4 2       6     8
+--R                         |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       x |-----------------------------------------------
+--R                         |      11 3         10 2 2        9 4        8 6
+--R                        \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                            4   4       3 3 3       2 5 2        7      9
+--R                     (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )x
+--R                *
+--R                     ROOT
+--R                                     5       4 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                          + 
+--R                                      3
+--R                            2a b c - b
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             7 4        6 2 3       5 4 2      4 6
+--R                       (2592a c  - 2592a b c  + 810a b c  - 81a b c)
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |      4 4      3 2 3      2 4 2       6     8
+--R                        |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                        |-----------------------------------------------
+--R                        |      11 3         10 2 2        9 4        8 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                        3   4      2 3 3        5 2     7
+--R                     24a b c  - 54a b c  + 24a b c  - 3b c
+--R                *
+--R                   ROOT
+--R                                   5       4 2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                        + 
+--R                                    3
+--R                          2a b c - b
+--R                     /
+--R                            5       4 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                    2 5       2 4     4 3  2
+--R                 (4a c  - 8a b c  + 2b c )x
+--R     + 
+--R                                    +--------------------+ +------------------+
+--R                      +-----------+ |   +-----------+      | +-----------+
+--R            3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R         6a \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       5       4 2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |      4 4      3 2 3      2 4 2       6     8
+--R                   |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   |-----------------------------------------------
+--R                   |      11 3         10 2 2        9 4        8 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                  5       4 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                              8 4         7 2 3         6 4 2        5 6
+--R                      - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                    + 
+--R                            4 8
+--R                      - 243a b
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |      4 4      3 2 3      2 4 2       6     8
+--R                     |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |-----------------------------------------------
+--R                     |      11 3         10 2 2        9 4        8 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                + 
+--R                      4   4       3 3 3       2 5 2        7      9
+--R                  216a b c  - 558a b c  + 378a b c  - 99a b c + 9b
+--R             *
+--R                  ROOT
+--R                                5       4 2
+--R                           (108a c - 27a b )
+--R                        *
+--R                            +-----------------------------------------------+
+--R                            |      4 4      3 2 3      2 4 2       6     8
+--R                            |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-----------------------------------------------
+--R                            |      11 3         10 2 2        9 4        8 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                           5       4 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                 2 5       2 4     4 3
+--R              (4a c  - 8a b c  + 2b c )x
+--R     + 
+--R       -
+--R                      +-----------+
+--R                3+-+2 |          2
+--R            18a \|2  \|- 4a c + b
+--R         *
+--R            ROOT
+--R                            5       4 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |      4 4      3 2 3      2 4 2       6     8
+--R                      |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |-----------------------------------------------
+--R                      |      11 3         10 2 2        9 4        8 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                             3
+--R                   2a b c - b
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R            3|   |          2      3| |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            atan
+--R                               8 4         7 2 3         6 4 2        5 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             4 8
+--R                         243a b
+--R                    *
+--R                            +-----------------------------------------------+
+--R                            |      4 4      3 2 3      2 4 2       6     8
+--R                        +-+ |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       \|3  |-----------------------------------------------
+--R                            |      11 3         10 2 2        9 4        8 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                          4   4       3 3 3       2 5 2        7      9  +-+
+--R                     (216a b c  - 558a b c  + 378a b c  - 99a b c + 9b )\|3
+--R                *
+--R                     ROOT
+--R                                     5       4 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                          + 
+--R                                      3
+--R                            2a b c - b
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                 8 4         7 2 3         6 4 2        5 6
+--R                           15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                         + 
+--R                               4 8
+--R                           243a b
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |      4 4      3 2 3      2 4 2       6     8
+--R                          |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-----------------------------------------------
+--R                          |      11 3         10 2 2        9 4        8 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                     + 
+--R                           4   4       3 3 3       2 5 2        7      9
+--R                       216a b c  - 558a b c  + 378a b c  - 99a b c + 9b
+--R                  *
+--R                       ROOT
+--R                                       5       4 2
+--R                                (- 108a c + 27a b )
+--R                             *
+--R                               +-----------------------------------------------+
+--R                               |      4 4      3 2 3      2 4 2       6     8
+--R                               |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                               |-----------------------------------------------
+--R                               |      11 3         10 2 2        9 4        8 6
+--R                              \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                            + 
+--R                                        3
+--R                              2a b c - b
+--R                         /
+--R                                5       4 2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                        2 5        2 4     4 3
+--R                   (- 8a c  + 16a b c  - 4b c )x
+--R     + 
+--R       -
+--R                                    +--------------------+ +------------------+
+--R                      +-----------+ |   +-----------+      | +-----------+
+--R                3+-+2 |          2 3|   |          2      3| |          2
+--R            18a \|2  \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          5       4 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |      4 4      3 2 3      2 4 2       6     8
+--R                      |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |-----------------------------------------------
+--R                      |      11 3         10 2 2        9 4        8 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                             3
+--R                   2a b c - b
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                               8 4         7 2 3         6 4 2        5 6
+--R                         15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                       + 
+--R                             4 8
+--R                         243a b
+--R                    *
+--R                            +-----------------------------------------------+
+--R                            |      4 4      3 2 3      2 4 2       6     8
+--R                        +-+ |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       \|3  |-----------------------------------------------
+--R                            |      11 3         10 2 2        9 4        8 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                            4   4       3 3 3       2 5 2        7      9  +-+
+--R                     (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )\|3
+--R                *
+--R                     ROOT
+--R                                   5       4 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                             +-----------------------------------------------+
+--R                             |      4 4      3 2 3      2 4 2       6     8
+--R                             |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                             |-----------------------------------------------
+--R                             |      11 3         10 2 2        9 4        8 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                          + 
+--R                                      3
+--R                            2a b c - b
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                 8 4         7 2 3         6 4 2        5 6
+--R                           15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                         + 
+--R                               4 8
+--R                           243a b
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |      4 4      3 2 3      2 4 2       6     8
+--R                          |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-----------------------------------------------
+--R                          |      11 3         10 2 2        9 4        8 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                     + 
+--R                             4   4       3 3 3       2 5 2        7      9
+--R                       - 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b
+--R                  *
+--R                       ROOT
+--R                                     5       4 2
+--R                                (108a c - 27a b )
+--R                             *
+--R                               +-----------------------------------------------+
+--R                               |      4 4      3 2 3      2 4 2       6     8
+--R                               |  - 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                               |-----------------------------------------------
+--R                               |      11 3         10 2 2        9 4        8 6
+--R                              \|46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                            + 
+--R                                        3
+--R                              2a b c - b
+--R                         /
+--R                                5       4 2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                      2 5        2 4     4 3
+--R                   (8a c  - 16a b c  + 4b c )x
+--R     + 
+--R                                      +--------------------+
+--R              +-----------+           |   +-----------+
+--R              |          2       3+-+3|   |          2
+--R         (- 6\|- 4a c + b   + 6b)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                      +------------------+
+--R              +-----------+           | +-----------+
+--R              |          2       3+-+3| |          2
+--R         (- 6\|- 4a c + b   - 6b)\|c \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R        3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R     6a \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 733
+
+)clear all
+
+--S 734 of 2282
+t0:=1/(x^3*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           9      6      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 734
+
+--S 735 of 2282
+r0:=(-1/2)/(a*x^2)-1/3*c^(2/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-_
+   4*a*c))^(1/3))*(1+b/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b-sqrt(b^2-_
+   4*a*c))^(2/3))+1/6*c^(2/3)*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*_
+   c^(1/3)*x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*_
+   (1+b/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b-sqrt(b^2-4*a*c))^(2/3))+_
+   c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(1+b/sqrt(b^2-_
+   4*a*c))/(2^(1/3)*a*sqrt(3)*(b-sqrt(b^2-4*a*c))^(2/3))-_
+   1/3*c^(2/3)*log(2^(1/3)*c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*_
+   (1-b/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b+sqrt(b^2-4*a*c))^(2/3))+_
+   1/6*c^(2/3)*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*_
+   (b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*_
+   (1-b/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b+sqrt(b^2-4*a*c))^(2/3))+_
+   c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(1-b/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*a*sqrt(3)*(b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                                                 +--------------------+2
+--R                 +-----------+                   |   +-----------+
+--R           2 +-+ |          2       2 +-+ 3+-+2 3|   |          2
+--R         (x \|3 \|- 4a c + b   - b x \|3 )\|c   \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                     +--------------------+2
+--R                    +-----------+                    |   +-----------+
+--R              2 +-+ |          2        2 +-+ 3+-+2 3|   |          2
+--R         (- 2x \|3 \|- 4a c + b   + 2b x \|3 )\|c   \|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                 +------------------+2
+--R                 +-----------+                   | +-----------+
+--R           2 +-+ |          2       2 +-+ 3+-+2 3| |          2
+--R         (x \|3 \|- 4a c + b   + b x \|3 )\|c   \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                     +------------------+2
+--R                    +-----------+                    | +-----------+
+--R              2 +-+ |          2        2 +-+ 3+-+2 3| |          2
+--R         (- 2x \|3 \|- 4a c + b   - 2b x \|3 )\|c   \|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                           +--------------------+2
+--R              +-----------+                |   +-----------+
+--R            2 |          2        2 3+-+2 3|   |          2
+--R         (6x \|- 4a c + b   - 6b x )\|c   \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                           +------------------+2
+--R              +-----------+                | +-----------+
+--R            2 |          2        2 3+-+2 3| |          2
+--R         (6x \|- 4a c + b   + 6b x )\|c   \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                 +--------------------+2  +------------------+2
+--R                   +-----------+ |   +-----------+        | +-----------+
+--R          3+-+ +-+ |          2 3|   |          2        3| |          2
+--R       - 3\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+2  +------------------+2
+--R                    +-----------+ |   +-----------+        | +-----------+
+--R         2 3+-+ +-+ |          2 3|   |          2        3| |          2
+--R     6a x  \|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 735
+
+--S 736 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R               2
+--R            a x
+--R         *
+--R            ROOT
+--R                          6       5 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +-------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |-------------------------------------------------
+--R                      |      13 3         12 2 2        11 4        10 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                 + 
+--R                    2 2       2     4
+--R                   a c  - 3a b c + b
+--R              /
+--R                     6       5 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                               9   4         8 3 3         7 5 2        6 7
+--R                         31104a b c  - 38880a b c  + 17496a b c  - 3402a b c
+--R                       + 
+--R                             5 9
+--R                         243a b
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                           5   5        4 3 4        3 5 3       2 7 2
+--R                     - 360a b c  + 1170a b c  - 1242a b c  + 567a b c
+--R                   + 
+--R                             9      11
+--R                     - 117a b c + 9b
+--R                *
+--R                     ROOT
+--R                                   6       5 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                             +-------------------------------------------------+
+--R                             |      4 2 4      3 4 3      2 6 2        8     10
+--R                             | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                             |-------------------------------------------------
+--R                             |      13 3         12 2 2        11 4        10 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                          + 
+--R                             2 2       2     4
+--R                            a c  - 3a b c + b
+--R                       /
+--R                              6       5 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             8 5        7 2 4       6 4 3      5 6 2
+--R                       (2592a c  - 2592a b c  + 810a b c  - 81a b c )x
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                         3 2 5      2 4 4        6 3     8 2
+--R                     (60a b c  - 75a b c  + 27a b c  - 3b c )x
+--R                *
+--R                   ROOT
+--R                                 6       5 2
+--R                            (108a c - 27a b )
+--R                         *
+--R                           +-------------------------------------------------+
+--R                           |      4 2 4      3 4 3      2 6 2        8     10
+--R                           | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                        + 
+--R                           2 2       2     4
+--R                          a c  - 3a b c + b
+--R                     /
+--R                            6       5 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                     2   6        3 5     5 4  2
+--R                 (10a b c  - 10a b c  + 2b c )x
+--R     + 
+--R             2
+--R         2a x
+--R      *
+--R         ROOT
+--R                         6       5 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |-------------------------------------------------
+--R                   |      13 3         12 2 2        11 4        10 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                 2 2       2     4
+--R                a c  - 3a b c + b
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                          8 3        7 2 2       6 4       5 6
+--R                    (2592a c  - 2592a b c  + 810a b c - 81a b )
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                       3 2 3      2 4 2        6      8
+--R                  - 60a b c  + 75a b c  - 27a b c + 3b
+--R             *
+--R                ROOT
+--R                                6       5 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                        2 2       2     4
+--R                       a c  - 3a b c + b
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                  2   4        3 3     5 2
+--R              (10a b c  - 10a b c  + 2b c )x
+--R     + 
+--R       -
+--R               2
+--R            a x
+--R         *
+--R            ROOT
+--R                            6       5 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +-------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |-------------------------------------------------
+--R                      |      13 3         12 2 2        11 4        10 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                 + 
+--R                    2 2       2     4
+--R                   a c  - 3a b c + b
+--R              /
+--R                     6       5 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                 9   4         8 3 3         7 5 2        6 7
+--R                         - 31104a b c  + 38880a b c  - 17496a b c  + 3402a b c
+--R                       + 
+--R                               5 9
+--R                         - 243a b
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                           5   5        4 3 4        3 5 3       2 7 2
+--R                     - 360a b c  + 1170a b c  - 1242a b c  + 567a b c
+--R                   + 
+--R                             9      11
+--R                     - 117a b c + 9b
+--R                *
+--R                     ROOT
+--R                                     6       5 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                             +-------------------------------------------------+
+--R                             |      4 2 4      3 4 3      2 6 2        8     10
+--R                             | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                             |-------------------------------------------------
+--R                             |      13 3         12 2 2        11 4        10 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                          + 
+--R                             2 2       2     4
+--R                            a c  - 3a b c + b
+--R                       /
+--R                              6       5 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               8 5        7 2 4       6 4 3      5 6 2
+--R                       (- 2592a c  + 2592a b c  - 810a b c  + 81a b c )x
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                         3 2 5      2 4 4        6 3     8 2
+--R                     (60a b c  - 75a b c  + 27a b c  - 3b c )x
+--R                *
+--R                   ROOT
+--R                                   6       5 2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                           +-------------------------------------------------+
+--R                           |      4 2 4      3 4 3      2 6 2        8     10
+--R                           | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                        + 
+--R                           2 2       2     4
+--R                          a c  - 3a b c + b
+--R                     /
+--R                            6       5 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                     2   6        3 5     5 4  2
+--R                 (10a b c  - 10a b c  + 2b c )x
+--R     + 
+--R             2
+--R         2a x
+--R      *
+--R         ROOT
+--R                       6       5 2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |-------------------------------------------------
+--R                   |      13 3         12 2 2        11 4        10 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                 2 2       2     4
+--R                a c  - 3a b c + b
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                            8 3        7 2 2       6 4       5 6
+--R                    (- 2592a c  + 2592a b c  - 810a b c + 81a b )
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                       3 2 3      2 4 2        6      8
+--R                  - 60a b c  + 75a b c  - 27a b c + 3b
+--R             *
+--R                ROOT
+--R                              6       5 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                        2 2       2     4
+--R                       a c  - 3a b c + b
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                  2   4        3 3     5 2
+--R              (10a b c  - 10a b c  + 2b c )x
+--R     + 
+--R             2 +-+
+--R         2a x \|3
+--R      *
+--R         ROOT
+--R                         6       5 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |-------------------------------------------------
+--R                   |      13 3         12 2 2        11 4        10 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                 2 2       2     4
+--R                a c  - 3a b c + b
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                          8 3        7 2 2       6 4       5 6  +-+
+--R                    (2592a c  - 2592a b c  + 810a b c - 81a b )\|3
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                        3 2 3      2 4 2        6      8  +-+
+--R                  (- 60a b c  + 75a b c  - 27a b c + 3b )\|3
+--R             *
+--R                ROOT
+--R                                6       5 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                        2 2       2     4
+--R                       a c  - 3a b c + b
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                            8 3        7 2 2       6 4       5 6
+--R                      (2592a c  - 2592a b c  + 810a b c - 81a b )
+--R                   *
+--R                       +-------------------------------------------------+
+--R                       |      4 2 4      3 4 3      2 6 2        8     10
+--R                       | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                       |-------------------------------------------------
+--R                       |      13 3         12 2 2        11 4        10 6
+--R                      \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                  + 
+--R                         3 2 3      2 4 2        6      8
+--R                    - 60a b c  + 75a b c  - 27a b c + 3b
+--R               *
+--R                  ROOT
+--R                                  6       5 2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                            +-------------------------------------------------+
+--R                            |      4 2 4      3 4 3      2 6 2        8     10
+--R                            | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                            |-------------------------------------------------
+--R                            |      13 3         12 2 2        11 4        10 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                       + 
+--R                          2 2       2     4
+--R                         a c  - 3a b c + b
+--R                    /
+--R                           6       5 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                      2   4        3 3     5 2
+--R                (- 20a b c  + 20a b c  - 4b c )x
+--R     + 
+--R             2 +-+
+--R         2a x \|3
+--R      *
+--R         ROOT
+--R                       6       5 2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |-------------------------------------------------
+--R                   |      13 3         12 2 2        11 4        10 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                 2 2       2     4
+--R                a c  - 3a b c + b
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                          8 3        7 2 2       6 4       5 6  +-+
+--R                    (2592a c  - 2592a b c  + 810a b c - 81a b )\|3
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                      3 2 3      2 4 2        6      8  +-+
+--R                  (60a b c  - 75a b c  + 27a b c - 3b )\|3
+--R             *
+--R                ROOT
+--R                              6       5 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                        2 2       2     4
+--R                       a c  - 3a b c + b
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                            8 3        7 2 2       6 4       5 6
+--R                      (2592a c  - 2592a b c  + 810a b c - 81a b )
+--R                   *
+--R                       +-------------------------------------------------+
+--R                       |      4 2 4      3 4 3      2 6 2        8     10
+--R                       | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                       |-------------------------------------------------
+--R                       |      13 3         12 2 2        11 4        10 6
+--R                      \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                  + 
+--R                       3 2 3      2 4 2        6      8
+--R                    60a b c  - 75a b c  + 27a b c - 3b
+--R               *
+--R                  ROOT
+--R                                6       5 2
+--R                           (108a c - 27a b )
+--R                        *
+--R                            +-------------------------------------------------+
+--R                            |      4 2 4      3 4 3      2 6 2        8     10
+--R                            | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                            |-------------------------------------------------
+--R                            |      13 3         12 2 2        11 4        10 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                       + 
+--R                          2 2       2     4
+--R                         a c  - 3a b c + b
+--R                    /
+--R                           6       5 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                    2   4        3 3     5 2
+--R                (20a b c  - 20a b c  + 4b c )x
+--R     + 
+--R       - 1
+--R  /
+--R         2
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 736
+
+--S 737 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +--------------------+2
+--R                 +-----------+                |   +-----------+
+--R             +-+ |          2      +-+ 3+-+2 3|   |          2
+--R         (- \|3 \|- 4a c + b   + b\|3 )\|c   \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                              +--------------------+2
+--R                +-----------+                 |   +-----------+
+--R            +-+ |          2       +-+ 3+-+2 3|   |          2
+--R         (2\|3 \|- 4a c + b   - 2b\|3 )\|c   \|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                                     +--------------------+2
+--R                       +-----------+ |   +-----------+
+--R              3+-+ +-+ |          2 3|   |          2
+--R            3a\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          6       5 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                      +-------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |-------------------------------------------------
+--R                      |      13 3         12 2 2        11 4        10 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                 + 
+--R                    2 2       2     4
+--R                   a c  - 3a b c + b
+--R              /
+--R                     6       5 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +------------------+2
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                               9   4         8 3 3         7 5 2        6 7
+--R                         31104a b c  - 38880a b c  + 17496a b c  - 3402a b c
+--R                       + 
+--R                             5 9
+--R                         243a b
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                           5   5        4 3 4        3 5 3       2 7 2
+--R                     - 360a b c  + 1170a b c  - 1242a b c  + 567a b c
+--R                   + 
+--R                             9      11
+--R                     - 117a b c + 9b
+--R                *
+--R                     ROOT
+--R                                   6       5 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                             +-------------------------------------------------+
+--R                             |      4 2 4      3 4 3      2 6 2        8     10
+--R                             | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                             |-------------------------------------------------
+--R                             |      13 3         12 2 2        11 4        10 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                          + 
+--R                             2 2       2     4
+--R                            a c  - 3a b c + b
+--R                       /
+--R                              6       5 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                             8 5        7 2 4       6 4 3      5 6 2
+--R                       (2592a c  - 2592a b c  + 810a b c  - 81a b c )x
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                         3 2 5      2 4 4        6 3     8 2
+--R                     (60a b c  - 75a b c  + 27a b c  - 3b c )x
+--R                *
+--R                   ROOT
+--R                                 6       5 2
+--R                            (108a c - 27a b )
+--R                         *
+--R                           +-------------------------------------------------+
+--R                           |      4 2 4      3 4 3      2 6 2        8     10
+--R                           | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                        + 
+--R                           2 2       2     4
+--R                          a c  - 3a b c + b
+--R                     /
+--R                            6       5 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                     2   6        3 5     5 4  2
+--R                 (10a b c  - 10a b c  + 2b c )x
+--R     + 
+--R                                  +--------------------+2
+--R                    +-----------+ |   +-----------+
+--R           3+-+ +-+ |          2 3|   |          2
+--R         6a\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         6       5 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |-------------------------------------------------
+--R                   |      13 3         12 2 2        11 4        10 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                 2 2       2     4
+--R                a c  - 3a b c + b
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          8 3        7 2 2       6 4       5 6
+--R                    (2592a c  - 2592a b c  + 810a b c - 81a b )
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                       3 2 3      2 4 2        6      8
+--R                  - 60a b c  + 75a b c  - 27a b c + 3b
+--R             *
+--R                ROOT
+--R                                6       5 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                        2 2       2     4
+--R                       a c  - 3a b c + b
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                  2   4        3 3     5 2
+--R              (10a b c  - 10a b c  + 2b c )x
+--R     + 
+--R                                              +------------------+2
+--R                 +-----------+                | +-----------+
+--R             +-+ |          2      +-+ 3+-+2 3| |          2
+--R         (- \|3 \|- 4a c + b   - b\|3 )\|c   \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                              +------------------+2
+--R                +-----------+                 | +-----------+
+--R            +-+ |          2       +-+ 3+-+2 3| |          2
+--R         (2\|3 \|- 4a c + b   + 2b\|3 )\|c   \|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                                     +--------------------+2
+--R                       +-----------+ |   +-----------+
+--R              3+-+ +-+ |          2 3|   |          2
+--R            3a\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            6       5 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                      +-------------------------------------------------+
+--R                      |      4 2 4      3 4 3      2 6 2        8     10
+--R                      | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                      |-------------------------------------------------
+--R                      |      13 3         12 2 2        11 4        10 6
+--R                     \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                 + 
+--R                    2 2       2     4
+--R                   a c  - 3a b c + b
+--R              /
+--R                     6       5 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +------------------+2
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                 9   4         8 3 3         7 5 2        6 7
+--R                         - 31104a b c  + 38880a b c  - 17496a b c  + 3402a b c
+--R                       + 
+--R                               5 9
+--R                         - 243a b
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                           5   5        4 3 4        3 5 3       2 7 2
+--R                     - 360a b c  + 1170a b c  - 1242a b c  + 567a b c
+--R                   + 
+--R                             9      11
+--R                     - 117a b c + 9b
+--R                *
+--R                     ROOT
+--R                                     6       5 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                             +-------------------------------------------------+
+--R                             |      4 2 4      3 4 3      2 6 2        8     10
+--R                             | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                             |-------------------------------------------------
+--R                             |      13 3         12 2 2        11 4        10 6
+--R                            \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                          + 
+--R                             2 2       2     4
+--R                            a c  - 3a b c + b
+--R                       /
+--R                              6       5 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               8 5        7 2 4       6 4 3      5 6 2
+--R                       (- 2592a c  + 2592a b c  - 810a b c  + 81a b c )x
+--R                    *
+--R                        +-------------------------------------------------+
+--R                        |      4 2 4      3 4 3      2 6 2        8     10
+--R                        | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                        |-------------------------------------------------
+--R                        |      13 3         12 2 2        11 4        10 6
+--R                       \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                         3 2 5      2 4 4        6 3     8 2
+--R                     (60a b c  - 75a b c  + 27a b c  - 3b c )x
+--R                *
+--R                   ROOT
+--R                                   6       5 2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                           +-------------------------------------------------+
+--R                           |      4 2 4      3 4 3      2 6 2        8     10
+--R                           | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                           |-------------------------------------------------
+--R                           |      13 3         12 2 2        11 4        10 6
+--R                          \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                        + 
+--R                           2 2       2     4
+--R                          a c  - 3a b c + b
+--R                     /
+--R                            6       5 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                     2   6        3 5     5 4  2
+--R                 (10a b c  - 10a b c  + 2b c )x
+--R     + 
+--R                                  +--------------------+2
+--R                    +-----------+ |   +-----------+
+--R           3+-+ +-+ |          2 3|   |          2
+--R         6a\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       6       5 2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |-------------------------------------------------
+--R                   |      13 3         12 2 2        11 4        10 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                 2 2       2     4
+--R                a c  - 3a b c + b
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            8 3        7 2 2       6 4       5 6
+--R                    (- 2592a c  + 2592a b c  - 810a b c + 81a b )
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                       3 2 3      2 4 2        6      8
+--R                  - 60a b c  + 75a b c  - 27a b c + 3b
+--R             *
+--R                ROOT
+--R                              6       5 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                        2 2       2     4
+--R                       a c  - 3a b c + b
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                  2   4        3 3     5 2
+--R              (10a b c  - 10a b c  + 2b c )x
+--R     + 
+--R                               +--------------------+2
+--R                 +-----------+ |   +-----------+
+--R            3+-+ |          2 3|   |          2
+--R         18a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         6       5 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |-------------------------------------------------
+--R                   |      13 3         12 2 2        11 4        10 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                 2 2       2     4
+--R                a c  - 3a b c + b
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                          8 3        7 2 2       6 4       5 6  +-+
+--R                    (2592a c  - 2592a b c  + 810a b c - 81a b )\|3
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                        3 2 3      2 4 2        6      8  +-+
+--R                  (- 60a b c  + 75a b c  - 27a b c + 3b )\|3
+--R             *
+--R                ROOT
+--R                                6       5 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                        2 2       2     4
+--R                       a c  - 3a b c + b
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                            8 3        7 2 2       6 4       5 6
+--R                      (2592a c  - 2592a b c  + 810a b c - 81a b )
+--R                   *
+--R                       +-------------------------------------------------+
+--R                       |      4 2 4      3 4 3      2 6 2        8     10
+--R                       | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                       |-------------------------------------------------
+--R                       |      13 3         12 2 2        11 4        10 6
+--R                      \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                  + 
+--R                         3 2 3      2 4 2        6      8
+--R                    - 60a b c  + 75a b c  - 27a b c + 3b
+--R               *
+--R                  ROOT
+--R                                  6       5 2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                            +-------------------------------------------------+
+--R                            |      4 2 4      3 4 3      2 6 2        8     10
+--R                            | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                            |-------------------------------------------------
+--R                            |      13 3         12 2 2        11 4        10 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                       + 
+--R                          2 2       2     4
+--R                         a c  - 3a b c + b
+--R                    /
+--R                           6       5 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                      2   4        3 3     5 2
+--R                (- 20a b c  + 20a b c  - 4b c )x
+--R     + 
+--R                               +--------------------+2
+--R                 +-----------+ |   +-----------+
+--R            3+-+ |          2 3|   |          2
+--R         18a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       6       5 2
+--R                  (108a c - 27a b )
+--R               *
+--R                   +-------------------------------------------------+
+--R                   |      4 2 4      3 4 3      2 6 2        8     10
+--R                   | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                   |-------------------------------------------------
+--R                   |      13 3         12 2 2        11 4        10 6
+--R                  \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                 2 2       2     4
+--R                a c  - 3a b c + b
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                          8 3        7 2 2       6 4       5 6  +-+
+--R                    (2592a c  - 2592a b c  + 810a b c - 81a b )\|3
+--R                 *
+--R                     +-------------------------------------------------+
+--R                     |      4 2 4      3 4 3      2 6 2        8     10
+--R                     | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                     |-------------------------------------------------
+--R                     |      13 3         12 2 2        11 4        10 6
+--R                    \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                      3 2 3      2 4 2        6      8  +-+
+--R                  (60a b c  - 75a b c  + 27a b c - 3b )\|3
+--R             *
+--R                ROOT
+--R                              6       5 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                          +-------------------------------------------------+
+--R                          |      4 2 4      3 4 3      2 6 2        8     10
+--R                          | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                          |-------------------------------------------------
+--R                          |      13 3         12 2 2        11 4        10 6
+--R                         \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                        2 2       2     4
+--R                       a c  - 3a b c + b
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                            8 3        7 2 2       6 4       5 6
+--R                      (2592a c  - 2592a b c  + 810a b c - 81a b )
+--R                   *
+--R                       +-------------------------------------------------+
+--R                       |      4 2 4      3 4 3      2 6 2        8     10
+--R                       | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                       |-------------------------------------------------
+--R                       |      13 3         12 2 2        11 4        10 6
+--R                      \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                  + 
+--R                       3 2 3      2 4 2        6      8
+--R                    60a b c  - 75a b c  + 27a b c - 3b
+--R               *
+--R                  ROOT
+--R                                6       5 2
+--R                           (108a c - 27a b )
+--R                        *
+--R                            +-------------------------------------------------+
+--R                            |      4 2 4      3 4 3      2 6 2        8     10
+--R                            | - 25a b c  + 50a b c  - 35a b c  + 10a b c - b
+--R                            |-------------------------------------------------
+--R                            |      13 3         12 2 2        11 4        10 6
+--R                           \|46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                       + 
+--R                          2 2       2     4
+--R                         a c  - 3a b c + b
+--R                    /
+--R                           6       5 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                    2   4        3 3     5 2
+--R                (20a b c  - 20a b c  + 4b c )x
+--R     + 
+--R                                        +--------------------+2
+--R              +-----------+             |   +-----------+
+--R              |          2       3+-+2 3|   |          2
+--R         (- 6\|- 4a c + b   + 6b)\|c   \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                        +------------------+2
+--R              +-----------+             | +-----------+
+--R              |          2       3+-+2 3| |          2
+--R         (- 6\|- 4a c + b   - 6b)\|c   \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                              +--------------------+2  +------------------+2
+--R                +-----------+ |   +-----------+        | +-----------+
+--R       3+-+ +-+ |          2 3|   |          2        3| |          2
+--R     6a\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 738
+
+)clear all
+
+--S 739 of 2282
+t0:=1/(x^4*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R           10      7      4
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 739
+
+--S 740 of 2282
+r0:=(-1/3)/(a*x^3)-b*log(x)/a^2+1/6*b*log(a+b*x^3+c*x^6)/a^2-_
+   1/3*(b^2-2*a*c)*atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                  3
+--R                 2  3         2c x  + b
+--R       (4a c - 2b )x atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R           3       6      3            3             |          2
+--R       (b x log(c x  + b x  + a) - 6b x log(x) - 2a)\|- 4a c + b
+--R  /
+--R           +-----------+
+--R       2 3 |          2
+--R     6a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2  3
+--R           (2a c - b )x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 6         3           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   3             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   6      3
+--R                c x  + b x  + a
+--R       + 
+--R                                                       +-----------+
+--R             3       6      3            3             |          2
+--R         (b x log(c x  + b x  + a) - 6b x log(x) - 2a)\|- 4a c + b
+--R    /
+--R             +-----------+
+--R         2 3 |          2
+--R       6a x \|- 4a c + b
+--R     ,
+--R
+--R                                          +---------+
+--R                                   3      |        2
+--R                     2  3     (2c x  + b)\|4a c - b
+--R         (- 4a c + 2b )x atan(-----------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R                                                       +---------+
+--R             3       6      3            3             |        2
+--R         (b x log(c x  + b x  + a) - 6b x log(x) - 2a)\|4a c - b
+--R    /
+--R             +---------+
+--R         2 3 |        2
+--R       6a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 741
+
+--S 742 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 6         3           2  |          2           2     2   3
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 6      3
+--R              c x  + b x  + a
+--R     + 
+--R                                  3
+--R                   2          2c x  + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     6a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 743
+
+--S 744 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+             3
+--R                  2  |        2          2c x  + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                     +-----------+          3      |        2
+--R                  2  |          2      (2c x  + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     3a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 745
+
+)clear all
+
+--S 746 of 2282
+t0:=x^m/(3+4*x^3+x^6)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 2282
+--r0:=1/2*x^(1+m)*hypergeometric(1,1/3*(1+m),1/3*(4+m),-x^3)/(1+m)-_
+--   1/6*x^(1+m)*hypergeometric(1,1/3*(1+m),1/3*(4+m),-1/3*x^3)/(1+m)
+--E 747
+
+--S 748 of 2282
+--a0:=integrate(t0,x)
+--E 748
+
+--S 749 of 2282
+--m0:=a0-r0
+--E 749
+
+--S 750 of 2282
+--d0:=normalize(D(m0,x))
+--E 750
+
+)clear all
+
+--S 751 of 2282
+t0:=x^11/(3+4*x^3+x^6)
+--R 
+--R
+--R              11
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 751
+
+--S 752 of 2282
+r0:=-4/3*x^3+1/6*x^6-1/6*log(1+x^3)+9/2*log(3+x^3)
+--R 
+--R
+--R               3             3         6     3
+--R        27log(x  + 3) - log(x  + 1) + x  - 8x
+--R   (2)  --------------------------------------
+--R                           6
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3             3         6     3
+--R        27log(x  + 3) - log(x  + 1) + x  - 8x
+--R   (3)  --------------------------------------
+--R                           6
+--R                                         Type: Union(Expression(Integer),...)
+--E 753
+
+--S 754 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 755
+
+)clear all
+
+--S 756 of 2282
+t0:=x^10/(3+4*x^3+x^6)
+--R 
+--R
+--R              10
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 756
+
+--S 757 of 2282
+r0:=-2*x^2+1/5*x^5-9/2*3^(1/6)*atan((3^(1/3)-2*x)/3^(5/6))+1/6*log(1+x)-_
+   3/2*3^(2/3)*log(3^(1/3)+x)-1/12*log(1-x+x^2)+3/4*3^(2/3)*_
+   log(3^(2/3)-3^(1/3)*x+x^2)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          +-+3+-+2    3+-+2    3+-+    2       +-+3+-+2    3+-+
+--R       45\|3 \|3  log(\|3   - x\|3  + x ) - 90\|3 \|3  log(\|3  + x)
+--R     + 
+--R           +-+     2               +-+
+--R       - 5\|3 log(x  - x + 1) + 10\|3 log(x + 1)
+--R     + 
+--R                          3+-+      6+-+                    +-+
+--R             +-+6+-+     (\|3  - 2x)\|3            (2x - 1)\|3
+--R       - 270\|3 \|3 atan(---------------) - 30atan(------------)
+--R                                3                        3
+--R     + 
+--R           5       2  +-+
+--R       (12x  - 120x )\|3
+--R  /
+--R        +-+
+--R     60\|3
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3+---+ +-+    3+---+2           +-+     2               +-+
+--R       90\|- 9 \|3 log(\|- 9   + 3x) - 5\|3 log(x  - x + 1) + 10\|3 log(x + 1)
+--R     + 
+--R                                                                        +-+
+--R           3+---+ +-+        3+---+2    3+---+     2           (2x - 1)\|3
+--R       - 45\|- 9 \|3 log(- x \|- 9   - 3\|- 9  + 3x ) - 30atan(------------)
+--R                                                                     3
+--R     + 
+--R                        3+---+2 +-+
+--R            3+---+      \|- 9  \|3         5       2  +-+
+--R       - 270\|- 9 atan(------------) + (12x  - 120x )\|3
+--R                       3+---+2
+--R                       \|- 9   - 6x
+--R  /
+--R        +-+
+--R     60\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 758
+
+--S 759 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           +-+3+-+2    3+-+2    3+-+    2      +-+3+-+2    3+-+
+--R       - 3\|3 \|3  log(\|3   - x\|3  + x ) + 6\|3 \|3  log(\|3  + x)
+--R     + 
+--R        3+---+ +-+    3+---+2
+--R       6\|- 9 \|3 log(\|- 9   + 3x)
+--R     + 
+--R          3+---+ +-+        3+---+2    3+---+     2
+--R       - 3\|- 9 \|3 log(- x \|- 9   - 3\|- 9  + 3x )
+--R     + 
+--R                       3+-+      6+-+                  3+---+2 +-+
+--R          +-+6+-+     (\|3  - 2x)\|3       3+---+      \|- 9  \|3
+--R       18\|3 \|3 atan(---------------) - 18\|- 9 atan(------------)
+--R                             3                        3+---+2
+--R                                                      \|- 9   - 6x
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 760
+
+)clear all
+
+--S 761 of 2282
+t0:=x^9/(3+4*x^3+x^6)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 761
+
+--S 762 of 2282
+r0:=-4*x+1/4*x^4-3/2*3^(5/6)*atan((3^(1/3)-2*x)/3^(5/6))-1/6*log(1+x)+_
+   3/2*3^(1/3)*log(3^(1/3)+x)+1/12*log(1-x+x^2)-3/4*3^(1/3)*log(3^(2/3)-_
+   3^(1/3)*x+x^2)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           +-+3+-+    3+-+2    3+-+    2       +-+3+-+    3+-+
+--R       - 9\|3 \|3 log(\|3   - x\|3  + x ) + 18\|3 \|3 log(\|3  + x)
+--R     + 
+--R                                                                3+-+      6+-+
+--R        +-+     2              +-+                +-+6+-+5     (\|3  - 2x)\|3
+--R       \|3 log(x  - x + 1) - 2\|3 log(x + 1) - 18\|3 \|3  atan(---------------)
+--R                                                                      3
+--R     + 
+--R                        +-+
+--R               (2x - 1)\|3        4        +-+
+--R       - 6atan(------------) + (3x  - 48x)\|3
+--R                     3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-+3+-+    3+-+2    3+-+    2       +-+3+-+    3+-+
+--R       - 9\|3 \|3 log(\|3   - x\|3  + x ) + 18\|3 \|3 log(\|3  + x)
+--R     + 
+--R                                                              +-+
+--R        +-+     2              +-+                   (2x - 1)\|3
+--R       \|3 log(x  - x + 1) - 2\|3 log(x + 1) - 6atan(------------)
+--R                                                           3
+--R     + 
+--R                    +-+3+-+
+--R         3+-+      \|3 \|3        4        +-+
+--R       54\|3 atan(---------) + (3x  - 48x)\|3
+--R                  3+-+
+--R                  \|3  - 2x
+--R  /
+--R        +-+
+--R     12\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 763
+
+--S 764 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                        3+-+      6+-+                +-+3+-+
+--R          +-+6+-+5     (\|3  - 2x)\|3      3+-+      \|3 \|3
+--R        3\|3 \|3  atan(---------------) + 9\|3 atan(---------)
+--R                              3                     3+-+
+--R                                                    \|3  - 2x
+--R   (4)  ------------------------------------------------------
+--R                                   +-+
+--R                                 2\|3
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 765
+
+)clear all
+
+--S 766 of 2282
+t0:=x^8/(3+4*x^3+x^6)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 766
+
+--S 767 of 2282
+r0:=1/3*x^3+1/6*log(1+x^3)-3/2*log(3+x^3)
+--R 
+--R
+--R                3             3          3
+--R        - 9log(x  + 3) + log(x  + 1) + 2x
+--R   (2)  ----------------------------------
+--R                         6
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3             3          3
+--R        - 9log(x  + 3) + log(x  + 1) + 2x
+--R   (3)  ----------------------------------
+--R                         6
+--R                                         Type: Union(Expression(Integer),...)
+--E 768
+
+--S 769 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 770
+
+)clear all
+
+--S 771 of 2282
+t0:=x^7/(3+4*x^3+x^6)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 771
+
+--S 772 of 2282
+r0:=1/2*x^2+3/2*3^(1/6)*atan((3^(1/3)-2*x)/3^(5/6))-1/6*log(1+x)+_
+   1/2*3^(2/3)*log(3^(1/3)+x)+1/12*log(1-x+x^2)-1/4*3^(2/3)*log(3^(2/3)-_
+   3^(1/3)*x+x^2)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           +-+3+-+2    3+-+2    3+-+    2      +-+3+-+2    3+-+
+--R       - 3\|3 \|3  log(\|3   - x\|3  + x ) + 6\|3 \|3  log(\|3  + x)
+--R     + 
+--R                                                               3+-+      6+-+
+--R        +-+     2              +-+                +-+6+-+     (\|3  - 2x)\|3
+--R       \|3 log(x  - x + 1) - 2\|3 log(x + 1) + 18\|3 \|3 atan(---------------)
+--R                                                                     3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3       2 +-+
+--R       6atan(------------) + 6x \|3
+--R                   3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         +-+3+-+    3+-+2          +-+     2              +-+
+--R       6\|3 \|9 log(\|9   + 3x) + \|3 log(x  - x + 1) - 2\|3 log(x + 1)
+--R     + 
+--R                                                                +-+
+--R           +-+3+-+        3+-+2    3+-+     2          (2x - 1)\|3
+--R       - 3\|3 \|9 log(- x \|9   + 3\|9  + 3x ) + 6atan(------------)
+--R                                                             3
+--R     + 
+--R                      +-+3+-+2
+--R           3+-+      \|3 \|9        2 +-+
+--R       - 18\|9 atan(----------) + 6x \|3
+--R                    3+-+2
+--R                    \|9   - 6x
+--R  /
+--R        +-+
+--R     12\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 773
+
+--S 774 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         +-+3+-+    3+-+2          +-+3+-+2    3+-+2    3+-+    2
+--R       2\|3 \|9 log(\|9   + 3x) + \|3 \|3  log(\|3   - x\|3  + x )
+--R     + 
+--R           +-+3+-+2    3+-+         +-+3+-+        3+-+2    3+-+     2
+--R       - 2\|3 \|3  log(\|3  + x) - \|3 \|9 log(- x \|9   + 3\|9  + 3x )
+--R     + 
+--R                        3+-+      6+-+                +-+3+-+2
+--R           +-+6+-+     (\|3  - 2x)\|3      3+-+      \|3 \|9
+--R       - 6\|3 \|3 atan(---------------) - 6\|9 atan(----------)
+--R                              3                     3+-+2
+--R                                                    \|9   - 6x
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 775
+
+)clear all
+
+--S 776 of 2282
+t0:=x^6/(3+4*x^3+x^6)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 776
+
+--S 777 of 2282
+r0:=x+1/2*3^(5/6)*atan((3^(1/3)-2*x)/3^(5/6))+1/6*log(1+x)-_
+   1/2*3^(1/3)*log(3^(1/3)+x)-1/12*log(1-x+x^2)+1/4*3^(1/3)*log(3^(2/3)-_
+   3^(1/3)*x+x^2)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         +-+3+-+    3+-+2    3+-+    2      +-+3+-+    3+-+
+--R       3\|3 \|3 log(\|3   - x\|3  + x ) - 6\|3 \|3 log(\|3  + x)
+--R     + 
+--R                                                                 3+-+      6+-+
+--R          +-+     2              +-+               +-+6+-+5     (\|3  - 2x)\|3
+--R       - \|3 log(x  - x + 1) + 2\|3 log(x + 1) + 6\|3 \|3  atan(---------------)
+--R                                                                       3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3         +-+
+--R       6atan(------------) + 12x\|3
+--R                   3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3+---+ +-+    3+---+2    3+---+    2     +-+     2
+--R       - 3\|- 3 \|3 log(\|- 3   + x\|- 3  + x ) - \|3 log(x  - x + 1)
+--R     + 
+--R                                                                       +-+
+--R         +-+              3+---+ +-+      3+---+              (2x - 1)\|3
+--R       2\|3 log(x + 1) + 6\|- 3 \|3 log(- \|- 3  + x) + 6atan(------------)
+--R                                                                    3
+--R     + 
+--R                     3+---+ +-+
+--R         3+---+      \|- 3 \|3         +-+
+--R       18\|- 3 atan(-----------) + 12x\|3
+--R                    3+---+
+--R                    \|- 3  + 2x
+--R  /
+--R        +-+
+--R     12\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 778
+
+--S 779 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +-+3+-+    3+-+2    3+-+    2      +-+3+-+    3+-+
+--R       - \|3 \|3 log(\|3   - x\|3  + x ) + 2\|3 \|3 log(\|3  + x)
+--R     + 
+--R         3+---+ +-+    3+---+2    3+---+    2     3+---+ +-+      3+---+
+--R       - \|- 3 \|3 log(\|- 3   + x\|- 3  + x ) + 2\|- 3 \|3 log(- \|- 3  + x)
+--R     + 
+--R                         3+-+      6+-+                 3+---+ +-+
+--R           +-+6+-+5     (\|3  - 2x)\|3      3+---+      \|- 3 \|3
+--R       - 2\|3 \|3  atan(---------------) + 6\|- 3 atan(-----------)
+--R                               3                       3+---+
+--R                                                       \|- 3  + 2x
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 780
+
+)clear all
+
+--S 781 of 2282
+t0:=x^5/(3+4*x^3+x^6)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 781
+
+--S 782 of 2282
+r0:=-1/6*log(1+x^3)+1/2*log(3+x^3)
+--R 
+--R
+--R              3             3
+--R        3log(x  + 3) - log(x  + 1)
+--R   (2)  --------------------------
+--R                     6
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3             3
+--R        3log(x  + 3) - log(x  + 1)
+--R   (3)  --------------------------
+--R                     6
+--R                                         Type: Union(Expression(Integer),...)
+--E 783
+
+--S 784 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 785
+
+)clear all
+
+--S 786 of 2282
+t0:=x^4/(3+4*x^3+x^6)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 786
+
+--S 787 of 2282
+r0:=-1/2*3^(1/6)*atan((3^(1/3)-2*x)/3^(5/6))+1/6*log(1+x)-_
+   1/2*log(3^(1/3)+x)/3^(1/3)-1/12*log(1-x+x^2)+1/4*log(3^(2/3)-3^(1/3)*x+_
+   x^2)/3^(1/3)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         +-+    3+-+2    3+-+    2      +-+    3+-+
+--R       3\|3 log(\|3   - x\|3  + x ) - 6\|3 log(\|3  + x)
+--R     + 
+--R          +-+3+-+     2              +-+3+-+
+--R       - \|3 \|3 log(x  - x + 1) + 2\|3 \|3 log(x + 1)
+--R     + 
+--R                            3+-+      6+-+                       +-+
+--R           +-+3+-+6+-+     (\|3  - 2x)\|3      3+-+     (2x - 1)\|3
+--R       - 6\|3 \|3 \|3 atan(---------------) - 6\|3 atan(------------)
+--R                                  3                           3
+--R  /
+--R        +-+3+-+
+--R     12\|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        3+---+ +-+      3+-+2    3+---+2     +-+3+-+     2
+--R       6\|- 1 \|3 log(x \|3   + 3\|- 1  ) - \|3 \|3 log(x  - x + 1)
+--R     + 
+--R         +-+3+-+              3+---+ +-+        3+---+2 3+-+2   2 3+-+   3+---+
+--R       2\|3 \|3 log(x + 1) - 3\|- 1 \|3 log(- x \|- 1   \|3  + x  \|3 - 3\|- 1 )
+--R     + 
+--R                            +-+                      3+---+2 +-+
+--R          3+-+     (2x - 1)\|3       3+---+         3\|- 1  \|3
+--R       - 6\|3 atan(------------) + 18\|- 1 atan(-------------------)
+--R                         3                         3+-+2    3+---+2
+--R                                                2x \|3   - 3\|- 1
+--R  /
+--R        +-+3+-+
+--R     12\|3 \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 788
+
+--S 789 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        3+---+ +-+      3+-+2    3+---+2     +-+    3+-+2    3+-+    2
+--R       2\|- 1 \|3 log(x \|3   + 3\|- 1  ) - \|3 log(\|3   - x\|3  + x )
+--R     + 
+--R         +-+    3+-+        3+---+ +-+        3+---+2 3+-+2   2 3+-+   3+---+
+--R       2\|3 log(\|3  + x) - \|- 1 \|3 log(- x \|- 1   \|3  + x  \|3 - 3\|- 1 )
+--R     + 
+--R                          3+-+      6+-+                     3+---+2 +-+
+--R         +-+3+-+6+-+     (\|3  - 2x)\|3      3+---+         3\|- 1  \|3
+--R       2\|3 \|3 \|3 atan(---------------) + 6\|- 1 atan(-------------------)
+--R                                3                          3+-+2    3+---+2
+--R                                                        2x \|3   - 3\|- 1
+--R  /
+--R       +-+3+-+
+--R     4\|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 790
+
+)clear all
+
+--S 791 of 2282
+t0:=x^3/(3+4*x^3+x^6)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 791
+
+--S 792 of 2282
+r0:=-1/2*atan((3^(1/3)-2*x)/3^(5/6))/3^(1/6)-1/6*log(1+x)+_
+   1/2*log(3^(1/3)+x)/3^(2/3)+1/12*log(1-x+x^2)-1/4*log(3^(2/3)-3^(1/3)*x+_
+   x^2)/3^(2/3)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           +-+6+-+    3+-+2    3+-+    2      +-+6+-+    3+-+
+--R       - 3\|3 \|3 log(\|3   - x\|3  + x ) + 6\|3 \|3 log(\|3  + x)
+--R     + 
+--R        +-+3+-+2 6+-+     2             +-+3+-+2 6+-+
+--R       \|3 \|3   \|3 log(x  - x + 1 - 2\|3 \|3   \|3 log(x + 1)
+--R     + 
+--R                         3+-+      6+-+                             +-+
+--R           +-+3+-+2     (\|3  - 2x)\|3      3+-+2 6+-+     (2x - 1)\|3
+--R       - 6\|3 \|3  atan(---------------) - 6\|3   \|3 atan(------------)
+--R                               3                                 3
+--R  /
+--R        +-+3+-+2 6+-+
+--R     12\|3 \|3   \|3
+--R                                                    Type: Expression(Integer)
+--E 792
+
+--S 793 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-+     2 3+-+2    3+-+          +-+     3+-+
+--R       - 3\|3 log(x  \|9  - 3x\|9  + 9) + 6\|3 log(x\|9  + 3)
+--R     + 
+--R                                                                          +-+
+--R        +-+3+-+     2              +-+3+-+              3+-+     (2x - 1)\|3
+--R       \|3 \|9 log(x  - x + 1) - 2\|3 \|9 log(x + 1) - 6\|9 atan(------------)
+--R                                                                       3
+--R     + 
+--R                     +-+
+--R                   3\|3
+--R       - 18atan(----------)
+--R                  3+-+
+--R                2x\|9  - 3
+--R  /
+--R        +-+3+-+
+--R     12\|3 \|9
+--R                                         Type: Union(Expression(Integer),...)
+--E 793
+
+--S 794 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +-+3+-+2 6+-+     2 3+-+2    3+-+         +-+3+-+2 6+-+     3+-+
+--R       - \|3 \|3   \|3 log(x  \|9  - 3x\|9  + 9 + 2\|3 \|3   \|3 log(x\|9  + 3)
+--R     + 
+--R        +-+6+-+3+-+    3+-+2    3+-+    2      +-+6+-+3+-+    3+-+
+--R       \|3 \|3 \|9 log(\|3   - x\|3  + x ) - 2\|3 \|3 \|9 log(\|3  + x)
+--R     + 
+--R                            3+-+      6+-+                        +-+
+--R         +-+3+-+2 3+-+     (\|3  - 2x)\|3     3+-+2 6+-+        3\|3
+--R       2\|3 \|3   \|9 atan(--------------- - 6\|3   \|3 atan(----------)
+--R                                  3                            3+-+
+--R                                                             2x\|9  - 3
+--R  /
+--R       +-+3+-+2 6+-+3+-+
+--R     4\|3 \|3   \|3 \|9
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 795
+
+)clear all
+
+--S 796 of 2282
+t0:=x^2/(3+4*x^3+x^6)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 796
+
+--S 797 of 2282
+r0:=-1/3*atanh(2+x^3),1/6*log(1+x^3)-1/6*log(3+x^3)
+--R 
+--R
+--R                  3             3             3
+--R           atanh(x  + 2) - log(x  + 3) + log(x  + 1)
+--R   (2)  [- -------------,---------------------------]
+--R                 3                    6
+--R                                             Type: Tuple(Expression(Integer))
+--E 797
+
+--S 798 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3             3
+--R        - log(x  + 3) + log(x  + 1)
+--R   (3)  ---------------------------
+--R                     6
+--R                                         Type: Union(Expression(Integer),...)
+--E 798
+
+--S 799 of 2282
+m0:=a0-r0
+--R 
+--R
+--R               3             3                3
+--R        - log(x  + 3) + log(x  + 1) + 2atanh(x  + 2)
+--R   (4)  --------------------------------------------
+--R                              6
+--R                                                    Type: Expression(Integer)
+--E 799
+
+--S 800 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 800
+
+)clear all
+
+--S 801 of 2282
+t0:=x/(3+4*x^3+x^6)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 801
+
+--S 802 of 2282
+r0:=1/2*atan((3^(1/3)-2*x)/3^(5/6))/3^(5/6)-1/6*log(1+x)+_
+   1/6*log(3^(1/3)+x)/3^(1/3)+1/12*log(1-x+x^2)-1/12*log(3^(2/3)-3^(1/3)*x+_
+   x^2)/3^(1/3)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          +-+6+-+5    3+-+2    3+-+    2      +-+6+-+5    3+-+
+--R       - \|3 \|3  log(\|3   - x\|3  + x ) + 2\|3 \|3  log(\|3  + x)
+--R     + 
+--R        +-+3+-+6+-+5     2              +-+3+-+6+-+5
+--R       \|3 \|3 \|3  log(x  - x + 1) - 2\|3 \|3 \|3  log(x + 1)
+--R     + 
+--R                      3+-+      6+-+                            +-+
+--R         +-+3+-+     (\|3  - 2x)\|3      3+-+6+-+5     (2x - 1)\|3
+--R       6\|3 \|3 atan(---------------) + 6\|3 \|3  atan(------------)
+--R                            3                                3
+--R  /
+--R        +-+3+-+6+-+5
+--R     12\|3 \|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 802
+
+--S 803 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         +-+      3+-+2         +-+3+-+     2              +-+3+-+
+--R       2\|3 log(x \|3   + 3) + \|3 \|3 log(x  - x + 1) - 2\|3 \|3 log(x + 1)
+--R     + 
+--R                                                    +-+3+-+2     +-+
+--R          +-+        3+-+2    2 3+-+             2x\|3 \|3   - 3\|3
+--R       - \|3 log(- x \|3   + x  \|3 + 3) - 6atan(-------------------)
+--R                                                          9
+--R     + 
+--R                          +-+
+--R        3+-+     (2x - 1)\|3
+--R       6\|3 atan(------------)
+--R                       3
+--R  /
+--R        +-+3+-+
+--R     12\|3 \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 803
+
+--S 804 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         +-+6+-+5      3+-+2         +-+6+-+5    3+-+2    3+-+    2
+--R       2\|3 \|3  log(x \|3   + 3) + \|3 \|3  log(\|3   - x\|3  + x )
+--R     + 
+--R           +-+6+-+5    3+-+         +-+6+-+5        3+-+2    2 3+-+
+--R       - 2\|3 \|3  log(\|3  + x) - \|3 \|3  log(- x \|3   + x  \|3 + 3)
+--R     + 
+--R                        3+-+      6+-+                  +-+3+-+2     +-+
+--R           +-+3+-+     (\|3  - 2x)\|3      6+-+5     2x\|3 \|3   - 3\|3
+--R       - 6\|3 \|3 atan(---------------) - 6\|3  atan(-------------------)
+--R                              3                               9
+--R  /
+--R        +-+3+-+6+-+5
+--R     12\|3 \|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 805
+
+)clear all
+
+--S 806 of 2282
+t0:=1/(3+4*x^3+x^6)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 806
+
+--S 807 of 2282
+r0:=1/6*atan((3^(1/3)-2*x)/3^(5/6))/3^(1/6)+1/6*log(1+x)-_
+   1/6*log(3^(1/3)+x)/3^(2/3)-1/12*log(1-x+x^2)+1/12*log(3^(2/3)-_
+   3^(1/3)*x+x^2)/3^(2/3)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R        +-+6+-+    3+-+2    3+-+    2      +-+6+-+    3+-+
+--R       \|3 \|3 log(\|3   - x\|3  + x ) - 2\|3 \|3 log(\|3  + x)
+--R     + 
+--R          +-+3+-+2 6+-+     2             +-+3+-+2 6+-+
+--R       - \|3 \|3   \|3 log(x  - x + 1 + 2\|3 \|3   \|3 log(x + 1)
+--R     + 
+--R                       3+-+      6+-+                             +-+
+--R         +-+3+-+2     (\|3  - 2x)\|3      3+-+2 6+-+     (2x - 1)\|3
+--R       2\|3 \|3  atan(---------------) + 6\|3   \|3 atan(------------)
+--R                             3                                 3
+--R  /
+--R        +-+3+-+2 6+-+
+--R     12\|3 \|3   \|3
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3+---+ +-+     2 3+-+2    3+---+3+-+    3+---+2
+--R       - \|- 1 \|3 log(x  \|9  + 3x\|- 1 \|9  + 9\|- 1  )
+--R     + 
+--R        3+---+ +-+     3+-+    3+---+     +-+3+-+     2
+--R       2\|- 1 \|3 log(x\|9  - 3\|- 1 ) - \|3 \|9 log(x  - x + 1)
+--R     + 
+--R                                            +-+3+-+    3+---+ +-+
+--R         +-+3+-+              3+---+     2x\|3 \|9  + 3\|- 1 \|3
+--R       2\|3 \|9 log(x + 1) - 6\|- 1 atan(------------------------)
+--R                                                   3+---+
+--R                                                  9\|- 1
+--R     + 
+--R                          +-+
+--R        3+-+     (2x - 1)\|3
+--R       6\|9 atan(------------)
+--R                       3
+--R  /
+--R        +-+3+-+
+--R     12\|3 \|9
+--R                                         Type: Union(Expression(Integer),...)
+--E 808
+
+--S 809 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         3+---+ +-+3+-+2 6+-+     2 3+-+2    3+---+3+-+    3+---+2
+--R       - \|- 1 \|3 \|3   \|3 log(x  \|9  + 3x\|- 1 \|9  + 9\|- 1  )
+--R     + 
+--R        3+---+ +-+3+-+2 6+-+     3+-+    3+---+
+--R       2\|- 1 \|3 \|3   \|3 log(x\|9  - 3\|- 1 )
+--R     + 
+--R          +-+6+-+3+-+    3+-+2    3+-+    2      +-+6+-+3+-+    3+-+
+--R       - \|3 \|3 \|9 log(\|3   - x\|3  + x ) + 2\|3 \|3 \|9 log(\|3  + x)
+--R     + 
+--R                                  +-+3+-+    3+---+ +-+
+--R          3+---+3+-+2 6+-+     2x\|3 \|9  + 3\|- 1 \|3
+--R       - 6\|- 1 \|3   \|3 atan(------------------------)
+--R                                         3+---+
+--R                                        9\|- 1
+--R     + 
+--R                              3+-+      6+-+
+--R           +-+3+-+2 3+-+     (\|3  - 2x)\|3
+--R       - 2\|3 \|3   \|9 atan(---------------)
+--R                                    3
+--R  /
+--R        +-+3+-+2 6+-+3+-+
+--R     12\|3 \|3   \|3 \|9
+--R                                                    Type: Expression(Integer)
+--E 809
+
+--S 810 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 810
+
+)clear all
+
+--S 811 of 2282
+t0:=1/(x*(3+4*x^3+x^6))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         7     4
+--R        x  + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 811
+
+--S 812 of 2282
+r0:=1/3*log(x)-1/6*log(1+x^3)+1/18*log(3+x^3)
+--R 
+--R
+--R             3              3
+--R        log(x  + 3) - 3log(x  + 1) + 6log(x)
+--R   (2)  ------------------------------------
+--R                         18
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3              3
+--R        log(x  + 3) - 3log(x  + 1) + 6log(x)
+--R   (3)  ------------------------------------
+--R                         18
+--R                                         Type: Union(Expression(Integer),...)
+--E 813
+
+--S 814 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 815
+
+)clear all
+
+--S 816 of 2282
+t0:=1/(x^2*(3+4*x^3+x^6))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         8     5     2
+--R        x  + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 816
+
+--S 817 of 2282
+r0:=(-1/3)/x-1/6*atan((3^(1/3)-2*x)/3^(5/6))/3^(5/6)+1/6*log(1+x)-_
+   1/18*log(3^(1/3)+x)/3^(1/3)-1/12*log(1-x+x^2)+1/36*log(3^(2/3)-_
+   3^(1/3)*x+x^2)/3^(1/3)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         +-+6+-+5    3+-+2    3+-+    2       +-+6+-+5    3+-+
+--R       x\|3 \|3  log(\|3   - x\|3  + x ) - 2x\|3 \|3  log(\|3  + x)
+--R     + 
+--R            +-+3+-+6+-+5     2               +-+3+-+6+-+5
+--R       - 3x\|3 \|3 \|3  log(x  - x + 1) + 6x\|3 \|3 \|3  log(x + 1)
+--R     + 
+--R                         3+-+      6+-+                              +-+
+--R            +-+3+-+     (\|3  - 2x)\|3        3+-+6+-+5     (2x - 1)\|3
+--R       - 6x\|3 \|3 atan(---------------) - 18x\|3 \|3  atan(------------)
+--R                               3                                  3
+--R     + 
+--R            +-+3+-+6+-+5
+--R       - 12\|3 \|3 \|3
+--R  /
+--R         +-+3+-+6+-+5
+--R     36x\|3 \|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3+---+ +-+      3+-+2    3+---+2       +-+3+-+     2
+--R       2x\|- 1 \|3 log(x \|3   + 3\|- 1  ) - 3x\|3 \|3 log(x  - x + 1)
+--R     + 
+--R          +-+3+-+
+--R       6x\|3 \|3 log(x + 1)
+--R     + 
+--R          3+---+ +-+        3+---+2 3+-+2   2 3+-+   3+---+
+--R       - x\|- 1 \|3 log(- x \|- 1   \|3  + x  \|3 - 3\|- 1 )
+--R     + 
+--R                         +-+3+-+2    3+---+2 +-+                         +-+
+--R           3+---+     2x\|3 \|3   - 3\|- 1  \|3        3+-+     (2x - 1)\|3
+--R       - 6x\|- 1 atan(--------------------------) - 18x\|3 atan(------------)
+--R                                3+---+2                               3
+--R                               9\|- 1
+--R     + 
+--R            +-+3+-+
+--R       - 12\|3 \|3
+--R  /
+--R         +-+3+-+
+--R     36x\|3 \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 818
+
+--S 819 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        3+---+ +-+6+-+5      3+-+2    3+---+2
+--R       2\|- 1 \|3 \|3  log(x \|3   + 3\|- 1  )
+--R     + 
+--R          +-+6+-+5    3+-+2    3+-+    2      +-+6+-+5    3+-+
+--R       - \|3 \|3  log(\|3   - x\|3  + x ) + 2\|3 \|3  log(\|3  + x)
+--R     + 
+--R         3+---+ +-+6+-+5        3+---+2 3+-+2   2 3+-+   3+---+
+--R       - \|- 1 \|3 \|3  log(- x \|- 1   \|3  + x  \|3 - 3\|- 1 )
+--R     + 
+--R                      3+-+      6+-+
+--R         +-+3+-+     (\|3  - 2x)\|3
+--R       6\|3 \|3 atan(---------------)
+--R                            3
+--R     + 
+--R                             +-+3+-+2    3+---+2 +-+
+--R          3+---+6+-+5     2x\|3 \|3   - 3\|- 1  \|3
+--R       - 6\|- 1 \|3  atan(--------------------------)
+--R                                    3+---+2
+--R                                   9\|- 1
+--R  /
+--R        +-+3+-+6+-+5
+--R     36\|3 \|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 820
+
+)clear all
+
+--S 821 of 2282
+t0:=1/(x^3*(3+4*x^3+x^6))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         9     6     3
+--R        x  + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 821
+
+--S 822 of 2282
+r0:=(-1/6)/x^2-1/18*atan((3^(1/3)-2*x)/3^(5/6))/3^(1/6)-1/6*log(1+x)+_
+   1/18*log(3^(1/3)+x)/3^(2/3)+1/12*log(1-x+x^2)-_
+   1/36*log(3^(2/3)-3^(1/3)*x+x^2)/3^(2/3)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          2 +-+6+-+    3+-+2    3+-+    2      2 +-+6+-+    3+-+
+--R       - x \|3 \|3 log(\|3   - x\|3  + x ) + 2x \|3 \|3 log(\|3  + x)
+--R     + 
+--R         2 +-+3+-+2 6+-+     2             2 +-+3+-+2 6+-+
+--R       3x \|3 \|3   \|3 log(x  - x + 1 - 6x \|3 \|3   \|3 log(x + 1)
+--R     + 
+--R                           3+-+      6+-+                                 +-+
+--R           2 +-+3+-+2     (\|3  - 2x)\|3        2 3+-+2 6+-+     (2x - 1)\|3
+--R       - 2x \|3 \|3  atan(---------------) - 18x  \|3   \|3 atan(------------)
+--R                                 3                                     3
+--R     + 
+--R           +-+3+-+2 6+-+
+--R       - 6\|3 \|3   \|3
+--R  /
+--R        2 +-+3+-+2 6+-+
+--R     36x \|3 \|3   \|3
+--R                                                    Type: Expression(Integer)
+--E 822
+
+--S 823 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 +-+     2 3+-+2    3+-+          2 +-+     3+-+
+--R       - x \|3 log(x  \|9  - 3x\|9  + 9) + 2x \|3 log(x\|9  + 3)
+--R     + 
+--R         2 +-+3+-+     2              2 +-+3+-+
+--R       3x \|3 \|9 log(x  - x + 1) - 6x \|3 \|9 log(x + 1)
+--R     + 
+--R                  +-+3+-+     +-+                           +-+
+--R         2     2x\|3 \|9  - 3\|3        2 3+-+     (2x - 1)\|3      +-+3+-+
+--R       6x atan(------------------) - 18x  \|9 atan(------------ - 6\|3 \|9
+--R                        9                                3
+--R  /
+--R        2 +-+3+-+
+--R     36x \|3 \|9
+--R                                         Type: Union(Expression(Integer),...)
+--E 823
+
+--S 824 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +-+3+-+2 6+-+     2 3+-+2    3+-+         +-+3+-+2 6+-+     3+-+
+--R       - \|3 \|3   \|3 log(x  \|9  - 3x\|9  + 9 + 2\|3 \|3   \|3 log(x\|9  + 3)
+--R     + 
+--R        +-+6+-+3+-+    3+-+2    3+-+    2      +-+6+-+3+-+    3+-+
+--R       \|3 \|3 \|9 log(\|3   - x\|3  + x ) - 2\|3 \|3 \|9 log(\|3  + x)
+--R     + 
+--R                          +-+3+-+     +-+                        3+-+      6+-+
+--R        3+-+2 6+-+     2x\|3 \|9  - 3\|3      +-+3+-+2 3+-+     (\|3  - 2x)\|3
+--R       6\|3   \|3 atan(------------------ + 2\|3 \|3   \|9 atan(---------------)
+--R                                9                                      3
+--R  /
+--R        +-+3+-+2 6+-+3+-+
+--R     36\|3 \|3   \|3 \|9
+--R                                                    Type: Expression(Integer)
+--E 824
+
+--S 825 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 825
+
+)clear all
+
+--S 826 of 2282
+t0:=1/(x^4*(3+4*x^3+x^6))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         10     7     4
+--R        x   + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 826
+
+--S 827 of 2282
+r0:=(-1/9)/x^3-4/9*log(x)+1/6*log(1+x^3)-1/54*log(3+x^3)
+--R 
+--R
+--R           3     3          3     3           3
+--R        - x log(x  + 3) + 9x log(x  + 1) - 24x log(x) - 6
+--R   (2)  -------------------------------------------------
+--R                                  3
+--R                               54x
+--R                                                    Type: Expression(Integer)
+--E 827
+
+--S 828 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3     3          3     3           3
+--R        - x log(x  + 3) + 9x log(x  + 1) - 24x log(x) - 6
+--R   (3)  -------------------------------------------------
+--R                                  3
+--R                               54x
+--R                                         Type: Union(Expression(Integer),...)
+--E 828
+
+--S 829 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 830
+
+)clear all
+
+--S 831 of 2282
+t0:=1/(x^5*(3+4*x^3+x^6))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         11     8     5
+--R        x   + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 831
+
+--S 832 of 2282
+r0:=(-1/12)/x^4+4/9/x+1/18*atan((3^(1/3)-2*x)/3^(5/6))/3^(5/6)-_
+   1/6*log(1+x)+1/54*log(3^(1/3)+x)/3^(1/3)+1/12*log(1-x+x^2)-_
+   1/108*log(3^(2/3)-3^(1/3)*x+x^2)/3^(1/3)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          4 +-+6+-+5    3+-+2    3+-+    2      4 +-+6+-+5    3+-+
+--R       - x \|3 \|3  log(\|3   - x\|3  + x ) + 2x \|3 \|3  log(\|3  + x)
+--R     + 
+--R         4 +-+3+-+6+-+5     2               4 +-+3+-+6+-+5
+--R       9x \|3 \|3 \|3  log(x  - x + 1) - 18x \|3 \|3 \|3  log(x + 1)
+--R     + 
+--R                        3+-+      6+-+                                +-+
+--R         4 +-+3+-+     (\|3  - 2x)\|3        4 3+-+6+-+5     (2x - 1)\|3
+--R       6x \|3 \|3 atan(---------------) + 54x  \|3 \|3  atan(------------)
+--R                              3                                    3
+--R     + 
+--R           3      +-+3+-+6+-+5
+--R       (48x  - 9)\|3 \|3 \|3
+--R  /
+--R         4 +-+3+-+6+-+5
+--R     108x \|3 \|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         4 +-+      3+-+2          4 +-+3+-+     2
+--R       2x \|3 log(x \|3   + 3) + 9x \|3 \|3 log(x  - x + 1)
+--R     + 
+--R            4 +-+3+-+              4 +-+        3+-+2    2 3+-+
+--R       - 18x \|3 \|3 log(x + 1) - x \|3 log(- x \|3   + x  \|3 + 3)
+--R     + 
+--R                    +-+3+-+2     +-+                           +-+
+--R           4     2x\|3 \|3   - 3\|3        4 3+-+     (2x - 1)\|3
+--R       - 6x atan(-------------------) + 54x  \|3 atan(------------)
+--R                          9                                 3
+--R     + 
+--R           3      +-+3+-+
+--R       (48x  - 9)\|3 \|3
+--R  /
+--R         4 +-+3+-+
+--R     108x \|3 \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 833
+
+--S 834 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         +-+6+-+5      3+-+2         +-+6+-+5    3+-+2    3+-+    2
+--R       2\|3 \|3  log(x \|3   + 3) + \|3 \|3  log(\|3   - x\|3  + x )
+--R     + 
+--R           +-+6+-+5    3+-+         +-+6+-+5        3+-+2    2 3+-+
+--R       - 2\|3 \|3  log(\|3  + x) - \|3 \|3  log(- x \|3   + x  \|3 + 3)
+--R     + 
+--R                        3+-+      6+-+                  +-+3+-+2     +-+
+--R           +-+3+-+     (\|3  - 2x)\|3      6+-+5     2x\|3 \|3   - 3\|3
+--R       - 6\|3 \|3 atan(---------------) - 6\|3  atan(-------------------)
+--R                              3                               9
+--R  /
+--R         +-+3+-+6+-+5
+--R     108\|3 \|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 834
+
+--S 835 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 835
+
+)clear all
+
+--S 836 of 2282
+t0:=1/(x^6*(3+4*x^3+x^6))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         12     9     6
+--R        x   + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 836
+
+--S 837 of 2282
+r0:=(-1/15)/x^5+2/9/x^2+1/54*atan((3^(1/3)-2*x)/3^(5/6))/3^(1/6)+_
+   1/6*log(1+x)-1/54*log(3^(1/3)+x)/3^(2/3)-1/12*log(1-x+x^2)+_
+   1/108*log(3^(2/3)-3^(1/3)*x+x^2)/3^(2/3)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         5 +-+6+-+    3+-+2    3+-+    2       5 +-+6+-+    3+-+
+--R       5x \|3 \|3 log(\|3   - x\|3  + x ) - 10x \|3 \|3 log(\|3  + x)
+--R     + 
+--R            5 +-+3+-+2 6+-+     2              5 +-+3+-+2 6+-+
+--R       - 45x \|3 \|3   \|3 log(x  - x + 1 + 90x \|3 \|3   \|3 log(x + 1)
+--R     + 
+--R                          3+-+      6+-+                                  +-+
+--R          5 +-+3+-+2     (\|3  - 2x)\|3         5 3+-+2 6+-+     (2x - 1)\|3
+--R       10x \|3 \|3  atan(---------------) + 270x  \|3   \|3 atan(------------)
+--R                                3                                      3
+--R     + 
+--R            3       +-+3+-+2 6+-+
+--R       (120x  - 36)\|3 \|3   \|3
+--R  /
+--R         5 +-+3+-+2 6+-+
+--R     540x \|3 \|3   \|3
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           5 3+---+ +-+     2 3+-+2    3+---+3+-+    3+---+2
+--R       - 5x  \|- 1 \|3 log(x  \|9  + 3x\|- 1 \|9  + 9\|- 1  )
+--R     + 
+--R          5 3+---+ +-+     3+-+    3+---+      5 +-+3+-+     2
+--R       10x  \|- 1 \|3 log(x\|9  - 3\|- 1  - 45x \|3 \|9 log(x  - x + 1)
+--R     + 
+--R                                                   +-+3+-+    3+---+ +-+
+--R          5 +-+3+-+                5 3+---+     2x\|3 \|9  + 3\|- 1 \|3
+--R       90x \|3 \|9 log(x + 1) - 30x  \|- 1 atan(------------------------)
+--R                                                          3+---+
+--R                                                         9\|- 1
+--R     + 
+--R                               +-+
+--R           5 3+-+     (2x - 1)\|3         3       +-+3+-+
+--R       270x  \|9 atan(------------ + (120x  - 36)\|3 \|9
+--R                            3
+--R  /
+--R         5 +-+3+-+
+--R     540x \|3 \|9
+--R                                         Type: Union(Expression(Integer),...)
+--E 838
+
+--S 839 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         3+---+ +-+3+-+2 6+-+     2 3+-+2    3+---+3+-+    3+---+2
+--R       - \|- 1 \|3 \|3   \|3 log(x  \|9  + 3x\|- 1 \|9  + 9\|- 1  )
+--R     + 
+--R        3+---+ +-+3+-+2 6+-+     3+-+    3+---+
+--R       2\|- 1 \|3 \|3   \|3 log(x\|9  - 3\|- 1 )
+--R     + 
+--R          +-+6+-+3+-+    3+-+2    3+-+    2      +-+6+-+3+-+    3+-+
+--R       - \|3 \|3 \|9 log(\|3   - x\|3  + x ) + 2\|3 \|3 \|9 log(\|3  + x)
+--R     + 
+--R                                  +-+3+-+    3+---+ +-+
+--R          3+---+3+-+2 6+-+     2x\|3 \|9  + 3\|- 1 \|3
+--R       - 6\|- 1 \|3   \|3 atan(------------------------)
+--R                                         3+---+
+--R                                        9\|- 1
+--R     + 
+--R                              3+-+      6+-+
+--R           +-+3+-+2 3+-+     (\|3  - 2x)\|3
+--R       - 2\|3 \|3   \|9 atan(---------------)
+--R                                    3
+--R  /
+--R         +-+3+-+2 6+-+3+-+
+--R     108\|3 \|3   \|3 \|9
+--R                                                    Type: Expression(Integer)
+--E 839
+
+--S 840 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 840
+
+)clear all
+
+--S 841 of 2282
+t0:=1/(x^7*(3+4*x^3+x^6))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R         13     10     7
+--R        x   + 4x   + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 841
+
+--S 842 of 2282
+r0:=(-1/18)/x^6+4/27/x^3+13/27*log(x)-1/6*log(1+x^3)+1/162*log(3+x^3)
+--R 
+--R
+--R         6     3           6     3           6            3
+--R        x log(x  + 3) - 27x log(x  + 1) + 78x log(x) + 24x  - 9
+--R   (2)  -------------------------------------------------------
+--R                                     6
+--R                                 162x
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R         6     3           6     3           6            3
+--R        x log(x  + 3) - 27x log(x  + 1) + 78x log(x) + 24x  - 9
+--R   (3)  -------------------------------------------------------
+--R                                     6
+--R                                 162x
+--R                                         Type: Union(Expression(Integer),...)
+--E 843
+
+--S 844 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 844
+
+--S 845 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 845
+
+)clear all
+
+--S 846 of 2282
+t0:=x^m/(1-x^3+x^6)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 846
+
+--S 847 of 2282
+--r0:=-2*x^(1+m)*hypergeometric(1,1/3*(1+m),1/3*(4+m),_
+--   2*x^3/(1+%i*sqrt(3)))/((1+m)*(%i-sqrt(3))*sqrt(3))+2*x^(1+m)*_
+--   hypergeometric(1,1/3*(1+m),1/3*(4+m),2*x^3/(1-%i*sqrt(3)))/_
+--   ((1+m)*sqrt(3)*(%i+sqrt(3)))
+--E 847
+
+--S 848 of 2282
+--a0:=integrate(t0,x)
+--E 848
+
+--S 849 of 2282
+--m0:=a0-r0
+--E 849
+
+--S 850 of 2282
+--d0:=normalize(D(m0,x))
+--E 850
+
+)clear all
+
+--S 851 of 2282
+t0:=x^6/(1-x^3+x^6)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 851
+
+--S 852 of 2282
+r0:=x+1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))+_
+   1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1-%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*_
+   sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1-%i*sqrt(3))^(2/3))+1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*_
+   (3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))-1/3*atan((4*x+_
+   2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*_
+   sqrt(3)))*(%i+sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))
+--R 
+--R
+--R   (2)
+--R                        +------------+2
+--R               +-+     3|     +-+
+--R         (- %i\|3  - 3)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +------------+2     +----------+
+--R            +-+     3|     +-+          3|   +-+         3+-+
+--R       (2%i\|3  + 6)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                      +----------+2
+--R             +-+     3|   +-+
+--R         (%i\|3  - 3)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +----------+2     +------------+
+--R              +-+     3|   +-+          3|     +-+         3+-+
+--R       (- 2%i\|3  + 6)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                +------------+
+--R                       +----------+2     3+-+2 3|     +-+
+--R            +-+       3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (- 6\|3  + 6%i)\|%i\|3  + 1  atan(-------------------------)
+--R                                                    +------------+
+--R                                          3+-+2 +-+3|     +-+
+--R                                          \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                  +----------+
+--R                       +------------+2     3+-+2 3|   +-+
+--R            +-+       3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (- 6\|3  - 6%i)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                      +----------+
+--R                                            3+-+2 +-+3|   +-+
+--R                                            \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R               +------------+2  +----------+2
+--R          3+-+3|     +-+       3|   +-+
+--R       18x\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R  /
+--R            +------------+2  +----------+2
+--R       3+-+3|     +-+       3|   +-+
+--R     18\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 852
+
+--S 853 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                           1                 1
+--R                    atan(----)        atan(----)
+--R                          +-+               +-+
+--R             +-+         \|3               \|3
+--R         (- \|3 sin(----------) - cos(----------))
+--R                         3                 3
+--R      *
+--R                        1   2                 1                 1   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      3                     3                 3
+--R     + 
+--R                         1                 1
+--R                  atan(----)        atan(----)
+--R                        +-+               +-+
+--R           +-+         \|3               \|3
+--R         (\|3 sin(----------) - cos(----------))
+--R                       3                 3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                              1
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            3
+--R     + 
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                                1
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              3
+--R     + 
+--R                        1                      1
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|3        +-+         \|3
+--R         (- 2sin(----------) - 2\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) + cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) - \|3 cos(----------) - 2x
+--R                       3                     3
+--R     + 
+--R                                                1                 1
+--R                                         atan(----)        atan(----)
+--R                     1                         +-+               +-+
+--R              atan(----)          +-+         \|3               \|3
+--R                    +-+          \|3 sin(----------) - cos(----------)
+--R                   \|3                        3                 3
+--R       - 4sin(----------)atan(------------------------------------------)
+--R                   3                     1                     1
+--R                                  atan(----)            atan(----)
+--R                                        +-+                   +-+
+--R                                       \|3       +-+         \|3
+--R                              sin(----------) + \|3 cos(----------) - 2x
+--R                                       3                     3
+--R     + 
+--R                                                                    1
+--R                                                             atan(----)
+--R                      1                      1                     +-+
+--R               atan(----)             atan(----)                  \|3
+--R                     +-+                    +-+          cos(----------)
+--R                    \|3        +-+         \|3                    3
+--R       (- 2sin(----------) + 2\|3 cos(----------))atan(-------------------)
+--R                    3                      3                      1
+--R                                                           atan(----)
+--R                                                                 +-+
+--R                                                                \|3
+--R                                                       sin(----------) + x
+--R                                                                3
+--R     + 
+--R          +-+
+--R       6x\|3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 853
+
+--S 854 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +------------+2
+--R           +-+      3|     +-+
+--R         (\|3  + %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +------------+2     +----------+
+--R            +-+       3|     +-+          3|   +-+         3+-+
+--R       (- 2\|3  - 2%i)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                     +----------+2
+--R           +-+      3|   +-+
+--R         (\|3  - %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +----------+2     +------------+
+--R            +-+       3|   +-+          3|     +-+         3+-+
+--R       (- 2\|3  + 2%i)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                             +------------+2  +----------+2
+--R            3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (- \|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                         18             18
+--R      *
+--R                 %pi 2          %pi        %pi 2    2
+--R         log(sin(---)  + 2x sin(---) + cos(---)  + x )
+--R                  18             18         18
+--R     + 
+--R                                           +------------+2  +----------+2
+--R          3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (\|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                       18             18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  - x sin(---) + cos(---)  + x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                       +------------+2  +----------+2
+--R          3+-+    %pi 3|     +-+       3|   +-+
+--R         2\|2 cos(---)\|- %i\|3  + 1   \|%i\|3  + 1
+--R                   18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  - x sin(---) + cos(---)  - x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                                               +------------+2  +----------+2
+--R             3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (- 2\|2 sin(---) - 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18                  18
+--R      *
+--R                  +-+    %pi        %pi
+--R                 \|3 sin(---) + cos(---)
+--R                          18         18
+--R         atan(----------------------------)
+--R                  %pi     +-+    %pi
+--R              sin(---) - \|3 cos(---) - 2x
+--R                   18             18
+--R     + 
+--R       -
+--R                          +------------+2  +----------+2
+--R             3+-+    %pi 3|     +-+       3|   +-+
+--R            4\|2 sin(---)\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18
+--R         *
+--R                     +-+    %pi        %pi
+--R                    \|3 sin(---) - cos(---)
+--R                             18         18
+--R            atan(----------------------------)
+--R                     %pi     +-+    %pi
+--R                 sin(---) + \|3 cos(---) - 2x
+--R                      18             18
+--R     + 
+--R                                                +------------+
+--R                       +----------+2     3+-+2 3|     +-+
+--R              +-+     3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (- 2%i\|3  + 6)\|%i\|3  + 1  atan(-------------------------)
+--R                                                    +------------+
+--R                                          3+-+2 +-+3|     +-+
+--R                                          \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                +----------+
+--R                     +------------+2     3+-+2 3|   +-+
+--R            +-+     3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (2%i\|3  + 6)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                    +----------+
+--R                                          3+-+2 +-+3|   +-+
+--R                                          \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                               +------------+2  +----------+2
+--R             3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (- 2\|2 sin(---) + 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18                  18
+--R      *
+--R                    %pi
+--R                cos(---)
+--R                     18
+--R         atan(------------)
+--R                  %pi
+--R              sin(---) + x
+--R                   18
+--R  /
+--R               +------------+2  +----------+2
+--R      3+-+ +-+3|     +-+       3|   +-+
+--R     6\|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 854
+
+--S 855 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                   8    %pi 6      8    %pi 2    %pi 4
+--R               - 6x sin(---)  - 18x cos(---) sin(---)
+--R                         18              18       18
+--R             + 
+--R                    11     8     5     %pi 3
+--R               (- 6x   - 6x  + 6x )sin(---)
+--R                                        18
+--R             + 
+--R                     8    %pi 4        11     8     5  +-+    %pi      %pi 2
+--R               (- 18x cos(---)  + (- 6x   + 6x  - 6x )\|3 cos(---))sin(---)
+--R                           18                                  18       18
+--R             + 
+--R                   11      8      5     %pi 2    %pi      8    %pi 6
+--R               (18x   + 18x  - 18x )cos(---) sin(---) - 6x cos(---)
+--R                                         18       18            18
+--R             + 
+--R                  11     8     5  +-+    %pi 3     11     8
+--R               (2x   - 2x  + 2x )\|3 cos(---)  - 6x   + 6x
+--R                                          18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   9 3+-+    %pi 6     9 3+-+    %pi 2    %pi 4
+--R               - 6x  \|2 sin(---) - 18x  \|2 cos(---) sin(---)
+--R                              18                  18       18
+--R             + 
+--R                    12     9     6 3+-+    %pi 3
+--R               (- 6x   - 6x  + 6x )\|2 sin(---)
+--R                                            18
+--R             + 
+--R                       9 3+-+    %pi 4       12     9     6 3+-+ +-+    %pi
+--R                 (- 18x  \|2 cos(---) + (- 6x   + 6x  - 6x )\|2 \|3 cos(---))
+--R                                  18                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi      9 3+-+    %pi 6
+--R               (18x   + 18x  - 18x )\|2 cos(---) sin(---) - 6x  \|2 cos(---)
+--R                                             18       18                 18
+--R             + 
+--R                  12     9     6 3+-+ +-+    %pi 3        12     9 3+-+
+--R               (2x   - 2x  + 2x )\|2 \|3 cos(---)  + (- 6x   + 6x )\|2
+--R                                              18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 - 3x  \|2 )sin(---)
+--R                                            18
+--R         + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 2    %pi 4
+--R           (9%i x  \|2  \|3 - 9x  \|2 )cos(---) sin(---)
+--R                                            18       18
+--R         + 
+--R                    10        7        4 3+-+2 +-+        10     7     4 3+-+2
+--R             ((3%i x   + 3%i x  - 3%i x )\|2  \|3  + (- 3x   - 3x  + 3x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     7 3+-+2 +-+    7 3+-+2    %pi 4
+--R               (9%i x  \|2  \|3 - 9x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                        10     7     4 3+-+2 +-+
+--R                   (- 3x   + 3x  - 3x )\|2  \|3
+--R                 + 
+--R                         10        7        4 3+-+2
+--R                   (9%i x   - 9%i x  + 9%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      10        7        4 3+-+2 +-+      10     7     4 3+-+2
+--R             ((- 9%i x   - 9%i x  + 9%i x )\|2  \|3  + (9x   + 9x  - 9x )\|2  )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 - 3x  \|2 )cos(---)
+--R                                            18
+--R         + 
+--R                10    7    4 3+-+2 +-+           10        7        4 3+-+2
+--R             ((x   - x  + x )\|2  \|3  + (- 3%i x   + 3%i x  - 3%i x )\|2  )
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                 10        7 3+-+2 +-+        10     7 3+-+2
+--R           (3%i x   - 3%i x )\|2  \|3  + (- 3x   + 3x )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                   9 3+-+    %pi 6     9 3+-+    %pi 2    %pi 4
+--R               - 6x  \|2 sin(---) - 18x  \|2 cos(---) sin(---)
+--R                              18                  18       18
+--R             + 
+--R                    12     9     6 3+-+    %pi 3
+--R               (- 6x   - 6x  + 6x )\|2 sin(---)
+--R                                            18
+--R             + 
+--R                       9 3+-+    %pi 4       12     9     6 3+-+ +-+    %pi
+--R                 (- 18x  \|2 cos(---) + (- 6x   + 6x  - 6x )\|2 \|3 cos(---))
+--R                                  18                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi      9 3+-+    %pi 6
+--R               (18x   + 18x  - 18x )\|2 cos(---) sin(---) - 6x  \|2 cos(---)
+--R                                             18       18                 18
+--R             + 
+--R                  12     9     6 3+-+ +-+    %pi 3        12     9 3+-+
+--R               (2x   - 2x  + 2x )\|2 \|3 cos(---)  + (- 6x   + 6x )\|2
+--R                                              18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   10 3+-+2    %pi 6     10 3+-+2    %pi 2    %pi 4
+--R               - 6x   \|2  sin(---) - 18x   \|2  cos(---) sin(---)
+--R                                18                    18       18
+--R             + 
+--R                    13     10     7 3+-+2    %pi 3
+--R               (- 6x   - 6x   + 6x )\|2  sin(---)
+--R                                              18
+--R             + 
+--R                          10 3+-+2    %pi 4
+--R                     - 18x   \|2  cos(---)
+--R                                       18
+--R                   + 
+--R                          13     10     7 3+-+2 +-+    %pi
+--R                     (- 6x   + 6x   - 6x )\|2  \|3 cos(---)
+--R                                                        18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   13      10      7 3+-+2    %pi 2    %pi      10 3+-+2    %pi 6
+--R               (18x   + 18x   - 18x )\|2  cos(---) sin(---) - 6x   \|2  cos(---)
+--R                                               18       18                   18
+--R             + 
+--R                  13     10     7 3+-+2 +-+    %pi 3        13     10 3+-+2
+--R               (2x   - 2x   + 2x )\|2  \|3 cos(---)  + (- 6x   + 6x  )\|2
+--R                                                18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 8 +-+     8     %pi 6          8 +-+      8     %pi 2    %pi 4
+--R           (6%i x \|3  - 6x )sin(---)  + (18%i x \|3  - 18x )cos(---) sin(---)
+--R                                  18                              18       18
+--R         + 
+--R                  11        8        5  +-+     11     8     5     %pi 3
+--R           ((6%i x   + 6%i x  - 6%i x )\|3  - 6x   - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                      8 +-+      8     %pi 4
+--R               (18%i x \|3  - 18x )cos(---)
+--R                                        18
+--R             + 
+--R                   11     8     5  +-+         11         8         5     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  + 18%i x   - 18%i x  + 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       11         8         5  +-+      11      8      5
+--R             ((- 18%i x   - 18%i x  + 18%i x )\|3  + 18x   + 18x  - 18x )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                 8 +-+     8     %pi 6
+--R           (6%i x \|3  - 6x )cos(---)
+--R                                  18
+--R         + 
+--R               11     8     5  +-+        11        8        5     %pi 3
+--R           ((2x   - 2x  + 2x )\|3  - 6%i x   + 6%i x  - 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                 11        8  +-+     11     8
+--R           (6%i x   - 6%i x )\|3  - 6x   + 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 - 3x  \|2 )sin(---)
+--R                                              18
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 2    %pi 4
+--R           (- 9%i x  \|2  \|3 - 9x  \|2 )cos(---) sin(---)
+--R                                              18       18
+--R         + 
+--R                         10        7        4 3+-+2 +-+
+--R                 (- 3%i x   - 3%i x  + 3%i x )\|2  \|3
+--R               + 
+--R                      10     7     4 3+-+2
+--R                 (- 3x   - 3x  + 3x )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7 3+-+2 +-+    7 3+-+2    %pi 4
+--R               (- 9%i x  \|2  \|3 - 9x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                        10     7     4 3+-+2 +-+
+--R                   (- 3x   + 3x  - 3x )\|2  \|3
+--R                 + 
+--R                           10        7        4 3+-+2
+--R                   (- 9%i x   + 9%i x  - 9%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    10        7        4 3+-+2 +-+      10     7     4 3+-+2
+--R             ((9%i x   + 9%i x  - 9%i x )\|2  \|3  + (9x   + 9x  - 9x )\|2  )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 - 3x  \|2 )cos(---)
+--R                                              18
+--R         + 
+--R                10    7    4 3+-+2 +-+         10        7        4 3+-+2
+--R             ((x   - x  + x )\|2  \|3  + (3%i x   - 3%i x  + 3%i x )\|2  )
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   10        7 3+-+2 +-+        10     7 3+-+2
+--R           (- 3%i x   + 3%i x )\|2  \|3  + (- 3x   + 3x )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                   8 +-+     8     %pi 6
+--R           (- 6%i x \|3  - 6x )sin(---)
+--R                                    18
+--R         + 
+--R                    8 +-+      8     %pi 2    %pi 4
+--R           (- 18%i x \|3  - 18x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                    11        8        5  +-+     11     8     5     %pi 3
+--R           ((- 6%i x   - 6%i x  + 6%i x )\|3  - 6x   - 6x  + 6x )sin(---)
+--R                                                                      18
+--R         + 
+--R                        8 +-+      8     %pi 4
+--R               (- 18%i x \|3  - 18x )cos(---)
+--R                                          18
+--R             + 
+--R                   11     8     5  +-+         11         8         5     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  - 18%i x   + 18%i x  - 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 2
+--R             ((18%i x   + 18%i x  - 18%i x )\|3  + 18x   + 18x  - 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   8 +-+     8     %pi 6
+--R           (- 6%i x \|3  - 6x )cos(---)
+--R                                    18
+--R         + 
+--R               11     8     5  +-+        11        8        5     %pi 3
+--R           ((2x   - 2x  + 2x )\|3  + 6%i x   - 6%i x  + 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   11        8  +-+     11     8
+--R           (- 6%i x   + 6%i x )\|3  - 6x   + 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R            6 3+-+    %pi 6     6 3+-+    %pi 2    %pi 4
+--R       - 12x  \|2 sin(---) - 36x  \|2 cos(---) sin(---)
+--R                       18                  18       18
+--R     + 
+--R             9      6      3 3+-+    %pi 3
+--R       (- 12x  - 12x  + 12x )\|2 sin(---)
+--R                                      18
+--R     + 
+--R             6 3+-+    %pi 4        9      6      3 3+-+ +-+    %pi      %pi 2
+--R       (- 36x  \|2 cos(---) + (- 12x  + 12x  - 12x )\|2 \|3 cos(---))sin(---)
+--R                        18                                       18       18
+--R     + 
+--R           9      6      3 3+-+    %pi 2    %pi       6 3+-+    %pi 6
+--R       (36x  + 36x  - 36x )\|2 cos(---) sin(---) - 12x  \|2 cos(---)
+--R                                    18       18                  18
+--R     + 
+--R          9     6     3 3+-+ +-+    %pi 3         9      6 3+-+
+--R       (4x  - 4x  + 4x )\|2 \|3 cos(---)  + (- 12x  + 12x )\|2
+--R                                     18
+--R  /
+--R                  8     5     2     %pi 6
+--R               (6x  - 6x  + 6x )sin(---)
+--R                                     18
+--R             + 
+--R                   8      5      2     %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                   11      8      5     %pi 3
+--R               (12x   - 12x  + 12x )sin(---)
+--R                                         18
+--R             + 
+--R                   8      5      2     %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                     11      8      5     %pi 2    %pi
+--R               (- 36x   + 36x  - 36x )cos(---) sin(---)
+--R                                           18       18
+--R             + 
+--R                  8     5     2     %pi 6     14     11     8
+--R               (6x  - 6x  + 6x )cos(---)  + 6x   - 6x   + 6x
+--R                                     18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 3
+--R               (12x   - 12x  + 12x )\|2 sin(---)
+--R                                             18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 2    %pi
+--R               (- 36x   + 36x  - 36x )\|2 cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      10        7        4 3+-+2 +-+      10     7     4 3+-+2
+--R             ((- 6%i x   + 6%i x  - 6%i x )\|2  \|3  + (6x   - 6x  + 6x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      10         7         4 3+-+2 +-+
+--R               (18%i x   - 18%i x  + 18%i x )\|2  \|3
+--R             + 
+--R                     10      7      4 3+-+2
+--R               (- 18x   + 18x  - 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 3
+--R               (12x   - 12x  + 12x )\|2 sin(---)
+--R                                             18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 2    %pi
+--R               (- 36x   + 36x  - 36x )\|2 cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  10     7     4 3+-+2    %pi 6
+--R               (6x   - 6x  + 6x )\|2  sin(---)
+--R                                           18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 2    %pi 4
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                   13      10      7 3+-+2    %pi 3
+--R               (12x   - 12x   + 12x )\|2  sin(---)
+--R                                               18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 4    %pi 2
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                     13      10      7 3+-+2    %pi 2    %pi
+--R               (- 36x   + 36x   - 36x )\|2  cos(---) sin(---)
+--R                                                 18       18
+--R             + 
+--R                  10     7     4 3+-+2    %pi 6      16     13     10 3+-+2
+--R               (6x   - 6x  + 6x )\|2  cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                           18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 2
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 3
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  + 12x   - 12x  + 12x )sin(---)
+--R                                                                            18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 4
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 2
+--R             ((36%i x   - 36%i x  + 36%i x )\|3  - 36x   + 36x  - 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   14        11        8  +-+     14     11     8
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )sin(---)
+--R                                                                            18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                    10        7        4 3+-+2 +-+      10     7     4 3+-+2
+--R             ((6%i x   - 6%i x  + 6%i x )\|2  \|3  + (6x   - 6x  + 6x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                        10         7         4 3+-+2 +-+
+--R               (- 18%i x   + 18%i x  - 18%i x )\|2  \|3
+--R             + 
+--R                     10      7      4 3+-+2
+--R               (- 18x   + 18x  - 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )cos(---)
+--R                                                                            18
+--R         + 
+--R                 13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 2
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   11         8         5  +-+      11      8      5     %pi 3
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  + 12x   - 12x  + 12x )sin(---)
+--R                                                                          18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 4
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       11         8         5  +-+      11      8      5
+--R             ((- 36%i x   + 36%i x  - 36%i x )\|3  - 36x   + 36x  - 36x )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                 14        11        8  +-+     14     11     8
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           6      3      3+-+    %pi 6
+--R       (12x  - 12x  + 12)\|2 sin(---)
+--R                                  18
+--R     + 
+--R           6      3      3+-+    %pi 2    %pi 4
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R           9      6      3 3+-+    %pi 3
+--R       (24x  - 24x  + 24x )\|2 sin(---)
+--R                                    18
+--R     + 
+--R           6      3      3+-+    %pi 4    %pi 2
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R             9      6      3 3+-+    %pi 2    %pi
+--R       (- 72x  + 72x  - 72x )\|2 cos(---) sin(---)
+--R                                      18       18
+--R     + 
+--R           6      3      3+-+    %pi 6       12      9      6 3+-+
+--R       (12x  - 12x  + 12)\|2 cos(---)  + (12x   - 12x  + 12x )\|2
+--R                                  18
+--R                                           Type: Expression(Complex(Integer))
+--E 855
+
+)clear all
+
+--S 856 of 2282
+t0:=x^5/(1-x^3+x^6)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 856
+
+--S 857 of 2282
+r0:=1/6*log(1-x^3+x^6)-1/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                        3      +-+
+--R         +-+     6    3              (2x  - 1)\|3
+--R        \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           6\|3
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        3      +-+
+--R         +-+     6    3              (2x  - 1)\|3
+--R        \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                           3
+--R   (3)  -------------------------------------------
+--R                             +-+
+--R                           6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 858
+
+--S 859 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 859
+
+--S 860 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 860
+
+)clear all
+
+--S 861 of 2282
+t0:=x^4/(1-x^3+x^6)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 861
+
+--S 862 of 2282
+r0:=-1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))+_
+   1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3))-1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*_
+   sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3))+1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))-1/18*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3+%i*_
+   sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))+1/3*atan((4*x+2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))*_
+   (%i+sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))
+--R 
+--R
+--R   (2)
+--R                      +------------+
+--R             +-+     3|     +-+
+--R         (%i\|3  - 3)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +------------+     +----------+
+--R              +-+     3|     +-+         3|   +-+         3+-+
+--R       (- 2%i\|3  + 6)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                        +----------+
+--R               +-+     3|   +-+
+--R         (- %i\|3  - 3)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+     +------------+
+--R            +-+     3|   +-+         3|     +-+         3+-+
+--R       (2%i\|3  + 6)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                             +------------+
+--R                     +----------+     3+-+2 3|     +-+
+--R          +-+       3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (6\|3  + 6%i)\|%i\|3  + 1 atan(-------------------------)
+--R                                                 +------------+
+--R                                       3+-+2 +-+3|     +-+
+--R                                       \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                               +----------+
+--R                     +------------+     3+-+2 3|   +-+
+--R          +-+       3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (6\|3  - 6%i)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                   +----------+
+--R                                         3+-+2 +-+3|   +-+
+--R                                         \|2  \|3 \|%i\|3  + 1
+--R  /
+--R              +------------+ +----------+
+--R       3+-+2 3|     +-+     3|   +-+
+--R     18\|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 862
+
+--S 863 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                           1                 1
+--R                    atan(----)        atan(----)
+--R                          +-+               +-+
+--R             +-+         \|3               \|3
+--R         (- \|3 sin(----------) - cos(----------))
+--R                         3                 3
+--R      *
+--R         log
+--R                         1   4                1   2                 1   2
+--R                  atan(----)           atan(----)            atan(----)
+--R                        +-+                  +-+                   +-+
+--R                       \|3                  \|3                   \|3
+--R              sin(----------)  + (2cos(----------)  + 2x)sin(----------)
+--R                       3                    3                     3
+--R            + 
+--R                         1   4                 1   2
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3                   \|3        2
+--R              cos(----------)  - 2x cos(----------)  + x
+--R                       3                     3
+--R     + 
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                               1              1                 1   4
+--R                        atan(----)     atan(----)        atan(----)
+--R                              +-+            +-+               +-+
+--R                 +-+         \|3            \|3               \|3
+--R              2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                             3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                         1                 1
+--R                  atan(----)        atan(----)
+--R                        +-+               +-+
+--R           +-+         \|3               \|3
+--R         (\|3 sin(----------) - cos(----------))
+--R                       3                 3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                                 1              1                 1   4
+--R                          atan(----)     atan(----)        atan(----)
+--R                                +-+            +-+               +-+
+--R                   +-+         \|3            \|3               \|3
+--R              - 2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                               3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         4sin(----------)
+--R                   3
+--R      *
+--R         atan
+--R                            1   2                   1              1
+--R                     atan(----)              atan(----)     atan(----)
+--R                           +-+                     +-+            +-+
+--R                          \|3         +-+         \|3            \|3
+--R                3sin(----------)  + 2\|3 cos(----------)sin(----------)
+--R                          3                       3              3
+--R              + 
+--R                              1   2
+--R                       atan(----)
+--R                             +-+
+--R                            \|3
+--R                - 3cos(----------)
+--R                            3
+--R           /
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  - 6cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3          +-+
+--R                - \|3 cos(----------)  - 2x\|3
+--R                               3
+--R     + 
+--R                      1                      1
+--R               atan(----)             atan(----)
+--R                     +-+                    +-+
+--R                    \|3        +-+         \|3
+--R         (2sin(----------) + 2\|3 cos(----------))
+--R                    3                      3
+--R      *
+--R         atan
+--R                            1   2                   1              1
+--R                     atan(----)              atan(----)     atan(----)
+--R                           +-+                     +-+            +-+
+--R                          \|3         +-+         \|3            \|3
+--R                3sin(----------)  - 2\|3 cos(----------)sin(----------)
+--R                          3                       3              3
+--R              + 
+--R                              1   2
+--R                       atan(----)
+--R                             +-+
+--R                            \|3
+--R                - 3cos(----------)
+--R                            3
+--R           /
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  + 6cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3          +-+
+--R                - \|3 cos(----------)  - 2x\|3
+--R                               3
+--R     + 
+--R                        1                      1
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|3        +-+         \|3
+--R         (- 2sin(----------) + 2\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R                              1              1
+--R                       atan(----)     atan(----)
+--R                             +-+            +-+
+--R                            \|3            \|3
+--R                  2cos(----------)sin(----------)
+--R                            3              3
+--R         atan(---------------------------------------)
+--R                         1   2              1   2
+--R                  atan(----)         atan(----)
+--R                        +-+                +-+
+--R                       \|3                \|3
+--R              sin(----------)  - cos(----------)  + x
+--R                       3                  3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 863
+
+--S 864 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +------------+
+--R           +-+      3|     +-+
+--R         (\|3  - %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +------------+     +----------+
+--R            +-+       3|     +-+         3|   +-+         3+-+
+--R       (- 2\|3  + 2%i)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                     +----------+
+--R           +-+      3|   +-+
+--R         (\|3  + %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +----------+     +------------+
+--R            +-+       3|   +-+         3|     +-+         3+-+
+--R       (- 2\|3  - 2%i)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                               +------------+ +----------+
+--R            3+-+2 +-+    %pi    3+-+2    %pi  3|     +-+     3|   +-+
+--R         (- \|2  \|3 sin(---) - \|2  cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                          18              18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2          %pi 2       %pi 4          %pi 2
+--R              sin(---)  + (2cos(---)  + 2x)sin(---)  + cos(---)  - 2x cos(---)
+--R                   18            18             18          18             18
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R                        +------------+ +----------+
+--R          3+-+2    %pi 3|     +-+     3|   +-+
+--R         2\|2  cos(---)\|- %i\|3  + 1 \|%i\|3  + 1
+--R                    18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2         %pi 2      +-+    %pi     %pi
+--R              sin(---)  + (2cos(---)  - x)sin(---)  + 2x\|3 cos(---)sin(---)
+--R                   18            18            18                18      18
+--R            + 
+--R                  %pi 4         %pi 2    2
+--R              cos(---)  + x cos(---)  + x
+--R                   18            18
+--R     + 
+--R                                             +------------+ +----------+
+--R          3+-+2 +-+    %pi    3+-+2    %pi  3|     +-+     3|   +-+
+--R         (\|2  \|3 sin(---) - \|2  cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                        18              18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2         %pi 2      +-+    %pi     %pi
+--R              sin(---)  + (2cos(---)  - x)sin(---)  - 2x\|3 cos(---)sin(---)
+--R                   18            18            18                18      18
+--R            + 
+--R                  %pi 4         %pi 2    2
+--R              cos(---)  + x cos(---)  + x
+--R                   18            18
+--R     + 
+--R                        +------------+ +----------+
+--R          3+-+2    %pi 3|     +-+     3|   +-+
+--R         4\|2  sin(---)\|- %i\|3  + 1 \|%i\|3  + 1
+--R                    18
+--R      *
+--R                         %pi 2     +-+    %pi     %pi         %pi 2
+--R                    3sin(---)  + 2\|3 cos(---)sin(---) - 3cos(---)
+--R                          18               18      18          18
+--R         atan(----------------------------------------------------------)
+--R               +-+    %pi 2        %pi     %pi     +-+    %pi 2      +-+
+--R              \|3 sin(---)  - 6cos(---)sin(---) - \|3 cos(---)  - 2x\|3
+--R                       18           18      18             18
+--R     + 
+--R                                               +------------+ +----------+
+--R           3+-+2    %pi     3+-+2 +-+    %pi  3|     +-+     3|   +-+
+--R         (2\|2  sin(---) + 2\|2  \|3 cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                     18                   18
+--R      *
+--R                         %pi 2     +-+    %pi     %pi         %pi 2
+--R                    3sin(---)  - 2\|3 cos(---)sin(---) - 3cos(---)
+--R                          18               18      18          18
+--R         atan(----------------------------------------------------------)
+--R               +-+    %pi 2        %pi     %pi     +-+    %pi 2      +-+
+--R              \|3 sin(---)  + 6cos(---)sin(---) - \|3 cos(---)  - 2x\|3
+--R                       18           18      18             18
+--R     + 
+--R                                               +------------+
+--R                       +----------+     3+-+2 3|     +-+
+--R              +-+     3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (- 2%i\|3  - 6)\|%i\|3  + 1 atan(-------------------------)
+--R                                                   +------------+
+--R                                         3+-+2 +-+3|     +-+
+--R                                         \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                               +----------+
+--R                     +------------+     3+-+2 3|   +-+
+--R            +-+     3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (2%i\|3  - 6)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                   +----------+
+--R                                         3+-+2 +-+3|   +-+
+--R                                         \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                 +------------+ +----------+
+--R             3+-+2    %pi     3+-+2 +-+    %pi  3|     +-+     3|   +-+
+--R         (- 2\|2  sin(---) + 2\|2  \|3 cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                       18                   18
+--R      *
+--R                       %pi     %pi
+--R                  2cos(---)sin(---)
+--R                        18      18
+--R         atan(-------------------------)
+--R                  %pi 2       %pi 2
+--R              sin(---)  - cos(---)  + x
+--R                   18          18
+--R  /
+--R                +------------+ +----------+
+--R      3+-+2 +-+3|     +-+     3|   +-+
+--R     6\|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 864
+
+--S 865 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                   8 3+-+    %pi 12     8 3+-+    %pi 2    %pi 10
+--R               - 6x  \|2 sin(---)  - 36x  \|2 cos(---) sin(---)
+--R                              18                   18       18
+--R             + 
+--R                  11     8     5 3+-+    %pi 9
+--R               (6x   - 6x  + 6x )\|2 sin(---)
+--R                                          18
+--R             + 
+--R                       8 3+-+    %pi 4       11     8     5 3+-+ +-+    %pi
+--R                 (- 90x  \|2 cos(---) + (- 6x   + 6x  - 6x )\|2 \|3 cos(---))
+--R                                  18                                     18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         8 3+-+    %pi 6
+--R                   - 120x  \|2 cos(---)
+--R                                    18
+--R                 + 
+--R                         11      8      5 3+-+ +-+    %pi 3      11 3+-+
+--R                   (- 16x   + 16x  - 16x )\|2 \|3 cos(---)  - 12x   \|2
+--R                                                       18
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     11      8      5 3+-+    %pi 4    %pi 5
+--R               (- 36x   + 36x  - 36x )\|2 cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                        8 3+-+    %pi 8
+--R                   - 90x  \|2 cos(---)
+--R                                   18
+--R                 + 
+--R                       11      8      5 3+-+ +-+    %pi 5       11 3+-+    %pi 2
+--R                 (- 12x   + 12x  - 12x )\|2 \|3 cos(---)  + 180x   \|2 cos(---)
+--R                                                     18                     18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           11      8      5 3+-+    %pi 6
+--R                     (- 48x   + 48x  - 48x )\|2 cos(---)
+--R                                                     18
+--R                   + 
+--R                        14     11     8 3+-+
+--R                     (6x   - 6x   + 6x )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        8 3+-+    %pi 10      11 3+-+    %pi 4
+--R                   - 36x  \|2 cos(---)  - 180x   \|2 cos(---)
+--R                                   18                     18
+--R                 + 
+--R                      14     11     8 3+-+ +-+    %pi
+--R                   (6x   - 6x   + 6x )\|2 \|3 cos(---)
+--R                                                   18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         11      8      5 3+-+    %pi 8
+--R                   (- 18x   + 18x  - 18x )\|2 cos(---)
+--R                                                   18
+--R                 + 
+--R                         14      11      8 3+-+    %pi 2
+--R                   (- 18x   + 18x   - 18x )\|2 cos(---)
+--R                                                    18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   8 3+-+    %pi 12     11     8     5 3+-+ +-+    %pi 9
+--R               - 6x  \|2 cos(---)  + (2x   - 2x  + 2x )\|2 \|3 cos(---)
+--R                              18                                    18
+--R             + 
+--R                  11 3+-+    %pi 6       14     11     8 3+-+ +-+    %pi 3
+--R               12x   \|2 cos(---) + (- 2x   + 2x   - 2x )\|2 \|3 cos(---)
+--R                              18                                      18
+--R             + 
+--R                   14 3+-+
+--R               - 6x   \|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                     6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (3%i x  \|2  \|3 - 3x  \|2 )sin(---)
+--R                                                18
+--R             + 
+--R                      6 3+-+2 +-+     6 3+-+2    %pi 2    %pi 10
+--R               (18%i x  \|2  \|3 - 18x  \|2 )cos(---) sin(---)
+--R                                                  18       18
+--R             + 
+--R                             9        6        3 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        9     6     3 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 9
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 4
+--R                   (45%i x  \|2  \|3 - 45x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 3x  + 3x  - 3x )\|2  \|3
+--R                     + 
+--R                             9        6        3 3+-+2
+--R                       (9%i x  - 9%i x  + 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 6
+--R                   (60%i x  \|2  \|3 - 60x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 8x  + 8x  - 8x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (24%i x  - 24%i x  + 24%i x )\|2
+--R                  *
+--R                         %pi 3
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                        9 3+-+2 +-+    9 3+-+2
+--R                   6%i x  \|2  \|3 - 6x  \|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          9         6         3 3+-+2 +-+
+--R                   (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                 + 
+--R                         9      6      3 3+-+2
+--R                   (- 18x  + 18x  - 18x )\|2
+--R              *
+--R                     %pi 4    %pi 5
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 8
+--R                   (45%i x  \|2  \|3 - 45x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 6x  + 6x  - 6x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (18%i x  - 18%i x  + 18%i x )\|2
+--R                  *
+--R                         %pi 5
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                            9 3+-+2 +-+     9 3+-+2    %pi 2
+--R                   (- 90%i x  \|2  \|3 + 90x  \|2 )cos(---)
+--R                                                        18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              9         6         3 3+-+2 +-+
+--R                       (24%i x  - 24%i x  + 24%i x )\|2  \|3
+--R                     + 
+--R                             9      6      3 3+-+2
+--R                       (- 24x  + 24x  - 24x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           12        9        6 3+-+2 +-+
+--R                   (- 3%i x   + 3%i x  - 3%i x )\|2  \|3
+--R                 + 
+--R                      12     9     6 3+-+2
+--R                   (3x   - 3x  + 3x )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 10
+--R                   (18%i x  \|2  \|3 - 18x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                          9 3+-+2 +-+     9 3+-+2    %pi 4
+--R                   (90%i x  \|2  \|3 - 90x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                          12     9     6 3+-+2 +-+
+--R                       (3x   - 3x  + 3x )\|2  \|3
+--R                     + 
+--R                               12        9        6 3+-+2
+--R                       (- 9%i x   + 9%i x  - 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                             9        6        3 3+-+2 +-+
+--R                       (9%i x  - 9%i x  + 9%i x )\|2  \|3
+--R                     + 
+--R                            9     6     3 3+-+2
+--R                       (- 9x  + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                             12        9        6 3+-+2 +-+
+--R                       (9%i x   - 9%i x  + 9%i x )\|2  \|3
+--R                     + 
+--R                            12     9     6 3+-+2
+--R                       (- 9x   + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (3%i x  \|2  \|3 - 3x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                    9    6    3 3+-+2 +-+           9        6        3 3+-+2
+--R                 ((x  - x  + x )\|2  \|3  + (- 3%i x  + 3%i x  - 3%i x )\|2  )
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       9 3+-+2 +-+    9 3+-+2    %pi 6
+--R               (- 6%i x  \|2  \|3 + 6x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                      12    9    6 3+-+2 +-+         12        9        6 3+-+2
+--R                 ((- x   + x  - x )\|2  \|3  + (3%i x   - 3%i x  + 3%i x )\|2  )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                    12 3+-+2 +-+    12 3+-+2
+--R               3%i x   \|2  \|3 - 3x   \|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 7 +-+     7     %pi 12
+--R           (6%i x \|3  - 6x )sin(---)
+--R                                  18
+--R         + 
+--R                  7 +-+      7     %pi 2    %pi 10
+--R           (36%i x \|3  - 36x )cos(---) sin(---)
+--R                                    18       18
+--R         + 
+--R                    10        7        4  +-+     10     7     4     %pi 9
+--R           ((- 6%i x   + 6%i x  - 6%i x )\|3  + 6x   - 6x  + 6x )sin(---)
+--R                                                                      18
+--R         + 
+--R                      7 +-+      7     %pi 4
+--R               (90%i x \|3  - 90x )cos(---)
+--R                                        18
+--R             + 
+--R                   10     7     4  +-+         10         7         4     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  + 18%i x   - 18%i x  + 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7 +-+       7     %pi 6
+--R               (120%i x \|3  - 120x )cos(---)
+--R                                          18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 16x   + 16x  - 16x )\|3  + 48%i x   - 48%i x  + 48%i x )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     10 +-+      10
+--R               12%i x  \|3  - 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     10         7         4  +-+      10      7      4     %pi 4
+--R             ((36%i x   - 36%i x  + 36%i x )\|3  - 36x   + 36x  - 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7 +-+      7     %pi 8
+--R               (90%i x \|3  - 90x )cos(---)
+--R                                        18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 12x   + 12x  - 12x )\|3  + 36%i x   - 36%i x  + 36%i x )
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         10 +-+       10     %pi 2
+--R               (- 180%i x  \|3  + 180x  )cos(---)
+--R                                              18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         10         7         4  +-+      10      7      4
+--R                 ((48%i x   - 48%i x  + 48%i x )\|3  - 48x   + 48x  - 48x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       13        10        7  +-+     13     10     7
+--R               (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7 +-+      7     %pi 10
+--R               (36%i x \|3  - 36x )cos(---)
+--R                                        18
+--R             + 
+--R                       10 +-+       10     %pi 4
+--R               (180%i x  \|3  - 180x  )cos(---)
+--R                                            18
+--R             + 
+--R                 13     10     7  +-+         13         10         7     %pi
+--R             ((6x   - 6x   + 6x )\|3  - 18%i x   + 18%i x   - 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         10         7         4  +-+      10      7      4
+--R                 ((18%i x   - 18%i x  + 18%i x )\|3  - 18x   + 18x  - 18x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         13         10         7  +-+      13      10      7
+--R                 ((18%i x   - 18%i x   + 18%i x )\|3  - 18x   + 18x   - 18x )
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 7 +-+     7     %pi 12
+--R           (6%i x \|3  - 6x )cos(---)
+--R                                  18
+--R         + 
+--R               10     7     4  +-+        10        7        4     %pi 9
+--R           ((2x   - 2x  + 2x )\|3  - 6%i x   + 6%i x  - 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                    10 +-+      10     %pi 6
+--R           (- 12%i x  \|3  + 12x  )cos(---)
+--R                                        18
+--R         + 
+--R                 13     10     7  +-+        13        10        7     %pi 3
+--R           ((- 2x   + 2x   - 2x )\|3  + 6%i x   - 6%i x   + 6%i x )cos(---)
+--R                                                                        18
+--R         + 
+--R                13 +-+     13
+--R           6%i x  \|3  - 6x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                       6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (- 3%i x  \|2  \|3 - 3x  \|2 )sin(---)
+--R                                                  18
+--R             + 
+--R                        6 3+-+2 +-+     6 3+-+2    %pi 2    %pi 10
+--R               (- 18%i x  \|2  \|3 - 18x  \|2 )cos(---) sin(---)
+--R                                                    18       18
+--R             + 
+--R                        9        6        3 3+-+2 +-+      9     6     3 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 9
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 4
+--R                   (- 45%i x  \|2  \|3 - 45x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 3x  + 3x  - 3x )\|2  \|3
+--R                     + 
+--R                               9        6        3 3+-+2
+--R                       (- 9%i x  + 9%i x  - 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 6
+--R                   (- 60%i x  \|2  \|3 - 60x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 8x  + 8x  - 8x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 24%i x  + 24%i x  - 24%i x )\|2
+--R                  *
+--R                         %pi 3
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                          9 3+-+2 +-+    9 3+-+2
+--R                   - 6%i x  \|2  \|3 - 6x  \|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            9         6         3 3+-+2 +-+
+--R                   (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                 + 
+--R                         9      6      3 3+-+2
+--R                   (- 18x  + 18x  - 18x )\|2
+--R              *
+--R                     %pi 4    %pi 5
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 8
+--R                   (- 45%i x  \|2  \|3 - 45x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 6x  + 6x  - 6x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 18%i x  + 18%i x  - 18%i x )\|2
+--R                  *
+--R                         %pi 5
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                          9 3+-+2 +-+     9 3+-+2    %pi 2
+--R                   (90%i x  \|2  \|3 + 90x  \|2 )cos(---)
+--R                                                      18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                9         6         3 3+-+2 +-+
+--R                       (- 24%i x  + 24%i x  - 24%i x )\|2  \|3
+--R                     + 
+--R                             9      6      3 3+-+2
+--R                       (- 24x  + 24x  - 24x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                       12        9        6 3+-+2 +-+      12     9     6 3+-+2
+--R                 (3%i x   - 3%i x  + 3%i x )\|2  \|3  + (3x   - 3x  + 3x )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 10
+--R                   (- 18%i x  \|2  \|3 - 18x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9 3+-+2 +-+     9 3+-+2    %pi 4
+--R                   (- 90%i x  \|2  \|3 - 90x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                          12     9     6 3+-+2 +-+
+--R                       (3x   - 3x  + 3x )\|2  \|3
+--R                     + 
+--R                             12        9        6 3+-+2
+--R                       (9%i x   - 9%i x  + 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               9        6        3 3+-+2 +-+
+--R                       (- 9%i x  + 9%i x  - 9%i x )\|2  \|3
+--R                     + 
+--R                            9     6     3 3+-+2
+--R                       (- 9x  + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                               12        9        6 3+-+2 +-+
+--R                       (- 9%i x   + 9%i x  - 9%i x )\|2  \|3
+--R                     + 
+--R                            12     9     6 3+-+2
+--R                       (- 9x   + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (- 3%i x  \|2  \|3 - 3x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                    9    6    3 3+-+2 +-+         9        6        3 3+-+2
+--R                 ((x  - x  + x )\|2  \|3  + (3%i x  - 3%i x  + 3%i x )\|2  )
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     9 3+-+2 +-+    9 3+-+2    %pi 6
+--R               (6%i x  \|2  \|3 + 6x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                         12    9    6 3+-+2 +-+
+--R                     (- x   + x  - x )\|2  \|3
+--R                   + 
+--R                             12        9        6 3+-+2
+--R                     (- 3%i x   + 3%i x  - 3%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      12 3+-+2 +-+    12 3+-+2
+--R               - 3%i x   \|2  \|3 - 3x   \|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    4    %pi 12      4    %pi 2    %pi 10
+--R               - 12x sin(---)   - 72x cos(---) sin(---)
+--R                          18               18       18
+--R             + 
+--R                   7      4           %pi 9
+--R               (12x  - 12x  + 12x)sin(---)
+--R                                       18
+--R             + 
+--R                      4    %pi 4         7      4        +-+    %pi      %pi 8
+--R               (- 180x cos(---)  + (- 12x  + 12x  - 12x)\|3 cos(---))sin(---)
+--R                            18                                   18       18
+--R             + 
+--R                        4    %pi 6         7      4        +-+    %pi 3      7
+--R                 (- 240x cos(---)  + (- 32x  + 32x  - 32x)\|3 cos(---)  - 24x )
+--R                              18                                   18
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     7      4           %pi 4    %pi 5
+--R               (- 72x  + 72x  - 72x)cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                         4    %pi 8         7      4        +-+    %pi 5
+--R                   - 180x cos(---)  + (- 24x  + 24x  - 24x)\|3 cos(---)
+--R                               18                                   18
+--R                 + 
+--R                       7    %pi 2
+--R                   360x cos(---)
+--R                             18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                      7      4           %pi 6      10      7      4     %pi 3
+--R               ((- 96x  + 96x  - 96x)cos(---)  + 12x   - 12x  + 12x )sin(---)
+--R                                          18                              18
+--R             + 
+--R                        4    %pi 10       7    %pi 4
+--R                   - 72x cos(---)   - 360x cos(---)
+--R                              18                18
+--R                 + 
+--R                       10      7      4  +-+    %pi
+--R                   (12x   - 12x  + 12x )\|3 cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         7      4           %pi 8
+--R                   (- 36x  + 36x  - 36x)cos(---)
+--R                                             18
+--R                 + 
+--R                         10      7      4     %pi 2
+--R                   (- 36x   + 36x  - 36x )cos(---)
+--R                                               18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    4    %pi 12      7     4       +-+    %pi 9      7    %pi 6
+--R               - 12x cos(---)   + (4x  - 4x  + 4x)\|3 cos(---)  + 24x cos(---)
+--R                          18                               18              18
+--R             + 
+--R                    10     7     4  +-+    %pi 3      10
+--R               (- 4x   + 4x  - 4x )\|3 cos(---)  - 12x
+--R                                            18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                5 3+-+    %pi 12     5 3+-+    %pi 2    %pi 10
+--R           - 12x  \|2 sin(---)  - 72x  \|2 cos(---) sin(---)
+--R                           18                   18       18
+--R         + 
+--R               8      5      2 3+-+    %pi 9
+--R           (12x  - 12x  + 12x )\|2 sin(---)
+--R                                        18
+--R         + 
+--R                    5 3+-+    %pi 4        8      5      2 3+-+ +-+    %pi
+--R             (- 180x  \|2 cos(---) + (- 12x  + 12x  - 12x )\|2 \|3 cos(---))
+--R                               18                                       18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     5 3+-+    %pi 6        8      5      2 3+-+ +-+    %pi 3
+--R               - 240x  \|2 cos(---) + (- 32x  + 32x  - 32x )\|2 \|3 cos(---)
+--R                                18                                       18
+--R             + 
+--R                    8 3+-+
+--R               - 24x  \|2
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 8      5      2 3+-+    %pi 4    %pi 5
+--R           (- 72x  + 72x  - 72x )\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                     5 3+-+    %pi 8        8      5      2 3+-+ +-+    %pi 5
+--R               - 180x  \|2 cos(---) + (- 24x  + 24x  - 24x )\|2 \|3 cos(---)
+--R                                18                                       18
+--R             + 
+--R                   8 3+-+    %pi 2
+--R               360x  \|2 cos(---)
+--R                              18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8      5      2 3+-+    %pi 6       11      8      5 3+-+
+--R             ((- 96x  + 96x  - 96x )\|2 cos(---)  + (12x   - 12x  + 12x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    5 3+-+    %pi 10      8 3+-+    %pi 4
+--R               - 72x  \|2 cos(---)  - 360x  \|2 cos(---)
+--R                               18                    18
+--R             + 
+--R                   11      8      5 3+-+ +-+    %pi
+--R               (12x   - 12x  + 12x )\|2 \|3 cos(---)
+--R                                                 18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     8      5      2 3+-+    %pi 8
+--R               (- 36x  + 36x  - 36x )\|2 cos(---)
+--R                                              18
+--R             + 
+--R                     11      8      5 3+-+    %pi 2
+--R               (- 36x   + 36x  - 36x )\|2 cos(---)
+--R                                               18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                5 3+-+    %pi 12     8     5     2 3+-+ +-+    %pi 9
+--R           - 12x  \|2 cos(---)  + (4x  - 4x  + 4x )\|2 \|3 cos(---)
+--R                           18                                   18
+--R         + 
+--R            8 3+-+    %pi 6       11     8     5 3+-+ +-+    %pi 3      11 3+-+
+--R         24x  \|2 cos(---) + (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  - 12x   \|2
+--R                       18                                     18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                   7 +-+     7     %pi 12
+--R           (- 6%i x \|3  - 6x )sin(---)
+--R                                    18
+--R         + 
+--R                    7 +-+      7     %pi 2    %pi 10
+--R           (- 36%i x \|3  - 36x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                  10        7        4  +-+     10     7     4     %pi 9
+--R           ((6%i x   - 6%i x  + 6%i x )\|3  + 6x   - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                        7 +-+      7     %pi 4
+--R               (- 90%i x \|3  - 90x )cos(---)
+--R                                          18
+--R             + 
+--R                   10     7     4  +-+         10         7         4     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  - 18%i x   + 18%i x  - 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         7 +-+       7     %pi 6
+--R               (- 120%i x \|3  - 120x )cos(---)
+--R                                            18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 16x   + 16x  - 16x )\|3  - 48%i x   + 48%i x  - 48%i x )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       10 +-+      10
+--R               - 12%i x  \|3  - 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       10         7         4  +-+      10      7      4
+--R             ((- 36%i x   + 36%i x  - 36%i x )\|3  - 36x   + 36x  - 36x )
+--R          *
+--R                 %pi 4    %pi 5
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                        7 +-+      7     %pi 8
+--R               (- 90%i x \|3  - 90x )cos(---)
+--R                                          18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 12x   + 12x  - 12x )\|3  - 36%i x   + 36%i x  - 36%i x )
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       10 +-+       10     %pi 2
+--R               (180%i x  \|3  + 180x  )cos(---)
+--R                                            18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           10         7         4  +-+      10      7      4
+--R                 ((- 48%i x   + 48%i x  - 48%i x )\|3  - 48x   + 48x  - 48x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     13        10        7  +-+     13     10     7
+--R               (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        7 +-+      7     %pi 10
+--R               (- 36%i x \|3  - 36x )cos(---)
+--R                                          18
+--R             + 
+--R                         10 +-+       10     %pi 4
+--R               (- 180%i x  \|3  - 180x  )cos(---)
+--R                                              18
+--R             + 
+--R                 13     10     7  +-+         13         10         7     %pi
+--R             ((6x   - 6x   + 6x )\|3  + 18%i x   - 18%i x   + 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           10         7         4  +-+      10      7      4
+--R                 ((- 18%i x   + 18%i x  - 18%i x )\|3  - 18x   + 18x  - 18x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           13         10         7  +-+      13      10      7
+--R                 ((- 18%i x   + 18%i x   - 18%i x )\|3  - 18x   + 18x   - 18x )
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7 +-+     7     %pi 12
+--R           (- 6%i x \|3  - 6x )cos(---)
+--R                                    18
+--R         + 
+--R               10     7     4  +-+        10        7        4     %pi 9
+--R           ((2x   - 2x  + 2x )\|3  + 6%i x   - 6%i x  + 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                  10 +-+      10     %pi 6
+--R           (12%i x  \|3  + 12x  )cos(---)
+--R                                      18
+--R         + 
+--R                 13     10     7  +-+        13        10        7     %pi 3
+--R           ((- 2x   + 2x   - 2x )\|3  - 6%i x   + 6%i x   - 6%i x )cos(---)
+--R                                                                        18
+--R         + 
+--R                  13 +-+     13
+--R           - 6%i x  \|3  - 6x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                5 3+-+    %pi 12     5 3+-+    %pi 2    %pi 10
+--R           - 12x  \|2 sin(---)  - 72x  \|2 cos(---) sin(---)
+--R                           18                   18       18
+--R         + 
+--R               8      5      2 3+-+    %pi 9
+--R           (12x  - 12x  + 12x )\|2 sin(---)
+--R                                        18
+--R         + 
+--R                    5 3+-+    %pi 4        8      5      2 3+-+ +-+    %pi
+--R             (- 180x  \|2 cos(---) + (- 12x  + 12x  - 12x )\|2 \|3 cos(---))
+--R                               18                                       18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     5 3+-+    %pi 6        8      5      2 3+-+ +-+    %pi 3
+--R               - 240x  \|2 cos(---) + (- 32x  + 32x  - 32x )\|2 \|3 cos(---)
+--R                                18                                       18
+--R             + 
+--R                    8 3+-+
+--R               - 24x  \|2
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 8      5      2 3+-+    %pi 4    %pi 5
+--R           (- 72x  + 72x  - 72x )\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                     5 3+-+    %pi 8        8      5      2 3+-+ +-+    %pi 5
+--R               - 180x  \|2 cos(---) + (- 24x  + 24x  - 24x )\|2 \|3 cos(---)
+--R                                18                                       18
+--R             + 
+--R                   8 3+-+    %pi 2
+--R               360x  \|2 cos(---)
+--R                              18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8      5      2 3+-+    %pi 6       11      8      5 3+-+
+--R             ((- 96x  + 96x  - 96x )\|2 cos(---)  + (12x   - 12x  + 12x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    5 3+-+    %pi 10      8 3+-+    %pi 4
+--R               - 72x  \|2 cos(---)  - 360x  \|2 cos(---)
+--R                               18                    18
+--R             + 
+--R                   11      8      5 3+-+ +-+    %pi
+--R               (12x   - 12x  + 12x )\|2 \|3 cos(---)
+--R                                                 18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     8      5      2 3+-+    %pi 8
+--R               (- 36x  + 36x  - 36x )\|2 cos(---)
+--R                                              18
+--R             + 
+--R                     11      8      5 3+-+    %pi 2
+--R               (- 36x   + 36x  - 36x )\|2 cos(---)
+--R                                               18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                5 3+-+    %pi 12     8     5     2 3+-+ +-+    %pi 9
+--R           - 12x  \|2 cos(---)  + (4x  - 4x  + 4x )\|2 \|3 cos(---)
+--R                           18                                   18
+--R         + 
+--R            8 3+-+    %pi 6       11     8     5 3+-+ +-+    %pi 3      11 3+-+
+--R         24x  \|2 cos(---) + (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  - 12x   \|2
+--R                       18                                     18
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R            6 3+-+2    %pi 12     6 3+-+2    %pi 2    %pi 10
+--R       - 12x  \|2  sin(---)  - 72x  \|2  cos(---) sin(---)
+--R                        18                    18       18
+--R     + 
+--R           9      6      3 3+-+2    %pi 9
+--R       (12x  - 12x  + 12x )\|2  sin(---)
+--R                                     18
+--R     + 
+--R                6 3+-+2    %pi 4        9      6      3 3+-+2 +-+    %pi
+--R         (- 180x  \|2  cos(---) + (- 12x  + 12x  - 12x )\|2  \|3 cos(---))
+--R                            18                                        18
+--R      *
+--R             %pi 8
+--R         sin(---)
+--R              18
+--R     + 
+--R                 6 3+-+2    %pi 6        9      6      3 3+-+2 +-+    %pi 3
+--R           - 240x  \|2  cos(---) + (- 32x  + 32x  - 32x )\|2  \|3 cos(---)
+--R                             18                                        18
+--R         + 
+--R                9 3+-+2
+--R           - 24x  \|2
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R             9      6      3 3+-+2    %pi 4    %pi 5
+--R       (- 72x  + 72x  - 72x )\|2  cos(---) sin(---)
+--R                                       18       18
+--R     + 
+--R                 6 3+-+2    %pi 8        9      6      3 3+-+2 +-+    %pi 5
+--R           - 180x  \|2  cos(---) + (- 24x  + 24x  - 24x )\|2  \|3 cos(---)
+--R                             18                                        18
+--R         + 
+--R               9 3+-+2    %pi 2
+--R           360x  \|2  cos(---)
+--R                           18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R                9      6      3 3+-+2    %pi 6       12      9      6 3+-+2
+--R         ((- 96x  + 96x  - 96x )\|2  cos(---)  + (12x   - 12x  + 12x )\|2  )
+--R                                          18
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              18
+--R     + 
+--R                6 3+-+2    %pi 10      9 3+-+2    %pi 4
+--R           - 72x  \|2  cos(---)  - 360x  \|2  cos(---)
+--R                            18                     18
+--R         + 
+--R               12      9      6 3+-+2 +-+    %pi
+--R           (12x   - 12x  + 12x )\|2  \|3 cos(---)
+--R                                              18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R                 9      6      3 3+-+2    %pi 8
+--R           (- 36x  + 36x  - 36x )\|2  cos(---)
+--R                                           18
+--R         + 
+--R                 12      9      6 3+-+2    %pi 2
+--R           (- 36x   + 36x  - 36x )\|2  cos(---)
+--R                                            18
+--R      *
+--R             %pi
+--R         sin(---)
+--R              18
+--R     + 
+--R            6 3+-+2    %pi 12     9     6     3 3+-+2 +-+    %pi 9
+--R       - 12x  \|2  cos(---)  + (4x  - 4x  + 4x )\|2  \|3 cos(---)
+--R                        18                                    18
+--R     + 
+--R          9 3+-+2    %pi 6       12     9     6 3+-+2 +-+    %pi 3      12 3+-+2
+--R       24x  \|2  cos(---) + (- 4x   + 4x  - 4x )\|2  \|3 cos(---)  - 12x   \|2
+--R                      18                                      18
+--R  /
+--R                  10     7     4 3+-+    %pi 12
+--R               (6x   - 6x  + 6x )\|2 sin(---)
+--R                                          18
+--R             + 
+--R                   10      7      4 3+-+    %pi 2    %pi 10
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                   10      7      4 3+-+    %pi 4    %pi 8
+--R               (90x   - 90x  + 90x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                        10       7       4 3+-+    %pi 6
+--R                   (120x   - 120x  + 120x )\|2 cos(---)
+--R                                                    18
+--R                 + 
+--R                       13      10      7 3+-+
+--R                   (12x   - 12x   + 12x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       10      7      4 3+-+    %pi 8
+--R                   (90x   - 90x  + 90x )\|2 cos(---)
+--R                                                 18
+--R                 + 
+--R                          13       10       7 3+-+    %pi 2
+--R                   (- 180x   + 180x   - 180x )\|2 cos(---)
+--R                                                       18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       10      7      4 3+-+    %pi 10
+--R                   (36x   - 36x  + 36x )\|2 cos(---)
+--R                                                 18
+--R                 + 
+--R                        13       10       7 3+-+    %pi 4
+--R                   (180x   - 180x   + 180x )\|2 cos(---)
+--R                                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                  10     7     4 3+-+    %pi 12
+--R               (6x   - 6x  + 6x )\|2 cos(---)
+--R                                          18
+--R             + 
+--R                     13      10      7 3+-+    %pi 6      16     13     10 3+-+
+--R               (- 12x   + 12x   - 12x )\|2 cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 12
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            8         5         2 3+-+2 +-+
+--R                   (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (18x  - 18x  + 18x )\|2
+--R              *
+--R                     %pi 2    %pi 10
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                            8         5         2 3+-+2 +-+
+--R                   (- 45%i x  + 45%i x  - 45%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (45x  - 45x  + 45x )\|2
+--R              *
+--R                     %pi 4    %pi 8
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 60%i x  + 60%i x  - 60%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (60x  - 60x  + 60x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           11        8        5 3+-+2 +-+
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R                 + 
+--R                      11     8     5 3+-+2
+--R                   (6x   - 6x  + 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 45%i x  + 45%i x  - 45%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (45x  - 45x  + 45x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (90%i x   - 90%i x  + 90%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 90x   + 90x  - 90x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (18x  - 18x  + 18x )\|2
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 90%i x   + 90%i x  - 90%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (90x   - 90x  + 90x )\|2
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 12
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         11        8        5 3+-+2 +-+
+--R                   (6%i x   - 6%i x  + 6%i x )\|2  \|3
+--R                 + 
+--R                        11     8     5 3+-+2
+--R                   (- 6x   + 6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     14        11        8 3+-+2 +-+      14     11     8 3+-+2
+--R             (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    9        6        3  +-+     9     6     3     %pi 12
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 2
+--R             ((- 36%i x  + 36%i x  - 36%i x )\|3  + 36x  - 36x  + 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 4
+--R             ((- 90%i x  + 90%i x  - 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                               9          6          3  +-+       9       6
+--R                     (- 120%i x  + 120%i x  - 120%i x )\|3  + 120x  - 120x
+--R                   + 
+--R                         3
+--R                     120x
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        12         9         6  +-+      12      9      6
+--R               (- 12%i x   + 12%i x  - 12%i x )\|3  + 12x   - 12x  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 90%i x  + 90%i x  - 90%i x )\|3  + 90x  - 90x  + 90x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                     (180%i x   - 180%i x  + 180%i x )\|3  - 180x   + 180x
+--R                   + 
+--R                           6
+--R                     - 180x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 36%i x  + 36%i x  - 36%i x )\|3  + 36x  - 36x  + 36x )
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                   (- 180%i x   + 180%i x  - 180%i x )\|3  + 180x   - 180x
+--R                 + 
+--R                       6
+--R                   180x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    9        6        3  +-+     9     6     3     %pi 12
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   12         9         6  +-+      12      9      6     %pi 6
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  - 12x   + 12x  - 12x )cos(---)
+--R                                                                          18
+--R         + 
+--R                   15        12        9  +-+     15     12     9
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 12
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          8         5         2 3+-+2 +-+
+--R                   (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (18x  - 18x  + 18x )\|2
+--R              *
+--R                     %pi 2    %pi 10
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                          8         5         2 3+-+2 +-+
+--R                   (45%i x  - 45%i x  + 45%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (45x  - 45x  + 45x )\|2
+--R              *
+--R                     %pi 4    %pi 8
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (60%i x  - 60%i x  + 60%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (60x  - 60x  + 60x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                       11        8        5 3+-+2 +-+      11     8     5 3+-+2
+--R                 (6%i x   - 6%i x  + 6%i x )\|2  \|3  + (6x   - 6x  + 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (45%i x  - 45%i x  + 45%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (45x  - 45x  + 45x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 90%i x   + 90%i x  - 90%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 90x   + 90x  - 90x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (18x  - 18x  + 18x )\|2
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (90%i x   - 90%i x  + 90%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (90x   - 90x  + 90x )\|2
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 12
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           11        8        5 3+-+2 +-+
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R                 + 
+--R                        11     8     5 3+-+2
+--R                   (- 6x   + 6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     14        11        8 3+-+2 +-+      14     11     8 3+-+2
+--R               (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   6      3          %pi 12
+--R               (12x  - 12x  + 12)sin(---)
+--R                                      18
+--R             + 
+--R                   6      3          %pi 2    %pi 10
+--R               (72x  - 72x  + 72)cos(---) sin(---)
+--R                                      18       18
+--R             + 
+--R                    6       3           %pi 4    %pi 8
+--R               (180x  - 180x  + 180)cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                     6       3           %pi 6      9      6      3     %pi 6
+--R               ((240x  - 240x  + 240)cos(---)  + 24x  - 24x  + 24x )sin(---)
+--R                                          18                             18
+--R             + 
+--R                        6       3           %pi 8
+--R                   (180x  - 180x  + 180)cos(---)
+--R                                             18
+--R                 + 
+--R                          9       6       3     %pi 2
+--R                   (- 360x  + 360x  - 360x )cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         6      3          %pi 10
+--R                     (72x  - 72x  + 72)cos(---)
+--R                                            18
+--R                   + 
+--R                          9       6       3     %pi 4
+--R                     (360x  - 360x  + 360x )cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   6      3          %pi 12         9      6      3     %pi 6
+--R               (12x  - 12x  + 12)cos(---)   + (- 24x  + 24x  - 24x )cos(---)
+--R                                      18                                 18
+--R             + 
+--R                  12      9      6
+--R               12x   - 12x  + 12x
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 sin(---)
+--R                                       18
+--R         + 
+--R               7      4       3+-+    %pi 2    %pi 10
+--R           (72x  - 72x  + 72x)\|2 cos(---) sin(---)
+--R                                       18       18
+--R         + 
+--R                7       4        3+-+    %pi 4    %pi 8
+--R           (180x  - 180x  + 180x)\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   7       4        3+-+    %pi 6       10      7      4 3+-+
+--R             ((240x  - 240x  + 240x)\|2 cos(---)  + (24x   - 24x  + 24x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7       4        3+-+    %pi 8
+--R               (180x  - 180x  + 180x)\|2 cos(---)
+--R                                              18
+--R             + 
+--R                      10       7       4 3+-+    %pi 2
+--R               (- 360x   + 360x  - 360x )\|2 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7      4       3+-+    %pi 10
+--R               (72x  - 72x  + 72x)\|2 cos(---)
+--R                                           18
+--R             + 
+--R                    10       7       4 3+-+    %pi 4
+--R               (360x   - 360x  + 360x )\|2 cos(---)
+--R                                                18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 cos(---)
+--R                                       18
+--R         + 
+--R                 10      7      4 3+-+    %pi 6       13      10      7 3+-+
+--R           (- 24x   + 24x  - 24x )\|2 cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                           18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9        6        3  +-+     9     6     3     %pi 12
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     9         6         3  +-+      9      6      3     %pi 2
+--R             ((36%i x  - 36%i x  + 36%i x )\|3  + 36x  - 36x  + 36x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     9         6         3  +-+      9      6      3     %pi 4
+--R             ((90%i x  - 90%i x  + 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          9          6          3  +-+       9       6       3
+--R                 ((120%i x  - 120%i x  + 120%i x )\|3  + 120x  - 120x  + 120x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      12         9         6  +-+      12      9      6
+--R               (12%i x   - 12%i x  + 12%i x )\|3  + 12x   - 12x  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 8
+--R               ((90%i x  - 90%i x  + 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                            18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                   (- 180%i x   + 180%i x  - 180%i x )\|3  - 180x   + 180x
+--R                 + 
+--R                         6
+--R                   - 180x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         9         6         3  +-+      9      6      3
+--R                 ((36%i x  - 36%i x  + 36%i x )\|3  + 36x  - 36x  + 36x )
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                     (180%i x   - 180%i x  + 180%i x )\|3  + 180x   - 180x
+--R                   + 
+--R                         6
+--R                     180x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  9        6        3  +-+     9     6     3     %pi 12
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                     12         9         6  +-+      12      9      6     %pi 6
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  - 12x   + 12x  - 12x )cos(---)
+--R                                                                            18
+--R         + 
+--R                 15        12        9  +-+     15     12     9
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 sin(---)
+--R                                       18
+--R         + 
+--R               7      4       3+-+    %pi 2    %pi 10
+--R           (72x  - 72x  + 72x)\|2 cos(---) sin(---)
+--R                                       18       18
+--R         + 
+--R                7       4        3+-+    %pi 4    %pi 8
+--R           (180x  - 180x  + 180x)\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   7       4        3+-+    %pi 6       10      7      4 3+-+
+--R             ((240x  - 240x  + 240x)\|2 cos(---)  + (24x   - 24x  + 24x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7       4        3+-+    %pi 8
+--R               (180x  - 180x  + 180x)\|2 cos(---)
+--R                                              18
+--R             + 
+--R                      10       7       4 3+-+    %pi 2
+--R               (- 360x   + 360x  - 360x )\|2 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7      4       3+-+    %pi 10
+--R               (72x  - 72x  + 72x)\|2 cos(---)
+--R                                           18
+--R             + 
+--R                    10       7       4 3+-+    %pi 4
+--R               (360x   - 360x  + 360x )\|2 cos(---)
+--R                                                18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 cos(---)
+--R                                       18
+--R         + 
+--R                 10      7      4 3+-+    %pi 6       13      10      7 3+-+
+--R           (- 24x   + 24x  - 24x )\|2 cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                           18
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           8      5      2 3+-+2    %pi 12
+--R       (12x  - 12x  + 12x )\|2  sin(---)
+--R                                     18
+--R     + 
+--R           8      5      2 3+-+2    %pi 2    %pi 10
+--R       (72x  - 72x  + 72x )\|2  cos(---) sin(---)
+--R                                     18       18
+--R     + 
+--R            8       5       2 3+-+2    %pi 4    %pi 8
+--R       (180x  - 180x  + 180x )\|2  cos(---) sin(---)
+--R                                        18       18
+--R     + 
+--R               8       5       2 3+-+2    %pi 6       11      8      5 3+-+2
+--R         ((240x  - 240x  + 240x )\|2  cos(---)  + (24x   - 24x  + 24x )\|2  )
+--R                                           18
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R                8       5       2 3+-+2    %pi 8
+--R           (180x  - 180x  + 180x )\|2  cos(---)
+--R                                            18
+--R         + 
+--R                  11       8       5 3+-+2    %pi 2
+--R           (- 360x   + 360x  - 360x )\|2  cos(---)
+--R                                               18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R               8      5      2 3+-+2    %pi 10
+--R           (72x  - 72x  + 72x )\|2  cos(---)
+--R                                         18
+--R         + 
+--R                11       8       5 3+-+2    %pi 4
+--R           (360x   - 360x  + 360x )\|2  cos(---)
+--R                                             18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R           8      5      2 3+-+2    %pi 12
+--R       (12x  - 12x  + 12x )\|2  cos(---)
+--R                                     18
+--R     + 
+--R             11      8      5 3+-+2    %pi 6       14      11      8 3+-+2
+--R       (- 24x   + 24x  - 24x )\|2  cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                        18
+--R                                           Type: Expression(Complex(Integer))
+--E 865
+
+)clear all
+
+--S 866 of 2282
+t0:=x^3/(1-x^3+x^6)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 866
+
+--S 867 of 2282
+r0:=1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))+_
+   1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*_
+   sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3))+1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3+%i*_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/3*atan((4*x+2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))*_
+   (%i+sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))
+--R 
+--R
+--R   (2)
+--R                      +------------+2
+--R             +-+     3|     +-+
+--R         (%i\|3  - 3)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +------------+2     +----------+
+--R              +-+     3|     +-+          3|   +-+         3+-+
+--R       (- 2%i\|3  + 6)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                        +----------+2
+--R               +-+     3|   +-+
+--R         (- %i\|3  - 3)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+2     +------------+
+--R            +-+     3|   +-+          3|     +-+         3+-+
+--R       (2%i\|3  + 6)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                +------------+
+--R                       +----------+2     3+-+2 3|     +-+
+--R            +-+       3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (- 6\|3  - 6%i)\|%i\|3  + 1  atan(-------------------------)
+--R                                                    +------------+
+--R                                          3+-+2 +-+3|     +-+
+--R                                          \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                  +----------+
+--R                       +------------+2     3+-+2 3|   +-+
+--R            +-+       3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (- 6\|3  + 6%i)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                      +----------+
+--R                                            3+-+2 +-+3|   +-+
+--R                                            \|2  \|3 \|%i\|3  + 1
+--R  /
+--R            +------------+2  +----------+2
+--R       3+-+3|     +-+       3|   +-+
+--R     18\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 867
+
+--S 868 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         1                 1
+--R                  atan(----)        atan(----)
+--R                        +-+               +-+
+--R           +-+         \|3               \|3
+--R         (\|3 sin(----------) - cos(----------))
+--R                       3                 3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                              1
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            3
+--R     + 
+--R                           1                 1
+--R                    atan(----)        atan(----)
+--R                          +-+               +-+
+--R             +-+         \|3               \|3
+--R         (- \|3 sin(----------) - cos(----------))
+--R                         3                 3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                                1
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              3
+--R     + 
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   3
+--R      *
+--R                        1   2                 1                 1   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                      3                     3                 3
+--R     + 
+--R                        1                      1
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|3        +-+         \|3
+--R         (- 2sin(----------) + 2\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) + cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) - \|3 cos(----------) + 2x
+--R                       3                     3
+--R     + 
+--R                      1                      1
+--R               atan(----)             atan(----)
+--R                     +-+                    +-+
+--R                    \|3        +-+         \|3
+--R         (2sin(----------) + 2\|3 cos(----------))
+--R                    3                      3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) - cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) + \|3 cos(----------) + 2x
+--R                       3                     3
+--R     + 
+--R                                         1
+--R                                  atan(----)
+--R                   1                    +-+
+--R            atan(----)                 \|3
+--R                  +-+         cos(----------)
+--R                 \|3                   3
+--R       4sin(----------)atan(-------------------)
+--R                 3                     1
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------) - x
+--R                                     3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 868
+
+--S 869 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +------------+2
+--R           +-+      3|     +-+
+--R         (\|3  - %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +------------+2     +----------+
+--R            +-+       3|     +-+          3|   +-+         3+-+
+--R       (- 2\|3  + 2%i)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                     +----------+2
+--R           +-+      3|   +-+
+--R         (\|3  + %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +----------+2     +------------+
+--R            +-+       3|   +-+          3|     +-+         3+-+
+--R       (- 2\|3  - 2%i)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                           +------------+2  +----------+2
+--R          3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (\|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                       18             18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  + x sin(---) + cos(---)  + x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                                             +------------+2  +----------+2
+--R            3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (- \|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                         18             18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  + x sin(---) + cos(---)  - x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                       +------------+2  +----------+2
+--R          3+-+    %pi 3|     +-+       3|   +-+
+--R         2\|2 cos(---)\|- %i\|3  + 1   \|%i\|3  + 1
+--R                   18
+--R      *
+--R                 %pi 2          %pi        %pi 2    2
+--R         log(sin(---)  - 2x sin(---) + cos(---)  + x )
+--R                  18             18         18
+--R     + 
+--R                                               +------------+2  +----------+2
+--R             3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (- 2\|2 sin(---) + 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18                  18
+--R      *
+--R                  +-+    %pi        %pi
+--R                 \|3 sin(---) + cos(---)
+--R                          18         18
+--R         atan(----------------------------)
+--R                  %pi     +-+    %pi
+--R              sin(---) - \|3 cos(---) + 2x
+--R                   18             18
+--R     + 
+--R                                             +------------+2  +----------+2
+--R           3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (2\|2 sin(---) + 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                    18                  18
+--R      *
+--R                  +-+    %pi        %pi
+--R                 \|3 sin(---) - cos(---)
+--R                          18         18
+--R         atan(----------------------------)
+--R                  %pi     +-+    %pi
+--R              sin(---) + \|3 cos(---) + 2x
+--R                   18             18
+--R     + 
+--R                                              +------------+
+--R                     +----------+2     3+-+2 3|     +-+
+--R            +-+     3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (2%i\|3  + 6)\|%i\|3  + 1  atan(-------------------------)
+--R                                                  +------------+
+--R                                        3+-+2 +-+3|     +-+
+--R                                        \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                  +----------+
+--R                       +------------+2     3+-+2 3|   +-+
+--R              +-+     3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (- 2%i\|3  + 6)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                      +----------+
+--R                                            3+-+2 +-+3|   +-+
+--R                                            \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                              %pi
+--R                     +------------+2  +----------+2       cos(---)
+--R        3+-+    %pi 3|     +-+       3|   +-+                  18
+--R       4\|2 sin(---)\|- %i\|3  + 1   \|%i\|3  + 1  atan(------------)
+--R                 18                                         %pi
+--R                                                        sin(---) - x
+--R                                                             18
+--R  /
+--R               +------------+2  +----------+2
+--R      3+-+ +-+3|     +-+       3|   +-+
+--R     6\|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 869
+
+--S 870 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                   5    %pi 6      5    %pi 2    %pi 4      8    %pi 3
+--R               - 6x sin(---)  - 18x cos(---) sin(---)  + 12x sin(---)
+--R                         18              18       18              18
+--R             + 
+--R                     5    %pi 4       11      8      5  +-+    %pi      %pi 2
+--R               (- 18x cos(---)  + (12x   - 12x  + 12x )\|3 cos(---))sin(---)
+--R                           18                                   18       18
+--R             + 
+--R                    8    %pi 2    %pi      5    %pi 6
+--R               - 36x cos(---) sin(---) - 6x cos(---)
+--R                          18       18            18
+--R             + 
+--R                    11     8     5  +-+    %pi 3     11
+--R               (- 4x   + 4x  - 4x )\|3 cos(---)  - 6x
+--R                                            18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   6 3+-+    %pi 6     6 3+-+    %pi 2    %pi 4
+--R               - 6x  \|2 sin(---) - 18x  \|2 cos(---) sin(---)
+--R                              18                  18       18
+--R             + 
+--R                  9 3+-+    %pi 3
+--R               12x  \|2 sin(---)
+--R                             18
+--R             + 
+--R                       6 3+-+    %pi 4      12      9      6 3+-+ +-+    %pi
+--R                 (- 18x  \|2 cos(---) + (12x   - 12x  + 12x )\|2 \|3 cos(---))
+--R                                  18                                      18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    9 3+-+    %pi 2    %pi     6 3+-+    %pi 6
+--R               - 36x  \|2 cos(---) sin(--- - 6x  \|2 cos(---)
+--R                               18       18                18
+--R             + 
+--R                    12     9     6 3+-+ +-+    %pi 3     12 3+-+
+--R               (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  - 6x   \|2
+--R                                                18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 - 3x  \|2 )sin(---)
+--R                                            18
+--R         + 
+--R                 4 3+-+2 +-+    4 3+-+2    %pi 2    %pi 4
+--R           (9%i x  \|2  \|3 - 9x  \|2 )cos(---) sin(---)
+--R                                            18       18
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 3
+--R           (- 6%i x  \|2  \|3 + 6x  \|2 )sin(---)
+--R                                              18
+--R         + 
+--R                     4 3+-+2 +-+    4 3+-+2    %pi 4
+--R               (9%i x  \|2  \|3 - 9x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                      10     7     4 3+-+2 +-+
+--R                   (6x   - 6x  + 6x )\|2  \|3
+--R                 + 
+--R                            10         7         4 3+-+2
+--R                   (- 18%i x   + 18%i x  - 18%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  7 3+-+2 +-+     7 3+-+2    %pi 2    %pi
+--R           (18%i x  \|2  \|3 - 18x  \|2 )cos(---) sin(---)
+--R                                              18       18
+--R         + 
+--R                 4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 - 3x  \|2 )cos(---)
+--R                                            18
+--R         + 
+--R                   10     7     4 3+-+2 +-+         10        7        4 3+-+2
+--R             ((- 2x   + 2x  - 2x )\|2  \|3  + (6%i x   - 6%i x  + 6%i x )\|2  )
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                10 3+-+2 +-+    10 3+-+2
+--R           3%i x   \|2  \|3 - 3x   \|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                   6 3+-+    %pi 6     6 3+-+    %pi 2    %pi 4
+--R               - 6x  \|2 sin(---) - 18x  \|2 cos(---) sin(---)
+--R                              18                  18       18
+--R             + 
+--R                  9 3+-+    %pi 3
+--R               12x  \|2 sin(---)
+--R                             18
+--R             + 
+--R                       6 3+-+    %pi 4      12      9      6 3+-+ +-+    %pi
+--R                 (- 18x  \|2 cos(---) + (12x   - 12x  + 12x )\|2 \|3 cos(---))
+--R                                  18                                      18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    9 3+-+    %pi 2    %pi     6 3+-+    %pi 6
+--R               - 36x  \|2 cos(---) sin(--- - 6x  \|2 cos(---)
+--R                               18       18                18
+--R             + 
+--R                    12     9     6 3+-+ +-+    %pi 3     12 3+-+
+--R               (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  - 6x   \|2
+--R                                                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   7 3+-+2    %pi 6     7 3+-+2    %pi 2    %pi 4
+--R               - 6x  \|2  sin(---) - 18x  \|2  cos(---) sin(---)
+--R                               18                   18       18
+--R             + 
+--R                  10 3+-+2    %pi 3
+--R               12x   \|2  sin(---)
+--R                               18
+--R             + 
+--R                          7 3+-+2    %pi 4
+--R                     - 18x  \|2  cos(---)
+--R                                      18
+--R                   + 
+--R                         13      10      7 3+-+2 +-+    %pi
+--R                     (12x   - 12x   + 12x )\|2  \|3 cos(---)
+--R                                                         18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    10 3+-+2    %pi 2    %pi     7 3+-+2    %pi 6
+--R               - 36x   \|2  cos(---) sin(--- - 6x  \|2  cos(---)
+--R                                 18       18                 18
+--R             + 
+--R                    13     10     7 3+-+2 +-+    %pi 3     13 3+-+2
+--R               (- 4x   + 4x   - 4x )\|2  \|3 cos(---)  - 6x   \|2
+--R                                                  18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 5 +-+     5     %pi 6          5 +-+      5     %pi 2    %pi 4
+--R           (6%i x \|3  - 6x )sin(---)  + (18%i x \|3  - 18x )cos(---) sin(---)
+--R                                  18                              18       18
+--R         + 
+--R                    8 +-+      8     %pi 3
+--R           (- 12%i x \|3  + 12x )sin(---)
+--R                                      18
+--R         + 
+--R                      5 +-+      5     %pi 4
+--R               (18%i x \|3  - 18x )cos(---)
+--R                                        18
+--R             + 
+--R                  11      8      5  +-+         11         8         5     %pi
+--R             ((12x   - 12x  + 12x )\|3  - 36%i x   + 36%i x  - 36%i x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  8 +-+      8     %pi 2    %pi          5 +-+     5     %pi 6
+--R           (36%i x \|3  - 36x )cos(---) sin(---) + (6%i x \|3  - 6x )cos(---)
+--R                                    18       18                           18
+--R         + 
+--R                 11     8     5  +-+         11         8         5     %pi 3
+--R           ((- 4x   + 4x  - 4x )\|3  + 12%i x   - 12%i x  + 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                11 +-+     11
+--R           6%i x  \|3  - 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                   4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 - 3x  \|2 )sin(---)
+--R                                              18
+--R         + 
+--R                   4 3+-+2 +-+    4 3+-+2    %pi 2    %pi 4
+--R           (- 9%i x  \|2  \|3 - 9x  \|2 )cos(---) sin(---)
+--R                                              18       18
+--R         + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 3
+--R           (6%i x  \|2  \|3 + 6x  \|2 )sin(---)
+--R                                            18
+--R         + 
+--R                       4 3+-+2 +-+    4 3+-+2    %pi 4
+--R               (- 9%i x  \|2  \|3 - 9x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                      10     7     4 3+-+2 +-+
+--R                   (6x   - 6x  + 6x )\|2  \|3
+--R                 + 
+--R                          10         7         4 3+-+2
+--R                   (18%i x   - 18%i x  + 18%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7 3+-+2 +-+     7 3+-+2    %pi 2    %pi
+--R           (- 18%i x  \|2  \|3 - 18x  \|2 )cos(---) sin(---)
+--R                                                18       18
+--R         + 
+--R                   4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 - 3x  \|2 )cos(---)
+--R                                              18
+--R         + 
+--R                      10     7     4 3+-+2 +-+
+--R                 (- 2x   + 2x  - 2x )\|2  \|3
+--R               + 
+--R                         10        7        4 3+-+2
+--R                 (- 6%i x   + 6%i x  - 6%i x )\|2
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                  10 3+-+2 +-+    10 3+-+2
+--R           - 3%i x   \|2  \|3 - 3x   \|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                   5 +-+     5     %pi 6
+--R           (- 6%i x \|3  - 6x )sin(---)
+--R                                    18
+--R         + 
+--R                    5 +-+      5     %pi 2    %pi 4
+--R           (- 18%i x \|3  - 18x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                  8 +-+      8     %pi 3
+--R           (12%i x \|3  + 12x )sin(---)
+--R                                    18
+--R         + 
+--R                        5 +-+      5     %pi 4
+--R               (- 18%i x \|3  - 18x )cos(---)
+--R                                          18
+--R             + 
+--R                  11      8      5  +-+         11         8         5     %pi
+--R             ((12x   - 12x  + 12x )\|3  + 36%i x   - 36%i x  + 36%i x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8 +-+      8     %pi 2    %pi
+--R           (- 36%i x \|3  - 36x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                   5 +-+     5     %pi 6
+--R           (- 6%i x \|3  - 6x )cos(---)
+--R                                    18
+--R         + 
+--R                 11     8     5  +-+         11         8         5     %pi 3
+--R           ((- 4x   + 4x  - 4x )\|3  - 12%i x   + 12%i x  - 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                  11 +-+     11
+--R           - 6%i x  \|3  - 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R            3 3+-+    %pi 6     3 3+-+    %pi 2    %pi 4     6 3+-+    %pi 3
+--R       - 12x  \|2 sin(---) - 36x  \|2 cos(---) sin(---) + 24x  \|2 sin(---)
+--R                       18                  18       18                  18
+--R     + 
+--R             3 3+-+    %pi 4      9      6      3 3+-+ +-+    %pi      %pi 2
+--R       (- 36x  \|2 cos(---) + (24x  - 24x  + 24x )\|2 \|3 cos(---))sin(---)
+--R                        18                                     18       18
+--R     + 
+--R            6 3+-+    %pi 2    %pi      3 3+-+    %pi 6
+--R       - 72x  \|2 cos(---) sin(--- - 12x  \|2 cos(---)
+--R                       18       18                 18
+--R     + 
+--R            9     6     3 3+-+ +-+    %pi 3      9 3+-+
+--R       (- 8x  + 8x  - 8x )\|2 \|3 cos(---)  - 12x  \|2
+--R                                       18
+--R  /
+--R                  8     5     2     %pi 6
+--R               (6x  - 6x  + 6x )sin(---)
+--R                                     18
+--R             + 
+--R                   8      5      2     %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                     11      8      5     %pi 3
+--R               (- 12x   + 12x  - 12x )sin(---)
+--R                                           18
+--R             + 
+--R                   8      5      2     %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                   11      8      5     %pi 2    %pi
+--R               (36x   - 36x  + 36x )cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                  8     5     2     %pi 6     14     11     8
+--R               (6x  - 6x  + 6x )cos(---)  + 6x   - 6x   + 6x
+--R                                     18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 3
+--R               (- 12x   + 12x  - 12x )\|2 sin(---)
+--R                                               18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                    10        7        4 3+-+2 +-+        10     7     4 3+-+2
+--R             ((6%i x   - 6%i x  + 6%i x )\|2  \|3  + (- 6x   + 6x  - 6x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                        10         7         4 3+-+2 +-+
+--R               (- 18%i x   + 18%i x  - 18%i x )\|2  \|3
+--R             + 
+--R                   10      7      4 3+-+2
+--R               (18x   - 18x  + 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 3
+--R               (- 12x   + 12x  - 12x )\|2 sin(---)
+--R                                               18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  10     7     4 3+-+2    %pi 6
+--R               (6x   - 6x  + 6x )\|2  sin(---)
+--R                                           18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 2    %pi 4
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                     13      10      7 3+-+2    %pi 3
+--R               (- 12x   + 12x   - 12x )\|2  sin(---)
+--R                                                 18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 4    %pi 2
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                   13      10      7 3+-+2    %pi 2    %pi
+--R               (36x   - 36x   + 36x )\|2  cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                  10     7     4 3+-+2    %pi 6      16     13     10 3+-+2
+--R               (6x   - 6x  + 6x )\|2  cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                           18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 2
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   11         8         5  +-+      11      8      5     %pi 3
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  - 12x   + 12x  - 12x )sin(---)
+--R                                                                          18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 4
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       11         8         5  +-+      11      8      5
+--R             ((- 36%i x   + 36%i x  - 36%i x )\|3  + 36x   - 36x  + 36x )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   14        11        8  +-+     14     11     8
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )sin(---)
+--R                                                                            18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                         10        7        4 3+-+2 +-+
+--R                 (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R               + 
+--R                      10     7     4 3+-+2
+--R                 (- 6x   + 6x  - 6x )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      10         7         4 3+-+2 +-+
+--R               (18%i x   - 18%i x  + 18%i x )\|2  \|3
+--R             + 
+--R                   10      7      4 3+-+2
+--R               (18x   - 18x  + 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )cos(---)
+--R                                                                            18
+--R         + 
+--R                 13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 2
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 3
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  - 12x   + 12x  - 12x )sin(---)
+--R                                                                            18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 4
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 2
+--R             ((36%i x   - 36%i x  + 36%i x )\|3  + 36x   - 36x  + 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                 14        11        8  +-+     14     11     8
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           6      3      3+-+    %pi 6
+--R       (12x  - 12x  + 12)\|2 sin(---)
+--R                                  18
+--R     + 
+--R           6      3      3+-+    %pi 2    %pi 4
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R             9      6      3 3+-+    %pi 3
+--R       (- 24x  + 24x  - 24x )\|2 sin(---)
+--R                                      18
+--R     + 
+--R           6      3      3+-+    %pi 4    %pi 2
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R           9      6      3 3+-+    %pi 2    %pi
+--R       (72x  - 72x  + 72x )\|2 cos(---) sin(---)
+--R                                    18       18
+--R     + 
+--R           6      3      3+-+    %pi 6       12      9      6 3+-+
+--R       (12x  - 12x  + 12)\|2 cos(---)  + (12x   - 12x  + 12x )\|2
+--R                                  18
+--R                                           Type: Expression(Complex(Integer))
+--E 870
+
+)clear all
+
+--S 871 of 2282
+t0:=x^2/(1-x^3+x^6)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 871
+
+--S 872 of 2282
+r0:=-2/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                 3      +-+
+--R              (2x  - 1)\|3
+--R        2atan(-------------)
+--R                    3
+--R   (2)  --------------------
+--R                  +-+
+--R                3\|3
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 3      +-+
+--R              (2x  - 1)\|3
+--R        2atan(-------------)
+--R                    3
+--R   (3)  --------------------
+--R                  +-+
+--R                3\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 873
+
+--S 874 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 874
+
+--S 875 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 875
+
+)clear all
+
+--S 876 of 2282
+t0:=x/(1-x^3+x^6)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 876
+
+--S 877 of 2282
+r0:=1/3*%i*2^(1/3)*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3)*sqrt(3)))/(1-%i*sqrt(3))^(1/3)-1/3*%i*2^(1/3)*_
+   atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*_
+   sqrt(3)))/(1+%i*sqrt(3))^(1/3)+1/3*%i*2^(1/3)*log(-2^(1/3)*x+(1-%i*_
+   sqrt(3))^(1/3))/((1-%i*sqrt(3))^(1/3)*sqrt(3))-1/3*%i*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3)*sqrt(3))-1/3*%i*2^(1/3)*log(-2^(1/3)*x+_
+   (1+%i*sqrt(3))^(1/3))/((1+%i*sqrt(3))^(1/3)*sqrt(3))+1/3*%i*_
+   log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))/_
+   (2^(2/3)*(1+%i*sqrt(3))^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +------------+     +----------+2         +----------+
+--R       1   3|     +-+         3|   +-+          3+-+3|   +-+         2 3+-+2
+--R       - %i\|- %i\|3  + 1 log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R       3
+--R     + 
+--R              +------------+     +----------+
+--R         2   3|     +-+         3|   +-+         3+-+
+--R       - - %i\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R         3
+--R     + 
+--R              +----------+     +------------+2         +------------+
+--R         1   3|   +-+         3|     +-+          3+-+3|     +-+         2 3+-+2
+--R       - - %i\|%i\|3  + 1 log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R         3
+--R     + 
+--R            +----------+     +------------+
+--R       2   3|   +-+         3|     +-+         3+-+
+--R       - %i\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R       3
+--R     + 
+--R                                        +------------+
+--R                +----------+     3+-+2 3|     +-+
+--R       2    +-+3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       - %i\|3 \|%i\|3  + 1 atan(-------------------------)
+--R       3                                    +------------+
+--R                                  3+-+2 +-+3|     +-+
+--R                                  \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                            +----------+
+--R                  +------------+     3+-+2 3|   +-+
+--R         2    +-+3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       - - %i\|3 \|- %i\|3  + 1 atan(-----------------------)
+--R         3                                      +----------+
+--R                                      3+-+2 +-+3|   +-+
+--R                                      \|2  \|3 \|%i\|3  + 1
+--R  /
+--R               +------------+ +----------+
+--R     3+-+2 +-+3|     +-+     3|   +-+
+--R     \|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 877
+
+--S 878 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         1                 1
+--R                  atan(----)        atan(----)
+--R                        +-+               +-+
+--R           +-+         \|3               \|3
+--R         (\|3 sin(----------) - cos(----------))
+--R                       3                 3
+--R      *
+--R         log
+--R                         1   4                1   2                 1   2
+--R                  atan(----)           atan(----)            atan(----)
+--R                        +-+                  +-+                   +-+
+--R                       \|3                  \|3                   \|3
+--R              sin(----------)  + (2cos(----------)  + 2x)sin(----------)
+--R                       3                    3                     3
+--R            + 
+--R                         1   4                 1   2
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3                   \|3        2
+--R              cos(----------)  - 2x cos(----------)  + x
+--R                       3                     3
+--R     + 
+--R                           1                 1
+--R                    atan(----)        atan(----)
+--R                          +-+               +-+
+--R             +-+         \|3               \|3
+--R         (- \|3 sin(----------) - cos(----------))
+--R                         3                 3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                               1              1                 1   4
+--R                        atan(----)     atan(----)        atan(----)
+--R                              +-+            +-+               +-+
+--R                 +-+         \|3            \|3               \|3
+--R              2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                             3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                                 1              1                 1   4
+--R                          atan(----)     atan(----)        atan(----)
+--R                                +-+            +-+               +-+
+--R                   +-+         \|3            \|3               \|3
+--R              - 2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                               3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                        1                      1
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|3        +-+         \|3
+--R         (- 2sin(----------) + 2\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R         atan
+--R                            1   2                   1              1
+--R                     atan(----)              atan(----)     atan(----)
+--R                           +-+                     +-+            +-+
+--R                          \|3         +-+         \|3            \|3
+--R                3sin(----------)  + 2\|3 cos(----------)sin(----------)
+--R                          3                       3              3
+--R              + 
+--R                              1   2
+--R                       atan(----)
+--R                             +-+
+--R                            \|3
+--R                - 3cos(----------)
+--R                            3
+--R           /
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  - 6cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3          +-+
+--R                - \|3 cos(----------)  - 2x\|3
+--R                               3
+--R     + 
+--R       -
+--R                        1
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            4sin(----------)
+--R                      3
+--R         *
+--R            atan
+--R                               1   2                   1              1
+--R                        atan(----)              atan(----)     atan(----)
+--R                              +-+                     +-+            +-+
+--R                             \|3         +-+         \|3            \|3
+--R                   3sin(----------)  - 2\|3 cos(----------)sin(----------)
+--R                             3                       3              3
+--R                 + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                   - 3cos(----------)
+--R                               3
+--R              /
+--R                                  1   2               1              1
+--R                           atan(----)          atan(----)     atan(----)
+--R                                 +-+                 +-+            +-+
+--R                    +-+         \|3                 \|3            \|3
+--R                   \|3 sin(----------)  + 6cos(----------)sin(----------)
+--R                                3                   3              3
+--R                 + 
+--R                                    1   2
+--R                             atan(----)
+--R                                   +-+
+--R                      +-+         \|3          +-+
+--R                   - \|3 cos(----------)  - 2x\|3
+--R                                  3
+--R     + 
+--R                        1                      1
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|3        +-+         \|3
+--R         (- 2sin(----------) - 2\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R                              1              1
+--R                       atan(----)     atan(----)
+--R                             +-+            +-+
+--R                            \|3            \|3
+--R                  2cos(----------)sin(----------)
+--R                            3              3
+--R         atan(---------------------------------------)
+--R                         1   2              1   2
+--R                  atan(----)         atan(----)
+--R                        +-+                +-+
+--R                       \|3                \|3
+--R              sin(----------)  - cos(----------)  + x
+--R                       3                  3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 878
+
+--S 879 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +------------+     +----------+2         +----------+
+--R         1   3|     +-+         3|   +-+          3+-+3|   +-+         2 3+-+2
+--R       - - %i\|- %i\|3  + 1 log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R         3
+--R     + 
+--R            +------------+     +----------+
+--R       2   3|     +-+         3|   +-+         3+-+
+--R       - %i\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R       3
+--R     + 
+--R            +----------+     +------------+2         +------------+
+--R       1   3|   +-+         3|     +-+          3+-+3|     +-+         2 3+-+2
+--R       - %i\|%i\|3  + 1 log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R       3
+--R     + 
+--R              +----------+     +------------+
+--R         2   3|   +-+         3|     +-+         3+-+
+--R       - - %i\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R         3
+--R     + 
+--R                                                       +------------+
+--R          1 3+-+2 +-+     1        1 3+-+2     1      3|     +-+
+--R         (- \|2  \|3 sin(-- %pi) - - \|2  cos(-- %pi))\|- %i\|3  + 1
+--R          6              18        6          18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R      *
+--R         log
+--R                   1     4          1     2           1     2        1     4
+--R              sin(-- %pi)  + (2cos(-- %pi)  + 2x)sin(-- %pi)  + cos(-- %pi)
+--R                  18               18                18             18
+--R            + 
+--R                        1     2    2
+--R              - 2x cos(-- %pi)  + x
+--R                       18
+--R     + 
+--R                                                         +------------+
+--R            1 3+-+2 +-+     1        1 3+-+2     1      3|     +-+
+--R         (- - \|2  \|3 sin(-- %pi) - - \|2  cos(-- %pi))\|- %i\|3  + 1
+--R            6              18        6          18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R      *
+--R         log
+--R                   1     4          1     2          1     2
+--R              sin(-- %pi)  + (2cos(-- %pi)  - x)sin(-- %pi)
+--R                  18               18               18
+--R            + 
+--R                 +-+     1          1             1     4          1     2    2
+--R              2x\|3 cos(-- %pi)sin(-- %pi) + cos(-- %pi)  + x cos(-- %pi)  + x
+--R                        18         18            18               18
+--R     + 
+--R                            +------------+ +----------+
+--R         1 3+-+2     1     3|     +-+     3|   +-+
+--R         - \|2  cos(-- %pi)\|- %i\|3  + 1 \|%i\|3  + 1
+--R         3          18
+--R      *
+--R         log
+--R                   1     4          1     2          1     2
+--R              sin(-- %pi)  + (2cos(-- %pi)  - x)sin(-- %pi)
+--R                  18               18               18
+--R            + 
+--R                 +-+     1          1             1     4          1     2    2
+--R            - 2x\|3 cos(-- %pi)sin(-- %pi) + cos(-- %pi)  + x cos(-- %pi)  + x
+--R                        18         18            18               18
+--R     + 
+--R                                                         +------------+
+--R            1 3+-+2     1        1 3+-+2 +-+     1      3|     +-+
+--R         (- - \|2  sin(-- %pi) + - \|2  \|3 cos(-- %pi))\|- %i\|3  + 1
+--R            3          18        3              18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R      *
+--R         atan
+--R                    1     2     +-+     1          1              1     2
+--R              3sin(-- %pi)  + 2\|3 cos(-- %pi)sin(-- %pi) - 3cos(-- %pi)
+--R                   18                  18         18             18
+--R           /
+--R                 +-+     1     2         1          1         +-+     1     2
+--R                \|3 sin(-- %pi)  - 6cos(-- %pi)sin(-- %pi) - \|3 cos(-- %pi)
+--R                        18              18         18                18
+--R              + 
+--R                     +-+
+--R                - 2x\|3
+--R     + 
+--R       -
+--R                               +------------+ +----------+
+--R            2 3+-+2     1     3|     +-+     3|   +-+
+--R            - \|2  sin(-- %pi)\|- %i\|3  + 1 \|%i\|3  + 1
+--R            3          18
+--R         *
+--R            atan
+--R                       1     2     +-+     1          1              1     2
+--R                 3sin(-- %pi)  - 2\|3 cos(-- %pi)sin(-- %pi) - 3cos(-- %pi)
+--R                      18                  18         18             18
+--R              /
+--R                    +-+     1     2         1          1         +-+     1     2
+--R                   \|3 sin(-- %pi)  + 6cos(-- %pi)sin(-- %pi) - \|3 cos(-- %pi)
+--R                           18              18         18                18
+--R                 + 
+--R                        +-+
+--R                   - 2x\|3
+--R     + 
+--R                                          +------------+
+--R                  +----------+     3+-+2 3|     +-+
+--R         2    +-+3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       - - %i\|3 \|%i\|3  + 1 atan(-------------------------)
+--R         3                                    +------------+
+--R                                    3+-+2 +-+3|     +-+
+--R                                    \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                          +----------+
+--R                +------------+     3+-+2 3|   +-+
+--R       2    +-+3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       - %i\|3 \|- %i\|3  + 1 atan(-----------------------)
+--R       3                                      +----------+
+--R                                    3+-+2 +-+3|   +-+
+--R                                    \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                         +------------+
+--R            1 3+-+2     1        1 3+-+2 +-+     1      3|     +-+
+--R         (- - \|2  sin(-- %pi) - - \|2  \|3 cos(-- %pi))\|- %i\|3  + 1
+--R            3          18        3              18
+--R      *
+--R                                     1          1
+--R          +----------+         2cos(-- %pi)sin(-- %pi)
+--R         3|   +-+                   18         18
+--R         \|%i\|3  + 1 atan(-------------------------------)
+--R                                1     2        1     2
+--R                           sin(-- %pi)  - cos(-- %pi)  + x
+--R                               18             18
+--R  /
+--R               +------------+ +----------+
+--R     3+-+2 +-+3|     +-+     3|   +-+
+--R     \|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 879
+
+--S 880 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                  5 3+-+     1     12    5 3+-+     1     2     1     10
+--R               - x  \|2 sin(-- %pi)  - 6x  \|2 cos(-- %pi) sin(-- %pi)
+--R                            18                     18          18
+--R             + 
+--R                   11    8    5 3+-+     1     9
+--R               (- x   + x  - x )\|2 sin(-- %pi)
+--R                                        18
+--R             + 
+--R                       5 3+-+     1     4      11    8    5 3+-+ +-+     1
+--R                 (- 15x  \|2 cos(-- %pi) + (- x   + x  - x )\|2 \|3 cos(-- %pi))
+--R                                 18                                     18
+--R              *
+--R                      1     8
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                        5 3+-+     1     6
+--R                   - 20x  \|2 cos(-- %pi)
+--R                                  18
+--R                 + 
+--R                      8  11   8  8   8  5 3+-+ +-+     1     3     8 3+-+
+--R                   (- - x   + - x  - - x )\|2 \|3 cos(-- %pi)  - 2x  \|2
+--R                      3       3      3                18
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                  11     8     5 3+-+     1     4     1     5
+--R               (6x   - 6x  + 6x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                         18          18
+--R             + 
+--R                        5 3+-+     1     8
+--R                   - 15x  \|2 cos(-- %pi)
+--R                                  18
+--R                 + 
+--R                      11     8     5 3+-+ +-+     1     5      8 3+-+     1     2
+--R                 (- 2x   + 2x  - 2x )\|2 \|3 cos(-- %pi)  + 30x  \|2 cos(-- %pi)
+--R                                                 18                      18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                     11     8     5 3+-+     1     6       14    11    8 3+-+
+--R                 ((8x   - 8x  + 8x )\|2 cos(-- %pi)  + (- x   + x   - x )\|2 )
+--R                                            18
+--R              *
+--R                      1     3
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                       5 3+-+     1     10     8 3+-+     1     4
+--R                   - 6x  \|2 cos(-- %pi)  - 30x  \|2 cos(-- %pi)
+--R                                 18                      18
+--R                 + 
+--R                     14    11    8 3+-+ +-+     1
+--R                   (x   - x   + x )\|2 \|3 cos(-- %pi)
+--R                                               18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                      11     8     5 3+-+     1     8
+--R                   (3x   - 3x  + 3x )\|2 cos(-- %pi)
+--R                                             18
+--R                 + 
+--R                      14     11     8 3+-+     1     2
+--R                   (3x   - 3x   + 3x )\|2 cos(-- %pi)
+--R                                              18
+--R              *
+--R                      1
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                  5 3+-+     1     12   1  11   1  8   1  5 3+-+ +-+     1     9
+--R               - x  \|2 cos(-- %pi)  + (- x   - - x  + - x )\|2 \|3 cos(-- %pi)
+--R                            18          3       3      3                18
+--R             + 
+--R                 8 3+-+     1     6
+--R               2x  \|2 cos(-- %pi)
+--R                           18
+--R             + 
+--R                  1  14   1  11   1  8 3+-+ +-+     1     3    11 3+-+
+--R               (- - x   + - x   - - x )\|2 \|3 cos(-- %pi)  - x   \|2
+--R                  3       3       3                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                1     3 3+-+2 +-+  1  3 3+-+2     1     12
+--R               (- %i x  \|2  \|3 - - x  \|2 )sin(-- %pi)
+--R                2                  2             18
+--R             + 
+--R                     3 3+-+2 +-+    3 3+-+2     1     2     1     10
+--R               (3%i x  \|2  \|3 - 3x  \|2 )cos(-- %pi) sin(-- %pi)
+--R                                               18          18
+--R             + 
+--R                    1     9   1     6   1     3 3+-+2 +-+
+--R                   (- %i x  - - %i x  + - %i x )\|2  \|3
+--R                    2         2         2
+--R                 + 
+--R                      1  9   1  6   1  3 3+-+2
+--R                   (- - x  + - x  - - x )\|2
+--R                      2      2      2
+--R              *
+--R                      1     9
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                    15     3 3+-+2 +-+  15  3 3+-+2     1     4
+--R                   (-- %i x  \|2  \|3 - -- x  \|2 )cos(-- %pi)
+--R                     2                   2             18
+--R                 + 
+--R                          1  9   1  6   1  3 3+-+2 +-+
+--R                       (- - x  + - x  - - x )\|2  \|3
+--R                          2      2      2
+--R                     + 
+--R                        3     9   3     6   3     3 3+-+2
+--R                       (- %i x  - - %i x  + - %i x )\|2
+--R                        2         2         2
+--R                  *
+--R                          1
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     8
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                          3 3+-+2 +-+     3 3+-+2     1     6
+--R                   (10%i x  \|2  \|3 - 10x  \|2 )cos(-- %pi)
+--R                                                     18
+--R                 + 
+--R                          4  9   4  6   4  3 3+-+2 +-+
+--R                       (- - x  + - x  - - x )\|2  \|3
+--R                          3      3      3
+--R                     + 
+--R                             9        6        3 3+-+2
+--R                       (4%i x  - 4%i x  + 4%i x )\|2
+--R                  *
+--R                          1     3
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                       6 3+-+2 +-+   6 3+-+2
+--R                   %i x  \|2  \|3 - x  \|2
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                             9        6        3 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        9     6     3 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                      1     4     1     5
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                    15     3 3+-+2 +-+  15  3 3+-+2     1     8
+--R                   (-- %i x  \|2  \|3 - -- x  \|2 )cos(-- %pi)
+--R                     2                   2             18
+--R                 + 
+--R                             9    6    3 3+-+2 +-+
+--R                         (- x  + x  - x )\|2  \|3
+--R                       + 
+--R                               9        6        3 3+-+2
+--R                         (3%i x  - 3%i x  + 3%i x )\|2
+--R                  *
+--R                          1     5
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                            6 3+-+2 +-+     6 3+-+2     1     2
+--R                   (- 15%i x  \|2  \|3 + 15x  \|2 )cos(-- %pi)
+--R                                                       18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                               9        6        3 3+-+2 +-+
+--R                       (- 4%i x  + 4%i x  - 4%i x )\|2  \|3
+--R                     + 
+--R                          9     6     3 3+-+2
+--R                       (4x  - 4x  + 4x )\|2
+--R                  *
+--R                          1     6
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                    1     12   1     9   1     6 3+-+2 +-+
+--R                   (- %i x   - - %i x  + - %i x )\|2  \|3
+--R                    2          2         2
+--R                 + 
+--R                      1  12   1  9   1  6 3+-+2
+--R                   (- - x   + - x  - - x )\|2
+--R                      2       2      2
+--R              *
+--R                      1     3
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                         3 3+-+2 +-+    3 3+-+2     1     10
+--R                   (3%i x  \|2  \|3 - 3x  \|2 )cos(-- %pi)
+--R                                                   18
+--R                 + 
+--R                          6 3+-+2 +-+     6 3+-+2     1     4
+--R                   (15%i x  \|2  \|3 - 15x  \|2 )cos(-- %pi)
+--R                                                     18
+--R                 + 
+--R                        1  12   1  9   1  6 3+-+2 +-+
+--R                       (- x   - - x  + - x )\|2  \|3
+--R                        2       2      2
+--R                     + 
+--R                          3     12   3     9   3     6 3+-+2
+--R                       (- - %i x   + - %i x  - - %i x )\|2
+--R                          2          2         2
+--R                  *
+--R                          1
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                          3     9   3     6   3     3 3+-+2 +-+
+--R                       (- - %i x  + - %i x  - - %i x )\|2  \|3
+--R                          2         2         2
+--R                     + 
+--R                        3  9   3  6   3  3 3+-+2
+--R                       (- x  - - x  + - x )\|2
+--R                        2      2      2
+--R                  *
+--R                          1     8
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                          3     12   3     9   3     6 3+-+2 +-+
+--R                       (- - %i x   + - %i x  - - %i x )\|2  \|3
+--R                          2          2         2
+--R                     + 
+--R                        3  12   3  9   3  6 3+-+2
+--R                       (- x   - - x  + - x )\|2
+--R                        2       2      2
+--R                  *
+--R                          1     2
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                1     3 3+-+2 +-+  1  3 3+-+2     1     12
+--R               (- %i x  \|2  \|3 - - x  \|2 )cos(-- %pi)
+--R                2                  2             18
+--R             + 
+--R                    1  9   1  6   1  3 3+-+2 +-+
+--R                   (- x  - - x  + - x )\|2  \|3
+--R                    6      6      6
+--R                 + 
+--R                      1     9   1     6   1     3 3+-+2
+--R                   (- - %i x  + - %i x  - - %i x )\|2
+--R                      2         2         2
+--R              *
+--R                      1     9
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                      6 3+-+2 +-+   6 3+-+2     1     6
+--R               (- %i x  \|2  \|3 + x  \|2 )cos(-- %pi)
+--R                                               18
+--R             + 
+--R                      1  12   1  9   1  6 3+-+2 +-+
+--R                   (- - x   + - x  - - x )\|2  \|3
+--R                      6       6      6
+--R                 + 
+--R                    1     12   1     9   1     6 3+-+2
+--R                   (- %i x   - - %i x  + - %i x )\|2
+--R                    2          2         2
+--R              *
+--R                      1     3
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R               1     9 3+-+2 +-+  1  9 3+-+2
+--R               - %i x  \|2  \|3 - - x  \|2
+--R               2                  2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                4 +-+    4      1     12
+--R           (%i x \|3  - x )sin(-- %pi)
+--R                               18
+--R         + 
+--R                 4 +-+     4      1     2     1     10
+--R           (6%i x \|3  - 6x )cos(-- %pi) sin(-- %pi)
+--R                                 18          18
+--R         + 
+--R                 10       7       4  +-+    10    7    4      1     9
+--R           ((%i x   - %i x  + %i x )\|3  - x   + x  - x )sin(-- %pi)
+--R                                                             18
+--R         + 
+--R                      4 +-+      4      1     4
+--R               (15%i x \|3  - 15x )cos(-- %pi)
+--R                                       18
+--R             + 
+--R                    10    7    4  +-+        10        7        4      1
+--R               ((- x   + x  - x )\|3  + 3%i x   - 3%i x  + 3%i x )cos(-- %pi)
+--R                                                                      18
+--R          *
+--R                  1     8
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      4 +-+      4      1     6
+--R               (20%i x \|3  - 20x )cos(-- %pi)
+--R                                       18
+--R             + 
+--R                     8  10   8  7   8  4  +-+        10        7        4
+--R                 ((- - x   + - x  - - x )\|3  + 8%i x   - 8%i x  + 8%i x )
+--R                     3       3      3
+--R              *
+--R                      1     3
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                    7 +-+     7
+--R               2%i x \|3  - 2x
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      10        7        4  +-+     10     7     4      1     4
+--R             ((- 6%i x   + 6%i x  - 6%i x )\|3  + 6x   - 6x  + 6x )cos(-- %pi)
+--R                                                                       18
+--R          *
+--R                  1     5
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      4 +-+      4      1     8
+--R               (15%i x \|3  - 15x )cos(-- %pi)
+--R                                       18
+--R             + 
+--R                       10     7     4  +-+        10        7        4
+--R                 ((- 2x   + 2x  - 2x )\|3  + 6%i x   - 6%i x  + 6%i x )
+--R              *
+--R                      1     5
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                        7 +-+      7      1     2
+--R               (- 30%i x \|3  + 30x )cos(-- %pi)
+--R                                         18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                          10        7        4  +-+     10     7     4
+--R                 ((- 8%i x   + 8%i x  - 8%i x )\|3  + 8x   - 8x  + 8x )
+--R              *
+--R                      1     6
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                    13       10       7  +-+    13    10    7
+--R               (%i x   - %i x   + %i x )\|3  - x   + x   - x
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                     4 +-+     4      1     10
+--R               (6%i x \|3  - 6x )cos(-- %pi)
+--R                                     18
+--R             + 
+--R                      7 +-+      7      1     4
+--R               (30%i x \|3  - 30x )cos(-- %pi)
+--R                                       18
+--R             + 
+--R                  13    10    7  +-+        13        10        7      1
+--R               ((x   - x   + x )\|3  - 3%i x   + 3%i x   - 3%i x )cos(-- %pi)
+--R                                                                      18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                          10        7        4  +-+     10     7     4
+--R                 ((- 3%i x   + 3%i x  - 3%i x )\|3  + 3x   - 3x  + 3x )
+--R              *
+--R                      1     8
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                          13        10        7  +-+     13     10     7
+--R                 ((- 3%i x   + 3%i x   - 3%i x )\|3  + 3x   - 3x   + 3x )
+--R              *
+--R                      1     2
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                4 +-+    4      1     12
+--R           (%i x \|3  - x )cos(-- %pi)
+--R                               18
+--R         + 
+--R             1  10   1  7   1  4  +-+       10       7       4      1     9
+--R           ((- x   - - x  + - x )\|3  - %i x   + %i x  - %i x )cos(-- %pi)
+--R             3       3      3                                      18
+--R         + 
+--R                   7 +-+     7      1     6
+--R           (- 2%i x \|3  + 2x )cos(-- %pi)
+--R                                   18
+--R         + 
+--R               1  13   1  10   1  7  +-+       13       10       7      1     3
+--R           ((- - x   + - x   - - x )\|3  + %i x   - %i x   + %i x )cos(-- %pi)
+--R               3       3       3                                       18
+--R         + 
+--R               10 +-+    10
+--R           %i x  \|3  - x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  1     3 3+-+2 +-+  1  3 3+-+2     1     12
+--R               (- - %i x  \|2  \|3 - - x  \|2 )sin(-- %pi)
+--R                  2                  2             18
+--R             + 
+--R                       3 3+-+2 +-+    3 3+-+2     1     2     1     10
+--R               (- 3%i x  \|2  \|3 - 3x  \|2 )cos(-- %pi) sin(-- %pi)
+--R                                                 18          18
+--R             + 
+--R                      1     9   1     6   1     3 3+-+2 +-+
+--R                   (- - %i x  + - %i x  - - %i x )\|2  \|3
+--R                      2         2         2
+--R                 + 
+--R                      1  9   1  6   1  3 3+-+2
+--R                   (- - x  + - x  - - x )\|2
+--R                      2      2      2
+--R              *
+--R                      1     9
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                      15     3 3+-+2 +-+  15  3 3+-+2     1     4
+--R                   (- -- %i x  \|2  \|3 - -- x  \|2 )cos(-- %pi)
+--R                       2                   2             18
+--R                 + 
+--R                          1  9   1  6   1  3 3+-+2 +-+
+--R                       (- - x  + - x  - - x )\|2  \|3
+--R                          2      2      2
+--R                     + 
+--R                          3     9   3     6   3     3 3+-+2
+--R                       (- - %i x  + - %i x  - - %i x )\|2
+--R                          2         2         2
+--R                  *
+--R                          1
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     8
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                            3 3+-+2 +-+     3 3+-+2     1     6
+--R                   (- 10%i x  \|2  \|3 - 10x  \|2 )cos(-- %pi)
+--R                                                       18
+--R                 + 
+--R                          4  9   4  6   4  3 3+-+2 +-+
+--R                       (- - x  + - x  - - x )\|2  \|3
+--R                          3      3      3
+--R                     + 
+--R                               9        6        3 3+-+2
+--R                       (- 4%i x  + 4%i x  - 4%i x )\|2
+--R                  *
+--R                          1     3
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                         6 3+-+2 +-+   6 3+-+2
+--R                   - %i x  \|2  \|3 - x  \|2
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                        9        6        3 3+-+2 +-+      9     6     3 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                      1     4     1     5
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                      15     3 3+-+2 +-+  15  3 3+-+2     1     8
+--R                   (- -- %i x  \|2  \|3 - -- x  \|2 )cos(-- %pi)
+--R                       2                   2             18
+--R                 + 
+--R                           9    6    3 3+-+2 +-+
+--R                       (- x  + x  - x )\|2  \|3
+--R                     + 
+--R                               9        6        3 3+-+2
+--R                       (- 3%i x  + 3%i x  - 3%i x )\|2
+--R                  *
+--R                          1     5
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                          6 3+-+2 +-+     6 3+-+2     1     2
+--R                   (15%i x  \|2  \|3 + 15x  \|2 )cos(-- %pi)
+--R                                                     18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                             9        6        3 3+-+2 +-+
+--R                       (4%i x  - 4%i x  + 4%i x )\|2  \|3
+--R                     + 
+--R                          9     6     3 3+-+2
+--R                       (4x  - 4x  + 4x )\|2
+--R                  *
+--R                          1     6
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                      1     12   1     9   1     6 3+-+2 +-+
+--R                   (- - %i x   + - %i x  - - %i x )\|2  \|3
+--R                      2          2         2
+--R                 + 
+--R                      1  12   1  9   1  6 3+-+2
+--R                   (- - x   + - x  - - x )\|2
+--R                      2       2      2
+--R              *
+--R                      1     3
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                           3 3+-+2 +-+    3 3+-+2     1     10
+--R                   (- 3%i x  \|2  \|3 - 3x  \|2 )cos(-- %pi)
+--R                                                     18
+--R                 + 
+--R                            6 3+-+2 +-+     6 3+-+2     1     4
+--R                   (- 15%i x  \|2  \|3 - 15x  \|2 )cos(-- %pi)
+--R                                                       18
+--R                 + 
+--R                        1  12   1  9   1  6 3+-+2 +-+
+--R                       (- x   - - x  + - x )\|2  \|3
+--R                        2       2      2
+--R                     + 
+--R                        3     12   3     9   3     6 3+-+2
+--R                       (- %i x   - - %i x  + - %i x )\|2
+--R                        2          2         2
+--R                  *
+--R                          1
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                        3     9   3     6   3     3 3+-+2 +-+
+--R                       (- %i x  - - %i x  + - %i x )\|2  \|3
+--R                        2         2         2
+--R                     + 
+--R                        3  9   3  6   3  3 3+-+2
+--R                       (- x  - - x  + - x )\|2
+--R                        2      2      2
+--R                  *
+--R                          1     8
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                        3     12   3     9   3     6 3+-+2 +-+
+--R                       (- %i x   - - %i x  + - %i x )\|2  \|3
+--R                        2          2         2
+--R                     + 
+--R                        3  12   3  9   3  6 3+-+2
+--R                       (- x   - - x  + - x )\|2
+--R                        2       2      2
+--R                  *
+--R                          1     2
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                  1     3 3+-+2 +-+  1  3 3+-+2     1     12
+--R               (- - %i x  \|2  \|3 - - x  \|2 )cos(-- %pi)
+--R                  2                  2             18
+--R             + 
+--R                    1  9   1  6   1  3 3+-+2 +-+
+--R                   (- x  - - x  + - x )\|2  \|3
+--R                    6      6      6
+--R                 + 
+--R                    1     9   1     6   1     3 3+-+2
+--R                   (- %i x  - - %i x  + - %i x )\|2
+--R                    2         2         2
+--R              *
+--R                      1     9
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                    6 3+-+2 +-+   6 3+-+2     1     6
+--R               (%i x  \|2  \|3 + x  \|2 )cos(-- %pi)
+--R                                             18
+--R             + 
+--R                      1  12   1  9   1  6 3+-+2 +-+
+--R                   (- - x   + - x  - - x )\|2  \|3
+--R                      6       6      6
+--R                 + 
+--R                      1     12   1     9   1     6 3+-+2
+--R                   (- - %i x   + - %i x  - - %i x )\|2
+--R                      2          2         2
+--R              *
+--R                      1     3
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                 1     9 3+-+2 +-+  1  9 3+-+2
+--R               - - %i x  \|2  \|3 - - x  \|2
+--R                 2                  2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                         1     12            1     2     1     10
+--R               - 2x sin(-- %pi)   - 12x cos(-- %pi) sin(-- %pi)
+--R                        18                  18          18
+--R             + 
+--R                    7     4           1     9
+--R               (- 2x  + 2x  - 2x)sin(-- %pi)
+--R                                     18
+--R             + 
+--R                             1     4        7     4       +-+     1
+--R                 (- 30x cos(-- %pi)  + (- 2x  + 2x  - 2x)\|3 cos(-- %pi))
+--R                            18                                   18
+--R              *
+--R                      1     8
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                              1     6      16  7   16  4   16    +-+     1     3
+--R                   - 40x cos(-- %pi)  + (- -- x  + -- x  - -- x)\|3 cos(-- %pi)
+--R                             18             3       3       3           18
+--R                 + 
+--R                       4
+--R                   - 4x
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                   7      4            1     4     1     5
+--R               (12x  - 12x  + 12x)cos(-- %pi) sin(-- %pi)
+--R                                      18          18
+--R             + 
+--R                              1     8        7     4       +-+     1     5
+--R                   - 30x cos(-- %pi)  + (- 4x  + 4x  - 4x)\|3 cos(-- %pi)
+--R                             18                                   18
+--R                 + 
+--R                      4     1     2
+--R                   60x cos(-- %pi)
+--R                           18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                    7      4            1     6     10     7     4      1     3
+--R               ((16x  - 16x  + 16x)cos(-- %pi)  - 2x   + 2x  - 2x )sin(-- %pi)
+--R                                       18                              18
+--R             + 
+--R                              1     10      4     1     4
+--R                   - 12x cos(-- %pi)   - 60x cos(-- %pi)
+--R                             18                  18
+--R                 + 
+--R                      10     7     4  +-+     1
+--R                   (2x   - 2x  + 2x )\|3 cos(-- %pi)
+--R                                             18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                     7     4           1     8      10     7     4      1     2
+--R                 ((6x  - 6x  + 6x)cos(-- %pi)  + (6x   - 6x  + 6x )cos(-- %pi) )
+--R                                      18                               18
+--R              *
+--R                      1
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                         1     12    2  7   2  4   2    +-+     1     9
+--R               - 2x cos(-- %pi)   + (- x  - - x  + - x)\|3 cos(-- %pi)
+--R                        18           3      3      3           18
+--R             + 
+--R                 4     1     6      2  10   2  7   2  4  +-+     1     3     7
+--R               4x cos(-- %pi)  + (- - x   + - x  - - x )\|3 cos(-- %pi)  - 2x
+--R                      18            3       3      3            18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R               2 3+-+     1     12     2 3+-+     1     2     1     10
+--R           - 2x  \|2 sin(-- %pi)  - 12x  \|2 cos(-- %pi) sin(-- %pi)
+--R                         18                      18          18
+--R         + 
+--R                8     5     2 3+-+     1     9
+--R           (- 2x  + 2x  - 2x )\|2 sin(-- %pi)
+--R                                      18
+--R         + 
+--R                   2 3+-+     1     4       8     5     2 3+-+ +-+     1
+--R             (- 30x  \|2 cos(-- %pi) + (- 2x  + 2x  - 2x )\|2 \|3 cos(-- %pi))
+--R                             18                                       18
+--R          *
+--R                  1     8
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    2 3+-+     1     6
+--R               - 40x  \|2 cos(-- %pi)
+--R                              18
+--R             + 
+--R                  16  8   16  5   16  2 3+-+ +-+     1     3     5 3+-+
+--R               (- -- x  + -- x  - -- x )\|2 \|3 cos(-- %pi)  - 4x  \|2
+--R                   3       3       3                18
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R               8      5      2 3+-+     1     4     1     5
+--R           (12x  - 12x  + 12x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                       18          18
+--R         + 
+--R                    2 3+-+     1     8       8     5     2 3+-+ +-+     1     5
+--R               - 30x  \|2 cos(-- %pi) + (- 4x  + 4x  - 4x )\|2 \|3 cos(-- %pi)
+--R                              18                                       18
+--R             + 
+--R                  5 3+-+     1     2
+--R               60x  \|2 cos(-- %pi)
+--R                            18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  8      5      2 3+-+     1     6        11     8     5 3+-+
+--R             ((16x  - 16x  + 16x )\|2 cos(-- %pi)  + (- 2x   + 2x  - 2x )\|2 )
+--R                                          18
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    2 3+-+     1     10     5 3+-+     1     4
+--R               - 12x  \|2 cos(-- %pi)  - 60x  \|2 cos(-- %pi)
+--R                              18                      18
+--R             + 
+--R                  11     8     5 3+-+ +-+     1
+--R               (2x   - 2x  + 2x )\|2 \|3 cos(-- %pi)
+--R                                             18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  8     5     2 3+-+     1     8
+--R               (6x  - 6x  + 6x )\|2 cos(-- %pi)
+--R                                        18
+--R             + 
+--R                  11     8     5 3+-+     1     2
+--R               (6x   - 6x  + 6x )\|2 cos(-- %pi)
+--R                                         18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R               2 3+-+     1     12   2  8   2  5   2  2 3+-+ +-+     1     9
+--R           - 2x  \|2 cos(-- %pi)  + (- x  - - x  + - x )\|2 \|3 cos(-- %pi)
+--R                         18          3      3      3                18
+--R         + 
+--R             5 3+-+     1     6     2  11   2  8   2  5 3+-+ +-+     1     3
+--R           4x  \|2 cos(-- %pi) + (- - x   + - x  - - x )\|2 \|3 cos(-- %pi)
+--R                       18           3       3      3                18
+--R         + 
+--R               8 3+-+
+--R           - 2x  \|2
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  4 +-+    4      1     12
+--R           (- %i x \|3  - x )sin(-- %pi)
+--R                                 18
+--R         + 
+--R                   4 +-+     4      1     2     1     10
+--R           (- 6%i x \|3  - 6x )cos(-- %pi) sin(-- %pi)
+--R                                   18          18
+--R         + 
+--R                   10       7       4  +-+    10    7    4      1     9
+--R           ((- %i x   + %i x  - %i x )\|3  - x   + x  - x )sin(-- %pi)
+--R                                                               18
+--R         + 
+--R                        4 +-+      4      1     4
+--R               (- 15%i x \|3  - 15x )cos(-- %pi)
+--R                                         18
+--R             + 
+--R                    10    7    4  +-+        10        7        4      1
+--R               ((- x   + x  - x )\|3  - 3%i x   + 3%i x  - 3%i x )cos(-- %pi)
+--R                                                                      18
+--R          *
+--R                  1     8
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                        4 +-+      4      1     6
+--R               (- 20%i x \|3  - 20x )cos(-- %pi)
+--R                                         18
+--R             + 
+--R                     8  10   8  7   8  4  +-+        10        7        4
+--R                 ((- - x   + - x  - - x )\|3  - 8%i x   + 8%i x  - 8%i x )
+--R                     3       3      3
+--R              *
+--R                      1     3
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                      7 +-+     7
+--R               - 2%i x \|3  - 2x
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    10        7        4  +-+     10     7     4      1     4
+--R             ((6%i x   - 6%i x  + 6%i x )\|3  + 6x   - 6x  + 6x )cos(-- %pi)
+--R                                                                     18
+--R          *
+--R                  1     5
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                        4 +-+      4      1     8
+--R               (- 15%i x \|3  - 15x )cos(-- %pi)
+--R                                         18
+--R             + 
+--R                       10     7     4  +-+        10        7        4
+--R                 ((- 2x   + 2x  - 2x )\|3  - 6%i x   + 6%i x  - 6%i x )
+--R              *
+--R                      1     5
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                      7 +-+      7      1     2
+--R               (30%i x \|3  + 30x )cos(-- %pi)
+--R                                       18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      10        7        4  +-+     10     7     4      1     6
+--R               ((8%i x   - 8%i x  + 8%i x )\|3  + 8x   - 8x  + 8x )cos(-- %pi)
+--R                                                                       18
+--R             + 
+--R                      13       10       7  +-+    13    10    7
+--R               (- %i x   + %i x   - %i x )\|3  - x   + x   - x
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                       4 +-+     4      1     10
+--R               (- 6%i x \|3  - 6x )cos(-- %pi)
+--R                                       18
+--R             + 
+--R                        7 +-+      7      1     4
+--R               (- 30%i x \|3  - 30x )cos(-- %pi)
+--R                                         18
+--R             + 
+--R                  13    10    7  +-+        13        10        7      1
+--R               ((x   - x   + x )\|3  + 3%i x   - 3%i x   + 3%i x )cos(-- %pi)
+--R                                                                      18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      10        7        4  +-+     10     7     4      1     8
+--R               ((3%i x   - 3%i x  + 3%i x )\|3  + 3x   - 3x  + 3x )cos(-- %pi)
+--R                                                                       18
+--R             + 
+--R                    13        10        7  +-+     13     10     7      1     2
+--R             ((3%i x   - 3%i x   + 3%i x )\|3  + 3x   - 3x   + 3x )cos(-- %pi)
+--R                                                                       18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  4 +-+    4      1     12
+--R           (- %i x \|3  - x )cos(-- %pi)
+--R                                 18
+--R         + 
+--R             1  10   1  7   1  4  +-+       10       7       4      1     9
+--R           ((- x   - - x  + - x )\|3  + %i x   - %i x  + %i x )cos(-- %pi)
+--R             3       3      3                                      18
+--R         + 
+--R                 7 +-+     7      1     6
+--R           (2%i x \|3  + 2x )cos(-- %pi)
+--R                                 18
+--R         + 
+--R               1  13   1  10   1  7  +-+       13       10       7      1     3
+--R           ((- - x   + - x   - - x )\|3  - %i x   + %i x   - %i x )cos(-- %pi)
+--R               3       3       3                                       18
+--R         + 
+--R                 10 +-+    10
+--R           - %i x  \|3  - x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R               2 3+-+     1     12     2 3+-+     1     2     1     10
+--R           - 2x  \|2 sin(-- %pi)  - 12x  \|2 cos(-- %pi) sin(-- %pi)
+--R                         18                      18          18
+--R         + 
+--R                8     5     2 3+-+     1     9
+--R           (- 2x  + 2x  - 2x )\|2 sin(-- %pi)
+--R                                      18
+--R         + 
+--R                   2 3+-+     1     4       8     5     2 3+-+ +-+     1
+--R             (- 30x  \|2 cos(-- %pi) + (- 2x  + 2x  - 2x )\|2 \|3 cos(-- %pi))
+--R                             18                                       18
+--R          *
+--R                  1     8
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    2 3+-+     1     6
+--R               - 40x  \|2 cos(-- %pi)
+--R                              18
+--R             + 
+--R                  16  8   16  5   16  2 3+-+ +-+     1     3     5 3+-+
+--R               (- -- x  + -- x  - -- x )\|2 \|3 cos(-- %pi)  - 4x  \|2
+--R                   3       3       3                18
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R               8      5      2 3+-+     1     4     1     5
+--R           (12x  - 12x  + 12x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                       18          18
+--R         + 
+--R                    2 3+-+     1     8       8     5     2 3+-+ +-+     1     5
+--R               - 30x  \|2 cos(-- %pi) + (- 4x  + 4x  - 4x )\|2 \|3 cos(-- %pi)
+--R                              18                                       18
+--R             + 
+--R                  5 3+-+     1     2
+--R               60x  \|2 cos(-- %pi)
+--R                            18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  8      5      2 3+-+     1     6        11     8     5 3+-+
+--R             ((16x  - 16x  + 16x )\|2 cos(-- %pi)  + (- 2x   + 2x  - 2x )\|2 )
+--R                                          18
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    2 3+-+     1     10     5 3+-+     1     4
+--R               - 12x  \|2 cos(-- %pi)  - 60x  \|2 cos(-- %pi)
+--R                              18                      18
+--R             + 
+--R                  11     8     5 3+-+ +-+     1
+--R               (2x   - 2x  + 2x )\|2 \|3 cos(-- %pi)
+--R                                             18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  8     5     2 3+-+     1     8
+--R               (6x  - 6x  + 6x )\|2 cos(-- %pi)
+--R                                        18
+--R             + 
+--R                  11     8     5 3+-+     1     2
+--R               (6x   - 6x  + 6x )\|2 cos(-- %pi)
+--R                                         18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R               2 3+-+     1     12   2  8   2  5   2  2 3+-+ +-+     1     9
+--R           - 2x  \|2 cos(-- %pi)  + (- x  - - x  + - x )\|2 \|3 cos(-- %pi)
+--R                         18          3      3      3                18
+--R         + 
+--R             5 3+-+     1     6     2  11   2  8   2  5 3+-+ +-+     1     3
+--R           4x  \|2 cos(-- %pi) + (- - x   + - x  - - x )\|2 \|3 cos(-- %pi)
+--R                       18           3       3      3                18
+--R         + 
+--R               8 3+-+
+--R           - 2x  \|2
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           3 3+-+2     1     12     3 3+-+2     1     2     1     10
+--R       - 2x  \|2  sin(-- %pi)  - 12x  \|2  cos(-- %pi) sin(-- %pi)
+--R                      18                       18          18
+--R     + 
+--R            9     6     3 3+-+2     1     9
+--R       (- 2x  + 2x  - 2x )\|2  sin(-- %pi)
+--R                                   18
+--R     + 
+--R               3 3+-+2     1     4       9     6     3 3+-+2 +-+     1
+--R         (- 30x  \|2  cos(-- %pi) + (- 2x  + 2x  - 2x )\|2  \|3 cos(-- %pi))
+--R                          18                                        18
+--R      *
+--R              1     8
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R                3 3+-+2     1     6
+--R           - 40x  \|2  cos(-- %pi)
+--R                           18
+--R         + 
+--R              16  9   16  6   16  3 3+-+2 +-+     1     3     6 3+-+2
+--R           (- -- x  + -- x  - -- x )\|2  \|3 cos(-- %pi)  - 4x  \|2
+--R               3       3       3                 18
+--R      *
+--R              1     6
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R           9      6      3 3+-+2     1     4     1     5
+--R       (12x  - 12x  + 12x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                    18          18
+--R     + 
+--R                3 3+-+2     1     8       9     6     3 3+-+2 +-+     1     5
+--R           - 30x  \|2  cos(-- %pi) + (- 4x  + 4x  - 4x )\|2  \|3 cos(-- %pi)
+--R                           18                                        18
+--R         + 
+--R              6 3+-+2     1     2
+--R           60x  \|2  cos(-- %pi)
+--R                         18
+--R      *
+--R              1     4
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R              9      6      3 3+-+2     1     6        12     9     6 3+-+2
+--R         ((16x  - 16x  + 16x )\|2  cos(-- %pi)  + (- 2x   + 2x  - 2x )\|2  )
+--R                                       18
+--R      *
+--R              1     3
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R                3 3+-+2     1     10     6 3+-+2     1     4
+--R           - 12x  \|2  cos(-- %pi)  - 60x  \|2  cos(-- %pi)
+--R                           18                       18
+--R         + 
+--R              12     9     6 3+-+2 +-+     1
+--R           (2x   - 2x  + 2x )\|2  \|3 cos(-- %pi)
+--R                                          18
+--R      *
+--R              1     2
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R              9     6     3 3+-+2     1     8
+--R           (6x  - 6x  + 6x )\|2  cos(-- %pi)
+--R                                     18
+--R         + 
+--R              12     9     6 3+-+2     1     2
+--R           (6x   - 6x  + 6x )\|2  cos(-- %pi)
+--R                                      18
+--R      *
+--R              1
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R           3 3+-+2     1     12   2  9   2  6   2  3 3+-+2 +-+     1     9
+--R       - 2x  \|2  cos(-- %pi)  + (- x  - - x  + - x )\|2  \|3 cos(-- %pi)
+--R                      18          3      3      3                 18
+--R     + 
+--R         6 3+-+2     1     6     2  12   2  9   2  6 3+-+2 +-+     1     3
+--R       4x  \|2  cos(-- %pi) + (- - x   + - x  - - x )\|2  \|3 cos(-- %pi)
+--R                    18           3       3      3                 18
+--R     + 
+--R           9 3+-+2
+--R       - 2x  \|2
+--R  /
+--R                 10    7    4 3+-+     1     12
+--R               (x   - x  + x )\|2 sin(-- %pi)
+--R                                      18
+--R             + 
+--R                  10     7     4 3+-+     1     2     1     10
+--R               (6x   - 6x  + 6x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                         18          18
+--R             + 
+--R                   10      7      4 3+-+     1     4     1     8
+--R               (15x   - 15x  + 15x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                            18          18
+--R             + 
+--R                         10      7      4 3+-+     1     6
+--R                     (20x   - 20x  + 20x )\|2 cos(-- %pi)
+--R                                                  18
+--R                   + 
+--R                        13     10     7 3+-+
+--R                     (2x   - 2x   + 2x )\|2
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                       10      7      4 3+-+     1     8
+--R                   (15x   - 15x  + 15x )\|2 cos(-- %pi)
+--R                                                18
+--R                 + 
+--R                         13      10      7 3+-+     1     2
+--R                   (- 30x   + 30x   - 30x )\|2 cos(-- %pi)
+--R                                                   18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                      10     7     4 3+-+     1     10
+--R                   (6x   - 6x  + 6x )\|2 cos(-- %pi)
+--R                                             18
+--R                 + 
+--R                       13      10      7 3+-+     1     4
+--R                   (30x   - 30x   + 30x )\|2 cos(-- %pi)
+--R                                                 18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                 10    7    4 3+-+     1     12
+--R               (x   - x  + x )\|2 cos(-- %pi)
+--R                                      18
+--R             + 
+--R                    13     10     7 3+-+     1     6     16    13    10 3+-+
+--R               (- 2x   + 2x   - 2x )\|2 cos(-- %pi)  + (x   - x   + x  )\|2
+--R                                            18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                      1     8   1     5   1     2 3+-+2 +-+
+--R                   (- - %i x  + - %i x  - - %i x )\|2  \|3
+--R                      2         2         2
+--R                 + 
+--R                    1  8   1  5   1  2 3+-+2
+--R                   (- x  - - x  + - x )\|2
+--R                    2      2      2
+--R              *
+--R                      1     12
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                      1     2     1     10
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                      15     8   15     5   15     2 3+-+2 +-+
+--R                   (- -- %i x  + -- %i x  - -- %i x )\|2  \|3
+--R                       2          2          2
+--R                 + 
+--R                    15  8   15  5   15  2 3+-+2
+--R                   (-- x  - -- x  + -- x )\|2
+--R                     2       2       2
+--R              *
+--R                      1     4     1     8
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 10%i x  + 10%i x  - 10%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (10x  - 10x  + 10x )\|2
+--R                  *
+--R                          1     6
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                          11       8       5 3+-+2 +-+     11    8    5 3+-+2
+--R                   (- %i x   + %i x  - %i x )\|2  \|3  + (x   - x  + x )\|2
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                          15     8   15     5   15     2 3+-+2 +-+
+--R                       (- -- %i x  + -- %i x  - -- %i x )\|2  \|3
+--R                           2          2          2
+--R                     + 
+--R                        15  8   15  5   15  2 3+-+2
+--R                       (-- x  - -- x  + -- x )\|2
+--R                         2       2       2
+--R                  *
+--R                          1     8
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (15%i x   - 15%i x  + 15%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 15x   + 15x  - 15x )\|2
+--R                  *
+--R                          1     2
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                               8        5        2 3+-+2 +-+
+--R                       (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                     + 
+--R                          8     5     2 3+-+2
+--R                       (3x  - 3x  + 3x )\|2
+--R                  *
+--R                          1     10
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 15%i x   + 15%i x  - 15%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (15x   - 15x  + 15x )\|2
+--R                  *
+--R                          1     4
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                      1     8   1     5   1     2 3+-+2 +-+
+--R                   (- - %i x  + - %i x  - - %i x )\|2  \|3
+--R                      2         2         2
+--R                 + 
+--R                    1  8   1  5   1  2 3+-+2
+--R                   (- x  - - x  + - x )\|2
+--R                    2      2      2
+--R              *
+--R                      1     12
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                       11       8       5 3+-+2 +-+       11    8    5 3+-+2
+--R                 ((%i x   - %i x  + %i x )\|2  \|3  + (- x   + x  - x )\|2  )
+--R              *
+--R                      1     6
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                  1     14   1     11   1     8 3+-+2 +-+
+--R               (- - %i x   + - %i x   - - %i x )\|2  \|3
+--R                  2          2          2
+--R             + 
+--R                1  14   1  11   1  8 3+-+2
+--R               (- x   - - x   + - x )\|2
+--R                2       2       2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   9       6       3  +-+    9    6    3      1     12
+--R           ((- %i x  + %i x  - %i x )\|3  + x  - x  + x )sin(-- %pi)
+--R                                                             18
+--R         + 
+--R                      9        6        3  +-+     9     6     3      1     2
+--R             ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(-- %pi)
+--R                                                                     18
+--R          *
+--R                  1     10
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                       9         6         3  +-+      9      6      3
+--R             ((- 15%i x  + 15%i x  - 15%i x )\|3  + 15x  - 15x  + 15x )
+--R          *
+--R                  1     4     1     8
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 20%i x  + 20%i x  - 20%i x )\|3  + 20x  - 20x  + 20x )
+--R              *
+--R                      1     6
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                       12        9        6  +-+     12     9     6
+--R               (- 2%i x   + 2%i x  - 2%i x )\|3  + 2x   - 2x  + 2x
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 15%i x  + 15%i x  - 15%i x )\|3  + 15x  - 15x  + 15x )
+--R              *
+--R                      1     8
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                         12         9         6  +-+      12      9      6
+--R                 ((30%i x   - 30%i x  + 30%i x )\|3  - 30x   + 30x  - 30x )
+--R              *
+--R                      1     2
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                        9        6        3  +-+     9     6     3      1     10
+--R               ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(-- %pi)
+--R                                                                       18
+--R             + 
+--R                           12         9         6  +-+      12      9      6
+--R                 ((- 30%i x   + 30%i x  - 30%i x )\|3  + 30x   - 30x  + 30x )
+--R              *
+--R                      1     4
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   9       6       3  +-+    9    6    3      1     12
+--R           ((- %i x  + %i x  - %i x )\|3  + x  - x  + x )cos(-- %pi)
+--R                                                             18
+--R         + 
+--R                  12        9        6  +-+     12     9     6      1     6
+--R           ((2%i x   - 2%i x  + 2%i x )\|3  - 2x   + 2x  - 2x )cos(-- %pi)
+--R                                                                   18
+--R         + 
+--R                  15       12       9  +-+    15    12    9
+--R           (- %i x   + %i x   - %i x )\|3  + x   - x   + x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                    1     8   1     5   1     2 3+-+2 +-+
+--R                   (- %i x  - - %i x  + - %i x )\|2  \|3
+--R                    2         2         2
+--R                 + 
+--R                    1  8   1  5   1  2 3+-+2
+--R                   (- x  - - x  + - x )\|2
+--R                    2      2      2
+--R              *
+--R                      1     12
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                      1     2     1     10
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                    15     8   15     5   15     2 3+-+2 +-+
+--R                   (-- %i x  - -- %i x  + -- %i x )\|2  \|3
+--R                     2          2          2
+--R                 + 
+--R                    15  8   15  5   15  2 3+-+2
+--R                   (-- x  - -- x  + -- x )\|2
+--R                     2       2       2
+--R              *
+--R                      1     4     1     8
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (10%i x  - 10%i x  + 10%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (10x  - 10x  + 10x )\|2
+--R                  *
+--R                          1     6
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                        11       8       5 3+-+2 +-+     11    8    5 3+-+2
+--R                   (%i x   - %i x  + %i x )\|2  \|3  + (x   - x  + x )\|2
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                        15     8   15     5   15     2 3+-+2 +-+
+--R                       (-- %i x  - -- %i x  + -- %i x )\|2  \|3
+--R                         2          2          2
+--R                     + 
+--R                        15  8   15  5   15  2 3+-+2
+--R                       (-- x  - -- x  + -- x )\|2
+--R                         2       2       2
+--R                  *
+--R                          1     8
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 15%i x   + 15%i x  - 15%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 15x   + 15x  - 15x )\|2
+--R                  *
+--R                          1     2
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                             8        5        2 3+-+2 +-+
+--R                       (3%i x  - 3%i x  + 3%i x )\|2  \|3
+--R                     + 
+--R                          8     5     2 3+-+2
+--R                       (3x  - 3x  + 3x )\|2
+--R                  *
+--R                          1     10
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (15%i x   - 15%i x  + 15%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (15x   - 15x  + 15x )\|2
+--R                  *
+--R                          1     4
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                    1     8   1     5   1     2 3+-+2 +-+
+--R                   (- %i x  - - %i x  + - %i x )\|2  \|3
+--R                    2         2         2
+--R                 + 
+--R                    1  8   1  5   1  2 3+-+2
+--R                   (- x  - - x  + - x )\|2
+--R                    2      2      2
+--R              *
+--R                      1     12
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                         11       8       5 3+-+2 +-+       11    8    5 3+-+2
+--R                 ((- %i x   + %i x  - %i x )\|2  \|3  + (- x   + x  - x )\|2  )
+--R              *
+--R                      1     6
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                1     14   1     11   1     8 3+-+2 +-+
+--R               (- %i x   - - %i x   + - %i x )\|2  \|3
+--R                2          2          2
+--R             + 
+--R                1  14   1  11   1  8 3+-+2
+--R               (- x   - - x   + - x )\|2
+--R                2       2       2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  6     3          1     12
+--R               (2x  - 2x  + 2)sin(-- %pi)
+--R                                  18
+--R             + 
+--R                   6      3           1     2     1     10
+--R               (12x  - 12x  + 12)cos(-- %pi) sin(-- %pi)
+--R                                     18          18
+--R             + 
+--R                   6      3           1     4     1     8
+--R               (30x  - 30x  + 30)cos(-- %pi) sin(-- %pi)
+--R                                     18          18
+--R             + 
+--R                    6      3           1     6     9     6     3      1     6
+--R               ((40x  - 40x  + 40)cos(-- %pi)  + 4x  - 4x  + 4x )sin(-- %pi)
+--R                                      18                             18
+--R             + 
+--R                       6      3           1     8
+--R                   (30x  - 30x  + 30)cos(-- %pi)
+--R                                         18
+--R                 + 
+--R                         9      6      3      1     2
+--R                   (- 60x  + 60x  - 60x )cos(-- %pi)
+--R                                             18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                       6      3           1     10
+--R                   (12x  - 12x  + 12)cos(-- %pi)
+--R                                         18
+--R                 + 
+--R                       9      6      3      1     4
+--R                   (60x  - 60x  + 60x )cos(-- %pi)
+--R                                           18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                  6     3          1     12        9     6     3      1     6
+--R               (2x  - 2x  + 2)cos(-- %pi)   + (- 4x  + 4x  - 4x )cos(-- %pi)
+--R                                  18                                 18
+--R             + 
+--R                 12     9     6
+--R               2x   - 2x  + 2x
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R              7     4      3+-+     1     12
+--R           (2x  - 2x  + 2x)\|2 sin(-- %pi)
+--R                                   18
+--R         + 
+--R               7      4       3+-+     1     2     1     10
+--R           (12x  - 12x  + 12x)\|2 cos(-- %pi) sin(-- %pi)
+--R                                      18          18
+--R         + 
+--R               7      4       3+-+     1     4     1     8
+--R           (30x  - 30x  + 30x)\|2 cos(-- %pi) sin(-- %pi)
+--R                                      18          18
+--R         + 
+--R                  7      4       3+-+     1     6      10     7     4 3+-+
+--R             ((40x  - 40x  + 40x)\|2 cos(-- %pi)  + (4x   - 4x  + 4x )\|2 )
+--R                                         18
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   7      4       3+-+     1     8
+--R               (30x  - 30x  + 30x)\|2 cos(-- %pi)
+--R                                          18
+--R             + 
+--R                     10      7      4 3+-+     1     2
+--R               (- 60x   + 60x  - 60x )\|2 cos(-- %pi)
+--R                                              18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   7      4       3+-+     1     10
+--R               (12x  - 12x  + 12x)\|2 cos(-- %pi)
+--R                                          18
+--R             + 
+--R                   10      7      4 3+-+     1     4
+--R               (60x   - 60x  + 60x )\|2 cos(-- %pi)
+--R                                            18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R              7     4      3+-+     1     12
+--R           (2x  - 2x  + 2x)\|2 cos(-- %pi)
+--R                                   18
+--R         + 
+--R                10     7     4 3+-+     1     6      13     10     7 3+-+
+--R           (- 4x   + 4x  - 4x )\|2 cos(-- %pi)  + (2x   - 2x   + 2x )\|2
+--R                                       18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 9       6       3  +-+    9    6    3      1     12
+--R           ((%i x  - %i x  + %i x )\|3  + x  - x  + x )sin(-- %pi)
+--R                                                           18
+--R         + 
+--R                    9        6        3  +-+     9     6     3      1     2
+--R             ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(-- %pi)
+--R                                                                   18
+--R          *
+--R                  1     10
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                     9         6         3  +-+      9      6      3
+--R             ((15%i x  - 15%i x  + 15%i x )\|3  + 15x  - 15x  + 15x )
+--R          *
+--R                  1     4     1     8
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R                         9         6         3  +-+      9      6      3
+--R                 ((20%i x  - 20%i x  + 20%i x )\|3  + 20x  - 20x  + 20x )
+--R              *
+--R                      1     6
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                     12        9        6  +-+     12     9     6
+--R               (2%i x   - 2%i x  + 2%i x )\|3  + 2x   - 2x  + 2x
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                         9         6         3  +-+      9      6      3
+--R                 ((15%i x  - 15%i x  + 15%i x )\|3  + 15x  - 15x  + 15x )
+--R              *
+--R                      1     8
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                           12         9         6  +-+      12      9      6
+--R                 ((- 30%i x   + 30%i x  - 30%i x )\|3  - 30x   + 30x  - 30x )
+--R              *
+--R                      1     2
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      9        6        3  +-+     9     6     3      1     10
+--R               ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(-- %pi)
+--R                                                                     18
+--R             + 
+--R                         12         9         6  +-+      12      9      6
+--R                 ((30%i x   - 30%i x  + 30%i x )\|3  + 30x   - 30x  + 30x )
+--R              *
+--R                      1     4
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                 9       6       3  +-+    9    6    3      1     12
+--R           ((%i x  - %i x  + %i x )\|3  + x  - x  + x )cos(-- %pi)
+--R                                                           18
+--R         + 
+--R                    12        9        6  +-+     12     9     6      1     6
+--R           ((- 2%i x   + 2%i x  - 2%i x )\|3  - 2x   + 2x  - 2x )cos(-- %pi)
+--R                                                                     18
+--R         + 
+--R                15       12       9  +-+    15    12    9
+--R           (%i x   - %i x   + %i x )\|3  + x   - x   + x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R              7     4      3+-+     1     12
+--R           (2x  - 2x  + 2x)\|2 sin(-- %pi)
+--R                                   18
+--R         + 
+--R               7      4       3+-+     1     2     1     10
+--R           (12x  - 12x  + 12x)\|2 cos(-- %pi) sin(-- %pi)
+--R                                      18          18
+--R         + 
+--R               7      4       3+-+     1     4     1     8
+--R           (30x  - 30x  + 30x)\|2 cos(-- %pi) sin(-- %pi)
+--R                                      18          18
+--R         + 
+--R                  7      4       3+-+     1     6      10     7     4 3+-+
+--R             ((40x  - 40x  + 40x)\|2 cos(-- %pi)  + (4x   - 4x  + 4x )\|2 )
+--R                                         18
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   7      4       3+-+     1     8
+--R               (30x  - 30x  + 30x)\|2 cos(-- %pi)
+--R                                          18
+--R             + 
+--R                     10      7      4 3+-+     1     2
+--R               (- 60x   + 60x  - 60x )\|2 cos(-- %pi)
+--R                                              18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   7      4       3+-+     1     10
+--R               (12x  - 12x  + 12x)\|2 cos(-- %pi)
+--R                                          18
+--R             + 
+--R                   10      7      4 3+-+     1     4
+--R               (60x   - 60x  + 60x )\|2 cos(-- %pi)
+--R                                            18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R              7     4      3+-+     1     12
+--R           (2x  - 2x  + 2x)\|2 cos(-- %pi)
+--R                                   18
+--R         + 
+--R                10     7     4 3+-+     1     6      13     10     7 3+-+
+--R           (- 4x   + 4x  - 4x )\|2 cos(-- %pi)  + (2x   - 2x   + 2x )\|2
+--R                                       18
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R          8     5     2 3+-+2     1     12
+--R       (2x  - 2x  + 2x )\|2  sin(-- %pi)
+--R                                 18
+--R     + 
+--R           8      5      2 3+-+2     1     2     1     10
+--R       (12x  - 12x  + 12x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                    18          18
+--R     + 
+--R           8      5      2 3+-+2     1     4     1     8
+--R       (30x  - 30x  + 30x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                    18          18
+--R     + 
+--R              8      5      2 3+-+2     1     6      11     8     5 3+-+2
+--R         ((40x  - 40x  + 40x )\|2  cos(-- %pi)  + (4x   - 4x  + 4x )\|2  )
+--R                                       18
+--R      *
+--R              1     6
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R               8      5      2 3+-+2     1     8
+--R           (30x  - 30x  + 30x )\|2  cos(-- %pi)
+--R                                        18
+--R         + 
+--R                 11      8      5 3+-+2     1     2
+--R           (- 60x   + 60x  - 60x )\|2  cos(-- %pi)
+--R                                           18
+--R      *
+--R              1     4
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R               8      5      2 3+-+2     1     10
+--R           (12x  - 12x  + 12x )\|2  cos(-- %pi)
+--R                                        18
+--R         + 
+--R               11      8      5 3+-+2     1     4
+--R           (60x   - 60x  + 60x )\|2  cos(-- %pi)
+--R                                         18
+--R      *
+--R              1     2
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R          8     5     2 3+-+2     1     12
+--R       (2x  - 2x  + 2x )\|2  cos(-- %pi)
+--R                                 18
+--R     + 
+--R            11     8     5 3+-+2     1     6      14     11     8 3+-+2
+--R       (- 4x   + 4x  - 4x )\|2  cos(-- %pi)  + (2x   - 2x   + 2x )\|2
+--R                                    18
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 880
+
+)clear all
+
+--S 881 of 2282
+t0:=1/(1-x^3+x^6)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 881
+
+--S 882 of 2282
+r0:=-1/3*(-1)^(13/18)*atan((1+2*(-1)^(1/9)*x)/sqrt(3))+1/3*(-1)^(5/18)*_
+   atan((1-2*(-1)^(8/9)*x)/sqrt(3))-1/9*(-1)^(5/18)*(log(2)+_
+   3*log((-1)^(1/9)-x))/sqrt(3)+1/3*(-1)^(13/18)*log(-2^(1/3)*_
+   ((-1)^(8/9)+x))/sqrt(3)-1/6*(-1)^(13/18)*log(-2^(2/3)*((-1)^(7/9)+_
+   ((-1)^(8/9)-x)*x))/sqrt(3)+1/6*(-1)^(5/18)*log(2^(2/3)*((-1)^(2/9)+_
+   x*((-1)^(1/9)+x)))/sqrt(3),-1/3*%i*2^(2/3)*atan((4*x+2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))/_
+   (1-%i*sqrt(3))^(2/3)+1/3*%i*2^(2/3)*atan((4*x+2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*sqrt(3)))/(1+%i*_
+   sqrt(3))^(2/3)+1/3*%i*2^(2/3)*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))/_
+   ((1-%i*sqrt(3))^(2/3)*sqrt(3))-1/3*%i*log(2^(2/3)*x^2+2^(1/3)*x*_
+   (1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))/(2^(1/3)*(1-%i*_
+   sqrt(3))^(2/3)*sqrt(3))-1/3*%i*2^(2/3)*log(-2^(1/3)*x+(1+%i*_
+   sqrt(3))^(1/3))/((1+%i*sqrt(3))^(2/3)*sqrt(3))+1/3*%i*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R   [
+--R         1 18+---+5     9+---+2    9+---+    2 3+-+2
+--R         -  \|- 1  log((\|- 1   + x\|- 1  + x )\|2  )
+--R         6
+--R       + 
+--R           1 18+---+5    9+---+        1 18+---+13       9+---+8     3+-+
+--R         - -  \|- 1  log(\|- 1  - x) + -  \|- 1   log((- \|- 1   - x)\|2 )
+--R           3                           3
+--R       + 
+--R           1 18+---+13       9+---+7    2     3+-+2
+--R         - -  \|- 1   log((- \|- 1   + x  - x)\|2  )
+--R           6
+--R       + 
+--R           1 18+---+5 +-+      2   9+---+8   1  +-+
+--R         - -  \|- 1  \|3 atan((- x \|- 1   - -)\|3 )
+--R           3                   3             3
+--R       + 
+--R           1 18+---+13 +-+      2  9+---+   1  +-+    1       18+---+5
+--R         - -  \|- 1   \|3 atan((- x\|- 1  + -)\|3 ) - - log(2) \|- 1
+--R           3                    3           3         9
+--R    /
+--R        +-+
+--R       \|3
+--R     ,
+--R
+--R               +------------+2     +----------+2         +----------+
+--R         1    3|     +-+          3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         - %i \|- %i\|3  + 1  log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R         3
+--R       + 
+--R                 +------------+2     +----------+
+--R           2    3|     +-+          3|   +-+         3+-+
+--R         - - %i \|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R           3
+--R       + 
+--R         -
+--R                    +----------+2
+--R              1    3|   +-+
+--R              - %i \|%i\|3  + 1
+--R              3
+--R           *
+--R                   +------------+2         +------------+
+--R                  3|     +-+          3+-+3|     +-+         2 3+-+2
+--R              log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R       + 
+--R               +----------+2     +------------+
+--R         2    3|   +-+          3|     +-+         3+-+
+--R         - %i \|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R         3
+--R       + 
+--R                                             +------------+
+--R                    +----------+2     3+-+2 3|     +-+
+--R           2    +-+3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R         - - %i\|3 \|%i\|3  + 1  atan(-------------------------)
+--R           3                                     +------------+
+--R                                       3+-+2 +-+3|     +-+
+--R                                       \|2  \|3 \|- %i\|3  + 1
+--R       + 
+--R                                             +----------+
+--R                  +------------+2     3+-+2 3|   +-+
+--R         2    +-+3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R         - %i\|3 \|- %i\|3  + 1  atan(-----------------------)
+--R         3                                       +----------+
+--R                                       3+-+2 +-+3|   +-+
+--R                                       \|2  \|3 \|%i\|3  + 1
+--R    /
+--R                +------------+2  +----------+2
+--R       3+-+ +-+3|     +-+       3|   +-+
+--R       \|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R     ]
+--R                          Type: Tuple(Expression(Complex(Fraction(Integer))))
+--E 882
+
+--S 883 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         1                 1
+--R                  atan(----)        atan(----)
+--R                        +-+               +-+
+--R           +-+         \|3               \|3
+--R         (\|3 sin(----------) - cos(----------))
+--R                       3                 3
+--R      *
+--R                        1   2                 1                 1   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      3                     3                 3
+--R     + 
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                              1
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            3
+--R     + 
+--R                           1                 1
+--R                    atan(----)        atan(----)
+--R                          +-+               +-+
+--R             +-+         \|3               \|3
+--R         (- \|3 sin(----------) - cos(----------))
+--R                         3                 3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                                1
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              3
+--R     + 
+--R                                              1                 1
+--R                                       atan(----)        atan(----)
+--R                   1                         +-+               +-+
+--R            atan(----)          +-+         \|3               \|3
+--R                  +-+          \|3 sin(----------) + cos(----------)
+--R                 \|3                        3                 3
+--R       4sin(----------)atan(------------------------------------------)
+--R                 3                     1                     1
+--R                                atan(----)            atan(----)
+--R                                      +-+                   +-+
+--R                                     \|3       +-+         \|3
+--R                            sin(----------) - \|3 cos(----------) - 2x
+--R                                     3                     3
+--R     + 
+--R                      1                      1
+--R               atan(----)             atan(----)
+--R                     +-+                    +-+
+--R                    \|3        +-+         \|3
+--R         (2sin(----------) - 2\|3 cos(----------))
+--R                    3                      3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) - cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) + \|3 cos(----------) - 2x
+--R                       3                     3
+--R     + 
+--R                                                                    1
+--R                                                             atan(----)
+--R                      1                      1                     +-+
+--R               atan(----)             atan(----)                  \|3
+--R                     +-+                    +-+          cos(----------)
+--R                    \|3        +-+         \|3                    3
+--R       (- 2sin(----------) - 2\|3 cos(----------))atan(-------------------)
+--R                    3                      3                      1
+--R                                                           atan(----)
+--R                                                                 +-+
+--R                                                                \|3
+--R                                                       sin(----------) + x
+--R                                                                3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 883
+
+--S 884 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          1                  1
+--R                   atan(----)         atan(----)
+--R                         +-+                +-+
+--R            +-+         \|3                \|3
+--R         (3\|3 sin(----------) - 3cos(----------))
+--R                        3                  3
+--R      *
+--R                        1   2                 1                 1   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      3                     3                 3
+--R     + 
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         6cos(----------)
+--R                   3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                              1
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            3
+--R     + 
+--R                            1                  1
+--R                     atan(----)         atan(----)
+--R                           +-+                +-+
+--R              +-+         \|3                \|3
+--R         (- 3\|3 sin(----------) - 3cos(----------))
+--R                          3                  3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                                1
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              3
+--R     + 
+--R                                               1                 1
+--R                                        atan(----)        atan(----)
+--R                    1                         +-+               +-+
+--R             atan(----)          +-+         \|3               \|3
+--R                   +-+          \|3 sin(----------) + cos(----------)
+--R                  \|3                        3                 3
+--R       12sin(----------)atan(------------------------------------------)
+--R                  3                     1                     1
+--R                                 atan(----)            atan(----)
+--R                                       +-+                   +-+
+--R                                      \|3       +-+         \|3
+--R                             sin(----------) - \|3 cos(----------) - 2x
+--R                                      3                     3
+--R     + 
+--R                      1                      1
+--R               atan(----)             atan(----)
+--R                     +-+                    +-+
+--R                    \|3        +-+         \|3
+--R         (6sin(----------) - 6\|3 cos(----------))
+--R                    3                      3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) - cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) + \|3 cos(----------) - 2x
+--R                       3                     3
+--R     + 
+--R                                                                    1
+--R                                                             atan(----)
+--R                      1                      1                     +-+
+--R               atan(----)             atan(----)                  \|3
+--R                     +-+                    +-+          cos(----------)
+--R                    \|3        +-+         \|3                    3
+--R       (- 6sin(----------) - 6\|3 cos(----------))atan(-------------------)
+--R                    3                      3                      1
+--R                                                           atan(----)
+--R                                                                 +-+
+--R                                                                \|3
+--R                                                       sin(----------) + x
+--R                                                                3
+--R     + 
+--R          18+---+5     9+---+2    9+---+    2 3+-+2     18+---+5    9+---+
+--R       - 3 \|- 1  log((\|- 1   + x\|- 1  + x )\|2  ) + 6 \|- 1  log(\|- 1  - x)
+--R     + 
+--R          18+---+13       9+---+8     3+-+
+--R       - 6 \|- 1   log((- \|- 1   - x)\|2 )
+--R     + 
+--R        18+---+13       9+---+7    2     3+-+2
+--R       3 \|- 1   log((- \|- 1   + x  - x)\|2  )
+--R     + 
+--R                             9+---+8      +-+
+--R        18+---+5 +-+     (2x \|- 1   - 1)\|3
+--R       6 \|- 1  \|3 atan(--------------------)
+--R                                   3
+--R     + 
+--R                             9+---+      +-+
+--R        18+---+13 +-+     (2x\|- 1  + 1)\|3            18+---+5
+--R       6 \|- 1   \|3 atan(------------------) + 2log(2) \|- 1
+--R                                   3
+--R  /
+--R        +-+
+--R     18\|3
+--R                                                    Type: Expression(Integer)
+--E 884
+
+--S 885 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                   6    5    4     3    2         18+---+17
+--R               (- x  + x  - x  - 7x  - x  - x + 1) \|- 1
+--R             + 
+--R                   7    6    5     4     3    2         18+---+15
+--R               (- x  - x  + x  - 7x  + 5x  - x  + x - 5) \|- 1
+--R             + 
+--R                   8    7    6    5    4    3    2      18+---+13
+--R               (- x  - x  + x  + x  + x  - x  + x  - 5x) \|- 1
+--R             + 
+--R                   8    7    6    5    4    3     2 18+---+11
+--R               (- x  + x  + x  + x  + x  - x  - 5x ) \|- 1
+--R             + 
+--R                 7    6    5    4    3 18+---+9
+--R               (x  + x  + x  - x  - x ) \|- 1
+--R             + 
+--R                 6    5    4     2      18+---+7       5     3     2 18+---+5
+--R               (x  - x  - x  + 6x  - 6x) \|- 1   + (- x  + 5x  - 6x ) \|- 1
+--R             + 
+--R                  4     3    2     18+---+3       5    4    3     2     18+---+
+--R               (5x  - 7x  + x  + 6) \|- 1   + (- x  - x  + x  + 7x  + x) \|- 1
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R               7      5      4       18+---+16
+--R           (18x  - 18x  + 18x  + 18x) \|- 1
+--R         + 
+--R               8      6      5      2 18+---+14
+--R           (18x  - 18x  + 18x  + 18x ) \|- 1
+--R         + 
+--R                 7      6      3 18+---+12       5      4 18+---+10
+--R           (- 18x  + 18x  - 18x ) \|- 1    + (18x  - 36x ) \|- 1
+--R         + 
+--R               6      5 18+---+8       7      6      3 18+---+6
+--R           (18x  - 36x ) \|- 1   + (18x  - 18x  + 18x ) \|- 1
+--R         + 
+--R                 8      7      4      2       18+---+4
+--R           (- 18x  + 18x  + 18x  - 18x  + 18x) \|- 1
+--R         + 
+--R                 9      8      5      3      2 18+---+2      10      9      6
+--R           (- 18x  + 18x  + 18x  - 18x  + 18x ) \|- 1   - 18x   + 18x  - 18x
+--R         + 
+--R                4      3
+--R           - 18x  + 18x  - 18
+--R      *
+--R                    1   6
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  3
+--R     + 
+--R                    6     5     4      3     2          18+---+17
+--R               (- 3x  + 3x  - 3x  - 21x  - 3x  - 3x + 3) \|- 1
+--R             + 
+--R                    7     6     5      4      3     2           18+---+15
+--R               (- 3x  - 3x  + 3x  - 21x  + 15x  - 3x  + 3x - 15) \|- 1
+--R             + 
+--R                    8     7     6     5     4     3     2       18+---+13
+--R               (- 3x  - 3x  + 3x  + 3x  + 3x  - 3x  + 3x  - 15x) \|- 1
+--R             + 
+--R                    8     7     6     5     4     3      2 18+---+11
+--R               (- 3x  + 3x  + 3x  + 3x  + 3x  - 3x  - 15x ) \|- 1
+--R             + 
+--R                  7     6     5     4     3 18+---+9
+--R               (3x  + 3x  + 3x  - 3x  - 3x ) \|- 1
+--R             + 
+--R                  6     5     4      2       18+---+7
+--R               (3x  - 3x  - 3x  + 18x  - 18x) \|- 1
+--R             + 
+--R                    5      3      2 18+---+5       4      3     2      18+---+3
+--R               (- 3x  + 15x  - 18x ) \|- 1   + (15x  - 21x  + 3x  + 18) \|- 1
+--R             + 
+--R                    5     4     3      2      18+---+
+--R               (- 3x  - 3x  + 3x  + 21x  + 3x) \|- 1
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R               7      5      4       18+---+16
+--R           (54x  - 54x  + 54x  + 54x) \|- 1
+--R         + 
+--R               8      6      5      2 18+---+14
+--R           (54x  - 54x  + 54x  + 54x ) \|- 1
+--R         + 
+--R                 7      6      3 18+---+12       5       4 18+---+10
+--R           (- 54x  + 54x  - 54x ) \|- 1    + (54x  - 108x ) \|- 1
+--R         + 
+--R               6       5 18+---+8       7      6      3 18+---+6
+--R           (54x  - 108x ) \|- 1   + (54x  - 54x  + 54x ) \|- 1
+--R         + 
+--R                 8      7      4      2       18+---+4
+--R           (- 54x  + 54x  + 54x  - 54x  + 54x) \|- 1
+--R         + 
+--R                 9      8      5      3      2 18+---+2      10      9      6
+--R           (- 54x  + 54x  + 54x  - 54x  + 54x ) \|- 1   - 54x   + 54x  - 54x
+--R         + 
+--R                4      3
+--R           - 54x  + 54x  - 54
+--R      *
+--R                    1   2           1   4
+--R             atan(----)      atan(----)
+--R                   +-+             +-+
+--R                  \|3             \|3
+--R         cos(----------) sin(----------)
+--R                  3               3
+--R     + 
+--R                    9     8     7      6     5     4     3 18+---+17
+--R               (- 2x  + 2x  - 2x  - 14x  - 2x  - 2x  + 2x ) \|- 1
+--R             + 
+--R                    10     9     8      7      6     5     4      3 18+---+15
+--R               (- 2x   - 2x  + 2x  - 14x  + 10x  - 2x  + 2x  - 10x ) \|- 1
+--R             + 
+--R                    11     10     9     8     7     6     5      4 18+---+13
+--R               (- 2x   - 2x   + 2x  + 2x  + 2x  - 2x  + 2x  - 10x ) \|- 1
+--R             + 
+--R                    11     10     9     8     7     6      5 18+---+11
+--R               (- 2x   + 2x   + 2x  + 2x  + 2x  - 2x  - 10x ) \|- 1
+--R             + 
+--R                  10     9     8     7     6 18+---+9
+--R               (2x   + 2x  + 2x  - 2x  - 2x ) \|- 1
+--R             + 
+--R                  9     8     7      5      4 18+---+7
+--R               (2x  - 2x  - 2x  + 12x  - 12x ) \|- 1
+--R             + 
+--R                    8      6      5 18+---+5
+--R               (- 2x  + 10x  - 12x ) \|- 1
+--R             + 
+--R                   7      6     5      3 18+---+3
+--R               (10x  - 14x  + 2x  + 12x ) \|- 1
+--R             + 
+--R                    8     7     6      5     4 18+---+
+--R               (- 2x  - 2x  + 2x  + 14x  + 2x ) \|- 1
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R               10      8      7      4 18+---+16
+--R           (18x   - 18x  + 18x  + 18x ) \|- 1
+--R         + 
+--R               11      9      8      5 18+---+14
+--R           (18x   - 18x  + 18x  + 18x ) \|- 1
+--R         + 
+--R                 10      9      6 18+---+12       8      7 18+---+10
+--R           (- 18x   + 18x  - 18x ) \|- 1    + (18x  - 36x ) \|- 1
+--R         + 
+--R               9      8 18+---+8       10      9      6 18+---+6
+--R           (18x  - 36x ) \|- 1   + (18x   - 18x  + 18x ) \|- 1
+--R         + 
+--R                 11      10      7      5      4 18+---+4
+--R           (- 18x   + 18x   + 18x  - 18x  + 18x ) \|- 1
+--R         + 
+--R                 12      11      8      6      5 18+---+2      13      12      9
+--R           (- 18x   + 18x   + 18x  - 18x  + 18x ) \|- 1   - 18x   + 18x   - 18x
+--R         + 
+--R                7      6      3
+--R           - 18x  + 18x  - 18x
+--R      *
+--R                    1   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  3
+--R     + 
+--R                        6     5     4      3     2          18+---+17
+--R                   (- 3x  + 3x  - 3x  - 21x  - 3x  - 3x + 3) \|- 1
+--R                 + 
+--R                        7     6     5      4      3     2           18+---+15
+--R                   (- 3x  - 3x  + 3x  - 21x  + 15x  - 3x  + 3x - 15) \|- 1
+--R                 + 
+--R                        8     7     6     5     4     3     2       18+---+13
+--R                   (- 3x  - 3x  + 3x  + 3x  + 3x  - 3x  + 3x  - 15x) \|- 1
+--R                 + 
+--R                        8     7     6     5     4     3      2 18+---+11
+--R                   (- 3x  + 3x  + 3x  + 3x  + 3x  - 3x  - 15x ) \|- 1
+--R                 + 
+--R                      7     6     5     4     3 18+---+9
+--R                   (3x  + 3x  + 3x  - 3x  - 3x ) \|- 1
+--R                 + 
+--R                      6     5     4      2       18+---+7
+--R                   (3x  - 3x  - 3x  + 18x  - 18x) \|- 1
+--R                 + 
+--R                        5      3      2 18+---+5
+--R                   (- 3x  + 15x  - 18x ) \|- 1
+--R                 + 
+--R                       4      3     2      18+---+3
+--R                   (15x  - 21x  + 3x  + 18) \|- 1
+--R                 + 
+--R                        5     4     3      2      18+---+
+--R                   (- 3x  - 3x  + 3x  + 21x  + 3x) \|- 1
+--R              *
+--R                  +-+
+--R                 \|3
+--R             + 
+--R                   7      5      4       18+---+16
+--R               (54x  - 54x  + 54x  + 54x) \|- 1
+--R             + 
+--R                   8      6      5      2 18+---+14
+--R               (54x  - 54x  + 54x  + 54x ) \|- 1
+--R             + 
+--R                     7      6      3 18+---+12       5       4 18+---+10
+--R               (- 54x  + 54x  - 54x ) \|- 1    + (54x  - 108x ) \|- 1
+--R             + 
+--R                   6       5 18+---+8       7      6      3 18+---+6
+--R               (54x  - 108x ) \|- 1   + (54x  - 54x  + 54x ) \|- 1
+--R             + 
+--R                     8      7      4      2       18+---+4
+--R               (- 54x  + 54x  + 54x  - 54x  + 54x) \|- 1
+--R             + 
+--R                     9      8      5      3      2 18+---+2      10      9
+--R               (- 54x  + 54x  + 54x  - 54x  + 54x ) \|- 1   - 54x   + 54x
+--R             + 
+--R                    6      4      3
+--R               - 54x  - 54x  + 54x  - 54
+--R          *
+--R                        1   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      3
+--R         + 
+--R                     10      8      7      4 18+---+16
+--R               (- 18x   + 18x  - 18x  - 18x ) \|- 1
+--R             + 
+--R                     11      9      8      5 18+---+14
+--R               (- 18x   + 18x  - 18x  - 18x ) \|- 1
+--R             + 
+--R                   10      9      6 18+---+12         8      7 18+---+10
+--R               (18x   - 18x  + 18x ) \|- 1    + (- 18x  + 36x ) \|- 1
+--R             + 
+--R                     9      8 18+---+8         10      9      6 18+---+6
+--R               (- 18x  + 36x ) \|- 1   + (- 18x   + 18x  - 18x ) \|- 1
+--R             + 
+--R                   11      10      7      5      4 18+---+4
+--R               (18x   - 18x   - 18x  + 18x  - 18x ) \|- 1
+--R             + 
+--R                   12      11      8      6      5 18+---+2      13      12
+--R               (18x   - 18x   - 18x  + 18x  - 18x ) \|- 1   + 18x   - 18x
+--R             + 
+--R                  9      7      6      3
+--R               18x  + 18x  - 18x  + 18x
+--R          *
+--R                            1
+--R                     atan(----)
+--R                           +-+
+--R              +-+         \|3
+--R             \|3 cos(----------)
+--R                          3
+--R      *
+--R                    1   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  3
+--R     + 
+--R                  9     8     7      6     5     4     3 18+---+17
+--R               (6x  - 6x  + 6x  + 42x  + 6x  + 6x  - 6x ) \|- 1
+--R             + 
+--R                  10     9     8      7      6     5     4      3 18+---+15
+--R               (6x   + 6x  - 6x  + 42x  - 30x  + 6x  - 6x  + 30x ) \|- 1
+--R             + 
+--R                  11     10     9     8     7     6     5      4 18+---+13
+--R               (6x   + 6x   - 6x  - 6x  - 6x  + 6x  - 6x  + 30x ) \|- 1
+--R             + 
+--R                  11     10     9     8     7     6      5 18+---+11
+--R               (6x   - 6x   - 6x  - 6x  - 6x  + 6x  + 30x ) \|- 1
+--R             + 
+--R                    10     9     8     7     6 18+---+9
+--R               (- 6x   - 6x  - 6x  + 6x  + 6x ) \|- 1
+--R             + 
+--R                    9     8     7      5      4 18+---+7
+--R               (- 6x  + 6x  + 6x  - 36x  + 36x ) \|- 1
+--R             + 
+--R                  8      6      5 18+---+5
+--R               (6x  - 30x  + 36x ) \|- 1
+--R             + 
+--R                     7      6     5      3 18+---+3
+--R               (- 30x  + 42x  - 6x  - 36x ) \|- 1
+--R             + 
+--R                  8     7     6      5     4 18+---+
+--R               (6x  + 6x  - 6x  - 42x  - 6x ) \|- 1
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R                 10      8      7      4 18+---+16
+--R           (- 54x   + 54x  - 54x  - 54x ) \|- 1
+--R         + 
+--R                 11      9      8      5 18+---+14
+--R           (- 54x   + 54x  - 54x  - 54x ) \|- 1
+--R         + 
+--R               10      9      6 18+---+12         8       7 18+---+10
+--R           (54x   - 54x  + 54x ) \|- 1    + (- 54x  + 108x ) \|- 1
+--R         + 
+--R                 9       8 18+---+8         10      9      6 18+---+6
+--R           (- 54x  + 108x ) \|- 1   + (- 54x   + 54x  - 54x ) \|- 1
+--R         + 
+--R               11      10      7      5      4 18+---+4
+--R           (54x   - 54x   - 54x  + 54x  - 54x ) \|- 1
+--R         + 
+--R               12      11      8      6      5 18+---+2      13      12      9
+--R           (54x   - 54x   - 54x  + 54x  - 54x ) \|- 1   + 54x   - 54x   + 54x
+--R         + 
+--R              7      6      3
+--R           54x  - 54x  + 54x
+--R      *
+--R                    1   2           1
+--R             atan(----)      atan(----)
+--R                   +-+             +-+
+--R                  \|3             \|3
+--R         cos(----------) sin(----------)
+--R                  3               3
+--R     + 
+--R                   6    5    4     3    2         18+---+17
+--R               (- x  + x  - x  - 7x  - x  - x + 1) \|- 1
+--R             + 
+--R                   7    6    5     4     3    2         18+---+15
+--R               (- x  - x  + x  - 7x  + 5x  - x  + x - 5) \|- 1
+--R             + 
+--R                   8    7    6    5    4    3    2      18+---+13
+--R               (- x  - x  + x  + x  + x  - x  + x  - 5x) \|- 1
+--R             + 
+--R                   8    7    6    5    4    3     2 18+---+11
+--R               (- x  + x  + x  + x  + x  - x  - 5x ) \|- 1
+--R             + 
+--R                 7    6    5    4    3 18+---+9
+--R               (x  + x  + x  - x  - x ) \|- 1
+--R             + 
+--R                 6    5    4     2      18+---+7       5     3     2 18+---+5
+--R               (x  - x  - x  + 6x  - 6x) \|- 1   + (- x  + 5x  - 6x ) \|- 1
+--R             + 
+--R                  4     3    2     18+---+3       5    4    3     2     18+---+
+--R               (5x  - 7x  + x  + 6) \|- 1   + (- x  - x  + x  + 7x  + x) \|- 1
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R               7      5      4       18+---+16
+--R           (18x  - 18x  + 18x  + 18x) \|- 1
+--R         + 
+--R               8      6      5      2 18+---+14
+--R           (18x  - 18x  + 18x  + 18x ) \|- 1
+--R         + 
+--R                 7      6      3 18+---+12       5      4 18+---+10
+--R           (- 18x  + 18x  - 18x ) \|- 1    + (18x  - 36x ) \|- 1
+--R         + 
+--R               6      5 18+---+8       7      6      3 18+---+6
+--R           (18x  - 36x ) \|- 1   + (18x  - 18x  + 18x ) \|- 1
+--R         + 
+--R                 8      7      4      2       18+---+4
+--R           (- 18x  + 18x  + 18x  - 18x  + 18x) \|- 1
+--R         + 
+--R                 9      8      5      3      2 18+---+2      10      9      6
+--R           (- 18x  + 18x  + 18x  - 18x  + 18x ) \|- 1   - 18x   + 18x  - 18x
+--R         + 
+--R                4      3
+--R           - 18x  + 18x  - 18
+--R      *
+--R                    1   6
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         cos(----------)
+--R                  3
+--R     + 
+--R              10     8     7     4 18+---+16      11     9     8     5 18+---+14
+--R           (6x   - 6x  + 6x  + 6x ) \|- 1    + (6x   - 6x  + 6x  + 6x ) \|- 1
+--R         + 
+--R                10     9     6 18+---+12      8      7 18+---+10
+--R           (- 6x   + 6x  - 6x ) \|- 1    + (6x  - 12x ) \|- 1
+--R         + 
+--R              9      8 18+---+8      10     9     6 18+---+6
+--R           (6x  - 12x ) \|- 1   + (6x   - 6x  + 6x ) \|- 1
+--R         + 
+--R                11     10     7     5     4 18+---+4
+--R           (- 6x   + 6x   + 6x  - 6x  + 6x ) \|- 1
+--R         + 
+--R                12     11     8     6     5 18+---+2     13     12     9     7
+--R           (- 6x   + 6x   + 6x  - 6x  + 6x ) \|- 1   - 6x   + 6x   - 6x  - 6x
+--R         + 
+--R             6     3
+--R           6x  - 6x
+--R      *
+--R                        1   3
+--R                 atan(----)
+--R                       +-+
+--R          +-+         \|3
+--R         \|3 cos(----------)
+--R                      3
+--R     + 
+--R               12    11    10     9    8    7    6 18+---+17
+--R           (- x   + x   - x   - 7x  - x  - x  + x ) \|- 1
+--R         + 
+--R               13    12    11     10     9    8    7     6 18+---+15
+--R           (- x   - x   + x   - 7x   + 5x  - x  + x  - 5x ) \|- 1
+--R         + 
+--R               14    13    12    11    10    9    8     7 18+---+13
+--R           (- x   - x   + x   + x   + x   - x  + x  - 5x ) \|- 1
+--R         + 
+--R               14    13    12    11    10    9     8 18+---+11
+--R           (- x   + x   + x   + x   + x   - x  - 5x ) \|- 1
+--R         + 
+--R             13    12    11    10    9 18+---+9
+--R           (x   + x   + x   - x   - x ) \|- 1
+--R         + 
+--R             12    11    10     8     7 18+---+7       11     9     8 18+---+5
+--R           (x   - x   - x   + 6x  - 6x ) \|- 1   + (- x   + 5x  - 6x ) \|- 1
+--R         + 
+--R            10     9    8     6 18+---+3       11    10    9     8    7 18+---+
+--R         (5x   - 7x  + x  + 6x ) \|- 1   + (- x   - x   + x  + 7x  + x ) \|- 1
+--R      *
+--R          +-+
+--R         \|3
+--R  /
+--R               7      5      4       18+---+16
+--R           (18x  - 18x  + 18x  + 18x) \|- 1
+--R         + 
+--R               8      6      5      2 18+---+14
+--R           (18x  - 18x  + 18x  + 18x ) \|- 1
+--R         + 
+--R                 7      6      3 18+---+12       5      4 18+---+10
+--R           (- 18x  + 18x  - 18x ) \|- 1    + (18x  - 36x ) \|- 1
+--R         + 
+--R               6      5 18+---+8       7      6      3 18+---+6
+--R           (18x  - 36x ) \|- 1   + (18x  - 18x  + 18x ) \|- 1
+--R         + 
+--R                 8      7      4      2       18+---+4
+--R           (- 18x  + 18x  + 18x  - 18x  + 18x) \|- 1
+--R         + 
+--R                 9      8      5      3      2 18+---+2      10      9      6
+--R           (- 18x  + 18x  + 18x  - 18x  + 18x ) \|- 1   - 18x   + 18x  - 18x
+--R         + 
+--R                4      3
+--R           - 18x  + 18x  - 18
+--R      *
+--R                    1   6
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  3
+--R     + 
+--R               7      5      4       18+---+16
+--R           (54x  - 54x  + 54x  + 54x) \|- 1
+--R         + 
+--R               8      6      5      2 18+---+14
+--R           (54x  - 54x  + 54x  + 54x ) \|- 1
+--R         + 
+--R                 7      6      3 18+---+12       5       4 18+---+10
+--R           (- 54x  + 54x  - 54x ) \|- 1    + (54x  - 108x ) \|- 1
+--R         + 
+--R               6       5 18+---+8       7      6      3 18+---+6
+--R           (54x  - 108x ) \|- 1   + (54x  - 54x  + 54x ) \|- 1
+--R         + 
+--R                 8      7      4      2       18+---+4
+--R           (- 54x  + 54x  + 54x  - 54x  + 54x) \|- 1
+--R         + 
+--R                 9      8      5      3      2 18+---+2      10      9      6
+--R           (- 54x  + 54x  + 54x  - 54x  + 54x ) \|- 1   - 54x   + 54x  - 54x
+--R         + 
+--R                4      3
+--R           - 54x  + 54x  - 54
+--R      *
+--R                    1   2           1   4
+--R             atan(----)      atan(----)
+--R                   +-+             +-+
+--R                  \|3             \|3
+--R         cos(----------) sin(----------)
+--R                  3               3
+--R     + 
+--R               10      8      7      4 18+---+16
+--R           (36x   - 36x  + 36x  + 36x ) \|- 1
+--R         + 
+--R               11      9      8      5 18+---+14
+--R           (36x   - 36x  + 36x  + 36x ) \|- 1
+--R         + 
+--R                 10      9      6 18+---+12       8      7 18+---+10
+--R           (- 36x   + 36x  - 36x ) \|- 1    + (36x  - 72x ) \|- 1
+--R         + 
+--R               9      8 18+---+8       10      9      6 18+---+6
+--R           (36x  - 72x ) \|- 1   + (36x   - 36x  + 36x ) \|- 1
+--R         + 
+--R                 11      10      7      5      4 18+---+4
+--R           (- 36x   + 36x   + 36x  - 36x  + 36x ) \|- 1
+--R         + 
+--R                 12      11      8      6      5 18+---+2      13      12      9
+--R           (- 36x   + 36x   + 36x  - 36x  + 36x ) \|- 1   - 36x   + 36x   - 36x
+--R         + 
+--R                7      6      3
+--R           - 36x  + 36x  - 36x
+--R      *
+--R                    1   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  3
+--R     + 
+--R               7      5      4       18+---+16
+--R           (54x  - 54x  + 54x  + 54x) \|- 1
+--R         + 
+--R               8      6      5      2 18+---+14
+--R           (54x  - 54x  + 54x  + 54x ) \|- 1
+--R         + 
+--R                 7      6      3 18+---+12       5       4 18+---+10
+--R           (- 54x  + 54x  - 54x ) \|- 1    + (54x  - 108x ) \|- 1
+--R         + 
+--R               6       5 18+---+8       7      6      3 18+---+6
+--R           (54x  - 108x ) \|- 1   + (54x  - 54x  + 54x ) \|- 1
+--R         + 
+--R                 8      7      4      2       18+---+4
+--R           (- 54x  + 54x  + 54x  - 54x  + 54x) \|- 1
+--R         + 
+--R                 9      8      5      3      2 18+---+2      10      9      6
+--R           (- 54x  + 54x  + 54x  - 54x  + 54x ) \|- 1   - 54x   + 54x  - 54x
+--R         + 
+--R                4      3
+--R           - 54x  + 54x  - 54
+--R      *
+--R                    1   4           1   2
+--R             atan(----)      atan(----)
+--R                   +-+             +-+
+--R                  \|3             \|3
+--R         cos(----------) sin(----------)
+--R                  3               3
+--R     + 
+--R                  10       8       7       4 18+---+16
+--R           (- 108x   + 108x  - 108x  - 108x ) \|- 1
+--R         + 
+--R                  11       9       8       5 18+---+14
+--R           (- 108x   + 108x  - 108x  - 108x ) \|- 1
+--R         + 
+--R                10       9       6 18+---+12          8       7 18+---+10
+--R           (108x   - 108x  + 108x ) \|- 1    + (- 108x  + 216x ) \|- 1
+--R         + 
+--R                  9       8 18+---+8          10       9       6 18+---+6
+--R           (- 108x  + 216x ) \|- 1   + (- 108x   + 108x  - 108x ) \|- 1
+--R         + 
+--R                11       10       7       5       4 18+---+4
+--R           (108x   - 108x   - 108x  + 108x  - 108x ) \|- 1
+--R         + 
+--R                12       11       8       6       5 18+---+2       13       12
+--R           (108x   - 108x   - 108x  + 108x  - 108x ) \|- 1   + 108x   - 108x
+--R         + 
+--R               9       7       6       3
+--R           108x  + 108x  - 108x  + 108x
+--R      *
+--R                    1   2           1
+--R             atan(----)      atan(----)
+--R                   +-+             +-+
+--R                  \|3             \|3
+--R         cos(----------) sin(----------)
+--R                  3               3
+--R     + 
+--R               7      5      4       18+---+16
+--R           (18x  - 18x  + 18x  + 18x) \|- 1
+--R         + 
+--R               8      6      5      2 18+---+14
+--R           (18x  - 18x  + 18x  + 18x ) \|- 1
+--R         + 
+--R                 7      6      3 18+---+12       5      4 18+---+10
+--R           (- 18x  + 18x  - 18x ) \|- 1    + (18x  - 36x ) \|- 1
+--R         + 
+--R               6      5 18+---+8       7      6      3 18+---+6
+--R           (18x  - 36x ) \|- 1   + (18x  - 18x  + 18x ) \|- 1
+--R         + 
+--R                 8      7      4      2       18+---+4
+--R           (- 18x  + 18x  + 18x  - 18x  + 18x) \|- 1
+--R         + 
+--R                 9      8      5      3      2 18+---+2      10      9      6
+--R           (- 18x  + 18x  + 18x  - 18x  + 18x ) \|- 1   - 18x   + 18x  - 18x
+--R         + 
+--R                4      3
+--R           - 18x  + 18x  - 18
+--R      *
+--R                    1   6
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         cos(----------)
+--R                  3
+--R     + 
+--R           13      11      10      7 18+---+16
+--R       (18x   - 18x   + 18x   + 18x ) \|- 1
+--R     + 
+--R           14      12      11      8 18+---+14
+--R       (18x   - 18x   + 18x   + 18x ) \|- 1
+--R     + 
+--R             13      12      9 18+---+12       11      10 18+---+10
+--R       (- 18x   + 18x   - 18x ) \|- 1    + (18x   - 36x  ) \|- 1
+--R     + 
+--R           12      11 18+---+8       13      12      9 18+---+6
+--R       (18x   - 36x  ) \|- 1   + (18x   - 18x   + 18x ) \|- 1
+--R     + 
+--R             14      13      10      8      7 18+---+4
+--R       (- 18x   + 18x   + 18x   - 18x  + 18x ) \|- 1
+--R     + 
+--R             15      14      11      9      8 18+---+2      16      15      12
+--R       (- 18x   + 18x   + 18x   - 18x  + 18x ) \|- 1   - 18x   + 18x   - 18x
+--R     + 
+--R            10      9      6
+--R       - 18x   + 18x  - 18x
+--R                                                    Type: Expression(Integer)
+--E 885
+
+)clear all
+
+--S 886 of 2282
+t0:=1/(x*(1-x^3+x^6))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         7    4
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 886
+
+--S 887 of 2282
+r0:=log(x)-1/6*log(1-x^3+x^6)-1/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                        3      +-+
+--R           +-+     6    3          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 6\|3 log(x) + 2atan(-------------)
+--R                                                           3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   6\|3
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        3      +-+
+--R           +-+     6    3          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 6\|3 log(x) + 2atan(-------------)
+--R                                                           3
+--R   (3)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 888
+
+--S 889 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 889
+
+--S 890 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 890
+
+)clear all
+
+--S 891 of 2282
+t0:=1/(x^2*(1-x^3+x^6))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         8    5    2
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 891
+
+--S 892 of 2282
+r0:=(-1)/x+1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))-_
+   1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*_
+   sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3+%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))-1/3*atan((4*x+2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*sqrt(3)))*_
+   (%i+sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))
+--R 
+--R
+--R   (2)
+--R                         +------------+
+--R               +-+      3|     +-+
+--R         (%i x\|3  + 3x)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                          +------------+     +----------+
+--R                +-+      3|     +-+         3|   +-+         3+-+
+--R       (- 2%i x\|3  - 6x)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                           +----------+
+--R                 +-+      3|   +-+
+--R         (- %i x\|3  + 3x)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                        +----------+     +------------+
+--R              +-+      3|   +-+         3|     +-+         3+-+
+--R       (2%i x\|3  - 6x)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                  +------------+
+--R                          +----------+     3+-+2 3|     +-+
+--R             +-+         3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (- 6x\|3  + 6%i x)\|%i\|3  + 1 atan(-------------------------)
+--R                                                      +------------+
+--R                                            3+-+2 +-+3|     +-+
+--R                                            \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                    +----------+
+--R                          +------------+     3+-+2 3|   +-+
+--R             +-+         3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (- 6x\|3  - 6%i x)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                        +----------+
+--R                                              3+-+2 +-+3|   +-+
+--R                                              \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                  +------------+ +----------+
+--R           3+-+2 3|     +-+     3|   +-+
+--R       - 18\|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R  /
+--R                +------------+ +----------+
+--R         3+-+2 3|     +-+     3|   +-+
+--R     18x \|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 892
+
+--S 893 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       1
+--R                atan(----)
+--R                      +-+
+--R                     \|3
+--R         2x cos(----------)
+--R                     3
+--R      *
+--R         log
+--R                         1   4                1   2                 1   2
+--R                  atan(----)           atan(----)            atan(----)
+--R                        +-+                  +-+                   +-+
+--R                       \|3                  \|3                   \|3
+--R              sin(----------)  + (2cos(----------)  + 2x)sin(----------)
+--R                       3                    3                     3
+--R            + 
+--R                         1   4                 1   2
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3                   \|3        2
+--R              cos(----------)  - 2x cos(----------)  + x
+--R                       3                     3
+--R     + 
+--R                          1                   1
+--R                   atan(----)          atan(----)
+--R                         +-+                 +-+
+--R            +-+         \|3                 \|3
+--R         (x\|3 sin(----------) - x cos(----------))
+--R                        3                   3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                               1              1                 1   4
+--R                        atan(----)     atan(----)        atan(----)
+--R                              +-+            +-+               +-+
+--R                 +-+         \|3            \|3               \|3
+--R              2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                             3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                            1                   1
+--R                     atan(----)          atan(----)
+--R                           +-+                 +-+
+--R              +-+         \|3                 \|3
+--R         (- x\|3 sin(----------) - x cos(----------))
+--R                          3                   3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                                 1              1                 1   4
+--R                          atan(----)     atan(----)        atan(----)
+--R                                +-+            +-+               +-+
+--R                   +-+         \|3            \|3               \|3
+--R              - 2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                               3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                          1                       1
+--R                   atan(----)              atan(----)
+--R                         +-+                     +-+
+--R                        \|3         +-+         \|3
+--R         (- 2x sin(----------) - 2x\|3 cos(----------))
+--R                        3                       3
+--R      *
+--R         atan
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  + 2cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3
+--R                - \|3 cos(----------)
+--R                               3
+--R           /
+--R                           1   2                   1              1
+--R                    atan(----)              atan(----)     atan(----)
+--R                          +-+                     +-+            +-+
+--R                         \|3         +-+         \|3            \|3
+--R                sin(----------)  - 2\|3 cos(----------)sin(----------)
+--R                         3                       3              3
+--R              + 
+--R                             1   2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                - cos(----------)  - 2x
+--R                           3
+--R     + 
+--R                        1                       1
+--R                 atan(----)              atan(----)
+--R                       +-+                     +-+
+--R                      \|3         +-+         \|3
+--R         (2x sin(----------) - 2x\|3 cos(----------))
+--R                      3                       3
+--R      *
+--R         atan
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  - 2cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3
+--R                - \|3 cos(----------)
+--R                               3
+--R           /
+--R                           1   2                   1              1
+--R                    atan(----)              atan(----)     atan(----)
+--R                          +-+                     +-+            +-+
+--R                         \|3         +-+         \|3            \|3
+--R                sin(----------)  + 2\|3 cos(----------)sin(----------)
+--R                         3                       3              3
+--R              + 
+--R                             1   2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                - cos(----------)  - 2x
+--R                           3
+--R     + 
+--R                                              1              1
+--R                                       atan(----)     atan(----)
+--R                     1                       +-+            +-+
+--R              atan(----)                    \|3            \|3
+--R                    +-+           2cos(----------)sin(----------)
+--R                   \|3                      3              3               +-+
+--R       4x sin(----------)atan(---------------------------------------) - 6\|3
+--R                   3                     1   2              1   2
+--R                                  atan(----)         atan(----)
+--R                                        +-+                +-+
+--R                                       \|3                \|3
+--R                              sin(----------)  - cos(----------)  + x
+--R                                       3                  3
+--R  /
+--R        +-+
+--R     6x\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 893
+
+--S 894 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +------------+
+--R             +-+      3|     +-+
+--R         (- \|3  - %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +------------+     +----------+
+--R          +-+       3|     +-+         3|   +-+         3+-+
+--R       (2\|3  + 2%i)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                       +----------+
+--R             +-+      3|   +-+
+--R         (- \|3  + %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+     +------------+
+--R          +-+       3|   +-+         3|     +-+         3+-+
+--R       (2\|3  - 2%i)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                        +------------+ +----------+
+--R          3+-+2    %pi 3|     +-+     3|   +-+
+--R         2\|2  cos(---)\|- %i\|3  + 1 \|%i\|3  + 1
+--R                    18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2          %pi 2       %pi 4          %pi 2
+--R              sin(---)  + (2cos(---)  + 2x)sin(---)  + cos(---)  - 2x cos(---)
+--R                   18            18             18          18             18
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R                                             +------------+ +----------+
+--R          3+-+2 +-+    %pi    3+-+2    %pi  3|     +-+     3|   +-+
+--R         (\|2  \|3 sin(---) - \|2  cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                        18              18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2         %pi 2      +-+    %pi     %pi
+--R              sin(---)  + (2cos(---)  - x)sin(---)  + 2x\|3 cos(---)sin(---)
+--R                   18            18            18                18      18
+--R            + 
+--R                  %pi 4         %pi 2    2
+--R              cos(---)  + x cos(---)  + x
+--R                   18            18
+--R     + 
+--R                                               +------------+ +----------+
+--R            3+-+2 +-+    %pi    3+-+2    %pi  3|     +-+     3|   +-+
+--R         (- \|2  \|3 sin(---) - \|2  cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                          18              18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2         %pi 2      +-+    %pi     %pi
+--R              sin(---)  + (2cos(---)  - x)sin(---)  - 2x\|3 cos(---)sin(---)
+--R                   18            18            18                18      18
+--R            + 
+--R                  %pi 4         %pi 2    2
+--R              cos(---)  + x cos(---)  + x
+--R                   18            18
+--R     + 
+--R                                                 +------------+ +----------+
+--R             3+-+2    %pi     3+-+2 +-+    %pi  3|     +-+     3|   +-+
+--R         (- 2\|2  sin(---) - 2\|2  \|3 cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                       18                   18
+--R      *
+--R                +-+    %pi 2        %pi     %pi     +-+    %pi 2
+--R               \|3 sin(---)  + 2cos(---)sin(---) - \|3 cos(---)
+--R                        18           18      18             18
+--R         atan(--------------------------------------------------)
+--R                  %pi 2     +-+    %pi     %pi        %pi 2
+--R              sin(---)  - 2\|3 cos(---)sin(---) - cos(---)  - 2x
+--R                   18               18      18         18
+--R     + 
+--R                                               +------------+ +----------+
+--R           3+-+2    %pi     3+-+2 +-+    %pi  3|     +-+     3|   +-+
+--R         (2\|2  sin(---) - 2\|2  \|3 cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                     18                   18
+--R      *
+--R                +-+    %pi 2        %pi     %pi     +-+    %pi 2
+--R               \|3 sin(---)  - 2cos(---)sin(---) - \|3 cos(---)
+--R                        18           18      18             18
+--R         atan(--------------------------------------------------)
+--R                  %pi 2     +-+    %pi     %pi        %pi 2
+--R              sin(---)  + 2\|3 cos(---)sin(---) - cos(---)  - 2x
+--R                   18               18      18         18
+--R     + 
+--R                                               +------------+
+--R                       +----------+     3+-+2 3|     +-+
+--R              +-+     3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (- 2%i\|3  + 6)\|%i\|3  + 1 atan(-------------------------)
+--R                                                   +------------+
+--R                                         3+-+2 +-+3|     +-+
+--R                                         \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                               +----------+
+--R                     +------------+     3+-+2 3|   +-+
+--R            +-+     3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (2%i\|3  + 6)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                   +----------+
+--R                                         3+-+2 +-+3|   +-+
+--R                                         \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                             %pi     %pi
+--R                    +------------+ +----------+         2cos(---)sin(---)
+--R      3+-+2    %pi 3|     +-+     3|   +-+                    18      18
+--R     4\|2  sin(---)\|- %i\|3  + 1 \|%i\|3  + 1 atan(-------------------------)
+--R                18                                      %pi 2       %pi 2
+--R                                                    sin(---)  - cos(---)  + x
+--R                                                         18          18
+--R  /
+--R                +------------+ +----------+
+--R      3+-+2 +-+3|     +-+     3|   +-+
+--R     6\|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 894
+
+--S 895 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                  8     5 3+-+    %pi 12       8      5 3+-+    %pi 2    %pi 10
+--R               (6x  - 6x )\|2 sin(---)   + (36x  - 36x )\|2 cos(---) sin(---)
+--R                                   18                            18       18
+--R             + 
+--R                       8      5 3+-+    %pi 4
+--R                   (90x  - 90x )\|2 cos(---)
+--R                                         18
+--R                 + 
+--R                       11      8      5 3+-+ +-+    %pi
+--R                   (12x   - 12x  + 12x )\|2 \|3 cos(---)
+--R                                                     18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        8       5 3+-+    %pi 6
+--R                   (120x  - 120x )\|2 cos(---)
+--R                                           18
+--R                 + 
+--R                       11      8      5 3+-+ +-+    %pi 3       11      8 3+-+
+--R                   (32x   - 32x  + 32x )\|2 \|3 cos(---)  + (12x   - 12x )\|2
+--R                                                     18
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       8      5 3+-+    %pi 8
+--R                   (90x  - 90x )\|2 cos(---)
+--R                                         18
+--R                 + 
+--R                       11      8      5 3+-+ +-+    %pi 5
+--R                   (24x   - 24x  + 24x )\|2 \|3 cos(---)
+--R                                                     18
+--R                 + 
+--R                          11       8 3+-+    %pi 2
+--R                   (- 180x   + 180x )\|2 cos(---)
+--R                                              18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       8      5 3+-+    %pi 10        11       8 3+-+    %pi 4
+--R                   (36x  - 36x )\|2 cos(---)   + (180x   - 180x )\|2 cos(---)
+--R                                         18                               18
+--R                 + 
+--R                         14      11      8 3+-+ +-+    %pi
+--R                   (- 12x   + 12x   - 12x )\|2 \|3 cos(---)
+--R                                                        18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                  8     5 3+-+    %pi 12        11     8     5 3+-+ +-+    %pi 9
+--R               (6x  - 6x )\|2 cos(---)   + (- 4x   + 4x  - 4x )\|2 \|3 cos(---)
+--R                                   18                                       18
+--R             + 
+--R                     11      8 3+-+    %pi 6
+--R               (- 12x   + 12x )\|2 cos(---)
+--R                                        18
+--R             + 
+--R                  14     11     8 3+-+ +-+    %pi 3      14     11 3+-+
+--R               (4x   - 4x   + 4x )\|2 \|3 cos(---)  + (6x   - 6x  )\|2
+--R                                               18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                        6        3 3+-+2 +-+      6     3 3+-+2     %pi 12
+--R               ((- 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x )\|2  )sin(---)
+--R                                                                     18
+--R             + 
+--R                           6         3 3+-+2 +-+       6      3 3+-+2     %pi 2
+--R                 ((- 18%i x  + 18%i x )\|2  \|3  + (18x  - 18x )\|2  )cos(---)
+--R                                                                           18
+--R              *
+--R                     %pi 10
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               6         3 3+-+2 +-+       6      3 3+-+2
+--R                     ((- 45%i x  + 45%i x )\|2  \|3  + (45x  - 45x )\|2  )
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                          9     6     3 3+-+2 +-+
+--R                       (6x  - 6x  + 6x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 18%i x  + 18%i x  - 18%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               6         3 3+-+2 +-+       6      3 3+-+2
+--R                     ((- 60%i x  + 60%i x )\|2  \|3  + (60x  - 60x )\|2  )
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           9      6      3 3+-+2 +-+
+--R                       (16x  - 16x  + 16x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 48%i x  + 48%i x  - 48%i x )\|2
+--R                  *
+--R                         %pi 3
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           9        6 3+-+2 +-+      9     6 3+-+2
+--R                   (- 6%i x  + 6%i x )\|2  \|3  + (6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               6         3 3+-+2 +-+       6      3 3+-+2
+--R                     ((- 45%i x  + 45%i x )\|2  \|3  + (45x  - 45x )\|2  )
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           9      6      3 3+-+2 +-+
+--R                       (12x  - 12x  + 12x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 36%i x  + 36%i x  - 36%i x )\|2
+--R                  *
+--R                         %pi 5
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                         9         6 3+-+2 +-+         9      6 3+-+2     %pi 2
+--R                 ((90%i x  - 90%i x )\|2  \|3  + (- 90x  + 90x )\|2  )cos(---)
+--R                                                                           18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               6         3 3+-+2 +-+       6      3 3+-+2
+--R                     ((- 18%i x  + 18%i x )\|2  \|3  + (18x  - 18x )\|2  )
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                               9         6 3+-+2 +-+       9      6 3+-+2
+--R                     ((- 90%i x  + 90%i x )\|2  \|3  + (90x  - 90x )\|2  )
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                            12     9     6 3+-+2 +-+
+--R                       (- 6x   + 6x  - 6x )\|2  \|3
+--R                     + 
+--R                              12         9         6 3+-+2
+--R                       (18%i x   - 18%i x  + 18%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        6        3 3+-+2 +-+      6     3 3+-+2     %pi 12
+--R               ((- 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x )\|2  )cos(---)
+--R                                                                     18
+--R             + 
+--R                          9     6     3 3+-+2 +-+
+--R                     (- 2x  + 2x  - 2x )\|2  \|3
+--R                   + 
+--R                           9        6        3 3+-+2
+--R                     (6%i x  - 6%i x  + 6%i x )\|2
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      9        6 3+-+2 +-+        9     6 3+-+2     %pi 6
+--R               ((6%i x  - 6%i x )\|2  \|3  + (- 6x  + 6x )\|2  )cos(---)
+--R                                                                     18
+--R             + 
+--R                      12     9     6 3+-+2 +-+
+--R                   (2x   - 2x  + 2x )\|2  \|3
+--R                 + 
+--R                           12        9        6 3+-+2
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       12        9 3+-+2 +-+      12     9 3+-+2
+--R               (- 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x )\|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    7        4  +-+     7     4     %pi 12
+--R           ((- 6%i x  + 6%i x )\|3  + 6x  - 6x )sin(---)
+--R                                                     18
+--R         + 
+--R                     7         4  +-+      7      4     %pi 2    %pi 10
+--R           ((- 36%i x  + 36%i x )\|3  + 36x  - 36x )cos(---) sin(---)
+--R                                                         18       18
+--R         + 
+--R                         7         4  +-+      7      4     %pi 4
+--R               ((- 90%i x  + 90%i x )\|3  + 90x  - 90x )cos(---)
+--R                                                             18
+--R             + 
+--R                  10      7      4  +-+         10         7         4     %pi
+--R             ((12x   - 12x  + 12x )\|3  - 36%i x   + 36%i x  - 36%i x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          7          4  +-+       7       4     %pi 6
+--R               ((- 120%i x  + 120%i x )\|3  + 120x  - 120x )cos(---)
+--R                                                                 18
+--R             + 
+--R                      10      7      4  +-+         10         7         4
+--R                 ((32x   - 32x  + 32x )\|3  - 96%i x   + 96%i x  - 96%i x )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        10         7  +-+      10      7
+--R               (- 12%i x   + 12%i x )\|3  + 12x   - 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         7         4  +-+      7      4     %pi 8
+--R               ((- 90%i x  + 90%i x )\|3  + 90x  - 90x )cos(---)
+--R                                                             18
+--R             + 
+--R                      10      7      4  +-+         10         7         4
+--R                 ((24x   - 24x  + 24x )\|3  - 72%i x   + 72%i x  - 72%i x )
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        10          7  +-+       10       7     %pi 2
+--R               ((180%i x   - 180%i x )\|3  - 180x   + 180x )cos(---)
+--R                                                                 18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         7         4  +-+      7      4     %pi 10
+--R               ((- 36%i x  + 36%i x )\|3  + 36x  - 36x )cos(---)
+--R                                                             18
+--R             + 
+--R                          10          7  +-+       10       7     %pi 4
+--R               ((- 180%i x   + 180%i x )\|3  + 180x   - 180x )cos(---)
+--R                                                                   18
+--R             + 
+--R                        13      10      7  +-+         13         10         7
+--R                 ((- 12x   + 12x   - 12x )\|3  + 36%i x   - 36%i x   + 36%i x )
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7        4  +-+     7     4     %pi 12
+--R           ((- 6%i x  + 6%i x )\|3  + 6x  - 6x )cos(---)
+--R                                                     18
+--R         + 
+--R                 10     7     4  +-+         10         7         4     %pi 9
+--R           ((- 4x   + 4x  - 4x )\|3  + 12%i x   - 12%i x  + 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                   10         7  +-+      10      7     %pi 6
+--R           ((12%i x   - 12%i x )\|3  - 12x   + 12x )cos(---)
+--R                                                         18
+--R         + 
+--R               13     10     7  +-+         13         10         7     %pi 3
+--R           ((4x   - 4x   + 4x )\|3  - 12%i x   + 12%i x   - 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                   13        10  +-+     13     10
+--R           (- 6%i x   + 6%i x  )\|3  + 6x   - 6x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                      6        3 3+-+2 +-+      6     3 3+-+2     %pi 12
+--R               ((3%i x  - 3%i x )\|2  \|3  + (3x  - 3x )\|2  )sin(---)
+--R                                                                   18
+--R             + 
+--R                         6         3 3+-+2 +-+       6      3 3+-+2     %pi 2
+--R                 ((18%i x  - 18%i x )\|2  \|3  + (18x  - 18x )\|2  )cos(---)
+--R                                                                         18
+--R              *
+--R                     %pi 10
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           6         3 3+-+2 +-+       6      3 3+-+2     %pi 4
+--R                   ((45%i x  - 45%i x )\|2  \|3  + (45x  - 45x )\|2  )cos(---)
+--R                                                                           18
+--R                 + 
+--R                          9     6     3 3+-+2 +-+
+--R                       (6x  - 6x  + 6x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (18%i x  - 18%i x  + 18%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           6         3 3+-+2 +-+       6      3 3+-+2     %pi 6
+--R                   ((60%i x  - 60%i x )\|2  \|3  + (60x  - 60x )\|2  )cos(---)
+--R                                                                           18
+--R                 + 
+--R                           9      6      3 3+-+2 +-+
+--R                       (16x  - 16x  + 16x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (48%i x  - 48%i x  + 48%i x )\|2
+--R                  *
+--R                         %pi 3
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                         9        6 3+-+2 +-+      9     6 3+-+2
+--R                   (6%i x  - 6%i x )\|2  \|3  + (6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           6         3 3+-+2 +-+       6      3 3+-+2     %pi 8
+--R                   ((45%i x  - 45%i x )\|2  \|3  + (45x  - 45x )\|2  )cos(---)
+--R                                                                           18
+--R                 + 
+--R                           9      6      3 3+-+2 +-+
+--R                       (12x  - 12x  + 12x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (36%i x  - 36%i x  + 36%i x )\|2
+--R                  *
+--R                         %pi 5
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                               9         6 3+-+2 +-+         9      6 3+-+2
+--R                     ((- 90%i x  + 90%i x )\|2  \|3  + (- 90x  + 90x )\|2  )
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           6         3 3+-+2 +-+       6      3 3+-+2     %pi 10
+--R                   ((18%i x  - 18%i x )\|2  \|3  + (18x  - 18x )\|2  )cos(---)
+--R                                                                           18
+--R                 + 
+--R                           9         6 3+-+2 +-+       9      6 3+-+2     %pi 4
+--R                   ((90%i x  - 90%i x )\|2  \|3  + (90x  - 90x )\|2  )cos(---)
+--R                                                                           18
+--R                 + 
+--R                            12     9     6 3+-+2 +-+
+--R                       (- 6x   + 6x  - 6x )\|2  \|3
+--R                     + 
+--R                                12         9         6 3+-+2
+--R                       (- 18%i x   + 18%i x  - 18%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                      6        3 3+-+2 +-+      6     3 3+-+2     %pi 12
+--R               ((3%i x  - 3%i x )\|2  \|3  + (3x  - 3x )\|2  )cos(---)
+--R                                                                   18
+--R             + 
+--R                        9     6     3 3+-+2 +-+
+--R                   (- 2x  + 2x  - 2x )\|2  \|3
+--R                 + 
+--R                           9        6        3 3+-+2
+--R                   (- 6%i x  + 6%i x  - 6%i x )\|2
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        9        6 3+-+2 +-+        9     6 3+-+2     %pi 6
+--R               ((- 6%i x  + 6%i x )\|2  \|3  + (- 6x  + 6x )\|2  )cos(---)
+--R                                                                       18
+--R             + 
+--R                        12     9     6 3+-+2 +-+
+--R                     (2x   - 2x  + 2x )\|2  \|3
+--R                   + 
+--R                           12        9        6 3+-+2
+--R                     (6%i x   - 6%i x  + 6%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     12        9 3+-+2 +-+      12     9 3+-+2
+--R               (3%i x   - 3%i x )\|2  \|3  + (3x   - 3x )\|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   4           %pi 12       4           %pi 2    %pi 10
+--R               (12x  - 12x)sin(---)   + (72x  - 72x)cos(---) sin(---)
+--R                                18                       18       18
+--R             + 
+--R                       4            %pi 4       7      4        +-+    %pi
+--R                 ((180x  - 180x)cos(---)  + (24x  - 24x  + 24x)\|3 cos(---))
+--R                                     18                                 18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        4            %pi 6       7      4        +-+    %pi 3
+--R                   (240x  - 240x)cos(---)  + (64x  - 64x  + 64x)\|3 cos(---)
+--R                                      18                                 18
+--R                 + 
+--R                      7      4
+--R                   24x  - 24x
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        4            %pi 8       7      4        +-+    %pi 5
+--R                   (180x  - 180x)cos(---)  + (48x  - 48x  + 48x)\|3 cos(---)
+--R                                      18                                 18
+--R                 + 
+--R                          7       4     %pi 2
+--R                   (- 360x  + 360x )cos(---)
+--R                                         18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       4           %pi 10        7       4     %pi 4
+--R                   (72x  - 72x)cos(---)   + (360x  - 360x )cos(---)
+--R                                    18                          18
+--R                 + 
+--R                         10      7      4  +-+    %pi
+--R                   (- 24x   + 24x  - 24x )\|3 cos(---)
+--R                                                   18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   4           %pi 12        7     4       +-+    %pi 9
+--R               (12x  - 12x)cos(---)   + (- 8x  + 8x  - 8x)\|3 cos(---)
+--R                                18                                 18
+--R             + 
+--R                     7      4     %pi 6      10     7     4  +-+    %pi 3
+--R               (- 24x  + 24x )cos(---)  + (8x   - 8x  + 8x )\|3 cos(---)
+--R                                   18                                18
+--R             + 
+--R                  10      7
+--R               12x   - 12x
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R               5      2 3+-+    %pi 12       5      2 3+-+    %pi 2    %pi 10
+--R           (12x  - 12x )\|2 sin(---)   + (72x  - 72x )\|2 cos(---) sin(---)
+--R                                 18                            18       18
+--R         + 
+--R                      5       2 3+-+    %pi 4
+--R                 (180x  - 180x )\|2 cos(---)
+--R                                         18
+--R               + 
+--R                     8      5      2 3+-+ +-+    %pi
+--R                 (24x  - 24x  + 24x )\|2 \|3 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    5       2 3+-+    %pi 6
+--R               (240x  - 240x )\|2 cos(---)
+--R                                       18
+--R             + 
+--R                   8      5      2 3+-+ +-+    %pi 3       8      5 3+-+
+--R               (64x  - 64x  + 64x )\|2 \|3 cos(---)  + (24x  - 24x )\|2
+--R                                                18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    5       2 3+-+    %pi 8
+--R               (180x  - 180x )\|2 cos(---)
+--R                                       18
+--R             + 
+--R                   8      5      2 3+-+ +-+    %pi 5
+--R               (48x  - 48x  + 48x )\|2 \|3 cos(---)
+--R                                                18
+--R             + 
+--R                      8       5 3+-+    %pi 2
+--R               (- 360x  + 360x )\|2 cos(---)
+--R                                         18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   5      2 3+-+    %pi 10        8       5 3+-+    %pi 4
+--R               (72x  - 72x )\|2 cos(---)   + (360x  - 360x )\|2 cos(---)
+--R                                     18                              18
+--R             + 
+--R                     11      8      5 3+-+ +-+    %pi
+--R               (- 24x   + 24x  - 24x )\|2 \|3 cos(---)
+--R                                                   18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               5      2 3+-+    %pi 12        8     5     2 3+-+ +-+    %pi 9
+--R           (12x  - 12x )\|2 cos(---)   + (- 8x  + 8x  - 8x )\|2 \|3 cos(---)
+--R                                 18                                      18
+--R         + 
+--R                 8      5 3+-+    %pi 6      11     8     5 3+-+ +-+    %pi 3
+--R           (- 24x  + 24x )\|2 cos(---)  + (8x   - 8x  + 8x )\|2 \|3 cos(---)
+--R                                   18                                    18
+--R         + 
+--R               11      8 3+-+
+--R           (12x   - 12x )\|2
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  7        4  +-+     7     4     %pi 12
+--R           ((6%i x  - 6%i x )\|3  + 6x  - 6x )sin(---)
+--R                                                   18
+--R         + 
+--R                   7         4  +-+      7      4     %pi 2    %pi 10
+--R           ((36%i x  - 36%i x )\|3  + 36x  - 36x )cos(---) sin(---)
+--R                                                       18       18
+--R         + 
+--R                       7         4  +-+      7      4     %pi 4
+--R               ((90%i x  - 90%i x )\|3  + 90x  - 90x )cos(---)
+--R                                                           18
+--R             + 
+--R                  10      7      4  +-+         10         7         4     %pi
+--R             ((12x   - 12x  + 12x )\|3  + 36%i x   - 36%i x  + 36%i x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        7          4  +-+       7       4     %pi 6
+--R               ((120%i x  - 120%i x )\|3  + 120x  - 120x )cos(---)
+--R                                                               18
+--R             + 
+--R                      10      7      4  +-+         10         7         4
+--R                 ((32x   - 32x  + 32x )\|3  + 96%i x   - 96%i x  + 96%i x )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      10         7  +-+      10      7
+--R               (12%i x   - 12%i x )\|3  + 12x   - 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7         4  +-+      7      4     %pi 8
+--R               ((90%i x  - 90%i x )\|3  + 90x  - 90x )cos(---)
+--R                                                           18
+--R             + 
+--R                      10      7      4  +-+         10         7         4
+--R                 ((24x   - 24x  + 24x )\|3  + 72%i x   - 72%i x  + 72%i x )
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          10          7  +-+       10       7     %pi 2
+--R               ((- 180%i x   + 180%i x )\|3  - 180x   + 180x )cos(---)
+--R                                                                   18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7         4  +-+      7      4     %pi 10
+--R               ((36%i x  - 36%i x )\|3  + 36x  - 36x )cos(---)
+--R                                                           18
+--R             + 
+--R                        10          7  +-+       10       7     %pi 4
+--R               ((180%i x   - 180%i x )\|3  + 180x   - 180x )cos(---)
+--R                                                                 18
+--R             + 
+--R                        13      10      7  +-+         13         10         7
+--R                 ((- 12x   + 12x   - 12x )\|3  - 36%i x   + 36%i x   - 36%i x )
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  7        4  +-+     7     4     %pi 12
+--R           ((6%i x  - 6%i x )\|3  + 6x  - 6x )cos(---)
+--R                                                   18
+--R         + 
+--R                 10     7     4  +-+         10         7         4     %pi 9
+--R           ((- 4x   + 4x  - 4x )\|3  - 12%i x   + 12%i x  - 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                     10         7  +-+      10      7     %pi 6
+--R           ((- 12%i x   + 12%i x )\|3  - 12x   + 12x )cos(---)
+--R                                                           18
+--R         + 
+--R               13     10     7  +-+         13         10         7     %pi 3
+--R           ((4x   - 4x   + 4x )\|3  + 12%i x   - 12%i x   + 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                 13        10  +-+     13     10
+--R           (6%i x   - 6%i x  )\|3  + 6x   - 6x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R               5      2 3+-+    %pi 12       5      2 3+-+    %pi 2    %pi 10
+--R           (12x  - 12x )\|2 sin(---)   + (72x  - 72x )\|2 cos(---) sin(---)
+--R                                 18                            18       18
+--R         + 
+--R                      5       2 3+-+    %pi 4
+--R                 (180x  - 180x )\|2 cos(---)
+--R                                         18
+--R               + 
+--R                     8      5      2 3+-+ +-+    %pi
+--R                 (24x  - 24x  + 24x )\|2 \|3 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    5       2 3+-+    %pi 6
+--R               (240x  - 240x )\|2 cos(---)
+--R                                       18
+--R             + 
+--R                   8      5      2 3+-+ +-+    %pi 3       8      5 3+-+
+--R               (64x  - 64x  + 64x )\|2 \|3 cos(---)  + (24x  - 24x )\|2
+--R                                                18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    5       2 3+-+    %pi 8
+--R               (180x  - 180x )\|2 cos(---)
+--R                                       18
+--R             + 
+--R                   8      5      2 3+-+ +-+    %pi 5
+--R               (48x  - 48x  + 48x )\|2 \|3 cos(---)
+--R                                                18
+--R             + 
+--R                      8       5 3+-+    %pi 2
+--R               (- 360x  + 360x )\|2 cos(---)
+--R                                         18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   5      2 3+-+    %pi 10        8       5 3+-+    %pi 4
+--R               (72x  - 72x )\|2 cos(---)   + (360x  - 360x )\|2 cos(---)
+--R                                     18                              18
+--R             + 
+--R                     11      8      5 3+-+ +-+    %pi
+--R               (- 24x   + 24x  - 24x )\|2 \|3 cos(---)
+--R                                                   18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               5      2 3+-+    %pi 12        8     5     2 3+-+ +-+    %pi 9
+--R           (12x  - 12x )\|2 cos(---)   + (- 8x  + 8x  - 8x )\|2 \|3 cos(---)
+--R                                 18                                      18
+--R         + 
+--R                 8      5 3+-+    %pi 6      11     8     5 3+-+ +-+    %pi 3
+--R           (- 24x  + 24x )\|2 cos(---)  + (8x   - 8x  + 8x )\|2 \|3 cos(---)
+--R                                   18                                    18
+--R         + 
+--R               11      8 3+-+
+--R           (12x   - 12x )\|2
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           6      3 3+-+2    %pi 12       6      3 3+-+2    %pi 2    %pi 10
+--R       (12x  - 12x )\|2  sin(---)   + (72x  - 72x )\|2  cos(---) sin(---)
+--R                              18                             18       18
+--R     + 
+--R               6       3 3+-+2    %pi 4       9      6      3 3+-+2 +-+    %pi
+--R         ((180x  - 180x )\|2  cos(---)  + (24x  - 24x  + 24x )\|2  \|3 cos(---))
+--R                                   18                                       18
+--R      *
+--R             %pi 8
+--R         sin(---)
+--R              18
+--R     + 
+--R                6       3 3+-+2    %pi 6
+--R           (240x  - 240x )\|2  cos(---)
+--R                                    18
+--R         + 
+--R               9      6      3 3+-+2 +-+    %pi 3       9      6 3+-+2
+--R           (64x  - 64x  + 64x )\|2  \|3 cos(---)  + (24x  - 24x )\|2
+--R                                             18
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R                6       3 3+-+2    %pi 8
+--R           (180x  - 180x )\|2  cos(---)
+--R                                    18
+--R         + 
+--R               9      6      3 3+-+2 +-+    %pi 5
+--R           (48x  - 48x  + 48x )\|2  \|3 cos(---)
+--R                                             18
+--R         + 
+--R                  9       6 3+-+2    %pi 2
+--R           (- 360x  + 360x )\|2  cos(---)
+--R                                      18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R               6      3 3+-+2    %pi 10        9       6 3+-+2    %pi 4
+--R           (72x  - 72x )\|2  cos(---)   + (360x  - 360x )\|2  cos(---)
+--R                                  18                               18
+--R         + 
+--R                 12      9      6 3+-+2 +-+    %pi
+--R           (- 24x   + 24x  - 24x )\|2  \|3 cos(---)
+--R                                                18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R           6      3 3+-+2    %pi 12        9     6     3 3+-+2 +-+    %pi 9
+--R       (12x  - 12x )\|2  cos(---)   + (- 8x  + 8x  - 8x )\|2  \|3 cos(---)
+--R                              18                                       18
+--R     + 
+--R             9      6 3+-+2    %pi 6      12     9     6 3+-+2 +-+    %pi 3
+--R       (- 24x  + 24x )\|2  cos(---)  + (8x   - 8x  + 8x )\|2  \|3 cos(---)
+--R                                18                                     18
+--R     + 
+--R           12      9 3+-+2
+--R       (12x   - 12x )\|2
+--R  /
+--R                  10     7     4 3+-+    %pi 12
+--R               (6x   - 6x  + 6x )\|2 sin(---)
+--R                                          18
+--R             + 
+--R                   10      7      4 3+-+    %pi 2    %pi 10
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                   10      7      4 3+-+    %pi 4    %pi 8
+--R               (90x   - 90x  + 90x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                        10       7       4 3+-+    %pi 6
+--R                   (120x   - 120x  + 120x )\|2 cos(---)
+--R                                                    18
+--R                 + 
+--R                       13      10      7 3+-+
+--R                   (12x   - 12x   + 12x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       10      7      4 3+-+    %pi 8
+--R                   (90x   - 90x  + 90x )\|2 cos(---)
+--R                                                 18
+--R                 + 
+--R                          13       10       7 3+-+    %pi 2
+--R                   (- 180x   + 180x   - 180x )\|2 cos(---)
+--R                                                       18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       10      7      4 3+-+    %pi 10
+--R                   (36x   - 36x  + 36x )\|2 cos(---)
+--R                                                 18
+--R                 + 
+--R                        13       10       7 3+-+    %pi 4
+--R                   (180x   - 180x   + 180x )\|2 cos(---)
+--R                                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                  10     7     4 3+-+    %pi 12
+--R               (6x   - 6x  + 6x )\|2 cos(---)
+--R                                          18
+--R             + 
+--R                     13      10      7 3+-+    %pi 6      16     13     10 3+-+
+--R               (- 12x   + 12x   - 12x )\|2 cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 12
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            8         5         2 3+-+2 +-+
+--R                   (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (18x  - 18x  + 18x )\|2
+--R              *
+--R                     %pi 2    %pi 10
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                            8         5         2 3+-+2 +-+
+--R                   (- 45%i x  + 45%i x  - 45%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (45x  - 45x  + 45x )\|2
+--R              *
+--R                     %pi 4    %pi 8
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 60%i x  + 60%i x  - 60%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (60x  - 60x  + 60x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           11        8        5 3+-+2 +-+
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R                 + 
+--R                      11     8     5 3+-+2
+--R                   (6x   - 6x  + 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 45%i x  + 45%i x  - 45%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (45x  - 45x  + 45x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (90%i x   - 90%i x  + 90%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 90x   + 90x  - 90x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (18x  - 18x  + 18x )\|2
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 90%i x   + 90%i x  - 90%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (90x   - 90x  + 90x )\|2
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 12
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         11        8        5 3+-+2 +-+
+--R                   (6%i x   - 6%i x  + 6%i x )\|2  \|3
+--R                 + 
+--R                        11     8     5 3+-+2
+--R                   (- 6x   + 6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     14        11        8 3+-+2 +-+      14     11     8 3+-+2
+--R             (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    9        6        3  +-+     9     6     3     %pi 12
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 2
+--R             ((- 36%i x  + 36%i x  - 36%i x )\|3  + 36x  - 36x  + 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 4
+--R             ((- 90%i x  + 90%i x  - 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                               9          6          3  +-+       9       6
+--R                     (- 120%i x  + 120%i x  - 120%i x )\|3  + 120x  - 120x
+--R                   + 
+--R                         3
+--R                     120x
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        12         9         6  +-+      12      9      6
+--R               (- 12%i x   + 12%i x  - 12%i x )\|3  + 12x   - 12x  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 90%i x  + 90%i x  - 90%i x )\|3  + 90x  - 90x  + 90x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                     (180%i x   - 180%i x  + 180%i x )\|3  - 180x   + 180x
+--R                   + 
+--R                           6
+--R                     - 180x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 36%i x  + 36%i x  - 36%i x )\|3  + 36x  - 36x  + 36x )
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                   (- 180%i x   + 180%i x  - 180%i x )\|3  + 180x   - 180x
+--R                 + 
+--R                       6
+--R                   180x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    9        6        3  +-+     9     6     3     %pi 12
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   12         9         6  +-+      12      9      6     %pi 6
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  - 12x   + 12x  - 12x )cos(---)
+--R                                                                          18
+--R         + 
+--R                   15        12        9  +-+     15     12     9
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 12
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          8         5         2 3+-+2 +-+
+--R                   (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (18x  - 18x  + 18x )\|2
+--R              *
+--R                     %pi 2    %pi 10
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                          8         5         2 3+-+2 +-+
+--R                   (45%i x  - 45%i x  + 45%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (45x  - 45x  + 45x )\|2
+--R              *
+--R                     %pi 4    %pi 8
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (60%i x  - 60%i x  + 60%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (60x  - 60x  + 60x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                       11        8        5 3+-+2 +-+      11     8     5 3+-+2
+--R                 (6%i x   - 6%i x  + 6%i x )\|2  \|3  + (6x   - 6x  + 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (45%i x  - 45%i x  + 45%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (45x  - 45x  + 45x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 90%i x   + 90%i x  - 90%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 90x   + 90x  - 90x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (18x  - 18x  + 18x )\|2
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (90%i x   - 90%i x  + 90%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (90x   - 90x  + 90x )\|2
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 12
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           11        8        5 3+-+2 +-+
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R                 + 
+--R                        11     8     5 3+-+2
+--R                   (- 6x   + 6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     14        11        8 3+-+2 +-+      14     11     8 3+-+2
+--R               (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   6      3          %pi 12
+--R               (12x  - 12x  + 12)sin(---)
+--R                                      18
+--R             + 
+--R                   6      3          %pi 2    %pi 10
+--R               (72x  - 72x  + 72)cos(---) sin(---)
+--R                                      18       18
+--R             + 
+--R                    6       3           %pi 4    %pi 8
+--R               (180x  - 180x  + 180)cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                     6       3           %pi 6      9      6      3     %pi 6
+--R               ((240x  - 240x  + 240)cos(---)  + 24x  - 24x  + 24x )sin(---)
+--R                                          18                             18
+--R             + 
+--R                        6       3           %pi 8
+--R                   (180x  - 180x  + 180)cos(---)
+--R                                             18
+--R                 + 
+--R                          9       6       3     %pi 2
+--R                   (- 360x  + 360x  - 360x )cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         6      3          %pi 10
+--R                     (72x  - 72x  + 72)cos(---)
+--R                                            18
+--R                   + 
+--R                          9       6       3     %pi 4
+--R                     (360x  - 360x  + 360x )cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   6      3          %pi 12         9      6      3     %pi 6
+--R               (12x  - 12x  + 12)cos(---)   + (- 24x  + 24x  - 24x )cos(---)
+--R                                      18                                 18
+--R             + 
+--R                  12      9      6
+--R               12x   - 12x  + 12x
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 sin(---)
+--R                                       18
+--R         + 
+--R               7      4       3+-+    %pi 2    %pi 10
+--R           (72x  - 72x  + 72x)\|2 cos(---) sin(---)
+--R                                       18       18
+--R         + 
+--R                7       4        3+-+    %pi 4    %pi 8
+--R           (180x  - 180x  + 180x)\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   7       4        3+-+    %pi 6       10      7      4 3+-+
+--R             ((240x  - 240x  + 240x)\|2 cos(---)  + (24x   - 24x  + 24x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7       4        3+-+    %pi 8
+--R               (180x  - 180x  + 180x)\|2 cos(---)
+--R                                              18
+--R             + 
+--R                      10       7       4 3+-+    %pi 2
+--R               (- 360x   + 360x  - 360x )\|2 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7      4       3+-+    %pi 10
+--R               (72x  - 72x  + 72x)\|2 cos(---)
+--R                                           18
+--R             + 
+--R                    10       7       4 3+-+    %pi 4
+--R               (360x   - 360x  + 360x )\|2 cos(---)
+--R                                                18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 cos(---)
+--R                                       18
+--R         + 
+--R                 10      7      4 3+-+    %pi 6       13      10      7 3+-+
+--R           (- 24x   + 24x  - 24x )\|2 cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                           18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9        6        3  +-+     9     6     3     %pi 12
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     9         6         3  +-+      9      6      3     %pi 2
+--R             ((36%i x  - 36%i x  + 36%i x )\|3  + 36x  - 36x  + 36x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     9         6         3  +-+      9      6      3     %pi 4
+--R             ((90%i x  - 90%i x  + 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          9          6          3  +-+       9       6       3
+--R                 ((120%i x  - 120%i x  + 120%i x )\|3  + 120x  - 120x  + 120x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      12         9         6  +-+      12      9      6
+--R               (12%i x   - 12%i x  + 12%i x )\|3  + 12x   - 12x  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 8
+--R               ((90%i x  - 90%i x  + 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                            18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                   (- 180%i x   + 180%i x  - 180%i x )\|3  - 180x   + 180x
+--R                 + 
+--R                         6
+--R                   - 180x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         9         6         3  +-+      9      6      3
+--R                 ((36%i x  - 36%i x  + 36%i x )\|3  + 36x  - 36x  + 36x )
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                     (180%i x   - 180%i x  + 180%i x )\|3  + 180x   - 180x
+--R                   + 
+--R                         6
+--R                     180x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  9        6        3  +-+     9     6     3     %pi 12
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                     12         9         6  +-+      12      9      6     %pi 6
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  - 12x   + 12x  - 12x )cos(---)
+--R                                                                            18
+--R         + 
+--R                 15        12        9  +-+     15     12     9
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 sin(---)
+--R                                       18
+--R         + 
+--R               7      4       3+-+    %pi 2    %pi 10
+--R           (72x  - 72x  + 72x)\|2 cos(---) sin(---)
+--R                                       18       18
+--R         + 
+--R                7       4        3+-+    %pi 4    %pi 8
+--R           (180x  - 180x  + 180x)\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   7       4        3+-+    %pi 6       10      7      4 3+-+
+--R             ((240x  - 240x  + 240x)\|2 cos(---)  + (24x   - 24x  + 24x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7       4        3+-+    %pi 8
+--R               (180x  - 180x  + 180x)\|2 cos(---)
+--R                                              18
+--R             + 
+--R                      10       7       4 3+-+    %pi 2
+--R               (- 360x   + 360x  - 360x )\|2 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7      4       3+-+    %pi 10
+--R               (72x  - 72x  + 72x)\|2 cos(---)
+--R                                           18
+--R             + 
+--R                    10       7       4 3+-+    %pi 4
+--R               (360x   - 360x  + 360x )\|2 cos(---)
+--R                                                18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 cos(---)
+--R                                       18
+--R         + 
+--R                 10      7      4 3+-+    %pi 6       13      10      7 3+-+
+--R           (- 24x   + 24x  - 24x )\|2 cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                           18
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           8      5      2 3+-+2    %pi 12
+--R       (12x  - 12x  + 12x )\|2  sin(---)
+--R                                     18
+--R     + 
+--R           8      5      2 3+-+2    %pi 2    %pi 10
+--R       (72x  - 72x  + 72x )\|2  cos(---) sin(---)
+--R                                     18       18
+--R     + 
+--R            8       5       2 3+-+2    %pi 4    %pi 8
+--R       (180x  - 180x  + 180x )\|2  cos(---) sin(---)
+--R                                        18       18
+--R     + 
+--R               8       5       2 3+-+2    %pi 6       11      8      5 3+-+2
+--R         ((240x  - 240x  + 240x )\|2  cos(---)  + (24x   - 24x  + 24x )\|2  )
+--R                                           18
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R                8       5       2 3+-+2    %pi 8
+--R           (180x  - 180x  + 180x )\|2  cos(---)
+--R                                            18
+--R         + 
+--R                  11       8       5 3+-+2    %pi 2
+--R           (- 360x   + 360x  - 360x )\|2  cos(---)
+--R                                               18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R               8      5      2 3+-+2    %pi 10
+--R           (72x  - 72x  + 72x )\|2  cos(---)
+--R                                         18
+--R         + 
+--R                11       8       5 3+-+2    %pi 4
+--R           (360x   - 360x  + 360x )\|2  cos(---)
+--R                                             18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R           8      5      2 3+-+2    %pi 12
+--R       (12x  - 12x  + 12x )\|2  cos(---)
+--R                                     18
+--R     + 
+--R             11      8      5 3+-+2    %pi 6       14      11      8 3+-+2
+--R       (- 24x   + 24x  - 24x )\|2  cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                        18
+--R                                           Type: Expression(Complex(Integer))
+--E 895
+
+)clear all
+
+--S 896 of 2282
+t0:=1/(x^3*(1-x^3+x^6))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         9    6    3
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 896
+
+--S 897 of 2282
+r0:=(-1/2)/x^2-1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1-%i*_
+   sqrt(3))^(2/3))-1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*(3-%i*_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))+1/18*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3-%i*_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/9*log(-2^(1/3)*x+(1+%i*_
+   sqrt(3))^(1/3))*(3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))+_
+   1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*_
+   sqrt(3))^(2/3))*(3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))+_
+   1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i+sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))
+--R 
+--R
+--R   (2)
+--R                           +------------+2
+--R              2 +-+     2 3|     +-+
+--R         (%i x \|3  + 3x )\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                            +------------+2     +----------+
+--R               2 +-+     2 3|     +-+          3|   +-+         3+-+
+--R       (- 2%i x \|3  - 6x )\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                             +----------+2
+--R                2 +-+     2 3|   +-+
+--R         (- %i x \|3  + 3x )\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                          +----------+2     +------------+
+--R             2 +-+     2 3|   +-+          3|     +-+         3+-+
+--R       (2%i x \|3  - 6x )\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                   +------------+
+--R                          +----------+2     3+-+2 3|     +-+
+--R          2 +-+        2 3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (6x \|3  - 6%i x )\|%i\|3  + 1  atan(-------------------------)
+--R                                                       +------------+
+--R                                             3+-+2 +-+3|     +-+
+--R                                             \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                     +----------+
+--R                          +------------+2     3+-+2 3|   +-+
+--R          2 +-+        2 3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (6x \|3  + 6%i x )\|- %i\|3  + 1  atan(-----------------------)
+--R                                                         +----------+
+--R                                               3+-+2 +-+3|   +-+
+--R                                               \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R               +------------+2  +----------+2
+--R          3+-+3|     +-+       3|   +-+
+--R       - 9\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R  /
+--R               +------------+2  +----------+2
+--R        2 3+-+3|     +-+       3|   +-+
+--R     18x  \|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 897
+
+--S 898 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       1
+--R                atan(----)
+--R                      +-+
+--R           2         \|3
+--R         2x cos(----------)
+--R                     3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                              1
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            3
+--R     + 
+--R                           1                   1
+--R                    atan(----)          atan(----)
+--R                          +-+                 +-+
+--R           2 +-+         \|3       2         \|3
+--R         (x \|3 sin(----------) - x cos(----------))
+--R                         3                   3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                                1
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              3
+--R     + 
+--R                             1                   1
+--R                      atan(----)          atan(----)
+--R                            +-+                 +-+
+--R             2 +-+         \|3       2         \|3
+--R         (- x \|3 sin(----------) - x cos(----------))
+--R                           3                   3
+--R      *
+--R                        1   2                 1                 1   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                      3                     3                 3
+--R     + 
+--R                          1                        1
+--R                   atan(----)               atan(----)
+--R                         +-+                      +-+
+--R              2         \|3        2 +-+         \|3
+--R         (- 2x sin(----------) - 2x \|3 cos(----------))
+--R                        3                        3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) + cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) - \|3 cos(----------) + 2x
+--R                       3                     3
+--R     + 
+--R                                                  1                 1
+--R                                           atan(----)        atan(----)
+--R                       1                         +-+               +-+
+--R                atan(----)          +-+         \|3               \|3
+--R                      +-+          \|3 sin(----------) - cos(----------)
+--R           2         \|3                        3                 3
+--R       - 4x sin(----------)atan(------------------------------------------)
+--R                     3                     1                     1
+--R                                    atan(----)            atan(----)
+--R                                          +-+                   +-+
+--R                                         \|3       +-+         \|3
+--R                                sin(----------) + \|3 cos(----------) + 2x
+--R                                         3                     3
+--R     + 
+--R                                                                        1
+--R                                                                 atan(----)
+--R                        1                        1                     +-+
+--R                 atan(----)               atan(----)                  \|3
+--R                       +-+                      +-+          cos(----------)
+--R            2         \|3        2 +-+         \|3                    3
+--R       (- 2x sin(----------) + 2x \|3 cos(----------))atan(-------------------)
+--R                      3                        3                      1
+--R                                                               atan(----)
+--R                                                                     +-+
+--R                                                                    \|3
+--R                                                           sin(----------) - x
+--R                                                                    3
+--R     + 
+--R           +-+
+--R       - 3\|3
+--R  /
+--R       2 +-+
+--R     6x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 898
+
+--S 899 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +------------+2
+--R             +-+      3|     +-+
+--R         (- \|3  - %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +------------+2     +----------+
+--R          +-+       3|     +-+          3|   +-+         3+-+
+--R       (2\|3  + 2%i)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                       +----------+2
+--R             +-+      3|   +-+
+--R         (- \|3  + %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+2     +------------+
+--R          +-+       3|   +-+          3|     +-+         3+-+
+--R       (2\|3  - 2%i)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                       +------------+2  +----------+2
+--R          3+-+    %pi 3|     +-+       3|   +-+
+--R         2\|2 cos(---)\|- %i\|3  + 1   \|%i\|3  + 1
+--R                   18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  + x sin(---) + cos(---)  + x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                                           +------------+2  +----------+2
+--R          3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (\|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                       18             18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  + x sin(---) + cos(---)  - x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                                             +------------+2  +----------+2
+--R            3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (- \|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                         18             18
+--R      *
+--R                 %pi 2          %pi        %pi 2    2
+--R         log(sin(---)  - 2x sin(---) + cos(---)  + x )
+--R                  18             18         18
+--R     + 
+--R                                               +------------+2  +----------+2
+--R             3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (- 2\|2 sin(---) - 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18                  18
+--R      *
+--R                  +-+    %pi        %pi
+--R                 \|3 sin(---) + cos(---)
+--R                          18         18
+--R         atan(----------------------------)
+--R                  %pi     +-+    %pi
+--R              sin(---) - \|3 cos(---) + 2x
+--R                   18             18
+--R     + 
+--R       -
+--R                          +------------+2  +----------+2
+--R             3+-+    %pi 3|     +-+       3|   +-+
+--R            4\|2 sin(---)\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18
+--R         *
+--R                     +-+    %pi        %pi
+--R                    \|3 sin(---) - cos(---)
+--R                             18         18
+--R            atan(----------------------------)
+--R                     %pi     +-+    %pi
+--R                 sin(---) + \|3 cos(---) + 2x
+--R                      18             18
+--R     + 
+--R                                              +------------+
+--R                     +----------+2     3+-+2 3|     +-+
+--R            +-+     3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (2%i\|3  - 6)\|%i\|3  + 1  atan(-------------------------)
+--R                                                  +------------+
+--R                                        3+-+2 +-+3|     +-+
+--R                                        \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                  +----------+
+--R                       +------------+2     3+-+2 3|   +-+
+--R              +-+     3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (- 2%i\|3  - 6)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                      +----------+
+--R                                            3+-+2 +-+3|   +-+
+--R                                            \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                               +------------+2  +----------+2
+--R             3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (- 2\|2 sin(---) + 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18                  18
+--R      *
+--R                    %pi
+--R                cos(---)
+--R                     18
+--R         atan(------------)
+--R                  %pi
+--R              sin(---) - x
+--R                   18
+--R  /
+--R               +------------+2  +----------+2
+--R      3+-+ +-+3|     +-+       3|   +-+
+--R     6\|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 899
+
+--S 900 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                 8    %pi 6      8    %pi 2    %pi 4
+--R               6x sin(---)  + 18x cos(---) sin(---)
+--R                       18              18       18
+--R             + 
+--R                    11     8     5     %pi 3
+--R               (- 6x   - 6x  + 6x )sin(---)
+--R                                        18
+--R             + 
+--R                   8    %pi 4        11     8     5  +-+    %pi      %pi 2
+--R               (18x cos(---)  + (- 6x   + 6x  - 6x )\|3 cos(---))sin(---)
+--R                         18                                  18       18
+--R             + 
+--R                   11      8      5     %pi 2    %pi      8    %pi 6
+--R               (18x   + 18x  - 18x )cos(---) sin(---) + 6x cos(---)
+--R                                         18       18            18
+--R             + 
+--R                  11     8     5  +-+    %pi 3     11     8
+--R               (2x   - 2x  + 2x )\|3 cos(---)  + 6x   - 6x
+--R                                          18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 9 3+-+    %pi 6     9 3+-+    %pi 2    %pi 4
+--R               6x  \|2 sin(---) + 18x  \|2 cos(---) sin(---)
+--R                            18                  18       18
+--R             + 
+--R                    12     9     6 3+-+    %pi 3
+--R               (- 6x   - 6x  + 6x )\|2 sin(---)
+--R                                            18
+--R             + 
+--R                     9 3+-+    %pi 4       12     9     6 3+-+ +-+    %pi
+--R                 (18x  \|2 cos(---) + (- 6x   + 6x  - 6x )\|2 \|3 cos(---))
+--R                                18                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi      9 3+-+    %pi 6
+--R               (18x   + 18x  - 18x )\|2 cos(---) sin(---) + 6x  \|2 cos(---)
+--R                                             18       18                 18
+--R             + 
+--R                  12     9     6 3+-+ +-+    %pi 3      12     9 3+-+
+--R               (2x   - 2x  + 2x )\|2 \|3 cos(---)  + (6x   - 6x )\|2
+--R                                              18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 + 3x  \|2 )sin(---)
+--R                                              18
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 2    %pi 4
+--R           (- 9%i x  \|2  \|3 + 9x  \|2 )cos(---) sin(---)
+--R                                              18       18
+--R         + 
+--R                    10        7        4 3+-+2 +-+        10     7     4 3+-+2
+--R             ((3%i x   + 3%i x  - 3%i x )\|2  \|3  + (- 3x   - 3x  + 3x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7 3+-+2 +-+    7 3+-+2    %pi 4
+--R               (- 9%i x  \|2  \|3 + 9x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                        10     7     4 3+-+2 +-+
+--R                   (- 3x   + 3x  - 3x )\|2  \|3
+--R                 + 
+--R                         10        7        4 3+-+2
+--R                   (9%i x   - 9%i x  + 9%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      10        7        4 3+-+2 +-+      10     7     4 3+-+2
+--R             ((- 9%i x   - 9%i x  + 9%i x )\|2  \|3  + (9x   + 9x  - 9x )\|2  )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 + 3x  \|2 )cos(---)
+--R                                              18
+--R         + 
+--R                10    7    4 3+-+2 +-+           10        7        4 3+-+2
+--R             ((x   - x  + x )\|2  \|3  + (- 3%i x   + 3%i x  - 3%i x )\|2  )
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   10        7 3+-+2 +-+      10     7 3+-+2
+--R           (- 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 9 3+-+    %pi 6     9 3+-+    %pi 2    %pi 4
+--R               6x  \|2 sin(---) + 18x  \|2 cos(---) sin(---)
+--R                            18                  18       18
+--R             + 
+--R                    12     9     6 3+-+    %pi 3
+--R               (- 6x   - 6x  + 6x )\|2 sin(---)
+--R                                            18
+--R             + 
+--R                     9 3+-+    %pi 4       12     9     6 3+-+ +-+    %pi
+--R                 (18x  \|2 cos(---) + (- 6x   + 6x  - 6x )\|2 \|3 cos(---))
+--R                                18                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi      9 3+-+    %pi 6
+--R               (18x   + 18x  - 18x )\|2 cos(---) sin(---) + 6x  \|2 cos(---)
+--R                                             18       18                 18
+--R             + 
+--R                  12     9     6 3+-+ +-+    %pi 3      12     9 3+-+
+--R               (2x   - 2x  + 2x )\|2 \|3 cos(---)  + (6x   - 6x )\|2
+--R                                              18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 10 3+-+2    %pi 6     10 3+-+2    %pi 2    %pi 4
+--R               6x   \|2  sin(---) + 18x   \|2  cos(---) sin(---)
+--R                              18                    18       18
+--R             + 
+--R                    13     10     7 3+-+2    %pi 3
+--R               (- 6x   - 6x   + 6x )\|2  sin(---)
+--R                                              18
+--R             + 
+--R                     10 3+-+2    %pi 4       13     10     7 3+-+2 +-+    %pi
+--R                 (18x   \|2  cos(---) + (- 6x   + 6x   - 6x )\|2  \|3 cos(---))
+--R                                  18                                       18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   13      10      7 3+-+2    %pi 2    %pi      10 3+-+2    %pi 6
+--R               (18x   + 18x   - 18x )\|2  cos(---) sin(---) + 6x   \|2  cos(---)
+--R                                               18       18                   18
+--R             + 
+--R                  13     10     7 3+-+2 +-+    %pi 3      13     10 3+-+2
+--R               (2x   - 2x   + 2x )\|2  \|3 cos(---)  + (6x   - 6x  )\|2
+--R                                                18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   8 +-+     8     %pi 6
+--R           (- 6%i x \|3  + 6x )sin(---)
+--R                                    18
+--R         + 
+--R                    8 +-+      8     %pi 2    %pi 4
+--R           (- 18%i x \|3  + 18x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                  11        8        5  +-+     11     8     5     %pi 3
+--R           ((6%i x   + 6%i x  - 6%i x )\|3  - 6x   - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                        8 +-+      8     %pi 4
+--R               (- 18%i x \|3  + 18x )cos(---)
+--R                                          18
+--R             + 
+--R                   11     8     5  +-+         11         8         5     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  + 18%i x   - 18%i x  + 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       11         8         5  +-+      11      8      5
+--R             ((- 18%i x   - 18%i x  + 18%i x )\|3  + 18x   + 18x  - 18x )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                   8 +-+     8     %pi 6
+--R           (- 6%i x \|3  + 6x )cos(---)
+--R                                    18
+--R         + 
+--R               11     8     5  +-+        11        8        5     %pi 3
+--R           ((2x   - 2x  + 2x )\|3  - 6%i x   + 6%i x  - 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   11        8  +-+     11     8
+--R           (- 6%i x   + 6%i x )\|3  + 6x   - 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 + 3x  \|2 )sin(---)
+--R                                            18
+--R         + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 2    %pi 4
+--R           (9%i x  \|2  \|3 + 9x  \|2 )cos(---) sin(---)
+--R                                            18       18
+--R         + 
+--R                         10        7        4 3+-+2 +-+
+--R                 (- 3%i x   - 3%i x  + 3%i x )\|2  \|3
+--R               + 
+--R                      10     7     4 3+-+2
+--R                 (- 3x   - 3x  + 3x )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     7 3+-+2 +-+    7 3+-+2    %pi 4
+--R               (9%i x  \|2  \|3 + 9x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                        10     7     4 3+-+2 +-+
+--R                   (- 3x   + 3x  - 3x )\|2  \|3
+--R                 + 
+--R                           10        7        4 3+-+2
+--R                   (- 9%i x   + 9%i x  - 9%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    10        7        4 3+-+2 +-+      10     7     4 3+-+2
+--R             ((9%i x   + 9%i x  - 9%i x )\|2  \|3  + (9x   + 9x  - 9x )\|2  )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 + 3x  \|2 )cos(---)
+--R                                            18
+--R         + 
+--R                10    7    4 3+-+2 +-+         10        7        4 3+-+2
+--R             ((x   - x  + x )\|2  \|3  + (3%i x   - 3%i x  + 3%i x )\|2  )
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                 10        7 3+-+2 +-+      10     7 3+-+2
+--R           (3%i x   - 3%i x )\|2  \|3  + (3x   - 3x )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                 8 +-+     8     %pi 6          8 +-+      8     %pi 2    %pi 4
+--R           (6%i x \|3  + 6x )sin(---)  + (18%i x \|3  + 18x )cos(---) sin(---)
+--R                                  18                              18       18
+--R         + 
+--R                    11        8        5  +-+     11     8     5     %pi 3
+--R           ((- 6%i x   - 6%i x  + 6%i x )\|3  - 6x   - 6x  + 6x )sin(---)
+--R                                                                      18
+--R         + 
+--R                      8 +-+      8     %pi 4
+--R               (18%i x \|3  + 18x )cos(---)
+--R                                        18
+--R             + 
+--R                   11     8     5  +-+         11         8         5     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  - 18%i x   + 18%i x  - 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 2
+--R             ((18%i x   + 18%i x  - 18%i x )\|3  + 18x   + 18x  - 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 8 +-+     8     %pi 6
+--R           (6%i x \|3  + 6x )cos(---)
+--R                                  18
+--R         + 
+--R               11     8     5  +-+        11        8        5     %pi 3
+--R           ((2x   - 2x  + 2x )\|3  + 6%i x   - 6%i x  + 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                 11        8  +-+     11     8
+--R           (6%i x   - 6%i x )\|3  + 6x   - 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R          6 3+-+    %pi 6     6 3+-+    %pi 2    %pi 4
+--R       12x  \|2 sin(---) + 36x  \|2 cos(---) sin(---)
+--R                     18                  18       18
+--R     + 
+--R             9      6      3 3+-+    %pi 3
+--R       (- 12x  - 12x  + 12x )\|2 sin(---)
+--R                                      18
+--R     + 
+--R           6 3+-+    %pi 4        9      6      3 3+-+ +-+    %pi      %pi 2
+--R       (36x  \|2 cos(---) + (- 12x  + 12x  - 12x )\|2 \|3 cos(---))sin(---)
+--R                      18                                       18       18
+--R     + 
+--R           9      6      3 3+-+    %pi 2    %pi       6 3+-+    %pi 6
+--R       (36x  + 36x  - 36x )\|2 cos(---) sin(---) + 12x  \|2 cos(---)
+--R                                    18       18                  18
+--R     + 
+--R          9     6     3 3+-+ +-+    %pi 3       9      6 3+-+
+--R       (4x  - 4x  + 4x )\|2 \|3 cos(---)  + (12x  - 12x )\|2
+--R                                     18
+--R  /
+--R                  8     5     2     %pi 6
+--R               (6x  - 6x  + 6x )sin(---)
+--R                                     18
+--R             + 
+--R                   8      5      2     %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                     11      8      5     %pi 3
+--R               (- 12x   + 12x  - 12x )sin(---)
+--R                                           18
+--R             + 
+--R                   8      5      2     %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                   11      8      5     %pi 2    %pi
+--R               (36x   - 36x  + 36x )cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                  8     5     2     %pi 6     14     11     8
+--R               (6x  - 6x  + 6x )cos(---)  + 6x   - 6x   + 6x
+--R                                     18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 3
+--R               (- 12x   + 12x  - 12x )\|2 sin(---)
+--R                                               18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                    10        7        4 3+-+2 +-+        10     7     4 3+-+2
+--R             ((6%i x   - 6%i x  + 6%i x )\|2  \|3  + (- 6x   + 6x  - 6x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                        10         7         4 3+-+2 +-+
+--R               (- 18%i x   + 18%i x  - 18%i x )\|2  \|3
+--R             + 
+--R                   10      7      4 3+-+2
+--R               (18x   - 18x  + 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 3
+--R               (- 12x   + 12x  - 12x )\|2 sin(---)
+--R                                               18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  10     7     4 3+-+2    %pi 6
+--R               (6x   - 6x  + 6x )\|2  sin(---)
+--R                                           18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 2    %pi 4
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                     13      10      7 3+-+2    %pi 3
+--R               (- 12x   + 12x   - 12x )\|2  sin(---)
+--R                                                 18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 4    %pi 2
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                   13      10      7 3+-+2    %pi 2    %pi
+--R               (36x   - 36x   + 36x )\|2  cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                  10     7     4 3+-+2    %pi 6      16     13     10 3+-+2
+--R               (6x   - 6x  + 6x )\|2  cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                           18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 2
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   11         8         5  +-+      11      8      5     %pi 3
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  - 12x   + 12x  - 12x )sin(---)
+--R                                                                          18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 4
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       11         8         5  +-+      11      8      5
+--R             ((- 36%i x   + 36%i x  - 36%i x )\|3  + 36x   - 36x  + 36x )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   14        11        8  +-+     14     11     8
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )sin(---)
+--R                                                                            18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                         10        7        4 3+-+2 +-+
+--R                 (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R               + 
+--R                      10     7     4 3+-+2
+--R                 (- 6x   + 6x  - 6x )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      10         7         4 3+-+2 +-+
+--R               (18%i x   - 18%i x  + 18%i x )\|2  \|3
+--R             + 
+--R                   10      7      4 3+-+2
+--R               (18x   - 18x  + 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )cos(---)
+--R                                                                            18
+--R         + 
+--R                 13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 2
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 3
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  - 12x   + 12x  - 12x )sin(---)
+--R                                                                            18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 4
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 2
+--R             ((36%i x   - 36%i x  + 36%i x )\|3  + 36x   - 36x  + 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                 14        11        8  +-+     14     11     8
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           6      3      3+-+    %pi 6
+--R       (12x  - 12x  + 12)\|2 sin(---)
+--R                                  18
+--R     + 
+--R           6      3      3+-+    %pi 2    %pi 4
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R             9      6      3 3+-+    %pi 3
+--R       (- 24x  + 24x  - 24x )\|2 sin(---)
+--R                                      18
+--R     + 
+--R           6      3      3+-+    %pi 4    %pi 2
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R           9      6      3 3+-+    %pi 2    %pi
+--R       (72x  - 72x  + 72x )\|2 cos(---) sin(---)
+--R                                    18       18
+--R     + 
+--R           6      3      3+-+    %pi 6       12      9      6 3+-+
+--R       (12x  - 12x  + 12)\|2 cos(---)  + (12x   - 12x  + 12x )\|2
+--R                                  18
+--R                                           Type: Expression(Complex(Integer))
+--E 900
+
+)clear all
+
+--S 901 of 2282
+t0:=1/(x^4*(1-x^3+x^6))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         10    7    4
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 901
+
+--S 902 of 2282
+r0:=(-1/3)/x^3+log(x)-1/6*log(1-x^3+x^6)+1/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                         3      +-+
+--R      3 +-+     6    3          3 +-+           3     (2x  - 1)\|3       +-+
+--R   - x \|3 log(x  - x  + 1) + 6x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                            3
+--R   -------------------------------------------------------------------------
+--R                                      3 +-+
+--R                                    6x \|3
+--R                                                    Type: Expression(Integer)
+--E 902
+
+--S 903 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                         3      +-+
+--R      3 +-+     6    3          3 +-+           3     (2x  - 1)\|3       +-+
+--R   - x \|3 log(x  - x  + 1) + 6x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                            3
+--R   -------------------------------------------------------------------------
+--R                                      3 +-+
+--R                                    6x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 903
+
+--S 904 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 905
+
+)clear all
+
+--S 906 of 2282
+t0:=1/(x^5*(1-x^3+x^6))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         11    8    5
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 906
+
+--S 907 of 2282
+r0:=(-1/4)/x^4+(-1)/x+1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+_
+   (1-%i*sqrt(3))^(1/3))*(3+%i*sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))+_
+   1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*_
+   sqrt(3))^(2/3))*(3+%i*sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))-_
+   1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i+sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))
+--R 
+--R
+--R   (2)
+--R                              +------------+
+--R                 4 +-+     4 3|     +-+
+--R         (- 2%i x \|3  + 6x )\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                           +------------+     +----------+
+--R             4 +-+      4 3|     +-+         3|   +-+         3+-+
+--R       (4%i x \|3  - 12x )\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                            +----------+
+--R               4 +-+     4 3|   +-+
+--R         (2%i x \|3  + 6x )\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                             +----------+     +------------+
+--R               4 +-+      4 3|   +-+         3|     +-+         3+-+
+--R       (- 4%i x \|3  - 12x )\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                      +------------+
+--R                              +----------+     3+-+2 3|     +-+
+--R             4 +-+         4 3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (- 12x \|3  - 12%i x )\|%i\|3  + 1 atan(-------------------------)
+--R                                                          +------------+
+--R                                                3+-+2 +-+3|     +-+
+--R                                                \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                        +----------+
+--R                              +------------+     3+-+2 3|   +-+
+--R             4 +-+         4 3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (- 12x \|3  + 12%i x )\|- %i\|3  + 1 atan(-----------------------)
+--R                                                            +----------+
+--R                                                  3+-+2 +-+3|   +-+
+--R                                                  \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                          +------------+ +----------+
+--R             3     3+-+2 3|     +-+     3|   +-+
+--R       (- 36x  - 9)\|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R  /
+--R                 +------------+ +----------+
+--R        4 3+-+2 3|     +-+     3|   +-+
+--R     36x  \|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 907
+
+--S 908 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                              1                    1
+--R                       atan(----)           atan(----)
+--R                             +-+                  +-+
+--R              4 +-+         \|3        4         \|3
+--R         (- 2x \|3 sin(----------) - 2x cos(----------))
+--R                            3                    3
+--R      *
+--R         log
+--R                         1   4                1   2                 1   2
+--R                  atan(----)           atan(----)            atan(----)
+--R                        +-+                  +-+                   +-+
+--R                       \|3                  \|3                   \|3
+--R              sin(----------)  + (2cos(----------)  + 2x)sin(----------)
+--R                       3                    3                     3
+--R            + 
+--R                         1   4                 1   2
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3                   \|3        2
+--R              cos(----------)  - 2x cos(----------)  + x
+--R                       3                     3
+--R     + 
+--R                       1
+--R                atan(----)
+--R                      +-+
+--R           4         \|3
+--R         4x cos(----------)
+--R                     3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                               1              1                 1   4
+--R                        atan(----)     atan(----)        atan(----)
+--R                              +-+            +-+               +-+
+--R                 +-+         \|3            \|3               \|3
+--R              2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                             3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                            1                    1
+--R                     atan(----)           atan(----)
+--R                           +-+                  +-+
+--R            4 +-+         \|3        4         \|3
+--R         (2x \|3 sin(----------) - 2x cos(----------))
+--R                          3                    3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                                 1              1                 1   4
+--R                          atan(----)     atan(----)        atan(----)
+--R                                +-+            +-+               +-+
+--R                   +-+         \|3            \|3               \|3
+--R              - 2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                               3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                       1
+--R                atan(----)
+--R                      +-+
+--R           4         \|3
+--R         8x sin(----------)
+--R                     3
+--R      *
+--R         atan
+--R                            1   2                   1              1
+--R                     atan(----)              atan(----)     atan(----)
+--R                           +-+                     +-+            +-+
+--R                          \|3         +-+         \|3            \|3
+--R                3sin(----------)  + 2\|3 cos(----------)sin(----------)
+--R                          3                       3              3
+--R              + 
+--R                              1   2
+--R                       atan(----)
+--R                             +-+
+--R                            \|3
+--R                - 3cos(----------)
+--R                            3
+--R           /
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  - 6cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3          +-+
+--R                - \|3 cos(----------)  - 2x\|3
+--R                               3
+--R     + 
+--R                        1                        1
+--R                 atan(----)               atan(----)
+--R                       +-+                      +-+
+--R            4         \|3        4 +-+         \|3
+--R         (4x sin(----------) + 4x \|3 cos(----------))
+--R                      3                        3
+--R      *
+--R         atan
+--R                            1   2                   1              1
+--R                     atan(----)              atan(----)     atan(----)
+--R                           +-+                     +-+            +-+
+--R                          \|3         +-+         \|3            \|3
+--R                3sin(----------)  - 2\|3 cos(----------)sin(----------)
+--R                          3                       3              3
+--R              + 
+--R                              1   2
+--R                       atan(----)
+--R                             +-+
+--R                            \|3
+--R                - 3cos(----------)
+--R                            3
+--R           /
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  + 6cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3          +-+
+--R                - \|3 cos(----------)  - 2x\|3
+--R                               3
+--R     + 
+--R                          1                        1
+--R                   atan(----)               atan(----)
+--R                         +-+                      +-+
+--R              4         \|3        4 +-+         \|3
+--R         (- 4x sin(----------) + 4x \|3 cos(----------))
+--R                        3                        3
+--R      *
+--R                              1              1
+--R                       atan(----)     atan(----)
+--R                             +-+            +-+
+--R                            \|3            \|3
+--R                  2cos(----------)sin(----------)
+--R                            3              3
+--R         atan(---------------------------------------)
+--R                         1   2              1   2
+--R                  atan(----)         atan(----)
+--R                        +-+                +-+
+--R                       \|3                \|3
+--R              sin(----------)  - cos(----------)  + x
+--R                       3                  3
+--R     + 
+--R             3      +-+
+--R       (- 12x  - 3)\|3
+--R  /
+--R        4 +-+
+--R     12x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 908
+
+--S 909 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +------------+
+--R             +-+      3|     +-+
+--R         (- \|3  + %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +------------+     +----------+
+--R          +-+       3|     +-+         3|   +-+         3+-+
+--R       (2\|3  - 2%i)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                       +----------+
+--R             +-+      3|   +-+
+--R         (- \|3  - %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+     +------------+
+--R          +-+       3|   +-+         3|     +-+         3+-+
+--R       (2\|3  + 2%i)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                               +------------+ +----------+
+--R            3+-+2 +-+    %pi    3+-+2    %pi  3|     +-+     3|   +-+
+--R         (- \|2  \|3 sin(---) - \|2  cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                          18              18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2          %pi 2       %pi 4          %pi 2
+--R              sin(---)  + (2cos(---)  + 2x)sin(---)  + cos(---)  - 2x cos(---)
+--R                   18            18             18          18             18
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R                        +------------+ +----------+
+--R          3+-+2    %pi 3|     +-+     3|   +-+
+--R         2\|2  cos(---)\|- %i\|3  + 1 \|%i\|3  + 1
+--R                    18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2         %pi 2      +-+    %pi     %pi
+--R              sin(---)  + (2cos(---)  - x)sin(---)  + 2x\|3 cos(---)sin(---)
+--R                   18            18            18                18      18
+--R            + 
+--R                  %pi 4         %pi 2    2
+--R              cos(---)  + x cos(---)  + x
+--R                   18            18
+--R     + 
+--R                                             +------------+ +----------+
+--R          3+-+2 +-+    %pi    3+-+2    %pi  3|     +-+     3|   +-+
+--R         (\|2  \|3 sin(---) - \|2  cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                        18              18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2         %pi 2      +-+    %pi     %pi
+--R              sin(---)  + (2cos(---)  - x)sin(---)  - 2x\|3 cos(---)sin(---)
+--R                   18            18            18                18      18
+--R            + 
+--R                  %pi 4         %pi 2    2
+--R              cos(---)  + x cos(---)  + x
+--R                   18            18
+--R     + 
+--R                        +------------+ +----------+
+--R          3+-+2    %pi 3|     +-+     3|   +-+
+--R         4\|2  sin(---)\|- %i\|3  + 1 \|%i\|3  + 1
+--R                    18
+--R      *
+--R                         %pi 2     +-+    %pi     %pi         %pi 2
+--R                    3sin(---)  + 2\|3 cos(---)sin(---) - 3cos(---)
+--R                          18               18      18          18
+--R         atan(----------------------------------------------------------)
+--R               +-+    %pi 2        %pi     %pi     +-+    %pi 2      +-+
+--R              \|3 sin(---)  - 6cos(---)sin(---) - \|3 cos(---)  - 2x\|3
+--R                       18           18      18             18
+--R     + 
+--R                                               +------------+ +----------+
+--R           3+-+2    %pi     3+-+2 +-+    %pi  3|     +-+     3|   +-+
+--R         (2\|2  sin(---) + 2\|2  \|3 cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                     18                   18
+--R      *
+--R                         %pi 2     +-+    %pi     %pi         %pi 2
+--R                    3sin(---)  - 2\|3 cos(---)sin(---) - 3cos(---)
+--R                          18               18      18          18
+--R         atan(----------------------------------------------------------)
+--R               +-+    %pi 2        %pi     %pi     +-+    %pi 2      +-+
+--R              \|3 sin(---)  + 6cos(---)sin(---) - \|3 cos(---)  - 2x\|3
+--R                       18           18      18             18
+--R     + 
+--R                                             +------------+
+--R                     +----------+     3+-+2 3|     +-+
+--R            +-+     3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (2%i\|3  + 6)\|%i\|3  + 1 atan(-------------------------)
+--R                                                 +------------+
+--R                                       3+-+2 +-+3|     +-+
+--R                                       \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                 +----------+
+--R                       +------------+     3+-+2 3|   +-+
+--R              +-+     3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (- 2%i\|3  + 6)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                     +----------+
+--R                                           3+-+2 +-+3|   +-+
+--R                                           \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                 +------------+ +----------+
+--R             3+-+2    %pi     3+-+2 +-+    %pi  3|     +-+     3|   +-+
+--R         (- 2\|2  sin(---) + 2\|2  \|3 cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                       18                   18
+--R      *
+--R                       %pi     %pi
+--R                  2cos(---)sin(---)
+--R                        18      18
+--R         atan(-------------------------)
+--R                  %pi 2       %pi 2
+--R              sin(---)  - cos(---)  + x
+--R                   18          18
+--R  /
+--R                +------------+ +----------+
+--R      3+-+2 +-+3|     +-+     3|   +-+
+--R     6\|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 909
+
+--S 910 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                 8 3+-+    %pi 12     8 3+-+    %pi 2    %pi 10
+--R               6x  \|2 sin(---)  + 36x  \|2 cos(---) sin(---)
+--R                            18                   18       18
+--R             + 
+--R                  11     8     5 3+-+    %pi 9
+--R               (6x   - 6x  + 6x )\|2 sin(---)
+--R                                          18
+--R             + 
+--R                     8 3+-+    %pi 4       11     8     5 3+-+ +-+    %pi
+--R                 (90x  \|2 cos(---) + (- 6x   + 6x  - 6x )\|2 \|3 cos(---))
+--R                                18                                     18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       8 3+-+    %pi 6        11      8      5 3+-+ +-+    %pi 3
+--R                   120x  \|2 cos(---) + (- 16x   + 16x  - 16x )\|2 \|3 cos(---)
+--R                                  18                                        18
+--R                 + 
+--R                      11 3+-+
+--R                   12x   \|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     11      8      5 3+-+    %pi 4    %pi 5
+--R               (- 36x   + 36x  - 36x )\|2 cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                      8 3+-+    %pi 8        11      8      5 3+-+ +-+    %pi 5
+--R                   90x  \|2 cos(---) + (- 12x   + 12x  - 12x )\|2 \|3 cos(---)
+--R                                 18                                        18
+--R                 + 
+--R                         11 3+-+    %pi 2
+--R                   - 180x   \|2 cos(---)
+--R                                     18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           11      8      5 3+-+    %pi 6
+--R                     (- 48x   + 48x  - 48x )\|2 cos(---)
+--R                                                     18
+--R                   + 
+--R                        14     11     8 3+-+
+--R                     (6x   - 6x   + 6x )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                      8 3+-+    %pi 10      11 3+-+    %pi 4
+--R                   36x  \|2 cos(---)  + 180x   \|2 cos(---)
+--R                                 18                     18
+--R                 + 
+--R                      14     11     8 3+-+ +-+    %pi
+--R                   (6x   - 6x   + 6x )\|2 \|3 cos(---)
+--R                                                   18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         11      8      5 3+-+    %pi 8
+--R                   (- 18x   + 18x  - 18x )\|2 cos(---)
+--R                                                   18
+--R                 + 
+--R                         14      11      8 3+-+    %pi 2
+--R                   (- 18x   + 18x   - 18x )\|2 cos(---)
+--R                                                    18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                 8 3+-+    %pi 12     11     8     5 3+-+ +-+    %pi 9
+--R               6x  \|2 cos(---)  + (2x   - 2x  + 2x )\|2 \|3 cos(---)
+--R                            18                                    18
+--R             + 
+--R                    11 3+-+    %pi 6       14     11     8 3+-+ +-+    %pi 3
+--R               - 12x   \|2 cos(---) + (- 2x   + 2x   - 2x )\|2 \|3 cos(---)
+--R                                18                                      18
+--R             + 
+--R                 14 3+-+
+--R               6x   \|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                       6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (- 3%i x  \|2  \|3 + 3x  \|2 )sin(---)
+--R                                                  18
+--R             + 
+--R                        6 3+-+2 +-+     6 3+-+2    %pi 2    %pi 10
+--R               (- 18%i x  \|2  \|3 + 18x  \|2 )cos(---) sin(---)
+--R                                                    18       18
+--R             + 
+--R                             9        6        3 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        9     6     3 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 9
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 4
+--R                   (- 45%i x  \|2  \|3 + 45x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 3x  + 3x  - 3x )\|2  \|3
+--R                     + 
+--R                             9        6        3 3+-+2
+--R                       (9%i x  - 9%i x  + 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 6
+--R                   (- 60%i x  \|2  \|3 + 60x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 8x  + 8x  - 8x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (24%i x  - 24%i x  + 24%i x )\|2
+--R                  *
+--R                         %pi 3
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                          9 3+-+2 +-+    9 3+-+2
+--R                   - 6%i x  \|2  \|3 + 6x  \|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          9         6         3 3+-+2 +-+
+--R                   (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                 + 
+--R                         9      6      3 3+-+2
+--R                   (- 18x  + 18x  - 18x )\|2
+--R              *
+--R                     %pi 4    %pi 5
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 8
+--R                   (- 45%i x  \|2  \|3 + 45x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 6x  + 6x  - 6x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (18%i x  - 18%i x  + 18%i x )\|2
+--R                  *
+--R                         %pi 5
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                          9 3+-+2 +-+     9 3+-+2    %pi 2
+--R                   (90%i x  \|2  \|3 - 90x  \|2 )cos(---)
+--R                                                      18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              9         6         3 3+-+2 +-+
+--R                       (24%i x  - 24%i x  + 24%i x )\|2  \|3
+--R                     + 
+--R                             9      6      3 3+-+2
+--R                       (- 24x  + 24x  - 24x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           12        9        6 3+-+2 +-+
+--R                   (- 3%i x   + 3%i x  - 3%i x )\|2  \|3
+--R                 + 
+--R                      12     9     6 3+-+2
+--R                   (3x   - 3x  + 3x )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 10
+--R                   (- 18%i x  \|2  \|3 + 18x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9 3+-+2 +-+     9 3+-+2    %pi 4
+--R                   (- 90%i x  \|2  \|3 + 90x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                          12     9     6 3+-+2 +-+
+--R                       (3x   - 3x  + 3x )\|2  \|3
+--R                     + 
+--R                               12        9        6 3+-+2
+--R                       (- 9%i x   + 9%i x  - 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                             9        6        3 3+-+2 +-+
+--R                       (9%i x  - 9%i x  + 9%i x )\|2  \|3
+--R                     + 
+--R                            9     6     3 3+-+2
+--R                       (- 9x  + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                             12        9        6 3+-+2 +-+
+--R                       (9%i x   - 9%i x  + 9%i x )\|2  \|3
+--R                     + 
+--R                            12     9     6 3+-+2
+--R                       (- 9x   + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (- 3%i x  \|2  \|3 + 3x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                    9    6    3 3+-+2 +-+           9        6        3 3+-+2
+--R                 ((x  - x  + x )\|2  \|3  + (- 3%i x  + 3%i x  - 3%i x )\|2  )
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     9 3+-+2 +-+    9 3+-+2    %pi 6
+--R               (6%i x  \|2  \|3 - 6x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                      12    9    6 3+-+2 +-+         12        9        6 3+-+2
+--R                 ((- x   + x  - x )\|2  \|3  + (3%i x   - 3%i x  + 3%i x )\|2  )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      12 3+-+2 +-+    12 3+-+2
+--R               - 3%i x   \|2  \|3 + 3x   \|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   7 +-+     7     %pi 12
+--R           (- 6%i x \|3  + 6x )sin(---)
+--R                                    18
+--R         + 
+--R                    7 +-+      7     %pi 2    %pi 10
+--R           (- 36%i x \|3  + 36x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                    10        7        4  +-+     10     7     4     %pi 9
+--R           ((- 6%i x   + 6%i x  - 6%i x )\|3  + 6x   - 6x  + 6x )sin(---)
+--R                                                                      18
+--R         + 
+--R                        7 +-+      7     %pi 4
+--R               (- 90%i x \|3  + 90x )cos(---)
+--R                                          18
+--R             + 
+--R                   10     7     4  +-+         10         7         4     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  + 18%i x   - 18%i x  + 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         7 +-+       7     %pi 6
+--R               (- 120%i x \|3  + 120x )cos(---)
+--R                                            18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 16x   + 16x  - 16x )\|3  + 48%i x   - 48%i x  + 48%i x )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       10 +-+      10
+--R               - 12%i x  \|3  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     10         7         4  +-+      10      7      4     %pi 4
+--R             ((36%i x   - 36%i x  + 36%i x )\|3  - 36x   + 36x  - 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        7 +-+      7     %pi 8
+--R               (- 90%i x \|3  + 90x )cos(---)
+--R                                          18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 12x   + 12x  - 12x )\|3  + 36%i x   - 36%i x  + 36%i x )
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       10 +-+       10     %pi 2
+--R               (180%i x  \|3  - 180x  )cos(---)
+--R                                            18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         10         7         4  +-+      10      7      4
+--R                 ((48%i x   - 48%i x  + 48%i x )\|3  - 48x   + 48x  - 48x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       13        10        7  +-+     13     10     7
+--R               (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        7 +-+      7     %pi 10
+--R               (- 36%i x \|3  + 36x )cos(---)
+--R                                          18
+--R             + 
+--R                         10 +-+       10     %pi 4
+--R               (- 180%i x  \|3  + 180x  )cos(---)
+--R                                              18
+--R             + 
+--R                 13     10     7  +-+         13         10         7     %pi
+--R             ((6x   - 6x   + 6x )\|3  - 18%i x   + 18%i x   - 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         10         7         4  +-+      10      7      4
+--R                 ((18%i x   - 18%i x  + 18%i x )\|3  - 18x   + 18x  - 18x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         13         10         7  +-+      13      10      7
+--R                 ((18%i x   - 18%i x   + 18%i x )\|3  - 18x   + 18x   - 18x )
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7 +-+     7     %pi 12
+--R           (- 6%i x \|3  + 6x )cos(---)
+--R                                    18
+--R         + 
+--R               10     7     4  +-+        10        7        4     %pi 9
+--R           ((2x   - 2x  + 2x )\|3  - 6%i x   + 6%i x  - 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                  10 +-+      10     %pi 6
+--R           (12%i x  \|3  - 12x  )cos(---)
+--R                                      18
+--R         + 
+--R                 13     10     7  +-+        13        10        7     %pi 3
+--R           ((- 2x   + 2x   - 2x )\|3  + 6%i x   - 6%i x   + 6%i x )cos(---)
+--R                                                                        18
+--R         + 
+--R                  13 +-+     13
+--R           - 6%i x  \|3  + 6x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                     6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (3%i x  \|2  \|3 + 3x  \|2 )sin(---)
+--R                                                18
+--R             + 
+--R                      6 3+-+2 +-+     6 3+-+2    %pi 2    %pi 10
+--R               (18%i x  \|2  \|3 + 18x  \|2 )cos(---) sin(---)
+--R                                                  18       18
+--R             + 
+--R                        9        6        3 3+-+2 +-+      9     6     3 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 9
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 4
+--R                   (45%i x  \|2  \|3 + 45x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 3x  + 3x  - 3x )\|2  \|3
+--R                     + 
+--R                               9        6        3 3+-+2
+--R                       (- 9%i x  + 9%i x  - 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 6
+--R                   (60%i x  \|2  \|3 + 60x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 8x  + 8x  - 8x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 24%i x  + 24%i x  - 24%i x )\|2
+--R                  *
+--R                         %pi 3
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                        9 3+-+2 +-+    9 3+-+2
+--R                   6%i x  \|2  \|3 + 6x  \|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            9         6         3 3+-+2 +-+
+--R                   (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                 + 
+--R                         9      6      3 3+-+2
+--R                   (- 18x  + 18x  - 18x )\|2
+--R              *
+--R                     %pi 4    %pi 5
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 8
+--R                   (45%i x  \|2  \|3 + 45x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 6x  + 6x  - 6x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 18%i x  + 18%i x  - 18%i x )\|2
+--R                  *
+--R                         %pi 5
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                            9 3+-+2 +-+     9 3+-+2    %pi 2
+--R                   (- 90%i x  \|2  \|3 - 90x  \|2 )cos(---)
+--R                                                        18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                9         6         3 3+-+2 +-+
+--R                       (- 24%i x  + 24%i x  - 24%i x )\|2  \|3
+--R                     + 
+--R                             9      6      3 3+-+2
+--R                       (- 24x  + 24x  - 24x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                       12        9        6 3+-+2 +-+      12     9     6 3+-+2
+--R                 (3%i x   - 3%i x  + 3%i x )\|2  \|3  + (3x   - 3x  + 3x )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 10
+--R                   (18%i x  \|2  \|3 + 18x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                          9 3+-+2 +-+     9 3+-+2    %pi 4
+--R                   (90%i x  \|2  \|3 + 90x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                          12     9     6 3+-+2 +-+
+--R                       (3x   - 3x  + 3x )\|2  \|3
+--R                     + 
+--R                             12        9        6 3+-+2
+--R                       (9%i x   - 9%i x  + 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               9        6        3 3+-+2 +-+
+--R                       (- 9%i x  + 9%i x  - 9%i x )\|2  \|3
+--R                     + 
+--R                            9     6     3 3+-+2
+--R                       (- 9x  + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                               12        9        6 3+-+2 +-+
+--R                       (- 9%i x   + 9%i x  - 9%i x )\|2  \|3
+--R                     + 
+--R                            12     9     6 3+-+2
+--R                       (- 9x   + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (3%i x  \|2  \|3 + 3x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                    9    6    3 3+-+2 +-+         9        6        3 3+-+2
+--R                 ((x  - x  + x )\|2  \|3  + (3%i x  - 3%i x  + 3%i x )\|2  )
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       9 3+-+2 +-+    9 3+-+2    %pi 6
+--R               (- 6%i x  \|2  \|3 - 6x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                         12    9    6 3+-+2 +-+
+--R                     (- x   + x  - x )\|2  \|3
+--R                   + 
+--R                             12        9        6 3+-+2
+--R                     (- 3%i x   + 3%i x  - 3%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                    12 3+-+2 +-+    12 3+-+2
+--R               3%i x   \|2  \|3 + 3x   \|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  4    %pi 12      4    %pi 2    %pi 10
+--R               12x sin(---)   + 72x cos(---) sin(---)
+--R                        18               18       18
+--R             + 
+--R                   7      4           %pi 9
+--R               (12x  - 12x  + 12x)sin(---)
+--R                                       18
+--R             + 
+--R                    4    %pi 4         7      4        +-+    %pi      %pi 8
+--R               (180x cos(---)  + (- 12x  + 12x  - 12x)\|3 cos(---))sin(---)
+--R                          18                                   18       18
+--R             + 
+--R                      4    %pi 6         7      4        +-+    %pi 3      7
+--R                 (240x cos(---)  + (- 32x  + 32x  - 32x)\|3 cos(---)  + 24x )
+--R                            18                                   18
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     7      4           %pi 4    %pi 5
+--R               (- 72x  + 72x  - 72x)cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                       4    %pi 8         7      4        +-+    %pi 5
+--R                   180x cos(---)  + (- 24x  + 24x  - 24x)\|3 cos(---)
+--R                             18                                   18
+--R                 + 
+--R                         7    %pi 2
+--R                   - 360x cos(---)
+--R                               18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                      7      4           %pi 6      10      7      4     %pi 3
+--R               ((- 96x  + 96x  - 96x)cos(---)  + 12x   - 12x  + 12x )sin(---)
+--R                                          18                              18
+--R             + 
+--R                      4    %pi 10       7    %pi 4
+--R                   72x cos(---)   + 360x cos(---)
+--R                            18                18
+--R                 + 
+--R                       10      7      4  +-+    %pi
+--R                   (12x   - 12x  + 12x )\|3 cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         7      4           %pi 8
+--R                   (- 36x  + 36x  - 36x)cos(---)
+--R                                             18
+--R                 + 
+--R                         10      7      4     %pi 2
+--R                   (- 36x   + 36x  - 36x )cos(---)
+--R                                               18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                  4    %pi 12      7     4       +-+    %pi 9      7    %pi 6
+--R               12x cos(---)   + (4x  - 4x  + 4x)\|3 cos(---)  - 24x cos(---)
+--R                        18                               18              18
+--R             + 
+--R                    10     7     4  +-+    %pi 3      10
+--R               (- 4x   + 4x  - 4x )\|3 cos(---)  + 12x
+--R                                            18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R              5 3+-+    %pi 12     5 3+-+    %pi 2    %pi 10
+--R           12x  \|2 sin(---)  + 72x  \|2 cos(---) sin(---)
+--R                         18                   18       18
+--R         + 
+--R               8      5      2 3+-+    %pi 9
+--R           (12x  - 12x  + 12x )\|2 sin(---)
+--R                                        18
+--R         + 
+--R                  5 3+-+    %pi 4        8      5      2 3+-+ +-+    %pi
+--R             (180x  \|2 cos(---) + (- 12x  + 12x  - 12x )\|2 \|3 cos(---))
+--R                             18                                       18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   5 3+-+    %pi 6        8      5      2 3+-+ +-+    %pi 3
+--R               240x  \|2 cos(---) + (- 32x  + 32x  - 32x )\|2 \|3 cos(---)
+--R                              18                                       18
+--R             + 
+--R                  8 3+-+
+--R               24x  \|2
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 8      5      2 3+-+    %pi 4    %pi 5
+--R           (- 72x  + 72x  - 72x )\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   5 3+-+    %pi 8        8      5      2 3+-+ +-+    %pi 5
+--R               180x  \|2 cos(---) + (- 24x  + 24x  - 24x )\|2 \|3 cos(---)
+--R                              18                                       18
+--R             + 
+--R                     8 3+-+    %pi 2
+--R               - 360x  \|2 cos(---)
+--R                                18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8      5      2 3+-+    %pi 6       11      8      5 3+-+
+--R             ((- 96x  + 96x  - 96x )\|2 cos(---)  + (12x   - 12x  + 12x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  5 3+-+    %pi 10      8 3+-+    %pi 4
+--R               72x  \|2 cos(---)  + 360x  \|2 cos(---)
+--R                             18                    18
+--R             + 
+--R                   11      8      5 3+-+ +-+    %pi
+--R               (12x   - 12x  + 12x )\|2 \|3 cos(---)
+--R                                                 18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     8      5      2 3+-+    %pi 8
+--R               (- 36x  + 36x  - 36x )\|2 cos(---)
+--R                                              18
+--R             + 
+--R                     11      8      5 3+-+    %pi 2
+--R               (- 36x   + 36x  - 36x )\|2 cos(---)
+--R                                               18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R              5 3+-+    %pi 12     8     5     2 3+-+ +-+    %pi 9
+--R           12x  \|2 cos(---)  + (4x  - 4x  + 4x )\|2 \|3 cos(---)
+--R                         18                                   18
+--R         + 
+--R              8 3+-+    %pi 6       11     8     5 3+-+ +-+    %pi 3      11 3+-+
+--R         - 24x  \|2 cos(---) + (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  + 12x   \|2
+--R                         18                                     18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 7 +-+     7     %pi 12
+--R           (6%i x \|3  + 6x )sin(---)
+--R                                  18
+--R         + 
+--R                  7 +-+      7     %pi 2    %pi 10
+--R           (36%i x \|3  + 36x )cos(---) sin(---)
+--R                                    18       18
+--R         + 
+--R                  10        7        4  +-+     10     7     4     %pi 9
+--R           ((6%i x   - 6%i x  + 6%i x )\|3  + 6x   - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                      7 +-+      7     %pi 4
+--R               (90%i x \|3  + 90x )cos(---)
+--R                                        18
+--R             + 
+--R                   10     7     4  +-+         10         7         4     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  - 18%i x   + 18%i x  - 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7 +-+       7     %pi 6
+--R               (120%i x \|3  + 120x )cos(---)
+--R                                          18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 16x   + 16x  - 16x )\|3  - 48%i x   + 48%i x  - 48%i x )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     10 +-+      10
+--R               12%i x  \|3  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       10         7         4  +-+      10      7      4
+--R             ((- 36%i x   + 36%i x  - 36%i x )\|3  - 36x   + 36x  - 36x )
+--R          *
+--R                 %pi 4    %pi 5
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      7 +-+      7     %pi 8
+--R               (90%i x \|3  + 90x )cos(---)
+--R                                        18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 12x   + 12x  - 12x )\|3  - 36%i x   + 36%i x  - 36%i x )
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         10 +-+       10     %pi 2
+--R               (- 180%i x  \|3  - 180x  )cos(---)
+--R                                              18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           10         7         4  +-+      10      7      4
+--R                 ((- 48%i x   + 48%i x  - 48%i x )\|3  - 48x   + 48x  - 48x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     13        10        7  +-+     13     10     7
+--R               (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7 +-+      7     %pi 10
+--R               (36%i x \|3  + 36x )cos(---)
+--R                                        18
+--R             + 
+--R                       10 +-+       10     %pi 4
+--R               (180%i x  \|3  + 180x  )cos(---)
+--R                                            18
+--R             + 
+--R                 13     10     7  +-+         13         10         7     %pi
+--R             ((6x   - 6x   + 6x )\|3  + 18%i x   - 18%i x   + 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           10         7         4  +-+      10      7      4
+--R                 ((- 18%i x   + 18%i x  - 18%i x )\|3  - 18x   + 18x  - 18x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           13         10         7  +-+      13      10      7
+--R                 ((- 18%i x   + 18%i x   - 18%i x )\|3  - 18x   + 18x   - 18x )
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 7 +-+     7     %pi 12
+--R           (6%i x \|3  + 6x )cos(---)
+--R                                  18
+--R         + 
+--R               10     7     4  +-+        10        7        4     %pi 9
+--R           ((2x   - 2x  + 2x )\|3  + 6%i x   - 6%i x  + 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                    10 +-+      10     %pi 6
+--R           (- 12%i x  \|3  - 12x  )cos(---)
+--R                                        18
+--R         + 
+--R                 13     10     7  +-+        13        10        7     %pi 3
+--R           ((- 2x   + 2x   - 2x )\|3  - 6%i x   + 6%i x   - 6%i x )cos(---)
+--R                                                                        18
+--R         + 
+--R                13 +-+     13
+--R           6%i x  \|3  + 6x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R              5 3+-+    %pi 12     5 3+-+    %pi 2    %pi 10
+--R           12x  \|2 sin(---)  + 72x  \|2 cos(---) sin(---)
+--R                         18                   18       18
+--R         + 
+--R               8      5      2 3+-+    %pi 9
+--R           (12x  - 12x  + 12x )\|2 sin(---)
+--R                                        18
+--R         + 
+--R                  5 3+-+    %pi 4        8      5      2 3+-+ +-+    %pi
+--R             (180x  \|2 cos(---) + (- 12x  + 12x  - 12x )\|2 \|3 cos(---))
+--R                             18                                       18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   5 3+-+    %pi 6        8      5      2 3+-+ +-+    %pi 3
+--R               240x  \|2 cos(---) + (- 32x  + 32x  - 32x )\|2 \|3 cos(---)
+--R                              18                                       18
+--R             + 
+--R                  8 3+-+
+--R               24x  \|2
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 8      5      2 3+-+    %pi 4    %pi 5
+--R           (- 72x  + 72x  - 72x )\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   5 3+-+    %pi 8        8      5      2 3+-+ +-+    %pi 5
+--R               180x  \|2 cos(---) + (- 24x  + 24x  - 24x )\|2 \|3 cos(---)
+--R                              18                                       18
+--R             + 
+--R                     8 3+-+    %pi 2
+--R               - 360x  \|2 cos(---)
+--R                                18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8      5      2 3+-+    %pi 6       11      8      5 3+-+
+--R             ((- 96x  + 96x  - 96x )\|2 cos(---)  + (12x   - 12x  + 12x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  5 3+-+    %pi 10      8 3+-+    %pi 4
+--R               72x  \|2 cos(---)  + 360x  \|2 cos(---)
+--R                             18                    18
+--R             + 
+--R                   11      8      5 3+-+ +-+    %pi
+--R               (12x   - 12x  + 12x )\|2 \|3 cos(---)
+--R                                                 18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     8      5      2 3+-+    %pi 8
+--R               (- 36x  + 36x  - 36x )\|2 cos(---)
+--R                                              18
+--R             + 
+--R                     11      8      5 3+-+    %pi 2
+--R               (- 36x   + 36x  - 36x )\|2 cos(---)
+--R                                               18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R              5 3+-+    %pi 12     8     5     2 3+-+ +-+    %pi 9
+--R           12x  \|2 cos(---)  + (4x  - 4x  + 4x )\|2 \|3 cos(---)
+--R                         18                                   18
+--R         + 
+--R              8 3+-+    %pi 6       11     8     5 3+-+ +-+    %pi 3      11 3+-+
+--R         - 24x  \|2 cos(---) + (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  + 12x   \|2
+--R                         18                                     18
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R          6 3+-+2    %pi 12     6 3+-+2    %pi 2    %pi 10
+--R       12x  \|2  sin(---)  + 72x  \|2  cos(---) sin(---)
+--R                      18                    18       18
+--R     + 
+--R           9      6      3 3+-+2    %pi 9
+--R       (12x  - 12x  + 12x )\|2  sin(---)
+--R                                     18
+--R     + 
+--R            6 3+-+2    %pi 4        9      6      3 3+-+2 +-+    %pi      %pi 8
+--R       (180x  \|2  cos(---) + (- 12x  + 12x  - 12x )\|2  \|3 cos(---))sin(---)
+--R                        18                                        18       18
+--R     + 
+--R               6 3+-+2    %pi 6        9      6      3 3+-+2 +-+    %pi 3
+--R           240x  \|2  cos(---) + (- 32x  + 32x  - 32x )\|2  \|3 cos(---)
+--R                           18                                        18
+--R         + 
+--R              9 3+-+2
+--R           24x  \|2
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R             9      6      3 3+-+2    %pi 4    %pi 5
+--R       (- 72x  + 72x  - 72x )\|2  cos(---) sin(---)
+--R                                       18       18
+--R     + 
+--R               6 3+-+2    %pi 8        9      6      3 3+-+2 +-+    %pi 5
+--R           180x  \|2  cos(---) + (- 24x  + 24x  - 24x )\|2  \|3 cos(---)
+--R                           18                                        18
+--R         + 
+--R                 9 3+-+2    %pi 2
+--R           - 360x  \|2  cos(---)
+--R                             18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R                9      6      3 3+-+2    %pi 6       12      9      6 3+-+2
+--R         ((- 96x  + 96x  - 96x )\|2  cos(---)  + (12x   - 12x  + 12x )\|2  )
+--R                                          18
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              18
+--R     + 
+--R              6 3+-+2    %pi 10      9 3+-+2    %pi 4
+--R           72x  \|2  cos(---)  + 360x  \|2  cos(---)
+--R                          18                     18
+--R         + 
+--R               12      9      6 3+-+2 +-+    %pi
+--R           (12x   - 12x  + 12x )\|2  \|3 cos(---)
+--R                                              18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R                 9      6      3 3+-+2    %pi 8
+--R           (- 36x  + 36x  - 36x )\|2  cos(---)
+--R                                           18
+--R         + 
+--R                 12      9      6 3+-+2    %pi 2
+--R           (- 36x   + 36x  - 36x )\|2  cos(---)
+--R                                            18
+--R      *
+--R             %pi
+--R         sin(---)
+--R              18
+--R     + 
+--R          6 3+-+2    %pi 12     9     6     3 3+-+2 +-+    %pi 9
+--R       12x  \|2  cos(---)  + (4x  - 4x  + 4x )\|2  \|3 cos(---)
+--R                      18                                    18
+--R     + 
+--R          9 3+-+2    %pi 6       12     9     6 3+-+2 +-+    %pi 3      12 3+-+2
+--R     - 24x  \|2  cos(---) + (- 4x   + 4x  - 4x )\|2  \|3 cos(---)  + 12x   \|2
+--R                      18                                      18
+--R  /
+--R                  10     7     4 3+-+    %pi 12
+--R               (6x   - 6x  + 6x )\|2 sin(---)
+--R                                          18
+--R             + 
+--R                   10      7      4 3+-+    %pi 2    %pi 10
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                   10      7      4 3+-+    %pi 4    %pi 8
+--R               (90x   - 90x  + 90x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                        10       7       4 3+-+    %pi 6
+--R                   (120x   - 120x  + 120x )\|2 cos(---)
+--R                                                    18
+--R                 + 
+--R                       13      10      7 3+-+
+--R                   (12x   - 12x   + 12x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       10      7      4 3+-+    %pi 8
+--R                   (90x   - 90x  + 90x )\|2 cos(---)
+--R                                                 18
+--R                 + 
+--R                          13       10       7 3+-+    %pi 2
+--R                   (- 180x   + 180x   - 180x )\|2 cos(---)
+--R                                                       18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       10      7      4 3+-+    %pi 10
+--R                   (36x   - 36x  + 36x )\|2 cos(---)
+--R                                                 18
+--R                 + 
+--R                        13       10       7 3+-+    %pi 4
+--R                   (180x   - 180x   + 180x )\|2 cos(---)
+--R                                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                  10     7     4 3+-+    %pi 12
+--R               (6x   - 6x  + 6x )\|2 cos(---)
+--R                                          18
+--R             + 
+--R                     13      10      7 3+-+    %pi 6      16     13     10 3+-+
+--R               (- 12x   + 12x   - 12x )\|2 cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 12
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            8         5         2 3+-+2 +-+
+--R                   (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (18x  - 18x  + 18x )\|2
+--R              *
+--R                     %pi 2    %pi 10
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                            8         5         2 3+-+2 +-+
+--R                   (- 45%i x  + 45%i x  - 45%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (45x  - 45x  + 45x )\|2
+--R              *
+--R                     %pi 4    %pi 8
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 60%i x  + 60%i x  - 60%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (60x  - 60x  + 60x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           11        8        5 3+-+2 +-+
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R                 + 
+--R                      11     8     5 3+-+2
+--R                   (6x   - 6x  + 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 45%i x  + 45%i x  - 45%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (45x  - 45x  + 45x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (90%i x   - 90%i x  + 90%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 90x   + 90x  - 90x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (18x  - 18x  + 18x )\|2
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 90%i x   + 90%i x  - 90%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (90x   - 90x  + 90x )\|2
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 12
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         11        8        5 3+-+2 +-+
+--R                   (6%i x   - 6%i x  + 6%i x )\|2  \|3
+--R                 + 
+--R                        11     8     5 3+-+2
+--R                   (- 6x   + 6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     14        11        8 3+-+2 +-+      14     11     8 3+-+2
+--R             (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    9        6        3  +-+     9     6     3     %pi 12
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 2
+--R             ((- 36%i x  + 36%i x  - 36%i x )\|3  + 36x  - 36x  + 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 4
+--R             ((- 90%i x  + 90%i x  - 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                               9          6          3  +-+       9       6
+--R                     (- 120%i x  + 120%i x  - 120%i x )\|3  + 120x  - 120x
+--R                   + 
+--R                         3
+--R                     120x
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        12         9         6  +-+      12      9      6
+--R               (- 12%i x   + 12%i x  - 12%i x )\|3  + 12x   - 12x  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 90%i x  + 90%i x  - 90%i x )\|3  + 90x  - 90x  + 90x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                     (180%i x   - 180%i x  + 180%i x )\|3  - 180x   + 180x
+--R                   + 
+--R                           6
+--R                     - 180x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 36%i x  + 36%i x  - 36%i x )\|3  + 36x  - 36x  + 36x )
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                   (- 180%i x   + 180%i x  - 180%i x )\|3  + 180x   - 180x
+--R                 + 
+--R                       6
+--R                   180x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    9        6        3  +-+     9     6     3     %pi 12
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   12         9         6  +-+      12      9      6     %pi 6
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  - 12x   + 12x  - 12x )cos(---)
+--R                                                                          18
+--R         + 
+--R                   15        12        9  +-+     15     12     9
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 12
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          8         5         2 3+-+2 +-+
+--R                   (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (18x  - 18x  + 18x )\|2
+--R              *
+--R                     %pi 2    %pi 10
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                          8         5         2 3+-+2 +-+
+--R                   (45%i x  - 45%i x  + 45%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (45x  - 45x  + 45x )\|2
+--R              *
+--R                     %pi 4    %pi 8
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (60%i x  - 60%i x  + 60%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (60x  - 60x  + 60x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                       11        8        5 3+-+2 +-+      11     8     5 3+-+2
+--R                 (6%i x   - 6%i x  + 6%i x )\|2  \|3  + (6x   - 6x  + 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (45%i x  - 45%i x  + 45%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (45x  - 45x  + 45x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 90%i x   + 90%i x  - 90%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 90x   + 90x  - 90x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (18x  - 18x  + 18x )\|2
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (90%i x   - 90%i x  + 90%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (90x   - 90x  + 90x )\|2
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 12
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           11        8        5 3+-+2 +-+
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R                 + 
+--R                        11     8     5 3+-+2
+--R                   (- 6x   + 6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     14        11        8 3+-+2 +-+      14     11     8 3+-+2
+--R               (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   6      3          %pi 12
+--R               (12x  - 12x  + 12)sin(---)
+--R                                      18
+--R             + 
+--R                   6      3          %pi 2    %pi 10
+--R               (72x  - 72x  + 72)cos(---) sin(---)
+--R                                      18       18
+--R             + 
+--R                    6       3           %pi 4    %pi 8
+--R               (180x  - 180x  + 180)cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                     6       3           %pi 6      9      6      3     %pi 6
+--R               ((240x  - 240x  + 240)cos(---)  + 24x  - 24x  + 24x )sin(---)
+--R                                          18                             18
+--R             + 
+--R                        6       3           %pi 8
+--R                   (180x  - 180x  + 180)cos(---)
+--R                                             18
+--R                 + 
+--R                          9       6       3     %pi 2
+--R                   (- 360x  + 360x  - 360x )cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         6      3          %pi 10
+--R                     (72x  - 72x  + 72)cos(---)
+--R                                            18
+--R                   + 
+--R                          9       6       3     %pi 4
+--R                     (360x  - 360x  + 360x )cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   6      3          %pi 12         9      6      3     %pi 6
+--R               (12x  - 12x  + 12)cos(---)   + (- 24x  + 24x  - 24x )cos(---)
+--R                                      18                                 18
+--R             + 
+--R                  12      9      6
+--R               12x   - 12x  + 12x
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 sin(---)
+--R                                       18
+--R         + 
+--R               7      4       3+-+    %pi 2    %pi 10
+--R           (72x  - 72x  + 72x)\|2 cos(---) sin(---)
+--R                                       18       18
+--R         + 
+--R                7       4        3+-+    %pi 4    %pi 8
+--R           (180x  - 180x  + 180x)\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   7       4        3+-+    %pi 6       10      7      4 3+-+
+--R             ((240x  - 240x  + 240x)\|2 cos(---)  + (24x   - 24x  + 24x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7       4        3+-+    %pi 8
+--R               (180x  - 180x  + 180x)\|2 cos(---)
+--R                                              18
+--R             + 
+--R                      10       7       4 3+-+    %pi 2
+--R               (- 360x   + 360x  - 360x )\|2 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7      4       3+-+    %pi 10
+--R               (72x  - 72x  + 72x)\|2 cos(---)
+--R                                           18
+--R             + 
+--R                    10       7       4 3+-+    %pi 4
+--R               (360x   - 360x  + 360x )\|2 cos(---)
+--R                                                18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 cos(---)
+--R                                       18
+--R         + 
+--R                 10      7      4 3+-+    %pi 6       13      10      7 3+-+
+--R           (- 24x   + 24x  - 24x )\|2 cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                           18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9        6        3  +-+     9     6     3     %pi 12
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     9         6         3  +-+      9      6      3     %pi 2
+--R             ((36%i x  - 36%i x  + 36%i x )\|3  + 36x  - 36x  + 36x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     9         6         3  +-+      9      6      3     %pi 4
+--R             ((90%i x  - 90%i x  + 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          9          6          3  +-+       9       6       3
+--R                 ((120%i x  - 120%i x  + 120%i x )\|3  + 120x  - 120x  + 120x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      12         9         6  +-+      12      9      6
+--R               (12%i x   - 12%i x  + 12%i x )\|3  + 12x   - 12x  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 8
+--R               ((90%i x  - 90%i x  + 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                            18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                   (- 180%i x   + 180%i x  - 180%i x )\|3  - 180x   + 180x
+--R                 + 
+--R                         6
+--R                   - 180x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         9         6         3  +-+      9      6      3
+--R                 ((36%i x  - 36%i x  + 36%i x )\|3  + 36x  - 36x  + 36x )
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                     (180%i x   - 180%i x  + 180%i x )\|3  + 180x   - 180x
+--R                   + 
+--R                         6
+--R                     180x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  9        6        3  +-+     9     6     3     %pi 12
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                     12         9         6  +-+      12      9      6     %pi 6
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  - 12x   + 12x  - 12x )cos(---)
+--R                                                                            18
+--R         + 
+--R                 15        12        9  +-+     15     12     9
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 sin(---)
+--R                                       18
+--R         + 
+--R               7      4       3+-+    %pi 2    %pi 10
+--R           (72x  - 72x  + 72x)\|2 cos(---) sin(---)
+--R                                       18       18
+--R         + 
+--R                7       4        3+-+    %pi 4    %pi 8
+--R           (180x  - 180x  + 180x)\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   7       4        3+-+    %pi 6       10      7      4 3+-+
+--R             ((240x  - 240x  + 240x)\|2 cos(---)  + (24x   - 24x  + 24x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7       4        3+-+    %pi 8
+--R               (180x  - 180x  + 180x)\|2 cos(---)
+--R                                              18
+--R             + 
+--R                      10       7       4 3+-+    %pi 2
+--R               (- 360x   + 360x  - 360x )\|2 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7      4       3+-+    %pi 10
+--R               (72x  - 72x  + 72x)\|2 cos(---)
+--R                                           18
+--R             + 
+--R                    10       7       4 3+-+    %pi 4
+--R               (360x   - 360x  + 360x )\|2 cos(---)
+--R                                                18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 cos(---)
+--R                                       18
+--R         + 
+--R                 10      7      4 3+-+    %pi 6       13      10      7 3+-+
+--R           (- 24x   + 24x  - 24x )\|2 cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                           18
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           8      5      2 3+-+2    %pi 12
+--R       (12x  - 12x  + 12x )\|2  sin(---)
+--R                                     18
+--R     + 
+--R           8      5      2 3+-+2    %pi 2    %pi 10
+--R       (72x  - 72x  + 72x )\|2  cos(---) sin(---)
+--R                                     18       18
+--R     + 
+--R            8       5       2 3+-+2    %pi 4    %pi 8
+--R       (180x  - 180x  + 180x )\|2  cos(---) sin(---)
+--R                                        18       18
+--R     + 
+--R               8       5       2 3+-+2    %pi 6       11      8      5 3+-+2
+--R         ((240x  - 240x  + 240x )\|2  cos(---)  + (24x   - 24x  + 24x )\|2  )
+--R                                           18
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R                8       5       2 3+-+2    %pi 8
+--R           (180x  - 180x  + 180x )\|2  cos(---)
+--R                                            18
+--R         + 
+--R                  11       8       5 3+-+2    %pi 2
+--R           (- 360x   + 360x  - 360x )\|2  cos(---)
+--R                                               18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R               8      5      2 3+-+2    %pi 10
+--R           (72x  - 72x  + 72x )\|2  cos(---)
+--R                                         18
+--R         + 
+--R                11       8       5 3+-+2    %pi 4
+--R           (360x   - 360x  + 360x )\|2  cos(---)
+--R                                             18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R           8      5      2 3+-+2    %pi 12
+--R       (12x  - 12x  + 12x )\|2  cos(---)
+--R                                     18
+--R     + 
+--R             11      8      5 3+-+2    %pi 6       14      11      8 3+-+2
+--R       (- 24x   + 24x  - 24x )\|2  cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                        18
+--R                                           Type: Expression(Complex(Integer))
+--E 910
+
+)clear all
+
+--S 911 of 2282
+t0:=1/(2+x^3+x^6)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         6    3
+--R        x  + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 911
+
+--S 912 of 2282
+r0:=-1/3*%i*2^(2/3)*log(2^(1/3)*x+(1-%i*sqrt(7))^(1/3))/((1-%i*_
+   sqrt(7))^(2/3)*sqrt(7))+1/3*%i*log(2^(2/3)*x^2-2^(1/3)*x*(1-%i*_
+   sqrt(7))^(1/3)+(1-%i*sqrt(7))^(2/3))/(2^(1/3)*(1-%i*sqrt(7))^(2/3)*_
+   sqrt(7))+1/3*%i*2^(2/3)*log(2^(1/3)*x+(1+%i*sqrt(7))^(1/3))/((1+%i*_
+   sqrt(7))^(2/3)*sqrt(7))-1/3*%i*log(2^(2/3)*x^2-2^(1/3)*x*(1+%i*_
+   sqrt(7))^(1/3)+(1+%i*sqrt(7))^(2/3))/(2^(1/3)*(1+%i*sqrt(7))^(2/3)*_
+   sqrt(7))+%i*2^(2/3)*atan((-4*x+2^(2/3)*(1-%i*sqrt(7))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(1-%i*sqrt(7))^(1/3)))/((1-%i*sqrt(7))^(2/3)*sqrt(21))-_
+   %i*2^(2/3)*atan((-4*x+2^(2/3)*(1+%i*sqrt(7))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(1+%i*sqrt(7))^(1/3)))/((1+%i*sqrt(7))^(2/3)*sqrt(21))
+--R 
+--R
+--R   (2)
+--R       -
+--R                      +------------+2
+--R            1    +--+3|     +-+
+--R            - %i\|21 \|- %i\|7  + 1
+--R            3
+--R         *
+--R                 +----------+2         +----------+
+--R                3|   +-+          3+-+3|   +-+         2 3+-+2
+--R            log(\|%i\|7  + 1   - x\|2 \|%i\|7  + 1  + x  \|2 )
+--R     + 
+--R                 +------------+2     +----------+
+--R       2    +--+3|     +-+          3|   +-+         3+-+
+--R       - %i\|21 \|- %i\|7  + 1  log(\|%i\|7  + 1  + x\|2 )
+--R       3
+--R     + 
+--R                   +----------+2
+--R         1    +--+3|   +-+
+--R         - %i\|21 \|%i\|7  + 1
+--R         3
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|7  + 1   - x\|2 \|- %i\|7  + 1  + x  \|2 )
+--R     + 
+--R                   +----------+2     +------------+
+--R         2    +--+3|   +-+          3|     +-+         3+-+
+--R       - - %i\|21 \|%i\|7  + 1  log(\|- %i\|7  + 1  + x\|2 )
+--R         3
+--R     + 
+--R                                            +----------+
+--R                 +------------+2     3+-+2 3|   +-+
+--R             +-+3|     +-+           \|2   \|%i\|7  + 1 - 4x
+--R       - 2%i\|7 \|- %i\|7  + 1  atan(-----------------------)
+--R                                                +----------+
+--R                                      3+-+2 +-+3|   +-+
+--R                                      \|2  \|3 \|%i\|7  + 1
+--R     + 
+--R                                        +------------+
+--R               +----------+2     3+-+2 3|     +-+
+--R           +-+3|   +-+           \|2   \|- %i\|7  + 1 - 4x
+--R       2%i\|7 \|%i\|7  + 1  atan(-------------------------)
+--R                                            +------------+
+--R                                  3+-+2 +-+3|     +-+
+--R                                  \|2  \|3 \|- %i\|7  + 1
+--R  /
+--R                   +------------+2  +----------+2
+--R     3+-+ +-+ +--+3|     +-+       3|   +-+
+--R     \|2 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 912
+
+--S 913 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         3                 3
+--R                  atan(----)        atan(----)
+--R                        +-+               +-+
+--R           +-+         \|7               \|7
+--R         (\|3 sin(----------) - cos(----------))
+--R                       3                 3
+--R      *
+--R         log
+--R                           3   2                                     3
+--R                    atan(----)                                atan(----)
+--R                          +-+                                       +-+
+--R                         \|7          +-+      +-+ 6+----+         \|7
+--R              28sin(----------)  + (x\|7  + 7x\|3 )\|1372 sin(----------)
+--R                         3                                         3
+--R            + 
+--R                           3   2                                     3
+--R                    atan(----)                                atan(----)
+--R                          +-+                                       +-+
+--R                         \|7          +-+ +-+      6+----+         \|7
+--R              28cos(----------)  + (x\|3 \|7  - 7x)\|1372 cos(----------)
+--R                         3                                         3
+--R            + 
+--R                2 6+----+2
+--R              2x  \|1372
+--R     + 
+--R                           3                 3
+--R                    atan(----)        atan(----)
+--R                          +-+               +-+
+--R             +-+         \|7               \|7
+--R         (- \|3 sin(----------) - cos(----------))
+--R                         3                 3
+--R      *
+--R         log
+--R                           3   2                                     3
+--R                    atan(----)                                atan(----)
+--R                          +-+                                       +-+
+--R                         \|7          +-+      +-+ 6+----+         \|7
+--R              28sin(----------)  + (x\|7  - 7x\|3 )\|1372 sin(----------)
+--R                         3                                         3
+--R            + 
+--R                           3   2                                       3
+--R                    atan(----)                                  atan(----)
+--R                          +-+                                         +-+
+--R                         \|7            +-+ +-+      6+----+         \|7
+--R              28cos(----------)  + (- x\|3 \|7  - 7x)\|1372 cos(----------)
+--R                         3                                           3
+--R            + 
+--R                2 6+----+2
+--R              2x  \|1372
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|7
+--R         2cos(----------)
+--R                   3
+--R      *
+--R         log
+--R                           3   2                          3
+--R                    atan(----)                     atan(----)
+--R                          +-+                            +-+
+--R                         \|7         +-+6+----+         \|7
+--R              14sin(----------)  - x\|7 \|1372 sin(----------)
+--R                         3                              3
+--R            + 
+--R                           3   2                       3
+--R                    atan(----)                  atan(----)
+--R                          +-+                         +-+
+--R                         \|7         6+----+         \|7       2 6+----+2
+--R              14cos(----------)  + 7x\|1372 cos(----------) + x  \|1372
+--R                         3                           3
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|7
+--R         4sin(----------)
+--R                   3
+--R      *
+--R                                      3                  3
+--R                               atan(----)         atan(----)
+--R                                     +-+                +-+
+--R                        +-+         \|7                \|7
+--R                      7\|7 sin(----------) + 7cos(----------)
+--R                                    3                  3
+--R         atan(-------------------------------------------------------)
+--R                          3                      3
+--R                   atan(----)             atan(----)
+--R                         +-+                    +-+
+--R                        \|7        +-+         \|7         +-+6+----+
+--R              7sin(----------) - 7\|7 cos(----------) - 2x\|7 \|1372
+--R                        3                      3
+--R     + 
+--R                      3                      3
+--R               atan(----)             atan(----)
+--R                     +-+                    +-+
+--R                    \|7        +-+         \|7
+--R         (2sin(----------) - 2\|3 cos(----------))
+--R                    3                      3
+--R      *
+--R         atan
+--R                                        3                                  3
+--R                                 atan(----)                         atan(----)
+--R                                       +-+                                +-+
+--R                 +-+     +-+          \|7           +-+ +-+              \|7
+--R              (7\|7  + 7\|3 )sin(----------) + (- 7\|3 \|7  + 7)cos(----------)
+--R                                      3                                  3
+--R           /
+--R                                          3                                3
+--R                                   atan(----)                       atan(----)
+--R                                         +-+                              +-+
+--R                   +-+ +-+              \|7         +-+     +-+          \|7
+--R                (7\|3 \|7  - 7)sin(----------) + (7\|7  + 7\|3 )cos(----------)
+--R                                        3                                3
+--R              + 
+--R                     +-+6+----+
+--R                - 4x\|7 \|1372
+--R     + 
+--R                        3                      3
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|7        +-+         \|7
+--R         (- 2sin(----------) - 2\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R         atan
+--R                                        3                                3
+--R                                 atan(----)                       atan(----)
+--R                                       +-+                              +-+
+--R                 +-+     +-+          \|7         +-+ +-+              \|7
+--R              (7\|7  - 7\|3 )sin(----------) + (7\|3 \|7  + 7)cos(----------)
+--R                                      3                                3
+--R           /
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                   +-+ +-+              \|7
+--R                (7\|3 \|7  + 7)sin(----------)
+--R                                        3
+--R              + 
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                     +-+     +-+          \|7         +-+6+----+
+--R                (- 7\|7  + 7\|3 )cos(----------) + 4x\|7 \|1372
+--R                                          3
+--R  /
+--R      6+----+
+--R     6\|1372
+--R                                         Type: Union(Expression(Integer),...)
+--E 913
+
+--S 914 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +------------+2  +----------+2
+--R           1 3+-+ +-+ +-+ +--+3|     +-+       3|   +-+          1        3
+--R           - \|2 \|3 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1  sin(- atan(----))
+--R           6                                                     3       +-+
+--R                                                                        \|7
+--R         + 
+--R                             +------------+2  +----------+2
+--R             1 3+-+ +-+ +--+3|     +-+       3|   +-+          1        3
+--R           - - \|2 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1  cos(- atan(----))
+--R             6                                                 3       +-+
+--R                                                                      \|7
+--R      *
+--R         log
+--R                    1        3   2      +-+      +-+ 6+----+    1        3
+--R              28sin(- atan(----))  + (x\|7  + 7x\|3 )\|1372 sin(- atan(----))
+--R                    3       +-+                                 3       +-+
+--R                           \|7                                         \|7
+--R            + 
+--R                    1        3   2      +-+ +-+      6+----+    1        3
+--R              28cos(- atan(----))  + (x\|3 \|7  - 7x)\|1372 cos(- atan(----))
+--R                    3       +-+                                 3       +-+
+--R                           \|7                                         \|7
+--R            + 
+--R                2 6+----+2
+--R              2x  \|1372
+--R     + 
+--R                                 +------------+2  +----------+2
+--R             1 3+-+ +-+ +-+ +--+3|     +-+       3|   +-+          1        3
+--R           - - \|2 \|3 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1  sin(- atan(----))
+--R             6                                                     3       +-+
+--R                                                                          \|7
+--R         + 
+--R                             +------------+2  +----------+2
+--R             1 3+-+ +-+ +--+3|     +-+       3|   +-+          1        3
+--R           - - \|2 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1  cos(- atan(----))
+--R             6                                                 3       +-+
+--R                                                                      \|7
+--R      *
+--R         log
+--R                    1        3   2      +-+      +-+ 6+----+    1        3
+--R              28sin(- atan(----))  + (x\|7  - 7x\|3 )\|1372 sin(- atan(----))
+--R                    3       +-+                                 3       +-+
+--R                           \|7                                         \|7
+--R            + 
+--R                    1        3   2        +-+ +-+      6+----+    1        3
+--R              28cos(- atan(----))  + (- x\|3 \|7  - 7x)\|1372 cos(- atan(----))
+--R                    3       +-+                                   3       +-+
+--R                           \|7                                           \|7
+--R            + 
+--R                2 6+----+2
+--R              2x  \|1372
+--R     + 
+--R                         +------------+2  +----------+2
+--R         1 3+-+ +-+ +--+3|     +-+       3|   +-+          1        3
+--R         - \|2 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1  cos(- atan(----))
+--R         3                                                 3       +-+
+--R                                                                  \|7
+--R      *
+--R         log
+--R                    1        3   2     +-+6+----+    1        3
+--R              14sin(- atan(----))  - x\|7 \|1372 sin(- atan(----))
+--R                    3       +-+                      3       +-+
+--R                           \|7                              \|7
+--R            + 
+--R                    1        3   2     6+----+    1        3       2 6+----+2
+--R              14cos(- atan(----))  + 7x\|1372 cos(- atan(----)) + x  \|1372
+--R                    3       +-+                   3       +-+
+--R                           \|7                           \|7
+--R     + 
+--R                         +------------+2  +----------+2
+--R         2 3+-+ +-+ +--+3|     +-+       3|   +-+          1        3
+--R         - \|2 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1  sin(- atan(----))
+--R         3                                                 3       +-+
+--R                                                                  \|7
+--R      *
+--R                        +-+    1        3          1        3
+--R                       \|7 sin(- atan(----)) + cos(- atan(----))
+--R                               3       +-+         3       +-+
+--R                                      \|7                 \|7
+--R         atan(----------------------------------------------------------)
+--R                  1        3       +-+    1        3      2   +-+6+----+
+--R              sin(- atan(----)) - \|7 cos(- atan(----)) - - x\|7 \|1372
+--R                  3       +-+             3       +-+     7
+--R                         \|7                     \|7
+--R     + 
+--R                           +------------+2  +----------+2
+--R           1 3+-+ +-+ +--+3|     +-+       3|   +-+          1        3
+--R           - \|2 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1  sin(- atan(----))
+--R           3                                                 3       +-+
+--R                                                                    \|7
+--R         + 
+--R                                 +------------+2  +----------+2
+--R             1 3+-+ +-+ +-+ +--+3|     +-+       3|   +-+          1        3
+--R           - - \|2 \|3 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1  cos(- atan(----))
+--R             3                                                     3       +-+
+--R                                                                          \|7
+--R      *
+--R         atan
+--R                +-+    +-+     1        3          +-+ +-+         1        3
+--R              (\|7  + \|3 )sin(- atan(----)) + (- \|3 \|7  + 1)cos(- atan(----))
+--R                               3       +-+                         3       +-+
+--R                                      \|7                                 \|7
+--R           /
+--R                  +-+ +-+         1        3        +-+    +-+     1        3
+--R                (\|3 \|7  - 1)sin(- atan(----)) + (\|7  + \|3 )cos(- atan(----))
+--R                                  3       +-+                      3       +-+
+--R                                         \|7                              \|7
+--R              + 
+--R                  4   +-+6+----+
+--R                - - x\|7 \|1372
+--R                  7
+--R     + 
+--R                             +------------+2  +----------+2
+--R             1 3+-+ +-+ +--+3|     +-+       3|   +-+          1        3
+--R           - - \|2 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1  sin(- atan(----))
+--R             3                                                 3       +-+
+--R                                                                      \|7
+--R         + 
+--R                                 +------------+2  +----------+2
+--R             1 3+-+ +-+ +-+ +--+3|     +-+       3|   +-+          1        3
+--R           - - \|2 \|3 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1  cos(- atan(----))
+--R             3                                                     3       +-+
+--R                                                                          \|7
+--R      *
+--R         atan
+--R                +-+    +-+     1        3        +-+ +-+         1        3
+--R              (\|7  - \|3 )sin(- atan(----)) + (\|3 \|7  + 1)cos(- atan(----))
+--R                               3       +-+                       3       +-+
+--R                                      \|7                               \|7
+--R           /
+--R                  +-+ +-+         1        3
+--R                (\|3 \|7  + 1)sin(- atan(----))
+--R                                  3       +-+
+--R                                         \|7
+--R              + 
+--R                    +-+    +-+     1        3      4   +-+6+----+
+--R                (- \|7  + \|3 )cos(- atan(----)) + - x\|7 \|1372
+--R                                   3       +-+     7
+--R                                          \|7
+--R     + 
+--R                          +------------+2
+--R         1    +--+6+----+3|     +-+
+--R         - %i\|21 \|1372 \|- %i\|7  + 1
+--R         3
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|7  + 1   - x\|2 \|%i\|7  + 1  + x  \|2 )
+--R     + 
+--R                          +------------+2     +----------+
+--R         2    +--+6+----+3|     +-+          3|   +-+         3+-+
+--R       - - %i\|21 \|1372 \|- %i\|7  + 1  log(\|%i\|7  + 1  + x\|2 )
+--R         3
+--R     + 
+--R       -
+--R                             +----------+2
+--R            1    +--+6+----+3|   +-+
+--R            - %i\|21 \|1372 \|%i\|7  + 1
+--R            3
+--R         *
+--R                 +------------+2         +------------+
+--R                3|     +-+          3+-+3|     +-+         2 3+-+2
+--R            log(\|- %i\|7  + 1   - x\|2 \|- %i\|7  + 1  + x  \|2 )
+--R     + 
+--R                        +----------+2     +------------+
+--R       2    +--+6+----+3|   +-+          3|     +-+         3+-+
+--R       - %i\|21 \|1372 \|%i\|7  + 1  log(\|- %i\|7  + 1  + x\|2 )
+--R       3
+--R     + 
+--R                                                 +----------+
+--R                      +------------+2     3+-+2 3|   +-+
+--R           +-+6+----+3|     +-+           \|2   \|%i\|7  + 1 - 4x
+--R       2%i\|7 \|1372 \|- %i\|7  + 1  atan(-----------------------)
+--R                                                     +----------+
+--R                                           3+-+2 +-+3|   +-+
+--R                                           \|2  \|3 \|%i\|7  + 1
+--R     + 
+--R                                                 +------------+
+--R                        +----------+2     3+-+2 3|     +-+
+--R             +-+6+----+3|   +-+           \|2   \|- %i\|7  + 1 - 4x
+--R       - 2%i\|7 \|1372 \|%i\|7  + 1  atan(-------------------------)
+--R                                                     +------------+
+--R                                           3+-+2 +-+3|     +-+
+--R                                           \|2  \|3 \|- %i\|7  + 1
+--R  /
+--R                          +------------+2  +----------+2
+--R     3+-+ +-+ +--+6+----+3|     +-+       3|   +-+
+--R     \|2 \|7 \|21 \|1372 \|- %i\|7  + 1   \|%i\|7  + 1
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 914
+
+--S 915 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                             +------------+2
+--R                1  8   1  5 3|     +-+
+--R               (- x  + - x )\|- %i\|7  + 1
+--R                2      2
+--R             + 
+--R                                   +------------+
+--R                  1  9   1  6 3+-+3|     +-+
+--R               (- - x  - - x )\|2 \|- %i\|7  + 1
+--R                  2      2
+--R             + 
+--R                   1     7    1     4    1      3+-+2 +-+ +--+
+--R               (- -- %i x  - -- %i x  - -- %i x)\|2  \|3 \|21
+--R                  42         42         21
+--R             + 
+--R                 9     7    9     4   1      3+-+2 +-+      1  7   1  4 3+-+2
+--R               (-- %i x  + -- %i x  + - %i x)\|2  \|7  + (- - x  - - x )\|2
+--R                28         28         7                     4      4
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                   +------------+2
+--R                  1  9   1  6 3+-+3|     +-+
+--R               (- - x  - - x )\|2 \|- %i\|7  + 1
+--R                  2      2
+--R             + 
+--R                                    +------------+
+--R                1  10   1  7 3+-+2 3|     +-+
+--R               (- x   + - x )\|2   \|- %i\|7  + 1
+--R                2       2
+--R             + 
+--R                 1     8    1     5    2     2  +-+ +--+
+--R               (-- %i x  + -- %i x  + -- %i x )\|3 \|21
+--R                21         21         21
+--R             + 
+--R                   9     8    9     5   2     2  +-+   1  8   1  5
+--R               (- -- %i x  - -- %i x  - - %i x )\|7  + - x  + - x
+--R                  14         14         7              2      2
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                 1     7    1     4    1      3+-+2 +-+ +--+
+--R               (-- %i x  + -- %i x  + -- %i x)\|2  \|3 \|21
+--R                42         42         21
+--R             + 
+--R                   9     7    9     4   1      3+-+2 +-+      1  7   1  4 3+-+2
+--R               (- -- %i x  - -- %i x  - - %i x)\|2  \|7  + (- - x  - - x )\|2
+--R                  28         28         7                     4      4
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                   1     8    1     5    2     2  +-+ +--+
+--R               (- -- %i x  - -- %i x  - -- %i x )\|3 \|21
+--R                  21         21         21
+--R             + 
+--R                 9     8    9     5   2     2  +-+   1  8   1  5
+--R               (-- %i x  + -- %i x  + - %i x )\|7  + - x  + - x
+--R                14         14         7              2      2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R               1  6    1  3    2 3+-+ +-+ +-+ +--+      6     3     3+-+
+--R           (- -- x  - -- x  - --)\|2 \|3 \|7 \|21  + (3x  + 3x  + 2)\|2
+--R              21      21      21
+--R      *
+--R             1        3   12
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                           +------------+2                     +------------+
+--R                  8     5 3|     +-+              9     6 3+-+3|     +-+
+--R               (3x  + 3x )\|- %i\|7  + 1   + (- 3x  - 3x )\|2 \|- %i\|7  + 1
+--R             + 
+--R                  1     7   1     4   2      3+-+2 +-+ +--+
+--R               (- - %i x  - - %i x  - - %i x)\|2  \|3 \|21
+--R                  7         7         7
+--R             + 
+--R                27     7   27     4   6      3+-+2 +-+      3  7   3  4 3+-+2
+--R               (-- %i x  + -- %i x  + - %i x)\|2  \|7  + (- - x  - - x )\|2
+--R                14         14         7                     2      2
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                 +------------+2
+--R                    9     6 3+-+3|     +-+
+--R               (- 3x  - 3x )\|2 \|- %i\|7  + 1
+--R             + 
+--R                                  +------------+
+--R                  10     7 3+-+2 3|     +-+
+--R               (3x   + 3x )\|2   \|- %i\|7  + 1
+--R             + 
+--R                2     8   2     5   4     2  +-+ +--+
+--R               (- %i x  + - %i x  + - %i x )\|3 \|21
+--R                7         7         7
+--R             + 
+--R                  27     8   27     5   12     2  +-+     8     5
+--R               (- -- %i x  - -- %i x  - -- %i x )\|7  + 3x  + 3x
+--R                   7          7          7
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                1     7   1     4   2      3+-+2 +-+ +--+
+--R               (- %i x  + - %i x  + - %i x)\|2  \|3 \|21
+--R                7         7         7
+--R             + 
+--R                  27     7   27     4   6      3+-+2 +-+      3  7   3  4 3+-+2
+--R               (- -- %i x  - -- %i x  - - %i x)\|2  \|7  + (- - x  - - x )\|2
+--R                  14         14         7                     2      2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                  2     8   2     5   4     2  +-+ +--+
+--R               (- - %i x  - - %i x  - - %i x )\|3 \|21
+--R                  7         7         7
+--R             + 
+--R                27     8   27     5   12     2  +-+     8     5
+--R               (-- %i x  + -- %i x  + -- %i x )\|7  + 3x  + 3x
+--R                 7          7          7
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R              2  6   2  3   4 3+-+ +-+ +-+ +--+       6      3      3+-+
+--R           (- - x  - - x  - -)\|2 \|3 \|7 \|21  + (18x  + 18x  + 12)\|2
+--R              7      7      7
+--R      *
+--R             1        3   2    1        3   10
+--R         cos(- atan(----)) sin(- atan(----))
+--R             3       +-+       3       +-+
+--R                    \|7               \|7
+--R     + 
+--R                                                        +------------+2
+--R                 1   11    1   8    3   5  +-+6+----+3 3|     +-+
+--R               (--- x   + --- x  - --- x )\|7 \|1372   \|- %i\|7  + 1
+--R                112       112      392
+--R             + 
+--R                                                              +------------+
+--R                   1   12    1   9    3   6 3+-+ +-+6+----+3 3|     +-+
+--R               (- --- x   - --- x  + --- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                  112       112      392
+--R             + 
+--R                        5      10     5      7     5      4 3+-+2 +-+ +-+ +--+
+--R                   (- ---- %i x   - ---- %i x  - ---- %i x )\|2  \|3 \|7 \|21
+--R                      8232          8232         4116
+--R                 + 
+--R                       1   10    1   7    3   4 3+-+2 +-+
+--R                   (- --- x   - --- x  + --- x )\|2  \|7
+--R                      224       224      784
+--R                 + 
+--R                     69      10    69      7    1      4 3+-+2
+--R                   (---- %i x   + ---- %i x  - --- %i x )\|2
+--R                    1568          1568         784
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                                              +------------+2
+--R                   1   12    1   9    3   6 3+-+ +-+6+----+3 3|     +-+
+--R               (- --- x   - --- x  + --- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                  112       112      392
+--R             + 
+--R                                                              +------------+
+--R                 1   13    1   10    3   7 3+-+2 +-+6+----+3 3|     +-+
+--R               (--- x   + --- x   - --- x )\|2  \|7 \|1372   \|- %i\|7  + 1
+--R                112       112       392
+--R             + 
+--R                      5      11     5      8     5      5  +-+ +-+ +--+
+--R                   (---- %i x   + ---- %i x  + ---- %i x )\|3 \|7 \|21
+--R                    4116          4116         2058
+--R                 + 
+--R                     1   11    1   8    3   5  +-+    69     11    69     8
+--R                   (--- x   + --- x  - --- x )\|7  - --- %i x   - --- %i x
+--R                    112       112      392           784          784
+--R                 + 
+--R                    1      5
+--R                   --- %i x
+--R                   392
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                  5      10     5      7     5      4 3+-+2 +-+ +-+ +--+
+--R               (---- %i x   + ---- %i x  + ---- %i x )\|2  \|3 \|7 \|21
+--R                8232          8232         4116
+--R             + 
+--R                   1   10    1   7    3   4 3+-+2 +-+
+--R               (- --- x   - --- x  + --- x )\|2  \|7
+--R                  224       224      784
+--R             + 
+--R                   69      10    69      7    1      4 3+-+2
+--R               (- ---- %i x   - ---- %i x  + --- %i x )\|2
+--R                  1568          1568         784
+--R          *
+--R                       +------------+2
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                    5      11     5      8     5      5  +-+ +-+ +--+
+--R               (- ---- %i x   - ---- %i x  - ---- %i x )\|3 \|7 \|21
+--R                  4116          4116         2058
+--R             + 
+--R                 1   11    1   8    3   5  +-+    69     11    69     8
+--R               (--- x   + --- x  - --- x )\|7  + --- %i x   + --- %i x
+--R                112       112      392           784          784
+--R             + 
+--R                  1      5
+--R               - --- %i x
+--R                 392
+--R          *
+--R                       +------------+
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                   5   9    5   6    5   3 3+-+ +-+ +--+
+--R               (- --- x  - --- x  - --- x )\|2 \|3 \|21
+--R                  588      588      294
+--R             + 
+--R                 3  9    3  6    1  3 3+-+ +-+
+--R               (-- x  + -- x  + -- x )\|2 \|7
+--R                49      49      49
+--R          *
+--R             6+----+3
+--R             \|1372
+--R      *
+--R             1        3   9
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                   +------------+2
+--R                    15  8   15  5 3|     +-+
+--R                   (-- x  + -- x )\|- %i\|7  + 1
+--R                     2       2
+--R                 + 
+--R                                         +------------+
+--R                      15  9   15  6 3+-+3|     +-+
+--R                   (- -- x  - -- x )\|2 \|- %i\|7  + 1
+--R                       2       2
+--R                 + 
+--R                       5     7    5     4   5      3+-+2 +-+ +--+
+--R                   (- -- %i x  - -- %i x  - - %i x)\|2  \|3 \|21
+--R                      14         14         7
+--R                 + 
+--R                    135     7   135     4   15      3+-+2 +-+
+--R                   (--- %i x  + --- %i x  + -- %i x)\|2  \|7
+--R                     28          28          7
+--R                 + 
+--R                      15  7   15  4 3+-+2
+--R                   (- -- x  - -- x )\|2
+--R                       4       4
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                         +------------+2
+--R                      15  9   15  6 3+-+3|     +-+
+--R                   (- -- x  - -- x )\|2 \|- %i\|7  + 1
+--R                       2       2
+--R                 + 
+--R                                          +------------+
+--R                    15  10   15  7 3+-+2 3|     +-+
+--R                   (-- x   + -- x )\|2   \|- %i\|7  + 1
+--R                     2        2
+--R                 + 
+--R                    5     8   5     5   10     2  +-+ +--+
+--R                   (- %i x  + - %i x  + -- %i x )\|3 \|21
+--R                    7         7          7
+--R                 + 
+--R                      135     8   135     5   30     2  +-+   15  8   15  5
+--R                   (- --- %i x  - --- %i x  - -- %i x )\|7  + -- x  + -- x
+--R                       14          14          7               2       2
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                     5     7    5     4   5      3+-+2 +-+ +--+
+--R                   (-- %i x  + -- %i x  + - %i x)\|2  \|3 \|21
+--R                    14         14         7
+--R                 + 
+--R                      135     7   135     4   15      3+-+2 +-+
+--R                   (- --- %i x  - --- %i x  - -- %i x)\|2  \|7
+--R                       28          28          7
+--R                 + 
+--R                      15  7   15  4 3+-+2
+--R                   (- -- x  - -- x )\|2
+--R                       4       4
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                      5     8   5     5   10     2  +-+ +--+
+--R                   (- - %i x  - - %i x  - -- %i x )\|3 \|21
+--R                      7         7          7
+--R                 + 
+--R                    135     8   135     5   30     2  +-+   15  8   15  5
+--R                   (--- %i x  + --- %i x  + -- %i x )\|7  + -- x  + -- x
+--R                     14          14          7               2       2
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                  5  6   5  3   10 3+-+ +-+ +-+ +--+       6      3      3+-+
+--R               (- - x  - - x  - --)\|2 \|3 \|7 \|21  + (45x  + 45x  + 30)\|2
+--R                  7      7       7
+--R          *
+--R                 1        3   4
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                          +------------+2
+--R                       39  11    39  8    3   5 6+----+3 3|     +-+
+--R                   (- --- x   - --- x  + --- x )\|1372   \|- %i\|7  + 1
+--R                      784       784      392
+--R                 + 
+--R                                                            +------------+
+--R                     39  12    39  9    3   6 3+-+6+----+3 3|     +-+
+--R                   (--- x   + --- x  - --- x )\|2 \|1372   \|- %i\|7  + 1
+--R                    784       784      392
+--R                 + 
+--R                         1      10    1      7    1      4 3+-+2 +-+ +--+
+--R                       (--- %i x   + --- %i x  + --- %i x )\|2  \|3 \|21
+--R                        392          392         196
+--R                     + 
+--R                           51      10    51      7    9      4 3+-+2 +-+
+--R                       (- ---- %i x   - ---- %i x  - --- %i x )\|2  \|7
+--R                          1568          1568         784
+--R                     + 
+--R                         39   10    39   7    3   4 3+-+2
+--R                       (---- x   + ---- x  - --- x )\|2
+--R                        1568       1568      784
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                            +------------+2
+--R                     39  12    39  9    3   6 3+-+6+----+3 3|     +-+
+--R                   (--- x   + --- x  - --- x )\|2 \|1372   \|- %i\|7  + 1
+--R                    784       784      392
+--R                 + 
+--R                                                                 +------------+
+--R                       39  13    39  10    3   7 3+-+2 6+----+3 3|     +-+
+--R                   (- --- x   - --- x   + --- x )\|2   \|1372   \|- %i\|7  + 1
+--R                      784       784       392
+--R                 + 
+--R                           1      11    1      8    1     5  +-+ +--+
+--R                       (- --- %i x   - --- %i x  - -- %i x )\|3 \|21
+--R                          196          196         98
+--R                     + 
+--R                         51     11    51     8    9      5  +-+    39  11
+--R                       (--- %i x   + --- %i x  + --- %i x )\|7  - --- x
+--R                        784          784         392              784
+--R                     + 
+--R                          39  8    3   5
+--R                       - --- x  + --- x
+--R                         784      392
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                       1      10    1      7    1      4 3+-+2 +-+ +--+
+--R                   (- --- %i x   - --- %i x  - --- %i x )\|2  \|3 \|21
+--R                      392          392         196
+--R                 + 
+--R                     51      10    51      7    9      4 3+-+2 +-+
+--R                   (---- %i x   + ---- %i x  + --- %i x )\|2  \|7
+--R                    1568          1568         784
+--R                 + 
+--R                     39   10    39   7    3   4 3+-+2
+--R                   (---- x   + ---- x  - --- x )\|2
+--R                    1568       1568      784
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     1      11    1      8    1     5  +-+ +--+
+--R                   (--- %i x   + --- %i x  + -- %i x )\|3 \|21
+--R                    196          196         98
+--R                 + 
+--R                       51     11    51     8    9      5  +-+    39  11    39  8
+--R                   (- --- %i x   - --- %i x  - --- %i x )\|7  - --- x   - --- x
+--R                      784          784         392              784       784
+--R                 + 
+--R                    3   5
+--R                   --- x
+--R                   392
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     1   9    1   6    1  3 3+-+ +-+ +-+ +--+
+--R                   (--- x  + --- x  + -- x )\|2 \|3 \|7 \|21
+--R                    196      196      98
+--R                 + 
+--R                      15  9   15  6    9  3 3+-+
+--R                   (- -- x  - -- x  - -- x )\|2
+--R                      49      49      49
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R                 1        3
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R      *
+--R             1        3   8
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                 +------------+2
+--R                       8      5 3|     +-+
+--R                   (10x  + 10x )\|- %i\|7  + 1
+--R                 + 
+--R                                       +------------+
+--R                         9      6 3+-+3|     +-+
+--R                   (- 10x  - 10x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                      10     7   10     4   20      3+-+2 +-+ +--+
+--R                   (- -- %i x  - -- %i x  - -- %i x)\|2  \|3 \|21
+--R                      21         21         21
+--R                 + 
+--R                  45     7   45     4   20      3+-+2 +-+        7     4 3+-+2
+--R                 (-- %i x  + -- %i x  + -- %i x)\|2  \|7  + (- 5x  - 5x )\|2
+--R                   7          7          7
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                       +------------+2
+--R                         9      6 3+-+3|     +-+
+--R                   (- 10x  - 10x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                                        +------------+
+--R                       10      7 3+-+2 3|     +-+
+--R                   (10x   + 10x )\|2   \|- %i\|7  + 1
+--R                 + 
+--R                    20     8   20     5   40     2  +-+ +--+
+--R                   (-- %i x  + -- %i x  + -- %i x )\|3 \|21
+--R                    21         21         21
+--R                 + 
+--R                      90     8   90     5   40     2  +-+      8      5
+--R                   (- -- %i x  - -- %i x  - -- %i x )\|7  + 10x  + 10x
+--R                       7          7          7
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                    10     7   10     4   20      3+-+2 +-+ +--+
+--R                   (-- %i x  + -- %i x  + -- %i x)\|2  \|3 \|21
+--R                    21         21         21
+--R                 + 
+--R                    45     7   45     4   20      3+-+2 +-+        7     4 3+-+2
+--R                 (- -- %i x  - -- %i x  - -- %i x)\|2  \|7  + (- 5x  - 5x )\|2
+--R                     7          7          7
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                      20     8   20     5   40     2  +-+ +--+
+--R                   (- -- %i x  - -- %i x  - -- %i x )\|3 \|21
+--R                      21         21         21
+--R                 + 
+--R                    90     8   90     5   40     2  +-+      8      5
+--R                   (-- %i x  + -- %i x  + -- %i x )\|7  + 10x  + 10x
+--R                     7          7          7
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                  20  6   20  3   40 3+-+ +-+ +-+ +--+       6      3      3+-+
+--R               (- -- x  - -- x  - --)\|2 \|3 \|7 \|21  + (60x  + 60x  + 40)\|2
+--R                  21      21      21
+--R          *
+--R                 1        3   6
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                       +------------+2
+--R                      13  11   13  8    1  5 6+----+3 3|     +-+
+--R                   (- -- x   - -- x  + -- x )\|1372   \|- %i\|7  + 1
+--R                      98       98      49
+--R                 + 
+--R                                                         +------------+
+--R                    13  12   13  9    1  6 3+-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  - -- x )\|2 \|1372   \|- %i\|7  + 1
+--R                    98       98      49
+--R                 + 
+--R                         1      10    1      7    2      4 3+-+2 +-+ +--+
+--R                       (--- %i x   + --- %i x  + --- %i x )\|2  \|3 \|21
+--R                        147          147         147
+--R                     + 
+--R                           17     10    17     7    3     4 3+-+2 +-+
+--R                       (- --- %i x   - --- %i x  - -- %i x )\|2  \|7
+--R                          196          196         98
+--R                     + 
+--R                         13  10    13  7    1  4 3+-+2
+--R                       (--- x   + --- x  - -- x )\|2
+--R                        196       196      98
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                         +------------+2
+--R                    13  12   13  9    1  6 3+-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  - -- x )\|2 \|1372   \|- %i\|7  + 1
+--R                    98       98      49
+--R                 + 
+--R                                                              +------------+
+--R                      13  13   13  10    1  7 3+-+2 6+----+3 3|     +-+
+--R                   (- -- x   - -- x   + -- x )\|2   \|1372   \|- %i\|7  + 1
+--R                      98       98       49
+--R                 + 
+--R                           2      11    2      8    4      5  +-+ +--+
+--R                       (- --- %i x   - --- %i x  - --- %i x )\|3 \|21
+--R                          147          147         147
+--R                     + 
+--R                        17     11   17     8    3     5  +-+   13  11   13  8
+--R                       (-- %i x   + -- %i x  + -- %i x )\|7  - -- x   - -- x
+--R                        98          98         49              98       98
+--R                     + 
+--R                        1  5
+--R                       -- x
+--R                       49
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                       1      10    1      7    2      4 3+-+2 +-+ +--+
+--R                   (- --- %i x   - --- %i x  - --- %i x )\|2  \|3 \|21
+--R                      147          147         147
+--R                 + 
+--R                     17     10    17     7    3     4 3+-+2 +-+
+--R                   (--- %i x   + --- %i x  + -- %i x )\|2  \|7
+--R                    196          196         98
+--R                 + 
+--R                     13  10    13  7    1  4 3+-+2
+--R                   (--- x   + --- x  - -- x )\|2
+--R                    196       196      98
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     2      11    2      8    4      5  +-+ +--+
+--R                   (--- %i x   + --- %i x  + --- %i x )\|3 \|21
+--R                    147          147         147
+--R                 + 
+--R                      17     11   17     8    3     5  +-+   13  11   13  8
+--R                   (- -- %i x   - -- %i x  - -- %i x )\|7  - -- x   - -- x
+--R                      98          98         49              98       98
+--R                 + 
+--R                    1  5
+--R                   -- x
+--R                   49
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     2   9    2   6    4   3 3+-+ +-+ +-+ +--+
+--R                   (--- x  + --- x  + --- x )\|2 \|3 \|7 \|21
+--R                    147      147      147
+--R                 + 
+--R                      40  9   40  6   24  3 3+-+
+--R                   (- -- x  - -- x  - -- x )\|2
+--R                      49      49      49
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R                 1        3   3
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                         +------------+2
+--R                 9  14    9  11   23  8 3|     +-+
+--R               (-- x   + -- x   - -- x )\|- %i\|7  + 1
+--R                16       16       16
+--R             + 
+--R                                               +------------+
+--R                   9  15    9  12   23  9 3+-+3|     +-+
+--R               (- -- x   - -- x   + -- x )\|2 \|- %i\|7  + 1
+--R                  16       16       16
+--R             + 
+--R                   41     13    41     10    41     7 3+-+2 +-+ +--+
+--R               (- --- %i x   - --- %i x   - --- %i x )\|2  \|3 \|21
+--R                  672          672          336
+--R             + 
+--R                13     13   13     10    79     7 3+-+2 +-+
+--R               (-- %i x   + -- %i x   - --- %i x )\|2  \|7
+--R                28          28          224
+--R             + 
+--R                   9  13    9  10   23  7 3+-+2
+--R               (- -- x   - -- x   + -- x )\|2
+--R                  32       32       32
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                               +------------+2
+--R                   9  15    9  12   23  9 3+-+3|     +-+
+--R               (- -- x   - -- x   + -- x )\|2 \|- %i\|7  + 1
+--R                  16       16       16
+--R             + 
+--R                                                +------------+
+--R                 9  16    9  13   23  10 3+-+2 3|     +-+
+--R               (-- x   + -- x   - -- x  )\|2   \|- %i\|7  + 1
+--R                16       16       16
+--R             + 
+--R                 41     14    41     11    41     8  +-+ +--+
+--R               (--- %i x   + --- %i x   + --- %i x )\|3 \|21
+--R                336          336          168
+--R             + 
+--R                13     14   13     11    79     8  +-+    9  14    9  11   23  8
+--R             (- -- %i x   - -- %i x   + --- %i x )\|7  + -- x   + -- x   - -- x
+--R                14          14          112              16       16       16
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                 41     13    41     10    41     7 3+-+2 +-+ +--+
+--R               (--- %i x   + --- %i x   + --- %i x )\|2  \|3 \|21
+--R                672          672          336
+--R             + 
+--R                  13     13   13     10    79     7 3+-+2 +-+
+--R               (- -- %i x   - -- %i x   + --- %i x )\|2  \|7
+--R                  28          28          224
+--R             + 
+--R                   9  13    9  10   23  7 3+-+2
+--R               (- -- x   - -- x   + -- x )\|2
+--R                  32       32       32
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                   41     14    41     11    41     8  +-+ +--+
+--R               (- --- %i x   - --- %i x   - --- %i x )\|3 \|21
+--R                  336          336          168
+--R             + 
+--R              13     14   13     11    79     8  +-+    9  14    9  11   23  8
+--R             (-- %i x   + -- %i x   - --- %i x )\|7  + -- x   + -- x   - -- x
+--R              14          14          112              16       16       16
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R               41  12    41  9    41  6 3+-+ +-+ +-+ +--+
+--R           (- --- x   - --- x  - --- x )\|2 \|3 \|7 \|21
+--R              336       336      168
+--R         + 
+--R            77  12   77  9   5  6 3+-+
+--R           (-- x   + -- x  - - x )\|2
+--R            16       16      8
+--R      *
+--R             1        3   6
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                                            +------------+2
+--R                       3  11    3  8    9   5  +-+6+----+3 3|     +-+
+--R                   (- -- x   - -- x  + --- x )\|7 \|1372   \|- %i\|7  + 1
+--R                      56       56      196
+--R                 + 
+--R                                                              +------------+
+--R                     3  12    3  9    9   6 3+-+ +-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  - --- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    56       56      196
+--R                 + 
+--R                          5      10     5      7    5      4 3+-+2 +-+ +-+ +--+
+--R                       (---- %i x   + ---- %i x  + --- %i x )\|2  \|3 \|7 \|21
+--R                        1372          1372         686
+--R                     + 
+--R                         3   10    3   7    9   4 3+-+2 +-+
+--R                       (--- x   + --- x  - --- x )\|2  \|7
+--R                        112       112      392
+--R                     + 
+--R                          207     10   207     7    3      4 3+-+2
+--R                       (- --- %i x   - --- %i x  + --- %i x )\|2
+--R                          784          784         392
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                              +------------+2
+--R                     3  12    3  9    9   6 3+-+ +-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  - --- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    56       56      196
+--R                 + 
+--R                                                                  +------------+
+--R                       3  13    3  10    9   7 3+-+2 +-+6+----+3 3|     +-+
+--R                   (- -- x   - -- x   + --- x )\|2  \|7 \|1372   \|- %i\|7  + 1
+--R                      56       56       196
+--R                 + 
+--R                           5      11    5      8    5      5  +-+ +-+ +--+
+--R                       (- --- %i x   - --- %i x  - --- %i x )\|3 \|7 \|21
+--R                          686          686         343
+--R                     + 
+--R                           3  11    3  8    9   5  +-+   207     11   207     8
+--R                       (- -- x   - -- x  + --- x )\|7  + --- %i x   + --- %i x
+--R                          56       56      196           392          392
+--R                     + 
+--R                          3      5
+--R                       - --- %i x
+--R                         196
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                        5      10     5      7    5      4 3+-+2 +-+ +-+ +--+
+--R                   (- ---- %i x   - ---- %i x  - --- %i x )\|2  \|3 \|7 \|21
+--R                      1372          1372         686
+--R                 + 
+--R                     3   10    3   7    9   4 3+-+2 +-+
+--R                   (--- x   + --- x  - --- x )\|2  \|7
+--R                    112       112      392
+--R                 + 
+--R                    207     10   207     7    3      4 3+-+2
+--R                   (--- %i x   + --- %i x  - --- %i x )\|2
+--R                    784          784         392
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     5      11    5      8    5      5  +-+ +-+ +--+
+--R                   (--- %i x   + --- %i x  + --- %i x )\|3 \|7 \|21
+--R                    686          686         343
+--R                 + 
+--R                       3  11    3  8    9   5  +-+   207     11   207     8
+--R                   (- -- x   - -- x  + --- x )\|7  - --- %i x   - --- %i x
+--R                      56       56      196           392          392
+--R                 + 
+--R                    3      5
+--R                   --- %i x
+--R                   196
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     5  9    5  6    5  3 3+-+ +-+ +--+
+--R                   (-- x  + -- x  + -- x )\|2 \|3 \|21
+--R                    98      98      49
+--R                 + 
+--R                      18  9   18  6    6  3 3+-+ +-+
+--R                   (- -- x  - -- x  - -- x )\|2 \|7
+--R                      49      49      49
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R                 1        3   4
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                   +------------+2
+--R                      33  14   33  11   39  8  +-+3|     +-+
+--R                   (- -- x   - -- x   + -- x )\|7 \|- %i\|7  + 1
+--R                      56       56       56
+--R                 + 
+--R                                                     +------------+
+--R                    33  15   33  12   39  9 3+-+ +-+3|     +-+
+--R                   (-- x   + -- x   - -- x )\|2 \|7 \|- %i\|7  + 1
+--R                    56       56       56
+--R                 + 
+--R                     5      13    5      10    5     7 3+-+2 +-+ +-+ +--+
+--R                   (--- %i x   + --- %i x   + -- %i x )\|2  \|3 \|7 \|21
+--R                    112          112          56
+--R                 + 
+--R                     33  13    33  10    39  7 3+-+2 +-+
+--R                   (--- x   + --- x   - --- x )\|2  \|7
+--R                    112       112       112
+--R                 + 
+--R                           13        10    9     7 3+-+2
+--R                   (- 3%i x   - 3%i x   + -- %i x )\|2
+--R                                          16
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                     +------------+2
+--R                    33  15   33  12   39  9 3+-+ +-+3|     +-+
+--R                   (-- x   + -- x   - -- x )\|2 \|7 \|- %i\|7  + 1
+--R                    56       56       56
+--R                 + 
+--R                                                         +------------+
+--R                      33  16   33  13   39  10 3+-+2 +-+3|     +-+
+--R                   (- -- x   - -- x   + -- x  )\|2  \|7 \|- %i\|7  + 1
+--R                      56       56       56
+--R                 + 
+--R                       5     14    5     11    5     8  +-+ +-+ +--+
+--R                   (- -- %i x   - -- %i x   - -- %i x )\|3 \|7 \|21
+--R                      56          56          28
+--R                 + 
+--R                    33  14   33  11   39  8  +-+        14        11   9     8
+--R                 (- -- x   - -- x   + -- x )\|7  + 6%i x   + 6%i x   - - %i x
+--R                    56       56       56                               8
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                       5      13    5      10    5     7 3+-+2 +-+ +-+ +--+
+--R                   (- --- %i x   - --- %i x   - -- %i x )\|2  \|3 \|7 \|21
+--R                      112          112          56
+--R                 + 
+--R                     33  13    33  10    39  7 3+-+2 +-+
+--R                   (--- x   + --- x   - --- x )\|2  \|7
+--R                    112       112       112
+--R                 + 
+--R                         13        10    9     7 3+-+2
+--R                   (3%i x   + 3%i x   - -- %i x )\|2
+--R                                        16
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                     5     14    5     11    5     8  +-+ +-+ +--+
+--R                   (-- %i x   + -- %i x   + -- %i x )\|3 \|7 \|21
+--R                    56          56          28
+--R                 + 
+--R                    33  14   33  11   39  8  +-+        14        11   9     8
+--R                 (- -- x   - -- x   + -- x )\|7  - 6%i x   - 6%i x   + - %i x
+--R                    56       56       56                               8
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                5  12   5  9   5  6 3+-+ +-+ +--+
+--R               (- x   + - x  + - x )\|2 \|3 \|21
+--R                8       8      4
+--R             + 
+--R                  237  12   237  9   27  6 3+-+ +-+
+--R               (- --- x   - --- x  - -- x )\|2 \|7
+--R                   56        56      28
+--R          *
+--R                 1        3
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R      *
+--R             1        3   5
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                   +------------+2
+--R                    15  8   15  5 3|     +-+
+--R                   (-- x  + -- x )\|- %i\|7  + 1
+--R                     2       2
+--R                 + 
+--R                                         +------------+
+--R                      15  9   15  6 3+-+3|     +-+
+--R                   (- -- x  - -- x )\|2 \|- %i\|7  + 1
+--R                       2       2
+--R                 + 
+--R                       5     7    5     4   5      3+-+2 +-+ +--+
+--R                   (- -- %i x  - -- %i x  - - %i x)\|2  \|3 \|21
+--R                      14         14         7
+--R                 + 
+--R                    135     7   135     4   15      3+-+2 +-+
+--R                   (--- %i x  + --- %i x  + -- %i x)\|2  \|7
+--R                     28          28          7
+--R                 + 
+--R                      15  7   15  4 3+-+2
+--R                   (- -- x  - -- x )\|2
+--R                       4       4
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                         +------------+2
+--R                      15  9   15  6 3+-+3|     +-+
+--R                   (- -- x  - -- x )\|2 \|- %i\|7  + 1
+--R                       2       2
+--R                 + 
+--R                                          +------------+
+--R                    15  10   15  7 3+-+2 3|     +-+
+--R                   (-- x   + -- x )\|2   \|- %i\|7  + 1
+--R                     2        2
+--R                 + 
+--R                    5     8   5     5   10     2  +-+ +--+
+--R                   (- %i x  + - %i x  + -- %i x )\|3 \|21
+--R                    7         7          7
+--R                 + 
+--R                      135     8   135     5   30     2  +-+   15  8   15  5
+--R                   (- --- %i x  - --- %i x  - -- %i x )\|7  + -- x  + -- x
+--R                       14          14          7               2       2
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                     5     7    5     4   5      3+-+2 +-+ +--+
+--R                   (-- %i x  + -- %i x  + - %i x)\|2  \|3 \|21
+--R                    14         14         7
+--R                 + 
+--R                      135     7   135     4   15      3+-+2 +-+
+--R                   (- --- %i x  - --- %i x  - -- %i x)\|2  \|7
+--R                       28          28          7
+--R                 + 
+--R                      15  7   15  4 3+-+2
+--R                   (- -- x  - -- x )\|2
+--R                       4       4
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                      5     8   5     5   10     2  +-+ +--+
+--R                   (- - %i x  - - %i x  - -- %i x )\|3 \|21
+--R                      7         7          7
+--R                 + 
+--R                    135     8   135     5   30     2  +-+   15  8   15  5
+--R                   (--- %i x  + --- %i x  + -- %i x )\|7  + -- x  + -- x
+--R                     14          14          7               2       2
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                  5  6   5  3   10 3+-+ +-+ +-+ +--+       6      3      3+-+
+--R               (- - x  - - x  - --)\|2 \|3 \|7 \|21  + (45x  + 45x  + 30)\|2
+--R                  7      7       7
+--R          *
+--R                 1        3   8
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                          +------------+2
+--R                       39  11    39  8    3   5 6+----+3 3|     +-+
+--R                   (- --- x   - --- x  + --- x )\|1372   \|- %i\|7  + 1
+--R                      392       392      196
+--R                 + 
+--R                                                            +------------+
+--R                     39  12    39  9    3   6 3+-+6+----+3 3|     +-+
+--R                   (--- x   + --- x  - --- x )\|2 \|1372   \|- %i\|7  + 1
+--R                    392       392      196
+--R                 + 
+--R                         1      10    1      7    1     4 3+-+2 +-+ +--+
+--R                       (--- %i x   + --- %i x  + -- %i x )\|2  \|3 \|21
+--R                        196          196         98
+--R                     + 
+--R                           51     10    51     7    9      4 3+-+2 +-+
+--R                       (- --- %i x   - --- %i x  - --- %i x )\|2  \|7
+--R                          784          784         392
+--R                     + 
+--R                         39  10    39  7    3   4 3+-+2
+--R                       (--- x   + --- x  - --- x )\|2
+--R                        784       784      392
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                            +------------+2
+--R                     39  12    39  9    3   6 3+-+6+----+3 3|     +-+
+--R                   (--- x   + --- x  - --- x )\|2 \|1372   \|- %i\|7  + 1
+--R                    392       392      196
+--R                 + 
+--R                                                                 +------------+
+--R                       39  13    39  10    3   7 3+-+2 6+----+3 3|     +-+
+--R                   (- --- x   - --- x   + --- x )\|2   \|1372   \|- %i\|7  + 1
+--R                      392       392       196
+--R                 + 
+--R                           1     11    1     8    1     5  +-+ +--+
+--R                       (- -- %i x   - -- %i x  - -- %i x )\|3 \|21
+--R                          98          98         49
+--R                     + 
+--R                         51     11    51     8    9      5  +-+    39  11
+--R                       (--- %i x   + --- %i x  + --- %i x )\|7  - --- x
+--R                        392          392         196              392
+--R                     + 
+--R                          39  8    3   5
+--R                       - --- x  + --- x
+--R                         392      196
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                       1      10    1      7    1     4 3+-+2 +-+ +--+
+--R                   (- --- %i x   - --- %i x  - -- %i x )\|2  \|3 \|21
+--R                      196          196         98
+--R                 + 
+--R                     51     10    51     7    9      4 3+-+2 +-+
+--R                   (--- %i x   + --- %i x  + --- %i x )\|2  \|7
+--R                    784          784         392
+--R                 + 
+--R                     39  10    39  7    3   4 3+-+2
+--R                   (--- x   + --- x  - --- x )\|2
+--R                    784       784      392
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     1     11    1     8    1     5  +-+ +--+
+--R                   (-- %i x   + -- %i x  + -- %i x )\|3 \|21
+--R                    98          98         49
+--R                 + 
+--R                       51     11    51     8    9      5  +-+    39  11    39  8
+--R                   (- --- %i x   - --- %i x  - --- %i x )\|7  - --- x   - --- x
+--R                      392          392         196              392       392
+--R                 + 
+--R                    3   5
+--R                   --- x
+--R                   196
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     1  9    1  6    1  3 3+-+ +-+ +-+ +--+
+--R                   (-- x  + -- x  + -- x )\|2 \|3 \|7 \|21
+--R                    98      98      49
+--R                 + 
+--R                      30  9   30  6   18  3 3+-+
+--R                   (- -- x  - -- x  - -- x )\|2
+--R                      49      49      49
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R                 1        3   5
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                             +------------+2
+--R                     9  14    9  11   57  8 3|     +-+
+--R                   (-- x   + -- x   + -- x )\|- %i\|7  + 1
+--R                    16       16       16
+--R                 + 
+--R                                                   +------------+
+--R                       9  15    9  12   57  9 3+-+3|     +-+
+--R                   (- -- x   - -- x   - -- x )\|2 \|- %i\|7  + 1
+--R                      16       16       16
+--R                 + 
+--R                     13     13    13     10    13     7 3+-+2 +-+ +--+
+--R                   (--- %i x   + --- %i x   + --- %i x )\|2  \|3 \|21
+--R                    224          224          112
+--R                 + 
+--R                     3     13    3     10   321     7 3+-+2 +-+
+--R                   (-- %i x   + -- %i x   + --- %i x )\|2  \|7
+--R                    28          28          224
+--R                 + 
+--R                       9  13    9  10   57  7 3+-+2
+--R                   (- -- x   - -- x   - -- x )\|2
+--R                      32       32       32
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                   +------------+2
+--R                       9  15    9  12   57  9 3+-+3|     +-+
+--R                   (- -- x   - -- x   - -- x )\|2 \|- %i\|7  + 1
+--R                      16       16       16
+--R                 + 
+--R                                                    +------------+
+--R                     9  16    9  13   57  10 3+-+2 3|     +-+
+--R                   (-- x   + -- x   + -- x  )\|2   \|- %i\|7  + 1
+--R                    16       16       16
+--R                 + 
+--R                       13     14    13     11   13     8  +-+ +--+
+--R                   (- --- %i x   - --- %i x   - -- %i x )\|3 \|21
+--R                      112          112          56
+--R                 + 
+--R                       3     14    3     11   321     8  +-+    9  14    9  11
+--R                   (- -- %i x   - -- %i x   - --- %i x )\|7  + -- x   + -- x
+--R                      14          14          112              16       16
+--R                 + 
+--R                   57  8
+--R                   -- x
+--R                   16
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                       13     13    13     10    13     7 3+-+2 +-+ +--+
+--R                   (- --- %i x   - --- %i x   - --- %i x )\|2  \|3 \|21
+--R                      224          224          112
+--R                 + 
+--R                       3     13    3     10   321     7 3+-+2 +-+
+--R                   (- -- %i x   - -- %i x   - --- %i x )\|2  \|7
+--R                      28          28          224
+--R                 + 
+--R                       9  13    9  10   57  7 3+-+2
+--R                   (- -- x   - -- x   - -- x )\|2
+--R                      32       32       32
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                     13     14    13     11   13     8  +-+ +--+
+--R                   (--- %i x   + --- %i x   + -- %i x )\|3 \|21
+--R                    112          112          56
+--R                 + 
+--R                     3     14    3     11   321     8  +-+    9  14    9  11
+--R                   (-- %i x   + -- %i x   + --- %i x )\|7  + -- x   + -- x
+--R                    14          14          112              16       16
+--R                 + 
+--R                   57  8
+--R                   -- x
+--R                   16
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                 13  12    13  9   13  6 3+-+ +-+ +-+ +--+
+--R               (--- x   + --- x  + -- x )\|2 \|3 \|7 \|21
+--R                112       112      56
+--R             + 
+--R                   3  12    3  9   75  6 3+-+
+--R               (- -- x   - -- x  + -- x )\|2
+--R                  16       16       8
+--R          *
+--R                 1        3   2
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R      *
+--R             1        3   4
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                                           +------------+2
+--R                       1  11    1  8    3  5  +-+6+----+3 3|     +-+
+--R                   (- -- x   - -- x  + -- x )\|7 \|1372   \|- %i\|7  + 1
+--R                      14       14      49
+--R                 + 
+--R                                                             +------------+
+--R                     1  12    1  9    3  6 3+-+ +-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  - -- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    14       14      49
+--R                 + 
+--R                          5      10     5      7    10      4 3+-+2 +-+ +-+ +--+
+--R                       (---- %i x   + ---- %i x  + ---- %i x )\|2  \|3 \|7 \|21
+--R                        1029          1029         1029
+--R                     + 
+--R                         1  10    1  7    3  4 3+-+2 +-+
+--R                       (-- x   + -- x  - -- x )\|2  \|7
+--R                        28       28      98
+--R                     + 
+--R                           69     10    69     7    1     4 3+-+2
+--R                       (- --- %i x   - --- %i x  + -- %i x )\|2
+--R                          196          196         98
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                             +------------+2
+--R                     1  12    1  9    3  6 3+-+ +-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  - -- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    14       14      49
+--R                 + 
+--R                                                                 +------------+
+--R                       1  13    1  10    3  7 3+-+2 +-+6+----+3 3|     +-+
+--R                   (- -- x   - -- x   + -- x )\|2  \|7 \|1372   \|- %i\|7  + 1
+--R                      14       14       49
+--R                 + 
+--R                           10      11    10      8    20      5  +-+ +-+ +--+
+--R                       (- ---- %i x   - ---- %i x  - ---- %i x )\|3 \|7 \|21
+--R                          1029          1029         1029
+--R                     + 
+--R                           1  11    1  8    3  5  +-+   69     11   69     8
+--R                       (- -- x   - -- x  + -- x )\|7  + -- %i x   + -- %i x
+--R                          14       14      49           98          98
+--R                     + 
+--R                          1     5
+--R                       - -- %i x
+--R                         49
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                        5      10     5      7    10      4 3+-+2 +-+ +-+ +--+
+--R                   (- ---- %i x   - ---- %i x  - ---- %i x )\|2  \|3 \|7 \|21
+--R                      1029          1029         1029
+--R                 + 
+--R                     1  10    1  7    3  4 3+-+2 +-+
+--R                   (-- x   + -- x  - -- x )\|2  \|7
+--R                    28       28      98
+--R                 + 
+--R                     69     10    69     7    1     4 3+-+2
+--R                   (--- %i x   + --- %i x  - -- %i x )\|2
+--R                    196          196         98
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     10      11    10      8    20      5  +-+ +-+ +--+
+--R                   (---- %i x   + ---- %i x  + ---- %i x )\|3 \|7 \|21
+--R                    1029          1029         1029
+--R                 + 
+--R                       1  11    1  8    3  5  +-+   69     11   69     8
+--R                   (- -- x   - -- x  + -- x )\|7  - -- %i x   - -- %i x
+--R                      14       14      49           98          98
+--R                 + 
+--R                    1     5
+--R                   -- %i x
+--R                   49
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     10  9    10  6    20  3 3+-+ +-+ +--+
+--R                   (--- x  + --- x  + --- x )\|2 \|3 \|21
+--R                    147      147      147
+--R                 + 
+--R                      24  9   24  6    8  3 3+-+ +-+
+--R                   (- -- x  - -- x  - -- x )\|2 \|7
+--R                      49      49      49
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R                 1        3   6
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                 +------------+2
+--R                    55  14   55  11   65  8  +-+3|     +-+
+--R                   (-- x   + -- x   - -- x )\|7 \|- %i\|7  + 1
+--R                    28       28       28
+--R                 + 
+--R                                                       +------------+
+--R                      55  15   55  12   65  9 3+-+ +-+3|     +-+
+--R                   (- -- x   - -- x   + -- x )\|2 \|7 \|- %i\|7  + 1
+--R                      28       28       28
+--R                 + 
+--R                       25     13    25     10   25     7 3+-+2 +-+ +-+ +--+
+--R                   (- --- %i x   - --- %i x   - -- %i x )\|2  \|3 \|7 \|21
+--R                      168          168          84
+--R                 + 
+--R                      55  13   55  10   65  7 3+-+2 +-+
+--R                   (- -- x   - -- x   + -- x )\|2  \|7
+--R                      56       56       56
+--R                 + 
+--R                          13         10   15     7 3+-+2
+--R                   (10%i x   + 10%i x   - -- %i x )\|2
+--R                                           8
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                       +------------+2
+--R                      55  15   55  12   65  9 3+-+ +-+3|     +-+
+--R                   (- -- x   - -- x   + -- x )\|2 \|7 \|- %i\|7  + 1
+--R                      28       28       28
+--R                 + 
+--R                                                       +------------+
+--R                    55  16   55  13   65  10 3+-+2 +-+3|     +-+
+--R                   (-- x   + -- x   - -- x  )\|2  \|7 \|- %i\|7  + 1
+--R                    28       28       28
+--R                 + 
+--R                    25     14   25     11   25     8  +-+ +-+ +--+
+--R                   (-- %i x   + -- %i x   + -- %i x )\|3 \|7 \|21
+--R                    84          84          42
+--R                 + 
+--R                  55  14   55  11   65  8  +-+         14         11   15     8
+--R                 (-- x   + -- x   - -- x )\|7  - 20%i x   - 20%i x   + -- %i x
+--R                  28       28       28                                  4
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                     25     13    25     10   25     7 3+-+2 +-+ +-+ +--+
+--R                   (--- %i x   + --- %i x   + -- %i x )\|2  \|3 \|7 \|21
+--R                    168          168          84
+--R                 + 
+--R                      55  13   55  10   65  7 3+-+2 +-+
+--R                   (- -- x   - -- x   + -- x )\|2  \|7
+--R                      56       56       56
+--R                 + 
+--R                            13         10   15     7 3+-+2
+--R                   (- 10%i x   - 10%i x   + -- %i x )\|2
+--R                                             8
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                      25     14   25     11   25     8  +-+ +-+ +--+
+--R                   (- -- %i x   - -- %i x   - -- %i x )\|3 \|7 \|21
+--R                      84          84          42
+--R                 + 
+--R                  55  14   55  11   65  8  +-+         14         11   15     8
+--R                 (-- x   + -- x   - -- x )\|7  + 20%i x   + 20%i x   - -- %i x
+--R                  28       28       28                                  4
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                  25  12   25  9   25  6 3+-+ +-+ +--+
+--R               (- -- x   - -- x  - -- x )\|2 \|3 \|21
+--R                  12       12       6
+--R             + 
+--R                395  12   395  9   45  6 3+-+ +-+
+--R               (--- x   + --- x  + -- x )\|2 \|7
+--R                 28        28      14
+--R          *
+--R                 1        3   3
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                         +------------+2
+--R                 1   17    1   14    1  11  +-+6+----+3 3|     +-+
+--R               (--- x   + --- x   - -- x  )\|7 \|1372   \|- %i\|7  + 1
+--R                784       784       98
+--R             + 
+--R                                                               +------------+
+--R                   1   18    1   15    1  12 3+-+ +-+6+----+3 3|     +-+
+--R               (- --- x   - --- x   + -- x  )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                  784       784       98
+--R             + 
+--R                          5       16     5       13     5      10 3+-+2 +-+ +-+
+--R                     (- ----- %i x   - ----- %i x   - ---- %i x  )\|2  \|3 \|7
+--R                        16464          16464          8232
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                        1   16     1   13    1   10 3+-+2 +-+
+--R                   (- ---- x   - ---- x   + --- x  )\|2  \|7
+--R                      1568       1568       196
+--R                 + 
+--R                     17      16    17      13    9      10 3+-+2
+--R                   (---- %i x   + ---- %i x   - --- %i x  )\|2
+--R                    1568          1568          392
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                                               +------------+2
+--R                   1   18    1   15    1  12 3+-+ +-+6+----+3 3|     +-+
+--R               (- --- x   - --- x   + -- x  )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                  784       784       98
+--R             + 
+--R                                                              +------------+
+--R                 1   19    1   16    1  13 3+-+2 +-+6+----+3 3|     +-+
+--R               (--- x   + --- x   - -- x  )\|2  \|7 \|1372   \|- %i\|7  + 1
+--R                784       784       98
+--R             + 
+--R                      5      17     5      14     5      11  +-+ +-+ +--+
+--R                   (---- %i x   + ---- %i x   + ---- %i x  )\|3 \|7 \|21
+--R                    8232          8232          4116
+--R                 + 
+--R                     1   17    1   14    1  11  +-+    17     17    17     14
+--R                   (--- x   + --- x   - -- x  )\|7  - --- %i x   - --- %i x
+--R                    784       784       98            784          784
+--R                 + 
+--R                    9      11
+--R                   --- %i x
+--R                   196
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                  5       16     5       13     5      10 3+-+2 +-+ +-+ +--+
+--R               (----- %i x   + ----- %i x   + ---- %i x  )\|2  \|3 \|7 \|21
+--R                16464          16464          8232
+--R             + 
+--R                    1   16     1   13    1   10 3+-+2 +-+
+--R               (- ---- x   - ---- x   + --- x  )\|2  \|7
+--R                  1568       1568       196
+--R             + 
+--R                   17      16    17      13    9      10 3+-+2
+--R               (- ---- %i x   - ---- %i x   + --- %i x  )\|2
+--R                  1568          1568          392
+--R          *
+--R                       +------------+2
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                    5      17     5      14     5      11  +-+ +-+ +--+
+--R               (- ---- %i x   - ---- %i x   - ---- %i x  )\|3 \|7 \|21
+--R                  8232          8232          4116
+--R             + 
+--R                 1   17    1   14    1  11  +-+    17     17    17     14
+--R               (--- x   + --- x   - -- x  )\|7  + --- %i x   + --- %i x
+--R                784       784       98            784          784
+--R             + 
+--R                  9      11
+--R               - --- %i x
+--R                 196
+--R          *
+--R                       +------------+
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                    5   15     5   12    5   9 3+-+ +-+ +--+
+--R               (- ---- x   - ---- x   - --- x )\|2 \|3 \|21
+--R                  1176       1176       588
+--R             + 
+--R                 1  15    1  12    3   9 3+-+ +-+
+--R               (-- x   + -- x   - --- x )\|2 \|7
+--R                56       56       196
+--R          *
+--R             6+----+3
+--R             \|1372
+--R      *
+--R             1        3   3
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                               +------------+2
+--R                      8     5 3|     +-+
+--R                   (3x  + 3x )\|- %i\|7  + 1
+--R                 + 
+--R                                     +------------+
+--R                        9     6 3+-+3|     +-+
+--R                   (- 3x  - 3x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                      1     7   1     4   2      3+-+2 +-+ +--+
+--R                   (- - %i x  - - %i x  - - %i x)\|2  \|3 \|21
+--R                      7         7         7
+--R                 + 
+--R                  27     7   27     4   6      3+-+2 +-+      3  7   3  4 3+-+2
+--R                 (-- %i x  + -- %i x  + - %i x)\|2  \|7  + (- - x  - - x )\|2
+--R                  14         14         7                     2      2
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                     +------------+2
+--R                        9     6 3+-+3|     +-+
+--R                   (- 3x  - 3x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                                      +------------+
+--R                      10     7 3+-+2 3|     +-+
+--R                   (3x   + 3x )\|2   \|- %i\|7  + 1
+--R                 + 
+--R                    2     8   2     5   4     2  +-+ +--+
+--R                   (- %i x  + - %i x  + - %i x )\|3 \|21
+--R                    7         7         7
+--R                 + 
+--R                      27     8   27     5   12     2  +-+     8     5
+--R                   (- -- %i x  - -- %i x  - -- %i x )\|7  + 3x  + 3x
+--R                       7          7          7
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                    1     7   1     4   2      3+-+2 +-+ +--+
+--R                   (- %i x  + - %i x  + - %i x)\|2  \|3 \|21
+--R                    7         7         7
+--R                 + 
+--R                      27     7   27     4   6      3+-+2 +-+
+--R                   (- -- %i x  - -- %i x  - - %i x)\|2  \|7
+--R                      14         14         7
+--R                 + 
+--R                      3  7   3  4 3+-+2
+--R                   (- - x  - - x )\|2
+--R                      2      2
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                      2     8   2     5   4     2  +-+ +--+
+--R                   (- - %i x  - - %i x  - - %i x )\|3 \|21
+--R                      7         7         7
+--R                 + 
+--R                    27     8   27     5   12     2  +-+     8     5
+--R                   (-- %i x  + -- %i x  + -- %i x )\|7  + 3x  + 3x
+--R                     7          7          7
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                  2  6   2  3   4 3+-+ +-+ +-+ +--+       6      3      3+-+
+--R               (- - x  - - x  - -)\|2 \|3 \|7 \|21  + (18x  + 18x  + 12)\|2
+--R                  7      7      7
+--R          *
+--R                 1        3   10
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                              +------------+2
+--R                    39  14   39  11   153  8 3|     +-+
+--R                   (-- x   + -- x   - --- x )\|- %i\|7  + 1
+--R                    16       16        16
+--R                 + 
+--R                                                    +------------+
+--R                      39  15   39  12   153  9 3+-+3|     +-+
+--R                   (- -- x   - -- x   + --- x )\|2 \|- %i\|7  + 1
+--R                      16       16        16
+--R                 + 
+--R                      11     13   11     10   11     7 3+-+2 +-+ +--+
+--R                   (- -- %i x   - -- %i x   - -- %i x )\|2  \|3 \|21
+--R                      32          32          16
+--R                 + 
+--R                    9     13   9     10   87     7 3+-+2 +-+
+--R                   (- %i x   + - %i x   - -- %i x )\|2  \|7
+--R                    4          4          32
+--R                 + 
+--R                      39  13   39  10   153  7 3+-+2
+--R                   (- -- x   - -- x   + --- x )\|2
+--R                      32       32        32
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                    +------------+2
+--R                      39  15   39  12   153  9 3+-+3|     +-+
+--R                   (- -- x   - -- x   + --- x )\|2 \|- %i\|7  + 1
+--R                      16       16        16
+--R                 + 
+--R                                                     +------------+
+--R                    39  16   39  13   153  10 3+-+2 3|     +-+
+--R                   (-- x   + -- x   - --- x  )\|2   \|- %i\|7  + 1
+--R                    16       16        16
+--R                 + 
+--R                    11     14   11     11   11     8  +-+ +--+
+--R                   (-- %i x   + -- %i x   + -- %i x )\|3 \|21
+--R                    16          16           8
+--R                 + 
+--R                      9     14   9     11   87     8  +-+   39  14   39  11
+--R                   (- - %i x   - - %i x   + -- %i x )\|7  + -- x   + -- x
+--R                      2          2          16              16       16
+--R                 + 
+--R                     153  8
+--R                   - --- x
+--R                      16
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                    11     13   11     10   11     7 3+-+2 +-+ +--+
+--R                   (-- %i x   + -- %i x   + -- %i x )\|2  \|3 \|21
+--R                    32          32          16
+--R                 + 
+--R                      9     13   9     10   87     7 3+-+2 +-+
+--R                   (- - %i x   - - %i x   + -- %i x )\|2  \|7
+--R                      4          4          32
+--R                 + 
+--R                      39  13   39  10   153  7 3+-+2
+--R                   (- -- x   - -- x   + --- x )\|2
+--R                      32       32        32
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                      11     14   11     11   11     8  +-+ +--+
+--R                   (- -- %i x   - -- %i x   - -- %i x )\|3 \|21
+--R                      16          16           8
+--R                 + 
+--R                  9     14   9     11   87     8  +-+   39  14   39  11   153  8
+--R                 (- %i x   + - %i x   - -- %i x )\|7  + -- x   + -- x   - --- x
+--R                  2          2          16              16       16        16
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                  11  12   11  9   11  6 3+-+ +-+ +-+ +--+
+--R               (- -- x   - -- x  - -- x )\|2 \|3 \|7 \|21
+--R                  16       16       8
+--R             + 
+--R                387  12   387  9   75  6 3+-+
+--R               (--- x   + --- x  - -- x )\|2
+--R                 16        16       8
+--R          *
+--R                 1        3   4
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                           +------------+2
+--R                       9   17    9   14    3  11 6+----+3 3|     +-+
+--R                   (- --- x   - --- x   + -- x  )\|1372   \|- %i\|7  + 1
+--R                      784       784       98
+--R                 + 
+--R                                                             +------------+
+--R                     9   18    9   15    3  12 3+-+6+----+3 3|     +-+
+--R                   (--- x   + --- x   - -- x  )\|2 \|1372   \|- %i\|7  + 1
+--R                    784       784       98
+--R                 + 
+--R                         1      16    1      13    1      10 3+-+2 +-+ +--+
+--R                       (--- %i x   + --- %i x   + --- %i x  )\|2  \|3 \|21
+--R                        784          784          392
+--R                     + 
+--R                           15      16    15      13    3      10 3+-+2 +-+
+--R                       (- ---- %i x   - ---- %i x   + --- %i x  )\|2  \|7
+--R                          1568          1568          392
+--R                     + 
+--R                          9   16     9   13    3   10 3+-+2
+--R                       (---- x   + ---- x   - --- x  )\|2
+--R                        1568       1568       196
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                             +------------+2
+--R                     9   18    9   15    3  12 3+-+6+----+3 3|     +-+
+--R                   (--- x   + --- x   - -- x  )\|2 \|1372   \|- %i\|7  + 1
+--R                    784       784       98
+--R                 + 
+--R                                                                 +------------+
+--R                       9   19    9   16    3  13 3+-+2 6+----+3 3|     +-+
+--R                   (- --- x   - --- x   + -- x  )\|2   \|1372   \|- %i\|7  + 1
+--R                      784       784       98
+--R                 + 
+--R                           1      17    1      14    1      11  +-+ +--+
+--R                       (- --- %i x   - --- %i x   - --- %i x  )\|3 \|21
+--R                          392          392          196
+--R                     + 
+--R                         15     17    15     14    3      11  +-+    9   17
+--R                       (--- %i x   + --- %i x   - --- %i x  )\|7  - --- x
+--R                        784          784          196               784
+--R                     + 
+--R                          9   14    3  11
+--R                       - --- x   + -- x
+--R                         784       98
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                       1      16    1      13    1      10 3+-+2 +-+ +--+
+--R                   (- --- %i x   - --- %i x   - --- %i x  )\|2  \|3 \|21
+--R                      784          784          392
+--R                 + 
+--R                     15      16    15      13    3      10 3+-+2 +-+
+--R                   (---- %i x   + ---- %i x   - --- %i x  )\|2  \|7
+--R                    1568          1568          392
+--R                 + 
+--R                      9   16     9   13    3   10 3+-+2
+--R                   (---- x   + ---- x   - --- x  )\|2
+--R                    1568       1568       196
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     1      17    1      14    1      11  +-+ +--+
+--R                   (--- %i x   + --- %i x   + --- %i x  )\|3 \|21
+--R                    392          392          196
+--R                 + 
+--R                       15     17    15     14    3      11  +-+    9   17
+--R                   (- --- %i x   - --- %i x   + --- %i x  )\|7  - --- x
+--R                      784          784          196               784
+--R                 + 
+--R                      9   14    3  11
+--R                   - --- x   + -- x
+--R                     784       98
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     1   15    1   12    1   9 3+-+ +-+ +-+ +--+
+--R                   (--- x   + --- x   + --- x )\|2 \|3 \|7 \|21
+--R                    392       392       196
+--R                 + 
+--R                       39  15    39  12    3   9 3+-+
+--R                   (- --- x   - --- x   + --- x )\|2
+--R                      392       392       196
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R                 1        3
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R      *
+--R             1        3   2
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                                              +------------+2
+--R                       3   11    3   8    9   5  +-+6+----+3 3|     +-+
+--R                   (- --- x   - --- x  + --- x )\|7 \|1372   \|- %i\|7  + 1
+--R                      112       112      392
+--R                 + 
+--R                                                                +------------+
+--R                     3   12    3   9    9   6 3+-+ +-+6+----+3 3|     +-+
+--R                   (--- x   + --- x  - --- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    112       112      392
+--R                 + 
+--R                          5      10     5      7     5      4 3+-+2 +-+ +-+ +--+
+--R                       (---- %i x   + ---- %i x  + ---- %i x )\|2  \|3 \|7 \|21
+--R                        2744          2744         1372
+--R                     + 
+--R                         3   10    3   7    9   4 3+-+2 +-+
+--R                       (--- x   + --- x  - --- x )\|2  \|7
+--R                        224       224      784
+--R                     + 
+--R                           207     10    207     7    3      4 3+-+2
+--R                       (- ---- %i x   - ---- %i x  + --- %i x )\|2
+--R                          1568          1568         784
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                                +------------+2
+--R                     3   12    3   9    9   6 3+-+ +-+6+----+3 3|     +-+
+--R                   (--- x   + --- x  - --- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    112       112      392
+--R                 + 
+--R                         3   13    3   10    9   7 3+-+2 +-+6+----+3
+--R                     (- --- x   - --- x   + --- x )\|2  \|7 \|1372
+--R                        112       112       392
+--R                  *
+--R                      +------------+
+--R                     3|     +-+
+--R                     \|- %i\|7  + 1
+--R                 + 
+--R                            5      11     5      8    5      5  +-+ +-+ +--+
+--R                       (- ---- %i x   - ---- %i x  - --- %i x )\|3 \|7 \|21
+--R                          1372          1372         686
+--R                     + 
+--R                           3   11    3   8    9   5  +-+   207     11
+--R                       (- --- x   - --- x  + --- x )\|7  + --- %i x
+--R                          112       112      392           784
+--R                     + 
+--R                       207     8    3      5
+--R                       --- %i x  - --- %i x
+--R                       784         392
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                        5      10     5      7     5      4 3+-+2 +-+ +-+ +--+
+--R                   (- ---- %i x   - ---- %i x  - ---- %i x )\|2  \|3 \|7 \|21
+--R                      2744          2744         1372
+--R                 + 
+--R                     3   10    3   7    9   4 3+-+2 +-+
+--R                   (--- x   + --- x  - --- x )\|2  \|7
+--R                    224       224      784
+--R                 + 
+--R                     207     10    207     7    3      4 3+-+2
+--R                   (---- %i x   + ---- %i x  - --- %i x )\|2
+--R                    1568          1568         784
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                      5      11     5      8    5      5  +-+ +-+ +--+
+--R                   (---- %i x   + ---- %i x  + --- %i x )\|3 \|7 \|21
+--R                    1372          1372         686
+--R                 + 
+--R                       3   11    3   8    9   5  +-+   207     11   207     8
+--R                   (- --- x   - --- x  + --- x )\|7  - --- %i x   - --- %i x
+--R                      112       112      392           784          784
+--R                 + 
+--R                    3      5
+--R                   --- %i x
+--R                   392
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     5   9    5   6    5  3 3+-+ +-+ +--+
+--R                   (--- x  + --- x  + -- x )\|2 \|3 \|21
+--R                    196      196      98
+--R                 + 
+--R                       9  9    9  6    3  3 3+-+ +-+
+--R                   (- -- x  - -- x  - -- x )\|2 \|7
+--R                      49      49      49
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R                 1        3   8
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                   +------------+2
+--R                      33  14   33  11   39  8  +-+3|     +-+
+--R                   (- -- x   - -- x   + -- x )\|7 \|- %i\|7  + 1
+--R                      56       56       56
+--R                 + 
+--R                                                     +------------+
+--R                    33  15   33  12   39  9 3+-+ +-+3|     +-+
+--R                   (-- x   + -- x   - -- x )\|2 \|7 \|- %i\|7  + 1
+--R                    56       56       56
+--R                 + 
+--R                     5      13    5      10    5     7 3+-+2 +-+ +-+ +--+
+--R                   (--- %i x   + --- %i x   + -- %i x )\|2  \|3 \|7 \|21
+--R                    112          112          56
+--R                 + 
+--R                     33  13    33  10    39  7 3+-+2 +-+
+--R                   (--- x   + --- x   - --- x )\|2  \|7
+--R                    112       112       112
+--R                 + 
+--R                           13        10    9     7 3+-+2
+--R                   (- 3%i x   - 3%i x   + -- %i x )\|2
+--R                                          16
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                     +------------+2
+--R                    33  15   33  12   39  9 3+-+ +-+3|     +-+
+--R                   (-- x   + -- x   - -- x )\|2 \|7 \|- %i\|7  + 1
+--R                    56       56       56
+--R                 + 
+--R                                                         +------------+
+--R                      33  16   33  13   39  10 3+-+2 +-+3|     +-+
+--R                   (- -- x   - -- x   + -- x  )\|2  \|7 \|- %i\|7  + 1
+--R                      56       56       56
+--R                 + 
+--R                       5     14    5     11    5     8  +-+ +-+ +--+
+--R                   (- -- %i x   - -- %i x   - -- %i x )\|3 \|7 \|21
+--R                      56          56          28
+--R                 + 
+--R                    33  14   33  11   39  8  +-+        14        11   9     8
+--R                 (- -- x   - -- x   + -- x )\|7  + 6%i x   + 6%i x   - - %i x
+--R                    56       56       56                               8
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                       5      13    5      10    5     7 3+-+2 +-+ +-+ +--+
+--R                   (- --- %i x   - --- %i x   - -- %i x )\|2  \|3 \|7 \|21
+--R                      112          112          56
+--R                 + 
+--R                     33  13    33  10    39  7 3+-+2 +-+
+--R                   (--- x   + --- x   - --- x )\|2  \|7
+--R                    112       112       112
+--R                 + 
+--R                         13        10    9     7 3+-+2
+--R                   (3%i x   + 3%i x   - -- %i x )\|2
+--R                                        16
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                     5     14    5     11    5     8  +-+ +-+ +--+
+--R                   (-- %i x   + -- %i x   + -- %i x )\|3 \|7 \|21
+--R                    56          56          28
+--R                 + 
+--R                    33  14   33  11   39  8  +-+        14        11   9     8
+--R                 (- -- x   - -- x   + -- x )\|7  - 6%i x   - 6%i x   + - %i x
+--R                    56       56       56                               8
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                5  12   5  9   5  6 3+-+ +-+ +--+
+--R               (- x   + - x  + - x )\|2 \|3 \|21
+--R                8       8      4
+--R             + 
+--R                  237  12   237  9   27  6 3+-+ +-+
+--R               (- --- x   - --- x  - -- x )\|2 \|7
+--R                   56        56      28
+--R          *
+--R                 1        3   5
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                               +------------+2
+--R                       3   17    3   14    3  11  +-+6+----+3 3|     +-+
+--R                   (- --- x   - --- x   + -- x  )\|7 \|1372   \|- %i\|7  + 1
+--R                      784       784       98
+--R                 + 
+--R                                                                 +------------+
+--R                     3   18    3   15    3  12 3+-+ +-+6+----+3 3|     +-+
+--R                   (--- x   + --- x   - -- x  )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    784       784       98
+--R                 + 
+--R                            5      16     5      13     5      10 3+-+2 +-+ +-+
+--R                         (---- %i x   + ---- %i x   + ---- %i x  )\|2  \|3 \|7
+--R                          5488          5488          2744
+--R                      *
+--R                          +--+
+--R                         \|21
+--R                     + 
+--R                          3   16     3   13    3   10 3+-+2 +-+
+--R                       (---- x   + ---- x   - --- x  )\|2  \|7
+--R                        1568       1568       196
+--R                     + 
+--R                           51      16    51      13    27     10 3+-+2
+--R                       (- ---- %i x   - ---- %i x   + --- %i x  )\|2
+--R                          1568          1568          392
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                                 +------------+2
+--R                     3   18    3   15    3  12 3+-+ +-+6+----+3 3|     +-+
+--R                   (--- x   + --- x   - -- x  )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    784       784       98
+--R                 + 
+--R                         3   19    3   16    3  13 3+-+2 +-+6+----+3
+--R                     (- --- x   - --- x   + -- x  )\|2  \|7 \|1372
+--R                        784       784       98
+--R                  *
+--R                      +------------+
+--R                     3|     +-+
+--R                     \|- %i\|7  + 1
+--R                 + 
+--R                            5      17     5      14     5      11  +-+ +-+ +--+
+--R                       (- ---- %i x   - ---- %i x   - ---- %i x  )\|3 \|7 \|21
+--R                          2744          2744          1372
+--R                     + 
+--R                           3   17    3   14    3  11  +-+    51     17
+--R                       (- --- x   - --- x   + -- x  )\|7  + --- %i x
+--R                          784       784       98            784
+--R                     + 
+--R                        51     14    27     11
+--R                       --- %i x   - --- %i x
+--R                       784          196
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                        5      16     5      13     5      10 3+-+2 +-+ +-+ +--+
+--R                   (- ---- %i x   - ---- %i x   - ---- %i x  )\|2  \|3 \|7 \|21
+--R                      5488          5488          2744
+--R                 + 
+--R                      3   16     3   13    3   10 3+-+2 +-+
+--R                   (---- x   + ---- x   - --- x  )\|2  \|7
+--R                    1568       1568       196
+--R                 + 
+--R                     51      16    51      13    27     10 3+-+2
+--R                   (---- %i x   + ---- %i x   - --- %i x  )\|2
+--R                    1568          1568          392
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                      5      17     5      14     5      11  +-+ +-+ +--+
+--R                   (---- %i x   + ---- %i x   + ---- %i x  )\|3 \|7 \|21
+--R                    2744          2744          1372
+--R                 + 
+--R                       3   17    3   14    3  11  +-+    51     17    51     14
+--R                   (- --- x   - --- x   + -- x  )\|7  - --- %i x   - --- %i x
+--R                      784       784       98            784          784
+--R                 + 
+--R                    27     11
+--R                   --- %i x
+--R                   196
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     5   15    5   12    5   9 3+-+ +-+ +--+
+--R                   (--- x   + --- x   + --- x )\|2 \|3 \|21
+--R                    392       392       196
+--R                 + 
+--R                       3  15    3  12    9   9 3+-+ +-+
+--R                   (- -- x   - -- x   + --- x )\|2 \|7
+--R                      56       56       196
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R                 1        3   2
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R      *
+--R             1        3
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                             +------------+2
+--R                1  8   1  5 3|     +-+
+--R               (- x  + - x )\|- %i\|7  + 1
+--R                2      2
+--R             + 
+--R                                   +------------+
+--R                  1  9   1  6 3+-+3|     +-+
+--R               (- - x  - - x )\|2 \|- %i\|7  + 1
+--R                  2      2
+--R             + 
+--R                   1     7    1     4    1      3+-+2 +-+ +--+
+--R               (- -- %i x  - -- %i x  - -- %i x)\|2  \|3 \|21
+--R                  42         42         21
+--R             + 
+--R                 9     7    9     4   1      3+-+2 +-+      1  7   1  4 3+-+2
+--R               (-- %i x  + -- %i x  + - %i x)\|2  \|7  + (- - x  - - x )\|2
+--R                28         28         7                     4      4
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                   +------------+2
+--R                  1  9   1  6 3+-+3|     +-+
+--R               (- - x  - - x )\|2 \|- %i\|7  + 1
+--R                  2      2
+--R             + 
+--R                                    +------------+
+--R                1  10   1  7 3+-+2 3|     +-+
+--R               (- x   + - x )\|2   \|- %i\|7  + 1
+--R                2       2
+--R             + 
+--R                 1     8    1     5    2     2  +-+ +--+
+--R               (-- %i x  + -- %i x  + -- %i x )\|3 \|21
+--R                21         21         21
+--R             + 
+--R                   9     8    9     5   2     2  +-+   1  8   1  5
+--R               (- -- %i x  - -- %i x  - - %i x )\|7  + - x  + - x
+--R                  14         14         7              2      2
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                 1     7    1     4    1      3+-+2 +-+ +--+
+--R               (-- %i x  + -- %i x  + -- %i x)\|2  \|3 \|21
+--R                42         42         21
+--R             + 
+--R                   9     7    9     4   1      3+-+2 +-+      1  7   1  4 3+-+2
+--R               (- -- %i x  - -- %i x  - - %i x)\|2  \|7  + (- - x  - - x )\|2
+--R                  28         28         7                     4      4
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                   1     8    1     5    2     2  +-+ +--+
+--R               (- -- %i x  - -- %i x  - -- %i x )\|3 \|21
+--R                  21         21         21
+--R             + 
+--R                 9     8    9     5   2     2  +-+   1  8   1  5
+--R               (-- %i x  + -- %i x  + - %i x )\|7  + - x  + - x
+--R                14         14         7              2      2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R               1  6    1  3    2 3+-+ +-+ +-+ +--+      6     3     3+-+
+--R           (- -- x  - -- x  - --)\|2 \|3 \|7 \|21  + (3x  + 3x  + 2)\|2
+--R              21      21      21
+--R      *
+--R             1        3   12
+--R         cos(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                                    +------------+2
+--R                 13  11    13  8    1   5 6+----+3 3|     +-+
+--R               (--- x   + --- x  - --- x )\|1372   \|- %i\|7  + 1
+--R                784       784      392
+--R             + 
+--R                                                          +------------+
+--R                   13  12    13  9    1   6 3+-+6+----+3 3|     +-+
+--R               (- --- x   - --- x  + --- x )\|2 \|1372   \|- %i\|7  + 1
+--R                  784       784      392
+--R             + 
+--R                        1      10     1      7    1      4 3+-+2 +-+ +--+
+--R                   (- ---- %i x   - ---- %i x  - --- %i x )\|2  \|3 \|21
+--R                      1176          1176         588
+--R                 + 
+--R                     17      10    17      7    3      4 3+-+2 +-+
+--R                   (---- %i x   + ---- %i x  + --- %i x )\|2  \|7
+--R                    1568          1568         784
+--R                 + 
+--R                       13   10    13   7    1   4 3+-+2
+--R                   (- ---- x   - ---- x  + --- x )\|2
+--R                      1568       1568      784
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                                          +------------+2
+--R                   13  12    13  9    1   6 3+-+6+----+3 3|     +-+
+--R               (- --- x   - --- x  + --- x )\|2 \|1372   \|- %i\|7  + 1
+--R                  784       784      392
+--R             + 
+--R                                                           +------------+
+--R                 13  13    13  10    1   7 3+-+2 6+----+3 3|     +-+
+--R               (--- x   + --- x   - --- x )\|2   \|1372   \|- %i\|7  + 1
+--R                784       784       392
+--R             + 
+--R                     1      11    1      8    1      5  +-+ +--+
+--R                   (--- %i x   + --- %i x  + --- %i x )\|3 \|21
+--R                    588          588         294
+--R                 + 
+--R                       17     11    17     8    3      5  +-+    13  11    13  8
+--R                   (- --- %i x   - --- %i x  - --- %i x )\|7  + --- x   + --- x
+--R                      784          784         392              784       784
+--R                 + 
+--R                      1   5
+--R                   - --- x
+--R                     392
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                  1      10     1      7    1      4 3+-+2 +-+ +--+
+--R               (---- %i x   + ---- %i x  + --- %i x )\|2  \|3 \|21
+--R                1176          1176         588
+--R             + 
+--R                   17      10    17      7    3      4 3+-+2 +-+
+--R               (- ---- %i x   - ---- %i x  - --- %i x )\|2  \|7
+--R                  1568          1568         784
+--R             + 
+--R                   13   10    13   7    1   4 3+-+2
+--R               (- ---- x   - ---- x  + --- x )\|2
+--R                  1568       1568      784
+--R          *
+--R                       +------------+2
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                   1      11    1      8    1      5  +-+ +--+
+--R               (- --- %i x   - --- %i x  - --- %i x )\|3 \|21
+--R                  588          588         294
+--R             + 
+--R                 17     11    17     8    3      5  +-+    13  11    13  8
+--R               (--- %i x   + --- %i x  + --- %i x )\|7  + --- x   + --- x
+--R                784          784         392              784       784
+--R             + 
+--R                  1   5
+--R               - --- x
+--R                 392
+--R          *
+--R                       +------------+
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                   1   9    1   6    1   3 3+-+ +-+ +-+ +--+
+--R               (- --- x  - --- x  - --- x )\|2 \|3 \|7 \|21
+--R                  588      588      294
+--R             + 
+--R                 5  9    5  6    3  3 3+-+
+--R               (-- x  + -- x  + -- x )\|2
+--R                49      49      49
+--R          *
+--R             6+----+3
+--R             \|1372
+--R      *
+--R             1        3   9
+--R         cos(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                         +------------+2
+--R                 7  14    7  11    9  8 3|     +-+
+--R               (-- x   + -- x   - -- x )\|- %i\|7  + 1
+--R                16       16       16
+--R             + 
+--R                                               +------------+
+--R                   7  15    7  12    9  9 3+-+3|     +-+
+--R               (- -- x   - -- x   + -- x )\|2 \|- %i\|7  + 1
+--R                  16       16       16
+--R             + 
+--R                   23     13    23     10    23     7 3+-+2 +-+ +--+
+--R               (- --- %i x   - --- %i x   - --- %i x )\|2  \|3 \|21
+--R                  672          672          336
+--R             + 
+--R                 9     13    9     10    17     7 3+-+2 +-+
+--R               (-- %i x   + -- %i x   - --- %i x )\|2  \|7
+--R                28          28          224
+--R             + 
+--R                   7  13    7  10    9  7 3+-+2
+--R               (- -- x   - -- x   + -- x )\|2
+--R                  32       32       32
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                               +------------+2
+--R                   7  15    7  12    9  9 3+-+3|     +-+
+--R               (- -- x   - -- x   + -- x )\|2 \|- %i\|7  + 1
+--R                  16       16       16
+--R             + 
+--R                                                +------------+
+--R                 7  16    7  13    9  10 3+-+2 3|     +-+
+--R               (-- x   + -- x   - -- x  )\|2   \|- %i\|7  + 1
+--R                16       16       16
+--R             + 
+--R                 23     14    23     11    23     8  +-+ +--+
+--R               (--- %i x   + --- %i x   + --- %i x )\|3 \|21
+--R                336          336          168
+--R             + 
+--R                 9     14    9     11    17     8  +-+    7  14    7  11    9  8
+--R             (- -- %i x   - -- %i x   + --- %i x )\|7  + -- x   + -- x   - -- x
+--R                14          14          112              16       16       16
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                 23     13    23     10    23     7 3+-+2 +-+ +--+
+--R               (--- %i x   + --- %i x   + --- %i x )\|2  \|3 \|21
+--R                672          672          336
+--R             + 
+--R                   9     13    9     10    17     7 3+-+2 +-+
+--R               (- -- %i x   - -- %i x   + --- %i x )\|2  \|7
+--R                  28          28          224
+--R             + 
+--R                   7  13    7  10    9  7 3+-+2
+--R               (- -- x   - -- x   + -- x )\|2
+--R                  32       32       32
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                   23     14    23     11    23     8  +-+ +--+
+--R               (- --- %i x   - --- %i x   - --- %i x )\|3 \|21
+--R                  336          336          168
+--R             + 
+--R               9     14    9     11    17     8  +-+    7  14    7  11    9  8
+--R             (-- %i x   + -- %i x   - --- %i x )\|7  + -- x   + -- x   - -- x
+--R              14          14          112              16       16       16
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R               23  12    23  9    23  6 3+-+ +-+ +-+ +--+
+--R           (- --- x   - --- x  - --- x )\|2 \|3 \|7 \|21
+--R              336       336      168
+--R         + 
+--R            51  12   51  9   5  6 3+-+
+--R           (-- x   + -- x  + - x )\|2
+--R            16       16      8
+--R      *
+--R             1        3   6
+--R         cos(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                                     +------------+2
+--R                 3   17    3   14    1  11 6+----+3 3|     +-+
+--R               (--- x   + --- x   - -- x  )\|1372   \|- %i\|7  + 1
+--R                784       784       98
+--R             + 
+--R                                                           +------------+
+--R                   3   18    3   15    1  12 3+-+6+----+3 3|     +-+
+--R               (- --- x   - --- x   + -- x  )\|2 \|1372   \|- %i\|7  + 1
+--R                  784       784       98
+--R             + 
+--R                        1      16     1      13     1      10 3+-+2 +-+ +--+
+--R                   (- ---- %i x   - ---- %i x   - ---- %i x  )\|2  \|3 \|21
+--R                      2352          2352          1176
+--R                 + 
+--R                      5      16     5      13    1      10 3+-+2 +-+
+--R                   (---- %i x   + ---- %i x   - --- %i x  )\|2  \|7
+--R                    1568          1568          392
+--R                 + 
+--R                        3   16     3   13    1   10 3+-+2
+--R                   (- ---- x   - ---- x   + --- x  )\|2
+--R                      1568       1568       196
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                                           +------------+2
+--R                   3   18    3   15    1  12 3+-+6+----+3 3|     +-+
+--R               (- --- x   - --- x   + -- x  )\|2 \|1372   \|- %i\|7  + 1
+--R                  784       784       98
+--R             + 
+--R                                                           +------------+
+--R                 3   19    3   16    1  13 3+-+2 6+----+3 3|     +-+
+--R               (--- x   + --- x   - -- x  )\|2   \|1372   \|- %i\|7  + 1
+--R                784       784       98
+--R             + 
+--R                      1      17     1      14    1      11  +-+ +--+
+--R                   (---- %i x   + ---- %i x   + --- %i x  )\|3 \|21
+--R                    1176          1176          588
+--R                 + 
+--R                       5      17    5      14    1      11  +-+    3   17
+--R                   (- --- %i x   - --- %i x   + --- %i x  )\|7  + --- x
+--R                      784          784          196               784
+--R                 + 
+--R                    3   14    1  11
+--R                   --- x   - -- x
+--R                   784       98
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                  1      16     1      13     1      10 3+-+2 +-+ +--+
+--R               (---- %i x   + ---- %i x   + ---- %i x  )\|2  \|3 \|21
+--R                2352          2352          1176
+--R             + 
+--R                    5      16     5      13    1      10 3+-+2 +-+
+--R               (- ---- %i x   - ---- %i x   + --- %i x  )\|2  \|7
+--R                  1568          1568          392
+--R             + 
+--R                    3   16     3   13    1   10 3+-+2
+--R               (- ---- x   - ---- x   + --- x  )\|2
+--R                  1568       1568       196
+--R          *
+--R                       +------------+2
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                    1      17     1      14    1      11  +-+ +--+
+--R               (- ---- %i x   - ---- %i x   - --- %i x  )\|3 \|21
+--R                  1176          1176          588
+--R             + 
+--R                 5      17    5      14    1      11  +-+    3   17    3   14
+--R               (--- %i x   + --- %i x   - --- %i x  )\|7  + --- x   + --- x
+--R                784          784          196               784       784
+--R             + 
+--R                  1  11
+--R               - -- x
+--R                 98
+--R          *
+--R                       +------------+
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                    1   15     1   12    1   9 3+-+ +-+ +-+ +--+
+--R               (- ---- x   - ---- x   - --- x )\|2 \|3 \|7 \|21
+--R                  1176       1176       588
+--R             + 
+--R                 13  15    13  12    1   9 3+-+
+--R               (--- x   + --- x   - --- x )\|2
+--R                392       392       196
+--R          *
+--R             6+----+3
+--R             \|1372
+--R      *
+--R             1        3   3
+--R         cos(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                    +------------+2             +------------+
+--R             1  14 3|     +-+        1  15 3+-+3|     +-+
+--R           - - x   \|- %i\|7  + 1  + - x   \|2 \|- %i\|7  + 1
+--R             4                       4
+--R         + 
+--R               1      19    1      16    1     13 3+-+2 +-+ +--+
+--R           (- --- %i x   - --- %i x   - -- %i x  )\|2  \|3 \|21
+--R              168          168          84
+--R         + 
+--R             1     19    1     16    5     13 3+-+2 +-+   1  13 3+-+2
+--R           (-- %i x   + -- %i x   - -- %i x  )\|2  \|7  + - x   \|2
+--R            56          56          56                    8
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                      +------------+2               +------------+
+--R           1  15 3+-+3|     +-+        1  16 3+-+2 3|     +-+
+--R           - x   \|2 \|- %i\|7  + 1  - - x   \|2   \|- %i\|7  + 1
+--R           4                           4
+--R         + 
+--R             1     20    1     17    1     14  +-+ +--+
+--R           (-- %i x   + -- %i x   + -- %i x  )\|3 \|21
+--R            84          84          42
+--R         + 
+--R               1     20    1     17    5     14  +-+   1  14
+--R           (- -- %i x   - -- %i x   + -- %i x  )\|7  - - x
+--R              28          28          28               4
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R             1      19    1      16    1     13 3+-+2 +-+ +--+
+--R           (--- %i x   + --- %i x   + -- %i x  )\|2  \|3 \|21
+--R            168          168          84
+--R         + 
+--R               1     19    1     16    5     13 3+-+2 +-+   1  13 3+-+2
+--R           (- -- %i x   - -- %i x   + -- %i x  )\|2  \|7  + - x   \|2
+--R              56          56          56                    8
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|7  + 1
+--R     + 
+--R               1     20    1     17    1     14  +-+ +--+
+--R           (- -- %i x   - -- %i x   - -- %i x  )\|3 \|21
+--R              84          84          42
+--R         + 
+--R             1     20    1     17    5     14  +-+   1  14
+--R           (-- %i x   + -- %i x   - -- %i x  )\|7  - - x
+--R            28          28          28               4
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|7  + 1
+--R     + 
+--R         1  18    1  15    1  12 3+-+ +-+ +-+ +--+    1  18   1  15   1  12 3+-+
+--R     (- -- x   - -- x   - -- x  )\|2 \|3 \|7 \|21  + (- x   + - x   - - x  )\|2
+--R        84       84       42                          4       4       2
+--R  /
+--R                               +------------+2
+--R                 8    5     2 3|     +-+
+--R               (x  + x  + 2x )\|- %i\|7  + 1
+--R             + 
+--R                                     +------------+
+--R                   9    6     3 3+-+3|     +-+
+--R               (- x  - x  - 2x )\|2 \|- %i\|7  + 1
+--R             + 
+--R                1     7   1     4        3+-+2 +-+      1  7   1  4     3+-+2
+--R               (- %i x  + - %i x  + %i x)\|2  \|7  + (- - x  - - x  - x)\|2
+--R                2         2                             2      2
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                     +------------+2
+--R                   9    6     3 3+-+3|     +-+
+--R               (- x  - x  - 2x )\|2 \|- %i\|7  + 1
+--R             + 
+--R                                      +------------+
+--R                 10    7     4 3+-+2 3|     +-+
+--R               (x   + x  + 2x )\|2   \|- %i\|7  + 1
+--R             + 
+--R                      8       5        2  +-+    8    5     2
+--R               (- %i x  - %i x  - 2%i x )\|7  + x  + x  + 2x
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                 1     7   1     4        3+-+2 +-+      1  7   1  4     3+-+2
+--R             ((- - %i x  - - %i x  - %i x)\|2  \|7  + (- - x  - - x  - x)\|2  )
+--R                 2         2                             2      2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                                                          +------------+
+--R                 8       5        2  +-+    8    5     2 3|     +-+
+--R           ((%i x  + %i x  + 2%i x )\|7  + x  + x  + 2x )\|- %i\|7  + 1
+--R         + 
+--R              6     3     3+-+
+--R           (4x  + 4x  + 8)\|2
+--R      *
+--R             1        3   12
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                  +------------+2
+--R                  8     5      2 3|     +-+
+--R               (6x  + 6x  + 12x )\|- %i\|7  + 1
+--R             + 
+--R                                        +------------+
+--R                    9     6      3 3+-+3|     +-+
+--R               (- 6x  - 6x  - 12x )\|2 \|- %i\|7  + 1
+--R             + 
+--R                     7        4         3+-+2 +-+        7     4      3+-+2
+--R               (3%i x  + 3%i x  + 6%i x)\|2  \|7  + (- 3x  - 3x  - 6x)\|2
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                        +------------+2
+--R                    9     6      3 3+-+3|     +-+
+--R               (- 6x  - 6x  - 12x )\|2 \|- %i\|7  + 1
+--R             + 
+--R                                         +------------+
+--R                  10     7      4 3+-+2 3|     +-+
+--R               (6x   + 6x  + 12x )\|2   \|- %i\|7  + 1
+--R             + 
+--R                       8        5         2  +-+     8     5      2
+--R               (- 6%i x  - 6%i x  - 12%i x )\|7  + 6x  + 6x  + 12x
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                      7        4         3+-+2 +-+        7     4      3+-+2
+--R             ((- 3%i x  - 3%i x  - 6%i x)\|2  \|7  + (- 3x  - 3x  - 6x)\|2  )
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                                                                +------------+
+--R                  8        5         2  +-+     8     5      2 3|     +-+
+--R           ((6%i x  + 6%i x  + 12%i x )\|7  + 6x  + 6x  + 12x )\|- %i\|7  + 1
+--R         + 
+--R               6      3      3+-+
+--R           (24x  + 24x  + 48)\|2
+--R      *
+--R             1        3   2    1        3   10
+--R         cos(- atan(----)) sin(- atan(----))
+--R             3       +-+       3       +-+
+--R                    \|7               \|7
+--R     + 
+--R                                                       +------------+2
+--R                 5   11    5   8    5  5  +-+6+----+3 3|     +-+
+--R               (--- x   + --- x  + -- x )\|7 \|1372   \|- %i\|7  + 1
+--R                196       196      98
+--R             + 
+--R                                                             +------------+
+--R                   5   12    5   9    5  6 3+-+ +-+6+----+3 3|     +-+
+--R               (- --- x   - --- x  - -- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                  196       196      98
+--R             + 
+--R                       5   10    5   7    5   4 3+-+2 +-+
+--R                   (- --- x   - --- x  - --- x )\|2  \|7
+--R                      392       392      196
+--R                 + 
+--R                     5     10    5     7    5     4 3+-+2
+--R                   (-- %i x   + -- %i x  + -- %i x )\|2
+--R                    56          56         28
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                                             +------------+2
+--R                   5   12    5   9    5  6 3+-+ +-+6+----+3 3|     +-+
+--R               (- --- x   - --- x  - -- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                  196       196      98
+--R             + 
+--R                                                             +------------+
+--R                 5   13    5   10    5  7 3+-+2 +-+6+----+3 3|     +-+
+--R               (--- x   + --- x   + -- x )\|2  \|7 \|1372   \|- %i\|7  + 1
+--R                196       196       98
+--R             + 
+--R                     5   11    5   8    5  5  +-+    5     11    5     8
+--R                   (--- x   + --- x  + -- x )\|7  - -- %i x   - -- %i x
+--R                    196       196      98           28          28
+--R                 + 
+--R                      5     5
+--R                   - -- %i x
+--R                     14
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                   5   10    5   7    5   4 3+-+2 +-+
+--R               (- --- x   - --- x  - --- x )\|2  \|7
+--R                  392       392      196
+--R             + 
+--R                   5     10    5     7    5     4 3+-+2
+--R               (- -- %i x   - -- %i x  - -- %i x )\|2
+--R                  56          56         28
+--R          *
+--R                       +------------+2
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                5   11    5   8    5  5  +-+    5     11    5     8    5     5
+--R             ((--- x   + --- x  + -- x )\|7  + -- %i x   + -- %i x  + -- %i x )
+--R               196       196      98           28          28         14
+--R          *
+--R                       +------------+
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R             5  9    5  6   10  3 3+-+ +-+6+----+3
+--R           (-- x  + -- x  + -- x )\|2 \|7 \|1372
+--R            49      49      49
+--R      *
+--R             1        3   9
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                        +------------+2
+--R                       8      5      2 3|     +-+
+--R                   (15x  + 15x  + 30x )\|- %i\|7  + 1
+--R                 + 
+--R                                              +------------+
+--R                         9      6      3 3+-+3|     +-+
+--R                   (- 15x  - 15x  - 30x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                    15     7   15     4          3+-+2 +-+
+--R                   (-- %i x  + -- %i x  + 15%i x)\|2  \|7
+--R                     2          2
+--R                 + 
+--R                      15  7   15  4       3+-+2
+--R                   (- -- x  - -- x  - 15x)\|2
+--R                       2       2
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                              +------------+2
+--R                         9      6      3 3+-+3|     +-+
+--R                   (- 15x  - 15x  - 30x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                                               +------------+
+--R                       10      7      4 3+-+2 3|     +-+
+--R                   (15x   + 15x  + 30x )\|2   \|- %i\|7  + 1
+--R                 + 
+--R                            8         5         2  +-+      8      5      2
+--R                   (- 15%i x  - 15%i x  - 30%i x )\|7  + 15x  + 15x  + 30x
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                      15     7   15     4          3+-+2 +-+
+--R                   (- -- %i x  - -- %i x  - 15%i x)\|2  \|7
+--R                       2          2
+--R                 + 
+--R                      15  7   15  4       3+-+2
+--R                   (- -- x  - -- x  - 15x)\|2
+--R                       2       2
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                         8         5         2  +-+      8      5      2
+--R                 ((15%i x  + 15%i x  + 30%i x )\|7  + 15x  + 15x  + 30x )
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                   6      3       3+-+
+--R               (60x  + 60x  + 120)\|2
+--R          *
+--R                 1        3   4
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                       +------------+2
+--R                       3  11    3  8    3  5 6+----+3 3|     +-+
+--R                   (- -- x   - -- x  - -- x )\|1372   \|- %i\|7  + 1
+--R                      28       28      14
+--R                 + 
+--R                                                         +------------+
+--R                     3  12    3  9    3  6 3+-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  + -- x )\|2 \|1372   \|- %i\|7  + 1
+--R                    28       28      14
+--R                 + 
+--R                           3     10    3     7    3     4 3+-+2 +-+
+--R                       (- -- %i x   - -- %i x  - -- %i x )\|2  \|7
+--R                          56          56         28
+--R                     + 
+--R                         3  10    3  7    3  4 3+-+2
+--R                       (-- x   + -- x  + -- x )\|2
+--R                        56       56      28
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                         +------------+2
+--R                     3  12    3  9    3  6 3+-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  + -- x )\|2 \|1372   \|- %i\|7  + 1
+--R                    28       28      14
+--R                 + 
+--R                                                              +------------+
+--R                       3  13    3  10    3  7 3+-+2 6+----+3 3|     +-+
+--R                   (- -- x   - -- x   - -- x )\|2   \|1372   \|- %i\|7  + 1
+--R                      28       28       14
+--R                 + 
+--R                         3     11    3     8    3     5  +-+    3  11    3  8
+--R                       (-- %i x   + -- %i x  + -- %i x )\|7  - -- x   - -- x
+--R                        28          28         14              28       28
+--R                     + 
+--R                          3  5
+--R                       - -- x
+--R                         14
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                     3     10    3     7    3     4 3+-+2 +-+
+--R                   (-- %i x   + -- %i x  + -- %i x )\|2  \|7
+--R                    56          56         28
+--R                 + 
+--R                     3  10    3  7    3  4 3+-+2
+--R                   (-- x   + -- x  + -- x )\|2
+--R                    56       56      28
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                       3     11    3     8    3     5  +-+    3  11    3  8
+--R                   (- -- %i x   - -- %i x  - -- %i x )\|7  - -- x   - -- x
+--R                      28          28         14              28       28
+--R                 + 
+--R                      3  5
+--R                   - -- x
+--R                     14
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                  3  9   3  6   6  3 3+-+6+----+3
+--R               (- - x  - - x  - - x )\|2 \|1372
+--R                  7      7      7
+--R          *
+--R                 1        3
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R      *
+--R             1        3   8
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                        +------------+2
+--R                       8      5      2 3|     +-+
+--R                   (20x  + 20x  + 40x )\|- %i\|7  + 1
+--R                 + 
+--R                                              +------------+
+--R                         9      6      3 3+-+3|     +-+
+--R                   (- 20x  - 20x  - 40x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                          7         4          3+-+2 +-+
+--R                   (10%i x  + 10%i x  + 20%i x)\|2  \|7
+--R                 + 
+--R                         7      4       3+-+2
+--R                   (- 10x  - 10x  - 20x)\|2
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                              +------------+2
+--R                         9      6      3 3+-+3|     +-+
+--R                   (- 20x  - 20x  - 40x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                                               +------------+
+--R                       10      7      4 3+-+2 3|     +-+
+--R                   (20x   + 20x  + 40x )\|2   \|- %i\|7  + 1
+--R                 + 
+--R                            8         5         2  +-+      8      5      2
+--R                   (- 20%i x  - 20%i x  - 40%i x )\|7  + 20x  + 20x  + 40x
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                            7         4          3+-+2 +-+
+--R                   (- 10%i x  - 10%i x  - 20%i x)\|2  \|7
+--R                 + 
+--R                         7      4       3+-+2
+--R                   (- 10x  - 10x  - 20x)\|2
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                         8         5         2  +-+      8      5      2
+--R                 ((20%i x  + 20%i x  + 40%i x )\|7  + 20x  + 20x  + 40x )
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                   6      3       3+-+
+--R               (80x  + 80x  + 160)\|2
+--R          *
+--R                 1        3   6
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                    +------------+2
+--R                      2  11   2  8   4  5 6+----+3 3|     +-+
+--R                   (- - x   - - x  - - x )\|1372   \|- %i\|7  + 1
+--R                      7       7      7
+--R                 + 
+--R                                                      +------------+
+--R                    2  12   2  9   4  6 3+-+6+----+3 3|     +-+
+--R                   (- x   + - x  + - x )\|2 \|1372   \|- %i\|7  + 1
+--R                    7       7      7
+--R                 + 
+--R                          1     10   1     7   2     4 3+-+2 +-+
+--R                       (- - %i x   - - %i x  - - %i x )\|2  \|7
+--R                          7          7         7
+--R                     + 
+--R                        1  10   1  7   2  4 3+-+2
+--R                       (- x   + - x  + - x )\|2
+--R                        7       7      7
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                      +------------+2
+--R                    2  12   2  9   4  6 3+-+6+----+3 3|     +-+
+--R                   (- x   + - x  + - x )\|2 \|1372   \|- %i\|7  + 1
+--R                    7       7      7
+--R                 + 
+--R                                                           +------------+
+--R                      2  13   2  10   4  7 3+-+2 6+----+3 3|     +-+
+--R                   (- - x   - - x   - - x )\|2   \|1372   \|- %i\|7  + 1
+--R                      7       7       7
+--R                 + 
+--R                       2     11   2     8   4     5  +-+   2  11   2  8   4  5
+--R                     ((- %i x   + - %i x  + - %i x )\|7  - - x   - - x  - - x )
+--R                       7          7         7              7       7      7
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                    1     10   1     7   2     4 3+-+2 +-+
+--R                   (- %i x   + - %i x  + - %i x )\|2  \|7
+--R                    7          7         7
+--R                 + 
+--R                    1  10   1  7   2  4 3+-+2
+--R                   (- x   + - x  + - x )\|2
+--R                    7       7      7
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                     2     11   2     8   4     5  +-+   2  11   2  8   4  5
+--R                 ((- - %i x   - - %i x  - - %i x )\|7  - - x   - - x  - - x )
+--R                     7          7         7              7       7      7
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                  8  9   8  6   16  3 3+-+6+----+3
+--R               (- - x  - - x  - -- x )\|2 \|1372
+--R                  7      7       7
+--R          *
+--R                 1        3   3
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                         +------------+2
+--R                41  14   41  11   41  8 3|     +-+
+--R               (-- x   + -- x   + -- x )\|- %i\|7  + 1
+--R                16       16        8
+--R             + 
+--R                                               +------------+
+--R                  41  15   41  12   41  9 3+-+3|     +-+
+--R               (- -- x   - -- x   - -- x )\|2 \|- %i\|7  + 1
+--R                  16       16        8
+--R             + 
+--R                41     13   41     10   41     7 3+-+2 +-+
+--R               (-- %i x   + -- %i x   + -- %i x )\|2  \|7
+--R                32          32          16
+--R             + 
+--R                  41  13   41  10   41  7 3+-+2
+--R               (- -- x   - -- x   - -- x )\|2
+--R                  32       32       16
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                               +------------+2
+--R                  41  15   41  12   41  9 3+-+3|     +-+
+--R               (- -- x   - -- x   - -- x )\|2 \|- %i\|7  + 1
+--R                  16       16        8
+--R             + 
+--R                                                +------------+
+--R                41  16   41  13   41  10 3+-+2 3|     +-+
+--R               (-- x   + -- x   + -- x  )\|2   \|- %i\|7  + 1
+--R                16       16        8
+--R             + 
+--R                41     14   41     11   41     8  +-+   41  14   41  11   41  8
+--R             (- -- %i x   - -- %i x   - -- %i x )\|7  + -- x   + -- x   + -- x
+--R                16          16           8              16       16        8
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                  41     13   41     10   41     7 3+-+2 +-+
+--R               (- -- %i x   - -- %i x   - -- %i x )\|2  \|7
+--R                  32          32          16
+--R             + 
+--R                  41  13   41  10   41  7 3+-+2
+--R               (- -- x   - -- x   - -- x )\|2
+--R                  32       32       16
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R               41     14   41     11   41     8  +-+   41  14   41  11   41  8
+--R             ((-- %i x   + -- %i x   + -- %i x )\|7  + -- x   + -- x   + -- x )
+--R               16          16           8              16       16        8
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R            41  12   41  9   41  6 3+-+
+--R           (-- x   + -- x  + -- x )\|2
+--R             4        4       2
+--R      *
+--R             1        3   6
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                                           +------------+2
+--R                      15  11   15  8   15  5  +-+6+----+3 3|     +-+
+--R                   (- -- x   - -- x  - -- x )\|7 \|1372   \|- %i\|7  + 1
+--R                      98       98      49
+--R                 + 
+--R                                                             +------------+
+--R                    15  12   15  9   15  6 3+-+ +-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  + -- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    98       98      49
+--R                 + 
+--R                         15  10    15  7   15  4 3+-+2 +-+
+--R                       (--- x   + --- x  + -- x )\|2  \|7
+--R                        196       196      98
+--R                     + 
+--R                          15     10   15     7   15     4 3+-+2
+--R                       (- -- %i x   - -- %i x  - -- %i x )\|2
+--R                          28          28         14
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                             +------------+2
+--R                    15  12   15  9   15  6 3+-+ +-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  + -- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    98       98      49
+--R                 + 
+--R                                                                 +------------+
+--R                      15  13   15  10   15  7 3+-+2 +-+6+----+3 3|     +-+
+--R                   (- -- x   - -- x   - -- x )\|2  \|7 \|1372   \|- %i\|7  + 1
+--R                      98       98       49
+--R                 + 
+--R                          15  11   15  8   15  5  +-+   15     11   15     8
+--R                       (- -- x   - -- x  - -- x )\|7  + -- %i x   + -- %i x
+--R                          98       98      49           14          14
+--R                     + 
+--R                       15     5
+--R                       -- %i x
+--R                        7
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                     15  10    15  7   15  4 3+-+2 +-+
+--R                   (--- x   + --- x  + -- x )\|2  \|7
+--R                    196       196      98
+--R                 + 
+--R                    15     10   15     7   15     4 3+-+2
+--R                   (-- %i x   + -- %i x  + -- %i x )\|2
+--R                    28          28         14
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                      15  11   15  8   15  5  +-+   15     11   15     8
+--R                   (- -- x   - -- x  - -- x )\|7  - -- %i x   - -- %i x
+--R                      98       98      49           14          14
+--R                 + 
+--R                     15     5
+--R                   - -- %i x
+--R                      7
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                  30  9   30  6   60  3 3+-+ +-+6+----+3
+--R               (- -- x  - -- x  - -- x )\|2 \|7 \|1372
+--R                  49      49      49
+--R          *
+--R                 1        3   4
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                   +------------+2
+--R                      15  14   15  11   15  8  +-+3|     +-+
+--R                   (- -- x   - -- x   - -- x )\|7 \|- %i\|7  + 1
+--R                       8        8        4
+--R                 + 
+--R                                                     +------------+
+--R                    15  15   15  12   15  9 3+-+ +-+3|     +-+
+--R                   (-- x   + -- x   + -- x )\|2 \|7 \|- %i\|7  + 1
+--R                     8        8        4
+--R                 + 
+--R                    15  13   15  10   15  7 3+-+2 +-+
+--R                   (-- x   + -- x   + -- x )\|2  \|7
+--R                    16       16        8
+--R                 + 
+--R                      105     13   105     10   105     7 3+-+2
+--R                   (- --- %i x   - --- %i x   - --- %i x )\|2
+--R                       16           16           8
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                     +------------+2
+--R                    15  15   15  12   15  9 3+-+ +-+3|     +-+
+--R                   (-- x   + -- x   + -- x )\|2 \|7 \|- %i\|7  + 1
+--R                     8        8        4
+--R                 + 
+--R                                                         +------------+
+--R                      15  16   15  13   15  10 3+-+2 +-+3|     +-+
+--R                   (- -- x   - -- x   - -- x  )\|2  \|7 \|- %i\|7  + 1
+--R                       8        8        4
+--R                 + 
+--R                      15  14   15  11   15  8  +-+   105     14   105     11
+--R                   (- -- x   - -- x   - -- x )\|7  + --- %i x   + --- %i x
+--R                       8        8        4            8            8
+--R                 + 
+--R                   105     8
+--R                   --- %i x
+--R                    4
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                    15  13   15  10   15  7 3+-+2 +-+
+--R                   (-- x   + -- x   + -- x )\|2  \|7
+--R                    16       16        8
+--R                 + 
+--R                    105     13   105     10   105     7 3+-+2
+--R                   (--- %i x   + --- %i x   + --- %i x )\|2
+--R                     16           16           8
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                      15  14   15  11   15  8  +-+   105     14   105     11
+--R                   (- -- x   - -- x   - -- x )\|7  - --- %i x   - --- %i x
+--R                       8        8        4            8            8
+--R                 + 
+--R                     105     8
+--R                   - --- %i x
+--R                      4
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                  15  12   15  9      6 3+-+ +-+
+--R               (- -- x   - -- x  - 15x )\|2 \|7
+--R                   2        2
+--R          *
+--R                 1        3
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R      *
+--R             1        3   5
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                        +------------+2
+--R                       8      5      2 3|     +-+
+--R                   (15x  + 15x  + 30x )\|- %i\|7  + 1
+--R                 + 
+--R                                              +------------+
+--R                         9      6      3 3+-+3|     +-+
+--R                   (- 15x  - 15x  - 30x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                    15     7   15     4          3+-+2 +-+
+--R                   (-- %i x  + -- %i x  + 15%i x)\|2  \|7
+--R                     2          2
+--R                 + 
+--R                      15  7   15  4       3+-+2
+--R                   (- -- x  - -- x  - 15x)\|2
+--R                       2       2
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                              +------------+2
+--R                         9      6      3 3+-+3|     +-+
+--R                   (- 15x  - 15x  - 30x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                                               +------------+
+--R                       10      7      4 3+-+2 3|     +-+
+--R                   (15x   + 15x  + 30x )\|2   \|- %i\|7  + 1
+--R                 + 
+--R                            8         5         2  +-+      8      5      2
+--R                   (- 15%i x  - 15%i x  - 30%i x )\|7  + 15x  + 15x  + 30x
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                      15     7   15     4          3+-+2 +-+
+--R                   (- -- %i x  - -- %i x  - 15%i x)\|2  \|7
+--R                       2          2
+--R                 + 
+--R                      15  7   15  4       3+-+2
+--R                   (- -- x  - -- x  - 15x)\|2
+--R                       2       2
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                         8         5         2  +-+      8      5      2
+--R                 ((15%i x  + 15%i x  + 30%i x )\|7  + 15x  + 15x  + 30x )
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                   6      3       3+-+
+--R               (60x  + 60x  + 120)\|2
+--R          *
+--R                 1        3   8
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                      +------------+2
+--R                       3  11    3  8   3  5 6+----+3 3|     +-+
+--R                   (- -- x   - -- x  - - x )\|1372   \|- %i\|7  + 1
+--R                      14       14      7
+--R                 + 
+--R                                                        +------------+
+--R                     3  12    3  9   3  6 3+-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  + - x )\|2 \|1372   \|- %i\|7  + 1
+--R                    14       14      7
+--R                 + 
+--R                           3     10    3     7    3     4 3+-+2 +-+
+--R                       (- -- %i x   - -- %i x  - -- %i x )\|2  \|7
+--R                          28          28         14
+--R                     + 
+--R                         3  10    3  7    3  4 3+-+2
+--R                       (-- x   + -- x  + -- x )\|2
+--R                        28       28      14
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                        +------------+2
+--R                     3  12    3  9   3  6 3+-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  + - x )\|2 \|1372   \|- %i\|7  + 1
+--R                    14       14      7
+--R                 + 
+--R                                                             +------------+
+--R                       3  13    3  10   3  7 3+-+2 6+----+3 3|     +-+
+--R                   (- -- x   - -- x   - - x )\|2   \|1372   \|- %i\|7  + 1
+--R                      14       14       7
+--R                 + 
+--R                         3     11    3     8   3     5  +-+    3  11    3  8
+--R                       (-- %i x   + -- %i x  + - %i x )\|7  - -- x   - -- x
+--R                        14          14         7              14       14
+--R                     + 
+--R                         3  5
+--R                       - - x
+--R                         7
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                     3     10    3     7    3     4 3+-+2 +-+
+--R                   (-- %i x   + -- %i x  + -- %i x )\|2  \|7
+--R                    28          28         14
+--R                 + 
+--R                     3  10    3  7    3  4 3+-+2
+--R                   (-- x   + -- x  + -- x )\|2
+--R                    28       28      14
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                         3     11    3     8   3     5  +-+    3  11    3  8
+--R                     (- -- %i x   - -- %i x  - - %i x )\|7  - -- x   - -- x
+--R                        14          14         7              14       14
+--R                   + 
+--R                       3  5
+--R                     - - x
+--R                       7
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                  6  9   6  6   12  3 3+-+6+----+3
+--R               (- - x  - - x  - -- x )\|2 \|1372
+--R                  7      7       7
+--R          *
+--R                 1        3   5
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                               +------------+2
+--R                      39  14   39  11   39  8 3|     +-+
+--R                   (- -- x   - -- x   - -- x )\|- %i\|7  + 1
+--R                      16       16        8
+--R                 + 
+--R                                                 +------------+
+--R                    39  15   39  12   39  9 3+-+3|     +-+
+--R                   (-- x   + -- x   + -- x )\|2 \|- %i\|7  + 1
+--R                    16       16        8
+--R                 + 
+--R                      39     13   39     10   39     7 3+-+2 +-+
+--R                   (- -- %i x   - -- %i x   - -- %i x )\|2  \|7
+--R                      32          32          16
+--R                 + 
+--R                    39  13   39  10   39  7 3+-+2
+--R                   (-- x   + -- x   + -- x )\|2
+--R                    32       32       16
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                 +------------+2
+--R                    39  15   39  12   39  9 3+-+3|     +-+
+--R                   (-- x   + -- x   + -- x )\|2 \|- %i\|7  + 1
+--R                    16       16        8
+--R                 + 
+--R                                                      +------------+
+--R                      39  16   39  13   39  10 3+-+2 3|     +-+
+--R                   (- -- x   - -- x   - -- x  )\|2   \|- %i\|7  + 1
+--R                      16       16        8
+--R                 + 
+--R                    39     14   39     11   39     8  +-+   39  14   39  11
+--R                   (-- %i x   + -- %i x   + -- %i x )\|7  - -- x   - -- x
+--R                    16          16           8              16       16
+--R                 + 
+--R                     39  8
+--R                   - -- x
+--R                      8
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                    39     13   39     10   39     7 3+-+2 +-+
+--R                   (-- %i x   + -- %i x   + -- %i x )\|2  \|7
+--R                    32          32          16
+--R                 + 
+--R                    39  13   39  10   39  7 3+-+2
+--R                   (-- x   + -- x   + -- x )\|2
+--R                    32       32       16
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                      39     14   39     11   39     8  +-+   39  14   39  11
+--R                   (- -- %i x   - -- %i x   - -- %i x )\|7  - -- x   - -- x
+--R                      16          16           8              16       16
+--R                 + 
+--R                     39  8
+--R                   - -- x
+--R                      8
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                  39  12   39  9   39  6 3+-+
+--R               (- -- x   - -- x  - -- x )\|2
+--R                   4        4       2
+--R          *
+--R                 1        3   2
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R      *
+--R             1        3   4
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                                           +------------+2
+--R                      10  11   10  8   20  5  +-+6+----+3 3|     +-+
+--R                   (- -- x   - -- x  - -- x )\|7 \|1372   \|- %i\|7  + 1
+--R                      49       49      49
+--R                 + 
+--R                                                             +------------+
+--R                    10  12   10  9   20  6 3+-+ +-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  + -- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    49       49      49
+--R                 + 
+--R                         5  10    5  7   10  4 3+-+2 +-+
+--R                       (-- x   + -- x  + -- x )\|2  \|7
+--R                        49       49      49
+--R                     + 
+--R                          5     10   5     7   10     4 3+-+2
+--R                       (- - %i x   - - %i x  - -- %i x )\|2
+--R                          7          7          7
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                             +------------+2
+--R                    10  12   10  9   20  6 3+-+ +-+6+----+3 3|     +-+
+--R                   (-- x   + -- x  + -- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    49       49      49
+--R                 + 
+--R                                                                 +------------+
+--R                      10  13   10  10   20  7 3+-+2 +-+6+----+3 3|     +-+
+--R                   (- -- x   - -- x   - -- x )\|2  \|7 \|1372   \|- %i\|7  + 1
+--R                      49       49       49
+--R                 + 
+--R                          10  11   10  8   20  5  +-+   10     11   10     8
+--R                       (- -- x   - -- x  - -- x )\|7  + -- %i x   + -- %i x
+--R                          49       49      49            7           7
+--R                     + 
+--R                       20     5
+--R                       -- %i x
+--R                        7
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                     5  10    5  7   10  4 3+-+2 +-+
+--R                   (-- x   + -- x  + -- x )\|2  \|7
+--R                    49       49      49
+--R                 + 
+--R                    5     10   5     7   10     4 3+-+2
+--R                   (- %i x   + - %i x  + -- %i x )\|2
+--R                    7          7          7
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                      10  11   10  8   20  5  +-+   10     11   10     8
+--R                   (- -- x   - -- x  - -- x )\|7  - -- %i x   - -- %i x
+--R                      49       49      49            7           7
+--R                 + 
+--R                     20     5
+--R                   - -- %i x
+--R                      7
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                  40  9   40  6   80  3 3+-+ +-+6+----+3
+--R               (- -- x  - -- x  - -- x )\|2 \|7 \|1372
+--R                  49      49      49
+--R          *
+--R                 1        3   6
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                 +------------+2
+--R                    25  14   25  11   25  8  +-+3|     +-+
+--R                   (-- x   + -- x   + -- x )\|7 \|- %i\|7  + 1
+--R                     4        4        2
+--R                 + 
+--R                                                       +------------+
+--R                      25  15   25  12   25  9 3+-+ +-+3|     +-+
+--R                   (- -- x   - -- x   - -- x )\|2 \|7 \|- %i\|7  + 1
+--R                       4        4        2
+--R                 + 
+--R                      25  13   25  10   25  7 3+-+2 +-+
+--R                   (- -- x   - -- x   - -- x )\|2  \|7
+--R                       8        8        4
+--R                 + 
+--R                    175     13   175     10   175     7 3+-+2
+--R                   (--- %i x   + --- %i x   + --- %i x )\|2
+--R                     8            8            4
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                       +------------+2
+--R                      25  15   25  12   25  9 3+-+ +-+3|     +-+
+--R                   (- -- x   - -- x   - -- x )\|2 \|7 \|- %i\|7  + 1
+--R                       4        4        2
+--R                 + 
+--R                                                       +------------+
+--R                    25  16   25  13   25  10 3+-+2 +-+3|     +-+
+--R                   (-- x   + -- x   + -- x  )\|2  \|7 \|- %i\|7  + 1
+--R                     4        4        2
+--R                 + 
+--R                    25  14   25  11   25  8  +-+   175     14   175     11
+--R                   (-- x   + -- x   + -- x )\|7  - --- %i x   - --- %i x
+--R                     4        4        2            4            4
+--R                 + 
+--R                     175     8
+--R                   - --- %i x
+--R                      2
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                      25  13   25  10   25  7 3+-+2 +-+
+--R                   (- -- x   - -- x   - -- x )\|2  \|7
+--R                       8        8        4
+--R                 + 
+--R                      175     13   175     10   175     7 3+-+2
+--R                   (- --- %i x   - --- %i x   - --- %i x )\|2
+--R                       8            8            4
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                    25  14   25  11   25  8  +-+   175     14   175     11
+--R                   (-- x   + -- x   + -- x )\|7  + --- %i x   + --- %i x
+--R                     4        4        2            4            4
+--R                 + 
+--R                   175     8
+--R                   --- %i x
+--R                    2
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                   12      9      6 3+-+ +-+
+--R               (25x   + 25x  + 50x )\|2 \|7
+--R          *
+--R                 1        3   3
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                          +------------+2
+--R                 5   17    5   14    5   11  +-+6+----+3 3|     +-+
+--R               (--- x   + --- x   + --- x  )\|7 \|1372   \|- %i\|7  + 1
+--R                392       392       196
+--R             + 
+--R                                                                +------------+
+--R                   5   18    5   15    5   12 3+-+ +-+6+----+3 3|     +-+
+--R               (- --- x   - --- x   - --- x  )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                  392       392       196
+--R             + 
+--R                       5   16    5   13    5   10 3+-+2 +-+
+--R                   (- --- x   - --- x   - --- x  )\|2  \|7
+--R                      784       784       392
+--R                 + 
+--R                     5      16    5      13    5     10 3+-+2
+--R                   (--- %i x   + --- %i x   + -- %i x  )\|2
+--R                    112          112          56
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                                                +------------+2
+--R                   5   18    5   15    5   12 3+-+ +-+6+----+3 3|     +-+
+--R               (- --- x   - --- x   - --- x  )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                  392       392       196
+--R             + 
+--R                                                               +------------+
+--R                 5   19    5   16    5   13 3+-+2 +-+6+----+3 3|     +-+
+--R               (--- x   + --- x   + --- x  )\|2  \|7 \|1372   \|- %i\|7  + 1
+--R                392       392       196
+--R             + 
+--R                     5   17    5   14    5   11  +-+    5     17    5     14
+--R                   (--- x   + --- x   + --- x  )\|7  - -- %i x   - -- %i x
+--R                    392       392       196            56          56
+--R                 + 
+--R                      5     11
+--R                   - -- %i x
+--R                     28
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                   5   16    5   13    5   10 3+-+2 +-+
+--R               (- --- x   - --- x   - --- x  )\|2  \|7
+--R                  784       784       392
+--R             + 
+--R                   5      16    5      13    5     10 3+-+2
+--R               (- --- %i x   - --- %i x   - -- %i x  )\|2
+--R                  112          112          56
+--R          *
+--R                       +------------+2
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                 5   17    5   14    5   11  +-+    5     17    5     14
+--R               (--- x   + --- x   + --- x  )\|7  + -- %i x   + -- %i x
+--R                392       392       196            56          56
+--R             + 
+--R                5     11
+--R               -- %i x
+--R               28
+--R          *
+--R                       +------------+
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R             5  15    5  12    5  9 3+-+ +-+6+----+3
+--R           (-- x   + -- x   + -- x )\|2 \|7 \|1372
+--R            98       98       49
+--R      *
+--R             1        3   3
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                      +------------+2
+--R                      8     5      2 3|     +-+
+--R                   (6x  + 6x  + 12x )\|- %i\|7  + 1
+--R                 + 
+--R                                            +------------+
+--R                        9     6      3 3+-+3|     +-+
+--R                   (- 6x  - 6x  - 12x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                         7        4         3+-+2 +-+        7     4      3+-+2
+--R                   (3%i x  + 3%i x  + 6%i x)\|2  \|7  + (- 3x  - 3x  - 6x)\|2
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                            +------------+2
+--R                        9     6      3 3+-+3|     +-+
+--R                   (- 6x  - 6x  - 12x )\|2 \|- %i\|7  + 1
+--R                 + 
+--R                                             +------------+
+--R                      10     7      4 3+-+2 3|     +-+
+--R                   (6x   + 6x  + 12x )\|2   \|- %i\|7  + 1
+--R                 + 
+--R                           8        5         2  +-+     8     5      2
+--R                   (- 6%i x  - 6%i x  - 12%i x )\|7  + 6x  + 6x  + 12x
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                             7        4         3+-+2 +-+
+--R                     (- 3%i x  - 3%i x  - 6%i x)\|2  \|7
+--R                   + 
+--R                          7     4      3+-+2
+--R                     (- 3x  - 3x  - 6x)\|2
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                        8        5         2  +-+     8     5      2
+--R                 ((6%i x  + 6%i x  + 12%i x )\|7  + 6x  + 6x  + 12x )
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                   6      3      3+-+
+--R               (24x  + 24x  + 48)\|2
+--R          *
+--R                 1        3   10
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                +------------+2
+--R                    231  14   231  11   231  8 3|     +-+
+--R                   (--- x   + --- x   + --- x )\|- %i\|7  + 1
+--R                     16        16        8
+--R                 + 
+--R                                                      +------------+
+--R                      231  15   231  12   231  9 3+-+3|     +-+
+--R                   (- --- x   - --- x   - --- x )\|2 \|- %i\|7  + 1
+--R                       16        16        8
+--R                 + 
+--R                    231     13   231     10   231     7 3+-+2 +-+
+--R                   (--- %i x   + --- %i x   + --- %i x )\|2  \|7
+--R                     32           32           16
+--R                 + 
+--R                      231  13   231  10   231  7 3+-+2
+--R                   (- --- x   - --- x   - --- x )\|2
+--R                       32        32        16
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                      +------------+2
+--R                      231  15   231  12   231  9 3+-+3|     +-+
+--R                   (- --- x   - --- x   - --- x )\|2 \|- %i\|7  + 1
+--R                       16        16        8
+--R                 + 
+--R                                                       +------------+
+--R                    231  16   231  13   231  10 3+-+2 3|     +-+
+--R                   (--- x   + --- x   + --- x  )\|2   \|- %i\|7  + 1
+--R                     16        16        8
+--R                 + 
+--R                      231     14   231     11   231     8  +-+   231  14
+--R                   (- --- %i x   - --- %i x   - --- %i x )\|7  + --- x
+--R                       16           16           8                16
+--R                 + 
+--R                   231  11   231  8
+--R                   --- x   + --- x
+--R                    16        8
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                      231     13   231     10   231     7 3+-+2 +-+
+--R                   (- --- %i x   - --- %i x   - --- %i x )\|2  \|7
+--R                       32           32           16
+--R                 + 
+--R                      231  13   231  10   231  7 3+-+2
+--R                   (- --- x   - --- x   - --- x )\|2
+--R                       32        32        16
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                    231     14   231     11   231     8  +-+   231  14   231  11
+--R                   (--- %i x   + --- %i x   + --- %i x )\|7  + --- x   + --- x
+--R                     16           16           8                16        16
+--R                 + 
+--R                   231  8
+--R                   --- x
+--R                    8
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                231  12   231  9   231  6 3+-+
+--R               (--- x   + --- x  + --- x )\|2
+--R                 4         4        2
+--R          *
+--R                 1        3   4
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                         +------------+2
+--R                       3  17    3  14    3  11 6+----+3 3|     +-+
+--R                   (- -- x   - -- x   - -- x  )\|1372   \|- %i\|7  + 1
+--R                      56       56       28
+--R                 + 
+--R                                                           +------------+
+--R                     3  18    3  15    3  12 3+-+6+----+3 3|     +-+
+--R                   (-- x   + -- x   + -- x  )\|2 \|1372   \|- %i\|7  + 1
+--R                    56       56       28
+--R                 + 
+--R                           3      16    3      13    3     10 3+-+2 +-+
+--R                       (- --- %i x   - --- %i x   - -- %i x  )\|2  \|7
+--R                          112          112          56
+--R                     + 
+--R                         3   16    3   13    3  10 3+-+2
+--R                       (--- x   + --- x   + -- x  )\|2
+--R                        112       112       56
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                           +------------+2
+--R                     3  18    3  15    3  12 3+-+6+----+3 3|     +-+
+--R                   (-- x   + -- x   + -- x  )\|2 \|1372   \|- %i\|7  + 1
+--R                    56       56       28
+--R                 + 
+--R                                                               +------------+
+--R                       3  19    3  16    3  13 3+-+2 6+----+3 3|     +-+
+--R                   (- -- x   - -- x   - -- x  )\|2   \|1372   \|- %i\|7  + 1
+--R                      56       56       28
+--R                 + 
+--R                         3     17    3     14    3     11  +-+    3  17    3  14
+--R                       (-- %i x   + -- %i x   + -- %i x  )\|7  - -- x   - -- x
+--R                        56          56          28               56       56
+--R                     + 
+--R                          3  11
+--R                       - -- x
+--R                         28
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                     3      16    3      13    3     10 3+-+2 +-+
+--R                   (--- %i x   + --- %i x   + -- %i x  )\|2  \|7
+--R                    112          112          56
+--R                 + 
+--R                     3   16    3   13    3  10 3+-+2
+--R                   (--- x   + --- x   + -- x  )\|2
+--R                    112       112       56
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                       3     17    3     14    3     11  +-+    3  17    3  14
+--R                   (- -- %i x   - -- %i x   - -- %i x  )\|7  - -- x   - -- x
+--R                      56          56          28               56       56
+--R                 + 
+--R                      3  11
+--R                   - -- x
+--R                     28
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                   3  15    3  12   3  9 3+-+6+----+3
+--R               (- -- x   - -- x   - - x )\|2 \|1372
+--R                  14       14       7
+--R          *
+--R                 1        3
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R      *
+--R             1        3   2
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                                             +------------+2
+--R                       15  11    15  8   15  5  +-+6+----+3 3|     +-+
+--R                   (- --- x   - --- x  - -- x )\|7 \|1372   \|- %i\|7  + 1
+--R                      196       196      98
+--R                 + 
+--R                                                               +------------+
+--R                     15  12    15  9   15  6 3+-+ +-+6+----+3 3|     +-+
+--R                   (--- x   + --- x  + -- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    196       196      98
+--R                 + 
+--R                         15  10    15  7    15  4 3+-+2 +-+
+--R                       (--- x   + --- x  + --- x )\|2  \|7
+--R                        392       392      196
+--R                     + 
+--R                          15     10   15     7   15     4 3+-+2
+--R                       (- -- %i x   - -- %i x  - -- %i x )\|2
+--R                          56          56         28
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                               +------------+2
+--R                     15  12    15  9   15  6 3+-+ +-+6+----+3 3|     +-+
+--R                   (--- x   + --- x  + -- x )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    196       196      98
+--R                 + 
+--R                                                                   +------------+
+--R                       15  13    15  10   15  7 3+-+2 +-+6+----+3 3|     +-+
+--R                   (- --- x   - --- x   - -- x )\|2  \|7 \|1372   \|- %i\|7  + 1
+--R                      196       196       98
+--R                 + 
+--R                           15  11    15  8   15  5  +-+   15     11   15     8
+--R                       (- --- x   - --- x  - -- x )\|7  + -- %i x   + -- %i x
+--R                          196       196      98           28          28
+--R                     + 
+--R                       15     5
+--R                       -- %i x
+--R                       14
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                     15  10    15  7    15  4 3+-+2 +-+
+--R                   (--- x   + --- x  + --- x )\|2  \|7
+--R                    392       392      196
+--R                 + 
+--R                    15     10   15     7   15     4 3+-+2
+--R                   (-- %i x   + -- %i x  + -- %i x )\|2
+--R                    56          56         28
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                       15  11    15  8   15  5  +-+   15     11   15     8
+--R                   (- --- x   - --- x  - -- x )\|7  - -- %i x   - -- %i x
+--R                      196       196      98           28          28
+--R                 + 
+--R                     15     5
+--R                   - -- %i x
+--R                     14
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                  15  9   15  6   30  3 3+-+ +-+6+----+3
+--R               (- -- x  - -- x  - -- x )\|2 \|7 \|1372
+--R                  49      49      49
+--R          *
+--R                 1        3   8
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                   +------------+2
+--R                      15  14   15  11   15  8  +-+3|     +-+
+--R                   (- -- x   - -- x   - -- x )\|7 \|- %i\|7  + 1
+--R                       8        8        4
+--R                 + 
+--R                                                     +------------+
+--R                    15  15   15  12   15  9 3+-+ +-+3|     +-+
+--R                   (-- x   + -- x   + -- x )\|2 \|7 \|- %i\|7  + 1
+--R                     8        8        4
+--R                 + 
+--R                    15  13   15  10   15  7 3+-+2 +-+
+--R                   (-- x   + -- x   + -- x )\|2  \|7
+--R                    16       16        8
+--R                 + 
+--R                      105     13   105     10   105     7 3+-+2
+--R                   (- --- %i x   - --- %i x   - --- %i x )\|2
+--R                       16           16           8
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                     +------------+2
+--R                    15  15   15  12   15  9 3+-+ +-+3|     +-+
+--R                   (-- x   + -- x   + -- x )\|2 \|7 \|- %i\|7  + 1
+--R                     8        8        4
+--R                 + 
+--R                                                         +------------+
+--R                      15  16   15  13   15  10 3+-+2 +-+3|     +-+
+--R                   (- -- x   - -- x   - -- x  )\|2  \|7 \|- %i\|7  + 1
+--R                       8        8        4
+--R                 + 
+--R                      15  14   15  11   15  8  +-+   105     14   105     11
+--R                   (- -- x   - -- x   - -- x )\|7  + --- %i x   + --- %i x
+--R                       8        8        4            8            8
+--R                 + 
+--R                   105     8
+--R                   --- %i x
+--R                    4
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                    15  13   15  10   15  7 3+-+2 +-+
+--R                   (-- x   + -- x   + -- x )\|2  \|7
+--R                    16       16        8
+--R                 + 
+--R                    105     13   105     10   105     7 3+-+2
+--R                   (--- %i x   + --- %i x   + --- %i x )\|2
+--R                     16           16           8
+--R              *
+--R                  +------------+2
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                      15  14   15  11   15  8  +-+   105     14   105     11
+--R                   (- -- x   - -- x   - -- x )\|7  - --- %i x   - --- %i x
+--R                       8        8        4            8            8
+--R                 + 
+--R                     105     8
+--R                   - --- %i x
+--R                      4
+--R              *
+--R                  +------------+
+--R                 3|     +-+
+--R                 \|- %i\|7  + 1
+--R             + 
+--R                  15  12   15  9      6 3+-+ +-+
+--R               (- -- x   - -- x  - 15x )\|2 \|7
+--R                   2        2
+--R          *
+--R                 1        3   5
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R         + 
+--R                                                                +------------+2
+--R                       15  17    15  14    15  11  +-+6+----+3 3|     +-+
+--R                   (- --- x   - --- x   - --- x  )\|7 \|1372   \|- %i\|7  + 1
+--R                      392       392       196
+--R                 + 
+--R                                                                  +------------+
+--R                     15  18    15  15    15  12 3+-+ +-+6+----+3 3|     +-+
+--R                   (--- x   + --- x   + --- x  )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    392       392       196
+--R                 + 
+--R                         15  16    15  13    15  10 3+-+2 +-+
+--R                       (--- x   + --- x   + --- x  )\|2  \|7
+--R                        784       784       392
+--R                     + 
+--R                           15     16    15     13   15     10 3+-+2
+--R                       (- --- %i x   - --- %i x   - -- %i x  )\|2
+--R                          112          112          56
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+2
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                                                                  +------------+2
+--R                     15  18    15  15    15  12 3+-+ +-+6+----+3 3|     +-+
+--R                   (--- x   + --- x   + --- x  )\|2 \|7 \|1372   \|- %i\|7  + 1
+--R                    392       392       196
+--R                 + 
+--R                         15  19    15  16    15  13 3+-+2 +-+6+----+3
+--R                     (- --- x   - --- x   - --- x  )\|2  \|7 \|1372
+--R                        392       392       196
+--R                  *
+--R                      +------------+
+--R                     3|     +-+
+--R                     \|- %i\|7  + 1
+--R                 + 
+--R                           15  17    15  14    15  11  +-+   15     17
+--R                       (- --- x   - --- x   - --- x  )\|7  + -- %i x
+--R                          392       392       196            56
+--R                     + 
+--R                       15     14   15     11
+--R                       -- %i x   + -- %i x
+--R                       56          28
+--R                  *
+--R                     6+----+3
+--R                     \|1372
+--R              *
+--R                  +----------+
+--R                 3|   +-+
+--R                 \|%i\|7  + 1
+--R             + 
+--R                     15  16    15  13    15  10 3+-+2 +-+
+--R                   (--- x   + --- x   + --- x  )\|2  \|7
+--R                    784       784       392
+--R                 + 
+--R                     15     16    15     13   15     10 3+-+2
+--R                   (--- %i x   + --- %i x   + -- %i x  )\|2
+--R                    112          112          56
+--R              *
+--R                           +------------+2
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                       15  17    15  14    15  11  +-+   15     17   15     14
+--R                   (- --- x   - --- x   - --- x  )\|7  - -- %i x   - -- %i x
+--R                      392       392       196            56          56
+--R                 + 
+--R                     15     11
+--R                   - -- %i x
+--R                     28
+--R              *
+--R                           +------------+
+--R                 6+----+3 3|     +-+
+--R                 \|1372   \|- %i\|7  + 1
+--R             + 
+--R                  15  15   15  12   15  9 3+-+ +-+6+----+3
+--R               (- -- x   - -- x   - -- x )\|2 \|7 \|1372
+--R                  98       98       49
+--R          *
+--R                 1        3   2
+--R             cos(- atan(----))
+--R                 3       +-+
+--R                        \|7
+--R      *
+--R             1        3
+--R         sin(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                               +------------+2
+--R                 8    5     2 3|     +-+
+--R               (x  + x  + 2x )\|- %i\|7  + 1
+--R             + 
+--R                                     +------------+
+--R                   9    6     3 3+-+3|     +-+
+--R               (- x  - x  - 2x )\|2 \|- %i\|7  + 1
+--R             + 
+--R                1     7   1     4        3+-+2 +-+      1  7   1  4     3+-+2
+--R               (- %i x  + - %i x  + %i x)\|2  \|7  + (- - x  - - x  - x)\|2
+--R                2         2                             2      2
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                     +------------+2
+--R                   9    6     3 3+-+3|     +-+
+--R               (- x  - x  - 2x )\|2 \|- %i\|7  + 1
+--R             + 
+--R                                      +------------+
+--R                 10    7     4 3+-+2 3|     +-+
+--R               (x   + x  + 2x )\|2   \|- %i\|7  + 1
+--R             + 
+--R                      8       5        2  +-+    8    5     2
+--R               (- %i x  - %i x  - 2%i x )\|7  + x  + x  + 2x
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                 1     7   1     4        3+-+2 +-+      1  7   1  4     3+-+2
+--R             ((- - %i x  - - %i x  - %i x)\|2  \|7  + (- - x  - - x  - x)\|2  )
+--R                 2         2                             2      2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                                                          +------------+
+--R                 8       5        2  +-+    8    5     2 3|     +-+
+--R           ((%i x  + %i x  + 2%i x )\|7  + x  + x  + 2x )\|- %i\|7  + 1
+--R         + 
+--R              6     3     3+-+
+--R           (4x  + 4x  + 8)\|2
+--R      *
+--R             1        3   12
+--R         cos(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                                 +------------+2
+--R                 1  11    1  8    1  5 6+----+3 3|     +-+
+--R               (-- x   + -- x  + -- x )\|1372   \|- %i\|7  + 1
+--R                28       28      14
+--R             + 
+--R                                                       +------------+
+--R                   1  12    1  9    1  6 3+-+6+----+3 3|     +-+
+--R               (- -- x   - -- x  - -- x )\|2 \|1372   \|- %i\|7  + 1
+--R                  28       28      14
+--R             + 
+--R                     1     10    1     7    1     4 3+-+2 +-+
+--R                   (-- %i x   + -- %i x  + -- %i x )\|2  \|7
+--R                    56          56         28
+--R                 + 
+--R                       1  10    1  7    1  4 3+-+2
+--R                   (- -- x   - -- x  - -- x )\|2
+--R                      56       56      28
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                                       +------------+2
+--R                   1  12    1  9    1  6 3+-+6+----+3 3|     +-+
+--R               (- -- x   - -- x  - -- x )\|2 \|1372   \|- %i\|7  + 1
+--R                  28       28      14
+--R             + 
+--R                                                        +------------+
+--R                 1  13    1  10    1  7 3+-+2 6+----+3 3|     +-+
+--R               (-- x   + -- x   + -- x )\|2   \|1372   \|- %i\|7  + 1
+--R                28       28       14
+--R             + 
+--R                       1     11    1     8    1     5  +-+    1  11    1  8
+--R                   (- -- %i x   - -- %i x  - -- %i x )\|7  + -- x   + -- x
+--R                      28          28         14              28       28
+--R                 + 
+--R                    1  5
+--R                   -- x
+--R                   14
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                   1     10    1     7    1     4 3+-+2 +-+
+--R               (- -- %i x   - -- %i x  - -- %i x )\|2  \|7
+--R                  56          56         28
+--R             + 
+--R                   1  10    1  7    1  4 3+-+2
+--R               (- -- x   - -- x  - -- x )\|2
+--R                  56       56      28
+--R          *
+--R                       +------------+2
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                1     11    1     8    1     5  +-+    1  11    1  8    1  5
+--R             ((-- %i x   + -- %i x  + -- %i x )\|7  + -- x   + -- x  + -- x )
+--R               28          28         14              28       28      14
+--R          *
+--R                       +------------+
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R            1  9   1  6   2  3 3+-+6+----+3
+--R           (- x  + - x  + - x )\|2 \|1372
+--R            7      7      7
+--R      *
+--R             1        3   9
+--R         cos(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                         +------------+2
+--R                23  14   23  11   23  8 3|     +-+
+--R               (-- x   + -- x   + -- x )\|- %i\|7  + 1
+--R                16       16        8
+--R             + 
+--R                                               +------------+
+--R                  23  15   23  12   23  9 3+-+3|     +-+
+--R               (- -- x   - -- x   - -- x )\|2 \|- %i\|7  + 1
+--R                  16       16        8
+--R             + 
+--R                23     13   23     10   23     7 3+-+2 +-+
+--R               (-- %i x   + -- %i x   + -- %i x )\|2  \|7
+--R                32          32          16
+--R             + 
+--R                  23  13   23  10   23  7 3+-+2
+--R               (- -- x   - -- x   - -- x )\|2
+--R                  32       32       16
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                               +------------+2
+--R                  23  15   23  12   23  9 3+-+3|     +-+
+--R               (- -- x   - -- x   - -- x )\|2 \|- %i\|7  + 1
+--R                  16       16        8
+--R             + 
+--R                                                +------------+
+--R                23  16   23  13   23  10 3+-+2 3|     +-+
+--R               (-- x   + -- x   + -- x  )\|2   \|- %i\|7  + 1
+--R                16       16        8
+--R             + 
+--R                23     14   23     11   23     8  +-+   23  14   23  11   23  8
+--R             (- -- %i x   - -- %i x   - -- %i x )\|7  + -- x   + -- x   + -- x
+--R                16          16           8              16       16        8
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                  23     13   23     10   23     7 3+-+2 +-+
+--R               (- -- %i x   - -- %i x   - -- %i x )\|2  \|7
+--R                  32          32          16
+--R             + 
+--R                  23  13   23  10   23  7 3+-+2
+--R               (- -- x   - -- x   - -- x )\|2
+--R                  32       32       16
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R               23     14   23     11   23     8  +-+   23  14   23  11   23  8
+--R             ((-- %i x   + -- %i x   + -- %i x )\|7  + -- x   + -- x   + -- x )
+--R               16          16           8              16       16        8
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R            23  12   23  9   23  6 3+-+
+--R           (-- x   + -- x  + -- x )\|2
+--R             4        4       2
+--R      *
+--R             1        3   6
+--R         cos(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                                   +------------+2
+--R                 1  17    1  14    1  11 6+----+3 3|     +-+
+--R               (-- x   + -- x   + -- x  )\|1372   \|- %i\|7  + 1
+--R                56       56       28
+--R             + 
+--R                                                         +------------+
+--R                   1  18    1  15    1  12 3+-+6+----+3 3|     +-+
+--R               (- -- x   - -- x   - -- x  )\|2 \|1372   \|- %i\|7  + 1
+--R                  56       56       28
+--R             + 
+--R                     1      16    1      13    1     10 3+-+2 +-+
+--R                   (--- %i x   + --- %i x   + -- %i x  )\|2  \|7
+--R                    112          112          56
+--R                 + 
+--R                       1   16    1   13    1  10 3+-+2
+--R                   (- --- x   - --- x   - -- x  )\|2
+--R                      112       112       56
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+2
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                                                         +------------+2
+--R                   1  18    1  15    1  12 3+-+6+----+3 3|     +-+
+--R               (- -- x   - -- x   - -- x  )\|2 \|1372   \|- %i\|7  + 1
+--R                  56       56       28
+--R             + 
+--R                                                         +------------+
+--R                 1  19    1  16    1  13 3+-+2 6+----+3 3|     +-+
+--R               (-- x   + -- x   + -- x  )\|2   \|1372   \|- %i\|7  + 1
+--R                56       56       28
+--R             + 
+--R                       1     17    1     14    1     11  +-+    1  17    1  14
+--R                   (- -- %i x   - -- %i x   - -- %i x  )\|7  + -- x   + -- x
+--R                      56          56          28               56       56
+--R                 + 
+--R                    1  11
+--R                   -- x
+--R                   28
+--R              *
+--R                 6+----+3
+--R                 \|1372
+--R          *
+--R              +----------+
+--R             3|   +-+
+--R             \|%i\|7  + 1
+--R         + 
+--R                   1      16    1      13    1     10 3+-+2 +-+
+--R               (- --- %i x   - --- %i x   - -- %i x  )\|2  \|7
+--R                  112          112          56
+--R             + 
+--R                   1   16    1   13    1  10 3+-+2
+--R               (- --- x   - --- x   - -- x  )\|2
+--R                  112       112       56
+--R          *
+--R                       +------------+2
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R                   1     17    1     14    1     11  +-+    1  17    1  14
+--R                 (-- %i x   + -- %i x   + -- %i x  )\|7  + -- x   + -- x
+--R                  56          56          28               56       56
+--R               + 
+--R                  1  11
+--R                 -- x
+--R                 28
+--R          *
+--R                       +------------+
+--R             6+----+3 3|     +-+
+--R             \|1372   \|- %i\|7  + 1
+--R         + 
+--R             1  15    1  12   1  9 3+-+6+----+3
+--R           (-- x   + -- x   + - x )\|2 \|1372
+--R            14       14       7
+--R      *
+--R             1        3   3
+--R         cos(- atan(----))
+--R             3       +-+
+--R                    \|7
+--R     + 
+--R                                   +------------+2
+--R            1  20   1  17   1  14 3|     +-+
+--R           (- x   + - x   + - x  )\|- %i\|7  + 1
+--R            4       4       2
+--R         + 
+--R                                         +------------+
+--R              1  21   1  18   1  15 3+-+3|     +-+
+--R           (- - x   - - x   - - x  )\|2 \|- %i\|7  + 1
+--R              4       4       2
+--R         + 
+--R            1     19   1     16   1     13 3+-+2 +-+
+--R           (- %i x   + - %i x   + - %i x  )\|2  \|7
+--R            8          8          4
+--R         + 
+--R              1  19   1  16   1  13 3+-+2
+--R           (- - x   - - x   - - x  )\|2
+--R              8       8       4
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                                         +------------+2
+--R              1  21   1  18   1  15 3+-+3|     +-+
+--R           (- - x   - - x   - - x  )\|2 \|- %i\|7  + 1
+--R              4       4       2
+--R         + 
+--R                                         +------------+
+--R            1  22   1  19   1  16 3+-+2 3|     +-+
+--R           (- x   + - x   + - x  )\|2   \|- %i\|7  + 1
+--R            4       4       2
+--R         + 
+--R              1     20   1     17   1     14  +-+   1  20   1  17   1  14
+--R           (- - %i x   - - %i x   - - %i x  )\|7  + - x   + - x   + - x
+--R              4          4          2               4       4       2
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R              1     19   1     16   1     13 3+-+2 +-+
+--R           (- - %i x   - - %i x   - - %i x  )\|2  \|7
+--R              8          8          4
+--R         + 
+--R              1  19   1  16   1  13 3+-+2
+--R           (- - x   - - x   - - x  )\|2
+--R              8       8       4
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|7  + 1
+--R     + 
+--R           1     20   1     17   1     14  +-+   1  20   1  17   1  14
+--R         ((- %i x   + - %i x   + - %i x  )\|7  + - x   + - x   + - x  )
+--R           4          4          2               4       4       2
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|7  + 1
+--R     + 
+--R         18    15     12 3+-+
+--R       (x   + x   + 2x  )\|2
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 915
+
+)clear all
+
+--S 916 of 2282
+t0:=x^2/(2+x^3+x^6)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 916
+
+--S 917 of 2282
+r0:=2/3*atan((1+2*x^3)/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                 3      +-+
+--R              (2x  + 1)\|7
+--R        2atan(-------------)
+--R                    7
+--R   (2)  --------------------
+--R                  +-+
+--R                3\|7
+--R                                                    Type: Expression(Integer)
+--E 917
+
+--S 918 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 3      +-+
+--R              (2x  + 1)\|7
+--R        2atan(-------------)
+--R                    7
+--R   (3)  --------------------
+--R                  +-+
+--R                3\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 918
+
+--S 919 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 919
+
+--S 920 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 920
+
+)clear all
+
+--S 921 of 2282
+t0:=x^3/(2+x^3+x^6)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 921
+
+--S 922 of 2282
+r0:=1/21*log(2^(1/3)*x+(1+%i*sqrt(7))^(1/3))*(7-%i*sqrt(7))/(2^(1/3)*_
+   (1+%i*sqrt(7))^(2/3))-1/42*log(2^(2/3)*x^2-2^(1/3)*x*(1+%i*_
+   sqrt(7))^(1/3)+(1+%i*sqrt(7))^(2/3))*(7-%i*sqrt(7))/(2^(1/3)*_
+   (1+%i*sqrt(7))^(2/3))+1/21*log(2^(1/3)*x+(1-%i*sqrt(7))^(1/3))*_
+   (7+%i*sqrt(7))/(2^(1/3)*(1-%i*sqrt(7))^(2/3))-1/42*log(2^(2/3)*_
+   x^2-2^(1/3)*x*(1-%i*sqrt(7))^(1/3)+(1-%i*sqrt(7))^(2/3))*(7+%i*_
+   sqrt(7))/(2^(1/3)*(1-%i*sqrt(7))^(2/3))-%i*atan((-4*x+2^(2/3)*_
+   (1-%i*sqrt(7))^(1/3))/(2^(2/3)*sqrt(3)*(1-%i*sqrt(7))^(1/3)))*_
+   (1-%i*sqrt(7))^(1/3)/(2^(1/3)*sqrt(21))+%i*atan((-4*x+2^(2/3)*_
+   (1+%i*sqrt(7))^(1/3))/(2^(2/3)*sqrt(3)*(1+%i*sqrt(7))^(1/3)))*_
+   (1+%i*sqrt(7))^(1/3)/(2^(1/3)*sqrt(21))
+--R 
+--R
+--R   (2)
+--R                           +------------+2
+--R             +-+      +--+3|     +-+
+--R         (%i\|7  - 7)\|21 \|- %i\|7  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|7  + 1   - x\|2 \|%i\|7  + 1  + x  \|2 )
+--R     + 
+--R                             +------------+2     +----------+
+--R              +-+       +--+3|     +-+          3|   +-+         3+-+
+--R       (- 2%i\|7  + 14)\|21 \|- %i\|7  + 1  log(\|%i\|7  + 1  + x\|2 )
+--R     + 
+--R                             +----------+2
+--R               +-+      +--+3|   +-+
+--R         (- %i\|7  - 7)\|21 \|%i\|7  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|7  + 1   - x\|2 \|- %i\|7  + 1  + x  \|2 )
+--R     + 
+--R                           +----------+2     +------------+
+--R            +-+       +--+3|   +-+          3|     +-+         3+-+
+--R       (2%i\|7  + 14)\|21 \|%i\|7  + 1  log(\|- %i\|7  + 1  + x\|2 )
+--R     + 
+--R                                                    +----------+
+--R                         +------------+2     3+-+2 3|   +-+
+--R             +-+        3|     +-+           \|2   \|%i\|7  + 1 - 4x
+--R       (- 42\|7  + 42%i)\|- %i\|7  + 1  atan(-----------------------)
+--R                                                        +----------+
+--R                                              3+-+2 +-+3|   +-+
+--R                                              \|2  \|3 \|%i\|7  + 1
+--R     + 
+--R                                                  +------------+
+--R                         +----------+2     3+-+2 3|     +-+
+--R             +-+        3|   +-+           \|2   \|- %i\|7  + 1 - 4x
+--R       (- 42\|7  - 42%i)\|%i\|7  + 1  atan(-------------------------)
+--R                                                      +------------+
+--R                                            3+-+2 +-+3|     +-+
+--R                                            \|2  \|3 \|- %i\|7  + 1
+--R  /
+--R                 +------------+2  +----------+2
+--R       3+-+ +--+3|     +-+       3|   +-+
+--R     42\|2 \|21 \|- %i\|7  + 1   \|%i\|7  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 922
+
+--S 923 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         1
+--R                  atan(----)
+--R                        +-+
+--R          6+-+         \|7
+--R         2\|2 cos(----------)
+--R                       3
+--R      *
+--R         log
+--R                               1   2                              1
+--R                        atan(----)                         atan(----)
+--R                              +-+                                +-+
+--R               6+-+2         \|7         6+-+ +-+6+---+         \|7
+--R              7\|2  sin(----------)  + 2x\|2 \|7 \|343 sin(----------)
+--R                             3                                  3
+--R            + 
+--R                               1   2
+--R                        atan(----)
+--R                              +-+
+--R               6+-+2         \|7        2 6+---+2
+--R              7\|2  cos(----------)  + x  \|343
+--R                             3
+--R     + 
+--R                               1                     1
+--R                        atan(----)            atan(----)
+--R                              +-+                   +-+
+--R            6+-+ +-+         \|7      6+-+         \|7
+--R         (- \|2 \|3 sin(----------) - \|2 cos(----------))
+--R                             3                     3
+--R      *
+--R         log
+--R                               1   2                             1
+--R                        atan(----)                        atan(----)
+--R                              +-+                               +-+
+--R               6+-+2         \|7        6+-+ +-+6+---+         \|7
+--R              7\|2  sin(----------)  - x\|2 \|7 \|343 sin(----------)
+--R                             3                                 3
+--R            + 
+--R                               1   2                                 1
+--R                        atan(----)                            atan(----)
+--R                              +-+                                   +-+
+--R               6+-+2         \|7        6+-+ +-+ +-+6+---+         \|7
+--R              7\|2  cos(----------)  + x\|2 \|3 \|7 \|343 cos(----------)
+--R                             3                                     3
+--R            + 
+--R               2 6+---+2
+--R              x  \|343
+--R     + 
+--R                             1                     1
+--R                      atan(----)            atan(----)
+--R                            +-+                   +-+
+--R          6+-+ +-+         \|7      6+-+         \|7
+--R         (\|2 \|3 sin(----------) - \|2 cos(----------))
+--R                           3                     3
+--R      *
+--R         log
+--R                               1   2                             1
+--R                        atan(----)                        atan(----)
+--R                              +-+                               +-+
+--R               6+-+2         \|7        6+-+ +-+6+---+         \|7
+--R              7\|2  sin(----------)  - x\|2 \|7 \|343 sin(----------)
+--R                             3                                 3
+--R            + 
+--R                               1   2                                 1
+--R                        atan(----)                            atan(----)
+--R                              +-+                                   +-+
+--R               6+-+2         \|7        6+-+ +-+ +-+6+---+         \|7
+--R              7\|2  cos(----------)  - x\|2 \|3 \|7 \|343 cos(----------)
+--R                             3                                     3
+--R            + 
+--R               2 6+---+2
+--R              x  \|343
+--R     + 
+--R                            1                          1
+--R                     atan(----)                 atan(----)
+--R                           +-+                        +-+
+--R             6+-+         \|7       6+-+ +-+         \|7
+--R         (- 2\|2 sin(----------) + 2\|2 \|3 cos(----------))
+--R                          3                          3
+--R      *
+--R                                          1                      1
+--R                                   atan(----)             atan(----)
+--R                                         +-+                    +-+
+--R                       6+-+ +-+         \|7       6+-+         \|7
+--R                      7\|2 \|3 sin(----------) + 7\|2 cos(----------)
+--R                                        3                      3
+--R         atan(--------------------------------------------------------------)
+--R                              1                          1
+--R                       atan(----)                 atan(----)
+--R                             +-+                        +-+
+--R               6+-+         \|7       6+-+ +-+         \|7         +-+6+---+
+--R              7\|2 sin(----------) - 7\|2 \|3 cos(----------) - 2x\|7 \|343
+--R                            3                          3
+--R     + 
+--R                          1                          1
+--R                   atan(----)                 atan(----)
+--R                         +-+                        +-+
+--R           6+-+         \|7       6+-+ +-+         \|7
+--R         (2\|2 sin(----------) + 2\|2 \|3 cos(----------))
+--R                        3                          3
+--R      *
+--R                                          1                      1
+--R                                   atan(----)             atan(----)
+--R                                         +-+                    +-+
+--R                       6+-+ +-+         \|7       6+-+         \|7
+--R                      7\|2 \|3 sin(----------) - 7\|2 cos(----------)
+--R                                        3                      3
+--R         atan(--------------------------------------------------------------)
+--R                              1                          1
+--R                       atan(----)                 atan(----)
+--R                             +-+                        +-+
+--R               6+-+         \|7       6+-+ +-+         \|7         +-+6+---+
+--R              7\|2 sin(----------) + 7\|2 \|3 cos(----------) - 2x\|7 \|343
+--R                            3                          3
+--R     + 
+--R                                                       1
+--R                                                atan(----)
+--R                       1                              +-+
+--R                atan(----)              6+-+         \|7
+--R                      +-+              7\|2 cos(----------)
+--R        6+-+         \|7                             3
+--R       4\|2 sin(----------)atan(----------------------------------)
+--R                     3                          1
+--R                                         atan(----)
+--R                                               +-+
+--R                                 6+-+         \|7        +-+6+---+
+--R                                7\|2 sin(----------) + x\|7 \|343
+--R                                              3
+--R  /
+--R      6+---+
+--R     6\|343
+--R                                         Type: Union(Expression(Integer),...)
+--E 923
+
+--S 924 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +------------+2
+--R           +-+       +--+3|     +-+
+--R         (\|7  - %i)\|21 \|- %i\|7  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|7  + 1   - x\|2 \|%i\|7  + 1  + x  \|2 )
+--R     + 
+--R                            +------------+2     +----------+
+--R            +-+        +--+3|     +-+          3|   +-+         3+-+
+--R       (- 2\|7  + 2%i)\|21 \|- %i\|7  + 1  log(\|%i\|7  + 1  + x\|2 )
+--R     + 
+--R                          +----------+2
+--R           +-+       +--+3|   +-+
+--R         (\|7  + %i)\|21 \|%i\|7  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|7  + 1   - x\|2 \|- %i\|7  + 1  + x  \|2 )
+--R     + 
+--R                            +----------+2     +------------+
+--R            +-+        +--+3|   +-+          3|     +-+         3+-+
+--R       (- 2\|7  - 2%i)\|21 \|%i\|7  + 1  log(\|- %i\|7  + 1  + x\|2 )
+--R     + 
+--R                                +------------+2  +----------+2
+--R          3+-+6+-+ +--+    %pi 3|     +-+       3|   +-+
+--R         2\|2 \|2 \|21 cos(---)\|- %i\|7  + 1   \|%i\|7  + 1
+--R                            18
+--R      *
+--R              6+-+2    %pi 2      6+-+    %pi     6+-+2    %pi 2     2
+--R         log(7\|2  sin(---)  + 14x\|2 sin(---) + 7\|2  cos(---)  + 7x )
+--R                        18                 18               18
+--R     + 
+--R                                                               +------------+2
+--R            3+-+6+-+ +-+ +--+    %pi    3+-+6+-+ +--+    %pi  3|     +-+
+--R         (- \|2 \|2 \|3 \|21 sin(---) - \|2 \|2 \|21 cos(---))\|- %i\|7  + 1
+--R                                  18                      18
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R      *
+--R         log
+--R               6+-+2    %pi 2     6+-+    %pi     6+-+2    %pi 2
+--R              7\|2  sin(---)  - 7x\|2 sin(---) + 7\|2  cos(---)
+--R                         18                18               18
+--R            + 
+--R                6+-+ +-+    %pi      2
+--R              7x\|2 \|3 cos(---) + 7x
+--R                             18
+--R     + 
+--R                                                             +------------+2
+--R          3+-+6+-+ +-+ +--+    %pi    3+-+6+-+ +--+    %pi  3|     +-+
+--R         (\|2 \|2 \|3 \|21 sin(---) - \|2 \|2 \|21 cos(---))\|- %i\|7  + 1
+--R                                18                      18
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R      *
+--R         log
+--R               6+-+2    %pi 2     6+-+    %pi     6+-+2    %pi 2
+--R              7\|2  sin(---)  - 7x\|2 sin(---) + 7\|2  cos(---)
+--R                         18                18               18
+--R            + 
+--R                  6+-+ +-+    %pi      2
+--R              - 7x\|2 \|3 cos(---) + 7x
+--R                               18
+--R     + 
+--R                                                                 +------------+2
+--R             3+-+6+-+ +--+    %pi     3+-+6+-+ +-+ +--+    %pi  3|     +-+
+--R         (- 2\|2 \|2 \|21 sin(---) + 2\|2 \|2 \|3 \|21 cos(---))\|- %i\|7  + 1
+--R                               18                           18
+--R      *
+--R                               6+-+ +-+    %pi    6+-+    %pi
+--R          +----------+2        \|2 \|3 sin(---) + \|2 cos(---)
+--R         3|   +-+                           18             18
+--R         \|%i\|7  + 1  atan(------------------------------------)
+--R                            6+-+    %pi    6+-+ +-+    %pi
+--R                            \|2 sin(---) - \|2 \|3 cos(---) - 2x
+--R                                     18                 18
+--R     + 
+--R                                                               +------------+2
+--R           3+-+6+-+ +--+    %pi     3+-+6+-+ +-+ +--+    %pi  3|     +-+
+--R         (2\|2 \|2 \|21 sin(---) + 2\|2 \|2 \|3 \|21 cos(---))\|- %i\|7  + 1
+--R                             18                           18
+--R      *
+--R                               6+-+ +-+    %pi    6+-+    %pi
+--R          +----------+2        \|2 \|3 sin(---) - \|2 cos(---)
+--R         3|   +-+                           18             18
+--R         \|%i\|7  + 1  atan(------------------------------------)
+--R                            6+-+    %pi    6+-+ +-+    %pi
+--R                            \|2 sin(---) + \|2 \|3 cos(---) - 2x
+--R                                     18                 18
+--R     + 
+--R                                                   +----------+
+--R                        +------------+2     3+-+2 3|   +-+
+--R              +-+      3|     +-+           \|2   \|%i\|7  + 1 - 4x
+--R       (- 6%i\|7  + 42)\|- %i\|7  + 1  atan(-----------------------)
+--R                                                       +----------+
+--R                                             3+-+2 +-+3|   +-+
+--R                                             \|2  \|3 \|%i\|7  + 1
+--R     + 
+--R                                               +------------+
+--R                      +----------+2     3+-+2 3|     +-+
+--R            +-+      3|   +-+           \|2   \|- %i\|7  + 1 - 4x
+--R       (6%i\|7  + 42)\|%i\|7  + 1  atan(-------------------------)
+--R                                                   +------------+
+--R                                         3+-+2 +-+3|     +-+
+--R                                         \|2  \|3 \|- %i\|7  + 1
+--R     + 
+--R                                                                 6+-+    %pi
+--R                            +------------+2  +----------+2       \|2 cos(---)
+--R      3+-+6+-+ +--+    %pi 3|     +-+       3|   +-+                      18
+--R     4\|2 \|2 \|21 sin(---)\|- %i\|7  + 1   \|%i\|7  + 1  atan(----------------)
+--R                        18                                     6+-+    %pi
+--R                                                               \|2 sin(---) + x
+--R                                                                        18
+--R  /
+--R                    +------------+2  +----------+2
+--R      3+-+ +-+ +--+3|     +-+       3|   +-+
+--R     6\|2 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 924
+
+--S 925 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                     5    %pi 12        5    %pi 2    %pi 10
+--R               - 336x sin(---)   - 2016x cos(---) sin(---)
+--R                           18                 18       18
+--R             + 
+--R                     8 6+-+3    %pi 9
+--R               - 672x  \|2  sin(---)
+--R                                 18
+--R             + 
+--R                         5    %pi 4        11       8       5 6+-+3 +-+    %pi
+--R                 (- 5040x cos(---)  + (144x   + 144x  + 288x )\|2  \|7 cos(---))
+--R                               18                                           18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          5    %pi 6
+--R                   - 6720x cos(---)
+--R                                18
+--R                 + 
+--R                        11       8       5 6+-+3 +-+    %pi 3        11
+--R                   (384x   + 384x  + 768x )\|2  \|7 cos(---)  - 1008x
+--R                                                         18
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       8 6+-+3    %pi 4       14       11       8  +-+    %pi
+--R                 (4032x  \|2  cos(---) + (288x   + 288x   + 576x )\|7 cos(---))
+--R                                   18                                      18
+--R              *
+--R                     %pi 5
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          5    %pi 8
+--R                   - 5040x cos(---)
+--R                                18
+--R                 + 
+--R                      11       8       5 6+-+3 +-+    %pi 5        11    %pi 2
+--R                 (288x   + 288x  + 576x )\|2  \|7 cos(---)  + 3024x  cos(---)
+--R                                                       18                 18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        8 6+-+3    %pi 6
+--R                   5376x  \|2  cos(---)
+--R                                    18
+--R                 + 
+--R                          14       11        8  +-+    %pi 3       14 6+-+3
+--R                   (- 960x   - 960x   - 1920x )\|7 cos(---)  - 336x   \|2
+--R                                                        18
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          5    %pi 10        11    %pi 4
+--R                   - 2016x cos(---)   - 7056x  cos(---)
+--R                                18                  18
+--R                 + 
+--R                       17      14       11 6+-+3 +-+    %pi
+--R                   (72x   + 72x   + 144x  )\|2  \|7 cos(---)
+--R                                                         18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        8 6+-+3    %pi 8       14       11       8  +-+    %pi 5
+--R                   2016x  \|2  cos(---) + (288x   + 288x   + 576x )\|7 cos(---)
+--R                                    18                                      18
+--R                 + 
+--R                        14 6+-+3    %pi 2
+--R                   1008x   \|2  cos(---)
+--R                                     18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     5    %pi 12         11      8      5 6+-+3 +-+    %pi 9
+--R               - 336x cos(---)   + (- 48x   - 48x  - 96x )\|2  \|7 cos(---)
+--R                           18                                           18
+--R             + 
+--R                     11    %pi 6         17      14      11 6+-+3 +-+    %pi 3
+--R               - 336x  cos(---)  + (- 24x   - 24x   - 48x  )\|2  \|7 cos(---)
+--R                            18                                            18
+--R             + 
+--R                    17
+--R               - 84x
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                   6 6+-+2    %pi 12       6 6+-+2    %pi 2    %pi 10
+--R               336x  \|2  sin(---)  + 2016x  \|2  cos(---) sin(---)
+--R                               18                      18       18
+--R             + 
+--R                   9 6+-+5    %pi 9
+--R               672x  \|2  sin(---)
+--R                               18
+--R             + 
+--R                        6 6+-+2    %pi 4
+--R                   5040x  \|2  cos(---)
+--R                                    18
+--R                 + 
+--R                          12       9       6 6+-+5 +-+    %pi
+--R                   (- 144x   - 144x  - 288x )\|2  \|7 cos(---)
+--R                                                           18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        6 6+-+2    %pi 6
+--R                   6720x  \|2  cos(---)
+--R                                    18
+--R                 + 
+--R                          12       9       6 6+-+5 +-+    %pi 3        12 6+-+2
+--R                   (- 384x   - 384x  - 768x )\|2  \|7 cos(---)  + 1008x   \|2
+--R                                                           18
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          9 6+-+5    %pi 4
+--R                   - 4032x  \|2  cos(---)
+--R                                      18
+--R                 + 
+--R                          15       12       9 6+-+2 +-+    %pi
+--R                   (- 288x   - 288x   - 576x )\|2  \|7 cos(---)
+--R                                                            18
+--R              *
+--R                     %pi 5
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        6 6+-+2    %pi 8
+--R                   5040x  \|2  cos(---)
+--R                                    18
+--R                 + 
+--R                          12       9       6 6+-+5 +-+    %pi 5
+--R                   (- 288x   - 288x  - 576x )\|2  \|7 cos(---)
+--R                                                           18
+--R                 + 
+--R                          12 6+-+2    %pi 2
+--R                   - 3024x   \|2  cos(---)
+--R                                       18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          9 6+-+5    %pi 6
+--R                   - 5376x  \|2  cos(---)
+--R                                      18
+--R                 + 
+--R                        15       12        9 6+-+2 +-+    %pi 3       15 6+-+5
+--R                   (960x   + 960x   + 1920x )\|2  \|7 cos(---)  + 336x   \|2
+--R                                                           18
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        6 6+-+2    %pi 10       12 6+-+2    %pi 4
+--R                   2016x  \|2  cos(---)  + 7056x   \|2  cos(---)
+--R                                    18                       18
+--R                 + 
+--R                         18      15       12 6+-+5 +-+    %pi
+--R                   (- 72x   - 72x   - 144x  )\|2  \|7 cos(---)
+--R                                                           18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          9 6+-+5    %pi 8
+--R                   - 2016x  \|2  cos(---)
+--R                                      18
+--R                 + 
+--R                          15       12       9 6+-+2 +-+    %pi 5
+--R                   (- 288x   - 288x   - 576x )\|2  \|7 cos(---)
+--R                                                            18
+--R                 + 
+--R                          15 6+-+5    %pi 2
+--R                   - 1008x   \|2  cos(---)
+--R                                       18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   6 6+-+2    %pi 12      12      9      6 6+-+5 +-+    %pi 9
+--R               336x  \|2  cos(---)  + (48x   + 48x  + 96x )\|2  \|7 cos(---)
+--R                               18                                        18
+--R             + 
+--R                   12 6+-+2    %pi 6      18      15      12 6+-+5 +-+    %pi 3
+--R               336x   \|2  cos(---) + (24x   + 24x   + 48x  )\|2  \|7 cos(---)
+--R                                18                                         18
+--R             + 
+--R                  18 6+-+2
+--R               84x   \|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                      7     4      6+-+4 +-+ +-+
+--R                   (4x  + 4x  + 8x)\|2  \|3 \|7
+--R                 + 
+--R                         7        4         6+-+4 +-+
+--R                   (4%i x  + 4%i x  + 8%i x)\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        7          4          6+-+4 +-+
+--R               (- 12%i x  - 180%i x  - 24%i x)\|2  \|7
+--R             + 
+--R                     7      4        6+-+4
+--R               (- 84x  + 84x  - 168x)\|2
+--R          *
+--R                 %pi 12
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7      4       6+-+4 +-+ +-+
+--R                   (24x  + 24x  + 48x)\|2  \|3 \|7
+--R                 + 
+--R                          7         4          6+-+4 +-+
+--R                   (24%i x  + 24%i x  + 48%i x)\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        7           4           6+-+4 +-+
+--R               (- 72%i x  - 1080%i x  - 144%i x)\|2  \|7
+--R             + 
+--R                      7       4         6+-+4
+--R               (- 504x  + 504x  - 1008x)\|2
+--R          *
+--R                 %pi 2    %pi 10
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                       10      7      4 6+-+ +-+ +-+
+--R                   (16x   + 16x  + 32x )\|2 \|3 \|7
+--R                 + 
+--R                          10         7         4 6+-+ +-+
+--R                   (16%i x   + 16%i x  + 32%i x )\|2 \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        10          7         4 6+-+ +-+
+--R               (- 48%i x   - 720%i x  - 96%i x )\|2 \|7
+--R             + 
+--R                      10       7       4 6+-+
+--R               (- 336x   + 336x  - 672x )\|2
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           7      4        6+-+4 +-+ +-+
+--R                       (60x  + 60x  + 120x)\|2  \|3 \|7
+--R                     + 
+--R                              7         4           6+-+4 +-+
+--R                       (60%i x  + 60%i x  + 120%i x)\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             7           4           6+-+4 +-+
+--R                   (- 180%i x  - 2700%i x  - 360%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 1260x  + 1260x  - 2520x)\|2
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          10       7       4 6+-+ +-+
+--R                   (- 144x   - 144x  - 288x )\|2 \|7
+--R                 + 
+--R                            10           7           4 6+-+
+--R                   (1008%i x   + 1008%i x  + 2016%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           7      4        6+-+4 +-+ +-+
+--R                       (80x  + 80x  + 160x)\|2  \|3 \|7
+--R                     + 
+--R                              7         4           6+-+4 +-+
+--R                       (80%i x  + 80%i x  + 160%i x)\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             7           4           6+-+4 +-+
+--R                   (- 240%i x  - 3600%i x  - 480%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 1680x  + 1680x  - 3360x)\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          10       7       4 6+-+ +-+
+--R                   (- 384x   - 384x  - 768x )\|2 \|7
+--R                 + 
+--R                            10           7           4 6+-+
+--R                   (2688%i x   + 2688%i x  + 5376%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       13      10      7 6+-+4 +-+ +-+
+--R                   (12x   + 12x   + 24x )\|2  \|3 \|7
+--R                 + 
+--R                          13         10         7 6+-+4 +-+
+--R                   (12%i x   + 12%i x   + 24%i x )\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        13          10         7 6+-+4 +-+
+--R               (- 36%i x   - 540%i x   - 72%i x )\|2  \|7
+--R             + 
+--R                      13       10       7 6+-+4
+--R               (- 252x   + 252x   - 504x )\|2
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                             10      7       4 6+-+ +-+ +-+
+--R                       (- 96x   - 96x  - 192x )\|2 \|3 \|7
+--R                     + 
+--R                                10         7          4 6+-+ +-+
+--R                       (- 96%i x   - 96%i x  - 192%i x )\|2 \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           10           7          4 6+-+ +-+
+--R                   (288%i x   + 4320%i x  + 576%i x )\|2 \|7
+--R                 + 
+--R                         10        7        4 6+-+
+--R                   (2016x   - 2016x  + 4032x )\|2
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          13       10       7 6+-+4 +-+
+--R                   (- 144x   - 144x   - 288x )\|2  \|7
+--R                 + 
+--R                            13           10           7 6+-+4
+--R                   (1008%i x   + 1008%i x   + 2016%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           7      4        6+-+4 +-+ +-+
+--R                       (60x  + 60x  + 120x)\|2  \|3 \|7
+--R                     + 
+--R                              7         4           6+-+4 +-+
+--R                       (60%i x  + 60%i x  + 120%i x)\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             7           4           6+-+4 +-+
+--R                   (- 180%i x  - 2700%i x  - 360%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 1260x  + 1260x  - 2520x)\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          10       7       4 6+-+ +-+
+--R                   (- 288x   - 288x  - 576x )\|2 \|7
+--R                 + 
+--R                            10           7           4 6+-+
+--R                   (2016%i x   + 2016%i x  + 4032%i x )\|2
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             13      10      7 6+-+4 +-+ +-+
+--R                       (- 36x   - 36x   - 72x )\|2  \|3 \|7
+--R                     + 
+--R                                13         10         7 6+-+4 +-+
+--R                       (- 36%i x   - 36%i x   - 72%i x )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           13           10          7 6+-+4 +-+
+--R                   (108%i x   + 1620%i x   + 216%i x )\|2  \|7
+--R                 + 
+--R                        13       10        7 6+-+4
+--R                   (756x   - 756x   + 1512x )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              10       7       4 6+-+ +-+ +-+
+--R                       (- 128x   - 128x  - 256x )\|2 \|3 \|7
+--R                     + 
+--R                                 10          7          4 6+-+ +-+
+--R                       (- 128%i x   - 128%i x  - 256%i x )\|2 \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           10           7          4 6+-+ +-+
+--R                   (384%i x   + 5760%i x  + 768%i x )\|2 \|7
+--R                 + 
+--R                         10        7        4 6+-+
+--R                   (2688x   - 2688x  + 5376x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        13       10       7 6+-+4 +-+
+--R                   (480x   + 480x   + 960x )\|2  \|7
+--R                 + 
+--R                              13           10           7 6+-+4
+--R                   (- 3360%i x   - 3360%i x   - 6720%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      16     13      10 6+-+ +-+ +-+
+--R                   (8x   + 8x   + 16x  )\|2 \|3 \|7
+--R                 + 
+--R                         16        13         10 6+-+ +-+
+--R                   (8%i x   + 8%i x   + 16%i x  )\|2 \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        16          13         10 6+-+ +-+
+--R               (- 24%i x   - 360%i x   - 48%i x  )\|2 \|7
+--R             + 
+--R                      16       13       10 6+-+
+--R               (- 168x   + 168x   - 336x  )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           7      4       6+-+4 +-+ +-+
+--R                       (24x  + 24x  + 48x)\|2  \|3 \|7
+--R                     + 
+--R                              7         4          6+-+4 +-+
+--R                       (24%i x  + 24%i x  + 48%i x)\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                            7           4           6+-+4 +-+
+--R                   (- 72%i x  - 1080%i x  - 144%i x)\|2  \|7
+--R                 + 
+--R                          7       4         6+-+4
+--R                   (- 504x  + 504x  - 1008x)\|2
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           13      10       7 6+-+4 +-+ +-+
+--R                       (84x   + 84x   + 168x )\|2  \|3 \|7
+--R                     + 
+--R                              13         10          7 6+-+4 +-+
+--R                       (84%i x   + 84%i x   + 168%i x )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             13           10          7 6+-+4 +-+
+--R                   (- 252%i x   - 3780%i x   - 504%i x )\|2  \|7
+--R                 + 
+--R                           13        10        7 6+-+4
+--R                   (- 1764x   + 1764x   - 3528x )\|2
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         16      13       10 6+-+ +-+
+--R                   (- 72x   - 72x   - 144x  )\|2 \|7
+--R                 + 
+--R                           16          13           10 6+-+
+--R                   (504%i x   + 504%i x   + 1008%i x  )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                             10      7      4 6+-+ +-+ +-+
+--R                       (- 48x   - 48x  - 96x )\|2 \|3 \|7
+--R                     + 
+--R                                10         7         4 6+-+ +-+
+--R                       (- 48%i x   - 48%i x  - 96%i x )\|2 \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           10           7          4 6+-+ +-+
+--R                   (144%i x   + 2160%i x  + 288%i x )\|2 \|7
+--R                 + 
+--R                         10        7        4 6+-+
+--R                   (1008x   - 1008x  + 2016x )\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          13       10       7 6+-+4 +-+
+--R                   (- 144x   - 144x   - 288x )\|2  \|7
+--R                 + 
+--R                            13           10           7 6+-+4
+--R                   (1008%i x   + 1008%i x   + 2016%i x )\|2
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             16      13      10 6+-+ +-+ +-+
+--R                       (- 24x   - 24x   - 48x  )\|2 \|3 \|7
+--R                     + 
+--R                                16         13         10 6+-+ +-+
+--R                       (- 24%i x   - 24%i x   - 48%i x  )\|2 \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                          16           13          10 6+-+ +-+
+--R                   (72%i x   + 1080%i x   + 144%i x  )\|2 \|7
+--R                 + 
+--R                        16       13        10 6+-+
+--R                   (504x   - 504x   + 1008x  )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7     4      6+-+4 +-+ +-+
+--R                   (4x  + 4x  + 8x)\|2  \|3 \|7
+--R                 + 
+--R                         7        4         6+-+4 +-+
+--R                   (4%i x  + 4%i x  + 8%i x)\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        7          4          6+-+4 +-+
+--R               (- 12%i x  - 180%i x  - 24%i x)\|2  \|7
+--R             + 
+--R                     7      4        6+-+4
+--R               (- 84x  + 84x  - 168x)\|2
+--R          *
+--R                 %pi 12
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   10      7      4 6+-+ +-+
+--R               (48x   + 48x  + 96x )\|2 \|7
+--R             + 
+--R                         10          7          4 6+-+
+--R               (- 336%i x   - 336%i x  - 672%i x )\|2
+--R          *
+--R                 %pi 9
+--R             cos(---)
+--R                  18
+--R         + 
+--R                      13     10     7 6+-+4 +-+ +-+
+--R                   (4x   + 4x   + 8x )\|2  \|3 \|7
+--R                 + 
+--R                         13        10        7 6+-+4 +-+
+--R                   (4%i x   + 4%i x   + 8%i x )\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        13          10         7 6+-+4 +-+
+--R               (- 12%i x   - 180%i x   - 24%i x )\|2  \|7
+--R             + 
+--R                     13      10       7 6+-+4
+--R               (- 84x   + 84x   - 168x )\|2
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   16      13      10 6+-+ +-+
+--R               (24x   + 24x   + 48x  )\|2 \|7
+--R             + 
+--R                         16          13          10 6+-+
+--R               (- 168%i x   - 168%i x   - 336%i x  )\|2
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                 19    16     13 6+-+4 +-+ +-+
+--R               (x   + x   + 2x  )\|2  \|3 \|7
+--R             + 
+--R                    19       16        13 6+-+4 +-+
+--R               (%i x   + %i x   + 2%i x  )\|2  \|3
+--R          *
+--R              +--+
+--R             \|21
+--R         + 
+--R                   19         16        13 6+-+4 +-+
+--R           (- 3%i x   - 45%i x   - 6%i x  )\|2  \|7
+--R         + 
+--R                 19      16      13 6+-+4
+--R           (- 21x   + 21x   - 42x  )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                   6 6+-+2    %pi 12       6 6+-+2    %pi 2    %pi 10
+--R               336x  \|2  sin(---)  + 2016x  \|2  cos(---) sin(---)
+--R                               18                      18       18
+--R             + 
+--R                   9 6+-+5    %pi 9
+--R               672x  \|2  sin(---)
+--R                               18
+--R             + 
+--R                        6 6+-+2    %pi 4
+--R                   5040x  \|2  cos(---)
+--R                                    18
+--R                 + 
+--R                          12       9       6 6+-+5 +-+    %pi
+--R                   (- 144x   - 144x  - 288x )\|2  \|7 cos(---)
+--R                                                           18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        6 6+-+2    %pi 6
+--R                   6720x  \|2  cos(---)
+--R                                    18
+--R                 + 
+--R                          12       9       6 6+-+5 +-+    %pi 3        12 6+-+2
+--R                   (- 384x   - 384x  - 768x )\|2  \|7 cos(---)  + 1008x   \|2
+--R                                                           18
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          9 6+-+5    %pi 4
+--R                   - 4032x  \|2  cos(---)
+--R                                      18
+--R                 + 
+--R                          15       12       9 6+-+2 +-+    %pi
+--R                   (- 288x   - 288x   - 576x )\|2  \|7 cos(---)
+--R                                                            18
+--R              *
+--R                     %pi 5
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        6 6+-+2    %pi 8
+--R                   5040x  \|2  cos(---)
+--R                                    18
+--R                 + 
+--R                          12       9       6 6+-+5 +-+    %pi 5
+--R                   (- 288x   - 288x  - 576x )\|2  \|7 cos(---)
+--R                                                           18
+--R                 + 
+--R                          12 6+-+2    %pi 2
+--R                   - 3024x   \|2  cos(---)
+--R                                       18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          9 6+-+5    %pi 6
+--R                   - 5376x  \|2  cos(---)
+--R                                      18
+--R                 + 
+--R                        15       12        9 6+-+2 +-+    %pi 3       15 6+-+5
+--R                   (960x   + 960x   + 1920x )\|2  \|7 cos(---)  + 336x   \|2
+--R                                                           18
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        6 6+-+2    %pi 10       12 6+-+2    %pi 4
+--R                   2016x  \|2  cos(---)  + 7056x   \|2  cos(---)
+--R                                    18                       18
+--R                 + 
+--R                         18      15       12 6+-+5 +-+    %pi
+--R                   (- 72x   - 72x   - 144x  )\|2  \|7 cos(---)
+--R                                                           18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          9 6+-+5    %pi 8
+--R                   - 2016x  \|2  cos(---)
+--R                                      18
+--R                 + 
+--R                          15       12       9 6+-+2 +-+    %pi 5
+--R                   (- 288x   - 288x   - 576x )\|2  \|7 cos(---)
+--R                                                            18
+--R                 + 
+--R                          15 6+-+5    %pi 2
+--R                   - 1008x   \|2  cos(---)
+--R                                       18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   6 6+-+2    %pi 12      12      9      6 6+-+5 +-+    %pi 9
+--R               336x  \|2  cos(---)  + (48x   + 48x  + 96x )\|2  \|7 cos(---)
+--R                               18                                        18
+--R             + 
+--R                   12 6+-+2    %pi 6      18      15      12 6+-+5 +-+    %pi 3
+--R               336x   \|2  cos(---) + (24x   + 24x   + 48x  )\|2  \|7 cos(---)
+--R                                18                                         18
+--R             + 
+--R                  18 6+-+2
+--R               84x   \|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                     7 6+-+4    %pi 12       7 6+-+4    %pi 2    %pi 10
+--R               - 336x  \|2  sin(---)  - 2016x  \|2  cos(---) sin(---)
+--R                                 18                      18       18
+--R             + 
+--R                      10 6+-+    %pi 9
+--R               - 1344x   \|2 sin(---)
+--R                                  18
+--R             + 
+--R                          7 6+-+4    %pi 4
+--R                   - 5040x  \|2  cos(---)
+--R                                      18
+--R                 + 
+--R                        13       10       7 6+-+ +-+    %pi
+--R                   (288x   + 288x   + 576x )\|2 \|7 cos(---)
+--R                                                         18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          7 6+-+4    %pi 6
+--R                   - 6720x  \|2  cos(---)
+--R                                      18
+--R                 + 
+--R                        13       10        7 6+-+ +-+    %pi 3        13 6+-+4
+--R                   (768x   + 768x   + 1536x )\|2 \|7 cos(---)  - 1008x   \|2
+--R                                                          18
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        10 6+-+    %pi 4
+--R                   8064x   \|2 cos(---)
+--R                                    18
+--R                 + 
+--R                        16       13       10 6+-+4 +-+    %pi
+--R                   (288x   + 288x   + 576x  )\|2  \|7 cos(---)
+--R                                                           18
+--R              *
+--R                     %pi 5
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          7 6+-+4    %pi 8
+--R                   - 5040x  \|2  cos(---)
+--R                                      18
+--R                 + 
+--R                        13       10        7 6+-+ +-+    %pi 5
+--R                   (576x   + 576x   + 1152x )\|2 \|7 cos(---)
+--R                                                          18
+--R                 + 
+--R                        13 6+-+4    %pi 2
+--R                   3024x   \|2  cos(---)
+--R                                     18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         10 6+-+    %pi 6
+--R                   10752x   \|2 cos(---)
+--R                                     18
+--R                 + 
+--R                          16       13        10 6+-+4 +-+    %pi 3       16 6+-+
+--R                   (- 960x   - 960x   - 1920x  )\|2  \|7 cos(---)  - 672x   \|2
+--R                                                              18
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          7 6+-+4    %pi 10       13 6+-+4    %pi 4
+--R                   - 2016x  \|2  cos(---)  - 7056x   \|2  cos(---)
+--R                                      18                       18
+--R                 + 
+--R                        19       16       13 6+-+ +-+    %pi
+--R                   (144x   + 144x   + 288x  )\|2 \|7 cos(---)
+--R                                                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        10 6+-+    %pi 8
+--R                   4032x   \|2 cos(---)
+--R                                    18
+--R                 + 
+--R                        16       13       10 6+-+4 +-+    %pi 5
+--R                   (288x   + 288x   + 576x  )\|2  \|7 cos(---)
+--R                                                           18
+--R                 + 
+--R                        16 6+-+    %pi 2
+--R                   2016x   \|2 cos(---)
+--R                                    18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     7 6+-+4    %pi 12
+--R               - 336x  \|2  cos(---)
+--R                                 18
+--R             + 
+--R                     13      10       7 6+-+ +-+    %pi 9       13 6+-+4    %pi 6
+--R               (- 96x   - 96x   - 192x )\|2 \|7 cos(---)  - 336x   \|2  cos(---)
+--R                                                     18                      18
+--R             + 
+--R                     19      16      13 6+-+ +-+    %pi 3      19 6+-+4
+--R               (- 48x   - 48x   - 96x  )\|2 \|7 cos(---)  - 84x   \|2
+--R                                                     18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                        8     5      2  +-+ +-+
+--R                   (- 8x  - 8x  - 16x )\|3 \|7
+--R                 + 
+--R                           8        5         2  +-+
+--R                   (- 8%i x  - 8%i x  - 16%i x )\|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      8          5         2  +-+       8       5       2
+--R               (24%i x  + 360%i x  + 48%i x )\|7  + 168x  - 168x  + 336x
+--R          *
+--R                 %pi 12
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         8      5      2  +-+ +-+
+--R                   (- 48x  - 48x  - 96x )\|3 \|7
+--R                 + 
+--R                            8         5         2  +-+
+--R                   (- 48%i x  - 48%i x  - 96%i x )\|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                       8           5          2  +-+        8        5        2
+--R               (144%i x  + 2160%i x  + 288%i x )\|7  + 1008x  - 1008x  + 2016x
+--R          *
+--R                 %pi 2    %pi 10
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                         11      8      5 6+-+3 +-+ +-+
+--R                   (- 16x   - 16x  - 32x )\|2  \|3 \|7
+--R                 + 
+--R                            11         8         5 6+-+3 +-+
+--R                   (- 16%i x   - 16%i x  - 32%i x )\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      11          8         5 6+-+3 +-+
+--R               (48%i x   + 720%i x  + 96%i x )\|2  \|7
+--R             + 
+--R                    11       8       5 6+-+3
+--R               (336x   - 336x  + 672x )\|2
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              8       5       2  +-+ +-+
+--R                       (- 120x  - 120x  - 240x )\|3 \|7
+--R                     + 
+--R                                 8          5          2  +-+
+--R                       (- 120%i x  - 120%i x  - 240%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           8           5          2  +-+        8        5
+--R                   (360%i x  + 5400%i x  + 720%i x )\|7  + 2520x  - 2520x
+--R                 + 
+--R                        2
+--R                   5040x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        11       8       5 6+-+3 +-+
+--R                   (144x   + 144x  + 288x )\|2  \|7
+--R                 + 
+--R                              11           8           5 6+-+3
+--R                   (- 1008%i x   - 1008%i x  - 2016%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              8       5       2  +-+ +-+
+--R                       (- 160x  - 160x  - 320x )\|3 \|7
+--R                     + 
+--R                                 8          5          2  +-+
+--R                       (- 160%i x  - 160%i x  - 320%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           8           5          2  +-+        8        5
+--R                   (480%i x  + 7200%i x  + 960%i x )\|7  + 3360x  - 3360x
+--R                 + 
+--R                        2
+--R                   6720x
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        11       8       5 6+-+3 +-+
+--R                   (384x   + 384x  + 768x )\|2  \|7
+--R                 + 
+--R                              11           8           5 6+-+3
+--R                   (- 2688%i x   - 2688%i x  - 5376%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         14      11      8  +-+ +-+
+--R                   (- 24x   - 24x   - 48x )\|3 \|7
+--R                 + 
+--R                            14         11         8  +-+
+--R                   (- 24%i x   - 24%i x   - 48%i x )\|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                    14           11          8  +-+       14       11        8
+--R             (72%i x   + 1080%i x   + 144%i x )\|7  + 504x   - 504x   + 1008x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           11      8       5 6+-+3 +-+ +-+
+--R                       (96x   + 96x  + 192x )\|2  \|3 \|7
+--R                     + 
+--R                              11         8          5 6+-+3 +-+
+--R                       (96%i x   + 96%i x  + 192%i x )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             11           8          5 6+-+3 +-+
+--R                   (- 288%i x   - 4320%i x  - 576%i x )\|2  \|7
+--R                 + 
+--R                           11        8        5 6+-+3
+--R                   (- 2016x   + 2016x  - 4032x )\|2
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        14       11       8  +-+           14           11
+--R                   (288x   + 288x   + 576x )\|7  - 2016%i x   - 2016%i x
+--R                 + 
+--R                             8
+--R                   - 4032%i x
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              8       5       2  +-+ +-+
+--R                       (- 120x  - 120x  - 240x )\|3 \|7
+--R                     + 
+--R                                 8          5          2  +-+
+--R                       (- 120%i x  - 120%i x  - 240%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           8           5          2  +-+        8        5
+--R                   (360%i x  + 5400%i x  + 720%i x )\|7  + 2520x  - 2520x
+--R                 + 
+--R                        2
+--R                   5040x
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        11       8       5 6+-+3 +-+
+--R                   (288x   + 288x  + 576x )\|2  \|7
+--R                 + 
+--R                              11           8           5 6+-+3
+--R                   (- 2016%i x   - 2016%i x  - 4032%i x )\|2
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           14      11       8  +-+ +-+
+--R                       (72x   + 72x   + 144x )\|3 \|7
+--R                     + 
+--R                              14         11          8  +-+
+--R                       (72%i x   + 72%i x   + 144%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             14           11          8  +-+        14        11
+--R                   (- 216%i x   - 3240%i x   - 432%i x )\|7  - 1512x   + 1512x
+--R                 + 
+--R                          8
+--R                   - 3024x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                            11       8       5 6+-+3 +-+ +-+
+--R                       (128x   + 128x  + 256x )\|2  \|3 \|7
+--R                     + 
+--R                               11          8          5 6+-+3 +-+
+--R                       (128%i x   + 128%i x  + 256%i x )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             11           8          5 6+-+3 +-+
+--R                   (- 384%i x   - 5760%i x  - 768%i x )\|2  \|7
+--R                 + 
+--R                           11        8        5 6+-+3
+--R                   (- 2688x   + 2688x  - 5376x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          14       11        8  +-+           14           11
+--R                   (- 960x   - 960x   - 1920x )\|7  + 6720%i x   + 6720%i x
+--R                 + 
+--R                            8
+--R                   13440%i x
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        17     14      11 6+-+3 +-+ +-+
+--R                   (- 8x   - 8x   - 16x  )\|2  \|3 \|7
+--R                 + 
+--R                           17        14         11 6+-+3 +-+
+--R                   (- 8%i x   - 8%i x   - 16%i x  )\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      17          14         11 6+-+3 +-+
+--R               (24%i x   + 360%i x   + 48%i x  )\|2  \|7
+--R             + 
+--R                    17       14       11 6+-+3
+--R               (168x   - 168x   + 336x  )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                             8      5      2  +-+ +-+
+--R                       (- 48x  - 48x  - 96x )\|3 \|7
+--R                     + 
+--R                                8         5         2  +-+
+--R                       (- 48%i x  - 48%i x  - 96%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           8           5          2  +-+        8        5
+--R                   (144%i x  + 2160%i x  + 288%i x )\|7  + 1008x  - 1008x
+--R                 + 
+--R                        2
+--R                   2016x
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                              14       11       8  +-+ +-+
+--R                       (- 168x   - 168x   - 336x )\|3 \|7
+--R                     + 
+--R                                 14          11          8  +-+
+--R                       (- 168%i x   - 168%i x   - 336%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           14           11           8  +-+        14        11
+--R                   (504%i x   + 7560%i x   + 1008%i x )\|7  + 3528x   - 3528x
+--R                 + 
+--R                        8
+--R                   7056x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       17      14       11 6+-+3 +-+
+--R                   (72x   + 72x   + 144x  )\|2  \|7
+--R                 + 
+--R                             17          14           11 6+-+3
+--R                   (- 504%i x   - 504%i x   - 1008%i x  )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           11      8      5 6+-+3 +-+ +-+
+--R                       (48x   + 48x  + 96x )\|2  \|3 \|7
+--R                     + 
+--R                              11         8         5 6+-+3 +-+
+--R                       (48%i x   + 48%i x  + 96%i x )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             11           8          5 6+-+3 +-+
+--R                   (- 144%i x   - 2160%i x  - 288%i x )\|2  \|7
+--R                 + 
+--R                           11        8        5 6+-+3
+--R                   (- 1008x   + 1008x  - 2016x )\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        14       11       8  +-+           14           11
+--R                   (288x   + 288x   + 576x )\|7  - 2016%i x   - 2016%i x
+--R                 + 
+--R                             8
+--R                   - 4032%i x
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           17      14      11 6+-+3 +-+ +-+
+--R                       (24x   + 24x   + 48x  )\|2  \|3 \|7
+--R                     + 
+--R                              17         14         11 6+-+3 +-+
+--R                       (24%i x   + 24%i x   + 48%i x  )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                            17           14          11 6+-+3 +-+
+--R                   (- 72%i x   - 1080%i x   - 144%i x  )\|2  \|7
+--R                 + 
+--R                          17       14        11 6+-+3
+--R                   (- 504x   + 504x   - 1008x  )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        8     5      2  +-+ +-+
+--R                   (- 8x  - 8x  - 16x )\|3 \|7
+--R                 + 
+--R                           8        5         2  +-+
+--R                   (- 8%i x  - 8%i x  - 16%i x )\|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      8          5         2  +-+       8       5       2
+--R               (24%i x  + 360%i x  + 48%i x )\|7  + 168x  - 168x  + 336x
+--R          *
+--R                 %pi 12
+--R             cos(---)
+--R                  18
+--R         + 
+--R                     11      8      5 6+-+3 +-+
+--R               (- 48x   - 48x  - 96x )\|2  \|7
+--R             + 
+--R                       11          8          5 6+-+3
+--R               (336%i x   + 336%i x  + 672%i x )\|2
+--R          *
+--R                 %pi 9
+--R             cos(---)
+--R                  18
+--R         + 
+--R                        14     11      8  +-+ +-+
+--R                   (- 8x   - 8x   - 16x )\|3 \|7
+--R                 + 
+--R                           14        11         8  +-+
+--R                   (- 8%i x   - 8%i x   - 16%i x )\|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      14          11         8  +-+       14       11       8
+--R               (24%i x   + 360%i x   + 48%i x )\|7  + 168x   - 168x   + 336x
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                     17      14      11 6+-+3 +-+
+--R               (- 24x   - 24x   - 48x  )\|2  \|7
+--R             + 
+--R                       17          14          11 6+-+3
+--R               (168%i x   + 168%i x   + 336%i x  )\|2
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                    20     17     14  +-+ +-+
+--R               (- 2x   - 2x   - 4x  )\|3 \|7
+--R             + 
+--R                       20        17        14  +-+
+--R               (- 2%i x   - 2%i x   - 4%i x  )\|3
+--R          *
+--R              +--+
+--R             \|21
+--R         + 
+--R                 20         17         14  +-+      20      17      14
+--R           (6%i x   + 90%i x   + 12%i x  )\|7  + 42x   - 42x   + 84x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                      7     4      6+-+4 +-+ +-+
+--R                   (4x  + 4x  + 8x)\|2  \|3 \|7
+--R                 + 
+--R                           7        4         6+-+4 +-+
+--R                   (- 4%i x  - 4%i x  - 8%i x)\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      7          4          6+-+4 +-+
+--R               (12%i x  + 180%i x  + 24%i x)\|2  \|7
+--R             + 
+--R                     7      4        6+-+4
+--R               (- 84x  + 84x  - 168x)\|2
+--R          *
+--R                 %pi 12
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7      4       6+-+4 +-+ +-+
+--R                   (24x  + 24x  + 48x)\|2  \|3 \|7
+--R                 + 
+--R                            7         4          6+-+4 +-+
+--R                   (- 24%i x  - 24%i x  - 48%i x)\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      7           4           6+-+4 +-+
+--R               (72%i x  + 1080%i x  + 144%i x)\|2  \|7
+--R             + 
+--R                      7       4         6+-+4
+--R               (- 504x  + 504x  - 1008x)\|2
+--R          *
+--R                 %pi 2    %pi 10
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                       10      7      4 6+-+ +-+ +-+
+--R                   (16x   + 16x  + 32x )\|2 \|3 \|7
+--R                 + 
+--R                            10         7         4 6+-+ +-+
+--R                   (- 16%i x   - 16%i x  - 32%i x )\|2 \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      10          7         4 6+-+ +-+
+--R               (48%i x   + 720%i x  + 96%i x )\|2 \|7
+--R             + 
+--R                      10       7       4 6+-+
+--R               (- 336x   + 336x  - 672x )\|2
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           7      4        6+-+4 +-+ +-+
+--R                       (60x  + 60x  + 120x)\|2  \|3 \|7
+--R                     + 
+--R                                7         4           6+-+4 +-+
+--R                       (- 60%i x  - 60%i x  - 120%i x)\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           7           4           6+-+4 +-+
+--R                   (180%i x  + 2700%i x  + 360%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 1260x  + 1260x  - 2520x)\|2
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          10       7       4 6+-+ +-+
+--R                   (- 144x   - 144x  - 288x )\|2 \|7
+--R                 + 
+--R                              10           7           4 6+-+
+--R                   (- 1008%i x   - 1008%i x  - 2016%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           7      4        6+-+4 +-+ +-+
+--R                       (80x  + 80x  + 160x)\|2  \|3 \|7
+--R                     + 
+--R                                7         4           6+-+4 +-+
+--R                       (- 80%i x  - 80%i x  - 160%i x)\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           7           4           6+-+4 +-+
+--R                   (240%i x  + 3600%i x  + 480%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 1680x  + 1680x  - 3360x)\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          10       7       4 6+-+ +-+
+--R                   (- 384x   - 384x  - 768x )\|2 \|7
+--R                 + 
+--R                              10           7           4 6+-+
+--R                   (- 2688%i x   - 2688%i x  - 5376%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       13      10      7 6+-+4 +-+ +-+
+--R                   (12x   + 12x   + 24x )\|2  \|3 \|7
+--R                 + 
+--R                            13         10         7 6+-+4 +-+
+--R                   (- 12%i x   - 12%i x   - 24%i x )\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      13          10         7 6+-+4 +-+
+--R               (36%i x   + 540%i x   + 72%i x )\|2  \|7
+--R             + 
+--R                      13       10       7 6+-+4
+--R               (- 252x   + 252x   - 504x )\|2
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                             10      7       4 6+-+ +-+ +-+
+--R                       (- 96x   - 96x  - 192x )\|2 \|3 \|7
+--R                     + 
+--R                              10         7          4 6+-+ +-+
+--R                       (96%i x   + 96%i x  + 192%i x )\|2 \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             10           7          4 6+-+ +-+
+--R                   (- 288%i x   - 4320%i x  - 576%i x )\|2 \|7
+--R                 + 
+--R                         10        7        4 6+-+
+--R                   (2016x   - 2016x  + 4032x )\|2
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          13       10       7 6+-+4 +-+
+--R                   (- 144x   - 144x   - 288x )\|2  \|7
+--R                 + 
+--R                              13           10           7 6+-+4
+--R                   (- 1008%i x   - 1008%i x   - 2016%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           7      4        6+-+4 +-+ +-+
+--R                       (60x  + 60x  + 120x)\|2  \|3 \|7
+--R                     + 
+--R                                7         4           6+-+4 +-+
+--R                       (- 60%i x  - 60%i x  - 120%i x)\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           7           4           6+-+4 +-+
+--R                   (180%i x  + 2700%i x  + 360%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 1260x  + 1260x  - 2520x)\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          10       7       4 6+-+ +-+
+--R                   (- 288x   - 288x  - 576x )\|2 \|7
+--R                 + 
+--R                              10           7           4 6+-+
+--R                   (- 2016%i x   - 2016%i x  - 4032%i x )\|2
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             13      10      7 6+-+4 +-+ +-+
+--R                       (- 36x   - 36x   - 72x )\|2  \|3 \|7
+--R                     + 
+--R                              13         10         7 6+-+4 +-+
+--R                       (36%i x   + 36%i x   + 72%i x )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             13           10          7 6+-+4 +-+
+--R                   (- 108%i x   - 1620%i x   - 216%i x )\|2  \|7
+--R                 + 
+--R                        13       10        7 6+-+4
+--R                   (756x   - 756x   + 1512x )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              10       7       4 6+-+ +-+ +-+
+--R                       (- 128x   - 128x  - 256x )\|2 \|3 \|7
+--R                     + 
+--R                               10          7          4 6+-+ +-+
+--R                       (128%i x   + 128%i x  + 256%i x )\|2 \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             10           7          4 6+-+ +-+
+--R                   (- 384%i x   - 5760%i x  - 768%i x )\|2 \|7
+--R                 + 
+--R                         10        7        4 6+-+
+--R                   (2688x   - 2688x  + 5376x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        13       10       7 6+-+4 +-+
+--R                   (480x   + 480x   + 960x )\|2  \|7
+--R                 + 
+--R                            13           10           7 6+-+4
+--R                   (3360%i x   + 3360%i x   + 6720%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      16     13      10 6+-+ +-+ +-+
+--R                   (8x   + 8x   + 16x  )\|2 \|3 \|7
+--R                 + 
+--R                           16        13         10 6+-+ +-+
+--R                   (- 8%i x   - 8%i x   - 16%i x  )\|2 \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      16          13         10 6+-+ +-+
+--R               (24%i x   + 360%i x   + 48%i x  )\|2 \|7
+--R             + 
+--R                      16       13       10 6+-+
+--R               (- 168x   + 168x   - 336x  )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           7      4       6+-+4 +-+ +-+
+--R                       (24x  + 24x  + 48x)\|2  \|3 \|7
+--R                     + 
+--R                                7         4          6+-+4 +-+
+--R                       (- 24%i x  - 24%i x  - 48%i x)\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                          7           4           6+-+4 +-+
+--R                   (72%i x  + 1080%i x  + 144%i x)\|2  \|7
+--R                 + 
+--R                          7       4         6+-+4
+--R                   (- 504x  + 504x  - 1008x)\|2
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           13      10       7 6+-+4 +-+ +-+
+--R                       (84x   + 84x   + 168x )\|2  \|3 \|7
+--R                     + 
+--R                                13         10          7 6+-+4 +-+
+--R                       (- 84%i x   - 84%i x   - 168%i x )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           13           10          7 6+-+4 +-+
+--R                   (252%i x   + 3780%i x   + 504%i x )\|2  \|7
+--R                 + 
+--R                           13        10        7 6+-+4
+--R                   (- 1764x   + 1764x   - 3528x )\|2
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         16      13       10 6+-+ +-+
+--R                   (- 72x   - 72x   - 144x  )\|2 \|7
+--R                 + 
+--R                             16          13           10 6+-+
+--R                   (- 504%i x   - 504%i x   - 1008%i x  )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                             10      7      4 6+-+ +-+ +-+
+--R                       (- 48x   - 48x  - 96x )\|2 \|3 \|7
+--R                     + 
+--R                              10         7         4 6+-+ +-+
+--R                       (48%i x   + 48%i x  + 96%i x )\|2 \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             10           7          4 6+-+ +-+
+--R                   (- 144%i x   - 2160%i x  - 288%i x )\|2 \|7
+--R                 + 
+--R                         10        7        4 6+-+
+--R                   (1008x   - 1008x  + 2016x )\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          13       10       7 6+-+4 +-+
+--R                   (- 144x   - 144x   - 288x )\|2  \|7
+--R                 + 
+--R                              13           10           7 6+-+4
+--R                   (- 1008%i x   - 1008%i x   - 2016%i x )\|2
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             16      13      10 6+-+ +-+ +-+
+--R                       (- 24x   - 24x   - 48x  )\|2 \|3 \|7
+--R                     + 
+--R                              16         13         10 6+-+ +-+
+--R                       (24%i x   + 24%i x   + 48%i x  )\|2 \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                            16           13          10 6+-+ +-+
+--R                   (- 72%i x   - 1080%i x   - 144%i x  )\|2 \|7
+--R                 + 
+--R                        16       13        10 6+-+
+--R                   (504x   - 504x   + 1008x  )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7     4      6+-+4 +-+ +-+
+--R                   (4x  + 4x  + 8x)\|2  \|3 \|7
+--R                 + 
+--R                           7        4         6+-+4 +-+
+--R                   (- 4%i x  - 4%i x  - 8%i x)\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      7          4          6+-+4 +-+
+--R               (12%i x  + 180%i x  + 24%i x)\|2  \|7
+--R             + 
+--R                     7      4        6+-+4
+--R               (- 84x  + 84x  - 168x)\|2
+--R          *
+--R                 %pi 12
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   10      7      4 6+-+ +-+
+--R               (48x   + 48x  + 96x )\|2 \|7
+--R             + 
+--R                       10          7          4 6+-+
+--R               (336%i x   + 336%i x  + 672%i x )\|2
+--R          *
+--R                 %pi 9
+--R             cos(---)
+--R                  18
+--R         + 
+--R                      13     10     7 6+-+4 +-+ +-+
+--R                   (4x   + 4x   + 8x )\|2  \|3 \|7
+--R                 + 
+--R                           13        10        7 6+-+4 +-+
+--R                   (- 4%i x   - 4%i x   - 8%i x )\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      13          10         7 6+-+4 +-+
+--R               (12%i x   + 180%i x   + 24%i x )\|2  \|7
+--R             + 
+--R                     13      10       7 6+-+4
+--R               (- 84x   + 84x   - 168x )\|2
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   16      13      10 6+-+ +-+
+--R               (24x   + 24x   + 48x  )\|2 \|7
+--R             + 
+--R                       16          13          10 6+-+
+--R               (168%i x   + 168%i x   + 336%i x  )\|2
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                 19    16     13 6+-+4 +-+ +-+
+--R               (x   + x   + 2x  )\|2  \|3 \|7
+--R             + 
+--R                      19       16        13 6+-+4 +-+
+--R               (- %i x   - %i x   - 2%i x  )\|2  \|3
+--R          *
+--R              +--+
+--R             \|21
+--R         + 
+--R                 19         16        13 6+-+4 +-+
+--R           (3%i x   + 45%i x   + 6%i x  )\|2  \|7
+--R         + 
+--R                 19      16      13 6+-+4
+--R           (- 21x   + 21x   - 42x  )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|7  + 1
+--R     + 
+--R                          8     5      2  +-+ +-+
+--R                     (- 8x  - 8x  - 16x )\|3 \|7
+--R                   + 
+--R                           8        5         2  +-+
+--R                     (8%i x  + 8%i x  + 16%i x )\|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        8          5         2  +-+       8       5       2
+--R               (- 24%i x  - 360%i x  - 48%i x )\|7  + 168x  - 168x  + 336x
+--R          *
+--R                 %pi 12
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         8      5      2  +-+ +-+
+--R                   (- 48x  - 48x  - 96x )\|3 \|7
+--R                 + 
+--R                          8         5         2  +-+
+--R                   (48%i x  + 48%i x  + 96%i x )\|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                       8           5          2  +-+        8        5        2
+--R             (- 144%i x  - 2160%i x  - 288%i x )\|7  + 1008x  - 1008x  + 2016x
+--R          *
+--R                 %pi 2    %pi 10
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                         11      8      5 6+-+3 +-+ +-+
+--R                   (- 16x   - 16x  - 32x )\|2  \|3 \|7
+--R                 + 
+--R                          11         8         5 6+-+3 +-+
+--R                   (16%i x   + 16%i x  + 32%i x )\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        11          8         5 6+-+3 +-+
+--R               (- 48%i x   - 720%i x  - 96%i x )\|2  \|7
+--R             + 
+--R                    11       8       5 6+-+3
+--R               (336x   - 336x  + 672x )\|2
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              8       5       2  +-+ +-+
+--R                       (- 120x  - 120x  - 240x )\|3 \|7
+--R                     + 
+--R                               8          5          2  +-+
+--R                       (120%i x  + 120%i x  + 240%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             8           5          2  +-+        8        5
+--R                   (- 360%i x  - 5400%i x  - 720%i x )\|7  + 2520x  - 2520x
+--R                 + 
+--R                        2
+--R                   5040x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        11       8       5 6+-+3 +-+
+--R                   (144x   + 144x  + 288x )\|2  \|7
+--R                 + 
+--R                            11           8           5 6+-+3
+--R                   (1008%i x   + 1008%i x  + 2016%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              8       5       2  +-+ +-+
+--R                       (- 160x  - 160x  - 320x )\|3 \|7
+--R                     + 
+--R                               8          5          2  +-+
+--R                       (160%i x  + 160%i x  + 320%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             8           5          2  +-+        8        5
+--R                   (- 480%i x  - 7200%i x  - 960%i x )\|7  + 3360x  - 3360x
+--R                 + 
+--R                        2
+--R                   6720x
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        11       8       5 6+-+3 +-+
+--R                   (384x   + 384x  + 768x )\|2  \|7
+--R                 + 
+--R                            11           8           5 6+-+3
+--R                   (2688%i x   + 2688%i x  + 5376%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         14      11      8  +-+ +-+
+--R                   (- 24x   - 24x   - 48x )\|3 \|7
+--R                 + 
+--R                          14         11         8  +-+
+--R                   (24%i x   + 24%i x   + 48%i x )\|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                      14           11          8  +-+       14       11        8
+--R             (- 72%i x   - 1080%i x   - 144%i x )\|7  + 504x   - 504x   + 1008x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           11      8       5 6+-+3 +-+ +-+
+--R                       (96x   + 96x  + 192x )\|2  \|3 \|7
+--R                     + 
+--R                                11         8          5 6+-+3 +-+
+--R                       (- 96%i x   - 96%i x  - 192%i x )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           11           8          5 6+-+3 +-+
+--R                   (288%i x   + 4320%i x  + 576%i x )\|2  \|7
+--R                 + 
+--R                           11        8        5 6+-+3
+--R                   (- 2016x   + 2016x  - 4032x )\|2
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        14       11       8  +-+           14           11
+--R                   (288x   + 288x   + 576x )\|7  + 2016%i x   + 2016%i x
+--R                 + 
+--R                           8
+--R                   4032%i x
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              8       5       2  +-+ +-+
+--R                       (- 120x  - 120x  - 240x )\|3 \|7
+--R                     + 
+--R                               8          5          2  +-+
+--R                       (120%i x  + 120%i x  + 240%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             8           5          2  +-+        8        5
+--R                   (- 360%i x  - 5400%i x  - 720%i x )\|7  + 2520x  - 2520x
+--R                 + 
+--R                        2
+--R                   5040x
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        11       8       5 6+-+3 +-+
+--R                   (288x   + 288x  + 576x )\|2  \|7
+--R                 + 
+--R                            11           8           5 6+-+3
+--R                   (2016%i x   + 2016%i x  + 4032%i x )\|2
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           14      11       8  +-+ +-+
+--R                       (72x   + 72x   + 144x )\|3 \|7
+--R                     + 
+--R                                14         11          8  +-+
+--R                       (- 72%i x   - 72%i x   - 144%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           14           11          8  +-+        14        11
+--R                   (216%i x   + 3240%i x   + 432%i x )\|7  - 1512x   + 1512x
+--R                 + 
+--R                          8
+--R                   - 3024x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                            11       8       5 6+-+3 +-+ +-+
+--R                       (128x   + 128x  + 256x )\|2  \|3 \|7
+--R                     + 
+--R                                 11          8          5 6+-+3 +-+
+--R                       (- 128%i x   - 128%i x  - 256%i x )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           11           8          5 6+-+3 +-+
+--R                   (384%i x   + 5760%i x  + 768%i x )\|2  \|7
+--R                 + 
+--R                           11        8        5 6+-+3
+--R                   (- 2688x   + 2688x  - 5376x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          14       11        8  +-+           14           11
+--R                   (- 960x   - 960x   - 1920x )\|7  - 6720%i x   - 6720%i x
+--R                 + 
+--R                              8
+--R                   - 13440%i x
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        17     14      11 6+-+3 +-+ +-+
+--R                   (- 8x   - 8x   - 16x  )\|2  \|3 \|7
+--R                 + 
+--R                         17        14         11 6+-+3 +-+
+--R                   (8%i x   + 8%i x   + 16%i x  )\|2  \|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        17          14         11 6+-+3 +-+
+--R               (- 24%i x   - 360%i x   - 48%i x  )\|2  \|7
+--R             + 
+--R                    17       14       11 6+-+3
+--R               (168x   - 168x   + 336x  )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                             8      5      2  +-+ +-+
+--R                       (- 48x  - 48x  - 96x )\|3 \|7
+--R                     + 
+--R                              8         5         2  +-+
+--R                       (48%i x  + 48%i x  + 96%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             8           5          2  +-+        8        5
+--R                   (- 144%i x  - 2160%i x  - 288%i x )\|7  + 1008x  - 1008x
+--R                 + 
+--R                        2
+--R                   2016x
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                              14       11       8  +-+ +-+
+--R                       (- 168x   - 168x   - 336x )\|3 \|7
+--R                     + 
+--R                               14          11          8  +-+
+--R                       (168%i x   + 168%i x   + 336%i x )\|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                             14           11           8  +-+        14
+--R                   (- 504%i x   - 7560%i x   - 1008%i x )\|7  + 3528x
+--R                 + 
+--R                          11        8
+--R                   - 3528x   + 7056x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       17      14       11 6+-+3 +-+
+--R                   (72x   + 72x   + 144x  )\|2  \|7
+--R                 + 
+--R                           17          14           11 6+-+3
+--R                   (504%i x   + 504%i x   + 1008%i x  )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           11      8      5 6+-+3 +-+ +-+
+--R                       (48x   + 48x  + 96x )\|2  \|3 \|7
+--R                     + 
+--R                                11         8         5 6+-+3 +-+
+--R                       (- 48%i x   - 48%i x  - 96%i x )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                           11           8          5 6+-+3 +-+
+--R                   (144%i x   + 2160%i x  + 288%i x )\|2  \|7
+--R                 + 
+--R                           11        8        5 6+-+3
+--R                   (- 1008x   + 1008x  - 2016x )\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        14       11       8  +-+           14           11
+--R                   (288x   + 288x   + 576x )\|7  + 2016%i x   + 2016%i x
+--R                 + 
+--R                           8
+--R                   4032%i x
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           17      14      11 6+-+3 +-+ +-+
+--R                       (24x   + 24x   + 48x  )\|2  \|3 \|7
+--R                     + 
+--R                                17         14         11 6+-+3 +-+
+--R                       (- 24%i x   - 24%i x   - 48%i x  )\|2  \|3
+--R                  *
+--R                      +--+
+--R                     \|21
+--R                 + 
+--R                          17           14          11 6+-+3 +-+
+--R                   (72%i x   + 1080%i x   + 144%i x  )\|2  \|7
+--R                 + 
+--R                          17       14        11 6+-+3
+--R                   (- 504x   + 504x   - 1008x  )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          8     5      2  +-+ +-+
+--R                     (- 8x  - 8x  - 16x )\|3 \|7
+--R                   + 
+--R                           8        5         2  +-+
+--R                     (8%i x  + 8%i x  + 16%i x )\|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        8          5         2  +-+       8       5       2
+--R               (- 24%i x  - 360%i x  - 48%i x )\|7  + 168x  - 168x  + 336x
+--R          *
+--R                 %pi 12
+--R             cos(---)
+--R                  18
+--R         + 
+--R                     11      8      5 6+-+3 +-+
+--R               (- 48x   - 48x  - 96x )\|2  \|7
+--R             + 
+--R                         11          8          5 6+-+3
+--R               (- 336%i x   - 336%i x  - 672%i x )\|2
+--R          *
+--R                 %pi 9
+--R             cos(---)
+--R                  18
+--R         + 
+--R                        14     11      8  +-+ +-+
+--R                   (- 8x   - 8x   - 16x )\|3 \|7
+--R                 + 
+--R                         14        11         8  +-+
+--R                   (8%i x   + 8%i x   + 16%i x )\|3
+--R              *
+--R                  +--+
+--R                 \|21
+--R             + 
+--R                        14          11         8  +-+       14       11       8
+--R               (- 24%i x   - 360%i x   - 48%i x )\|7  + 168x   - 168x   + 336x
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                     17      14      11 6+-+3 +-+
+--R               (- 24x   - 24x   - 48x  )\|2  \|7
+--R             + 
+--R                         17          14          11 6+-+3
+--R               (- 168%i x   - 168%i x   - 336%i x  )\|2
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                      20     17     14  +-+ +-+
+--R                 (- 2x   - 2x   - 4x  )\|3 \|7
+--R               + 
+--R                       20        17        14  +-+
+--R                 (2%i x   + 2%i x   + 4%i x  )\|3
+--R          *
+--R              +--+
+--R             \|21
+--R         + 
+--R                   20         17         14  +-+      20      17      14
+--R           (- 6%i x   - 90%i x   - 12%i x  )\|7  + 42x   - 42x   + 84x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|7  + 1
+--R     + 
+--R              3 6+-+2    %pi 12       3 6+-+2    %pi 2    %pi 10
+--R       - 1344x  \|2  sin(---)  - 8064x  \|2  cos(---) sin(---)
+--R                          18                      18       18
+--R     + 
+--R              6 6+-+5    %pi 9
+--R       - 2688x  \|2  sin(---)
+--R                          18
+--R     + 
+--R                  3 6+-+2    %pi 4       9       6        3 6+-+5 +-+    %pi
+--R         (- 20160x  \|2  cos(---) + (576x  + 576x  + 1152x )\|2  \|7 cos(---))
+--R                              18                                          18
+--R      *
+--R             %pi 8
+--R         sin(---)
+--R              18
+--R     + 
+--R                   3 6+-+2    %pi 6
+--R           - 26880x  \|2  cos(---)
+--R                               18
+--R         + 
+--R                 9        6        3 6+-+5 +-+    %pi 3        9 6+-+2
+--R           (1536x  + 1536x  + 3072x )\|2  \|7 cos(---)  - 4032x  \|2
+--R                                                   18
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R                6 6+-+5    %pi 4        12        9        6 6+-+2 +-+    %pi
+--R         (16128x  \|2  cos(---) + (1152x   + 1152x  + 2304x )\|2  \|7 cos(---))
+--R                            18                                             18
+--R      *
+--R             %pi 5
+--R         sin(---)
+--R              18
+--R     + 
+--R                   3 6+-+2    %pi 8
+--R           - 20160x  \|2  cos(---)
+--R                               18
+--R         + 
+--R                 9        6        3 6+-+5 +-+    %pi 5         9 6+-+2    %pi 2
+--R           (1152x  + 1152x  + 2304x )\|2  \|7 cos(---)  + 12096x  \|2  cos(---)
+--R                                                   18                       18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R                 6 6+-+5    %pi 6
+--R           21504x  \|2  cos(---)
+--R                             18
+--R         + 
+--R                   12        9        6 6+-+2 +-+    %pi 3        12 6+-+5
+--R           (- 3840x   - 3840x  - 7680x )\|2  \|7 cos(---)  - 1344x   \|2
+--R                                                      18
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              18
+--R     + 
+--R                  3 6+-+2    %pi 10        9 6+-+2    %pi 4
+--R           - 8064x  \|2  cos(---)  - 28224x  \|2  cos(---)
+--R                              18                       18
+--R         + 
+--R                15       12       9 6+-+5 +-+    %pi
+--R           (288x   + 288x   + 576x )\|2  \|7 cos(---)
+--R                                                  18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R                6 6+-+5    %pi 8        12        9        6 6+-+2 +-+    %pi 5
+--R           8064x  \|2  cos(---) + (1152x   + 1152x  + 2304x )\|2  \|7 cos(---)
+--R                            18                                             18
+--R         + 
+--R                12 6+-+5    %pi 2
+--R           4032x   \|2  cos(---)
+--R                             18
+--R      *
+--R             %pi
+--R         sin(---)
+--R              18
+--R     + 
+--R              3 6+-+2    %pi 12         9       6       3 6+-+5 +-+    %pi 9
+--R       - 1344x  \|2  cos(---)  + (- 192x  - 192x  - 384x )\|2  \|7 cos(---)
+--R                          18                                            18
+--R     + 
+--R              9 6+-+2    %pi 6        15      12       9 6+-+5 +-+    %pi 3
+--R       - 1344x  \|2  cos(---) + (- 96x   - 96x   - 192x )\|2  \|7 cos(---)
+--R                          18                                           18
+--R     + 
+--R             15 6+-+2
+--R       - 336x   \|2
+--R  /
+--R                    8       5       2     %pi 12
+--R               (336x  + 336x  + 672x )sin(---)
+--R                                           18
+--R             + 
+--R                     8        5        2     %pi 2    %pi 10
+--R               (2016x  + 2016x  + 4032x )cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                    11       8        5 6+-+3    %pi 9
+--R               (672x   + 672x  + 1344x )\|2  sin(---)
+--R                                                  18
+--R             + 
+--R                     8        5         2     %pi 4    %pi 8
+--R               (5040x  + 5040x  + 10080x )cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                         8        5         2     %pi 6        14        11
+--R                   (6720x  + 6720x  + 13440x )cos(---)  + 1008x   + 1008x
+--R                                                   18
+--R                 + 
+--R                        8
+--R                   2016x
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       11        8        5 6+-+3    %pi 4    %pi 5
+--R               (- 4032x   - 4032x  - 8064x )\|2  cos(---) sin(---)
+--R                                                      18       18
+--R             + 
+--R                         8        5         2     %pi 8
+--R                   (5040x  + 5040x  + 10080x )cos(---)
+--R                                                   18
+--R                 + 
+--R                           14        11        8     %pi 2
+--R                   (- 3024x   - 3024x   - 6048x )cos(---)
+--R                                                      18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           11        8         5 6+-+3    %pi 6
+--R                   (- 5376x   - 5376x  - 10752x )\|2  cos(---)
+--R                                                           18
+--R                 + 
+--R                        17       14       11 6+-+3
+--R                   (336x   + 336x   + 672x  )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         8        5        2     %pi 10
+--R                   (2016x  + 2016x  + 4032x )cos(---)
+--R                                                  18
+--R                 + 
+--R                         14        11         8     %pi 4
+--R                   (7056x   + 7056x   + 14112x )cos(---)
+--R                                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           11        8        5 6+-+3    %pi 8
+--R                   (- 2016x   - 2016x  - 4032x )\|2  cos(---)
+--R                                                          18
+--R                 + 
+--R                           17        14        11 6+-+3    %pi 2
+--R                   (- 1008x   - 1008x   - 2016x  )\|2  cos(---)
+--R                                                            18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    8       5       2     %pi 12
+--R               (336x  + 336x  + 672x )cos(---)
+--R                                           18
+--R             + 
+--R                    14       11       8     %pi 6      20      17       14
+--R               (336x   + 336x   + 672x )cos(---)  + 84x   + 84x   + 168x
+--R                                             18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                      9       6       3 6+-+2    %pi 12
+--R               (- 336x  - 336x  - 672x )\|2  sin(---)
+--R                                                  18
+--R             + 
+--R                       9        6        3 6+-+2    %pi 2    %pi 10
+--R               (- 2016x  - 2016x  - 4032x )\|2  cos(---) sin(---)
+--R                                                     18       18
+--R             + 
+--R                      12       9        6 6+-+5    %pi 9
+--R               (- 672x   - 672x  - 1344x )\|2  sin(---)
+--R                                                    18
+--R             + 
+--R                       9        6         3 6+-+2    %pi 4    %pi 8
+--R               (- 5040x  - 5040x  - 10080x )\|2  cos(---) sin(---)
+--R                                                      18       18
+--R             + 
+--R                           9        6         3 6+-+2    %pi 6
+--R                   (- 6720x  - 6720x  - 13440x )\|2  cos(---)
+--R                                                          18
+--R                 + 
+--R                           15        12        9 6+-+2
+--R                   (- 1008x   - 1008x   - 2016x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     12        9        6 6+-+5    %pi 4    %pi 5
+--R               (4032x   + 4032x  + 8064x )\|2  cos(---) sin(---)
+--R                                                    18       18
+--R             + 
+--R                           9        6         3 6+-+2    %pi 8
+--R                   (- 5040x  - 5040x  - 10080x )\|2  cos(---)
+--R                                                          18
+--R                 + 
+--R                         15        12        9 6+-+2    %pi 2
+--R                   (3024x   + 3024x   + 6048x )\|2  cos(---)
+--R                                                         18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         12        9         6 6+-+5    %pi 6
+--R                   (5376x   + 5376x  + 10752x )\|2  cos(---)
+--R                                                         18
+--R                 + 
+--R                          18       15       12 6+-+5
+--R                   (- 336x   - 336x   - 672x  )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           9        6        3 6+-+2    %pi 10
+--R                   (- 2016x  - 2016x  - 4032x )\|2  cos(---)
+--R                                                         18
+--R                 + 
+--R                           15        12         9 6+-+2    %pi 4
+--R                   (- 7056x   - 7056x   - 14112x )\|2  cos(---)
+--R                                                            18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         12        9        6 6+-+5    %pi 8
+--R                   (2016x   + 2016x  + 4032x )\|2  cos(---)
+--R                                                        18
+--R                 + 
+--R                         18        15        12 6+-+5    %pi 2
+--R                   (1008x   + 1008x   + 2016x  )\|2  cos(---)
+--R                                                          18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                      9       6       3 6+-+2    %pi 12
+--R               (- 336x  - 336x  - 672x )\|2  cos(---)
+--R                                                  18
+--R             + 
+--R                      15       12       9 6+-+2    %pi 6
+--R               (- 336x   - 336x   - 672x )\|2  cos(---)
+--R                                                    18
+--R             + 
+--R                     21      18       15 6+-+2
+--R               (- 84x   - 84x   - 168x  )\|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                       7          4           6+-+4 +-+
+--R               (168%i x  + 168%i x  + 336%i x)\|2  \|7
+--R             + 
+--R                      7       4        6+-+4
+--R               (- 168x  - 168x  - 336x)\|2
+--R          *
+--R                 %pi 12
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        7           4            6+-+4 +-+
+--R               (1008%i x  + 1008%i x  + 2016%i x)\|2  \|7
+--R             + 
+--R                       7        4         6+-+4
+--R               (- 1008x  - 1008x  - 2016x)\|2
+--R          *
+--R                 %pi 2    %pi 10
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                       10          7           4 6+-+ +-+
+--R               (672%i x   + 672%i x  + 1344%i x )\|2 \|7
+--R             + 
+--R                      10       7        4 6+-+
+--R               (- 672x   - 672x  - 1344x )\|2
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        7           4            6+-+4 +-+
+--R               (2520%i x  + 2520%i x  + 5040%i x)\|2  \|7
+--R             + 
+--R                       7        4         6+-+4
+--R               (- 2520x  - 2520x  - 5040x)\|2
+--R          *
+--R                 %pi 4    %pi 8
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                            7           4            6+-+4 +-+
+--R                   (3360%i x  + 3360%i x  + 6720%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 3360x  - 3360x  - 6720x)\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       13          10           7 6+-+4 +-+
+--R               (504%i x   + 504%i x   + 1008%i x )\|2  \|7
+--R             + 
+--R                      13       10        7 6+-+4
+--R               (- 504x   - 504x   - 1008x )\|2
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          10           7           4 6+-+ +-+
+--R               (- 4032%i x   - 4032%i x  - 8064%i x )\|2 \|7
+--R             + 
+--R                     10        7        4 6+-+
+--R               (4032x   + 4032x  + 8064x )\|2
+--R          *
+--R                 %pi 4    %pi 5
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                            7           4            6+-+4 +-+
+--R                   (2520%i x  + 2520%i x  + 5040%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 2520x  - 2520x  - 5040x)\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                              13           10           7 6+-+4 +-+
+--R                   (- 1512%i x   - 1512%i x   - 3024%i x )\|2  \|7
+--R                 + 
+--R                         13        10        7 6+-+4
+--R                   (1512x   + 1512x   + 3024x )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              10           7            4 6+-+ +-+
+--R                   (- 5376%i x   - 5376%i x  - 10752%i x )\|2 \|7
+--R                 + 
+--R                         10        7         4 6+-+
+--R                   (5376x   + 5376x  + 10752x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       16          13          10 6+-+ +-+
+--R               (336%i x   + 336%i x   + 672%i x  )\|2 \|7
+--R             + 
+--R                      16       13       10 6+-+
+--R               (- 336x   - 336x   - 672x  )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                            7           4            6+-+4 +-+
+--R                   (1008%i x  + 1008%i x  + 2016%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 1008x  - 1008x  - 2016x)\|2
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                            13           10           7 6+-+4 +-+
+--R                   (3528%i x   + 3528%i x   + 7056%i x )\|2  \|7
+--R                 + 
+--R                           13        10        7 6+-+4
+--R                   (- 3528x   - 3528x   - 7056x )\|2
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              10           7           4 6+-+ +-+
+--R                   (- 2016%i x   - 2016%i x  - 4032%i x )\|2 \|7
+--R                 + 
+--R                         10        7        4 6+-+
+--R                   (2016x   + 2016x  + 4032x )\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                              16           13           10 6+-+ +-+
+--R                   (- 1008%i x   - 1008%i x   - 2016%i x  )\|2 \|7
+--R                 + 
+--R                         16        13        10 6+-+
+--R                   (1008x   + 1008x   + 2016x  )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7          4           6+-+4 +-+
+--R               (168%i x  + 168%i x  + 336%i x)\|2  \|7
+--R             + 
+--R                      7       4        6+-+4
+--R               (- 168x  - 168x  - 336x)\|2
+--R          *
+--R                 %pi 12
+--R             cos(---)
+--R                  18
+--R         + 
+--R                       13          10          7 6+-+4 +-+
+--R               (168%i x   + 168%i x   + 336%i x )\|2  \|7
+--R             + 
+--R                      13       10       7 6+-+4
+--R               (- 168x   - 168x   - 336x )\|2
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                  19         16         13 6+-+4 +-+
+--R           (42%i x   + 42%i x   + 84%i x  )\|2  \|7
+--R         + 
+--R                 19      16      13 6+-+4
+--R           (- 42x   - 42x   - 84x  )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                      9       6       3 6+-+2    %pi 12
+--R               (- 336x  - 336x  - 672x )\|2  sin(---)
+--R                                                  18
+--R             + 
+--R                       9        6        3 6+-+2    %pi 2    %pi 10
+--R               (- 2016x  - 2016x  - 4032x )\|2  cos(---) sin(---)
+--R                                                     18       18
+--R             + 
+--R                      12       9        6 6+-+5    %pi 9
+--R               (- 672x   - 672x  - 1344x )\|2  sin(---)
+--R                                                    18
+--R             + 
+--R                       9        6         3 6+-+2    %pi 4    %pi 8
+--R               (- 5040x  - 5040x  - 10080x )\|2  cos(---) sin(---)
+--R                                                      18       18
+--R             + 
+--R                           9        6         3 6+-+2    %pi 6
+--R                   (- 6720x  - 6720x  - 13440x )\|2  cos(---)
+--R                                                          18
+--R                 + 
+--R                           15        12        9 6+-+2
+--R                   (- 1008x   - 1008x   - 2016x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     12        9        6 6+-+5    %pi 4    %pi 5
+--R               (4032x   + 4032x  + 8064x )\|2  cos(---) sin(---)
+--R                                                    18       18
+--R             + 
+--R                           9        6         3 6+-+2    %pi 8
+--R                   (- 5040x  - 5040x  - 10080x )\|2  cos(---)
+--R                                                          18
+--R                 + 
+--R                         15        12        9 6+-+2    %pi 2
+--R                   (3024x   + 3024x   + 6048x )\|2  cos(---)
+--R                                                         18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         12        9         6 6+-+5    %pi 6
+--R                   (5376x   + 5376x  + 10752x )\|2  cos(---)
+--R                                                         18
+--R                 + 
+--R                          18       15       12 6+-+5
+--R                   (- 336x   - 336x   - 672x  )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           9        6        3 6+-+2    %pi 10
+--R                   (- 2016x  - 2016x  - 4032x )\|2  cos(---)
+--R                                                         18
+--R                 + 
+--R                           15        12         9 6+-+2    %pi 4
+--R                   (- 7056x   - 7056x   - 14112x )\|2  cos(---)
+--R                                                            18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         12        9        6 6+-+5    %pi 8
+--R                   (2016x   + 2016x  + 4032x )\|2  cos(---)
+--R                                                        18
+--R                 + 
+--R                         18        15        12 6+-+5    %pi 2
+--R                   (1008x   + 1008x   + 2016x  )\|2  cos(---)
+--R                                                          18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                      9       6       3 6+-+2    %pi 12
+--R               (- 336x  - 336x  - 672x )\|2  cos(---)
+--R                                                  18
+--R             + 
+--R                      15       12       9 6+-+2    %pi 6
+--R               (- 336x   - 336x   - 672x )\|2  cos(---)
+--R                                                    18
+--R             + 
+--R                     21      18       15 6+-+2
+--R               (- 84x   - 84x   - 168x  )\|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                    10       7       4 6+-+4    %pi 12
+--R               (336x   + 336x  + 672x )\|2  sin(---)
+--R                                                 18
+--R             + 
+--R                     10        7        4 6+-+4    %pi 2    %pi 10
+--R               (2016x   + 2016x  + 4032x )\|2  cos(---) sin(---)
+--R                                                    18       18
+--R             + 
+--R                     13        10        7 6+-+    %pi 9
+--R               (1344x   + 1344x   + 2688x )\|2 sin(---)
+--R                                                    18
+--R             + 
+--R                     10        7         4 6+-+4    %pi 4    %pi 8
+--R               (5040x   + 5040x  + 10080x )\|2  cos(---) sin(---)
+--R                                                     18       18
+--R             + 
+--R                         10        7         4 6+-+4    %pi 6
+--R                   (6720x   + 6720x  + 13440x )\|2  cos(---)
+--R                                                         18
+--R                 + 
+--R                         16        13        10 6+-+4
+--R                   (1008x   + 1008x   + 2016x  )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       13        10         7 6+-+    %pi 4    %pi 5
+--R               (- 8064x   - 8064x   - 16128x )\|2 cos(---) sin(---)
+--R                                                       18       18
+--R             + 
+--R                         10        7         4 6+-+4    %pi 8
+--R                   (5040x   + 5040x  + 10080x )\|2  cos(---)
+--R                                                         18
+--R                 + 
+--R                           16        13        10 6+-+4    %pi 2
+--R                   (- 3024x   - 3024x   - 6048x  )\|2  cos(---)
+--R                                                            18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            13         10         7 6+-+    %pi 6
+--R                   (- 10752x   - 10752x   - 21504x )\|2 cos(---)
+--R                                                             18
+--R                 + 
+--R                        19       16        13 6+-+
+--R                   (672x   + 672x   + 1344x  )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         10        7        4 6+-+4    %pi 10
+--R                   (2016x   + 2016x  + 4032x )\|2  cos(---)
+--R                                                        18
+--R                 + 
+--R                         16        13         10 6+-+4    %pi 4
+--R                   (7056x   + 7056x   + 14112x  )\|2  cos(---)
+--R                                                           18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           13        10        7 6+-+    %pi 8
+--R                   (- 4032x   - 4032x   - 8064x )\|2 cos(---)
+--R                                                          18
+--R                 + 
+--R                           19        16        13 6+-+    %pi 2
+--R                   (- 2016x   - 2016x   - 4032x  )\|2 cos(---)
+--R                                                           18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    10       7       4 6+-+4    %pi 12
+--R               (336x   + 336x  + 672x )\|2  cos(---)
+--R                                                 18
+--R             + 
+--R                    16       13       10 6+-+4    %pi 6
+--R               (336x   + 336x   + 672x  )\|2  cos(---)
+--R                                                   18
+--R             + 
+--R                   22      19       16 6+-+4
+--R               (84x   + 84x   + 168x  )\|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|7  + 1
+--R         + 
+--R                        8          5          2  +-+       8       5       2
+--R             ((- 336%i x  - 336%i x  - 672%i x )\|7  + 336x  + 336x  + 672x )
+--R          *
+--R                 %pi 12
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          8           5           2  +-+        8        5
+--R               (- 2016%i x  - 2016%i x  - 4032%i x )\|7  + 2016x  + 2016x
+--R             + 
+--R                    2
+--R               4032x
+--R          *
+--R                 %pi 2    %pi 10
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                         11          8           5 6+-+3 +-+
+--R               (- 672%i x   - 672%i x  - 1344%i x )\|2  \|7
+--R             + 
+--R                    11       8        5 6+-+3
+--R               (672x   + 672x  + 1344x )\|2
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          8           5            2  +-+        8        5
+--R               (- 5040%i x  - 5040%i x  - 10080%i x )\|7  + 5040x  + 5040x
+--R             + 
+--R                     2
+--R               10080x
+--R          *
+--R                 %pi 4    %pi 8
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                              8           5            2  +-+        8        5
+--R                   (- 6720%i x  - 6720%i x  - 13440%i x )\|7  + 6720x  + 6720x
+--R                 + 
+--R                         2
+--R                   13440x
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          14           11           8  +-+        14        11
+--R               (- 1008%i x   - 1008%i x   - 2016%i x )\|7  + 1008x   + 1008x
+--R             + 
+--R                    8
+--R               2016x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        11           8           5 6+-+3 +-+
+--R               (4032%i x   + 4032%i x  + 8064%i x )\|2  \|7
+--R             + 
+--R                       11        8        5 6+-+3
+--R               (- 4032x   - 4032x  - 8064x )\|2
+--R          *
+--R                 %pi 4    %pi 5
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                              8           5            2  +-+        8        5
+--R                   (- 5040%i x  - 5040%i x  - 10080%i x )\|7  + 5040x  + 5040x
+--R                 + 
+--R                         2
+--R                   10080x
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                            14           11           8  +-+        14        11
+--R                   (3024%i x   + 3024%i x   + 6048%i x )\|7  - 3024x   - 3024x
+--R                 + 
+--R                          8
+--R                   - 6048x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                            11           8            5 6+-+3 +-+
+--R                   (5376%i x   + 5376%i x  + 10752%i x )\|2  \|7
+--R                 + 
+--R                           11        8         5 6+-+3
+--R                   (- 5376x   - 5376x  - 10752x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         17          14          11 6+-+3 +-+
+--R               (- 336%i x   - 336%i x   - 672%i x  )\|2  \|7
+--R             + 
+--R                    17       14       11 6+-+3
+--R               (336x   + 336x   + 672x  )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              8           5           2  +-+        8        5
+--R                   (- 2016%i x  - 2016%i x  - 4032%i x )\|7  + 2016x  + 2016x
+--R                 + 
+--R                        2
+--R                   4032x
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                              14           11            8  +-+        14
+--R                   (- 7056%i x   - 7056%i x   - 14112%i x )\|7  + 7056x
+--R                 + 
+--R                        11         8
+--R                   7056x   + 14112x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                            11           8           5 6+-+3 +-+
+--R                   (2016%i x   + 2016%i x  + 4032%i x )\|2  \|7
+--R                 + 
+--R                           11        8        5 6+-+3
+--R                   (- 2016x   - 2016x  - 4032x )\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                            17           14           11 6+-+3 +-+
+--R                   (1008%i x   + 1008%i x   + 2016%i x  )\|2  \|7
+--R                 + 
+--R                           17        14        11 6+-+3
+--R                   (- 1008x   - 1008x   - 2016x  )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        8          5          2  +-+       8       5       2
+--R             ((- 336%i x  - 336%i x  - 672%i x )\|7  + 336x  + 336x  + 672x )
+--R          *
+--R                 %pi 12
+--R             cos(---)
+--R                  18
+--R         + 
+--R                           14          11          8  +-+       14       11
+--R                 (- 336%i x   - 336%i x   - 672%i x )\|7  + 336x   + 336x
+--R               + 
+--R                     8
+--R                 672x
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                    20         17          14  +-+      20      17       14
+--R           (- 84%i x   - 84%i x   - 168%i x  )\|7  + 84x   + 84x   + 168x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                         7          4           6+-+4 +-+
+--R               (- 168%i x  - 168%i x  - 336%i x)\|2  \|7
+--R             + 
+--R                      7       4        6+-+4
+--R               (- 168x  - 168x  - 336x)\|2
+--R          *
+--R                 %pi 12
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          7           4            6+-+4 +-+
+--R               (- 1008%i x  - 1008%i x  - 2016%i x)\|2  \|7
+--R             + 
+--R                       7        4         6+-+4
+--R               (- 1008x  - 1008x  - 2016x)\|2
+--R          *
+--R                 %pi 2    %pi 10
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                         10          7           4 6+-+ +-+
+--R               (- 672%i x   - 672%i x  - 1344%i x )\|2 \|7
+--R             + 
+--R                      10       7        4 6+-+
+--R               (- 672x   - 672x  - 1344x )\|2
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          7           4            6+-+4 +-+
+--R               (- 2520%i x  - 2520%i x  - 5040%i x)\|2  \|7
+--R             + 
+--R                       7        4         6+-+4
+--R               (- 2520x  - 2520x  - 5040x)\|2
+--R          *
+--R                 %pi 4    %pi 8
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                              7           4            6+-+4 +-+
+--R                   (- 3360%i x  - 3360%i x  - 6720%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 3360x  - 3360x  - 6720x)\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         13          10           7 6+-+4 +-+
+--R               (- 504%i x   - 504%i x   - 1008%i x )\|2  \|7
+--R             + 
+--R                      13       10        7 6+-+4
+--R               (- 504x   - 504x   - 1008x )\|2
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        10           7           4 6+-+ +-+
+--R               (4032%i x   + 4032%i x  + 8064%i x )\|2 \|7
+--R             + 
+--R                     10        7        4 6+-+
+--R               (4032x   + 4032x  + 8064x )\|2
+--R          *
+--R                 %pi 4    %pi 5
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                              7           4            6+-+4 +-+
+--R                   (- 2520%i x  - 2520%i x  - 5040%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 2520x  - 2520x  - 5040x)\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                            13           10           7 6+-+4 +-+
+--R                   (1512%i x   + 1512%i x   + 3024%i x )\|2  \|7
+--R                 + 
+--R                         13        10        7 6+-+4
+--R                   (1512x   + 1512x   + 3024x )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                            10           7            4 6+-+ +-+
+--R                   (5376%i x   + 5376%i x  + 10752%i x )\|2 \|7
+--R                 + 
+--R                         10        7         4 6+-+
+--R                   (5376x   + 5376x  + 10752x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         16          13          10 6+-+ +-+
+--R               (- 336%i x   - 336%i x   - 672%i x  )\|2 \|7
+--R             + 
+--R                      16       13       10 6+-+
+--R               (- 336x   - 336x   - 672x  )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              7           4            6+-+4 +-+
+--R                   (- 1008%i x  - 1008%i x  - 2016%i x)\|2  \|7
+--R                 + 
+--R                           7        4         6+-+4
+--R                   (- 1008x  - 1008x  - 2016x)\|2
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                              13           10           7 6+-+4 +-+
+--R                   (- 3528%i x   - 3528%i x   - 7056%i x )\|2  \|7
+--R                 + 
+--R                           13        10        7 6+-+4
+--R                   (- 3528x   - 3528x   - 7056x )\|2
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                            10           7           4 6+-+ +-+
+--R                   (2016%i x   + 2016%i x  + 4032%i x )\|2 \|7
+--R                 + 
+--R                         10        7        4 6+-+
+--R                   (2016x   + 2016x  + 4032x )\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                            16           13           10 6+-+ +-+
+--R                   (1008%i x   + 1008%i x   + 2016%i x  )\|2 \|7
+--R                 + 
+--R                         16        13        10 6+-+
+--R                   (1008x   + 1008x   + 2016x  )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         7          4           6+-+4 +-+
+--R               (- 168%i x  - 168%i x  - 336%i x)\|2  \|7
+--R             + 
+--R                      7       4        6+-+4
+--R               (- 168x  - 168x  - 336x)\|2
+--R          *
+--R                 %pi 12
+--R             cos(---)
+--R                  18
+--R         + 
+--R                         13          10          7 6+-+4 +-+
+--R               (- 168%i x   - 168%i x   - 336%i x )\|2  \|7
+--R             + 
+--R                      13       10       7 6+-+4
+--R               (- 168x   - 168x   - 336x )\|2
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                    19         16         13 6+-+4 +-+
+--R           (- 42%i x   - 42%i x   - 84%i x  )\|2  \|7
+--R         + 
+--R                 19      16      13 6+-+4
+--R           (- 42x   - 42x   - 84x  )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|7  + 1
+--R     + 
+--R                      8          5          2  +-+       8       5       2
+--R             ((336%i x  + 336%i x  + 672%i x )\|7  + 336x  + 336x  + 672x )
+--R          *
+--R                 %pi 12
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          8           5           2  +-+        8        5
+--R                 (2016%i x  + 2016%i x  + 4032%i x )\|7  + 2016x  + 2016x
+--R               + 
+--R                      2
+--R                 4032x
+--R          *
+--R                 %pi 2    %pi 10
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                       11          8           5 6+-+3 +-+
+--R               (672%i x   + 672%i x  + 1344%i x )\|2  \|7
+--R             + 
+--R                    11       8        5 6+-+3
+--R               (672x   + 672x  + 1344x )\|2
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        8           5            2  +-+        8        5
+--R               (5040%i x  + 5040%i x  + 10080%i x )\|7  + 5040x  + 5040x
+--R             + 
+--R                     2
+--R               10080x
+--R          *
+--R                 %pi 4    %pi 8
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                            8           5            2  +-+        8        5
+--R                   (6720%i x  + 6720%i x  + 13440%i x )\|7  + 6720x  + 6720x
+--R                 + 
+--R                         2
+--R                   13440x
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        14           11           8  +-+        14        11
+--R               (1008%i x   + 1008%i x   + 2016%i x )\|7  + 1008x   + 1008x
+--R             + 
+--R                    8
+--R               2016x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          11           8           5 6+-+3 +-+
+--R               (- 4032%i x   - 4032%i x  - 8064%i x )\|2  \|7
+--R             + 
+--R                       11        8        5 6+-+3
+--R               (- 4032x   - 4032x  - 8064x )\|2
+--R          *
+--R                 %pi 4    %pi 5
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                            8           5            2  +-+        8        5
+--R                   (5040%i x  + 5040%i x  + 10080%i x )\|7  + 5040x  + 5040x
+--R                 + 
+--R                         2
+--R                   10080x
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                              14           11           8  +-+        14
+--R                   (- 3024%i x   - 3024%i x   - 6048%i x )\|7  - 3024x
+--R                 + 
+--R                          11        8
+--R                   - 3024x   - 6048x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              11           8            5 6+-+3 +-+
+--R                   (- 5376%i x   - 5376%i x  - 10752%i x )\|2  \|7
+--R                 + 
+--R                           11        8         5 6+-+3
+--R                   (- 5376x   - 5376x  - 10752x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       17          14          11 6+-+3 +-+
+--R               (336%i x   + 336%i x   + 672%i x  )\|2  \|7
+--R             + 
+--R                    17       14       11 6+-+3
+--R               (336x   + 336x   + 672x  )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                            8           5           2  +-+        8        5
+--R                   (2016%i x  + 2016%i x  + 4032%i x )\|7  + 2016x  + 2016x
+--R                 + 
+--R                        2
+--R                   4032x
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                            14           11            8  +-+        14
+--R                   (7056%i x   + 7056%i x   + 14112%i x )\|7  + 7056x
+--R                 + 
+--R                        11         8
+--R                   7056x   + 14112x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                              11           8           5 6+-+3 +-+
+--R                   (- 2016%i x   - 2016%i x  - 4032%i x )\|2  \|7
+--R                 + 
+--R                           11        8        5 6+-+3
+--R                   (- 2016x   - 2016x  - 4032x )\|2
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                              17           14           11 6+-+3 +-+
+--R                   (- 1008%i x   - 1008%i x   - 2016%i x  )\|2  \|7
+--R                 + 
+--R                           17        14        11 6+-+3
+--R                   (- 1008x   - 1008x   - 2016x  )\|2
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      8          5          2  +-+       8       5       2
+--R             ((336%i x  + 336%i x  + 672%i x )\|7  + 336x  + 336x  + 672x )
+--R          *
+--R                 %pi 12
+--R             cos(---)
+--R                  18
+--R         + 
+--R                      14          11          8  +-+       14       11       8
+--R             ((336%i x   + 336%i x   + 672%i x )\|7  + 336x   + 336x   + 672x )
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                  20         17          14  +-+      20      17       14
+--R           (84%i x   + 84%i x   + 168%i x  )\|7  + 84x   + 84x   + 168x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|7  + 1
+--R     + 
+--R             6        3        6+-+2    %pi 12
+--R       (1344x  + 1344x  + 2688)\|2  sin(---)
+--R                                         18
+--R     + 
+--R             6        3         6+-+2    %pi 2    %pi 10
+--R       (8064x  + 8064x  + 16128)\|2  cos(---) sin(---)
+--R                                          18       18
+--R     + 
+--R             9        6        3 6+-+5    %pi 9
+--R       (2688x  + 2688x  + 5376x )\|2  sin(---)
+--R                                           18
+--R     + 
+--R              6         3         6+-+2    %pi 4    %pi 8
+--R       (20160x  + 20160x  + 40320)\|2  cos(---) sin(---)
+--R                                            18       18
+--R     + 
+--R                  6         3         6+-+2    %pi 6
+--R           (26880x  + 26880x  + 53760)\|2  cos(---)
+--R                                                18
+--R         + 
+--R                 12        9        6 6+-+2
+--R           (4032x   + 4032x  + 8064x )\|2
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R                9         6         3 6+-+5    %pi 4    %pi 5
+--R       (- 16128x  - 16128x  - 32256x )\|2  cos(---) sin(---)
+--R                                                18       18
+--R     + 
+--R                  6         3         6+-+2    %pi 8
+--R           (20160x  + 20160x  + 40320)\|2  cos(---)
+--R                                                18
+--R         + 
+--R                    12         9         6 6+-+2    %pi 2
+--R           (- 12096x   - 12096x  - 24192x )\|2  cos(---)
+--R                                                     18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R                    9         6         3 6+-+5    %pi 6
+--R           (- 21504x  - 21504x  - 43008x )\|2  cos(---)
+--R                                                    18
+--R         + 
+--R                 15        12        9 6+-+5
+--R           (1344x   + 1344x   + 2688x )\|2
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              18
+--R     + 
+--R                 6        3         6+-+2    %pi 10
+--R           (8064x  + 8064x  + 16128)\|2  cos(---)
+--R                                              18
+--R         + 
+--R                  12         9         6 6+-+2    %pi 4
+--R           (28224x   + 28224x  + 56448x )\|2  cos(---)
+--R                                                   18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R                   9        6         3 6+-+5    %pi 8
+--R           (- 8064x  - 8064x  - 16128x )\|2  cos(---)
+--R                                                  18
+--R         + 
+--R                   15        12        9 6+-+5    %pi 2
+--R           (- 4032x   - 4032x   - 8064x )\|2  cos(---)
+--R                                                   18
+--R      *
+--R             %pi
+--R         sin(---)
+--R              18
+--R     + 
+--R             6        3        6+-+2    %pi 12
+--R       (1344x  + 1344x  + 2688)\|2  cos(---)
+--R                                         18
+--R     + 
+--R           12        9        6 6+-+2    %pi 6        18       15       12 6+-+2
+--R     (1344x   + 1344x  + 2688x )\|2  cos(---)  + (336x   + 336x   + 672x  )\|2
+--R                                          18
+--R                                           Type: Expression(Complex(Integer))
+--E 925
+
+)clear all
+
+--S 926 of 2282
+t0:=x^m/(1+2*x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                                    Type: Expression(Integer)
+--E 926
+
+--S 927 of 2282
+--r0:=1/4*x^(1+m)/(1+x^4)+1/4*(3-m)*x^(1+m)*hypergeometric(1,1/4*(1+m),_
+--   1/4*(5+m),-x^4)/(1+m)
+--E 927
+
+--S 928 of 2282
+--a0:=integrate(t0,x)
+--E 928
+
+--S 929 of 2282
+--m0:=a0-r0
+--E 929
+
+--S 930 of 2282
+--d0:=normalize(D(m0,x))
+--E 930
+
+)clear all
+
+--S 931 of 2282
+t0:=x^9/(1+2*x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 931
+
+--S 932 of 2282
+r0:=3/4*x^2-1/4*x^6/(1+x^4)-3/4*atan(x^2)
+--R 
+--R
+--R             4           2      6     2
+--R        (- 3x  - 3)atan(x ) + 2x  + 3x
+--R   (2)  -------------------------------
+--R                      4
+--R                    4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 932
+
+--S 933 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4           2      6     2
+--R        (- 3x  - 3)atan(x ) + 2x  + 3x
+--R   (3)  -------------------------------
+--R                      4
+--R                    4x  + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 933
+
+--S 934 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 934
+
+--S 935 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 935
+
+)clear all
+
+--S 936 of 2282
+t0:=x^7/(1+2*x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 936
+
+--S 937 of 2282
+r0:=1/4/(1+x^4)+1/4*log(1+x^4)
+--R 
+--R
+--R          4          4
+--R        (x  + 1)log(x  + 1) + 1
+--R   (2)  -----------------------
+--R                  4
+--R                4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 937
+
+--S 938 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4          4
+--R        (x  + 1)log(x  + 1) + 1
+--R   (3)  -----------------------
+--R                  4
+--R                4x  + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 938
+
+--S 939 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 939
+
+--S 940 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 940
+
+)clear all
+
+--S 941 of 2282
+t0:=x^5/(1+2*x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 941
+
+--S 942 of 2282
+r0:=-1/4*x^2/(1+x^4)+1/4*atan(x^2)
+--R 
+--R
+--R          4           2     2
+--R        (x  + 1)atan(x ) - x
+--R   (2)  ---------------------
+--R                 4
+--R               4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 942
+
+--S 943 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4           2     2
+--R        (x  + 1)atan(x ) - x
+--R   (3)  ---------------------
+--R                 4
+--R               4x  + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 943
+
+--S 944 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 944
+
+--S 945 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 945
+
+)clear all
+
+--S 946 of 2282
+t0:=x^3/(1+2*x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 946
+
+--S 947 of 2282
+r0:=(-1/4)/(1+x^4)
+--R 
+--R
+--R             1
+--R             -
+--R             4
+--R   (2)  - ------
+--R           4
+--R          x  + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 947
+
+--S 948 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            4
+--R          4x  + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 948
+
+--S 949 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 949
+
+--S 950 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 950
+
+)clear all
+
+--S 951 of 2282
+t0:=x/(1+2*x^4+x^8)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 951
+
+--S 952 of 2282
+r0:=1/4*x^2/(1+x^4)+1/4*atan(x^2)
+--R 
+--R
+--R          4           2     2
+--R        (x  + 1)atan(x ) + x
+--R   (2)  ---------------------
+--R                 4
+--R               4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 952
+
+--S 953 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4           2     2
+--R        (x  + 1)atan(x ) + x
+--R   (3)  ---------------------
+--R                 4
+--R               4x  + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 953
+
+--S 954 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 954
+
+--S 955 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 955
+
+)clear all
+
+--S 956 of 2282
+t0:=1/(x*(1+2*x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         9     5
+--R        x  + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 956
+
+--S 957 of 2282
+r0:=1/4/(1+x^4)-1/2*atanh(1+2*x^4)
+--R 
+--R
+--R             4             4
+--R        (- 2x  - 2)atanh(2x  + 1) + 1
+--R   (2)  -----------------------------
+--R                     4
+--R                   4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 957
+
+--S 958 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4          4           4
+--R        (- x  - 1)log(x  + 1) + (4x  + 4)log(x) + 1
+--R   (3)  -------------------------------------------
+--R                            4
+--R                          4x  + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 958
+
+--S 959 of 2282
+m0:=a0-r0
+--R 
+--R
+--R               4                           4
+--R        - log(x  + 1) + 4log(x) + 2atanh(2x  + 1)
+--R   (4)  -----------------------------------------
+--R                            4
+--R                                                    Type: Expression(Integer)
+--E 959
+
+--S 960 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 960
+
+)clear all
+
+--S 961 of 2282
+t0:=1/(x^3*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         11     7    3
+--R        x   + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 961
+
+--S 962 of 2282
+r0:=(-3/4)/x^2+1/4/(x^2*(1+x^4))-3/4*atan(x^2)
+--R 
+--R
+--R             6     2       2      4
+--R        (- 3x  - 3x )atan(x ) - 3x  - 2
+--R   (2)  -------------------------------
+--R                     6     2
+--R                   4x  + 4x
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             6     2       2      4
+--R        (- 3x  - 3x )atan(x ) - 3x  - 2
+--R   (3)  -------------------------------
+--R                     6     2
+--R                   4x  + 4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 963
+
+--S 964 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 964
+
+--S 965 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 965
+
+)clear all
+
+--S 966 of 2282
+t0:=1/(x^5*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         13     9    5
+--R        x   + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 966
+
+--S 967 of 2282
+r0:=(-1/2)/x^4+1/4/(x^4*(1+x^4))+atanh(1+2*x^4)
+--R 
+--R
+--R           8     4         4          4
+--R        (4x  + 4x )atanh(2x  + 1) - 2x  - 1
+--R   (2)  -----------------------------------
+--R                       8     4
+--R                     4x  + 4x
+--R                                                    Type: Expression(Integer)
+--E 967
+
+--S 968 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           8     4      4             8     4            4
+--R        (2x  + 2x )log(x  + 1) + (- 8x  - 8x )log(x) - 2x  - 1
+--R   (3)  ------------------------------------------------------
+--R                                 8     4
+--R                               4x  + 4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 968
+
+--S 969 of 2282
+m0:=a0-r0
+--R 
+--R
+--R             4                           4
+--R        log(x  + 1) - 4log(x) - 2atanh(2x  + 1)
+--R   (4)  ---------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 969
+
+--S 970 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 970
+
+)clear all
+
+--S 971 of 2282
+t0:=1/(x^7*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         15     11    7
+--R        x   + 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 971
+
+--S 972 of 2282
+r0:=(-5/12)/x^6+5/4/x^2+1/4/(x^6*(1+x^4))+5/4*atan(x^2)
+--R 
+--R
+--R            10      6       2       8      4
+--R        (15x   + 15x )atan(x ) + 15x  + 10x  - 2
+--R   (2)  ----------------------------------------
+--R                         10      6
+--R                      12x   + 12x
+--R                                                    Type: Expression(Integer)
+--E 972
+
+--S 973 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            10      6       2       8      4
+--R        (15x   + 15x )atan(x ) + 15x  + 10x  - 2
+--R   (3)  ----------------------------------------
+--R                         10      6
+--R                      12x   + 12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 973
+
+--S 974 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 974
+
+--S 975 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 975
+
+)clear all
+
+--S 976 of 2282
+t0:=x^8/(1+2*x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 976
+
+--S 977 of 2282
+r0:=5/4*x-1/4*x^5/(1+x^4)+5/8*atan(1-x*sqrt(2))/sqrt(2)-5/8*atan(1+_
+   x*sqrt(2))/sqrt(2)+5/16*log(1+x^2-x*sqrt(2))/sqrt(2)-5/16*log(1+_
+   x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R            4           +-+    2           4             +-+    2
+--R       (- 5x  - 5)log(x\|2  + x  + 1) + (5x  + 5)log(- x\|2  + x  + 1)
+--R     + 
+--R             4             +-+              4             +-+
+--R       (- 10x  - 10)atan(x\|2  + 1) + (- 10x  - 10)atan(x\|2  - 1)
+--R     + 
+--R           5        +-+
+--R       (16x  + 20x)\|2
+--R  /
+--R         4       +-+
+--R     (16x  + 16)\|2
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4      +-+      +-+    2           4      +-+        +-+    2
+--R       (- 5x  - 5)\|2 log(x\|2  + x  + 1) + (5x  + 5)\|2 log(- x\|2  + x  + 1)
+--R     + 
+--R           4       +-+         1            4       +-+         1           5
+--R       (10x  + 10)\|2 atan(---------) + (10x  + 10)\|2 atan(---------) + 32x
+--R                             +-+                              +-+
+--R                           x\|2  - 1                        x\|2  + 1
+--R     + 
+--R       40x
+--R  /
+--R        4
+--R     32x  + 32
+--R                                         Type: Union(Expression(Integer),...)
+--E 978
+
+--S 979 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           +-+                +-+                  1                  1
+--R   5atan(x\|2  + 1) + 5atan(x\|2  - 1) + 5atan(---------) + 5atan(---------)
+--R                                                 +-+                +-+
+--R                                               x\|2  - 1          x\|2  + 1
+--R   -------------------------------------------------------------------------
+--R                                       +-+
+--R                                     8\|2
+--R                                                    Type: Expression(Integer)
+--E 979
+
+--S 980 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 980
+
+)clear all
+
+--S 981 of 2282
+t0:=x^6/(1+2*x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 981
+
+--S 982 of 2282
+r0:=-1/4*x^3/(1+x^4)-3/8*atan(1-x*sqrt(2))/sqrt(2)+3/8*atan(1+x*sqrt(2))/_
+   sqrt(2)+3/16*log(1+x^2-x*sqrt(2))/sqrt(2)-3/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R            4           +-+    2           4             +-+    2
+--R       (- 3x  - 3)log(x\|2  + x  + 1) + (3x  + 3)log(- x\|2  + x  + 1)
+--R     + 
+--R          4            +-+           4            +-+          3 +-+
+--R       (6x  + 6)atan(x\|2  + 1) + (6x  + 6)atan(x\|2  - 1) - 4x \|2
+--R  /
+--R         4       +-+
+--R     (16x  + 16)\|2
+--R                                                    Type: Expression(Integer)
+--E 982
+
+--S 983 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4      +-+      +-+    2           4      +-+        +-+    2
+--R       (- 3x  - 3)\|2 log(x\|2  + x  + 1) + (3x  + 3)\|2 log(- x\|2  + x  + 1)
+--R     + 
+--R            4      +-+         1             4      +-+         1          3
+--R       (- 6x  - 6)\|2 atan(---------) + (- 6x  - 6)\|2 atan(---------) - 8x
+--R                             +-+                              +-+
+--R                           x\|2  - 1                        x\|2  + 1
+--R  /
+--R        4
+--R     32x  + 32
+--R                                         Type: Union(Expression(Integer),...)
+--E 983
+
+--S 984 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             +-+                +-+                  1                  1
+--R   - 3atan(x\|2  + 1) - 3atan(x\|2  - 1) - 3atan(---------) - 3atan(---------)
+--R                                                   +-+                +-+
+--R                                                 x\|2  - 1          x\|2  + 1
+--R   ---------------------------------------------------------------------------
+--R                                        +-+
+--R                                      8\|2
+--R                                                    Type: Expression(Integer)
+--E 984
+
+--S 985 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 985
+
+)clear all
+
+--S 986 of 2282
+t0:=x^4/(1+2*x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 986
+
+--S 987 of 2282
+r0:=-1/4*x/(1+x^4)-1/8*atan(1-x*sqrt(2))/sqrt(2)+1/8*atan(1+x*sqrt(2))/_
+   sqrt(2)-1/16*log(1+x^2-x*sqrt(2))/sqrt(2)+1/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R         4           +-+    2            4             +-+    2
+--R       (x  + 1)log(x\|2  + x  + 1) + (- x  - 1)log(- x\|2  + x  + 1)
+--R     + 
+--R          4            +-+           4            +-+           +-+
+--R       (2x  + 2)atan(x\|2  + 1) + (2x  + 2)atan(x\|2  - 1) - 4x\|2
+--R  /
+--R         4       +-+
+--R     (16x  + 16)\|2
+--R                                                    Type: Expression(Integer)
+--E 987
+
+--S 988 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         4      +-+      +-+    2            4      +-+        +-+    2
+--R       (x  + 1)\|2 log(x\|2  + x  + 1) + (- x  - 1)\|2 log(- x\|2  + x  + 1)
+--R     + 
+--R            4      +-+         1             4      +-+         1
+--R       (- 2x  - 2)\|2 atan(---------) + (- 2x  - 2)\|2 atan(---------) - 8x
+--R                             +-+                              +-+
+--R                           x\|2  - 1                        x\|2  + 1
+--R  /
+--R        4
+--R     32x  + 32
+--R                                         Type: Union(Expression(Integer),...)
+--E 988
+
+--S 989 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +-+               +-+                 1                 1
+--R   - atan(x\|2  + 1) - atan(x\|2  - 1) - atan(---------) - atan(---------)
+--R                                                +-+               +-+
+--R                                              x\|2  - 1         x\|2  + 1
+--R   -----------------------------------------------------------------------
+--R                                      +-+
+--R                                    8\|2
+--R                                                    Type: Expression(Integer)
+--E 989
+
+--S 990 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 990
+
+)clear all
+
+--S 991 of 2282
+t0:=x^2/(1+2*x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 991
+
+--S 992 of 2282
+r0:=1/4*x^3/(1+x^4)-1/8*atan(1-x*sqrt(2))/sqrt(2)+1/8*atan(1+x*sqrt(2))/_
+   sqrt(2)+1/16*log(1+x^2-x*sqrt(2))/sqrt(2)-1/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R           4           +-+    2          4             +-+    2
+--R       (- x  - 1)log(x\|2  + x  + 1) + (x  + 1)log(- x\|2  + x  + 1)
+--R     + 
+--R          4            +-+           4            +-+          3 +-+
+--R       (2x  + 2)atan(x\|2  + 1) + (2x  + 2)atan(x\|2  - 1) + 4x \|2
+--R  /
+--R         4       +-+
+--R     (16x  + 16)\|2
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4      +-+      +-+    2          4      +-+        +-+    2
+--R       (- x  - 1)\|2 log(x\|2  + x  + 1) + (x  + 1)\|2 log(- x\|2  + x  + 1)
+--R     + 
+--R            4      +-+         1             4      +-+         1          3
+--R       (- 2x  - 2)\|2 atan(---------) + (- 2x  - 2)\|2 atan(---------) + 8x
+--R                             +-+                              +-+
+--R                           x\|2  - 1                        x\|2  + 1
+--R  /
+--R        4
+--R     32x  + 32
+--R                                         Type: Union(Expression(Integer),...)
+--E 993
+
+--S 994 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +-+               +-+                 1                 1
+--R   - atan(x\|2  + 1) - atan(x\|2  - 1) - atan(---------) - atan(---------)
+--R                                                +-+               +-+
+--R                                              x\|2  - 1         x\|2  + 1
+--R   -----------------------------------------------------------------------
+--R                                      +-+
+--R                                    8\|2
+--R                                                    Type: Expression(Integer)
+--E 994
+
+--S 995 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 995
+
+)clear all
+
+--S 996 of 2282
+t0:=1/(1+2*x^4+x^8)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 996
+
+--S 997 of 2282
+r0:=1/4*x/(1+x^4)-3/8*atan(1-x*sqrt(2))/sqrt(2)+3/8*atan(1+x*sqrt(2))/_
+   sqrt(2)-3/16*log(1+x^2-x*sqrt(2))/sqrt(2)+3/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R          4           +-+    2             4             +-+    2
+--R       (3x  + 3)log(x\|2  + x  + 1) + (- 3x  - 3)log(- x\|2  + x  + 1)
+--R     + 
+--R          4            +-+           4            +-+           +-+
+--R       (6x  + 6)atan(x\|2  + 1) + (6x  + 6)atan(x\|2  - 1) + 4x\|2
+--R  /
+--R         4       +-+
+--R     (16x  + 16)\|2
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          4      +-+      +-+    2             4      +-+        +-+    2
+--R       (3x  + 3)\|2 log(x\|2  + x  + 1) + (- 3x  - 3)\|2 log(- x\|2  + x  + 1)
+--R     + 
+--R            4      +-+         1             4      +-+         1
+--R       (- 6x  - 6)\|2 atan(---------) + (- 6x  - 6)\|2 atan(---------) + 8x
+--R                             +-+                              +-+
+--R                           x\|2  - 1                        x\|2  + 1
+--R  /
+--R        4
+--R     32x  + 32
+--R                                         Type: Union(Expression(Integer),...)
+--E 998
+
+--S 999 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             +-+                +-+                  1                  1
+--R   - 3atan(x\|2  + 1) - 3atan(x\|2  - 1) - 3atan(---------) - 3atan(---------)
+--R                                                   +-+                +-+
+--R                                                 x\|2  - 1          x\|2  + 1
+--R   ---------------------------------------------------------------------------
+--R                                        +-+
+--R                                      8\|2
+--R                                                    Type: Expression(Integer)
+--E 999
+
+--S 1000 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+)clear all
+
+--S 1001 of 2282
+t0:=1/(x^2*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         10     6    2
+--R        x   + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1001
+
+--S 1002 of 2282
+r0:=(-5/4)/x+1/4/(x*(1+x^4))+5/8*atan(1-x*sqrt(2))/sqrt(2)-_
+   5/8*atan(1+x*sqrt(2))/sqrt(2)-5/16*log(1+x^2-x*sqrt(2))/sqrt(2)+_
+   5/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R          5            +-+    2             5              +-+    2
+--R       (5x  + 5x)log(x\|2  + x  + 1) + (- 5x  - 5x)log(- x\|2  + x  + 1)
+--R     + 
+--R             5              +-+              5              +-+
+--R       (- 10x  - 10x)atan(x\|2  + 1) + (- 10x  - 10x)atan(x\|2  - 1)
+--R     + 
+--R             4       +-+
+--R       (- 20x  - 16)\|2
+--R  /
+--R         5        +-+
+--R     (16x  + 16x)\|2
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+--S 1003 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          5       +-+      +-+    2             5       +-+        +-+    2
+--R       (5x  + 5x)\|2 log(x\|2  + x  + 1) + (- 5x  - 5x)\|2 log(- x\|2  + x  + 1)
+--R     + 
+--R           5        +-+         1            5        +-+         1           4
+--R       (10x  + 10x)\|2 atan(---------) + (10x  + 10x)\|2 atan(---------) - 40x
+--R                              +-+                               +-+
+--R                            x\|2  - 1                         x\|2  + 1
+--R     + 
+--R       - 32
+--R  /
+--R        5
+--R     32x  + 32x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1003
+
+--S 1004 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           +-+                +-+                  1                  1
+--R   5atan(x\|2  + 1) + 5atan(x\|2  - 1) + 5atan(---------) + 5atan(---------)
+--R                                                 +-+                +-+
+--R                                               x\|2  - 1          x\|2  + 1
+--R   -------------------------------------------------------------------------
+--R                                       +-+
+--R                                     8\|2
+--R                                                    Type: Expression(Integer)
+--E 1004
+
+--S 1005 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1005
+
+)clear all
+
+--S 1006 of 2282
+t0:=1/(x^4*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         12     8    4
+--R        x   + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1006
+
+--S 1007 of 2282
+r0:=(-7/12)/x^3+1/4/(x^3*(1+x^4))+7/8*atan(1-x*sqrt(2))/sqrt(2)-_
+   7/8*atan(1+x*sqrt(2))/sqrt(2)+7/16*log(1+x^2-x*sqrt(2))/sqrt(2)-_
+   7/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R             7      3       +-+    2            7      3         +-+    2
+--R       (- 21x  - 21x )log(x\|2  + x  + 1) + (21x  + 21x )log(- x\|2  + x  + 1)
+--R     + 
+--R             7      3        +-+              7      3        +-+
+--R       (- 42x  - 42x )atan(x\|2  + 1) + (- 42x  - 42x )atan(x\|2  - 1)
+--R     + 
+--R             4       +-+
+--R       (- 28x  - 16)\|2
+--R  /
+--R         7      3  +-+
+--R     (48x  + 48x )\|2
+--R                                                    Type: Expression(Integer)
+--E 1007
+
+--S 1008 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             7      3  +-+      +-+    2
+--R       (- 21x  - 21x )\|2 log(x\|2  + x  + 1)
+--R     + 
+--R           7      3  +-+        +-+    2            7      3  +-+         1
+--R       (21x  + 21x )\|2 log(- x\|2  + x  + 1) + (42x  + 42x )\|2 atan(---------)
+--R                                                                        +-+
+--R                                                                      x\|2  - 1
+--R     + 
+--R           7      3  +-+         1           4
+--R       (42x  + 42x )\|2 atan(---------) - 56x  - 32
+--R                               +-+
+--R                             x\|2  + 1
+--R  /
+--R        7      3
+--R     96x  + 96x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1008
+
+--S 1009 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           +-+                +-+                  1                  1
+--R   7atan(x\|2  + 1) + 7atan(x\|2  - 1) + 7atan(---------) + 7atan(---------)
+--R                                                 +-+                +-+
+--R                                               x\|2  - 1          x\|2  + 1
+--R   -------------------------------------------------------------------------
+--R                                       +-+
+--R                                     8\|2
+--R                                                    Type: Expression(Integer)
+--E 1009
+
+--S 1010 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1010
+
+)clear all
+
+--S 1011 of 2282
+t0:=1/(x^6*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         14     10    6
+--R        x   + 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1011
+
+--S 1012 of 2282
+r0:=(-9/20)/x^5+9/4/x+1/4/(x^5*(1+x^4))-9/8*atan(1-x*sqrt(2))/sqrt(2)+_
+   9/8*atan(1+x*sqrt(2))/sqrt(2)+9/16*log(1+x^2-x*sqrt(2))/sqrt(2)-_
+   9/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R             9      5       +-+    2            9      5         +-+    2
+--R       (- 45x  - 45x )log(x\|2  + x  + 1) + (45x  + 45x )log(- x\|2  + x  + 1)
+--R     + 
+--R           9      5        +-+            9      5        +-+
+--R       (90x  + 90x )atan(x\|2  + 1) + (90x  + 90x )atan(x\|2  - 1)
+--R     + 
+--R            8       4       +-+
+--R       (180x  + 144x  - 16)\|2
+--R  /
+--R         9      5  +-+
+--R     (80x  + 80x )\|2
+--R                                                    Type: Expression(Integer)
+--E 1012
+
+--S 1013 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             9      5  +-+      +-+    2
+--R       (- 45x  - 45x )\|2 log(x\|2  + x  + 1)
+--R     + 
+--R           9      5  +-+        +-+    2
+--R       (45x  + 45x )\|2 log(- x\|2  + x  + 1)
+--R     + 
+--R             9      5  +-+         1              9      5  +-+         1
+--R       (- 90x  - 90x )\|2 atan(---------) + (- 90x  - 90x )\|2 atan(---------)
+--R                                 +-+                                  +-+
+--R                               x\|2  - 1                            x\|2  + 1
+--R     + 
+--R           8       4
+--R       360x  + 288x  - 32
+--R  /
+--R         9       5
+--R     160x  + 160x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1013
+
+--S 1014 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             +-+                +-+                  1                  1
+--R   - 9atan(x\|2  + 1) - 9atan(x\|2  - 1) - 9atan(---------) - 9atan(---------)
+--R                                                   +-+                +-+
+--R                                                 x\|2  - 1          x\|2  + 1
+--R   ---------------------------------------------------------------------------
+--R                                        +-+
+--R                                      8\|2
+--R                                                    Type: Expression(Integer)
+--E 1014
+
+--S 1015 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1015
+
+)clear all
+
+--S 1016 of 2282
+t0:=1/(x^8*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         16     12    8
+--R        x   + 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1016
+
+--S 1017 of 2282
+r0:=(-11/28)/x^7+11/12/x^3+1/4/(x^7*(1+x^4))-11/8*atan(1-x*sqrt(2))/_
+   sqrt(2)+11/8*atan(1+x*sqrt(2))/sqrt(2)-11/16*log(1+x^2-x*sqrt(2))/_
+   sqrt(2)+11/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R            11       7       +-+    2
+--R       (231x   + 231x )log(x\|2  + x  + 1)
+--R     + 
+--R              11       7         +-+    2             11       7        +-+
+--R       (- 231x   - 231x )log(- x\|2  + x  + 1) + (462x   + 462x )atan(x\|2  + 1)
+--R     + 
+--R            11       7        +-+             8       4       +-+
+--R       (462x   + 462x )atan(x\|2  - 1) + (308x  + 176x  - 48)\|2
+--R  /
+--R          11       7  +-+
+--R     (336x   + 336x )\|2
+--R                                                    Type: Expression(Integer)
+--E 1017
+
+--S 1018 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            11       7  +-+      +-+    2
+--R       (231x   + 231x )\|2 log(x\|2  + x  + 1)
+--R     + 
+--R              11       7  +-+        +-+    2
+--R       (- 231x   - 231x )\|2 log(- x\|2  + x  + 1)
+--R     + 
+--R              11       7  +-+         1
+--R       (- 462x   - 462x )\|2 atan(---------)
+--R                                    +-+
+--R                                  x\|2  - 1
+--R     + 
+--R              11       7  +-+         1            8       4
+--R       (- 462x   - 462x )\|2 atan(---------) + 616x  + 352x  - 96
+--R                                    +-+
+--R                                  x\|2  + 1
+--R  /
+--R         11       7
+--R     672x   + 672x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1018
+
+--S 1019 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +-+                 +-+                   1
+--R       - 11atan(x\|2  + 1) - 11atan(x\|2  - 1) - 11atan(---------)
+--R                                                          +-+
+--R                                                        x\|2  - 1
+--R     + 
+--R                    1
+--R       - 11atan(---------)
+--R                  +-+
+--R                x\|2  + 1
+--R  /
+--R       +-+
+--R     8\|2
+--R                                                    Type: Expression(Integer)
+--E 1019
+
+--S 1020 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1020
+
+)clear all
+
+--S 1021 of 2282
+t0:=x^m/(1-2*x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1021
+
+--S 1022 of 2282
+--r0:=1/4*x^(1+m)/(1-x^4)+1/4*(3-m)*x^(1+m)*hypergeometric(1,1/4*(1+m),_
+--   1/4*(5+m),x^4)/(1+m)
+--E 1022
+
+--S 1023 of 2282
+--a0:=integrate(t0,x)
+--E 1023
+
+--S 1024 of 2282
+--m0:=a0-r0
+--E 1024
+
+--S 1025 of 2282
+--d0:=normalize(D(m0,x))
+--E 1025
+
+)clear all
+
+--S 1026 of 2282
+t0:=x^9/(1-2*x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1026
+
+--S 1027 of 2282
+r0:=3/4*x^2+1/4*x^6/(1-x^4)-3/4*atanh(x^2)
+--R 
+--R
+--R             4            2      6     2
+--R        (- 3x  + 3)atanh(x ) + 2x  - 3x
+--R   (2)  --------------------------------
+--R                       4
+--R                     4x  - 4
+--R                                                    Type: Expression(Integer)
+--E 1027
+
+--S 1028 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4          2           4          2          6     2
+--R        (- 3x  + 3)log(x  + 1) + (3x  - 3)log(x  - 1) + 4x  - 6x
+--R   (3)  ---------------------------------------------------------
+--R                                   4
+--R                                 8x  - 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1028
+
+--S 1029 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                2              2                2
+--R        - 3log(x  + 1) + 3log(x  - 1) + 6atanh(x )
+--R   (4)  ------------------------------------------
+--R                             8
+--R                                                    Type: Expression(Integer)
+--E 1029
+
+--S 1030 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1030
+
+)clear all
+
+--S 1031 of 2282
+t0:=x^7/(1-2*x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1031
+
+--S 1032 of 2282
+r0:=1/4/(1-x^4)+1/4*log(1-x^4)
+--R 
+--R
+--R          4            4
+--R        (x  - 1)log(- x  + 1) - 1
+--R   (2)  -------------------------
+--R                   4
+--R                 4x  - 4
+--R                                                    Type: Expression(Integer)
+--E 1032
+
+--S 1033 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4          4
+--R        (x  - 1)log(x  - 1) - 1
+--R   (3)  -----------------------
+--R                  4
+--R                4x  - 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1033
+
+--S 1034 of 2282
+m0:=a0-r0
+--R 
+--R
+--R             4               4
+--R        log(x  - 1) - log(- x  + 1)
+--R   (4)  ---------------------------
+--R                     4
+--R                                                    Type: Expression(Integer)
+--E 1034
+
+--S 1035 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1035
+
+)clear all
+
+--S 1036 of 2282
+t0:=x^5/(1-2*x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1036
+
+--S 1037 of 2282
+r0:=1/4*x^2/(1-x^4)-1/4*atanh(x^2)
+--R 
+--R
+--R            4            2     2
+--R        (- x  + 1)atanh(x ) - x
+--R   (2)  ------------------------
+--R                   4
+--R                 4x  - 4
+--R                                                    Type: Expression(Integer)
+--E 1037
+
+--S 1038 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4          2          4          2          2
+--R        (- x  + 1)log(x  + 1) + (x  - 1)log(x  - 1) - 2x
+--R   (3)  -------------------------------------------------
+--R                               4
+--R                             8x  - 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1038
+
+--S 1039 of 2282
+m0:=a0-r0
+--R 
+--R
+--R               2             2                2
+--R        - log(x  + 1) + log(x  - 1) + 2atanh(x )
+--R   (4)  ----------------------------------------
+--R                            8
+--R                                                    Type: Expression(Integer)
+--E 1039
+
+--S 1040 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1040
+
+)clear all
+
+--S 1041 of 2282
+t0:=x^3/(1-2*x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1041
+
+--S 1042 of 2282
+r0:=1/4/(1-x^4)
+--R 
+--R
+--R             1
+--R             -
+--R             4
+--R   (2)  - ------
+--R           4
+--R          x  - 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1042
+
+--S 1043 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            4
+--R          4x  - 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1043
+
+--S 1044 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1044
+
+--S 1045 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1045
+
+)clear all
+
+--S 1046 of 2282
+t0:=x/(1-2*x^4+x^8)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1046
+
+--S 1047 of 2282
+r0:=1/4*x^2/(1-x^4)+1/4*atanh(x^2)
+--R 
+--R
+--R          4            2     2
+--R        (x  - 1)atanh(x ) - x
+--R   (2)  ----------------------
+--R                  4
+--R                4x  - 4
+--R                                                    Type: Expression(Integer)
+--E 1047
+
+--S 1048 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4          2            4          2          2
+--R        (x  - 1)log(x  + 1) + (- x  + 1)log(x  - 1) - 2x
+--R   (3)  -------------------------------------------------
+--R                               4
+--R                             8x  - 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1048
+
+--S 1049 of 2282
+m0:=a0-r0
+--R 
+--R
+--R             2             2                2
+--R        log(x  + 1) - log(x  - 1) - 2atanh(x )
+--R   (4)  --------------------------------------
+--R                           8
+--R                                                    Type: Expression(Integer)
+--E 1049
+
+--S 1050 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1050
+
+)clear all
+
+--S 1051 of 2282
+t0:=1/(x*(1-2*x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         9     5
+--R        x  - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1051
+
+--S 1052 of 2282
+r0:=1/4/(1-x^4)-1/2*atanh(1-2*x^4)
+--R 
+--R
+--R           4             4
+--R        (2x  - 2)atanh(2x  - 1) - 1
+--R   (2)  ---------------------------
+--R                    4
+--R                  4x  - 4
+--R                                                    Type: Expression(Integer)
+--E 1052
+
+--S 1053 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4          4           4
+--R        (- x  + 1)log(x  - 1) + (4x  - 4)log(x) - 1
+--R   (3)  -------------------------------------------
+--R                            4
+--R                          4x  - 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1053
+
+--S 1054 of 2282
+m0:=a0-r0
+--R 
+--R
+--R               4                           4
+--R        - log(x  - 1) + 4log(x) - 2atanh(2x  - 1)
+--R   (4)  -----------------------------------------
+--R                            4
+--R                                                    Type: Expression(Integer)
+--E 1054
+
+--S 1055 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1055
+
+)clear all
+
+--S 1056 of 2282
+t0:=1/(x^3*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         11     7    3
+--R        x   - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1056
+
+--S 1057 of 2282
+r0:=(-3/4)/x^2+1/4/(x^2*(1-x^4))+3/4*atanh(x^2)
+--R 
+--R
+--R           6     2        2      4
+--R        (3x  - 3x )atanh(x ) - 3x  + 2
+--R   (2)  ------------------------------
+--R                     6     2
+--R                   4x  - 4x
+--R                                                    Type: Expression(Integer)
+--E 1057
+
+--S 1058 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           6     2      2             6     2      2          4
+--R        (3x  - 3x )log(x  + 1) + (- 3x  + 3x )log(x  - 1) - 6x  + 4
+--R   (3)  -----------------------------------------------------------
+--R                                   6     2
+--R                                 8x  - 8x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1058
+
+--S 1059 of 2282
+m0:=a0-r0
+--R 
+--R
+--R              2              2                2
+--R        3log(x  + 1) - 3log(x  - 1) - 6atanh(x )
+--R   (4)  ----------------------------------------
+--R                            8
+--R                                                    Type: Expression(Integer)
+--E 1059
+
+--S 1060 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1060
+
+)clear all
+
+--S 1061 of 2282
+t0:=1/(x^5*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         13     9    5
+--R        x   - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1061
+
+--S 1062 of 2282
+r0:=(-1/2)/x^4+1/4/(x^4*(1-x^4))-atanh(1-2*x^4)
+--R 
+--R
+--R           8     4         4          4
+--R        (4x  - 4x )atanh(2x  - 1) - 2x  + 1
+--R   (2)  -----------------------------------
+--R                       8     4
+--R                     4x  - 4x
+--R                                                    Type: Expression(Integer)
+--E 1062
+
+--S 1063 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             8     4      4           8     4            4
+--R        (- 2x  + 2x )log(x  - 1) + (8x  - 8x )log(x) - 2x  + 1
+--R   (3)  ------------------------------------------------------
+--R                                 8     4
+--R                               4x  - 4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1063
+
+--S 1064 of 2282
+m0:=a0-r0
+--R 
+--R
+--R               4                           4
+--R        - log(x  - 1) + 4log(x) - 2atanh(2x  - 1)
+--R   (4)  -----------------------------------------
+--R                            2
+--R                                                    Type: Expression(Integer)
+--E 1064
+
+--S 1065 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1065
+
+)clear all
+
+--S 1066 of 2282
+t0:=1/(x^7*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         15     11    7
+--R        x   - 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1066
+
+--S 1067 of 2282
+r0:=(-5/12)/x^6+(-5/4)/x^2+1/4/(x^6*(1-x^4))+5/4*atanh(x^2)
+--R 
+--R
+--R            10      6        2       8      4
+--R        (15x   - 15x )atanh(x ) - 15x  + 10x  + 2
+--R   (2)  -----------------------------------------
+--R                          10      6
+--R                       12x   - 12x
+--R                                                    Type: Expression(Integer)
+--E 1067
+
+--S 1068 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       10      6      2              10      6      2           8      4
+--R   (15x   - 15x )log(x  + 1) + (- 15x   + 15x )log(x  - 1) - 30x  + 20x  + 4
+--R   -------------------------------------------------------------------------
+--R                                     10      6
+--R                                  24x   - 24x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1068
+
+--S 1069 of 2282
+m0:=a0-r0
+--R 
+--R
+--R              2              2                 2
+--R        5log(x  + 1) - 5log(x  - 1) - 10atanh(x )
+--R   (4)  -----------------------------------------
+--R                            8
+--R                                                    Type: Expression(Integer)
+--E 1069
+
+--S 1070 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1070
+
+)clear all
+
+--S 1071 of 2282
+t0:=x^8/(1-2*x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1071
+
+--S 1072 of 2282
+r0:=5/4*x+1/4*x^5/(1-x^4)-5/8*atan(x)-5/8*atanh(x)
+--R 
+--R
+--R             4                     4                 5
+--R        (- 5x  + 5)atanh(x) + (- 5x  + 5)atan(x) + 8x  - 10x
+--R   (2)  ----------------------------------------------------
+--R                                 4
+--R                               8x  - 8
+--R                                                    Type: Expression(Integer)
+--E 1072
+
+--S 1073 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4                     4                        4                   5
+--R       (- 5x  + 5)log(x + 1) + (5x  - 5)log(x - 1) + (- 10x  + 10)atan(x) + 16x
+--R     + 
+--R       - 20x
+--R  /
+--R        4
+--R     16x  - 16
+--R                                         Type: Union(Expression(Integer),...)
+--E 1073
+
+--S 1074 of 2282
+m0:=a0-r0
+--R 
+--R
+--R        - 5log(x + 1) + 5log(x - 1) + 10atanh(x)
+--R   (4)  ----------------------------------------
+--R                           16
+--R                                                    Type: Expression(Integer)
+--E 1074
+
+--S 1075 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1075
+
+)clear all
+
+--S 1076 of 2282
+t0:=x^6/(1-2*x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1076
+
+--S 1077 of 2282
+r0:=1/4*x^3/(1-x^4)+3/8*atan(x)-3/8*atanh(x)
+--R 
+--R
+--R             4                   4                 3
+--R        (- 3x  + 3)atanh(x) + (3x  - 3)atan(x) - 2x
+--R   (2)  --------------------------------------------
+--R                             4
+--R                           8x  - 8
+--R                                                    Type: Expression(Integer)
+--E 1077
+
+--S 1078 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4                     4                     4                 3
+--R        (- 3x  + 3)log(x + 1) + (3x  - 3)log(x - 1) + (6x  - 6)atan(x) - 4x
+--R   (3)  --------------------------------------------------------------------
+--R                                         4
+--R                                      16x  - 16
+--R                                         Type: Union(Expression(Integer),...)
+--E 1078
+
+--S 1079 of 2282
+m0:=a0-r0
+--R 
+--R
+--R        - 3log(x + 1) + 3log(x - 1) + 6atanh(x)
+--R   (4)  ---------------------------------------
+--R                           16
+--R                                                    Type: Expression(Integer)
+--E 1079
+
+--S 1080 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1080
+
+)clear all
+
+--S 1081 of 2282
+t0:=x^4/(1-2*x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1081
+
+--S 1082 of 2282
+r0:=1/4*x/(1-x^4)-1/8*atan(x)-1/8*atanh(x)
+--R 
+--R
+--R            4                    4
+--R        (- x  + 1)atanh(x) + (- x  + 1)atan(x) - 2x
+--R   (2)  -------------------------------------------
+--R                            4
+--R                          8x  - 8
+--R                                                    Type: Expression(Integer)
+--E 1082
+
+--S 1083 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4                    4                       4
+--R        (- x  + 1)log(x + 1) + (x  - 1)log(x - 1) + (- 2x  + 2)atan(x) - 4x
+--R   (3)  -------------------------------------------------------------------
+--R                                        4
+--R                                     16x  - 16
+--R                                         Type: Union(Expression(Integer),...)
+--E 1083
+
+--S 1084 of 2282
+m0:=a0-r0
+--R 
+--R
+--R        - log(x + 1) + log(x - 1) + 2atanh(x)
+--R   (4)  -------------------------------------
+--R                          16
+--R                                                    Type: Expression(Integer)
+--E 1084
+
+--S 1085 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1085
+
+)clear all
+
+--S 1086 of 2282
+t0:=x^2/(1-2*x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1086
+
+--S 1087 of 2282
+r0:=1/4*x^3/(1-x^4)-1/8*atan(x)+1/8*atanh(x)
+--R 
+--R
+--R          4                    4                 3
+--R        (x  - 1)atanh(x) + (- x  + 1)atan(x) - 2x
+--R   (2)  ------------------------------------------
+--R                            4
+--R                          8x  - 8
+--R                                                    Type: Expression(Integer)
+--E 1087
+
+--S 1088 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4                      4                       4                 3
+--R        (x  - 1)log(x + 1) + (- x  + 1)log(x - 1) + (- 2x  + 2)atan(x) - 4x
+--R   (3)  --------------------------------------------------------------------
+--R                                         4
+--R                                      16x  - 16
+--R                                         Type: Union(Expression(Integer),...)
+--E 1088
+
+--S 1089 of 2282
+m0:=a0-r0
+--R 
+--R
+--R        log(x + 1) - log(x - 1) - 2atanh(x)
+--R   (4)  -----------------------------------
+--R                         16
+--R                                                    Type: Expression(Integer)
+--E 1089
+
+--S 1090 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1090
+
+)clear all
+
+--S 1091 of 2282
+t0:=1/(1-2*x^4+x^8)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1091
+
+--S 1092 of 2282
+r0:=1/4*x/(1-x^4)+3/8*atan(x)+3/8*atanh(x)
+--R 
+--R
+--R           4                   4
+--R        (3x  - 3)atanh(x) + (3x  - 3)atan(x) - 2x
+--R   (2)  -----------------------------------------
+--R                           4
+--R                         8x  - 8
+--R                                                    Type: Expression(Integer)
+--E 1092
+
+--S 1093 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4                       4                     4
+--R        (3x  - 3)log(x + 1) + (- 3x  + 3)log(x - 1) + (6x  - 6)atan(x) - 4x
+--R   (3)  -------------------------------------------------------------------
+--R                                        4
+--R                                     16x  - 16
+--R                                         Type: Union(Expression(Integer),...)
+--E 1093
+
+--S 1094 of 2282
+m0:=a0-r0
+--R 
+--R
+--R        3log(x + 1) - 3log(x - 1) - 6atanh(x)
+--R   (4)  -------------------------------------
+--R                          16
+--R                                                    Type: Expression(Integer)
+--E 1094
+
+--S 1095 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1095
+
+)clear all
+
+--S 1096 of 2282
+t0:=1/(x^2*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         10     6    2
+--R        x   - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1096
+
+--S 1097 of 2282
+r0:=(-5/4)/x+1/4/(x*(1-x^4))-5/8*atan(x)+5/8*atanh(x)
+--R 
+--R
+--R           5                      5                   4
+--R        (5x  - 5x)atanh(x) + (- 5x  + 5x)atan(x) - 10x  + 8
+--R   (2)  ---------------------------------------------------
+--R                                5
+--R                              8x  - 8x
+--R                                                    Type: Expression(Integer)
+--E 1097
+
+--S 1098 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          5                        5                         5
+--R       (5x  - 5x)log(x + 1) + (- 5x  + 5x)log(x - 1) + (- 10x  + 10x)atan(x)
+--R     + 
+--R            4
+--R       - 20x  + 16
+--R  /
+--R        5
+--R     16x  - 16x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1098
+
+--S 1099 of 2282
+m0:=a0-r0
+--R 
+--R
+--R        5log(x + 1) - 5log(x - 1) - 10atanh(x)
+--R   (4)  --------------------------------------
+--R                          16
+--R                                                    Type: Expression(Integer)
+--E 1099
+
+--S 1100 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1100
+
+)clear all
+
+--S 1101 of 2282
+t0:=1/(x^4*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         12     8    4
+--R        x   - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1101
+
+--S 1102 of 2282
+r0:=(-7/12)/x^3+1/4/(x^3*(1-x^4))+7/8*atan(x)+7/8*atanh(x)
+--R 
+--R
+--R            7      3                7      3              4
+--R        (21x  - 21x )atanh(x) + (21x  - 21x )atan(x) - 14x  + 8
+--R   (2)  -------------------------------------------------------
+--R                                 7      3
+--R                              24x  - 24x
+--R                                                    Type: Expression(Integer)
+--E 1102
+
+--S 1103 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           7      3                    7      3
+--R       (21x  - 21x )log(x + 1) + (- 21x  + 21x )log(x - 1)
+--R     + 
+--R           7      3              4
+--R       (42x  - 42x )atan(x) - 28x  + 16
+--R  /
+--R        7      3
+--R     48x  - 48x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1103
+
+--S 1104 of 2282
+m0:=a0-r0
+--R 
+--R
+--R        7log(x + 1) - 7log(x - 1) - 14atanh(x)
+--R   (4)  --------------------------------------
+--R                          16
+--R                                                    Type: Expression(Integer)
+--E 1104
+
+--S 1105 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1105
+
+)clear all
+
+--S 1106 of 2282
+t0:=1/(x^6*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         14     10    6
+--R        x   - 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1106
+
+--S 1107 of 2282
+r0:=(-9/20)/x^5+(-9/4)/x+1/4/(x^5*(1-x^4))-9/8*atan(x)+9/8*atanh(x)
+--R 
+--R
+--R            9      5                  9      5              8      4
+--R        (45x  - 45x )atanh(x) + (- 45x  + 45x )atan(x) - 90x  + 72x  + 8
+--R   (2)  ----------------------------------------------------------------
+--R                                      9      5
+--R                                   40x  - 40x
+--R                                                    Type: Expression(Integer)
+--E 1107
+
+--S 1108 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           9      5                    9      5
+--R       (45x  - 45x )log(x + 1) + (- 45x  + 45x )log(x - 1)
+--R     + 
+--R             9      5               8       4
+--R       (- 90x  + 90x )atan(x) - 180x  + 144x  + 16
+--R  /
+--R        9      5
+--R     80x  - 80x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1108
+
+--S 1109 of 2282
+m0:=a0-r0
+--R 
+--R
+--R        9log(x + 1) - 9log(x - 1) - 18atanh(x)
+--R   (4)  --------------------------------------
+--R                          16
+--R                                                    Type: Expression(Integer)
+--E 1109
+
+--S 1110 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1110
+
+)clear all
+
+--S 1111 of 2282
+t0:=1/(x^8*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         16     12    8
+--R        x   - 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1111
+
+--S 1112 of 2282
+r0:=(-11/28)/x^7+(-11/12)/x^3+1/4/(x^7*(1-x^4))+11/8*atan(x)+11/8*atanh(x)
+--R 
+--R
+--R             11       7                 11       7               8      4
+--R        (231x   - 231x )atanh(x) + (231x   - 231x )atan(x) - 154x  + 88x  + 24
+--R   (2)  ----------------------------------------------------------------------
+--R                                        11       7
+--R                                    168x   - 168x
+--R                                                    Type: Expression(Integer)
+--E 1112
+
+--S 1113 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            11       7                     11       7
+--R       (231x   - 231x )log(x + 1) + (- 231x   + 231x )log(x - 1)
+--R     + 
+--R            11       7               8       4
+--R       (462x   - 462x )atan(x) - 308x  + 176x  + 48
+--R  /
+--R         11       7
+--R     336x   - 336x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1113
+
+--S 1114 of 2282
+m0:=a0-r0
+--R 
+--R
+--R        11log(x + 1) - 11log(x - 1) - 22atanh(x)
+--R   (4)  ----------------------------------------
+--R                           16
+--R                                                    Type: Expression(Integer)
+--E 1114
+
+--S 1115 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1115
+
+)clear all
+
+--S 1116 of 2282
+t0:=x^m/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1116
+
+--S 1117 of 2282
+--r0:=2*c*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),-2*c*x^4/(b-_
+--   sqrt(b^2-4*a*c)))/((1+m)*(b-sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))-_
+--   2*c*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),_
+--   -2*c*x^4/(b+sqrt(b^2-4*a*c)))/((1+m)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))
+--E 1117
+
+--S 1118 of 2282
+--a0:=integrate(t0,x)
+--E 1118
+
+--S 1119 of 2282
+--m0:=a0-r0
+--E 1119
+
+--S 1120 of 2282
+--d0:=normalize(D(m0,x))
+--E 1120
+
+)clear all
+
+--S 1121 of 2282
+t0:=x^11/(a+b*x^4+c*x^8)
+--R 
+--R
+--R               11
+--R              x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1121
+
+--S 1122 of 2282
+r0:=1/4*x^4/c-1/8*b*log(a+b*x^4+c*x^8)/c^2-_
+   1/4*(b^2-2*a*c)*atanh((b+2*c*x^4)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                4
+--R                 2          2c x  + b
+--R       (4a c - 2b )atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                          +-----------+
+--R                   8      4            4  |          2
+--R       (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     8c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1122
+
+--S 1123 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2
+--R           (2a c - b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 8         4           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   4             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   8      4
+--R                c x  + b x  + a
+--R       + 
+--R                                            +-----------+
+--R                     8      4            4  |          2
+--R         (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         2 |          2
+--R       8c \|- 4a c + b
+--R     ,
+--R
+--R                                        +---------+
+--R                                 4      |        2
+--R                     2      (2c x  + b)\|4a c - b
+--R         (- 4a c + 2b )atan(-----------------------)
+--R                                           2
+--R                                   4a c - b
+--R       + 
+--R                                            +---------+
+--R                     8      4            4  |        2
+--R         (- b log(c x  + b x  + a) + 2c x )\|4a c - b
+--R    /
+--R           +---------+
+--R         2 |        2
+--R       8c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1123
+
+--S 1124 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 8         4           2  |          2           2     2   4
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 8      4
+--R              c x  + b x  + a
+--R     + 
+--R                                  4
+--R                   2          2c x  + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     8c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1124
+
+--S 1125 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1125
+
+--S 1126 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+             4
+--R                  2  |        2          2c x  + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                     +-----------+          4      |        2
+--R                  2  |          2      (2c x  + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     4c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1126
+
+--S 1127 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1127
+
+)clear all
+
+--S 1128 of 2282
+t0:=x^9/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                9
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1128
+
+--S 1129 of 2282
+r0:=1/2*x^2/c-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R              +-----------+              | +-----------+
+--R              |          2            2  | |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   + b
+--R      *
+--R                      2 +-+ +-+
+--R                     x \|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R              +-----------+              |   +-----------+
+--R              |          2            2  |   |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   + b
+--R      *
+--R                     2 +-+ +-+
+--R                    x \|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R        2 +-+ |          2  +-+ |   |          2       | |          2
+--R       x \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1129
+
+--S 1130 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +------------------------------------------------------+
+--R           |                  +--------------------+
+--R           |                  |   2 2       2     4
+--R           |      4      2 3  |- a c  + 2a b c - b               3
+--R           |(64a c  - 16b c ) |--------------------  - 3a b c + b
+--R           |                  |        7       2 6
+--R           |                 \| 1024a c  - 256b c
+--R         c |------------------------------------------------------
+--R           |                         4     2 3
+--R          \|                    32a c  - 8b c
+--R      *
+--R         log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                            4      3 3  |- a c  + 2a b c - b       2 2       2
+--R                    (64a b c  - 16b c ) |--------------------  - 4a c  + 5a b c
+--R                                        |        7       2 6
+--R                                       \| 1024a c  - 256b c
+--R                  + 
+--R                       4
+--R                    - b
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                  +--------------------+
+--R                 |                  |   2 2       2     4
+--R                 |      4      2 3  |- a c  + 2a b c - b               3
+--R                 |(64a c  - 16b c ) |--------------------  - 3a b c + b
+--R                 |                  |        7       2 6
+--R                 |                 \| 1024a c  - 256b c
+--R                 |------------------------------------------------------
+--R                 |                         4     2 3
+--R                \|                    32a c  - 8b c
+--R            + 
+--R                2       2  2
+--R              (a c - a b )x
+--R     + 
+--R       -
+--R              +--------------------------------------------------------+
+--R              |                    +--------------------+
+--R              |                    |   2 2       2     4
+--R              |        4      2 3  |- a c  + 2a b c - b               3
+--R              |(- 64a c  + 16b c ) |--------------------  - 3a b c + b
+--R              |                    |        7       2 6
+--R              |                   \| 1024a c  - 256b c
+--R            c |--------------------------------------------------------
+--R              |                          4     2 3
+--R             \|                     32a c  - 8b c
+--R         *
+--R            log
+--R                                         +--------------------+
+--R                                         |   2 2       2     4
+--R                             4      3 3  |- a c  + 2a b c - b       2 2       2
+--R                     (64a b c  - 16b c ) |--------------------  + 4a c  - 5a b c
+--R                                         |        7       2 6
+--R                                        \| 1024a c  - 256b c
+--R                   + 
+--R                      4
+--R                     b
+--R                *
+--R                    +--------------------------------------------------------+
+--R                    |                    +--------------------+
+--R                    |                    |   2 2       2     4
+--R                    |        4      2 3  |- a c  + 2a b c - b               3
+--R                    |(- 64a c  + 16b c ) |--------------------  - 3a b c + b
+--R                    |                    |        7       2 6
+--R                    |                   \| 1024a c  - 256b c
+--R                    |--------------------------------------------------------
+--R                    |                          4     2 3
+--R                   \|                     32a c  - 8b c
+--R               + 
+--R                   2       2  2
+--R                 (a c - a b )x
+--R     + 
+--R           +--------------------------------------------------------+
+--R           |                    +--------------------+
+--R           |                    |   2 2       2     4
+--R           |        4      2 3  |- a c  + 2a b c - b               3
+--R           |(- 64a c  + 16b c ) |--------------------  - 3a b c + b
+--R           |                    |        7       2 6
+--R           |                   \| 1024a c  - 256b c
+--R         c |--------------------------------------------------------
+--R           |                          4     2 3
+--R          \|                     32a c  - 8b c
+--R      *
+--R         log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                            4      3 3  |- a c  + 2a b c - b       2 2       2
+--R                  (- 64a b c  + 16b c ) |--------------------  - 4a c  + 5a b c
+--R                                        |        7       2 6
+--R                                       \| 1024a c  - 256b c
+--R                + 
+--R                     4
+--R                  - b
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |                    +--------------------+
+--R                 |                    |   2 2       2     4
+--R                 |        4      2 3  |- a c  + 2a b c - b               3
+--R                 |(- 64a c  + 16b c ) |--------------------  - 3a b c + b
+--R                 |                    |        7       2 6
+--R                 |                   \| 1024a c  - 256b c
+--R                 |--------------------------------------------------------
+--R                 |                          4     2 3
+--R                \|                     32a c  - 8b c
+--R            + 
+--R                2       2  2
+--R              (a c - a b )x
+--R     + 
+--R       -
+--R              +------------------------------------------------------+
+--R              |                  +--------------------+
+--R              |                  |   2 2       2     4
+--R              |      4      2 3  |- a c  + 2a b c - b               3
+--R              |(64a c  - 16b c ) |--------------------  - 3a b c + b
+--R              |                  |        7       2 6
+--R              |                 \| 1024a c  - 256b c
+--R            c |------------------------------------------------------
+--R              |                         4     2 3
+--R             \|                    32a c  - 8b c
+--R         *
+--R            log
+--R                                           +--------------------+
+--R                                           |   2 2       2     4
+--R                               4      3 3  |- a c  + 2a b c - b       2 2
+--R                     (- 64a b c  + 16b c ) |--------------------  + 4a c
+--R                                           |        7       2 6
+--R                                          \| 1024a c  - 256b c
+--R                   + 
+--R                           2     4
+--R                     - 5a b c + b
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                  +--------------------+
+--R                    |                  |   2 2       2     4
+--R                    |      4      2 3  |- a c  + 2a b c - b               3
+--R                    |(64a c  - 16b c ) |--------------------  - 3a b c + b
+--R                    |                  |        7       2 6
+--R                    |                 \| 1024a c  - 256b c
+--R                    |------------------------------------------------------
+--R                    |                         4     2 3
+--R                   \|                    32a c  - 8b c
+--R               + 
+--R                   2       2  2
+--R                 (a c - a b )x
+--R     + 
+--R        2
+--R       x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1130
+
+--S 1131 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +------------------------------------------------------+
+--R          |                  +--------------------+
+--R          |                  |   2 2       2     4
+--R          |      4      2 3  |- a c  + 2a b c - b               3
+--R          |(64a c  - 16b c ) |--------------------  - 3a b c + b
+--R          |                  |        7       2 6
+--R          |                 \| 1024a c  - 256b c
+--R          |------------------------------------------------------
+--R          |                         4     2 3
+--R         \|                    32a c  - 8b c
+--R      *
+--R         log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                            4      3 3  |- a c  + 2a b c - b       2 2       2
+--R                    (64a b c  - 16b c ) |--------------------  - 4a c  + 5a b c
+--R                                        |        7       2 6
+--R                                       \| 1024a c  - 256b c
+--R                  + 
+--R                       4
+--R                    - b
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                  +--------------------+
+--R                 |                  |   2 2       2     4
+--R                 |      4      2 3  |- a c  + 2a b c - b               3
+--R                 |(64a c  - 16b c ) |--------------------  - 3a b c + b
+--R                 |                  |        7       2 6
+--R                 |                 \| 1024a c  - 256b c
+--R                 |------------------------------------------------------
+--R                 |                         4     2 3
+--R                \|                    32a c  - 8b c
+--R            + 
+--R                2       2  2
+--R              (a c - a b )x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            c\|2 \|- 4a c + b  \|c
+--R         *
+--R             +--------------------------------------------------------+
+--R             |                    +--------------------+
+--R             |                    |   2 2       2     4
+--R             |        4      2 3  |- a c  + 2a b c - b               3
+--R             |(- 64a c  + 16b c ) |--------------------  - 3a b c + b
+--R             |                    |        7       2 6
+--R             |                   \| 1024a c  - 256b c
+--R             |--------------------------------------------------------
+--R             |                          4     2 3
+--R            \|                     32a c  - 8b c
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                         +--------------------+
+--R                                         |   2 2       2     4
+--R                             4      3 3  |- a c  + 2a b c - b       2 2       2
+--R                     (64a b c  - 16b c ) |--------------------  + 4a c  - 5a b c
+--R                                         |        7       2 6
+--R                                        \| 1024a c  - 256b c
+--R                   + 
+--R                      4
+--R                     b
+--R                *
+--R                    +--------------------------------------------------------+
+--R                    |                    +--------------------+
+--R                    |                    |   2 2       2     4
+--R                    |        4      2 3  |- a c  + 2a b c - b               3
+--R                    |(- 64a c  + 16b c ) |--------------------  - 3a b c + b
+--R                    |                    |        7       2 6
+--R                    |                   \| 1024a c  - 256b c
+--R                    |--------------------------------------------------------
+--R                    |                          4     2 3
+--R                   \|                     32a c  - 8b c
+--R               + 
+--R                   2       2  2
+--R                 (a c - a b )x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2  +-+
+--R         c\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------------------------------------------+
+--R          |                    +--------------------+
+--R          |                    |   2 2       2     4
+--R          |        4      2 3  |- a c  + 2a b c - b               3
+--R          |(- 64a c  + 16b c ) |--------------------  - 3a b c + b
+--R          |                    |        7       2 6
+--R          |                   \| 1024a c  - 256b c
+--R          |--------------------------------------------------------
+--R          |                          4     2 3
+--R         \|                     32a c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                            4      3 3  |- a c  + 2a b c - b       2 2       2
+--R                  (- 64a b c  + 16b c ) |--------------------  - 4a c  + 5a b c
+--R                                        |        7       2 6
+--R                                       \| 1024a c  - 256b c
+--R                + 
+--R                     4
+--R                  - b
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |                    +--------------------+
+--R                 |                    |   2 2       2     4
+--R                 |        4      2 3  |- a c  + 2a b c - b               3
+--R                 |(- 64a c  + 16b c ) |--------------------  - 3a b c + b
+--R                 |                    |        7       2 6
+--R                 |                   \| 1024a c  - 256b c
+--R                 |--------------------------------------------------------
+--R                 |                          4     2 3
+--R                \|                     32a c  - 8b c
+--R            + 
+--R                2       2  2
+--R              (a c - a b )x
+--R     + 
+--R       -
+--R                                    +--------------------+ +------------------+
+--R                  +-----------+     |   +-----------+      | +-----------+
+--R              +-+ |          2  +-+ |   |          2       | |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +------------------------------------------------------+
+--R             |                  +--------------------+
+--R             |                  |   2 2       2     4
+--R             |      4      2 3  |- a c  + 2a b c - b               3
+--R             |(64a c  - 16b c ) |--------------------  - 3a b c + b
+--R             |                  |        7       2 6
+--R             |                 \| 1024a c  - 256b c
+--R             |------------------------------------------------------
+--R             |                         4     2 3
+--R            \|                    32a c  - 8b c
+--R         *
+--R            log
+--R                                           +--------------------+
+--R                                           |   2 2       2     4
+--R                               4      3 3  |- a c  + 2a b c - b       2 2
+--R                     (- 64a b c  + 16b c ) |--------------------  + 4a c
+--R                                           |        7       2 6
+--R                                          \| 1024a c  - 256b c
+--R                   + 
+--R                           2     4
+--R                     - 5a b c + b
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                  +--------------------+
+--R                    |                  |   2 2       2     4
+--R                    |      4      2 3  |- a c  + 2a b c - b               3
+--R                    |(64a c  - 16b c ) |--------------------  - 3a b c + b
+--R                    |                  |        7       2 6
+--R                    |                 \| 1024a c  - 256b c
+--R                    |------------------------------------------------------
+--R                    |                         4     2 3
+--R                   \|                    32a c  - 8b c
+--R               + 
+--R                   2       2  2
+--R                 (a c - a b )x
+--R     + 
+--R                                       +------------------+
+--R            +-----------+              | +-----------+
+--R            |          2            2  | |          2
+--R         (b\|- 4a c + b   + 2a c - b )\|\|- 4a c + b   + b
+--R      *
+--R                      2 +-+ +-+
+--R                     x \|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                       +--------------------+
+--R            +-----------+              |   +-----------+
+--R            |          2            2  |   |          2
+--R         (b\|- 4a c + b   - 2a c + b )\|- \|- 4a c + b   + b
+--R      *
+--R                     2 +-+ +-+
+--R                    x \|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1131
+
+--S 1132 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1132
+
+)clear all
+
+--S 1133 of 2282
+t0:=x^7/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                7
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1133
+
+--S 1134 of 2282
+r0:=1/8*log(a+b*x^4+c*x^8)/c+1/4*b*atanh((b+2*c*x^4)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                        4                               +-----------+
+--R                    2c x  + b             8      4      |          2
+--R        2b atanh(--------------) + log(c x  + b x  + a)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  -------------------------------------------------------------
+--R                                  +-----------+
+--R                                  |          2
+--R                               8c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1134
+
+--S 1135 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 8         4           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   4             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   8      4
+--R                c x  + b x  + a
+--R       + 
+--R                              +-----------+
+--R                8      4      |          2
+--R         log(c x  + b x  + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       8c\|- 4a c + b
+--R     ,
+--R                          +---------+
+--R                   4      |        2                          +---------+
+--R              (2c x  + b)\|4a c - b             8      4      |        2
+--R    - 2b atan(-----------------------) + log(c x  + b x  + a)\|4a c - b
+--R                             2
+--R                     4a c - b
+--R    ---------------------------------------------------------------------]
+--R                                   +---------+
+--R                                   |        2
+--R                                8c\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1135
+
+--S 1136 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 8         4           2  |          2           2     2   4
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 8      4
+--R              c x  + b x  + a
+--R     + 
+--R                         4
+--R                     2c x  + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     8c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1136
+
+--S 1137 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1137
+
+--S 1138 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             4
+--R           |        2          2c x  + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          4      |        2
+--R           |          2      (2c x  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     4c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1138
+
+--S 1139 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1139
+
+)clear all
+
+--S 1140 of 2282
+t0:=x^5/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                5
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1140
+
+--S 1141 of 2282
+r0:=-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(b-sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+_
+   1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   sqrt(b+sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +--------------------+
+--R          |   +-----------+                  2 +-+ +-+
+--R          |   |          2                  x \|2 \|c
+--R       - \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                      |   |          2
+--R                                     \|- \|- 4a c + b   + b
+--R     + 
+--R        +------------------+
+--R        | +-----------+                 2 +-+ +-+
+--R        | |          2                 x \|2 \|c
+--R       \|\|- 4a c + b   + b atan(---------------------)
+--R                                  +------------------+
+--R                                  | +-----------+
+--R                                  | |          2
+--R                                 \|\|- 4a c + b   + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 1141
+
+--S 1142 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-------------------------------------------+
+--R          |                 +--------------------+
+--R          |      2      2   |           1
+--R          |(64a c  - 16b c) |- ------------------  + b
+--R          |                 |         3       2 2
+--R          |                \|  1024a c  - 256b c
+--R          |-------------------------------------------
+--R          |                    2     2
+--R         \|               32a c  - 8b c
+--R      *
+--R         log
+--R                                  +--------------------+
+--R                       2      2   |           1
+--R                (128a c  - 32b c) |- ------------------
+--R                                  |         3       2 2
+--R                                 \|  1024a c  - 256b c
+--R             *
+--R                 +-------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |      2      2   |           1
+--R                 |(64a c  - 16b c) |- ------------------  + b
+--R                 |                 |         3       2 2
+--R                 |                \|  1024a c  - 256b c
+--R                 |-------------------------------------------
+--R                 |                    2     2
+--R                \|               32a c  - 8b c
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R       -
+--R             +---------------------------------------------+
+--R             |                   +--------------------+
+--R             |        2      2   |           1
+--R             |(- 64a c  + 16b c) |- ------------------  + b
+--R             |                   |         3       2 2
+--R             |                  \|  1024a c  - 256b c
+--R             |---------------------------------------------
+--R             |                     2     2
+--R            \|                32a c  - 8b c
+--R         *
+--R            log
+--R                                     +--------------------+
+--R                          2      2   |           1
+--R                   (128a c  - 32b c) |- ------------------
+--R                                     |         3       2 2
+--R                                    \|  1024a c  - 256b c
+--R                *
+--R                    +---------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |        2      2   |           1
+--R                    |(- 64a c  + 16b c) |- ------------------  + b
+--R                    |                   |         3       2 2
+--R                    |                  \|  1024a c  - 256b c
+--R                    |---------------------------------------------
+--R                    |                     2     2
+--R                   \|                32a c  - 8b c
+--R               + 
+--R                  2
+--R                 x
+--R     + 
+--R          +---------------------------------------------+
+--R          |                   +--------------------+
+--R          |        2      2   |           1
+--R          |(- 64a c  + 16b c) |- ------------------  + b
+--R          |                   |         3       2 2
+--R          |                  \|  1024a c  - 256b c
+--R          |---------------------------------------------
+--R          |                     2     2
+--R         \|                32a c  - 8b c
+--R      *
+--R         log
+--R                                    +--------------------+
+--R                         2      2   |           1
+--R                (- 128a c  + 32b c) |- ------------------
+--R                                    |         3       2 2
+--R                                   \|  1024a c  - 256b c
+--R             *
+--R                 +---------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |        2      2   |           1
+--R                 |(- 64a c  + 16b c) |- ------------------  + b
+--R                 |                   |         3       2 2
+--R                 |                  \|  1024a c  - 256b c
+--R                 |---------------------------------------------
+--R                 |                     2     2
+--R                \|                32a c  - 8b c
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R       -
+--R             +-------------------------------------------+
+--R             |                 +--------------------+
+--R             |      2      2   |           1
+--R             |(64a c  - 16b c) |- ------------------  + b
+--R             |                 |         3       2 2
+--R             |                \|  1024a c  - 256b c
+--R             |-------------------------------------------
+--R             |                    2     2
+--R            \|               32a c  - 8b c
+--R         *
+--R            log
+--R                                       +--------------------+
+--R                            2      2   |           1
+--R                   (- 128a c  + 32b c) |- ------------------
+--R                                       |         3       2 2
+--R                                      \|  1024a c  - 256b c
+--R                *
+--R                    +-------------------------------------------+
+--R                    |                 +--------------------+
+--R                    |      2      2   |           1
+--R                    |(64a c  - 16b c) |- ------------------  + b
+--R                    |                 |         3       2 2
+--R                    |                \|  1024a c  - 256b c
+--R                    |-------------------------------------------
+--R                    |                    2     2
+--R                   \|               32a c  - 8b c
+--R               + 
+--R                  2
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1142
+
+--S 1143 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +-------------------------------------------+
+--R                                |                 +--------------------+
+--R                                |      2      2   |           1
+--R                                |(64a c  - 16b c) |- ------------------  + b
+--R              +-----------+     |                 |         3       2 2
+--R          +-+ |          2  +-+ |                \|  1024a c  - 256b c
+--R         \|2 \|- 4a c + b  \|c  |-------------------------------------------
+--R                                |                    2     2
+--R                               \|               32a c  - 8b c
+--R      *
+--R         log
+--R                                  +--------------------+
+--R                       2      2   |           1
+--R                (128a c  - 32b c) |- ------------------
+--R                                  |         3       2 2
+--R                                 \|  1024a c  - 256b c
+--R             *
+--R                 +-------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |      2      2   |           1
+--R                 |(64a c  - 16b c) |- ------------------  + b
+--R                 |                 |         3       2 2
+--R                 |                \|  1024a c  - 256b c
+--R                 |-------------------------------------------
+--R                 |                    2     2
+--R                \|               32a c  - 8b c
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2  +-+
+--R            \|2 \|- 4a c + b  \|c
+--R         *
+--R             +---------------------------------------------+
+--R             |                   +--------------------+
+--R             |        2      2   |           1
+--R             |(- 64a c  + 16b c) |- ------------------  + b
+--R             |                   |         3       2 2
+--R             |                  \|  1024a c  - 256b c
+--R             |---------------------------------------------
+--R             |                     2     2
+--R            \|                32a c  - 8b c
+--R         *
+--R            log
+--R                                     +--------------------+
+--R                          2      2   |           1
+--R                   (128a c  - 32b c) |- ------------------
+--R                                     |         3       2 2
+--R                                    \|  1024a c  - 256b c
+--R                *
+--R                    +---------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |        2      2   |           1
+--R                    |(- 64a c  + 16b c) |- ------------------  + b
+--R                    |                   |         3       2 2
+--R                    |                  \|  1024a c  - 256b c
+--R                    |---------------------------------------------
+--R                    |                     2     2
+--R                   \|                32a c  - 8b c
+--R               + 
+--R                  2
+--R                 x
+--R     + 
+--R                                +---------------------------------------------+
+--R                                |                   +--------------------+
+--R                                |        2      2   |           1
+--R                                |(- 64a c  + 16b c) |- ------------------  + b
+--R              +-----------+     |                   |         3       2 2
+--R          +-+ |          2  +-+ |                  \|  1024a c  - 256b c
+--R         \|2 \|- 4a c + b  \|c  |---------------------------------------------
+--R                                |                     2     2
+--R                               \|                32a c  - 8b c
+--R      *
+--R         log
+--R                                    +--------------------+
+--R                         2      2   |           1
+--R                (- 128a c  + 32b c) |- ------------------
+--R                                    |         3       2 2
+--R                                   \|  1024a c  - 256b c
+--R             *
+--R                 +---------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |        2      2   |           1
+--R                 |(- 64a c  + 16b c) |- ------------------  + b
+--R                 |                   |         3       2 2
+--R                 |                  \|  1024a c  - 256b c
+--R                 |---------------------------------------------
+--R                 |                     2     2
+--R                \|                32a c  - 8b c
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                                   +-------------------------------------------+
+--R                                   |                 +--------------------+
+--R                                   |      2      2   |           1
+--R                                   |(64a c  - 16b c) |- ------------------  + b
+--R                 +-----------+     |                 |         3       2 2
+--R             +-+ |          2  +-+ |                \|  1024a c  - 256b c
+--R            \|2 \|- 4a c + b  \|c  |-------------------------------------------
+--R                                   |                    2     2
+--R                                  \|               32a c  - 8b c
+--R         *
+--R            log
+--R                                       +--------------------+
+--R                            2      2   |           1
+--R                   (- 128a c  + 32b c) |- ------------------
+--R                                       |         3       2 2
+--R                                      \|  1024a c  - 256b c
+--R                *
+--R                    +-------------------------------------------+
+--R                    |                 +--------------------+
+--R                    |      2      2   |           1
+--R                    |(64a c  - 16b c) |- ------------------  + b
+--R                    |                 |         3       2 2
+--R                    |                \|  1024a c  - 256b c
+--R                    |-------------------------------------------
+--R                    |                    2     2
+--R                   \|               32a c  - 8b c
+--R               + 
+--R                  2
+--R                 x
+--R     + 
+--R        +--------------------+
+--R        |   +-----------+                  2 +-+ +-+
+--R        |   |          2                  x \|2 \|c
+--R       \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                 2 +-+ +-+
+--R          | |          2                 x \|2 \|c
+--R       - \|\|- 4a c + b   + b atan(---------------------)
+--R                                    +------------------+
+--R                                    | +-----------+
+--R                                    | |          2
+--R                                   \|\|- 4a c + b   + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 1143
+
+--S 1144 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1144
+
+)clear all
+
+--S 1145 of 2282
+t0:=x^3/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1145
+
+--S 1146 of 2282
+r0:=-1/2*atanh((b+2*c*x^4)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                       4
+--R                   2c x  + b
+--R          atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R   (2)  - ---------------------
+--R               +-----------+
+--R               |          2
+--R             2\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1146
+
+--S 1147 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                            +-----------+
+--R                 2 8         4           2  |          2         2     2   4
+--R              (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               8      4
+--R            c x  + b x  + a
+--R    /
+--R         +-----------+
+--R         |          2
+--R       4\|- 4a c + b
+--R     ,
+--R                     +---------+
+--R              4      |        2
+--R         (2c x  + b)\|4a c - b
+--R    atan(-----------------------)
+--R                        2
+--R                4a c - b
+--R    -----------------------------]
+--R              +---------+
+--R              |        2
+--R            2\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1147
+
+--S 1148 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                            +-----------+
+--R                 2 8         4           2  |          2         2     2   4
+--R              (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               8      4
+--R            c x  + b x  + a
+--R     + 
+--R                     4
+--R                 2c x  + b
+--R       2atanh(--------------)
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R  /
+--R       +-----------+
+--R       |          2
+--R     4\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1148
+
+--S 1149 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1149
+
+--S 1150 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        +---------+             4
+--R        |        2          2c x  + b
+--R       \|4a c - b  atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                      +---------+
+--R        +-----------+          4      |        2
+--R        |          2      (2c x  + b)\|4a c - b
+--R       \|- 4a c + b  atan(-----------------------)
+--R                                         2
+--R                                 4a c - b
+--R  /
+--R       +-----------+ +---------+
+--R       |          2  |        2
+--R     2\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1150
+
+--S 1151 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1151
+
+)clear all
+
+--S 1152 of 2282
+t0:=x/(a+b*x^4+c*x^8)
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1152
+
+--S 1153 of 2282
+r0:=atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)/_
+   (sqrt(2)*sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x^2*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)/(sqrt(2)*sqrt(b^2-4*a*c)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R            +------------------+
+--R            | +-----------+                  2 +-+ +-+
+--R        +-+ | |          2                  x \|2 \|c
+--R       \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                      |   |          2
+--R                                     \|- \|- 4a c + b   + b
+--R     + 
+--R              +--------------------+
+--R              |   +-----------+                 2 +-+ +-+
+--R          +-+ |   |          2                 x \|2 \|c
+--R       - \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R      +-+ |          2  |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1153
+
+--S 1154 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +------------------------------------------+
+--R          |                 +-------------------+
+--R          |    2         2  |          1
+--R          |(64a c - 16a b ) |- -----------------  + b
+--R          |                 |       3        2 2
+--R          |                \|  1024a c - 256a b
+--R          |------------------------------------------
+--R          |                  2        2
+--R         \|               32a c - 8a b
+--R      *
+--R         log
+--R                                    +-------------------+
+--R                     2           3  |          1                    2
+--R                ((64a b c - 16a b ) |- -----------------  + 4a c - b )
+--R                                    |       3        2 2
+--R                                   \|  1024a c - 256a b
+--R             *
+--R                 +------------------------------------------+
+--R                 |                 +-------------------+
+--R                 |    2         2  |          1
+--R                 |(64a c - 16a b ) |- -----------------  + b
+--R                 |                 |       3        2 2
+--R                 |                \|  1024a c - 256a b
+--R                 |------------------------------------------
+--R                 |                  2        2
+--R                \|               32a c - 8a b
+--R            + 
+--R                 2
+--R              c x
+--R     + 
+--R       -
+--R             +--------------------------------------------+
+--R             |                   +-------------------+
+--R             |      2         2  |          1
+--R             |(- 64a c + 16a b ) |- -----------------  + b
+--R             |                   |       3        2 2
+--R             |                  \|  1024a c - 256a b
+--R             |--------------------------------------------
+--R             |                   2        2
+--R            \|                32a c - 8a b
+--R         *
+--R            log
+--R                                       +-------------------+
+--R                        2           3  |          1                    2
+--R                   ((64a b c - 16a b ) |- -----------------  - 4a c + b )
+--R                                       |       3        2 2
+--R                                      \|  1024a c - 256a b
+--R                *
+--R                    +--------------------------------------------+
+--R                    |                   +-------------------+
+--R                    |      2         2  |          1
+--R                    |(- 64a c + 16a b ) |- -----------------  + b
+--R                    |                   |       3        2 2
+--R                    |                  \|  1024a c - 256a b
+--R                    |--------------------------------------------
+--R                    |                   2        2
+--R                   \|                32a c - 8a b
+--R               + 
+--R                    2
+--R                 c x
+--R     + 
+--R          +--------------------------------------------+
+--R          |                   +-------------------+
+--R          |      2         2  |          1
+--R          |(- 64a c + 16a b ) |- -----------------  + b
+--R          |                   |       3        2 2
+--R          |                  \|  1024a c - 256a b
+--R          |--------------------------------------------
+--R          |                   2        2
+--R         \|                32a c - 8a b
+--R      *
+--R         log
+--R                                      +-------------------+
+--R                       2           3  |          1                    2
+--R                ((- 64a b c + 16a b ) |- -----------------  + 4a c - b )
+--R                                      |       3        2 2
+--R                                     \|  1024a c - 256a b
+--R             *
+--R                 +--------------------------------------------+
+--R                 |                   +-------------------+
+--R                 |      2         2  |          1
+--R                 |(- 64a c + 16a b ) |- -----------------  + b
+--R                 |                   |       3        2 2
+--R                 |                  \|  1024a c - 256a b
+--R                 |--------------------------------------------
+--R                 |                   2        2
+--R                \|                32a c - 8a b
+--R            + 
+--R                 2
+--R              c x
+--R     + 
+--R       -
+--R             +------------------------------------------+
+--R             |                 +-------------------+
+--R             |    2         2  |          1
+--R             |(64a c - 16a b ) |- -----------------  + b
+--R             |                 |       3        2 2
+--R             |                \|  1024a c - 256a b
+--R             |------------------------------------------
+--R             |                  2        2
+--R            \|               32a c - 8a b
+--R         *
+--R            log
+--R                                         +-------------------+
+--R                          2           3  |          1                    2
+--R                   ((- 64a b c + 16a b ) |- -----------------  - 4a c + b )
+--R                                         |       3        2 2
+--R                                        \|  1024a c - 256a b
+--R                *
+--R                    +------------------------------------------+
+--R                    |                 +-------------------+
+--R                    |    2         2  |          1
+--R                    |(64a c - 16a b ) |- -----------------  + b
+--R                    |                 |       3        2 2
+--R                    |                \|  1024a c - 256a b
+--R                    |------------------------------------------
+--R                    |                  2        2
+--R                   \|               32a c - 8a b
+--R               + 
+--R                    2
+--R                 c x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1154
+
+--S 1155 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +------------------------------------------+
+--R          |                 +-------------------+
+--R          |    2         2  |          1
+--R          |(64a c - 16a b ) |- -----------------  + b
+--R          |                 |       3        2 2
+--R          |                \|  1024a c - 256a b
+--R          |------------------------------------------
+--R          |                  2        2
+--R         \|               32a c - 8a b
+--R      *
+--R         log
+--R                                    +-------------------+
+--R                     2           3  |          1                    2
+--R                ((64a b c - 16a b ) |- -----------------  + 4a c - b )
+--R                                    |       3        2 2
+--R                                   \|  1024a c - 256a b
+--R             *
+--R                 +------------------------------------------+
+--R                 |                 +-------------------+
+--R                 |    2         2  |          1
+--R                 |(64a c - 16a b ) |- -----------------  + b
+--R                 |                 |       3        2 2
+--R                 |                \|  1024a c - 256a b
+--R                 |------------------------------------------
+--R                 |                  2        2
+--R                \|               32a c - 8a b
+--R            + 
+--R                 2
+--R              c x
+--R     + 
+--R       -
+--R                               +--------------------------------------------+
+--R                               |                   +-------------------+
+--R                               |      2         2  |          1
+--R                               |(- 64a c + 16a b ) |- -----------------  + b
+--R                 +-----------+ |                   |       3        2 2
+--R             +-+ |          2  |                  \|  1024a c - 256a b
+--R            \|2 \|- 4a c + b   |--------------------------------------------
+--R                               |                   2        2
+--R                              \|                32a c - 8a b
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                       +-------------------+
+--R                        2           3  |          1                    2
+--R                   ((64a b c - 16a b ) |- -----------------  - 4a c + b )
+--R                                       |       3        2 2
+--R                                      \|  1024a c - 256a b
+--R                *
+--R                    +--------------------------------------------+
+--R                    |                   +-------------------+
+--R                    |      2         2  |          1
+--R                    |(- 64a c + 16a b ) |- -----------------  + b
+--R                    |                   |       3        2 2
+--R                    |                  \|  1024a c - 256a b
+--R                    |--------------------------------------------
+--R                    |                   2        2
+--R                   \|                32a c - 8a b
+--R               + 
+--R                    2
+--R                 c x
+--R     + 
+--R                            +--------------------------------------------+
+--R                            |                   +-------------------+
+--R                            |      2         2  |          1
+--R                            |(- 64a c + 16a b ) |- -----------------  + b
+--R              +-----------+ |                   |       3        2 2
+--R          +-+ |          2  |                  \|  1024a c - 256a b
+--R         \|2 \|- 4a c + b   |--------------------------------------------
+--R                            |                   2        2
+--R                           \|                32a c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                      +-------------------+
+--R                       2           3  |          1                    2
+--R                ((- 64a b c + 16a b ) |- -----------------  + 4a c - b )
+--R                                      |       3        2 2
+--R                                     \|  1024a c - 256a b
+--R             *
+--R                 +--------------------------------------------+
+--R                 |                   +-------------------+
+--R                 |      2         2  |          1
+--R                 |(- 64a c + 16a b ) |- -----------------  + b
+--R                 |                   |       3        2 2
+--R                 |                  \|  1024a c - 256a b
+--R                 |--------------------------------------------
+--R                 |                   2        2
+--R                \|                32a c - 8a b
+--R            + 
+--R                 2
+--R              c x
+--R     + 
+--R       -
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R             +-+ |          2  |   |          2       | |          2
+--R            \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +------------------------------------------+
+--R             |                 +-------------------+
+--R             |    2         2  |          1
+--R             |(64a c - 16a b ) |- -----------------  + b
+--R             |                 |       3        2 2
+--R             |                \|  1024a c - 256a b
+--R             |------------------------------------------
+--R             |                  2        2
+--R            \|               32a c - 8a b
+--R         *
+--R            log
+--R                                         +-------------------+
+--R                          2           3  |          1                    2
+--R                   ((- 64a b c + 16a b ) |- -----------------  - 4a c + b )
+--R                                         |       3        2 2
+--R                                        \|  1024a c - 256a b
+--R                *
+--R                    +------------------------------------------+
+--R                    |                 +-------------------+
+--R                    |    2         2  |          1
+--R                    |(64a c - 16a b ) |- -----------------  + b
+--R                    |                 |       3        2 2
+--R                    |                \|  1024a c - 256a b
+--R                    |------------------------------------------
+--R                    |                  2        2
+--R                   \|               32a c - 8a b
+--R               + 
+--R                    2
+--R                 c x
+--R     + 
+--R               +------------------+
+--R               | +-----------+                  2 +-+ +-+
+--R           +-+ | |          2                  x \|2 \|c
+--R       - 2\|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                         |   |          2
+--R                                        \|- \|- 4a c + b   + b
+--R     + 
+--R             +--------------------+
+--R             |   +-----------+                 2 +-+ +-+
+--R         +-+ |   |          2                 x \|2 \|c
+--R       2\|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                         +------------------+
+--R                                         | +-----------+
+--R                                         | |          2
+--R                                        \|\|- 4a c + b   + b
+--R  /
+--R                         +--------------------+ +------------------+
+--R           +-----------+ |   +-----------+      | +-----------+
+--R       +-+ |          2  |   |          2       | |          2
+--R     2\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1155
+
+--S 1156 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1156
+
+)clear all
+
+--S 1157 of 2282
+t0:=1/(x*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           9      5
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1157
+
+--S 1158 of 2282
+r0:=log(x)/a-1/8*log(a+b*x^4+c*x^8)/a+1/4*b*atanh((b+2*c*x^4)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                   4                                             +-----------+
+--R               2c x  + b                8      4                 |          2
+--R   2b atanh(--------------) + (- log(c x  + b x  + a) + 8log(x))\|- 4a c + b
+--R             +-----------+
+--R             |          2
+--R            \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                    +-----------+
+--R                                    |          2
+--R                                 8a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1158
+
+--S 1159 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 8         4           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   4             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   8      4
+--R                c x  + b x  + a
+--R       + 
+--R                                            +-----------+
+--R                   8      4                 |          2
+--R         (- log(c x  + b x  + a) + 8log(x))\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       8a\|- 4a c + b
+--R     ,
+--R
+--R                               +---------+
+--R                        4      |        2
+--R                   (2c x  + b)\|4a c - b
+--R         - 2b atan(-----------------------)
+--R                                  2
+--R                          4a c - b
+--R       + 
+--R                                            +---------+
+--R                   8      4                 |        2
+--R         (- log(c x  + b x  + a) + 8log(x))\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       8a\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1159
+
+--S 1160 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 8         4           2  |          2           2     2   4
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 8      4
+--R              c x  + b x  + a
+--R     + 
+--R                         4
+--R                     2c x  + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     8a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1160
+
+--S 1161 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1161
+
+--S 1162 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             4
+--R           |        2          2c x  + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          4      |        2
+--R           |          2      (2c x  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     4a\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1162
+
+--S 1163 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1163
+
+)clear all
+
+--S 1164 of 2282
+t0:=1/(x^3*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R           11      7      3
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1164
+
+--S 1165 of 2282
+r0:=(-1/2)/(a*x^2)-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(1+b/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (1-b/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R               +-----------+             | +-----------+
+--R             2 |          2       2  +-+ | |          2
+--R         (- x \|- 4a c + b   - b x )\|c \|\|- 4a c + b   + b
+--R      *
+--R                      2 +-+ +-+
+--R                     x \|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R               +-----------+             |   +-----------+
+--R             2 |          2       2  +-+ |   |          2
+--R         (- x \|- 4a c + b   + b x )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                     2 +-+ +-+
+--R                    x \|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R       - \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R         2 +-+ |          2  |   |          2       | |          2
+--R     2a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1165
+
+--S 1166 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                 +-----------------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |                 |   2 2       2     4
+--R                 |    4       3 2  |- a c  + 2a b c - b               3
+--R                 |(64a c - 16a b ) |--------------------  - 3a b c + b
+--R                 |                 |       7        6 2
+--R               2 |                \|  1024a c - 256a b
+--R            a x  |-----------------------------------------------------
+--R                 |                       4      3 2
+--R                \|                    32a c - 8a b
+--R         *
+--R            log
+--R                                                  +--------------------+
+--R                                                  |   2 2       2     4
+--R                          5 2      4 2       3 4  |- a c  + 2a b c - b
+--R                     (128a c  - 96a b c + 16a b ) |--------------------
+--R                                                  |       7        6 2
+--R                                                 \|  1024a c - 256a b
+--R                   + 
+--R                       2   2       3     5
+--R                     4a b c  - 5a b c + b
+--R                *
+--R                    +-----------------------------------------------------+
+--R                    |                 +--------------------+
+--R                    |                 |   2 2       2     4
+--R                    |    4       3 2  |- a c  + 2a b c - b               3
+--R                    |(64a c - 16a b ) |--------------------  - 3a b c + b
+--R                    |                 |       7        6 2
+--R                    |                \|  1024a c - 256a b
+--R                    |-----------------------------------------------------
+--R                    |                       4      3 2
+--R                   \|                    32a c - 8a b
+--R               + 
+--R                     3    2 2  2
+--R                 (a c  - b c )x
+--R     + 
+--R              +-------------------------------------------------------+
+--R              |                   +--------------------+
+--R              |                   |   2 2       2     4
+--R              |      4       3 2  |- a c  + 2a b c - b               3
+--R              |(- 64a c + 16a b ) |--------------------  - 3a b c + b
+--R              |                   |       7        6 2
+--R            2 |                  \|  1024a c - 256a b
+--R         a x  |-------------------------------------------------------
+--R              |                        4      3 2
+--R             \|                     32a c - 8a b
+--R      *
+--R         log
+--R                                               +--------------------+
+--R                                               |   2 2       2     4
+--R                       5 2      4 2       3 4  |- a c  + 2a b c - b       2   2
+--R                  (128a c  - 96a b c + 16a b ) |--------------------  - 4a b c
+--R                                               |       7        6 2
+--R                                              \|  1024a c - 256a b
+--R                + 
+--R                      3     5
+--R                  5a b c - b
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |      4       3 2  |- a c  + 2a b c - b               3
+--R                 |(- 64a c + 16a b ) |--------------------  - 3a b c + b
+--R                 |                   |       7        6 2
+--R                 |                  \|  1024a c - 256a b
+--R                 |-------------------------------------------------------
+--R                 |                        4      3 2
+--R                \|                     32a c - 8a b
+--R            + 
+--R                  3    2 2  2
+--R              (a c  - b c )x
+--R     + 
+--R       -
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |      4       3 2  |- a c  + 2a b c - b               3
+--R                 |(- 64a c + 16a b ) |--------------------  - 3a b c + b
+--R                 |                   |       7        6 2
+--R               2 |                  \|  1024a c - 256a b
+--R            a x  |-------------------------------------------------------
+--R                 |                        4      3 2
+--R                \|                     32a c - 8a b
+--R         *
+--R            log
+--R                                                    +--------------------+
+--R                                                    |   2 2       2     4
+--R                            5 2      4 2       3 4  |- a c  + 2a b c - b
+--R                     (- 128a c  + 96a b c - 16a b ) |--------------------
+--R                                                    |       7        6 2
+--R                                                   \|  1024a c - 256a b
+--R                   + 
+--R                       2   2       3     5
+--R                     4a b c  - 5a b c + b
+--R                *
+--R                    +-------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |      4       3 2  |- a c  + 2a b c - b               3
+--R                    |(- 64a c + 16a b ) |--------------------  - 3a b c + b
+--R                    |                   |       7        6 2
+--R                    |                  \|  1024a c - 256a b
+--R                    |-------------------------------------------------------
+--R                    |                        4      3 2
+--R                   \|                     32a c - 8a b
+--R               + 
+--R                     3    2 2  2
+--R                 (a c  - b c )x
+--R     + 
+--R              +-----------------------------------------------------+
+--R              |                 +--------------------+
+--R              |                 |   2 2       2     4
+--R              |    4       3 2  |- a c  + 2a b c - b               3
+--R              |(64a c - 16a b ) |--------------------  - 3a b c + b
+--R              |                 |       7        6 2
+--R            2 |                \|  1024a c - 256a b
+--R         a x  |-----------------------------------------------------
+--R              |                       4      3 2
+--R             \|                    32a c - 8a b
+--R      *
+--R         log
+--R                                                 +--------------------+
+--R                                                 |   2 2       2     4
+--R                         5 2      4 2       3 4  |- a c  + 2a b c - b
+--R                  (- 128a c  + 96a b c - 16a b ) |--------------------
+--R                                                 |       7        6 2
+--R                                                \|  1024a c - 256a b
+--R                + 
+--R                      2   2       3     5
+--R                  - 4a b c  + 5a b c - b
+--R             *
+--R                 +-----------------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |                 |   2 2       2     4
+--R                 |    4       3 2  |- a c  + 2a b c - b               3
+--R                 |(64a c - 16a b ) |--------------------  - 3a b c + b
+--R                 |                 |       7        6 2
+--R                 |                \|  1024a c - 256a b
+--R                 |-----------------------------------------------------
+--R                 |                       4      3 2
+--R                \|                    32a c - 8a b
+--R            + 
+--R                  3    2 2  2
+--R              (a c  - b c )x
+--R     + 
+--R       - 1
+--R  /
+--R         2
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1166
+
+--S 1167 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R              +-+ |          2  |   |          2       | |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +-----------------------------------------------------+
+--R             |                 +--------------------+
+--R             |                 |   2 2       2     4
+--R             |    4       3 2  |- a c  + 2a b c - b               3
+--R             |(64a c - 16a b ) |--------------------  - 3a b c + b
+--R             |                 |       7        6 2
+--R             |                \|  1024a c - 256a b
+--R             |-----------------------------------------------------
+--R             |                       4      3 2
+--R            \|                    32a c - 8a b
+--R         *
+--R            log
+--R                                                  +--------------------+
+--R                                                  |   2 2       2     4
+--R                          5 2      4 2       3 4  |- a c  + 2a b c - b
+--R                     (128a c  - 96a b c + 16a b ) |--------------------
+--R                                                  |       7        6 2
+--R                                                 \|  1024a c - 256a b
+--R                   + 
+--R                       2   2       3     5
+--R                     4a b c  - 5a b c + b
+--R                *
+--R                    +-----------------------------------------------------+
+--R                    |                 +--------------------+
+--R                    |                 |   2 2       2     4
+--R                    |    4       3 2  |- a c  + 2a b c - b               3
+--R                    |(64a c - 16a b ) |--------------------  - 3a b c + b
+--R                    |                 |       7        6 2
+--R                    |                \|  1024a c - 256a b
+--R                    |-----------------------------------------------------
+--R                    |                       4      3 2
+--R                   \|                    32a c - 8a b
+--R               + 
+--R                     3    2 2  2
+--R                 (a c  - b c )x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2
+--R         a\|2 \|- 4a c + b
+--R      *
+--R          +-------------------------------------------------------+
+--R          |                   +--------------------+
+--R          |                   |   2 2       2     4
+--R          |      4       3 2  |- a c  + 2a b c - b               3
+--R          |(- 64a c + 16a b ) |--------------------  - 3a b c + b
+--R          |                   |       7        6 2
+--R          |                  \|  1024a c - 256a b
+--R          |-------------------------------------------------------
+--R          |                        4      3 2
+--R         \|                     32a c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                               +--------------------+
+--R                                               |   2 2       2     4
+--R                       5 2      4 2       3 4  |- a c  + 2a b c - b       2   2
+--R                  (128a c  - 96a b c + 16a b ) |--------------------  - 4a b c
+--R                                               |       7        6 2
+--R                                              \|  1024a c - 256a b
+--R                + 
+--R                      3     5
+--R                  5a b c - b
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |      4       3 2  |- a c  + 2a b c - b               3
+--R                 |(- 64a c + 16a b ) |--------------------  - 3a b c + b
+--R                 |                   |       7        6 2
+--R                 |                  \|  1024a c - 256a b
+--R                 |-------------------------------------------------------
+--R                 |                        4      3 2
+--R                \|                     32a c - 8a b
+--R            + 
+--R                  3    2 2  2
+--R              (a c  - b c )x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2
+--R            a\|2 \|- 4a c + b
+--R         *
+--R             +-------------------------------------------------------+
+--R             |                   +--------------------+
+--R             |                   |   2 2       2     4
+--R             |      4       3 2  |- a c  + 2a b c - b               3
+--R             |(- 64a c + 16a b ) |--------------------  - 3a b c + b
+--R             |                   |       7        6 2
+--R             |                  \|  1024a c - 256a b
+--R             |-------------------------------------------------------
+--R             |                        4      3 2
+--R            \|                     32a c - 8a b
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                                    +--------------------+
+--R                                                    |   2 2       2     4
+--R                            5 2      4 2       3 4  |- a c  + 2a b c - b
+--R                     (- 128a c  + 96a b c - 16a b ) |--------------------
+--R                                                    |       7        6 2
+--R                                                   \|  1024a c - 256a b
+--R                   + 
+--R                       2   2       3     5
+--R                     4a b c  - 5a b c + b
+--R                *
+--R                    +-------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |      4       3 2  |- a c  + 2a b c - b               3
+--R                    |(- 64a c + 16a b ) |--------------------  - 3a b c + b
+--R                    |                   |       7        6 2
+--R                    |                  \|  1024a c - 256a b
+--R                    |-------------------------------------------------------
+--R                    |                        4      3 2
+--R                   \|                     32a c - 8a b
+--R               + 
+--R                     3    2 2  2
+--R                 (a c  - b c )x
+--R     + 
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R           +-+ |          2  |   |          2       | |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------------------------------------+
+--R          |                 +--------------------+
+--R          |                 |   2 2       2     4
+--R          |    4       3 2  |- a c  + 2a b c - b               3
+--R          |(64a c - 16a b ) |--------------------  - 3a b c + b
+--R          |                 |       7        6 2
+--R          |                \|  1024a c - 256a b
+--R          |-----------------------------------------------------
+--R          |                       4      3 2
+--R         \|                    32a c - 8a b
+--R      *
+--R         log
+--R                                                 +--------------------+
+--R                                                 |   2 2       2     4
+--R                         5 2      4 2       3 4  |- a c  + 2a b c - b
+--R                  (- 128a c  + 96a b c - 16a b ) |--------------------
+--R                                                 |       7        6 2
+--R                                                \|  1024a c - 256a b
+--R                + 
+--R                      2   2       3     5
+--R                  - 4a b c  + 5a b c - b
+--R             *
+--R                 +-----------------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |                 |   2 2       2     4
+--R                 |    4       3 2  |- a c  + 2a b c - b               3
+--R                 |(64a c - 16a b ) |--------------------  - 3a b c + b
+--R                 |                 |       7        6 2
+--R                 |                \|  1024a c - 256a b
+--R                 |-----------------------------------------------------
+--R                 |                       4      3 2
+--R                \|                    32a c - 8a b
+--R            + 
+--R                  3    2 2  2
+--R              (a c  - b c )x
+--R     + 
+--R                                  +------------------+
+--R           +-----------+          | +-----------+
+--R           |          2       +-+ | |          2
+--R         (\|- 4a c + b   + b)\|c \|\|- 4a c + b   + b
+--R      *
+--R                      2 +-+ +-+
+--R                     x \|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                              +--------------------+
+--R       +-----------+          |   +-----------+                 2 +-+ +-+
+--R       |          2       +-+ |   |          2                 x \|2 \|c
+--R     (\|- 4a c + b   - b)\|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                                          +------------------+
+--R                                                          | +-----------+
+--R                                                          | |          2
+--R                                                         \|\|- 4a c + b   + b
+--R  /
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R     2a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1167
+
+--S 1168 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1168
+
+)clear all
+
+--S 1169 of 2282
+t0:=1/(x^5*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R           13      9      5
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1169
+
+--S 1170 of 2282
+r0:=(-1/4)/(a*x^4)-b*log(x)/a^2+1/8*b*log(a+b*x^4+c*x^8)/a^2-_
+   1/4*(b^2-2*a*c)*atanh((b+2*c*x^4)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                  4
+--R                 2  4         2c x  + b
+--R       (4a c - 2b )x atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R           4       8      4            4             |          2
+--R       (b x log(c x  + b x  + a) - 8b x log(x) - 2a)\|- 4a c + b
+--R  /
+--R           +-----------+
+--R       2 4 |          2
+--R     8a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1170
+
+--S 1171 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2  4
+--R           (2a c - b )x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 8         4           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   4             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   8      4
+--R                c x  + b x  + a
+--R       + 
+--R                                                       +-----------+
+--R             4       8      4            4             |          2
+--R         (b x log(c x  + b x  + a) - 8b x log(x) - 2a)\|- 4a c + b
+--R    /
+--R             +-----------+
+--R         2 4 |          2
+--R       8a x \|- 4a c + b
+--R     ,
+--R
+--R                                          +---------+
+--R                                   4      |        2
+--R                     2  4     (2c x  + b)\|4a c - b
+--R         (- 4a c + 2b )x atan(-----------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R                                                       +---------+
+--R             4       8      4            4             |        2
+--R         (b x log(c x  + b x  + a) - 8b x log(x) - 2a)\|4a c - b
+--R    /
+--R             +---------+
+--R         2 4 |        2
+--R       8a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1171
+
+--S 1172 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 8         4           2  |          2           2     2   4
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 8      4
+--R              c x  + b x  + a
+--R     + 
+--R                                  4
+--R                   2          2c x  + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     8a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1172
+
+--S 1173 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1173
+
+--S 1174 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+             4
+--R                  2  |        2          2c x  + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                     +-----------+          4      |        2
+--R                  2  |          2      (2c x  + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     4a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1174
+
+--S 1175 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1175
+
+)clear all
+
+--S 1176 of 2282
+t0:=x^10/(a+b*x^4+c*x^8)
+--R 
+--R
+--R               10
+--R              x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1176
+
+--S 1177 of 2282
+r0:=1/3*x^3/c-1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-1/2*atan(2^(1/4)*c^(1/4)*x/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   c^(7/4)*(-b+sqrt(b^2-4*a*c))^(1/4))+1/2*atanh(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   c^(7/4)*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R             +-----------+               | +-----------+
+--R             |          2             2 4| |          2
+--R         (3b\|- 4a c + b   - 6a c + 3b )\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                         +--------------------+
+--R             +-----------+               |   +-----------+
+--R             |          2             2 4|   |          2
+--R         (3b\|- 4a c + b   + 6a c - 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                           +------------------+
+--R               +-----------+               | +-----------+
+--R               |          2             2 4| |          2
+--R         (- 3b\|- 4a c + b   + 6a c - 3b )\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+
+--R               +-----------+               |   +-----------+
+--R               |          2             2 4|   |          2
+--R         (- 3b\|- 4a c + b   - 6a c + 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                                     +--------------------+ +------------------+
+--R                 +-----------+       |   +-----------+      | +-----------+
+--R         3 4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R       2x  \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                                  +--------------------+ +------------------+
+--R              +-----------+       |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R     6c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1177
+
+--S 1178 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 9          2 8       4 7
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        2 9          2 8       4 7
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                             5   12           4 3 11          3 5 10
+--R                      655360a b c   - 1146880a b c   + 745472a b c
+--R                    + 
+--R                               2 7 9           9 8        11 7
+--R                      - 231424a b c  + 34816a b c  - 2048b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                                   3 17           2 2 16            4 15
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 14
+--R                           - 65536b c
+--R                + 
+--R                      7 7        6 2 6        5 4 5        4 6 4        3 8 3
+--R                  128a c  - 1216a b c  + 3656a b c  - 4424a b c  + 2624a b c
+--R                + 
+--R                        2 10 2         12      14
+--R                  - 816a b  c  + 128a b  c - 8b
+--R             *
+--R                ROOT
+--R                               2 9          2 8       4 7
+--R                         (4096a c  - 2048a b c  + 256b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                        3 17           2 2 16            4 15
+--R                                4194304a c   - 3145728a b c   + 786432a b c
+--R                              + 
+--R                                        6 14
+--R                                - 65536b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                          2 9          2 8       4 7
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 9          2 8       4 7
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             3 17           2 2 16
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 15         6 14
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               2 9          2 8       4 7
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                8 3     7 2 2     6 4     5 6
+--R              (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 9          2 8       4 7
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         3 17           2 2 16            4 15
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 14
+--R                                 - 65536b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           2 9          2 8       4 7
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                                5   12           4 3 11          3 5 10
+--R                         655360a b c   - 1146880a b c   + 745472a b c
+--R                       + 
+--R                                  2 7 9           9 8        11 7
+--R                         - 231424a b c  + 34816a b c  - 2048b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                           7 7        6 2 6        5 4 5        4 6 4
+--R                     - 128a c  + 1216a b c  - 3656a b c  + 4424a b c
+--R                   + 
+--R                            3 8 3       2 10 2         12      14
+--R                     - 2624a b c  + 816a b  c  - 128a b  c + 8b
+--R                *
+--R                   ROOT
+--R                                    2 9          2 8       4 7
+--R                            (- 4096a c  + 2048a b c  - 256b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                           3 17           2 2 16            4 15
+--R                                   4194304a c   - 3145728a b c   + 786432a b c
+--R                                 + 
+--R                                           6 14
+--R                                   - 65536b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                             2 9          2 8       4 7
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 9          2 8       4 7
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                3 17           2 2 16
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 15         6 14
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  2 9          2 8       4 7
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   8 3     7 2 2     6 4     5 6
+--R                 (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 9          2 8       4 7
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        2 9          2 8       4 7
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                               5   12           4 3 11          3 5 10
+--R                      - 655360a b c   + 1146880a b c   - 745472a b c
+--R                    + 
+--R                             2 7 9           9 8        11 7
+--R                      231424a b c  - 34816a b c  + 2048b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                                   3 17           2 2 16            4 15
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 14
+--R                           - 65536b c
+--R                + 
+--R                      7 7        6 2 6        5 4 5        4 6 4        3 8 3
+--R                  128a c  - 1216a b c  + 3656a b c  - 4424a b c  + 2624a b c
+--R                + 
+--R                        2 10 2         12      14
+--R                  - 816a b  c  + 128a b  c - 8b
+--R             *
+--R                ROOT
+--R                                 2 9          2 8       4 7
+--R                         (- 4096a c  + 2048a b c  - 256b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                        3 17           2 2 16            4 15
+--R                                4194304a c   - 3145728a b c   + 786432a b c
+--R                              + 
+--R                                        6 14
+--R                                - 65536b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                          2 9          2 8       4 7
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 9          2 8       4 7
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             3 17           2 2 16
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 15         6 14
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               2 9          2 8       4 7
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                8 3     7 2 2     6 4     5 6
+--R              (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 9          2 8       4 7
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         3 17           2 2 16            4 15
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 14
+--R                                 - 65536b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           2 9          2 8       4 7
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                                  5   12           4 3 11          3 5 10
+--R                         - 655360a b c   + 1146880a b c   - 745472a b c
+--R                       + 
+--R                                2 7 9           9 8        11 7
+--R                         231424a b c  - 34816a b c  + 2048b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                           7 7        6 2 6        5 4 5        4 6 4
+--R                     - 128a c  + 1216a b c  - 3656a b c  + 4424a b c
+--R                   + 
+--R                            3 8 3       2 10 2         12      14
+--R                     - 2624a b c  + 816a b  c  - 128a b  c + 8b
+--R                *
+--R                   ROOT
+--R                                  2 9          2 8       4 7
+--R                            (4096a c  - 2048a b c  + 256b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                           3 17           2 2 16            4 15
+--R                                   4194304a c   - 3145728a b c   + 786432a b c
+--R                                 + 
+--R                                           6 14
+--R                                   - 65536b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                             2 9          2 8       4 7
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 9          2 8       4 7
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                3 17           2 2 16
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 15         6 14
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  2 9          2 8       4 7
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   8 3     7 2 2     6 4     5 6
+--R                 (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 9          2 8       4 7
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        2 9          2 8       4 7
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         atan
+--R                             5   12           4 3 11          3 5 10
+--R                      655360a b c   - 1146880a b c   + 745472a b c
+--R                    + 
+--R                               2 7 9           9 8        11 7
+--R                      - 231424a b c  + 34816a b c  - 2048b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                                   3 17           2 2 16            4 15
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 14
+--R                           - 65536b c
+--R                + 
+--R                      7 7        6 2 6        5 4 5        4 6 4        3 8 3
+--R                  128a c  - 1216a b c  + 3656a b c  - 4424a b c  + 2624a b c
+--R                + 
+--R                        2 10 2         12      14
+--R                  - 816a b  c  + 128a b  c - 8b
+--R             *
+--R                ROOT
+--R                               2 9          2 8       4 7
+--R                         (4096a c  - 2048a b c  + 256b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                        3 17           2 2 16            4 15
+--R                                4194304a c   - 3145728a b c   + 786432a b c
+--R                              + 
+--R                                        6 14
+--R                                - 65536b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                          2 9          2 8       4 7
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 9          2 8       4 7
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             3 17           2 2 16
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 15         6 14
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               2 9          2 8       4 7
+--R                          2048a c  - 1024a b c  + 128b c
+--R           /
+--R                8 3     7 2 2     6 4     5 6
+--R              (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 9          2 8       4 7
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         3 17           2 2 16            4 15
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 14
+--R                                 - 65536b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           2 9          2 8       4 7
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            atan
+--R                                5   12           4 3 11          3 5 10
+--R                         655360a b c   - 1146880a b c   + 745472a b c
+--R                       + 
+--R                                  2 7 9           9 8        11 7
+--R                         - 231424a b c  + 34816a b c  - 2048b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                           7 7        6 2 6        5 4 5        4 6 4
+--R                     - 128a c  + 1216a b c  - 3656a b c  + 4424a b c
+--R                   + 
+--R                            3 8 3       2 10 2         12      14
+--R                     - 2624a b c  + 816a b  c  - 128a b  c + 8b
+--R                *
+--R                   ROOT
+--R                                    2 9          2 8       4 7
+--R                            (- 4096a c  + 2048a b c  - 256b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                           3 17           2 2 16            4 15
+--R                                   4194304a c   - 3145728a b c   + 786432a b c
+--R                                 + 
+--R                                           6 14
+--R                                   - 65536b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                             2 9          2 8       4 7
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 9          2 8       4 7
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                3 17           2 2 16
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 15         6 14
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  2 9          2 8       4 7
+--R                             2048a c  - 1024a b c  + 128b c
+--R              /
+--R                   8 3     7 2 2     6 4     5 6
+--R                 (a c  - 6a b c  + 5a b c - a b )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1178
+
+--S 1179 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R            4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R         3c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 9          2 8       4 7
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        2 9          2 8       4 7
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                             5   12           4 3 11          3 5 10
+--R                      655360a b c   - 1146880a b c   + 745472a b c
+--R                    + 
+--R                               2 7 9           9 8        11 7
+--R                      - 231424a b c  + 34816a b c  - 2048b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                                   3 17           2 2 16            4 15
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 14
+--R                           - 65536b c
+--R                + 
+--R                      7 7        6 2 6        5 4 5        4 6 4        3 8 3
+--R                  128a c  - 1216a b c  + 3656a b c  - 4424a b c  + 2624a b c
+--R                + 
+--R                        2 10 2         12      14
+--R                  - 816a b  c  + 128a b  c - 8b
+--R             *
+--R                ROOT
+--R                               2 9          2 8       4 7
+--R                         (4096a c  - 2048a b c  + 256b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                        3 17           2 2 16            4 15
+--R                                4194304a c   - 3145728a b c   + 786432a b c
+--R                              + 
+--R                                        6 14
+--R                                - 65536b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                          2 9          2 8       4 7
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 9          2 8       4 7
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             3 17           2 2 16
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 15         6 14
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               2 9          2 8       4 7
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                8 3     7 2 2     6 4     5 6
+--R              (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R       -
+--R                                         +--------------------+
+--R                     +-----------+       |   +-----------+
+--R               4+-+3 |          2 4+-+3 4|   |          2
+--R            3c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 9          2 8       4 7
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         3 17           2 2 16            4 15
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 14
+--R                                 - 65536b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           2 9          2 8       4 7
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                                5   12           4 3 11          3 5 10
+--R                         655360a b c   - 1146880a b c   + 745472a b c
+--R                       + 
+--R                                  2 7 9           9 8        11 7
+--R                         - 231424a b c  + 34816a b c  - 2048b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                           7 7        6 2 6        5 4 5        4 6 4
+--R                     - 128a c  + 1216a b c  - 3656a b c  + 4424a b c
+--R                   + 
+--R                            3 8 3       2 10 2         12      14
+--R                     - 2624a b c  + 816a b  c  - 128a b  c + 8b
+--R                *
+--R                   ROOT
+--R                                    2 9          2 8       4 7
+--R                            (- 4096a c  + 2048a b c  - 256b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                           3 17           2 2 16            4 15
+--R                                   4194304a c   - 3145728a b c   + 786432a b c
+--R                                 + 
+--R                                           6 14
+--R                                   - 65536b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                             2 9          2 8       4 7
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 9          2 8       4 7
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                3 17           2 2 16
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 15         6 14
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  2 9          2 8       4 7
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   8 3     7 2 2     6 4     5 6
+--R                 (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R            4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R         3c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 9          2 8       4 7
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        2 9          2 8       4 7
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                               5   12           4 3 11          3 5 10
+--R                      - 655360a b c   + 1146880a b c   - 745472a b c
+--R                    + 
+--R                             2 7 9           9 8        11 7
+--R                      231424a b c  - 34816a b c  + 2048b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                                   3 17           2 2 16            4 15
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 14
+--R                           - 65536b c
+--R                + 
+--R                      7 7        6 2 6        5 4 5        4 6 4        3 8 3
+--R                  128a c  - 1216a b c  + 3656a b c  - 4424a b c  + 2624a b c
+--R                + 
+--R                        2 10 2         12      14
+--R                  - 816a b  c  + 128a b  c - 8b
+--R             *
+--R                ROOT
+--R                                 2 9          2 8       4 7
+--R                         (- 4096a c  + 2048a b c  - 256b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                        3 17           2 2 16            4 15
+--R                                4194304a c   - 3145728a b c   + 786432a b c
+--R                              + 
+--R                                        6 14
+--R                                - 65536b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                          2 9          2 8       4 7
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 9          2 8       4 7
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             3 17           2 2 16
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 15         6 14
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               2 9          2 8       4 7
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                8 3     7 2 2     6 4     5 6
+--R              (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R       -
+--R                                         +--------------------+
+--R                     +-----------+       |   +-----------+
+--R               4+-+3 |          2 4+-+3 4|   |          2
+--R            3c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 9          2 8       4 7
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         3 17           2 2 16            4 15
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 14
+--R                                 - 65536b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           2 9          2 8       4 7
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                                  5   12           4 3 11          3 5 10
+--R                         - 655360a b c   + 1146880a b c   - 745472a b c
+--R                       + 
+--R                                2 7 9           9 8        11 7
+--R                         231424a b c  - 34816a b c  + 2048b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                           7 7        6 2 6        5 4 5        4 6 4
+--R                     - 128a c  + 1216a b c  - 3656a b c  + 4424a b c
+--R                   + 
+--R                            3 8 3       2 10 2         12      14
+--R                     - 2624a b c  + 816a b  c  - 128a b  c + 8b
+--R                *
+--R                   ROOT
+--R                                  2 9          2 8       4 7
+--R                            (4096a c  - 2048a b c  + 256b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                           3 17           2 2 16            4 15
+--R                                   4194304a c   - 3145728a b c   + 786432a b c
+--R                                 + 
+--R                                           6 14
+--R                                   - 65536b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                             2 9          2 8       4 7
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 9          2 8       4 7
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                3 17           2 2 16
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 15         6 14
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  2 9          2 8       4 7
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   8 3     7 2 2     6 4     5 6
+--R                 (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R            4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R         6c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 9          2 8       4 7
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        2 9          2 8       4 7
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         atan
+--R                             5   12           4 3 11          3 5 10
+--R                      655360a b c   - 1146880a b c   + 745472a b c
+--R                    + 
+--R                               2 7 9           9 8        11 7
+--R                      - 231424a b c  + 34816a b c  - 2048b  c
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                                   3 17           2 2 16            4 15
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 14
+--R                           - 65536b c
+--R                + 
+--R                      7 7        6 2 6        5 4 5        4 6 4        3 8 3
+--R                  128a c  - 1216a b c  + 3656a b c  - 4424a b c  + 2624a b c
+--R                + 
+--R                        2 10 2         12      14
+--R                  - 816a b  c  + 128a b  c - 8b
+--R             *
+--R                ROOT
+--R                               2 9          2 8       4 7
+--R                         (4096a c  - 2048a b c  + 256b c )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                        3 17           2 2 16            4 15
+--R                                4194304a c   - 3145728a b c   + 786432a b c
+--R                              + 
+--R                                        6 14
+--R                                - 65536b c
+--R                     + 
+--R                         3   3      2 3 2       5     7
+--R                       7a b c  - 14a b c  + 7a b c - b
+--R                  /
+--R                          2 9          2 8       4 7
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 9          2 8       4 7
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             3 17           2 2 16
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 15         6 14
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               2 9          2 8       4 7
+--R                          2048a c  - 1024a b c  + 128b c
+--R           /
+--R                8 3     7 2 2     6 4     5 6
+--R              (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R       -
+--R                                         +--------------------+
+--R                     +-----------+       |   +-----------+
+--R               4+-+3 |          2 4+-+3 4|   |          2
+--R            6c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 9          2 8       4 7
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         3 17           2 2 16            4 15
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 14
+--R                                 - 65536b c
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           2 9          2 8       4 7
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            atan
+--R                                5   12           4 3 11          3 5 10
+--R                         655360a b c   - 1146880a b c   + 745472a b c
+--R                       + 
+--R                                  2 7 9           9 8        11 7
+--R                         - 231424a b c  + 34816a b c  - 2048b  c
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      3 17           2 2 16            4 15
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 14
+--R                              - 65536b c
+--R                   + 
+--R                           7 7        6 2 6        5 4 5        4 6 4
+--R                     - 128a c  + 1216a b c  - 3656a b c  + 4424a b c
+--R                   + 
+--R                            3 8 3       2 10 2         12      14
+--R                     - 2624a b c  + 816a b  c  - 128a b  c + 8b
+--R                *
+--R                   ROOT
+--R                                    2 9          2 8       4 7
+--R                            (- 4096a c  + 2048a b c  - 256b c )
+--R                         *
+--R                            ROOT
+--R                                      6 6      5 2 5      4 4 4      3 6 3
+--R                                   - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                 + 
+--R                                        2 8 2        10     12
+--R                                   - 37a b c  + 10a b  c - b
+--R                              /
+--R                                           3 17           2 2 16            4 15
+--R                                   4194304a c   - 3145728a b c   + 786432a b c
+--R                                 + 
+--R                                           6 14
+--R                                   - 65536b c
+--R                        + 
+--R                            3   3      2 3 2       5     7
+--R                          7a b c  - 14a b c  + 7a b c - b
+--R                     /
+--R                             2 9          2 8       4 7
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 9          2 8       4 7
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                3 17           2 2 16
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 15         6 14
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  2 9          2 8       4 7
+--R                             2048a c  - 1024a b c  + 128b c
+--R              /
+--R                   8 3     7 2 2     6 4     5 6
+--R                 (a c  - 6a b c  + 5a b c - a b )x
+--R     + 
+--R                                           +------------------+
+--R               +-----------+               | +-----------+
+--R               |          2             2 4| |          2
+--R         (- 3b\|- 4a c + b   + 6a c - 3b )\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+
+--R               +-----------+               |   +-----------+
+--R               |          2             2 4|   |          2
+--R         (- 3b\|- 4a c + b   - 6a c + 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                         +------------------+
+--R             +-----------+               | +-----------+
+--R             |          2             2 4| |          2
+--R         (3b\|- 4a c + b   - 6a c + 3b )\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                         +--------------------+
+--R             +-----------+               |   +-----------+
+--R             |          2             2 4|   |          2
+--R         (3b\|- 4a c + b   + 6a c - 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                                     +--------------------+ +------------------+
+--R                 +-----------+       |   +-----------+      | +-----------+
+--R         3 4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R     - 2x  \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                                  +--------------------+ +------------------+
+--R              +-----------+       |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R     6c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1179
+
+--S 1180 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           2
+--R          x
+--R   (5)  - --
+--R           c
+--R                                                    Type: Expression(Integer)
+--E 1180
+
+)clear all
+
+--S 1181 of 2282
+t0:=x^8/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                8
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1181
+
+--S 1182 of 2282
+r0:=x/c+1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b-sqrt(b^2-_
+   4*a*c))^(3/4))+1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b-sqrt(b^2-_
+   4*a*c))^(3/4))+1/2*atan(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b+sqrt(b^2-_
+   4*a*c))^(3/4))+1/2*atanh(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                       +------------------+3
+--R            +-----------+              | +-----------+
+--R            |          2            2 4| |          2
+--R         (b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                       +--------------------+3
+--R            +-----------+              |   +-----------+
+--R            |          2            2 4|   |          2
+--R         (b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                       +------------------+3
+--R            +-----------+              | +-----------+
+--R            |          2            2 4| |          2
+--R         (b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                       +--------------------+3
+--R            +-----------+              |   +-----------+
+--R            |          2            2 4|   |          2
+--R         (b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2 4+-+4|   |          2        4| |          2
+--R       2x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+3  +------------------+3
+--R            +-----------+     |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1182
+
+--S 1183 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 7          2 6       4 5
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                          2   7          3 6       5 5
+--R                    (4096a b c  - 2048a b c  + 256b c )
+--R                 *
+--R                   +----------------------------------------------------------+
+--R                   |            4 4     3 2 3      2 4 2       6     8
+--R                   |         - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |----------------------------------------------------------
+--R                   |        3 13           2 2 12            4 11         6 10
+--R                  \|4194304a c   - 3145728a b c   + 786432a b c   - 65536b c
+--R                + 
+--R                      3 3      2 2 2       4     6
+--R                  - 4a c  + 13a b c  - 7a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 7          2 6       4 5
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                3 2     2 2       4
+--R              (a c  - 3a b c + a b )x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 7          2 6       4 5
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                             2   7          3 6       5 5
+--R                       (4096a b c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                       3 3      2 2 2       4     6
+--R                     4a c  - 13a b c  + 7a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 7          2 6       4 5
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   3 2     2 2       4
+--R                 (a c  - 3a b c + a b )x
+--R     + 
+--R         c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 7          2 6       4 5
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                            2   7          3 6       5 5
+--R                    (- 4096a b c  + 2048a b c  - 256b c )
+--R                 *
+--R                   +----------------------------------------------------------+
+--R                   |            4 4     3 2 3      2 4 2       6     8
+--R                   |         - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |----------------------------------------------------------
+--R                   |        3 13           2 2 12            4 11         6 10
+--R                  \|4194304a c   - 3145728a b c   + 786432a b c   - 65536b c
+--R                + 
+--R                      3 3      2 2 2       4     6
+--R                  - 4a c  + 13a b c  - 7a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 7          2 6       4 5
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                3 2     2 2       4
+--R              (a c  - 3a b c + a b )x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 7          2 6       4 5
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                               2   7          3 6       5 5
+--R                       (- 4096a b c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                       3 3      2 2 2       4     6
+--R                     4a c  - 13a b c  + 7a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 7          2 6       4 5
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   3 2     2 2       4
+--R                 (a c  - 3a b c + a b )x
+--R     + 
+--R       -
+--R            2c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 7          2 6       4 5
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            atan
+--R                             2   7          3 6       5 5
+--R                       (4096a b c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                         3 3      2 2 2       4     6
+--R                     - 4a c  + 13a b c  - 7a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 7          2 6       4 5
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R              /
+--R                   3 2     2 2       4
+--R                 (a c  - 3a b c + a b )x
+--R     + 
+--R         2c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 7          2 6       4 5
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         atan
+--R                          2   7          3 6       5 5
+--R                    (4096a b c  - 2048a b c  + 256b c )
+--R                 *
+--R                   +----------------------------------------------------------+
+--R                   |            4 4     3 2 3      2 4 2       6     8
+--R                   |         - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |----------------------------------------------------------
+--R                   |        3 13           2 2 12            4 11         6 10
+--R                  \|4194304a c   - 3145728a b c   + 786432a b c   - 65536b c
+--R                + 
+--R                    3 3      2 2 2       4     6
+--R                  4a c  - 13a b c  + 7a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 7          2 6       4 5
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R           /
+--R                3 2     2 2       4
+--R              (a c  - 3a b c + a b )x
+--R     + 
+--R       2x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1183
+
+--S 1184 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------------------+3  +------------------+3
+--R               +-----------+     |   +-----------+        | +-----------+
+--R          4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 7          2 6       4 5
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                          2   7          3 6       5 5
+--R                    (4096a b c  - 2048a b c  + 256b c )
+--R                 *
+--R                   +----------------------------------------------------------+
+--R                   |            4 4     3 2 3      2 4 2       6     8
+--R                   |         - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |----------------------------------------------------------
+--R                   |        3 13           2 2 12            4 11         6 10
+--R                  \|4194304a c   - 3145728a b c   + 786432a b c   - 65536b c
+--R                + 
+--R                      3 3      2 2 2       4     6
+--R                  - 4a c  + 13a b c  - 7a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 7          2 6       4 5
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                3 2     2 2       4
+--R              (a c  - 3a b c + a b )x
+--R     + 
+--R       -
+--R                                    +--------------------+3
+--R                  +-----------+     |   +-----------+
+--R             4+-+ |          2 4+-+4|   |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 7          2 6       4 5
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                             2   7          3 6       5 5
+--R                       (4096a b c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                       3 3      2 2 2       4     6
+--R                     4a c  - 13a b c  + 7a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 7          2 6       4 5
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   3 2     2 2       4
+--R                 (a c  - 3a b c + a b )x
+--R     + 
+--R                                 +--------------------+3  +------------------+3
+--R               +-----------+     |   +-----------+        | +-----------+
+--R          4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 7          2 6       4 5
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                            2   7          3 6       5 5
+--R                    (- 4096a b c  + 2048a b c  - 256b c )
+--R                 *
+--R                   +----------------------------------------------------------+
+--R                   |            4 4     3 2 3      2 4 2       6     8
+--R                   |         - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |----------------------------------------------------------
+--R                   |        3 13           2 2 12            4 11         6 10
+--R                  \|4194304a c   - 3145728a b c   + 786432a b c   - 65536b c
+--R                + 
+--R                      3 3      2 2 2       4     6
+--R                  - 4a c  + 13a b c  - 7a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 7          2 6       4 5
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                3 2     2 2       4
+--R              (a c  - 3a b c + a b )x
+--R     + 
+--R       -
+--R                                    +--------------------+3
+--R                  +-----------+     |   +-----------+
+--R             4+-+ |          2 4+-+4|   |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 7          2 6       4 5
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                               2   7          3 6       5 5
+--R                       (- 4096a b c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                       3 3      2 2 2       4     6
+--R                     4a c  - 13a b c  + 7a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 7          2 6       4 5
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   3 2     2 2       4
+--R                 (a c  - 3a b c + a b )x
+--R     + 
+--R       -
+--R                                     +--------------------+3
+--R                   +-----------+     |   +-----------+
+--R              4+-+ |          2 4+-+4|   |          2
+--R            2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 7          2 6       4 5
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            atan
+--R                             2   7          3 6       5 5
+--R                       (4096a b c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                         3 3      2 2 2       4     6
+--R                     - 4a c  + 13a b c  - 7a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 7          2 6       4 5
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R              /
+--R                   3 2     2 2       4
+--R                 (a c  - 3a b c + a b )x
+--R     + 
+--R                                  +--------------------+3  +------------------+3
+--R                +-----------+     |   +-----------+        | +-----------+
+--R           4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 7          2 6       4 5
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         atan
+--R                          2   7          3 6       5 5
+--R                    (4096a b c  - 2048a b c  + 256b c )
+--R                 *
+--R                   +----------------------------------------------------------+
+--R                   |            4 4     3 2 3      2 4 2       6     8
+--R                   |         - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |----------------------------------------------------------
+--R                   |        3 13           2 2 12            4 11         6 10
+--R                  \|4194304a c   - 3145728a b c   + 786432a b c   - 65536b c
+--R                + 
+--R                    3 3      2 2 2       4     6
+--R                  4a c  - 13a b c  + 7a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 7          2 6       4 5
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R           /
+--R                3 2     2 2       4
+--R              (a c  - 3a b c + a b )x
+--R     + 
+--R                                         +------------------+3
+--R              +-----------+              | +-----------+
+--R              |          2            2 4| |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                         +--------------------+3
+--R              +-----------+              |   +-----------+
+--R              |          2            2 4|   |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                         +------------------+3
+--R              +-----------+              | +-----------+
+--R              |          2            2 4| |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                         +--------------------+3
+--R              +-----------+              |   +-----------+
+--R              |          2            2 4|   |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+3  +------------------+3
+--R            +-----------+     |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1184
+
+--S 1185 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1185
+
+)clear all
+
+--S 1186 of 2282
+t0:=x^6/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                6
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1186
+
+--S 1187 of 2282
+r0:=-1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (-b-sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))+_
+   1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (-b-sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))+_
+   1/2*atan(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (-b+sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))-_
+   1/2*atanh(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (-b+sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +--------------------+3
+--R        |   +-----------+                    4+-+4+-+
+--R       4|   |          2                    x\|2 \|c
+--R       \|- \|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+3
+--R          | +-----------+                   4+-+4+-+
+--R         4| |          2                   x\|2 \|c
+--R       - \|\|- 4a c + b   - b  atanh(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R          +--------------------+3
+--R          |   +-----------+                   4+-+4+-+
+--R         4|   |          2                   x\|2 \|c
+--R       - \|- \|- 4a c + b   - b  atan(-----------------------)
+--R                                       +--------------------+
+--R                                       |   +-----------+
+--R                                      4|   |          2
+--R                                      \|- \|- 4a c + b   - b
+--R     + 
+--R        +------------------+3
+--R        | +-----------+                  4+-+4+-+
+--R       4| |          2                  x\|2 \|c
+--R       \|\|- 4a c + b   - b  atan(---------------------)
+--R                                   +------------------+
+--R                                   | +-----------+
+--R                                  4| |          2
+--R                                  \|\|- 4a c + b   - b
+--R  /
+--R            +-----------+
+--R      4+-+3 |          2 4+-+3
+--R     2\|2  \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 1187
+
+--S 1188 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 5          2 4       4 3
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        2 5          2 4       4 3
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                             4 7          3 2 6          2 4 5           6 4
+--R                      262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                    + 
+--R                           8 3
+--R                      2048b c
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                    2 2       2     4
+--R                     |                 - a c  + 2a b c - b
+--R                     |------------------------------------------------------
+--R                     |        3 9           2 2 8            4 7         6 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                + 
+--R                        3   3       2 3 2        5      7
+--R                  - 128a b c  + 192a b c  - 72a b c + 8b
+--R             *
+--R                ROOT
+--R                               2 5          2 4       4 3
+--R                         (4096a c  - 2048a b c  + 256b c )
+--R                      *
+--R                        +------------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |------------------------------------------------------
+--R                        |        3 9           2 2 8            4 7         6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                          2 5          2 4       4 3
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 5          2 4       4 3
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             3 9           2 2 8            4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               2 5          2 4       4 3
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                3     2 2
+--R              (a c - a b )x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 5          2 4       4 3
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                  2 2       2     4
+--R                               - a c  + 2a b c - b
+--R                            /
+--R                                         3 9           2 2 8            4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6
+--R                                 - 65536b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           2 5          2 4       4 3
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                                4 7          3 2 6          2 4 5           6 4
+--R                         262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                       + 
+--R                              8 3
+--R                         2048b c
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                         3   3       2 3 2        5      7
+--R                     128a b c  - 192a b c  + 72a b c - 8b
+--R                *
+--R                   ROOT
+--R                                    2 5          2 4       4 3
+--R                            (- 4096a c  + 2048a b c  - 256b c )
+--R                         *
+--R                            ROOT
+--R                                    2 2       2     4
+--R                                 - a c  + 2a b c - b
+--R                              /
+--R                                           3 9           2 2 8            4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           6 6
+--R                                   - 65536b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                             2 5          2 4       4 3
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 5          2 4       4 3
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                3 9           2 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 7         6 6
+--R                                        786432a b c  - 65536b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  2 5          2 4       4 3
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   3     2 2
+--R                 (a c - a b )x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 5          2 4       4 3
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        2 5          2 4       4 3
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                               4 7          3 2 6          2 4 5           6 4
+--R                      - 262144a c  + 327680a b c  - 147456a b c  + 28672a b c
+--R                    + 
+--R                             8 3
+--R                      - 2048b c
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                    2 2       2     4
+--R                     |                 - a c  + 2a b c - b
+--R                     |------------------------------------------------------
+--R                     |        3 9           2 2 8            4 7         6 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                + 
+--R                        3   3       2 3 2        5      7
+--R                  - 128a b c  + 192a b c  - 72a b c + 8b
+--R             *
+--R                ROOT
+--R                                 2 5          2 4       4 3
+--R                         (- 4096a c  + 2048a b c  - 256b c )
+--R                      *
+--R                        +------------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |------------------------------------------------------
+--R                        |        3 9           2 2 8            4 7         6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                          2 5          2 4       4 3
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 5          2 4       4 3
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             3 9           2 2 8            4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               2 5          2 4       4 3
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                3     2 2
+--R              (a c - a b )x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 5          2 4       4 3
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                  2 2       2     4
+--R                               - a c  + 2a b c - b
+--R                            /
+--R                                         3 9           2 2 8            4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6
+--R                                 - 65536b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           2 5          2 4       4 3
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                                  4 7          3 2 6          2 4 5
+--R                         - 262144a c  + 327680a b c  - 147456a b c
+--R                       + 
+--R                                 6 4        8 3
+--R                         28672a b c  - 2048b c
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                         3   3       2 3 2        5      7
+--R                     128a b c  - 192a b c  + 72a b c - 8b
+--R                *
+--R                   ROOT
+--R                                  2 5          2 4       4 3
+--R                            (4096a c  - 2048a b c  + 256b c )
+--R                         *
+--R                            ROOT
+--R                                    2 2       2     4
+--R                                 - a c  + 2a b c - b
+--R                              /
+--R                                           3 9           2 2 8            4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           6 6
+--R                                   - 65536b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                             2 5          2 4       4 3
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 5          2 4       4 3
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                3 9           2 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 7         6 6
+--R                                        786432a b c  - 65536b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  2 5          2 4       4 3
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   3     2 2
+--R                 (a c - a b )x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 5          2 4       4 3
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        2 5          2 4       4 3
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         atan
+--R                             4 7          3 2 6          2 4 5           6 4
+--R                      262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                    + 
+--R                           8 3
+--R                      2048b c
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                    2 2       2     4
+--R                     |                 - a c  + 2a b c - b
+--R                     |------------------------------------------------------
+--R                     |        3 9           2 2 8            4 7         6 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                + 
+--R                        3   3       2 3 2        5      7
+--R                  - 128a b c  + 192a b c  - 72a b c + 8b
+--R             *
+--R                ROOT
+--R                               2 5          2 4       4 3
+--R                         (4096a c  - 2048a b c  + 256b c )
+--R                      *
+--R                        +------------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |------------------------------------------------------
+--R                        |        3 9           2 2 8            4 7         6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                          2 5          2 4       4 3
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 5          2 4       4 3
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             3 9           2 2 8            4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               2 5          2 4       4 3
+--R                          2048a c  - 1024a b c  + 128b c
+--R           /
+--R                3     2 2
+--R              (a c - a b )x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 5          2 4       4 3
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                  2 2       2     4
+--R                               - a c  + 2a b c - b
+--R                            /
+--R                                         3 9           2 2 8            4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6
+--R                                 - 65536b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           2 5          2 4       4 3
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            atan
+--R                                4 7          3 2 6          2 4 5           6 4
+--R                         262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                       + 
+--R                              8 3
+--R                         2048b c
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                         3   3       2 3 2        5      7
+--R                     128a b c  - 192a b c  + 72a b c - 8b
+--R                *
+--R                   ROOT
+--R                                    2 5          2 4       4 3
+--R                            (- 4096a c  + 2048a b c  - 256b c )
+--R                         *
+--R                            ROOT
+--R                                    2 2       2     4
+--R                                 - a c  + 2a b c - b
+--R                              /
+--R                                           3 9           2 2 8            4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           6 6
+--R                                   - 65536b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                             2 5          2 4       4 3
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 5          2 4       4 3
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                3 9           2 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 7         6 6
+--R                                        786432a b c  - 65536b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  2 5          2 4       4 3
+--R                             2048a c  - 1024a b c  + 128b c
+--R              /
+--R                   3     2 2
+--R                 (a c - a b )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1188
+
+--S 1189 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-----------+
+--R         4+-+3 |          2 4+-+3
+--R         \|2  \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 5          2 4       4 3
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        2 5          2 4       4 3
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                             4 7          3 2 6          2 4 5           6 4
+--R                      262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                    + 
+--R                           8 3
+--R                      2048b c
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                    2 2       2     4
+--R                     |                 - a c  + 2a b c - b
+--R                     |------------------------------------------------------
+--R                     |        3 9           2 2 8            4 7         6 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                + 
+--R                        3   3       2 3 2        5      7
+--R                  - 128a b c  + 192a b c  - 72a b c + 8b
+--R             *
+--R                ROOT
+--R                               2 5          2 4       4 3
+--R                         (4096a c  - 2048a b c  + 256b c )
+--R                      *
+--R                        +------------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |------------------------------------------------------
+--R                        |        3 9           2 2 8            4 7         6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                          2 5          2 4       4 3
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 5          2 4       4 3
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             3 9           2 2 8            4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               2 5          2 4       4 3
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                3     2 2
+--R              (a c - a b )x
+--R     + 
+--R       -
+--R                  +-----------+
+--R            4+-+3 |          2 4+-+3
+--R            \|2  \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 5          2 4       4 3
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                  2 2       2     4
+--R                               - a c  + 2a b c - b
+--R                            /
+--R                                         3 9           2 2 8            4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6
+--R                                 - 65536b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           2 5          2 4       4 3
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                                4 7          3 2 6          2 4 5           6 4
+--R                         262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                       + 
+--R                              8 3
+--R                         2048b c
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                         3   3       2 3 2        5      7
+--R                     128a b c  - 192a b c  + 72a b c - 8b
+--R                *
+--R                   ROOT
+--R                                    2 5          2 4       4 3
+--R                            (- 4096a c  + 2048a b c  - 256b c )
+--R                         *
+--R                            ROOT
+--R                                    2 2       2     4
+--R                                 - a c  + 2a b c - b
+--R                              /
+--R                                           3 9           2 2 8            4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           6 6
+--R                                   - 65536b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                             2 5          2 4       4 3
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 5          2 4       4 3
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                3 9           2 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 7         6 6
+--R                                        786432a b c  - 65536b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  2 5          2 4       4 3
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   3     2 2
+--R                 (a c - a b )x
+--R     + 
+--R               +-----------+
+--R         4+-+3 |          2 4+-+3
+--R         \|2  \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 5          2 4       4 3
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        2 5          2 4       4 3
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                               4 7          3 2 6          2 4 5           6 4
+--R                      - 262144a c  + 327680a b c  - 147456a b c  + 28672a b c
+--R                    + 
+--R                             8 3
+--R                      - 2048b c
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                    2 2       2     4
+--R                     |                 - a c  + 2a b c - b
+--R                     |------------------------------------------------------
+--R                     |        3 9           2 2 8            4 7         6 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                + 
+--R                        3   3       2 3 2        5      7
+--R                  - 128a b c  + 192a b c  - 72a b c + 8b
+--R             *
+--R                ROOT
+--R                                 2 5          2 4       4 3
+--R                         (- 4096a c  + 2048a b c  - 256b c )
+--R                      *
+--R                        +------------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |------------------------------------------------------
+--R                        |        3 9           2 2 8            4 7         6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                          2 5          2 4       4 3
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 5          2 4       4 3
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             3 9           2 2 8            4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               2 5          2 4       4 3
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                3     2 2
+--R              (a c - a b )x
+--R     + 
+--R       -
+--R                  +-----------+
+--R            4+-+3 |          2 4+-+3
+--R            \|2  \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 5          2 4       4 3
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                  2 2       2     4
+--R                               - a c  + 2a b c - b
+--R                            /
+--R                                         3 9           2 2 8            4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6
+--R                                 - 65536b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           2 5          2 4       4 3
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                                  4 7          3 2 6          2 4 5
+--R                         - 262144a c  + 327680a b c  - 147456a b c
+--R                       + 
+--R                                 6 4        8 3
+--R                         28672a b c  - 2048b c
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                         3   3       2 3 2        5      7
+--R                     128a b c  - 192a b c  + 72a b c - 8b
+--R                *
+--R                   ROOT
+--R                                  2 5          2 4       4 3
+--R                            (4096a c  - 2048a b c  + 256b c )
+--R                         *
+--R                            ROOT
+--R                                    2 2       2     4
+--R                                 - a c  + 2a b c - b
+--R                              /
+--R                                           3 9           2 2 8            4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           6 6
+--R                                   - 65536b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                             2 5          2 4       4 3
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 5          2 4       4 3
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                3 9           2 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 7         6 6
+--R                                        786432a b c  - 65536b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  2 5          2 4       4 3
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                   3     2 2
+--R                 (a c - a b )x
+--R     + 
+--R                +-----------+
+--R          4+-+3 |          2 4+-+3
+--R         2\|2  \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 5          2 4       4 3
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        2 5          2 4       4 3
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         atan
+--R                             4 7          3 2 6          2 4 5           6 4
+--R                      262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                    + 
+--R                           8 3
+--R                      2048b c
+--R                 *
+--R                     +------------------------------------------------------+
+--R                     |                    2 2       2     4
+--R                     |                 - a c  + 2a b c - b
+--R                     |------------------------------------------------------
+--R                     |        3 9           2 2 8            4 7         6 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                + 
+--R                        3   3       2 3 2        5      7
+--R                  - 128a b c  + 192a b c  - 72a b c + 8b
+--R             *
+--R                ROOT
+--R                               2 5          2 4       4 3
+--R                         (4096a c  - 2048a b c  + 256b c )
+--R                      *
+--R                        +------------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |------------------------------------------------------
+--R                        |        3 9           2 2 8            4 7         6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                     + 
+--R                                 3
+--R                       3a b c - b
+--R                  /
+--R                          2 5          2 4       4 3
+--R                     2048a c  - 1024a b c  + 128b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 5          2 4       4 3
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             3 9           2 2 8            4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536b c
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               2 5          2 4       4 3
+--R                          2048a c  - 1024a b c  + 128b c
+--R           /
+--R                3     2 2
+--R              (a c - a b )x
+--R     + 
+--R       -
+--R                   +-----------+
+--R             4+-+3 |          2 4+-+3
+--R            2\|2  \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 5          2 4       4 3
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                  2 2       2     4
+--R                               - a c  + 2a b c - b
+--R                            /
+--R                                         3 9           2 2 8            4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6
+--R                                 - 65536b c
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           2 5          2 4       4 3
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            atan
+--R                                4 7          3 2 6          2 4 5           6 4
+--R                         262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                       + 
+--R                              8 3
+--R                         2048b c
+--R                    *
+--R                      +------------------------------------------------------+
+--R                      |                    2 2       2     4
+--R                      |                 - a c  + 2a b c - b
+--R                      |------------------------------------------------------
+--R                      |        3 9           2 2 8            4 7         6 6
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                   + 
+--R                         3   3       2 3 2        5      7
+--R                     128a b c  - 192a b c  + 72a b c - 8b
+--R                *
+--R                   ROOT
+--R                                    2 5          2 4       4 3
+--R                            (- 4096a c  + 2048a b c  - 256b c )
+--R                         *
+--R                            ROOT
+--R                                    2 2       2     4
+--R                                 - a c  + 2a b c - b
+--R                              /
+--R                                           3 9           2 2 8            4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           6 6
+--R                                   - 65536b c
+--R                        + 
+--R                                    3
+--R                          3a b c - b
+--R                     /
+--R                             2 5          2 4       4 3
+--R                        2048a c  - 1024a b c  + 128b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 5          2 4       4 3
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                3 9           2 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 7         6 6
+--R                                        786432a b c  - 65536b c
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  2 5          2 4       4 3
+--R                             2048a c  - 1024a b c  + 128b c
+--R              /
+--R                   3     2 2
+--R                 (a c - a b )x
+--R     + 
+--R          +--------------------+3
+--R          |   +-----------+                    4+-+4+-+
+--R         4|   |          2                    x\|2 \|c
+--R       - \|- \|- 4a c + b   - b  atanh(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R        +------------------+3
+--R        | +-----------+                   4+-+4+-+
+--R       4| |          2                   x\|2 \|c
+--R       \|\|- 4a c + b   - b  atanh(---------------------)
+--R                                    +------------------+
+--R                                    | +-----------+
+--R                                   4| |          2
+--R                                   \|\|- 4a c + b   - b
+--R     + 
+--R        +--------------------+3
+--R        |   +-----------+                   4+-+4+-+
+--R       4|   |          2                   x\|2 \|c
+--R       \|- \|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+
+--R         4| |          2                  x\|2 \|c
+--R       - \|\|- 4a c + b   - b  atan(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                    4| |          2
+--R                                    \|\|- 4a c + b   - b
+--R  /
+--R            +-----------+
+--R      4+-+3 |          2 4+-+3
+--R     2\|2  \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 1189
+
+--S 1190 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1190
+
+)clear all
+
+--S 1191 of 2282
+t0:=x^4/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1191
+
+--S 1192 of 2282
+r0:=1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (-b-sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))+_
+   1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (-b-sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))-_
+   1/2*atan(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (-b+sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))-_
+   1/2*atanh(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (-b+sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +--------------------+
+--R        |   +-----------+                   4+-+4+-+
+--R       4|   |          2                   x\|2 \|c
+--R       \|- \|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                  4+-+4+-+
+--R         4| |          2                  x\|2 \|c
+--R       - \|\|- 4a c + b   - b atanh(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                    4| |          2
+--R                                    \|\|- 4a c + b   - b
+--R     + 
+--R        +--------------------+
+--R        |   +-----------+                  4+-+4+-+
+--R       4|   |          2                  x\|2 \|c
+--R       \|- \|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+
+--R         4| |          2                 x\|2 \|c
+--R       - \|\|- 4a c + b   - b atan(---------------------)
+--R                                    +------------------+
+--R                                    | +-----------+
+--R                                   4| |          2
+--R                                   \|\|- 4a c + b   - b
+--R  /
+--R           +-----------+
+--R      4+-+ |          2 4+-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 1192
+
+--S 1193 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                              2
+--R                   (16a c - 4b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                          2 3          2 2        4
+--R                   (16384a c  - 8192a b c  + 1024b c)x
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                           1
+--R                    |------------------------------------------------------
+--R                    |        3 5           2 2 4            4 3         6 2
+--R                   \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                              2
+--R                   (16a c - 4b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                  2
+--R                 x
+--R     + 
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                           2
+--R                (16a c - 4b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                           2
+--R                (16a c - 4b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                       2 3          2 2        4
+--R                (16384a c  - 8192a b c  + 1024b c)x
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                           1
+--R                 |------------------------------------------------------
+--R                 |        3 5           2 2 4            4 3         6 2
+--R                \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                              2
+--R                   (16a c - 4b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                              2
+--R                   (16a c - 4b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                            2 3          2 2        4
+--R                   (- 16384a c  + 8192a b c  - 1024b c)x
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                           1
+--R                    |------------------------------------------------------
+--R                    |        3 5           2 2 4            4 3         6 2
+--R                   \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                  2
+--R                 x
+--R     + 
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                           2
+--R                (16a c - 4b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                         2 3          2 2        4
+--R                (- 16384a c  + 8192a b c  - 1024b c)x
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                           1
+--R                 |------------------------------------------------------
+--R                 |        3 5           2 2 4            4 3         6 2
+--R                \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                           2
+--R                (16a c - 4b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                         2 3          2 2       4
+--R                   (8192a c  - 4096a b c  + 512b c)
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                           1
+--R                    |------------------------------------------------------
+--R                    |        3 5           2 2 4            4 3         6 2
+--R                   \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R              /
+--R                           2 3          2 2       4
+--R                     (8192a c  - 4096a b c  + 512b c)
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                           1
+--R                      |------------------------------------------------------
+--R                      |        3 5           2 2 4            4 3         6 2
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                   - x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                      2 3          2 2       4
+--R                (8192a c  - 4096a b c  + 512b c)
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                           1
+--R                 |------------------------------------------------------
+--R                 |        3 5           2 2 4            4 3         6 2
+--R                \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R           /
+--R                        2 3          2 2       4
+--R                  (8192a c  - 4096a b c  + 512b c)
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                           1
+--R                   |------------------------------------------------------
+--R                   |        3 5           2 2 4            4 3         6 2
+--R                  \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                      2 3          2 2       4
+--R                (8192a c  - 4096a b c  + 512b c)
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                           1
+--R                 |------------------------------------------------------
+--R                 |        3 5           2 2 4            4 3         6 2
+--R                \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R           /
+--R                        2 3          2 2       4
+--R                  (8192a c  - 4096a b c  + 512b c)
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                           1
+--R                   |------------------------------------------------------
+--R                   |        3 5           2 2 4            4 3         6 2
+--R                  \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                - x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                         2 3          2 2       4
+--R                   (8192a c  - 4096a b c  + 512b c)
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                           1
+--R                    |------------------------------------------------------
+--R                    |        3 5           2 2 4            4 3         6 2
+--R                   \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R              /
+--R                           2 3          2 2       4
+--R                     (8192a c  - 4096a b c  + 512b c)
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                           1
+--R                      |------------------------------------------------------
+--R                      |        3 5           2 2 4            4 3         6 2
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                   x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1193
+
+--S 1194 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                 +-----------+
+--R            4+-+ |          2 4+-+
+--R            \|2 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                              2
+--R                   (16a c - 4b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                          2 3          2 2        4
+--R                   (16384a c  - 8192a b c  + 1024b c)x
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                           1
+--R                    |------------------------------------------------------
+--R                    |        3 5           2 2 4            4 3         6 2
+--R                   \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                              2
+--R                   (16a c - 4b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                  2
+--R                 x
+--R     + 
+--R              +-----------+
+--R         4+-+ |          2 4+-+
+--R         \|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                           2
+--R                (16a c - 4b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                           2
+--R                (16a c - 4b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                       2 3          2 2        4
+--R                (16384a c  - 8192a b c  + 1024b c)x
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                           1
+--R                 |------------------------------------------------------
+--R                 |        3 5           2 2 4            4 3         6 2
+--R                \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                 +-----------+
+--R            4+-+ |          2 4+-+
+--R            \|2 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                              2
+--R                   (16a c - 4b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                              2
+--R                   (16a c - 4b )
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                            2 3          2 2        4
+--R                   (- 16384a c  + 8192a b c  - 1024b c)x
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                           1
+--R                    |------------------------------------------------------
+--R                    |        3 5           2 2 4            4 3         6 2
+--R                   \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                  2
+--R                 x
+--R     + 
+--R              +-----------+
+--R         4+-+ |          2 4+-+
+--R         \|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                           2
+--R                (16a c - 4b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                         2 3          2 2        4
+--R                (- 16384a c  + 8192a b c  - 1024b c)x
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                           1
+--R                 |------------------------------------------------------
+--R                 |        3 5           2 2 4            4 3         6 2
+--R                \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                           2
+--R                (16a c - 4b )
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R       -
+--R                  +-----------+
+--R             4+-+ |          2 4+-+
+--R            2\|2 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                         2 3          2 2       4
+--R                   (8192a c  - 4096a b c  + 512b c)
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                           1
+--R                    |------------------------------------------------------
+--R                    |        3 5           2 2 4            4 3         6 2
+--R                   \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R              /
+--R                           2 3          2 2       4
+--R                     (8192a c  - 4096a b c  + 512b c)
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                           1
+--R                      |------------------------------------------------------
+--R                      |        3 5           2 2 4            4 3         6 2
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                   - x
+--R     + 
+--R               +-----------+
+--R          4+-+ |          2 4+-+
+--R         2\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                      2 3          2 2       4
+--R                (8192a c  - 4096a b c  + 512b c)
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                           1
+--R                 |------------------------------------------------------
+--R                 |        3 5           2 2 4            4 3         6 2
+--R                \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R           /
+--R                        2 3          2 2       4
+--R                  (8192a c  - 4096a b c  + 512b c)
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                           1
+--R                   |------------------------------------------------------
+--R                   |        3 5           2 2 4            4 3         6 2
+--R                  \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                x
+--R     + 
+--R               +-----------+
+--R          4+-+ |          2 4+-+
+--R         2\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       a
+--R                    /
+--R                                 4 5           3 2 4          2 4 3
+--R                         1048576a c  - 1048576a b c  + 393216a b c
+--R                       + 
+--R                                   6 2        8
+--R                         - 65536a b c  + 4096b c
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    2 3          2 2       4
+--R                              (4096a c  - 2048a b c  + 256b c)
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             3 5           2 2 4            4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 2
+--R                                     - 65536b c
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     2 3          2 2       4
+--R                               (4096a c  - 2048a b c  + 256b c)
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              3 5           2 2 4            4 3
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              6 2
+--R                                      - 65536b c
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                      2 3          2 2       4
+--R                (8192a c  - 4096a b c  + 512b c)
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                           1
+--R                 |------------------------------------------------------
+--R                 |        3 5           2 2 4            4 3         6 2
+--R                \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              a
+--R                           /
+--R                                        4 5           3 2 4          2 4 3
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                          6 2        8
+--R                                - 65536a b c  + 4096b c
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           2 3          2 2       4
+--R                                     (4096a c  - 2048a b c  + 256b c)
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    3 5           2 2 4
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                     4 3         6 2
+--R                                            786432a b c  - 65536b c
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            2 3          2 2       4
+--R                                      (4096a c  - 2048a b c  + 256b c)
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     3 5           2 2 4
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                      4 3         6 2
+--R                                             786432a b c  - 65536b c
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R           /
+--R                        2 3          2 2       4
+--R                  (8192a c  - 4096a b c  + 512b c)
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                           1
+--R                   |------------------------------------------------------
+--R                   |        3 5           2 2 4            4 3         6 2
+--R                  \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                a
+--R                             /
+--R                                          4 5           3 2 4          2 4 3
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                            6 2        8
+--R                                  - 65536a b c  + 4096b c
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             2 3          2 2       4
+--R                                       (4096a c  - 2048a b c  + 256b c)
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      3 5           2 2 4
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                       4 3         6 2
+--R                                              786432a b c  - 65536b c
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                - x
+--R     + 
+--R       -
+--R                  +-----------+
+--R             4+-+ |          2 4+-+
+--R            2\|2 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          a
+--R                       /
+--R                                    4 5           3 2 4          2 4 3
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                      6 2        8
+--R                            - 65536a b c  + 4096b c
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       2 3          2 2       4
+--R                                 (4096a c  - 2048a b c  + 256b c)
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                3 5           2 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                                 4 3         6 2
+--R                                        786432a b c  - 65536b c
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        2 3          2 2       4
+--R                                  (4096a c  - 2048a b c  + 256b c)
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 3 5           2 2 4
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                  4 3         6 2
+--R                                         786432a b c  - 65536b c
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                         2 3          2 2       4
+--R                   (8192a c  - 4096a b c  + 512b c)
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                           1
+--R                    |------------------------------------------------------
+--R                    |        3 5           2 2 4            4 3         6 2
+--R                   \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 a
+--R                              /
+--R                                           4 5           3 2 4          2 4 3
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                             6 2        8
+--R                                   - 65536a b c  + 4096b c
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              2 3          2 2       4
+--R                                        (4096a c  - 2048a b c  + 256b c)
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       3 5           2 2 4
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                        4 3         6 2
+--R                                               786432a b c  - 65536b c
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               2 3          2 2       4
+--R                                         (4096a c  - 2048a b c  + 256b c)
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        3 5           2 2 4
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                         4 3         6 2
+--R                                                786432a b c  - 65536b c
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R              /
+--R                           2 3          2 2       4
+--R                     (8192a c  - 4096a b c  + 512b c)
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                           1
+--R                      |------------------------------------------------------
+--R                      |        3 5           2 2 4            4 3         6 2
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   a
+--R                                /
+--R                                             4 5           3 2 4          2 4 3
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                               6 2        8
+--R                                     - 65536a b c  + 4096b c
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                2 3          2 2       4
+--R                                          (4096a c  - 2048a b c  + 256b c)
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         3 5           2 2 4
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                          4 3         6 2
+--R                                                 786432a b c  - 65536b c
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 2 3          2 2       4
+--R                                           (4096a c  - 2048a b c  + 256b c)
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          3 5           2 2 4
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                           4 3         6 2
+--R                                                  786432a b c  - 65536b c
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                   x
+--R     + 
+--R          +--------------------+
+--R          |   +-----------+                   4+-+4+-+
+--R         4|   |          2                   x\|2 \|c
+--R       - \|- \|- 4a c + b   - b atanh(-----------------------)
+--R                                       +--------------------+
+--R                                       |   +-----------+
+--R                                      4|   |          2
+--R                                      \|- \|- 4a c + b   - b
+--R     + 
+--R        +------------------+
+--R        | +-----------+                  4+-+4+-+
+--R       4| |          2                  x\|2 \|c
+--R       \|\|- 4a c + b   - b atanh(---------------------)
+--R                                   +------------------+
+--R                                   | +-----------+
+--R                                  4| |          2
+--R                                  \|\|- 4a c + b   - b
+--R     + 
+--R          +--------------------+
+--R          |   +-----------+                  4+-+4+-+
+--R         4|   |          2                  x\|2 \|c
+--R       - \|- \|- 4a c + b   - b atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R        +------------------+
+--R        | +-----------+                 4+-+4+-+
+--R       4| |          2                 x\|2 \|c
+--R       \|\|- 4a c + b   - b atan(---------------------)
+--R                                  +------------------+
+--R                                  | +-----------+
+--R                                 4| |          2
+--R                                 \|\|- 4a c + b   - b
+--R  /
+--R           +-----------+
+--R      4+-+ |          2 4+-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 1194
+
+--S 1195 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                          8   9                 7 3 8
+--R                           - 391169179648a b c  - 3603519504384a b c
+--R                         + 
+--R                                           6 5 7                5 7 6
+--R                           - 1941153251328a b c  + 840009515008a b c
+--R                         + 
+--R                                        4 9 5               3 11 4
+--R                           135450918912a b c  - 31559483392a b  c
+--R                         + 
+--R                                        2 13 3              15 2        17
+--R                           - 2421948416a b  c  - 20436992a b  c  - 4480b  c
+--R                      *
+--R                          16
+--R                         x
+--R                     + 
+--R                                          9   8                 8 3 7
+--R                           - 391169179648a b c  - 3603519504384a b c
+--R                         + 
+--R                                           7 5 6                6 7 5
+--R                           - 1941153251328a b c  + 840009515008a b c
+--R                         + 
+--R                                        5 9 4               4 11 3
+--R                           135450918912a b c  - 31559483392a b  c
+--R                         + 
+--R                                        3 13 2            2 15           17
+--R                           - 2421948416a b  c  - 20436992a b  c - 4480a b
+--R                      *
+--R                          8
+--R                         x
+--R                  *
+--R                       ROOT
+--R                            a
+--R                         /
+--R                                      4 5           3 2 4          2 4 3
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                        6 2        8
+--R                              - 65536a b c  + 4096b c
+--R                      ,
+--R                          4
+--R                    **
+--R                       2
+--R                 + 
+--R                                 6   7              5 3 6              4 5 5
+--R                       887947264a b c  + 2294714368a b c  + 1040019456a b c
+--R                     + 
+--R                                 3 7 4           2 9 3          11 2
+--R                       109997568a b c  + 2374144a b c  + 4880a b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                  7   6              6 3 5              5 5 4
+--R                       1775894528a b c  + 5477376000a b c  + 4374753280a b c
+--R                     + 
+--R                                  4 7 3             3 9 2           2 11
+--R                       1260014592a b c  + 114745856a b c  + 2383904a b  c
+--R                     + 
+--R                              13
+--R                       4880a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                 8   5              7 3 4              6 5 3
+--R                       887947264a b c  + 2294714368a b c  + 1040019456a b c
+--R                     + 
+--R                                 5 7 2           4 9         3 11
+--R                       109997568a b c  + 2374144a b c + 4880a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +---------+
+--R                  |        2
+--R                 \|4a c - b
+--R             + 
+--R                                       10 13                    9 2 12
+--R                       801114479919104a  c   + 6979450705018880a b c
+--R                     + 
+--R                                       8 4 11                    7 6 10
+--R                       335547541225472a b c   - 3246829919535104a b c
+--R                     + 
+--R                                       6 8 9                  5 10 8
+--R                       831233877606400a b c  + 95814345031680a b  c
+--R                     + 
+--R                                        4 12 7                 3 14 6
+--R                       - 44694478258176a b  c  + 1601393655808a b  c
+--R                     + 
+--R                                    2 16 5                18 4          20 3
+--R                       289091092480a b  c  + 2611347456a b  c  + 573440b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                       10   12                    9 3 11
+--R                       801114479919104a  b c   + 6979450705018880a b c
+--R                     + 
+--R                                       8 5 10                    7 7 9
+--R                       335547541225472a b c   - 3246829919535104a b c
+--R                     + 
+--R                                       6 9 8                  5 11 7
+--R                       831233877606400a b c  + 95814345031680a b  c
+--R                     + 
+--R                                        4 13 6                 3 15 5
+--R                       - 44694478258176a b  c  + 1601393655808a b  c
+--R                     + 
+--R                                    2 17 4                19 3          21 2
+--R                       289091092480a b  c  + 2611347456a b  c  + 573440b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                        11 12                     10 2 11
+--R                       1602228959838208a  c   + 13958901410037760a  b c
+--R                     + 
+--R                                       9 4 10                    8 6 9
+--R                       671095082450944a b c   - 6493659839070208a b c
+--R                     + 
+--R                                        7 8 8                   6 10 7
+--R                       1662467755212800a b c  + 191628690063360a b  c
+--R                     + 
+--R                                        5 12 6                 4 14 5
+--R                       - 89388956516352a b  c  + 3202787311616a b  c
+--R                     + 
+--R                                    3 16 4              2 18 3             20 2
+--R                       578182184960a b  c  + 5222694912a b  c  + 1146880a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                       11   11                    10 3 10
+--R                       801114479919104a  b c   + 6979450705018880a  b c
+--R                     + 
+--R                                       9 5 9                    8 7 8
+--R                       335547541225472a b c  - 3246829919535104a b c
+--R                     + 
+--R                                       7 9 7                  6 11 6
+--R                       831233877606400a b c  + 95814345031680a b  c
+--R                     + 
+--R                                        5 13 5                 4 15 4
+--R                       - 44694478258176a b  c  + 1601393655808a b  c
+--R                     + 
+--R                                    3 17 3              2 19 2            21
+--R                       289091092480a b  c  + 2611347456a b  c  + 573440a b  c
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                       12 11                    11 2 10
+--R                       801114479919104a  c   + 6979450705018880a  b c
+--R                     + 
+--R                                       10 4 9                    9 6 8
+--R                       335547541225472a  b c  - 3246829919535104a b c
+--R                     + 
+--R                                       8 8 7                  7 10 6
+--R                       831233877606400a b c  + 95814345031680a b  c
+--R                     + 
+--R                                        6 12 5                 5 14 4
+--R                       - 44694478258176a b  c  + 1601393655808a b  c
+--R                     + 
+--R                                    4 16 3              3 18 2          2 20
+--R                       289091092480a b  c  + 2611347456a b  c  + 573440a b  c
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +------------------------------------------------------+
+--R                  |                           1
+--R                  |------------------------------------------------------
+--R                  |        3 5           2 2 4            4 3         6 2
+--R                 \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                                       8 2 9                 7 4 8
+--R                       - 3637031993344a b c  - 7580634054656a b c
+--R                     + 
+--R                                    6 6 7                 5 8 6
+--R                       212340834304a b c  + 1091962929152a b c
+--R                     + 
+--R                                     4 10 5               3 12 4
+--R                       - 50694455296a b  c  - 23317118976a b  c
+--R                     + 
+--R                                   2 14 3             16 2
+--R                       - 597786624a b  c  - 1249280a b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                       8 3 8                 7 5 7
+--R                       - 3637031993344a b c  - 7580634054656a b c
+--R                     + 
+--R                                    6 7 6                 5 9 5
+--R                       212340834304a b c  + 1091962929152a b c
+--R                     + 
+--R                                     4 11 4               3 13 3
+--R                       - 50694455296a b  c  - 23317118976a b  c
+--R                     + 
+--R                                   2 15 2             17
+--R                       - 597786624a b  c  - 1249280a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                       9 2 8                 8 4 7
+--R                       - 3637031993344a b c  - 7580634054656a b c
+--R                     + 
+--R                                    7 6 6                 6 8 5
+--R                       212340834304a b c  + 1091962929152a b c
+--R                     + 
+--R                                     5 10 4               4 12 3
+--R                       - 50694455296a b  c  - 23317118976a b  c
+--R                     + 
+--R                                   3 14 2           2 16
+--R                       - 597786624a b  c  - 1249280a b  c
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                  +------------------------------------------------------+
+--R                  |                           1
+--R                  |------------------------------------------------------
+--R                  |        3 5           2 2 4            4 3         6 2
+--R                 \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R          *
+--R                2
+--R             %DO
+--R         + 
+--R                                              9   12                    8 3 11
+--R                           - 3323763521224704a b c   - 3241624419172352a b c
+--R                         + 
+--R                                            7 5 10                   6 7 9
+--R                           3223319268556800a b c   - 293294189838336a b c
+--R                         + 
+--R                                             5 9 8                  4 11 7
+--R                           - 255112937209856a b c  + 56093396959232a b  c
+--R                         + 
+--R                                          3 13 6                2 15 5
+--R                           - 242103615488a b  c  - 447337201664a b  c
+--R                         + 
+--R                                          17 4           19 3
+--R                           - 4907466752a b  c  - 1146880b  c
+--R                      *
+--R                          20
+--R                         x
+--R                     + 
+--R                                              9 2 11                    8 4 10
+--R                           - 3323763521224704a b c   - 3241624419172352a b c
+--R                         + 
+--R                                            7 6 9                   6 8 8
+--R                           3223319268556800a b c  - 293294189838336a b c
+--R                         + 
+--R                                             5 10 7                  4 12 6
+--R                           - 255112937209856a b  c  + 56093396959232a b  c
+--R                         + 
+--R                                          3 14 5                2 16 4
+--R                           - 242103615488a b  c  - 447337201664a b  c
+--R                         + 
+--R                                          18 3           20 2
+--R                           - 4907466752a b  c  - 1146880b  c
+--R                      *
+--R                          16
+--R                         x
+--R                     + 
+--R                                              10   11                    9 3 10
+--R                           - 6647527042449408a  b c   - 6483248838344704a b c
+--R                         + 
+--R                                            8 5 9                   7 7 8
+--R                           6446638537113600a b c  - 586588379676672a b c
+--R                         + 
+--R                                             6 9 7                   5 11 6
+--R                           - 510225874419712a b c  + 112186793918464a b  c
+--R                         + 
+--R                                          4 13 5                3 15 4
+--R                           - 484207230976a b  c  - 894674403328a b  c
+--R                         + 
+--R                                        2 17 3             19 2
+--R                           - 9814933504a b  c  - 2293760a b  c
+--R                      *
+--R                          12
+--R                         x
+--R                     + 
+--R                                              10 2 10                    9 4 9
+--R                           - 3323763521224704a  b c   - 3241624419172352a b c
+--R                         + 
+--R                                            8 6 8                   7 8 7
+--R                           3223319268556800a b c  - 293294189838336a b c
+--R                         + 
+--R                                             6 10 6                  5 12 5
+--R                           - 255112937209856a b  c  + 56093396959232a b  c
+--R                         + 
+--R                                          4 14 4                3 16 3
+--R                           - 242103615488a b  c  - 447337201664a b  c
+--R                         + 
+--R                                        2 18 2             20
+--R                           - 4907466752a b  c  - 1146880a b  c
+--R                      *
+--R                          8
+--R                         x
+--R                     + 
+--R                                              11   10                    10 3 9
+--R                           - 3323763521224704a  b c   - 3241624419172352a  b c
+--R                         + 
+--R                                            9 5 8                   8 7 7
+--R                           3223319268556800a b c  - 293294189838336a b c
+--R                         + 
+--R                                             7 9 6                  6 11 5
+--R                           - 255112937209856a b c  + 56093396959232a b  c
+--R                         + 
+--R                                          5 13 4                4 15 3
+--R                           - 242103615488a b  c  - 447337201664a b  c
+--R                         + 
+--R                                        3 17 2           2 19
+--R                           - 4907466752a b  c  - 1146880a b  c
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                           1
+--R                      |------------------------------------------------------
+--R                      |        3 5           2 2 4            4 3         6 2
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                  *
+--R                       ROOT
+--R                            a
+--R                         /
+--R                                      4 5           3 2 4          2 4 3
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                        6 2        8
+--R                              - 65536a b c  + 4096b c
+--R                      ,
+--R                          4
+--R                    **
+--R                       2
+--R                 + 
+--R                                        8   9                 7 3 8
+--R                           782338359296a b c  + 5584107601920a b c
+--R                         + 
+--R                                         6 5 7                 5 7 6
+--R                           1488016375808a b c  - 1201844518912a b c
+--R                         + 
+--R                                         4 9 5               3 11 4
+--R                           - 25381502976a b c  + 31426363392a b  c
+--R                         + 
+--R                                      2 13 3             15 2
+--R                           1041928192a b  c  + 2462720a b  c
+--R                      *
+--R                          16
+--R                         x
+--R                     + 
+--R                                        8 2 8                 7 4 7
+--R                           782338359296a b c  + 5584107601920a b c
+--R                         + 
+--R                                         6 6 6                 5 8 5
+--R                           1488016375808a b c  - 1201844518912a b c
+--R                         + 
+--R                                         4 10 4               3 12 3
+--R                           - 25381502976a b  c  + 31426363392a b  c
+--R                         + 
+--R                                      2 14 2             16
+--R                           1041928192a b  c  + 2462720a b  c
+--R                      *
+--R                          12
+--R                         x
+--R                     + 
+--R                                        9   8                 8 3 7
+--R                           782338359296a b c  + 5584107601920a b c
+--R                         + 
+--R                                         7 5 6                 6 7 5
+--R                           1488016375808a b c  - 1201844518912a b c
+--R                         + 
+--R                                         5 9 4               4 11 3
+--R                           - 25381502976a b c  + 31426363392a b  c
+--R                         + 
+--R                                      3 13 2           2 15
+--R                           1041928192a b  c  + 2462720a b  c
+--R                      *
+--R                          8
+--R                         x
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                           1
+--R                      |------------------------------------------------------
+--R                      |        3 5           2 2 4            4 3         6 2
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R              *
+--R                  +---------+
+--R                  |        2
+--R                 \|4a c - b
+--R             + 
+--R                                     8 2 9                 7 4 8
+--R                       6491725627392a b c  + 7954229100544a b c
+--R                     + 
+--R                                       6 6 7                5 8 6
+--R                       - 4306988171264a b c  - 503906828288a b c
+--R                     + 
+--R                                    4 10 5               3 12 4
+--R                       372290748416a b  c  - 16484728832a b  c
+--R                     + 
+--R                                    2 14 3              16 2        18
+--R                       - 3648323584a b  c  - 38375424a b  c  - 8960b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                     9 2 8                 8 4 7
+--R                       6491725627392a b c  + 7954229100544a b c
+--R                     + 
+--R                                       7 6 6                6 8 5
+--R                       - 4306988171264a b c  - 503906828288a b c
+--R                     + 
+--R                                    5 10 4               4 12 3
+--R                       372290748416a b  c  - 16484728832a b  c
+--R                     + 
+--R                                    3 14 2            2 16           18
+--R                       - 3648323584a b  c  - 38375424a b  c - 8960a b
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                               7 8              6 2 7              5 4 6
+--R                   - 764002304a c  - 5644230656a b c  - 2864198656a b c
+--R                 + 
+--R                             4 6 5             3 8 4           2 10 3
+--R                   457626624a b c  + 139193280a b c  + 4108512a b  c
+--R                 + 
+--R                          12 2
+--R                   9620a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                8 7               7 2 6               6 4 5
+--R                   - 1528004608a c  - 12052463616a b c  - 11372627968a b c
+--R                 + 
+--R                                5 6 4             4 8 3             3 10 2
+--R                   - 1948945408a b c  + 736013184a b c  + 147410304a b  c
+--R                 + 
+--R                           2 12           14
+--R                   4127752a b  c + 9620a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                               9 6              8 2 5              7 4 4
+--R                   - 764002304a c  - 5644230656a b c  - 2864198656a b c
+--R                 + 
+--R                           6 6 3             5 8 2           4 10         3 12
+--R                 457626624a b c  + 139193280a b c  + 4108512a b  c + 9620a b
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R             %DO
+--R         + 
+--R                                    8   9                 7 3 8
+--R                       391169179648a b c  + 3603519504384a b c
+--R                     + 
+--R                                     6 5 7                5 7 6
+--R                       1941153251328a b c  - 840009515008a b c
+--R                     + 
+--R                                      4 9 5               3 11 4
+--R                       - 135450918912a b c  + 31559483392a b  c
+--R                     + 
+--R                                  2 13 3              15 2        17
+--R                       2421948416a b  c  + 20436992a b  c  + 4480b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                    9   8                 8 3 7
+--R                       391169179648a b c  + 3603519504384a b c
+--R                     + 
+--R                                     7 5 6                6 7 5
+--R                       1941153251328a b c  - 840009515008a b c
+--R                     + 
+--R                                      5 9 4               4 11 3
+--R                       - 135450918912a b c  + 31559483392a b  c
+--R                     + 
+--R                                  3 13 2            2 15           17
+--R                       2421948416a b  c  + 20436992a b  c + 4480a b
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                               6   7              5 3 6              4 5 5
+--R                   - 887947264a b c  - 2294714368a b c  - 1040019456a b c
+--R                 + 
+--R                               3 7 4           2 9 3          11 2
+--R                   - 109997568a b c  - 2374144a b c  - 4880a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                7   6              6 3 5              5 5 4
+--R                   - 1775894528a b c  - 5477376000a b c  - 4374753280a b c
+--R                 + 
+--R                                4 7 3             3 9 2           2 11
+--R                   - 1260014592a b c  - 114745856a b c  - 2383904a b  c
+--R                 + 
+--R                            13
+--R                   - 4880a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                               8   5              7 3 4              6 5 3
+--R                   - 887947264a b c  - 2294714368a b c  - 1040019456a b c
+--R                 + 
+--R                               5 7 2           4 9         3 11
+--R                   - 109997568a b c  - 2374144a b c - 4880a b
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R         + 
+--R                                     10 13                    9 2 12
+--R                   - 801114479919104a  c   - 6979450705018880a b c
+--R                 + 
+--R                                     8 4 11                    7 6 10
+--R                   - 335547541225472a b c   + 3246829919535104a b c
+--R                 + 
+--R                                     6 8 9                  5 10 8
+--R                   - 831233877606400a b c  - 95814345031680a b  c
+--R                 + 
+--R                                  4 12 7                 3 14 6
+--R                   44694478258176a b  c  - 1601393655808a b  c
+--R                 + 
+--R                                  2 16 5                18 4          20 3
+--R                   - 289091092480a b  c  - 2611347456a b  c  - 573440b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                     10   12                    9 3 11
+--R                   - 801114479919104a  b c   - 6979450705018880a b c
+--R                 + 
+--R                                     8 5 10                    7 7 9
+--R                   - 335547541225472a b c   + 3246829919535104a b c
+--R                 + 
+--R                                     6 9 8                  5 11 7
+--R                   - 831233877606400a b c  - 95814345031680a b  c
+--R                 + 
+--R                                  4 13 6                 3 15 5
+--R                   44694478258176a b  c  - 1601393655808a b  c
+--R                 + 
+--R                                  2 17 4                19 3          21 2
+--R                   - 289091092480a b  c  - 2611347456a b  c  - 573440b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                      11 12                     10 2 11
+--R                   - 1602228959838208a  c   - 13958901410037760a  b c
+--R                 + 
+--R                                     9 4 10                    8 6 9
+--R                   - 671095082450944a b c   + 6493659839070208a b c
+--R                 + 
+--R                                      7 8 8                   6 10 7
+--R                   - 1662467755212800a b c  - 191628690063360a b  c
+--R                 + 
+--R                                  5 12 6                 4 14 5
+--R                   89388956516352a b  c  - 3202787311616a b  c
+--R                 + 
+--R                                  3 16 4              2 18 3             20 2
+--R                   - 578182184960a b  c  - 5222694912a b  c  - 1146880a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                     11   11                    10 3 10
+--R                   - 801114479919104a  b c   - 6979450705018880a  b c
+--R                 + 
+--R                                     9 5 9                    8 7 8
+--R                   - 335547541225472a b c  + 3246829919535104a b c
+--R                 + 
+--R                                     7 9 7                  6 11 6
+--R                   - 831233877606400a b c  - 95814345031680a b  c
+--R                 + 
+--R                                  5 13 5                 4 15 4
+--R                   44694478258176a b  c  - 1601393655808a b  c
+--R                 + 
+--R                                  3 17 3              2 19 2            21
+--R                   - 289091092480a b  c  - 2611347456a b  c  - 573440a b  c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                     12 11                    11 2 10
+--R                   - 801114479919104a  c   - 6979450705018880a  b c
+--R                 + 
+--R                                     10 4 9                    9 6 8
+--R                   - 335547541225472a  b c  + 3246829919535104a b c
+--R                 + 
+--R                                     8 8 7                  7 10 6
+--R                   - 831233877606400a b c  - 95814345031680a b  c
+--R                 + 
+--R                                  6 12 5                 5 14 4
+--R                   44694478258176a b  c  - 1601393655808a b  c
+--R                 + 
+--R                                  4 16 3              3 18 2          2 20
+--R                   - 289091092480a b  c  - 2611347456a b  c  - 573440a b  c
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R              +------------------------------------------------------+
+--R              |                           1
+--R              |------------------------------------------------------
+--R              |        3 5           2 2 4            4 3         6 2
+--R             \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R          *
+--R               ROOT
+--R                    a
+--R                 /
+--R                              4 5           3 2 4          2 4 3           6 2
+--R                      1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                    + 
+--R                           8
+--R                      4096b c
+--R              ,
+--R                  4
+--R            **
+--R               2
+--R         + 
+--R                                 8 2 9                 7 4 8
+--R                   3637031993344a b c  + 7580634054656a b c
+--R                 + 
+--R                                  6 6 7                 5 8 6
+--R                   - 212340834304a b c  - 1091962929152a b c
+--R                 + 
+--R                               4 10 5               3 12 4             2 14 3
+--R                   50694455296a b  c  + 23317118976a b  c  + 597786624a b  c
+--R                 + 
+--R                             16 2
+--R                   1249280a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                 8 3 8                 7 5 7
+--R                   3637031993344a b c  + 7580634054656a b c
+--R                 + 
+--R                                  6 7 6                 5 9 5
+--R                   - 212340834304a b c  - 1091962929152a b c
+--R                 + 
+--R                               4 11 4               3 13 3             2 15 2
+--R                   50694455296a b  c  + 23317118976a b  c  + 597786624a b  c
+--R                 + 
+--R                             17
+--R                   1249280a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                 9 2 8                 8 4 7
+--R                   3637031993344a b c  + 7580634054656a b c
+--R                 + 
+--R                                  7 6 6                 6 8 5
+--R                   - 212340834304a b c  - 1091962929152a b c
+--R                 + 
+--R                               5 10 4               4 12 3             3 14 2
+--R                   50694455296a b  c  + 23317118976a b  c  + 597786624a b  c
+--R                 + 
+--R                           2 16
+--R                   1249280a b  c
+--R              *
+--R                  8
+--R                 x
+--R          *
+--R              +------------------------------------------------------+
+--R              |                           1
+--R              |------------------------------------------------------
+--R              |        3 5           2 2 4            4 3         6 2
+--R             \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R      *
+--R            3
+--R         %DP
+--R     + 
+--R                                            9   12                    8 3 11
+--R                           1769724094447616a b c   + 2026032710287360a b c
+--R                         + 
+--R                                              7 5 10                  6 7 9
+--R                           - 1790041437241344a b c   + 69484517785600a b c
+--R                         + 
+--R                                           5 9 8                  4 11 7
+--R                           175332980162560a b c  - 33150923177984a b  c
+--R                         + 
+--R                                          3 13 6                2 15 5
+--R                           - 505707233280a b  c  + 315187265536a b  c
+--R                         + 
+--R                                        17 4           19 3
+--R                           4395499520a b  c  + 1474560b  c
+--R                      *
+--R                          20
+--R                         x
+--R                     + 
+--R                                            9 2 11                    8 4 10
+--R                           1769724094447616a b c   + 2026032710287360a b c
+--R                         + 
+--R                                              7 6 9                  6 8 8
+--R                           - 1790041437241344a b c  + 69484517785600a b c
+--R                         + 
+--R                                           5 10 7                  4 12 6
+--R                           175332980162560a b  c  - 33150923177984a b  c
+--R                         + 
+--R                                          3 14 5                2 16 4
+--R                           - 505707233280a b  c  + 315187265536a b  c
+--R                         + 
+--R                                        18 3           20 2
+--R                           4395499520a b  c  + 1474560b  c
+--R                      *
+--R                          16
+--R                         x
+--R                     + 
+--R                                            10   11                    9 3 10
+--R                           3539448188895232a  b c   + 4052065420574720a b c
+--R                         + 
+--R                                              8 5 9                   7 7 8
+--R                           - 3580082874482688a b c  + 138969035571200a b c
+--R                         + 
+--R                                           6 9 7                  5 11 6
+--R                           350665960325120a b c  - 66301846355968a b  c
+--R                         + 
+--R                                           4 13 5                3 15 4
+--R                           - 1011414466560a b  c  + 630374531072a b  c
+--R                         + 
+--R                                      2 17 3             19 2
+--R                           8790999040a b  c  + 2949120a b  c
+--R                      *
+--R                          12
+--R                         x
+--R                     + 
+--R                                            10 2 10                    9 4 9
+--R                           1769724094447616a  b c   + 2026032710287360a b c
+--R                         + 
+--R                                              8 6 8                  7 8 7
+--R                           - 1790041437241344a b c  + 69484517785600a b c
+--R                         + 
+--R                                           6 10 6                  5 12 5
+--R                           175332980162560a b  c  - 33150923177984a b  c
+--R                         + 
+--R                                          4 14 4                3 16 3
+--R                           - 505707233280a b  c  + 315187265536a b  c
+--R                         + 
+--R                                      2 18 2             20
+--R                           4395499520a b  c  + 1474560a b  c
+--R                      *
+--R                          8
+--R                         x
+--R                     + 
+--R                                            11   10                    10 3 9
+--R                           1769724094447616a  b c   + 2026032710287360a  b c
+--R                         + 
+--R                                              9 5 8                  8 7 7
+--R                           - 1790041437241344a b c  + 69484517785600a b c
+--R                         + 
+--R                                           7 9 6                  6 11 5
+--R                           175332980162560a b c  - 33150923177984a b  c
+--R                         + 
+--R                                          5 13 4                4 15 3
+--R                           - 505707233280a b  c  + 315187265536a b  c
+--R                         + 
+--R                                      3 17 2           2 19
+--R                           4395499520a b  c  + 1474560a b  c
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                           1
+--R                      |------------------------------------------------------
+--R                      |        3 5           2 2 4            4 3         6 2
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                  *
+--R                       ROOT
+--R                            a
+--R                         /
+--R                                      4 5           3 2 4          2 4 3
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                        6 2        8
+--R                              - 65536a b c  + 4096b c
+--R                      ,
+--R                          4
+--R                    **
+--R                       2
+--R                 + 
+--R                                          8   9                 7 3 8
+--R                           - 401864654848a b c  - 3107731800064a b c
+--R                         + 
+--R                                           6 5 7                5 7 6
+--R                           - 1056072269824a b c  + 700966502400a b c
+--R                         + 
+--R                                       4 9 5               3 11 4
+--R                           35999514624a b c  - 20415102976a b  c
+--R                         + 
+--R                                       2 13 3             15 2
+--R                           - 830205952a b  c  - 2575360a b  c
+--R                      *
+--R                          16
+--R                         x
+--R                     + 
+--R                                          8 2 8                 7 4 7
+--R                           - 401864654848a b c  - 3107731800064a b c
+--R                         + 
+--R                                           6 6 6                5 8 5
+--R                           - 1056072269824a b c  + 700966502400a b c
+--R                         + 
+--R                                       4 10 4               3 12 3
+--R                           35999514624a b  c  - 20415102976a b  c
+--R                         + 
+--R                                       2 14 2             16
+--R                           - 830205952a b  c  - 2575360a b  c
+--R                      *
+--R                          12
+--R                         x
+--R                     + 
+--R                                          9   8                 8 3 7
+--R                           - 401864654848a b c  - 3107731800064a b c
+--R                         + 
+--R                                           7 5 6                6 7 5
+--R                           - 1056072269824a b c  + 700966502400a b c
+--R                         + 
+--R                                       5 9 4               4 11 3
+--R                           35999514624a b c  - 20415102976a b  c
+--R                         + 
+--R                                       3 13 2           2 15
+--R                           - 830205952a b  c  - 2575360a b  c
+--R                      *
+--R                          8
+--R                         x
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                           1
+--R                      |------------------------------------------------------
+--R                      |        3 5           2 2 4            4 3         6 2
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R              *
+--R                  +---------+
+--R                  |        2
+--R                 \|4a c - b
+--R             + 
+--R                                       8 2 9                 7 4 8
+--R                       - 3456492371968a b c  - 4821218230272a b c
+--R                     + 
+--R                                     6 6 7                5 8 6
+--R                       2290870124544a b c  + 437005582336a b c
+--R                     + 
+--R                                      4 10 5              3 12 4
+--R                       - 233195831296a b  c  + 6448939008a b  c
+--R                     + 
+--R                                  2 14 3              16 2         18
+--R                       2599944192a b  c  + 34385920a b  c  + 11520b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                       9 2 8                 8 4 7
+--R                       - 3456492371968a b c  - 4821218230272a b c
+--R                     + 
+--R                                     7 6 6                6 8 5
+--R                       2290870124544a b c  + 437005582336a b c
+--R                     + 
+--R                                      5 10 4              4 12 3
+--R                       - 233195831296a b  c  + 6448939008a b  c
+--R                     + 
+--R                                  3 14 2            2 16            18
+--R                       2599944192a b  c  + 34385920a b  c + 11520a b
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                             7 8              6 2 7              5 4 6
+--R                   392445952a c  + 3133005824a b c  + 1814572032a b c
+--R                 + 
+--R                               4 6 5            3 8 4           2 10 3
+--R                   - 230894592a b c  - 92879424a b c  - 3283232a b  c
+--R                 + 
+--R                             12 2
+--R                   - 10060a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                             8 7              7 2 6              6 4 5
+--R                   784891904a c  + 6658457600a b c  + 6762149888a b c
+--R                 + 
+--R                              5 6 4             4 8 3            3 10 2
+--R                   1352782848a b c  - 416653440a b c  - 99445888a b  c
+--R                 + 
+--R                             2 12            14
+--R                   - 3303352a b  c - 10060a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             9 6              8 2 5              7 4 4
+--R                   392445952a c  + 3133005824a b c  + 1814572032a b c
+--R                 + 
+--R                             6 6 3            5 8 2           4 10          3 12
+--R                 - 230894592a b c  - 92879424a b c  - 3283232a b  c - 10060a b
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R                2
+--R             %DO
+--R         + 
+--R                                        8   9                 7 3 8
+--R                           803729309696a b c  + 4487217414144a b c
+--R                         + 
+--R                                          6 5 7                5 7 6
+--R                           - 730526121984a b c  - 967165607936a b c
+--R                         + 
+--R                                        4 9 5              3 11 4
+--R                           255195611136a b c  + 6030950400a b  c
+--R                         + 
+--R                                        2 13 3              15 2         17
+--R                           - 3814932480a b  c  - 63713280a b  c  - 23040b  c
+--R                      *
+--R                          16
+--R                         x
+--R                     + 
+--R                                        9   8                 8 3 7
+--R                           803729309696a b c  + 4487217414144a b c
+--R                         + 
+--R                                          7 5 6                6 7 5
+--R                           - 730526121984a b c  - 967165607936a b c
+--R                         + 
+--R                                        5 9 4              4 11 3
+--R                           255195611136a b c  + 6030950400a b  c
+--R                         + 
+--R                                        3 13 2            2 15            17
+--R                           - 3814932480a b  c  - 63713280a b  c - 23040a b
+--R                      *
+--R                          8
+--R                         x
+--R                  *
+--R                       ROOT
+--R                            a
+--R                         /
+--R                                      4 5           3 2 4          2 4 3
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                        6 2        8
+--R                              - 65536a b c  + 4096b c
+--R                      ,
+--R                          4
+--R                    **
+--R                       2
+--R                 + 
+--R                                    6   7              5 3 6            4 5 5
+--R                       - 1491517440a b c  - 2004357120a b c  + 31279104a b c
+--R                     + 
+--R                                 3 7 4           2 9 3           11 2
+--R                       118169088a b c  + 5568064a b c  + 19760a b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                    7   6              6 3 5              5 5 4
+--R                       - 2983034880a b c  - 5500231680a b c  - 1941798912a b c
+--R                     + 
+--R                                 4 7 3             3 9 2           2 11
+--R                       267617280a b c  + 129305216a b c  + 5607584a b  c
+--R                     + 
+--R                               13
+--R                       19760a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                    8   5              7 3 4            6 5 3
+--R                       - 1491517440a b c  - 2004357120a b c  + 31279104a b c
+--R                     + 
+--R                                 5 7 2           4 9          3 11
+--R                       118169088a b c  + 5568064a b c + 19760a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +---------+
+--R                  |        2
+--R                 \|4a c - b
+--R             + 
+--R                                          10 13                    9 2 12
+--R                       - 1646037626257408a  c   - 8366802451038208a b c
+--R                     + 
+--R                                        8 4 11                   7 6 10
+--R                       5988150778265600a b c   + 658332587130880a b c
+--R                     + 
+--R                                          6 8 9                   5 10 8
+--R                       - 1419510850519040a b c  + 372766117199872a b  c
+--R                     + 
+--R                                        4 12 7                 3 14 6
+--R                       - 18676363296768a b  c  - 4547967713280a b  c
+--R                     + 
+--R                                    2 16 5                18 4           20 3
+--R                       423116144640a b  c  + 8131706880a b  c  + 2949120b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                          10   12                    9 3 11
+--R                       - 1646037626257408a  b c   - 8366802451038208a b c
+--R                     + 
+--R                                        8 5 10                   7 7 9
+--R                       5988150778265600a b c   + 658332587130880a b c
+--R                     + 
+--R                                          6 9 8                   5 11 7
+--R                       - 1419510850519040a b c  + 372766117199872a b  c
+--R                     + 
+--R                                        4 13 6                 3 15 5
+--R                       - 18676363296768a b  c  - 4547967713280a b  c
+--R                     + 
+--R                                    2 17 4                19 3           21 2
+--R                       423116144640a b  c  + 8131706880a b  c  + 2949120b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                          11 12                     10 2 11
+--R                       - 3292075252514816a  c   - 16733604902076416a  b c
+--R                     + 
+--R                                         9 4 10                    8 6 9
+--R                       11976301556531200a b c   + 1316665174261760a b c
+--R                     + 
+--R                                          7 8 8                   6 10 7
+--R                       - 2839021701038080a b c  + 745532234399744a b  c
+--R                     + 
+--R                                        5 12 6                 4 14 5
+--R                       - 37352726593536a b  c  - 9095935426560a b  c
+--R                     + 
+--R                                  3 16 4               2 18 3             20 2
+--R                     846232289280a b  c  + 16263413760a b  c  + 5898240a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                          11   11                    10 3 10
+--R                       - 1646037626257408a  b c   - 8366802451038208a  b c
+--R                     + 
+--R                                        9 5 9                   8 7 8
+--R                       5988150778265600a b c  + 658332587130880a b c
+--R                     + 
+--R                                          7 9 7                   6 11 6
+--R                       - 1419510850519040a b c  + 372766117199872a b  c
+--R                     + 
+--R                                        5 13 5                 4 15 4
+--R                       - 18676363296768a b  c  - 4547967713280a b  c
+--R                     + 
+--R                                    3 17 3              2 19 2             21
+--R                       423116144640a b  c  + 8131706880a b  c  + 2949120a b  c
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                          12 11                    11 2 10
+--R                       - 1646037626257408a  c   - 8366802451038208a  b c
+--R                     + 
+--R                                        10 4 9                   9 6 8
+--R                       5988150778265600a  b c  + 658332587130880a b c
+--R                     + 
+--R                                          8 8 7                   7 10 6
+--R                       - 1419510850519040a b c  + 372766117199872a b  c
+--R                     + 
+--R                                        6 12 5                 5 14 4
+--R                       - 18676363296768a b  c  - 4547967713280a b  c
+--R                     + 
+--R                                    4 16 3              3 18 2           2 20
+--R                       423116144640a b  c  + 8131706880a b  c  + 2949120a b  c
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +------------------------------------------------------+
+--R                  |                           1
+--R                  |------------------------------------------------------
+--R                  |        3 5           2 2 4            4 3         6 2
+--R                 \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                                     8 2 9                 7 4 8
+--R                       6109255434240a b c  + 5155219046400a b c
+--R                     + 
+--R                                       6 6 7               5 8 6
+--R                       - 3851214127104a b c  + 93154443264a b c
+--R                     + 
+--R                                    4 10 5               3 12 4
+--R                       211196051456a b  c  - 18928828416a b  c
+--R                     + 
+--R                                    2 14 3             16 2
+--R                       - 1384955904a b  c  - 5058560a b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                     8 3 8                 7 5 7
+--R                       6109255434240a b c  + 5155219046400a b c
+--R                     + 
+--R                                       6 7 6               5 9 5
+--R                       - 3851214127104a b c  + 93154443264a b c
+--R                     + 
+--R                                    4 11 4               3 13 3
+--R                       211196051456a b  c  - 18928828416a b  c
+--R                     + 
+--R                                    2 15 2             17
+--R                       - 1384955904a b  c  - 5058560a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                     9 2 8                 8 4 7
+--R                       6109255434240a b c  + 5155219046400a b c
+--R                     + 
+--R                                       7 6 6               6 8 5
+--R                       - 3851214127104a b c  + 93154443264a b c
+--R                     + 
+--R                                    5 10 4               4 12 3
+--R                       211196051456a b  c  - 18928828416a b  c
+--R                     + 
+--R                                    3 14 2           2 16
+--R                       - 1384955904a b  c  - 5058560a b  c
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                  +------------------------------------------------------+
+--R                  |                           1
+--R                  |------------------------------------------------------
+--R                  |        3 5           2 2 4            4 3         6 2
+--R                 \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R          *
+--R             %DO
+--R         + 
+--R                                          9   12                    8 3 11
+--R                       - 1769724094447616a b c   - 2026032710287360a b c
+--R                     + 
+--R                                        7 5 10                  6 7 9
+--R                       1790041437241344a b c   - 69484517785600a b c
+--R                     + 
+--R                                         5 9 8                  4 11 7
+--R                       - 175332980162560a b c  + 33150923177984a b  c
+--R                     + 
+--R                                    3 13 6                2 15 5
+--R                       505707233280a b  c  - 315187265536a b  c
+--R                     + 
+--R                                      17 4           19 3
+--R                       - 4395499520a b  c  - 1474560b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                          9 2 11                    8 4 10
+--R                       - 1769724094447616a b c   - 2026032710287360a b c
+--R                     + 
+--R                                        7 6 9                  6 8 8
+--R                       1790041437241344a b c  - 69484517785600a b c
+--R                     + 
+--R                                         5 10 7                  4 12 6
+--R                       - 175332980162560a b  c  + 33150923177984a b  c
+--R                     + 
+--R                                    3 14 5                2 16 4
+--R                       505707233280a b  c  - 315187265536a b  c
+--R                     + 
+--R                                      18 3           20 2
+--R                       - 4395499520a b  c  - 1474560b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                          10   11                    9 3 10
+--R                       - 3539448188895232a  b c   - 4052065420574720a b c
+--R                     + 
+--R                                        8 5 9                   7 7 8
+--R                       3580082874482688a b c  - 138969035571200a b c
+--R                     + 
+--R                                         6 9 7                  5 11 6
+--R                       - 350665960325120a b c  + 66301846355968a b  c
+--R                     + 
+--R                                     4 13 5                3 15 4
+--R                       1011414466560a b  c  - 630374531072a b  c
+--R                     + 
+--R                                    2 17 3             19 2
+--R                       - 8790999040a b  c  - 2949120a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                          10 2 10                    9 4 9
+--R                       - 1769724094447616a  b c   - 2026032710287360a b c
+--R                     + 
+--R                                        8 6 8                  7 8 7
+--R                       1790041437241344a b c  - 69484517785600a b c
+--R                     + 
+--R                                         6 10 6                  5 12 5
+--R                       - 175332980162560a b  c  + 33150923177984a b  c
+--R                     + 
+--R                                    4 14 4                3 16 3
+--R                       505707233280a b  c  - 315187265536a b  c
+--R                     + 
+--R                                    2 18 2             20
+--R                       - 4395499520a b  c  - 1474560a b  c
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                          11   10                    10 3 9
+--R                       - 1769724094447616a  b c   - 2026032710287360a  b c
+--R                     + 
+--R                                        9 5 8                  8 7 7
+--R                       1790041437241344a b c  - 69484517785600a b c
+--R                     + 
+--R                                         7 9 6                  6 11 5
+--R                       - 175332980162560a b c  + 33150923177984a b  c
+--R                     + 
+--R                                    5 13 4                4 15 3
+--R                       505707233280a b  c  - 315187265536a b  c
+--R                     + 
+--R                                    3 17 2           2 19
+--R                       - 4395499520a b  c  - 1474560a b  c
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +------------------------------------------------------+
+--R                  |                           1
+--R                  |------------------------------------------------------
+--R                  |        3 5           2 2 4            4 3         6 2
+--R                 \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                                    8   9                 7 3 8
+--R                       401864654848a b c  + 3107731800064a b c
+--R                     + 
+--R                                     6 5 7                5 7 6
+--R                       1056072269824a b c  - 700966502400a b c
+--R                     + 
+--R                                     4 9 5               3 11 4
+--R                       - 35999514624a b c  + 20415102976a b  c
+--R                     + 
+--R                                 2 13 3             15 2
+--R                       830205952a b  c  + 2575360a b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                    8 2 8                 7 4 7
+--R                       401864654848a b c  + 3107731800064a b c
+--R                     + 
+--R                                     6 6 6                5 8 5
+--R                       1056072269824a b c  - 700966502400a b c
+--R                     + 
+--R                                     4 10 4               3 12 3
+--R                       - 35999514624a b  c  + 20415102976a b  c
+--R                     + 
+--R                                 2 14 2             16
+--R                       830205952a b  c  + 2575360a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                    9   8                 8 3 7
+--R                       401864654848a b c  + 3107731800064a b c
+--R                     + 
+--R                                     7 5 6                6 7 5
+--R                       1056072269824a b c  - 700966502400a b c
+--R                     + 
+--R                                     5 9 4               4 11 3
+--R                       - 35999514624a b c  + 20415102976a b  c
+--R                     + 
+--R                                 3 13 2           2 15
+--R                       830205952a b  c  + 2575360a b  c
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                  +------------------------------------------------------+
+--R                  |                           1
+--R                  |------------------------------------------------------
+--R                  |        3 5           2 2 4            4 3         6 2
+--R                 \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R          *
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R         + 
+--R                                 8 2 9                 7 4 8
+--R                   3456492371968a b c  + 4821218230272a b c
+--R                 + 
+--R                                   6 6 7                5 8 6
+--R                   - 2290870124544a b c  - 437005582336a b c
+--R                 + 
+--R                                4 10 5              3 12 4              2 14 3
+--R                   233195831296a b  c  - 6448939008a b  c  - 2599944192a b  c
+--R                 + 
+--R                                16 2         18
+--R                   - 34385920a b  c  - 11520b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                 9 2 8                 8 4 7
+--R                   3456492371968a b c  + 4821218230272a b c
+--R                 + 
+--R                                   7 6 6                6 8 5
+--R                   - 2290870124544a b c  - 437005582336a b c
+--R                 + 
+--R                                5 10 4              4 12 3              3 14 2
+--R                   233195831296a b  c  - 6448939008a b  c  - 2599944192a b  c
+--R                 + 
+--R                              2 16            18
+--R                   - 34385920a b  c - 11520a b
+--R              *
+--R                  8
+--R                 x
+--R          *
+--R               ROOT
+--R                    a
+--R                 /
+--R                              4 5           3 2 4          2 4 3           6 2
+--R                      1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                    + 
+--R                           8
+--R                      4096b c
+--R              ,
+--R                  4
+--R            **
+--R               2
+--R         + 
+--R                           7 8              6 2 7              5 4 6
+--R               - 392445952a c  - 3133005824a b c  - 1814572032a b c
+--R             + 
+--R                         4 6 5            3 8 4           2 10 3           12 2
+--R               230894592a b c  + 92879424a b c  + 3283232a b  c  + 10060a b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                           8 7              7 2 6              6 4 5
+--R               - 784891904a c  - 6658457600a b c  - 6762149888a b c
+--R             + 
+--R                            5 6 4             4 8 3            3 10 2
+--R               - 1352782848a b c  + 416653440a b c  + 99445888a b  c
+--R             + 
+--R                       2 12            14
+--R               3303352a b  c + 10060a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           9 6              8 2 5              7 4 4
+--R               - 392445952a c  - 3133005824a b c  - 1814572032a b c
+--R             + 
+--R                         6 6 3            5 8 2           4 10          3 12
+--R               230894592a b c  + 92879424a b c  + 3283232a b  c + 10060a b
+--R          *
+--R              4
+--R             x
+--R      *
+--R            2
+--R         %DP
+--R     + 
+--R                                        8   9                 7 3 8
+--R                           326711115776a b c  + 3204657971200a b c
+--R                         + 
+--R                                         6 5 7                5 7 6
+--R                           1975127113728a b c  - 739587391488a b c
+--R                         + 
+--R                                          4 9 5               3 11 4
+--R                           - 158008147968a b c  + 30203019264a b  c
+--R                         + 
+--R                                      2 13 3              15 2         17
+--R                           2837053440a b  c  + 29734912a b  c  + 10112b  c
+--R                      *
+--R                          16
+--R                         x
+--R                     + 
+--R                                        9   8                 8 3 7
+--R                           326711115776a b c  + 3204657971200a b c
+--R                         + 
+--R                                         7 5 6                6 7 5
+--R                           1975127113728a b c  - 739587391488a b c
+--R                         + 
+--R                                          5 9 4               4 11 3
+--R                           - 158008147968a b c  + 30203019264a b  c
+--R                         + 
+--R                                      3 13 2            2 15            17
+--R                           2837053440a b  c  + 29734912a b  c + 10112a b
+--R                      *
+--R                          8
+--R                         x
+--R                  *
+--R                       ROOT
+--R                            a
+--R                         /
+--R                                      4 5           3 2 4          2 4 3
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                        6 2        8
+--R                              - 65536a b c  + 4096b c
+--R                      ,
+--R                          4
+--R                    **
+--R                       2
+--R                 + 
+--R                                   6   7              5 3 6              4 5 5
+--R                       - 763035648a b c  - 2105561088a b c  - 1035563008a b c
+--R                     + 
+--R                                   3 7 4           2 9 3          11 2
+--R                       - 122000896a b c  - 3081216a b c  - 8400a b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                    7   6              6 3 5              5 5 4
+--R                       - 1526071296a b c  - 4974157824a b c  - 4176687104a b c
+--R                     + 
+--R                                    4 7 3             3 9 2           2 11
+--R                       - 1279564800a b c  - 128163328a b c  - 3098016a b  c
+--R                     + 
+--R                                13
+--R                       - 8400a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                   8   5              7 3 4              6 5 3
+--R                       - 763035648a b c  - 2105561088a b c  - 1035563008a b c
+--R                     + 
+--R                                   5 7 2           4 9         3 11
+--R                       - 122000896a b c  - 3081216a b c - 8400a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +---------+
+--R                  |        2
+--R                 \|4a c - b
+--R             + 
+--R                                         10 13                    9 2 12
+--R                       - 669104365109248a  c   - 6228587342462976a b c
+--R                     + 
+--R                                         8 4 11                    7 6 10
+--R                       - 805309589225472a b c   + 3127008921911296a b c
+--R                     + 
+--R                                         6 8 9                   5 10 8
+--R                       - 686553072402432a b c  - 128988940861440a b  c
+--R                     + 
+--R                                      4 12 7                 3 14 6
+--R                       45342649221120a b  c  - 1021740843008a b  c
+--R                     + 
+--R                                      2 16 5                18 4           20 3
+--R                       - 332714999808a b  c  - 3795714048a b  c  - 1294336b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                         10   12                    9 3 11
+--R                       - 669104365109248a  b c   - 6228587342462976a b c
+--R                     + 
+--R                                         8 5 10                    7 7 9
+--R                       - 805309589225472a b c   + 3127008921911296a b c
+--R                     + 
+--R                                         6 9 8                   5 11 7
+--R                       - 686553072402432a b c  - 128988940861440a b  c
+--R                     + 
+--R                                      4 13 6                 3 15 5
+--R                       45342649221120a b  c  - 1021740843008a b  c
+--R                     + 
+--R                                      2 17 4                19 3           21 2
+--R                       - 332714999808a b  c  - 3795714048a b  c  - 1294336b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                          11 12                     10 2 11
+--R                       - 1338208730218496a  c   - 12457174684925952a  b c
+--R                     + 
+--R                                          9 4 10                    8 6 9
+--R                       - 1610619178450944a b c   + 6254017843822592a b c
+--R                     + 
+--R                                          7 8 8                   6 10 7
+--R                       - 1373106144804864a b c  - 257977881722880a b  c
+--R                     + 
+--R                                      5 12 6                 4 14 5
+--R                       90685298442240a b  c  - 2043481686016a b  c
+--R                     + 
+--R                                    3 16 4              2 18 3             20 2
+--R                     - 665429999616a b  c  - 7591428096a b  c  - 2588672a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                         11   11                    10 3 10
+--R                       - 669104365109248a  b c   - 6228587342462976a  b c
+--R                     + 
+--R                                         9 5 9                    8 7 8
+--R                       - 805309589225472a b c  + 3127008921911296a b c
+--R                     + 
+--R                                         7 9 7                   6 11 6
+--R                       - 686553072402432a b c  - 128988940861440a b  c
+--R                     + 
+--R                                      5 13 5                 4 15 4
+--R                       45342649221120a b  c  - 1021740843008a b  c
+--R                     + 
+--R                                    3 17 3              2 19 2             21
+--R                     - 332714999808a b  c  - 3795714048a b  c  - 1294336a b  c
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                         12 11                    11 2 10
+--R                       - 669104365109248a  c   - 6228587342462976a  b c
+--R                     + 
+--R                                         10 4 9                    9 6 8
+--R                       - 805309589225472a  b c  + 3127008921911296a b c
+--R                     + 
+--R                                         8 8 7                   7 10 6
+--R                       - 686553072402432a b c  - 128988940861440a b  c
+--R                     + 
+--R                                      6 12 5                 5 14 4
+--R                       45342649221120a b  c  - 1021740843008a b  c
+--R                     + 
+--R                                    4 16 3              3 18 2           2 20
+--R                     - 332714999808a b  c  - 3795714048a b  c  - 1294336a b  c
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +------------------------------------------------------+
+--R                  |                           1
+--R                  |------------------------------------------------------
+--R                  |        3 5           2 2 4            4 3         6 2
+--R                 \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                                     8 2 9                 7 4 8
+--R                       3125394014208a b c  + 7061681209344a b c
+--R                     + 
+--R                                    6 6 7                 5 8 6
+--R                       124814098432a b c  - 1082093731840a b c
+--R                     + 
+--R                                   4 10 5               3 12 4
+--R                       27866955776a b  c  + 24956305408a b  c
+--R                     + 
+--R                                 2 14 3             16 2
+--R                       771588096a b  c  + 2150400a b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                     8 3 8                 7 5 7
+--R                       3125394014208a b c  + 7061681209344a b c
+--R                     + 
+--R                                    6 7 6                 5 9 5
+--R                       124814098432a b c  - 1082093731840a b c
+--R                     + 
+--R                                   4 11 4               3 13 3
+--R                       27866955776a b  c  + 24956305408a b  c
+--R                     + 
+--R                                 2 15 2             17
+--R                       771588096a b  c  + 2150400a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                     9 2 8                 8 4 7
+--R                       3125394014208a b c  + 7061681209344a b c
+--R                     + 
+--R                                    7 6 6                 6 8 5
+--R                       124814098432a b c  - 1082093731840a b c
+--R                     + 
+--R                                   5 10 4               4 12 3
+--R                       27866955776a b  c  + 24956305408a b  c
+--R                     + 
+--R                                 3 14 2           2 16
+--R                       771588096a b  c  + 2150400a b  c
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                  +------------------------------------------------------+
+--R                  |                           1
+--R                  |------------------------------------------------------
+--R                  |        3 5           2 2 4            4 3         6 2
+--R                 \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R          *
+--R                2
+--R             %DO
+--R         + 
+--R                                            9   12                    8 3 11
+--R                           2865851287994368a b c   + 3233128973860864a b c
+--R                         + 
+--R                                              7 5 10                   6 7 9
+--R                           - 2882118476627968a b c   + 122953639395328a b c
+--R                         + 
+--R                                           5 9 8                  4 11 7
+--R                           278017729363968a b c  - 52956661547008a b  c
+--R                         + 
+--R                                          3 13 6                2 15 5
+--R                           - 771877765120a b  c  + 500512587776a b  c
+--R                         + 
+--R                                        17 4           19 3
+--R                           7051280384a b  c  + 2588672b  c
+--R                      *
+--R                          20
+--R                         x
+--R                     + 
+--R                                            9 2 11                    8 4 10
+--R                           2865851287994368a b c   + 3233128973860864a b c
+--R                         + 
+--R                                              7 6 9                   6 8 8
+--R                           - 2882118476627968a b c  + 122953639395328a b c
+--R                         + 
+--R                                           5 10 7                  4 12 6
+--R                           278017729363968a b  c  - 52956661547008a b  c
+--R                         + 
+--R                                          3 14 5                2 16 4
+--R                           - 771877765120a b  c  + 500512587776a b  c
+--R                         + 
+--R                                        18 3           20 2
+--R                           7051280384a b  c  + 2588672b  c
+--R                      *
+--R                          16
+--R                         x
+--R                     + 
+--R                                            10   11                    9 3 10
+--R                           5731702575988736a  b c   + 6466257947721728a b c
+--R                         + 
+--R                                              8 5 9                   7 7 8
+--R                           - 5764236953255936a b c  + 245907278790656a b c
+--R                         + 
+--R                                           6 9 7                   5 11 6
+--R                           556035458727936a b c  - 105913323094016a b  c
+--R                         + 
+--R                                           4 13 5                 3 15 4
+--R                           - 1543755530240a b  c  + 1001025175552a b  c
+--R                         + 
+--R                                       2 17 3             19 2
+--R                           14102560768a b  c  + 5177344a b  c
+--R                      *
+--R                          12
+--R                         x
+--R                     + 
+--R                                            10 2 10                    9 4 9
+--R                           2865851287994368a  b c   + 3233128973860864a b c
+--R                         + 
+--R                                              8 6 8                   7 8 7
+--R                           - 2882118476627968a b c  + 122953639395328a b c
+--R                         + 
+--R                                           6 10 6                  5 12 5
+--R                           278017729363968a b  c  - 52956661547008a b  c
+--R                         + 
+--R                                          4 14 4                3 16 3
+--R                           - 771877765120a b  c  + 500512587776a b  c
+--R                         + 
+--R                                      2 18 2             20
+--R                           7051280384a b  c  + 2588672a b  c
+--R                      *
+--R                          8
+--R                         x
+--R                     + 
+--R                                            11   10                    10 3 9
+--R                           2865851287994368a  b c   + 3233128973860864a  b c
+--R                         + 
+--R                                              9 5 8                   8 7 7
+--R                           - 2882118476627968a b c  + 122953639395328a b c
+--R                         + 
+--R                                           7 9 6                  6 11 5
+--R                           278017729363968a b c  - 52956661547008a b  c
+--R                         + 
+--R                                          5 13 4                4 15 3
+--R                           - 771877765120a b  c  + 500512587776a b  c
+--R                         + 
+--R                                      3 17 2           2 19
+--R                           7051280384a b  c  + 2588672a b  c
+--R                      *
+--R                          4
+--R                         x
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                           1
+--R                      |------------------------------------------------------
+--R                      |        3 5           2 2 4            4 3         6 2
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R                  *
+--R                       ROOT
+--R                            a
+--R                         /
+--R                                      4 5           3 2 4          2 4 3
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                        6 2        8
+--R                              - 65536a b c  + 4096b c
+--R                      ,
+--R                          4
+--R                    **
+--R                       2
+--R                 + 
+--R                                          8   9                 7 3 8
+--R                           - 653422231552a b c  - 5009974493184a b c
+--R                         + 
+--R                                           6 5 7                 5 7 6
+--R                           - 1671907246080a b c  + 1123605020672a b c
+--R                         + 
+--R                                       4 9 5               3 11 4
+--R                           55870685184a b c  - 32504889344a b  c
+--R                         + 
+--R                                        2 13 3             15 2
+--R                           - 1322176512a b  c  - 4219904a b  c
+--R                      *
+--R                          16
+--R                         x
+--R                     + 
+--R                                          8 2 8                 7 4 7
+--R                           - 653422231552a b c  - 5009974493184a b c
+--R                         + 
+--R                                           6 6 6                 5 8 5
+--R                           - 1671907246080a b c  + 1123605020672a b c
+--R                         + 
+--R                                       4 10 4               3 12 3
+--R                           55870685184a b  c  - 32504889344a b  c
+--R                         + 
+--R                                        2 14 2             16
+--R                           - 1322176512a b  c  - 4219904a b  c
+--R                      *
+--R                          12
+--R                         x
+--R                     + 
+--R                                          9   8                 8 3 7
+--R                           - 653422231552a b c  - 5009974493184a b c
+--R                         + 
+--R                                           7 5 6                 6 7 5
+--R                           - 1671907246080a b c  + 1123605020672a b c
+--R                         + 
+--R                                       5 9 4               4 11 3
+--R                           55870685184a b c  - 32504889344a b  c
+--R                         + 
+--R                                        3 13 2           2 15
+--R                           - 1322176512a b  c  - 4219904a b  c
+--R                      *
+--R                          8
+--R                         x
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                           1
+--R                      |------------------------------------------------------
+--R                      |        3 5           2 2 4            4 3         6 2
+--R                     \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R              *
+--R                  +---------+
+--R                  |        2
+--R                 \|4a c - b
+--R             + 
+--R                                       8 2 9                 7 4 8
+--R                       - 5597365796864a b c  - 7714046476288a b c
+--R                     + 
+--R                                     6 6 7                5 8 6
+--R                       3700626030592a b c  + 685012680704a b c
+--R                     + 
+--R                                      4 10 5               3 12 4
+--R                       - 371750207488a b  c  + 10493427712a b  c
+--R                     + 
+--R                                  2 14 3              16 2         18
+--R                       4130930688a b  c  + 55169024a b  c  + 20224b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                       9 2 8                 8 4 7
+--R                       - 5597365796864a b c  - 7714046476288a b c
+--R                     + 
+--R                                     7 6 6                6 8 5
+--R                       3700626030592a b c  + 685012680704a b c
+--R                     + 
+--R                                      5 10 4               4 12 3
+--R                       - 371750207488a b  c  + 10493427712a b  c
+--R                     + 
+--R                                  3 14 2            2 16            18
+--R                       4130930688a b  c  + 55169024a b  c + 20224a b
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                             7 8              6 2 7              5 4 6
+--R                   638107648a c  + 5052080128a b c  + 2895741952a b c
+--R                 + 
+--R                               4 6 5             3 8 4           2 10 3
+--R                   - 373335040a b c  - 147894976a b c  - 5230688a b  c
+--R                 + 
+--R                             12 2
+--R                   - 16484a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                              8 7               7 2 6               6 4 5
+--R                   1276215296a c  + 10742267904a b c  + 10843564032a b c
+--R                 + 
+--R                              5 6 4             4 8 3             3 10 2
+--R                   2149071872a b c  - 669124992a b c  - 158356352a b  c
+--R                 + 
+--R                             2 12            14
+--R                   - 5263656a b  c - 16484a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             9 6              8 2 5              7 4 4
+--R                   638107648a c  + 5052080128a b c  + 2895741952a b c
+--R                 + 
+--R                               6 6 3             5 8 2           4 10
+--R                   - 373335040a b c  - 147894976a b c  - 5230688a b  c
+--R                 + 
+--R                           3 12
+--R                   - 16484a b
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R             %DO
+--R         + 
+--R                                      8   9                 7 3 8
+--R                       - 326711115776a b c  - 3204657971200a b c
+--R                     + 
+--R                                       6 5 7                5 7 6
+--R                       - 1975127113728a b c  + 739587391488a b c
+--R                     + 
+--R                                    4 9 5               3 11 4
+--R                       158008147968a b c  - 30203019264a b  c
+--R                     + 
+--R                                    2 13 3              15 2         17
+--R                       - 2837053440a b  c  - 29734912a b  c  - 10112b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                      9   8                 8 3 7
+--R                       - 326711115776a b c  - 3204657971200a b c
+--R                     + 
+--R                                       7 5 6                6 7 5
+--R                       - 1975127113728a b c  + 739587391488a b c
+--R                     + 
+--R                                    5 9 4               4 11 3
+--R                       158008147968a b c  - 30203019264a b  c
+--R                     + 
+--R                                    3 13 2            2 15            17
+--R                       - 2837053440a b  c  - 29734912a b  c - 10112a b
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                             6   7              5 3 6              4 5 5
+--R                   763035648a b c  + 2105561088a b c  + 1035563008a b c
+--R                 + 
+--R                             3 7 4           2 9 3          11 2
+--R                   122000896a b c  + 3081216a b c  + 8400a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                              7   6              6 3 5              5 5 4
+--R                   1526071296a b c  + 4974157824a b c  + 4176687104a b c
+--R                 + 
+--R                            4 7 3             3 9 2           2 11           13
+--R                 1279564800a b c  + 128163328a b c  + 3098016a b  c + 8400a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             8   5              7 3 4              6 5 3
+--R                   763035648a b c  + 2105561088a b c  + 1035563008a b c
+--R                 + 
+--R                             5 7 2           4 9         3 11
+--R                   122000896a b c  + 3081216a b c + 8400a b
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R         + 
+--R                                   10 13                    9 2 12
+--R                   669104365109248a  c   + 6228587342462976a b c
+--R                 + 
+--R                                   8 4 11                    7 6 10
+--R                   805309589225472a b c   - 3127008921911296a b c
+--R                 + 
+--R                                   6 8 9                   5 10 8
+--R                   686553072402432a b c  + 128988940861440a b  c
+--R                 + 
+--R                                    4 12 7                 3 14 6
+--R                   - 45342649221120a b  c  + 1021740843008a b  c
+--R                 + 
+--R                                2 16 5                18 4           20 3
+--R                   332714999808a b  c  + 3795714048a b  c  + 1294336b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                   10   12                    9 3 11
+--R                   669104365109248a  b c   + 6228587342462976a b c
+--R                 + 
+--R                                   8 5 10                    7 7 9
+--R                   805309589225472a b c   - 3127008921911296a b c
+--R                 + 
+--R                                   6 9 8                   5 11 7
+--R                   686553072402432a b c  + 128988940861440a b  c
+--R                 + 
+--R                                    4 13 6                 3 15 5
+--R                   - 45342649221120a b  c  + 1021740843008a b  c
+--R                 + 
+--R                                2 17 4                19 3           21 2
+--R                   332714999808a b  c  + 3795714048a b  c  + 1294336b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                    11 12                     10 2 11
+--R                   1338208730218496a  c   + 12457174684925952a  b c
+--R                 + 
+--R                                    9 4 10                    8 6 9
+--R                   1610619178450944a b c   - 6254017843822592a b c
+--R                 + 
+--R                                    7 8 8                   6 10 7
+--R                   1373106144804864a b c  + 257977881722880a b  c
+--R                 + 
+--R                                    5 12 6                 4 14 5
+--R                   - 90685298442240a b  c  + 2043481686016a b  c
+--R                 + 
+--R                                3 16 4              2 18 3             20 2
+--R                   665429999616a b  c  + 7591428096a b  c  + 2588672a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                   11   11                    10 3 10
+--R                   669104365109248a  b c   + 6228587342462976a  b c
+--R                 + 
+--R                                   9 5 9                    8 7 8
+--R                   805309589225472a b c  - 3127008921911296a b c
+--R                 + 
+--R                                   7 9 7                   6 11 6
+--R                   686553072402432a b c  + 128988940861440a b  c
+--R                 + 
+--R                                    5 13 5                 4 15 4
+--R                   - 45342649221120a b  c  + 1021740843008a b  c
+--R                 + 
+--R                                3 17 3              2 19 2             21
+--R                   332714999808a b  c  + 3795714048a b  c  + 1294336a b  c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                   12 11                    11 2 10
+--R                   669104365109248a  c   + 6228587342462976a  b c
+--R                 + 
+--R                                   10 4 9                    9 6 8
+--R                   805309589225472a  b c  - 3127008921911296a b c
+--R                 + 
+--R                                   8 8 7                   7 10 6
+--R                   686553072402432a b c  + 128988940861440a b  c
+--R                 + 
+--R                                    6 12 5                 5 14 4
+--R                   - 45342649221120a b  c  + 1021740843008a b  c
+--R                 + 
+--R                                4 16 3              3 18 2           2 20
+--R                   332714999808a b  c  + 3795714048a b  c  + 1294336a b  c
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R              +------------------------------------------------------+
+--R              |                           1
+--R              |------------------------------------------------------
+--R              |        3 5           2 2 4            4 3         6 2
+--R             \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R          *
+--R               ROOT
+--R                    a
+--R                 /
+--R                              4 5           3 2 4          2 4 3           6 2
+--R                      1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                    + 
+--R                           8
+--R                      4096b c
+--R              ,
+--R                  4
+--R            **
+--R               2
+--R         + 
+--R                                   8 2 9                 7 4 8
+--R                   - 3125394014208a b c  - 7061681209344a b c
+--R                 + 
+--R                                  6 6 7                 5 8 6
+--R                   - 124814098432a b c  + 1082093731840a b c
+--R                 + 
+--R                                 4 10 5               3 12 4             2 14 3
+--R                   - 27866955776a b  c  - 24956305408a b  c  - 771588096a b  c
+--R                 + 
+--R                               16 2
+--R                   - 2150400a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                   8 3 8                 7 5 7
+--R                   - 3125394014208a b c  - 7061681209344a b c
+--R                 + 
+--R                                  6 7 6                 5 9 5
+--R                   - 124814098432a b c  + 1082093731840a b c
+--R                 + 
+--R                                 4 11 4               3 13 3             2 15 2
+--R                   - 27866955776a b  c  - 24956305408a b  c  - 771588096a b  c
+--R                 + 
+--R                               17
+--R                   - 2150400a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                   9 2 8                 8 4 7
+--R                   - 3125394014208a b c  - 7061681209344a b c
+--R                 + 
+--R                                  7 6 6                 6 8 5
+--R                   - 124814098432a b c  + 1082093731840a b c
+--R                 + 
+--R                                 5 10 4               4 12 3             3 14 2
+--R                   - 27866955776a b  c  - 24956305408a b  c  - 771588096a b  c
+--R                 + 
+--R                             2 16
+--R                   - 2150400a b  c
+--R              *
+--R                  8
+--R                 x
+--R          *
+--R              +------------------------------------------------------+
+--R              |                           1
+--R              |------------------------------------------------------
+--R              |        3 5           2 2 4            4 3         6 2
+--R             \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R      *
+--R         %DP
+--R     + 
+--R                                         9   12                   8 3 11
+--R                       - 344381215211520a b c   - 403524525490176a b c
+--R                     + 
+--R                                       7 5 10                  6 7 9
+--R                       349654898180096a b c   - 10183770112000a b c
+--R                     + 
+--R                                        5 9 8                 4 11 7
+--R                       - 35411518816256a b c  + 6511837315072a b  c
+--R                     + 
+--R                                    3 13 6               2 15 5
+--R                       128662372352a b  c  - 64172326912a b  c
+--R                     + 
+--R                                     17 4          19 3
+--R                       - 953843712a b  c  - 385024b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                         9 2 11                   8 4 10
+--R                       - 344381215211520a b c   - 403524525490176a b c
+--R                     + 
+--R                                       7 6 9                  6 8 8
+--R                       349654898180096a b c  - 10183770112000a b c
+--R                     + 
+--R                                        5 10 7                 4 12 6
+--R                       - 35411518816256a b  c  + 6511837315072a b  c
+--R                     + 
+--R                                    3 14 5               2 16 4
+--R                       128662372352a b  c  - 64172326912a b  c
+--R                     + 
+--R                                     18 3          20 2
+--R                       - 953843712a b  c  - 385024b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                         10   11                   9 3 10
+--R                       - 688762430423040a  b c   - 807049050980352a b c
+--R                     + 
+--R                                       8 5 9                  7 7 8
+--R                       699309796360192a b c  - 20367540224000a b c
+--R                     + 
+--R                                        6 9 7                  5 11 6
+--R                       - 70823037632512a b c  + 13023674630144a b  c
+--R                     + 
+--R                                    4 13 5                3 15 4
+--R                       257324744704a b  c  - 128344653824a b  c
+--R                     + 
+--R                                    2 17 3            19 2
+--R                       - 1907687424a b  c  - 770048a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                         10 2 10                   9 4 9
+--R                       - 344381215211520a  b c   - 403524525490176a b c
+--R                     + 
+--R                                       8 6 8                  7 8 7
+--R                       349654898180096a b c  - 10183770112000a b c
+--R                     + 
+--R                                        6 10 6                 5 12 5
+--R                       - 35411518816256a b  c  + 6511837315072a b  c
+--R                     + 
+--R                                    4 14 4               3 16 3
+--R                       128662372352a b  c  - 64172326912a b  c
+--R                     + 
+--R                                   2 18 2            20
+--R                       - 953843712a b  c  - 385024a b  c
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                         11   10                   10 3 9
+--R                       - 344381215211520a  b c   - 403524525490176a  b c
+--R                     + 
+--R                                       9 5 8                  8 7 7
+--R                       349654898180096a b c  - 10183770112000a b c
+--R                     + 
+--R                                        7 9 6                 6 11 5
+--R                       - 35411518816256a b c  + 6511837315072a b  c
+--R                     + 
+--R                                    5 13 4               4 15 3
+--R                       128662372352a b  c  - 64172326912a b  c
+--R                     + 
+--R                                   3 17 2          2 19
+--R                       - 953843712a b  c  - 385024a b  c
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                  +------------------------------------------------------+
+--R                  |                           1
+--R                  |------------------------------------------------------
+--R                  |        3 5           2 2 4            4 3         6 2
+--R                 \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                                   8   9                7 3 8
+--R                       77808533504a b c  + 608672153600a b c
+--R                     + 
+--R                                    6 5 7                5 7 6
+--R                       214386343936a b c  - 137933946880a b c
+--R                     + 
+--R                                    4 9 5              3 11 4             2 13 3
+--R                       - 7926890496a b c  + 4092334080a b  c  + 174351360a b  c
+--R                     + 
+--R                                15 2
+--R                       591104a b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                   8 2 8                7 4 7
+--R                       77808533504a b c  + 608672153600a b c
+--R                     + 
+--R                                    6 6 6                5 8 5
+--R                       214386343936a b c  - 137933946880a b c
+--R                     + 
+--R                                    4 10 4              3 12 3
+--R                       - 7926890496a b  c  + 4092334080a b  c
+--R                     + 
+--R                                 2 14 2            16
+--R                       174351360a b  c  + 591104a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                   9   8                8 3 7
+--R                       77808533504a b c  + 608672153600a b c
+--R                     + 
+--R                                    7 5 6                6 7 5
+--R                       214386343936a b c  - 137933946880a b c
+--R                     + 
+--R                                    5 9 4              4 11 3             3 13 2
+--R                       - 7926890496a b c  + 4092334080a b  c  + 174351360a b  c
+--R                     + 
+--R                              2 15
+--R                       591104a b  c
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                  +------------------------------------------------------+
+--R                  |                           1
+--R                  |------------------------------------------------------
+--R                  |        3 5           2 2 4            4 3         6 2
+--R                 \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R          *
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R         + 
+--R                                8 2 9                7 4 8                6 6 7
+--R                   672619560960a b c  + 956288729088a b c  - 443847540736a b c
+--R                 + 
+--R                                 5 8 6               4 10 5              3 12 4
+--R                   - 91071709184a b c  + 46395195392a b  c  - 1119633408a b  c
+--R                 + 
+--R                               2 14 3             16 2        18
+--R                   - 531202048a b  c  - 7463936a b  c  - 3008b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                9 2 8                8 4 7                7 6 6
+--R                   672619560960a b c  + 956288729088a b c  - 443847540736a b c
+--R                 + 
+--R                                 6 8 5               5 10 4              4 12 3
+--R                   - 91071709184a b c  + 46395195392a b  c  - 1119633408a b  c
+--R                 + 
+--R                               3 14 2           2 16           18
+--R                   - 531202048a b  c  - 7463936a b  c - 3008a b
+--R              *
+--R                  8
+--R                 x
+--R          *
+--R               ROOT
+--R                    a
+--R                 /
+--R                              4 5           3 2 4          2 4 3           6 2
+--R                      1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                    + 
+--R                           8
+--R                      4096b c
+--R              ,
+--R                  4
+--R            **
+--R               2
+--R         + 
+--R                          7 8             6 2 7             5 4 6
+--R               - 75984896a c  - 613402624a b c  - 362712320a b c
+--R             + 
+--R                        4 6 5            3 8 4          2 10 3          12 2
+--R               44023040a b c  + 18746864a b c  + 690296a b  c  + 2309a b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                           8 7              7 2 6              6 4 5
+--R               - 151969792a c  - 1302790144a b c  - 1338827264a b c
+--R             + 
+--R                           5 6 4            4 8 3            3 10 2
+--R               - 274666240a b c  + 81516768a b c  + 20127456a b  c
+--R             + 
+--R                      2 12           14
+--R               694914a b  c + 2309a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          9 6             8 2 5             7 4 4
+--R               - 75984896a c  - 613402624a b c  - 362712320a b c
+--R             + 
+--R                        6 6 3            5 8 2          4 10         3 12
+--R               44023040a b c  + 18746864a b c  + 690296a b  c + 2309a b
+--R          *
+--R              4
+--R             x
+--R      *
+--R            2
+--R         %DO
+--R     + 
+--R                                      8   9                7 3 8
+--R                       - 155617067008a b c  - 881034526720a b c
+--R                     + 
+--R                                    6 5 7                5 7 6
+--R                       133449121792a b c  + 194499575808a b c
+--R                     + 
+--R                                     4 9 5              3 11 4
+--R                       - 50024153088a b c  - 1456553984a b  c
+--R                     + 
+--R                                 2 13 3              15 2        17
+--R                       773509120a b  c  + 13769728a b  c  + 6016b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                      9   8                8 3 7
+--R                       - 155617067008a b c  - 881034526720a b c
+--R                     + 
+--R                                    7 5 6                6 7 5
+--R                       133449121792a b c  + 194499575808a b c
+--R                     + 
+--R                                     5 9 4              4 11 3
+--R                       - 50024153088a b c  - 1456553984a b  c
+--R                     + 
+--R                                 3 13 2            2 15           17
+--R                       773509120a b  c  + 13769728a b  c + 6016a b
+--R                  *
+--R                      8
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                             6   7             5 3 6           4 5 5
+--R                   290435072a b c  + 397059072a b c  - 3764736a b c
+--R                 + 
+--R                              3 7 4           2 9 3          11 2
+--R                   - 23681920a b c  - 1164688a b c  - 4524a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                             7   6              6 3 5             5 5 4
+--R                   580870144a b c  + 1084553216a b c  + 389529600a b c
+--R                 + 
+--R                            4 7 3            3 9 2           2 11           13
+--R                 - 51128576a b c  - 26011296a b c  - 1173736a b  c - 4524a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             8   5             7 3 4           6 5 3
+--R                   290435072a b c  + 397059072a b c  - 3764736a b c
+--R                 + 
+--R                              5 7 2           4 9         3 11
+--R                   - 23681920a b c  - 1164688a b c - 4524a b
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R         + 
+--R                                   10 13                    9 2 12
+--R                   318703753232384a  c   + 1645006834106368a b c
+--R                 + 
+--R                                      8 4 11                   7 6 10
+--R                   - 1155564172214272a b c   - 148910811119616a b c
+--R                 + 
+--R                                   6 8 9                  5 10 8
+--R                   284535543562240a b c  - 73137655906304a b  c
+--R                 + 
+--R                                 4 12 7                3 14 6
+--R                   3327433637888a b  c  + 950311845888a b  c
+--R                 + 
+--R                                 2 16 5                18 4          20 3
+--R                   - 84921286656a b  c  - 1756364800a b  c  - 770048b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                   10   12                    9 3 11
+--R                   318703753232384a  b c   + 1645006834106368a b c
+--R                 + 
+--R                                      8 5 10                   7 7 9
+--R                   - 1155564172214272a b c   - 148910811119616a b c
+--R                 + 
+--R                                   6 9 8                  5 11 7
+--R                   284535543562240a b c  - 73137655906304a b  c
+--R                 + 
+--R                                 4 13 6                3 15 5
+--R                   3327433637888a b  c  + 950311845888a b  c
+--R                 + 
+--R                                 2 17 4                19 3          21 2
+--R                   - 84921286656a b  c  - 1756364800a b  c  - 770048b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                   11 12                    10 2 11
+--R                   637407506464768a  c   + 3290013668212736a  b c
+--R                 + 
+--R                                      9 4 10                   8 6 9
+--R                   - 2311128344428544a b c   - 297821622239232a b c
+--R                 + 
+--R                                   7 8 8                   6 10 7
+--R                   569071087124480a b c  - 146275311812608a b  c
+--R                 + 
+--R                                 5 12 6                 4 14 5
+--R                   6654867275776a b  c  + 1900623691776a b  c
+--R                 + 
+--R                                  3 16 4              2 18 3             20 2
+--R                   - 169842573312a b  c  - 3512729600a b  c  - 1540096a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                   11   11                    10 3 10
+--R                   318703753232384a  b c   + 1645006834106368a  b c
+--R                 + 
+--R                                      9 5 9                   8 7 8
+--R                   - 1155564172214272a b c  - 148910811119616a b c
+--R                 + 
+--R                                   7 9 7                  6 11 6
+--R                   284535543562240a b c  - 73137655906304a b  c
+--R                 + 
+--R                                 5 13 5                4 15 4
+--R                   3327433637888a b  c  + 950311845888a b  c
+--R                 + 
+--R                                 3 17 3              2 19 2            21
+--R                   - 84921286656a b  c  - 1756364800a b  c  - 770048a b  c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                   12 11                    11 2 10
+--R                   318703753232384a  c   + 1645006834106368a  b c
+--R                 + 
+--R                                      10 4 9                   9 6 8
+--R                   - 1155564172214272a  b c  - 148910811119616a b c
+--R                 + 
+--R                                   8 8 7                  7 10 6
+--R                   284535543562240a b c  - 73137655906304a b  c
+--R                 + 
+--R                                 6 12 5                5 14 4
+--R                   3327433637888a b  c  + 950311845888a b  c
+--R                 + 
+--R                                 4 16 3              3 18 2          2 20
+--R                   - 84921286656a b  c  - 1756364800a b  c  - 770048a b  c
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R              +------------------------------------------------------+
+--R              |                           1
+--R              |------------------------------------------------------
+--R              |        3 5           2 2 4            4 3         6 2
+--R             \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R          *
+--R               ROOT
+--R                    a
+--R                 /
+--R                              4 5           3 2 4          2 4 3           6 2
+--R                      1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                    + 
+--R                           8
+--R                      4096b c
+--R              ,
+--R                  4
+--R            **
+--R               2
+--R         + 
+--R                                   8 2 9                 7 4 8
+--R                   - 1189622054912a b c  - 1031542931456a b c
+--R                 + 
+--R                                6 6 7               5 8 6               4 10 5
+--R                   754245959680a b c  - 12356157440a b c  - 42766237696a b  c
+--R                 + 
+--R                              3 12 4             2 14 3             16 2
+--R                   3695820800a b  c  + 288894976a b  c  + 1158144a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                   8 3 8                 7 5 7
+--R                   - 1189622054912a b c  - 1031542931456a b c
+--R                 + 
+--R                                6 7 6               5 9 5               4 11 4
+--R                   754245959680a b c  - 12356157440a b c  - 42766237696a b  c
+--R                 + 
+--R                              3 13 3             2 15 2             17
+--R                   3695820800a b  c  + 288894976a b  c  + 1158144a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                   9 2 8                 8 4 7
+--R                   - 1189622054912a b c  - 1031542931456a b c
+--R                 + 
+--R                                7 6 6               6 8 5               5 10 4
+--R                   754245959680a b c  - 12356157440a b c  - 42766237696a b  c
+--R                 + 
+--R                              4 12 3             3 14 2           2 16
+--R                   3695820800a b  c  + 288894976a b  c  + 1158144a b  c
+--R              *
+--R                  8
+--R                 x
+--R          *
+--R              +------------------------------------------------------+
+--R              |                           1
+--R              |------------------------------------------------------
+--R              |        3 5           2 2 4            4 3         6 2
+--R             \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R      *
+--R         %DO
+--R     + 
+--R                                   9   12                   8 3 11
+--R                   344381215211520a b c   + 403524525490176a b c
+--R                 + 
+--R                                     7 5 10                  6 7 9
+--R                   - 349654898180096a b c   + 10183770112000a b c
+--R                 + 
+--R                                  5 9 8                 4 11 7
+--R                   35411518816256a b c  - 6511837315072a b  c
+--R                 + 
+--R                                  3 13 6               2 15 5               17 4
+--R                   - 128662372352a b  c  + 64172326912a b  c  + 953843712a b  c
+--R                 + 
+--R                          19 3
+--R                   385024b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                   9 2 11                   8 4 10
+--R                   344381215211520a b c   + 403524525490176a b c
+--R                 + 
+--R                                     7 6 9                  6 8 8
+--R                   - 349654898180096a b c  + 10183770112000a b c
+--R                 + 
+--R                                  5 10 7                 4 12 6
+--R                   35411518816256a b  c  - 6511837315072a b  c
+--R                 + 
+--R                                  3 14 5               2 16 4               18 3
+--R                   - 128662372352a b  c  + 64172326912a b  c  + 953843712a b  c
+--R                 + 
+--R                          20 2
+--R                   385024b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                   10   11                   9 3 10
+--R                   688762430423040a  b c   + 807049050980352a b c
+--R                 + 
+--R                                     8 5 9                  7 7 8
+--R                   - 699309796360192a b c  + 20367540224000a b c
+--R                 + 
+--R                                  6 9 7                  5 11 6
+--R                   70823037632512a b c  - 13023674630144a b  c
+--R                 + 
+--R                                  4 13 5                3 15 4
+--R                   - 257324744704a b  c  + 128344653824a b  c
+--R                 + 
+--R                              2 17 3            19 2
+--R                   1907687424a b  c  + 770048a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                   10 2 10                   9 4 9
+--R                   344381215211520a  b c   + 403524525490176a b c
+--R                 + 
+--R                                     8 6 8                  7 8 7
+--R                   - 349654898180096a b c  + 10183770112000a b c
+--R                 + 
+--R                                  6 10 6                 5 12 5
+--R                   35411518816256a b  c  - 6511837315072a b  c
+--R                 + 
+--R                                  4 14 4               3 16 3             2 18 2
+--R                   - 128662372352a b  c  + 64172326912a b  c  + 953843712a b  c
+--R                 + 
+--R                            20
+--R                   385024a b  c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                   11   10                   10 3 9
+--R                   344381215211520a  b c   + 403524525490176a  b c
+--R                 + 
+--R                                     9 5 8                  8 7 7
+--R                   - 349654898180096a b c  + 10183770112000a b c
+--R                 + 
+--R                                  7 9 6                 6 11 5
+--R                   35411518816256a b c  - 6511837315072a b  c
+--R                 + 
+--R                                  5 13 4               4 15 3             3 17 2
+--R                   - 128662372352a b  c  + 64172326912a b  c  + 953843712a b  c
+--R                 + 
+--R                          2 19
+--R                   385024a b  c
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R              +------------------------------------------------------+
+--R              |                           1
+--R              |------------------------------------------------------
+--R              |        3 5           2 2 4            4 3         6 2
+--R             \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R          *
+--R               ROOT
+--R                    a
+--R                 /
+--R                              4 5           3 2 4          2 4 3           6 2
+--R                      1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                    + 
+--R                           8
+--R                      4096b c
+--R              ,
+--R                  4
+--R            **
+--R               2
+--R         + 
+--R                                 8   9                7 3 8                6 5 7
+--R                   - 77808533504a b c  - 608672153600a b c  - 214386343936a b c
+--R                 + 
+--R                                5 7 6              4 9 5              3 11 4
+--R                   137933946880a b c  + 7926890496a b c  - 4092334080a b  c
+--R                 + 
+--R                               2 13 3            15 2
+--R                   - 174351360a b  c  - 591104a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                 8 2 8                7 4 7                6 6 6
+--R                   - 77808533504a b c  - 608672153600a b c  - 214386343936a b c
+--R                 + 
+--R                                5 8 5              4 10 4              3 12 3
+--R                   137933946880a b c  + 7926890496a b  c  - 4092334080a b  c
+--R                 + 
+--R                               2 14 2            16
+--R                   - 174351360a b  c  - 591104a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                 9   8                8 3 7                7 5 6
+--R                   - 77808533504a b c  - 608672153600a b c  - 214386343936a b c
+--R                 + 
+--R                                6 7 5              5 9 4              4 11 3
+--R                   137933946880a b c  + 7926890496a b c  - 4092334080a b  c
+--R                 + 
+--R                               3 13 2          2 15
+--R                   - 174351360a b  c  - 591104a b  c
+--R              *
+--R                  8
+--R                 x
+--R          *
+--R              +------------------------------------------------------+
+--R              |                           1
+--R              |------------------------------------------------------
+--R              |        3 5           2 2 4            4 3         6 2
+--R             \|4194304a c  - 3145728a b c  + 786432a b c  - 65536b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     + 
+--R                              8 2 9                7 4 8                6 6 7
+--R               - 672619560960a b c  - 956288729088a b c  + 443847540736a b c
+--R             + 
+--R                           5 8 6               4 10 5              3 12 4
+--R               91071709184a b c  - 46395195392a b  c  + 1119633408a b  c
+--R             + 
+--R                         2 14 3             16 2        18
+--R               531202048a b  c  + 7463936a b  c  + 3008b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                              9 2 8                8 4 7                7 6 6
+--R               - 672619560960a b c  - 956288729088a b c  + 443847540736a b c
+--R             + 
+--R                           6 8 5               5 10 4              4 12 3
+--R               91071709184a b c  - 46395195392a b  c  + 1119633408a b  c
+--R             + 
+--R                         3 14 2           2 16           18
+--R               531202048a b  c  + 7463936a b  c + 3008a b
+--R          *
+--R              8
+--R             x
+--R      *
+--R          +------------------------------------------------------------------+2
+--R          |                                 a
+--R          |------------------------------------------------------------------
+--R         4|        4 5           3 2 4          2 4 3           6 2        8
+--R         \|1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c  + 4096b c
+--R     + 
+--R                    7 8             6 2 7             5 4 6            4 6 5
+--R           75984896a c  + 613402624a b c  + 362712320a b c  - 44023040a b c
+--R         + 
+--R                      3 8 4          2 10 3          12 2
+--R           - 18746864a b c  - 690296a b  c  - 2309a b  c
+--R      *
+--R          20
+--R         x
+--R     + 
+--R                     8 7              7 2 6              6 4 5             5 6 4
+--R           151969792a c  + 1302790144a b c  + 1338827264a b c  + 274666240a b c
+--R         + 
+--R                      4 8 3            3 10 2          2 12           14
+--R           - 81516768a b c  - 20127456a b  c  - 694914a b  c - 2309a b
+--R      *
+--R          12
+--R         x
+--R     + 
+--R                    9 6             8 2 5             7 4 4            6 6 3
+--R           75984896a c  + 613402624a b c  + 362712320a b c  - 44023040a b c
+--R         + 
+--R                      5 8 2          4 10         3 12
+--R           - 18746864a b c  - 690296a b  c - 2309a b
+--R      *
+--R          4
+--R         x
+--R  /
+--R                                    8   10                 7 3 9
+--R                       391169179648a b c   + 3603519504384a b c
+--R                     + 
+--R                                     6 5 8                5 7 7
+--R                       1941153251328a b c  - 840009515008a b c
+--R                     + 
+--R                                      4 9 6               3 11 5
+--R                       - 135450918912a b c  + 31559483392a b  c
+--R                     + 
+--R                                  2 13 4              15 3        17 2
+--R                       2421948416a b  c  + 20436992a b  c  + 4480b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                    8 2 9                 7 4 8
+--R                       391169179648a b c  + 3603519504384a b c
+--R                     + 
+--R                                     6 6 7                5 8 6
+--R                       1941153251328a b c  - 840009515008a b c
+--R                     + 
+--R                                      4 10 5               3 12 4
+--R                       - 135450918912a b  c  + 31559483392a b  c
+--R                     + 
+--R                                  2 14 3              16 2        18
+--R                       2421948416a b  c  + 20436992a b  c  + 4480b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                    9   9                 8 3 8
+--R                       782338359296a b c  + 7207039008768a b c
+--R                     + 
+--R                                     7 5 7                 6 7 6
+--R                       3882306502656a b c  - 1680019030016a b c
+--R                     + 
+--R                                      5 9 5               4 11 4
+--R                       - 270901837824a b c  + 63118966784a b  c
+--R                     + 
+--R                                  3 13 3            2 15 2          17
+--R                       4843896832a b  c  + 40873984a b  c  + 8960a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                    9 2 8                 8 4 7
+--R                       391169179648a b c  + 3603519504384a b c
+--R                     + 
+--R                                     7 6 6                6 8 5
+--R                       1941153251328a b c  - 840009515008a b c
+--R                     + 
+--R                                      5 10 4               4 12 3
+--R                       - 135450918912a b  c  + 31559483392a b  c
+--R                     + 
+--R                                  3 14 2            2 16           18
+--R                       2421948416a b  c  + 20436992a b  c + 4480a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                    10   8                 9 3 7
+--R                       391169179648a  b c  + 3603519504384a b c
+--R                     + 
+--R                                     8 5 6                7 7 5
+--R                       1941153251328a b c  - 840009515008a b c
+--R                     + 
+--R                                      6 9 4               5 11 3
+--R                       - 135450918912a b c  + 31559483392a b  c
+--R                     + 
+--R                                  4 13 2            3 15         2 17
+--R                       2421948416a b  c  + 20436992a b  c + 4480a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                               6   8              5 3 7              4 5 6
+--R                   - 887947264a b c  - 2294714368a b c  - 1040019456a b c
+--R                 + 
+--R                               3 7 5           2 9 4          11 3
+--R                   - 109997568a b c  - 2374144a b c  - 4880a b  c
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                               6 2 7              5 4 6              4 6 5
+--R                   - 887947264a b c  - 2294714368a b c  - 1040019456a b c
+--R                 + 
+--R                               3 8 4           2 10 3          12 2
+--R                   - 109997568a b c  - 2374144a b  c  - 4880a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                7   7              6 3 6              5 5 5
+--R                   - 2663841792a b c  - 7772090368a b c  - 5414772736a b c
+--R                 + 
+--R                                4 7 4             3 9 3           2 11 2
+--R                   - 1370012160a b c  - 117120000a b c  - 2388784a b  c
+--R                 + 
+--R                            13
+--R                   - 4880a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                7 2 6              6 4 5              5 6 4
+--R                   - 1775894528a b c  - 5477376000a b c  - 4374753280a b c
+--R                 + 
+--R                                4 8 3             3 10 2           2 12
+--R                   - 1260014592a b c  - 114745856a b  c  - 2383904a b  c
+--R                 + 
+--R                            14
+--R                   - 4880a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                8   6              7 3 5              6 5 4
+--R                   - 2663841792a b c  - 7772090368a b c  - 5414772736a b c
+--R                 + 
+--R                                5 7 3             4 9 2           3 11
+--R                   - 1370012160a b c  - 117120000a b c  - 2388784a b  c
+--R                 + 
+--R                          2 13
+--R                   - 4880a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               8 2 5              7 4 4              6 6 3
+--R                   - 887947264a b c  - 2294714368a b c  - 1040019456a b c
+--R                 + 
+--R                               5 8 2           4 10         3 12
+--R                   - 109997568a b c  - 2374144a b  c - 4880a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           9   5              8 3 4              7 5 3
+--R               - 887947264a b c  - 2294714368a b c  - 1040019456a b c
+--R             + 
+--R                           6 7 2           5 9         4 11
+--R               - 109997568a b c  - 2374144a b c - 4880a b
+--R          *
+--R              +---------+
+--R              |        2    2
+--R             \|4a c - b  %DO
+--R         + 
+--R                                       8 2 10                 7 4 9
+--R                       - 6491725627392a b c   - 7954229100544a b c
+--R                     + 
+--R                                     6 6 8                5 8 7
+--R                       4306988171264a b c  + 503906828288a b c
+--R                     + 
+--R                                      4 10 6               3 12 5
+--R                       - 372290748416a b  c  + 16484728832a b  c
+--R                     + 
+--R                                  2 14 4              16 3        18 2
+--R                       3648323584a b  c  + 38375424a b  c  + 8960b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                       8 3 9                 7 5 8
+--R                       - 6491725627392a b c  - 7954229100544a b c
+--R                     + 
+--R                                     6 7 7                5 9 6
+--R                       4306988171264a b c  + 503906828288a b c
+--R                     + 
+--R                                      4 11 5               3 13 4
+--R                       - 372290748416a b  c  + 16484728832a b  c
+--R                     + 
+--R                                  2 15 3              17 2        19
+--R                       3648323584a b  c  + 38375424a b  c  + 8960b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                        9 2 9                  8 4 8
+--R                       - 12983451254784a b c  - 15908458201088a b c
+--R                     + 
+--R                                     7 6 7                 6 8 6
+--R                       8613976342528a b c  + 1007813656576a b c
+--R                     + 
+--R                                      5 10 5               4 12 4
+--R                       - 744581496832a b  c  + 32969457664a b  c
+--R                     + 
+--R                                  3 14 3            2 16 2           18
+--R                       7296647168a b  c  + 76750848a b  c  + 17920a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                       9 3 8                 8 5 7
+--R                       - 6491725627392a b c  - 7954229100544a b c
+--R                     + 
+--R                                     7 7 6                6 9 5
+--R                       4306988171264a b c  + 503906828288a b c
+--R                     + 
+--R                                      5 11 4               4 13 3
+--R                       - 372290748416a b  c  + 16484728832a b  c
+--R                     + 
+--R                                  3 15 2            2 17           19
+--R                       3648323584a b  c  + 38375424a b  c + 8960a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                       10 2 8                 9 4 7
+--R                       - 6491725627392a  b c  - 7954229100544a b c
+--R                     + 
+--R                                     8 6 6                7 8 5
+--R                       4306988171264a b c  + 503906828288a b c
+--R                     + 
+--R                                      6 10 4               5 12 3
+--R                       - 372290748416a b  c  + 16484728832a b  c
+--R                     + 
+--R                                  4 14 2            3 16         2 18
+--R                       3648323584a b  c  + 38375424a b  c + 8960a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                             7 9              6 2 8              5 4 7
+--R                   764002304a c  + 5644230656a b c  + 2864198656a b c
+--R                 + 
+--R                               4 6 6             3 8 5           2 10 4
+--R                   - 457626624a b c  - 139193280a b c  - 4108512a b  c
+--R                 + 
+--R                            12 3
+--R                   - 9620a b  c
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                             7   8              6 3 7              5 5 6
+--R                   764002304a b c  + 5644230656a b c  + 2864198656a b c
+--R                 + 
+--R                               4 7 5             3 9 4           2 11 3
+--R                   - 457626624a b c  - 139193280a b c  - 4108512a b  c
+--R                 + 
+--R                            13 2
+--R                   - 9620a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                              8 8               7 2 7               6 4 6
+--R                   2292006912a c  + 17696694272a b c  + 14236826624a b c
+--R                 + 
+--R                              5 6 5             4 8 4             3 10 3
+--R                   1491318784a b c  - 875206464a b c  - 151518816a b  c
+--R                 + 
+--R                             2 12 2          14
+--R                   - 4137372a b  c  - 9620a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                              8   7               7 3 6               6 5 5
+--R                   1528004608a b c  + 12052463616a b c  + 11372627968a b c
+--R                 + 
+--R                              5 7 4             4 9 3             3 11 2
+--R                   1948945408a b c  - 736013184a b c  - 147410304a b  c
+--R                 + 
+--R                             2 13           15
+--R                   - 4127752a b  c - 9620a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                              9 7               8 2 6               7 4 5
+--R                   2292006912a c  + 17696694272a b c  + 14236826624a b c
+--R                 + 
+--R                              6 6 4             5 8 3             4 10 2
+--R                   1491318784a b c  - 875206464a b c  - 151518816a b  c
+--R                 + 
+--R                             3 12         2 14
+--R                   - 4137372a b  c - 9620a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             9   6              8 3 5              7 5 4
+--R                   764002304a b c  + 5644230656a b c  + 2864198656a b c
+--R                 + 
+--R                             6 7 3             5 9 2           4 11         3 13
+--R                 - 457626624a b c  - 139193280a b c  - 4108512a b  c - 9620a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         10 6              9 2 5              8 4 4
+--R               764002304a  c  + 5644230656a b c  + 2864198656a b c
+--R             + 
+--R                           7 6 3             6 8 2           5 10         4 12
+--R               - 457626624a b c  - 139193280a b c  - 4108512a b  c - 9620a b
+--R          *
+--R             %DO
+--R         + 
+--R                                      8   10                 7 3 9
+--R                       - 391169179648a b c   - 3603519504384a b c
+--R                     + 
+--R                                       6 5 8                5 7 7
+--R                       - 1941153251328a b c  + 840009515008a b c
+--R                     + 
+--R                                    4 9 6               3 11 5
+--R                       135450918912a b c  - 31559483392a b  c
+--R                     + 
+--R                                    2 13 4              15 3        17 2
+--R                       - 2421948416a b  c  - 20436992a b  c  - 4480b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                      8 2 9                 7 4 8
+--R                       - 391169179648a b c  - 3603519504384a b c
+--R                     + 
+--R                                       6 6 7                5 8 6
+--R                       - 1941153251328a b c  + 840009515008a b c
+--R                     + 
+--R                                    4 10 5               3 12 4
+--R                       135450918912a b  c  - 31559483392a b  c
+--R                     + 
+--R                                    2 14 3              16 2        18
+--R                       - 2421948416a b  c  - 20436992a b  c  - 4480b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                      9   9                 8 3 8
+--R                       - 782338359296a b c  - 7207039008768a b c
+--R                     + 
+--R                                       7 5 7                 6 7 6
+--R                       - 3882306502656a b c  + 1680019030016a b c
+--R                     + 
+--R                                    5 9 5               4 11 4
+--R                       270901837824a b c  - 63118966784a b  c
+--R                     + 
+--R                                    3 13 3            2 15 2          17
+--R                       - 4843896832a b  c  - 40873984a b  c  - 8960a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                      9 2 8                 8 4 7
+--R                       - 391169179648a b c  - 3603519504384a b c
+--R                     + 
+--R                                       7 6 6                6 8 5
+--R                       - 1941153251328a b c  + 840009515008a b c
+--R                     + 
+--R                                    5 10 4               4 12 3
+--R                       135450918912a b  c  - 31559483392a b  c
+--R                     + 
+--R                                    3 14 2            2 16           18
+--R                       - 2421948416a b  c  - 20436992a b  c - 4480a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                      10   8                 9 3 7
+--R                       - 391169179648a  b c  - 3603519504384a b c
+--R                     + 
+--R                                       8 5 6                7 7 5
+--R                       - 1941153251328a b c  + 840009515008a b c
+--R                     + 
+--R                                    6 9 4               5 11 3
+--R                       135450918912a b c  - 31559483392a b  c
+--R                     + 
+--R                                    4 13 2            3 15         2 17
+--R                       - 2421948416a b  c  - 20436992a b  c - 4480a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                             6   8              5 3 7              4 5 6
+--R                   887947264a b c  + 2294714368a b c  + 1040019456a b c
+--R                 + 
+--R                             3 7 5           2 9 4          11 3
+--R                   109997568a b c  + 2374144a b c  + 4880a b  c
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                             6 2 7              5 4 6              4 6 5
+--R                   887947264a b c  + 2294714368a b c  + 1040019456a b c
+--R                 + 
+--R                             3 8 4           2 10 3          12 2
+--R                   109997568a b c  + 2374144a b  c  + 4880a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                              7   7              6 3 6              5 5 5
+--R                   2663841792a b c  + 7772090368a b c  + 5414772736a b c
+--R                 + 
+--R                              4 7 4             3 9 3           2 11 2
+--R                   1370012160a b c  + 117120000a b c  + 2388784a b  c
+--R                 + 
+--R                          13
+--R                   4880a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                              7 2 6              6 4 5              5 6 4
+--R                   1775894528a b c  + 5477376000a b c  + 4374753280a b c
+--R                 + 
+--R                            4 8 3             3 10 2           2 12           14
+--R                 1260014592a b c  + 114745856a b  c  + 2383904a b  c + 4880a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                              8   6              7 3 5              6 5 4
+--R                   2663841792a b c  + 7772090368a b c  + 5414772736a b c
+--R                 + 
+--R                            5 7 3             4 9 2           3 11         2 13
+--R                 1370012160a b c  + 117120000a b c  + 2388784a b  c + 4880a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             8 2 5              7 4 4              6 6 3
+--R                   887947264a b c  + 2294714368a b c  + 1040019456a b c
+--R                 + 
+--R                             5 8 2           4 10         3 12
+--R                   109997568a b c  + 2374144a b  c + 4880a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         9   5              8 3 4              7 5 3
+--R               887947264a b c  + 2294714368a b c  + 1040019456a b c
+--R             + 
+--R                         6 7 2           5 9         4 11
+--R               109997568a b c  + 2374144a b c + 4880a b
+--R          *
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R      *
+--R            3
+--R         %DP
+--R     + 
+--R                                     8 2 10                 7 4 9
+--R                       3456492371968a b c   + 4821218230272a b c
+--R                     + 
+--R                                       6 6 8                5 8 7
+--R                       - 2290870124544a b c  - 437005582336a b c
+--R                     + 
+--R                                    4 10 6              3 12 5
+--R                       233195831296a b  c  - 6448939008a b  c
+--R                     + 
+--R                                    2 14 4              16 3         18 2
+--R                       - 2599944192a b  c  - 34385920a b  c  - 11520b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                     8 3 9                 7 5 8
+--R                       3456492371968a b c  + 4821218230272a b c
+--R                     + 
+--R                                       6 7 7                5 9 6
+--R                       - 2290870124544a b c  - 437005582336a b c
+--R                     + 
+--R                                    4 11 5              3 13 4
+--R                       233195831296a b  c  - 6448939008a b  c
+--R                     + 
+--R                                    2 15 3              17 2         19
+--R                       - 2599944192a b  c  - 34385920a b  c  - 11520b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                     9 2 9                 8 4 8
+--R                       6912984743936a b c  + 9642436460544a b c
+--R                     + 
+--R                                       7 6 7                6 8 6
+--R                       - 4581740249088a b c  - 874011164672a b c
+--R                     + 
+--R                                    5 10 5               4 12 4
+--R                       466391662592a b  c  - 12897878016a b  c
+--R                     + 
+--R                                    3 14 3            2 16 2           18
+--R                       - 5199888384a b  c  - 68771840a b  c  - 23040a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                     9 3 8                 8 5 7
+--R                       3456492371968a b c  + 4821218230272a b c
+--R                     + 
+--R                                       7 7 6                6 9 5
+--R                       - 2290870124544a b c  - 437005582336a b c
+--R                     + 
+--R                                    5 11 4              4 13 3
+--R                       233195831296a b  c  - 6448939008a b  c
+--R                     + 
+--R                                    3 15 2            2 17            19
+--R                       - 2599944192a b  c  - 34385920a b  c - 11520a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                     10 2 8                 9 4 7
+--R                       3456492371968a  b c  + 4821218230272a b c
+--R                     + 
+--R                                       8 6 6                7 8 5
+--R                       - 2290870124544a b c  - 437005582336a b c
+--R                     + 
+--R                                    6 10 4              5 12 3
+--R                       233195831296a b  c  - 6448939008a b  c
+--R                     + 
+--R                                    4 14 2            3 16          2 18
+--R                       - 2599944192a b  c  - 34385920a b  c - 11520a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                               7 9              6 2 8              5 4 7
+--R                   - 392445952a c  - 3133005824a b c  - 1814572032a b c
+--R                 + 
+--R                             4 6 6            3 8 5           2 10 4
+--R                   230894592a b c  + 92879424a b c  + 3283232a b  c
+--R                 + 
+--R                           12 3
+--R                   10060a b  c
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                               7   8              6 3 7              5 5 6
+--R                   - 392445952a b c  - 3133005824a b c  - 1814572032a b c
+--R                 + 
+--R                             4 7 5            3 9 4           2 11 3
+--R                   230894592a b c  + 92879424a b c  + 3283232a b  c
+--R                 + 
+--R                           13 2
+--R                   10060a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                8 8              7 2 7              6 4 6
+--R                   - 1177337856a c  - 9791463424a b c  - 8576721920a b c
+--R                 + 
+--R                                5 6 5             4 8 4             3 10 3
+--R                   - 1121888256a b c  + 509532864a b c  + 102729120a b  c
+--R                 + 
+--R                           2 12 2           14
+--R                   3313412a b  c  + 10060a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                               8   7              7 3 6              6 5 5
+--R                   - 784891904a b c  - 6658457600a b c  - 6762149888a b c
+--R                 + 
+--R                                5 7 4             4 9 3            3 11 2
+--R                   - 1352782848a b c  + 416653440a b c  + 99445888a b  c
+--R                 + 
+--R                           2 13            15
+--R                   3303352a b  c + 10060a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                9 7              8 2 6              7 4 5
+--R                   - 1177337856a c  - 9791463424a b c  - 8576721920a b c
+--R                 + 
+--R                                6 6 4             5 8 3             4 10 2
+--R                   - 1121888256a b c  + 509532864a b c  + 102729120a b  c
+--R                 + 
+--R                           3 12          2 14
+--R                   3313412a b  c + 10060a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               9   6              8 3 5              7 5 4
+--R                   - 392445952a b c  - 3133005824a b c  - 1814572032a b c
+--R                 + 
+--R                           6 7 3            5 9 2           4 11          3 13
+--R                 230894592a b c  + 92879424a b c  + 3283232a b  c + 10060a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           10 6              9 2 5              8 4 4
+--R               - 392445952a  c  - 3133005824a b c  - 1814572032a b c
+--R             + 
+--R                         7 6 3            6 8 2           5 10          4 12
+--R               230894592a b c  + 92879424a b c  + 3283232a b  c + 10060a b
+--R          *
+--R                2
+--R             %DO
+--R         + 
+--R                                      8   10                 7 3 9
+--R                       - 803729309696a b c   - 4487217414144a b c
+--R                     + 
+--R                                    6 5 8                5 7 7
+--R                       730526121984a b c  + 967165607936a b c
+--R                     + 
+--R                                      4 9 6              3 11 5
+--R                       - 255195611136a b c  - 6030950400a b  c
+--R                     + 
+--R                                  2 13 4              15 3         17 2
+--R                       3814932480a b  c  + 63713280a b  c  + 23040b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                      8 2 9                 7 4 8
+--R                       - 803729309696a b c  - 4487217414144a b c
+--R                     + 
+--R                                    6 6 7                5 8 6
+--R                       730526121984a b c  + 967165607936a b c
+--R                     + 
+--R                                      4 10 5              3 12 4
+--R                       - 255195611136a b  c  - 6030950400a b  c
+--R                     + 
+--R                                  2 14 3              16 2         18
+--R                       3814932480a b  c  + 63713280a b  c  + 23040b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                       9   9                 8 3 8
+--R                       - 1607458619392a b c  - 8974434828288a b c
+--R                     + 
+--R                                     7 5 7                 6 7 6
+--R                       1461052243968a b c  + 1934331215872a b c
+--R                     + 
+--R                                      5 9 5               4 11 4
+--R                       - 510391222272a b c  - 12061900800a b  c
+--R                     + 
+--R                                  3 13 3             2 15 2           17
+--R                       7629864960a b  c  + 127426560a b  c  + 46080a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                      9 2 8                 8 4 7
+--R                       - 803729309696a b c  - 4487217414144a b c
+--R                     + 
+--R                                    7 6 6                6 8 5
+--R                       730526121984a b c  + 967165607936a b c
+--R                     + 
+--R                                      5 10 4              4 12 3
+--R                       - 255195611136a b  c  - 6030950400a b  c
+--R                     + 
+--R                                  3 14 2            2 16            18
+--R                       3814932480a b  c  + 63713280a b  c + 23040a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                      10   8                 9 3 7
+--R                       - 803729309696a  b c  - 4487217414144a b c
+--R                     + 
+--R                                    8 5 6                7 7 5
+--R                       730526121984a b c  + 967165607936a b c
+--R                     + 
+--R                                      6 9 4              5 11 3
+--R                       - 255195611136a b c  - 6030950400a b  c
+--R                     + 
+--R                                  4 13 2            3 15          2 17
+--R                       3814932480a b  c  + 63713280a b  c + 23040a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                              6   8              5 3 7            4 5 6
+--R                   1491517440a b c  + 2004357120a b c  - 31279104a b c
+--R                 + 
+--R                               3 7 5           2 9 4           11 3
+--R                   - 118169088a b c  - 5568064a b c  - 19760a b  c
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                              6 2 7              5 4 6            4 6 5
+--R                   1491517440a b c  + 2004357120a b c  - 31279104a b c
+--R                 + 
+--R                               3 8 4           2 10 3           12 2
+--R                   - 118169088a b c  - 5568064a b  c  - 19760a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                              7   7              6 3 6              5 5 5
+--R                   4474552320a b c  + 7504588800a b c  + 1910519808a b c
+--R                 + 
+--R                               4 7 4             3 9 3           2 11 2
+--R                   - 385786368a b c  - 134873280a b c  - 5627344a b  c
+--R                 + 
+--R                             13
+--R                   - 19760a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                              7 2 6              6 4 5              5 6 4
+--R                   2983034880a b c  + 5500231680a b c  + 1941798912a b c
+--R                 + 
+--R                               4 8 3             3 10 2           2 12
+--R                   - 267617280a b c  - 129305216a b  c  - 5607584a b  c
+--R                 + 
+--R                             14
+--R                   - 19760a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                              8   6              7 3 5              6 5 4
+--R                   4474552320a b c  + 7504588800a b c  + 1910519808a b c
+--R                 + 
+--R                               5 7 3             4 9 2           3 11
+--R                   - 385786368a b c  - 134873280a b c  - 5627344a b  c
+--R                 + 
+--R                           2 13
+--R                   - 19760a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              8 2 5              7 4 4            6 6 3
+--R                   1491517440a b c  + 2004357120a b c  - 31279104a b c
+--R                 + 
+--R                               5 8 2           4 10          3 12
+--R                   - 118169088a b c  - 5568064a b  c - 19760a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          9   5              8 3 4            7 5 3
+--R               1491517440a b c  + 2004357120a b c  - 31279104a b c
+--R             + 
+--R                           6 7 2           5 9          4 11
+--R               - 118169088a b c  - 5568064a b c - 19760a b
+--R          *
+--R              +---------+
+--R              |        2
+--R             \|4a c - b  %DO
+--R         + 
+--R                                   8 2 10                 7 4 9
+--R                   - 3456492371968a b c   - 4821218230272a b c
+--R                 + 
+--R                                 6 6 8                5 8 7
+--R                   2290870124544a b c  + 437005582336a b c
+--R                 + 
+--R                                  4 10 6              3 12 5              2 14 4
+--R                   - 233195831296a b  c  + 6448939008a b  c  + 2599944192a b  c
+--R                 + 
+--R                              16 3         18 2
+--R                   34385920a b  c  + 11520b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                   8 3 9                 7 5 8
+--R                   - 3456492371968a b c  - 4821218230272a b c
+--R                 + 
+--R                                 6 7 7                5 9 6
+--R                   2290870124544a b c  + 437005582336a b c
+--R                 + 
+--R                                  4 11 5              3 13 4              2 15 3
+--R                   - 233195831296a b  c  + 6448939008a b  c  + 2599944192a b  c
+--R                 + 
+--R                              17 2         19
+--R                   34385920a b  c  + 11520b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                   9 2 9                 8 4 8
+--R                   - 6912984743936a b c  - 9642436460544a b c
+--R                 + 
+--R                                 7 6 7                6 8 6
+--R                   4581740249088a b c  + 874011164672a b c
+--R                 + 
+--R                                  5 10 5               4 12 4
+--R                   - 466391662592a b  c  + 12897878016a b  c
+--R                 + 
+--R                              3 14 3            2 16 2           18
+--R                   5199888384a b  c  + 68771840a b  c  + 23040a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                   9 3 8                 8 5 7
+--R                   - 3456492371968a b c  - 4821218230272a b c
+--R                 + 
+--R                                 7 7 6                6 9 5
+--R                   2290870124544a b c  + 437005582336a b c
+--R                 + 
+--R                                  5 11 4              4 13 3              3 15 2
+--R                   - 233195831296a b  c  + 6448939008a b  c  + 2599944192a b  c
+--R                 + 
+--R                            2 17            19
+--R                   34385920a b  c + 11520a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                   10 2 8                 9 4 7
+--R                   - 3456492371968a  b c  - 4821218230272a b c
+--R                 + 
+--R                                 8 6 6                7 8 5
+--R                   2290870124544a b c  + 437005582336a b c
+--R                 + 
+--R                                  6 10 4              5 12 3              4 14 2
+--R                   - 233195831296a b  c  + 6448939008a b  c  + 2599944192a b  c
+--R                 + 
+--R                            3 16          2 18
+--R                   34385920a b  c + 11520a b
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R               ROOT
+--R                    a
+--R                 /
+--R                              4 5           3 2 4          2 4 3           6 2
+--R                      1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                    + 
+--R                           8
+--R                      4096b c
+--R              ,
+--R                  4
+--R            **
+--R               2
+--R         + 
+--R                         7 9              6 2 8              5 4 7
+--R               392445952a c  + 3133005824a b c  + 1814572032a b c
+--R             + 
+--R                         4 6 6            3 8 5           2 10 4           12 3
+--R             - 230894592a b c  - 92879424a b c  - 3283232a b  c  - 10060a b  c
+--R          *
+--R              24
+--R             x
+--R         + 
+--R                         7   8              6 3 7              5 5 6
+--R               392445952a b c  + 3133005824a b c  + 1814572032a b c
+--R             + 
+--R                         4 7 5            3 9 4           2 11 3           13 2
+--R             - 230894592a b c  - 92879424a b c  - 3283232a b  c  - 10060a b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                          8 8              7 2 7              6 4 6
+--R               1177337856a c  + 9791463424a b c  + 8576721920a b c
+--R             + 
+--R                          5 6 5             4 8 4             3 10 3
+--R               1121888256a b c  - 509532864a b c  - 102729120a b  c
+--R             + 
+--R                         2 12 2           14
+--R               - 3313412a b  c  - 10060a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                         8   7              7 3 6              6 5 5
+--R               784891904a b c  + 6658457600a b c  + 6762149888a b c
+--R             + 
+--R                          5 7 4             4 9 3            3 11 2
+--R               1352782848a b c  - 416653440a b c  - 99445888a b  c
+--R             + 
+--R                         2 13            15
+--R               - 3303352a b  c - 10060a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          9 7              8 2 6              7 4 5
+--R               1177337856a c  + 9791463424a b c  + 8576721920a b c
+--R             + 
+--R                          6 6 4             5 8 3             4 10 2
+--R               1121888256a b c  - 509532864a b c  - 102729120a b  c
+--R             + 
+--R                         3 12          2 14
+--R               - 3313412a b  c - 10060a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         9   6              8 3 5              7 5 4
+--R               392445952a b c  + 3133005824a b c  + 1814572032a b c
+--R             + 
+--R                           6 7 3            5 9 2           4 11          3 13
+--R               - 230894592a b c  - 92879424a b c  - 3283232a b  c - 10060a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     10 6              9 2 5              8 4 4
+--R           392445952a  c  + 3133005824a b c  + 1814572032a b c
+--R         + 
+--R                       7 6 3            6 8 2           5 10          4 12
+--R           - 230894592a b c  - 92879424a b c  - 3283232a b  c - 10060a b
+--R      *
+--R            2
+--R         %DP
+--R     + 
+--R                                      8   10                 7 3 9
+--R                       - 326711115776a b c   - 3204657971200a b c
+--R                     + 
+--R                                       6 5 8                5 7 7
+--R                       - 1975127113728a b c  + 739587391488a b c
+--R                     + 
+--R                                    4 9 6               3 11 5
+--R                       158008147968a b c  - 30203019264a b  c
+--R                     + 
+--R                                    2 13 4              15 3         17 2
+--R                       - 2837053440a b  c  - 29734912a b  c  - 10112b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                      8 2 9                 7 4 8
+--R                       - 326711115776a b c  - 3204657971200a b c
+--R                     + 
+--R                                       6 6 7                5 8 6
+--R                       - 1975127113728a b c  + 739587391488a b c
+--R                     + 
+--R                                    4 10 5               3 12 4
+--R                       158008147968a b  c  - 30203019264a b  c
+--R                     + 
+--R                                    2 14 3              16 2         18
+--R                       - 2837053440a b  c  - 29734912a b  c  - 10112b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                      9   9                 8 3 8
+--R                       - 653422231552a b c  - 6409315942400a b c
+--R                     + 
+--R                                       7 5 7                 6 7 6
+--R                       - 3950254227456a b c  + 1479174782976a b c
+--R                     + 
+--R                                    5 9 5               4 11 4
+--R                       316016295936a b c  - 60406038528a b  c
+--R                     + 
+--R                                    3 13 3            2 15 2           17
+--R                       - 5674106880a b  c  - 59469824a b  c  - 20224a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                      9 2 8                 8 4 7
+--R                       - 326711115776a b c  - 3204657971200a b c
+--R                     + 
+--R                                       7 6 6                6 8 5
+--R                       - 1975127113728a b c  + 739587391488a b c
+--R                     + 
+--R                                    5 10 4               4 12 3
+--R                       158008147968a b  c  - 30203019264a b  c
+--R                     + 
+--R                                    3 14 2            2 16            18
+--R                       - 2837053440a b  c  - 29734912a b  c - 10112a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                      10   8                 9 3 7
+--R                       - 326711115776a  b c  - 3204657971200a b c
+--R                     + 
+--R                                       8 5 6                7 7 5
+--R                       - 1975127113728a b c  + 739587391488a b c
+--R                     + 
+--R                                    6 9 4               5 11 3
+--R                       158008147968a b c  - 30203019264a b  c
+--R                     + 
+--R                                    4 13 2            3 15          2 17
+--R                       - 2837053440a b  c  - 29734912a b  c - 10112a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                             6   8              5 3 7              4 5 6
+--R                   763035648a b c  + 2105561088a b c  + 1035563008a b c
+--R                 + 
+--R                             3 7 5           2 9 4          11 3
+--R                   122000896a b c  + 3081216a b c  + 8400a b  c
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                             6 2 7              5 4 6              4 6 5
+--R                   763035648a b c  + 2105561088a b c  + 1035563008a b c
+--R                 + 
+--R                             3 8 4           2 10 3          12 2
+--R                   122000896a b c  + 3081216a b  c  + 8400a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                              7   7              6 3 6              5 5 5
+--R                   2289106944a b c  + 7079718912a b c  + 5212250112a b c
+--R                 + 
+--R                              4 7 4             3 9 3           2 11 2
+--R                   1401565696a b c  + 131244544a b c  + 3106416a b  c
+--R                 + 
+--R                          13
+--R                   8400a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                              7 2 6              6 4 5              5 6 4
+--R                   1526071296a b c  + 4974157824a b c  + 4176687104a b c
+--R                 + 
+--R                            4 8 3             3 10 2           2 12           14
+--R                 1279564800a b c  + 128163328a b  c  + 3098016a b  c + 8400a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                              8   6              7 3 5              6 5 4
+--R                   2289106944a b c  + 7079718912a b c  + 5212250112a b c
+--R                 + 
+--R                            5 7 3             4 9 2           3 11         2 13
+--R                 1401565696a b c  + 131244544a b c  + 3106416a b  c + 8400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             8 2 5              7 4 4              6 6 3
+--R                   763035648a b c  + 2105561088a b c  + 1035563008a b c
+--R                 + 
+--R                             5 8 2           4 10         3 12
+--R                   122000896a b c  + 3081216a b  c + 8400a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         9   5              8 3 4              7 5 3
+--R               763035648a b c  + 2105561088a b c  + 1035563008a b c
+--R             + 
+--R                         6 7 2           5 9         4 11
+--R               122000896a b c  + 3081216a b c + 8400a b
+--R          *
+--R              +---------+
+--R              |        2    2
+--R             \|4a c - b  %DO
+--R         + 
+--R                                     8 2 10                 7 4 9
+--R                       5597365796864a b c   + 7714046476288a b c
+--R                     + 
+--R                                       6 6 8                5 8 7
+--R                       - 3700626030592a b c  - 685012680704a b c
+--R                     + 
+--R                                    4 10 6               3 12 5
+--R                       371750207488a b  c  - 10493427712a b  c
+--R                     + 
+--R                                    2 14 4              16 3         18 2
+--R                       - 4130930688a b  c  - 55169024a b  c  - 20224b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                     8 3 9                 7 5 8
+--R                       5597365796864a b c  + 7714046476288a b c
+--R                     + 
+--R                                       6 7 7                5 9 6
+--R                       - 3700626030592a b c  - 685012680704a b c
+--R                     + 
+--R                                    4 11 5               3 13 4
+--R                       371750207488a b  c  - 10493427712a b  c
+--R                     + 
+--R                                    2 15 3              17 2         19
+--R                       - 4130930688a b  c  - 55169024a b  c  - 20224b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                      9 2 9                  8 4 8
+--R                       11194731593728a b c  + 15428092952576a b c
+--R                     + 
+--R                                       7 6 7                 6 8 6
+--R                       - 7401252061184a b c  - 1370025361408a b c
+--R                     + 
+--R                                    5 10 5               4 12 4
+--R                       743500414976a b  c  - 20986855424a b  c
+--R                     + 
+--R                                    3 14 3             2 16 2           18
+--R                       - 8261861376a b  c  - 110338048a b  c  - 40448a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                     9 3 8                 8 5 7
+--R                       5597365796864a b c  + 7714046476288a b c
+--R                     + 
+--R                                       7 7 6                6 9 5
+--R                       - 3700626030592a b c  - 685012680704a b c
+--R                     + 
+--R                                    5 11 4               4 13 3
+--R                       371750207488a b  c  - 10493427712a b  c
+--R                     + 
+--R                                    3 15 2            2 17            19
+--R                       - 4130930688a b  c  - 55169024a b  c - 20224a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                     10 2 8                 9 4 7
+--R                       5597365796864a  b c  + 7714046476288a b c
+--R                     + 
+--R                                       8 6 6                7 8 5
+--R                       - 3700626030592a b c  - 685012680704a b c
+--R                     + 
+--R                                    6 10 4               5 12 3
+--R                       371750207488a b  c  - 10493427712a b  c
+--R                     + 
+--R                                    4 14 2            3 16          2 18
+--R                       - 4130930688a b  c  - 55169024a b  c - 20224a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                               7 9              6 2 8              5 4 7
+--R                   - 638107648a c  - 5052080128a b c  - 2895741952a b c
+--R                 + 
+--R                             4 6 6             3 8 5           2 10 4
+--R                   373335040a b c  + 147894976a b c  + 5230688a b  c
+--R                 + 
+--R                           12 3
+--R                   16484a b  c
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                               7   8              6 3 7              5 5 6
+--R                   - 638107648a b c  - 5052080128a b c  - 2895741952a b c
+--R                 + 
+--R                             4 7 5             3 9 4           2 11 3
+--R                   373335040a b c  + 147894976a b c  + 5230688a b  c
+--R                 + 
+--R                           13 2
+--R                   16484a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                8 8               7 2 7               6 4 6
+--R                   - 1914322944a c  - 15794348032a b c  - 13739305984a b c
+--R                 + 
+--R                                5 6 5             4 8 4             3 10 3
+--R                   - 1775736832a b c  + 817019968a b c  + 163587040a b  c
+--R                 + 
+--R                           2 12 2           14
+--R                   5280140a b  c  + 16484a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                8   7               7 3 6               6 5 5
+--R                   - 1276215296a b c  - 10742267904a b c  - 10843564032a b c
+--R                 + 
+--R                                5 7 4             4 9 3             3 11 2
+--R                   - 2149071872a b c  + 669124992a b c  + 158356352a b  c
+--R                 + 
+--R                           2 13            15
+--R                   5263656a b  c + 16484a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                9 7               8 2 6               7 4 5
+--R                   - 1914322944a c  - 15794348032a b c  - 13739305984a b c
+--R                 + 
+--R                                6 6 4             5 8 3             4 10 2
+--R                   - 1775736832a b c  + 817019968a b c  + 163587040a b  c
+--R                 + 
+--R                           3 12          2 14
+--R                   5280140a b  c + 16484a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               9   6              8 3 5              7 5 4
+--R                   - 638107648a b c  - 5052080128a b c  - 2895741952a b c
+--R                 + 
+--R                           6 7 3             5 9 2           4 11          3 13
+--R                 373335040a b c  + 147894976a b c  + 5230688a b  c + 16484a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           10 6              9 2 5              8 4 4
+--R               - 638107648a  c  - 5052080128a b c  - 2895741952a b c
+--R             + 
+--R                         7 6 3             6 8 2           5 10          4 12
+--R               373335040a b c  + 147894976a b c  + 5230688a b  c + 16484a b
+--R          *
+--R             %DO
+--R         + 
+--R                                    8   10                 7 3 9
+--R                       326711115776a b c   + 3204657971200a b c
+--R                     + 
+--R                                     6 5 8                5 7 7
+--R                       1975127113728a b c  - 739587391488a b c
+--R                     + 
+--R                                      4 9 6               3 11 5
+--R                       - 158008147968a b c  + 30203019264a b  c
+--R                     + 
+--R                                  2 13 4              15 3         17 2
+--R                       2837053440a b  c  + 29734912a b  c  + 10112b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                    8 2 9                 7 4 8
+--R                       326711115776a b c  + 3204657971200a b c
+--R                     + 
+--R                                     6 6 7                5 8 6
+--R                       1975127113728a b c  - 739587391488a b c
+--R                     + 
+--R                                      4 10 5               3 12 4
+--R                       - 158008147968a b  c  + 30203019264a b  c
+--R                     + 
+--R                                  2 14 3              16 2         18
+--R                       2837053440a b  c  + 29734912a b  c  + 10112b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                    9   9                 8 3 8
+--R                       653422231552a b c  + 6409315942400a b c
+--R                     + 
+--R                                     7 5 7                 6 7 6
+--R                       3950254227456a b c  - 1479174782976a b c
+--R                     + 
+--R                                      5 9 5               4 11 4
+--R                       - 316016295936a b c  + 60406038528a b  c
+--R                     + 
+--R                                  3 13 3            2 15 2           17
+--R                       5674106880a b  c  + 59469824a b  c  + 20224a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                    9 2 8                 8 4 7
+--R                       326711115776a b c  + 3204657971200a b c
+--R                     + 
+--R                                     7 6 6                6 8 5
+--R                       1975127113728a b c  - 739587391488a b c
+--R                     + 
+--R                                      5 10 4               4 12 3
+--R                       - 158008147968a b  c  + 30203019264a b  c
+--R                     + 
+--R                                  3 14 2            2 16            18
+--R                       2837053440a b  c  + 29734912a b  c + 10112a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                    10   8                 9 3 7
+--R                       326711115776a  b c  + 3204657971200a b c
+--R                     + 
+--R                                     8 5 6                7 7 5
+--R                       1975127113728a b c  - 739587391488a b c
+--R                     + 
+--R                                      6 9 4               5 11 3
+--R                       - 158008147968a b c  + 30203019264a b  c
+--R                     + 
+--R                                  4 13 2            3 15          2 17
+--R                       2837053440a b  c  + 29734912a b  c + 10112a b
+--R                  *
+--R                      4
+--R                     x
+--R              *
+--R                   ROOT
+--R                        a
+--R                     /
+--R                                  4 5           3 2 4          2 4 3
+--R                          1048576a c  - 1048576a b c  + 393216a b c
+--R                        + 
+--R                                    6 2        8
+--R                          - 65536a b c  + 4096b c
+--R                  ,
+--R                      4
+--R                **
+--R                   2
+--R             + 
+--R                               6   8              5 3 7              4 5 6
+--R                   - 763035648a b c  - 2105561088a b c  - 1035563008a b c
+--R                 + 
+--R                               3 7 5           2 9 4          11 3
+--R                   - 122000896a b c  - 3081216a b c  - 8400a b  c
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                               6 2 7              5 4 6              4 6 5
+--R                   - 763035648a b c  - 2105561088a b c  - 1035563008a b c
+--R                 + 
+--R                               3 8 4           2 10 3          12 2
+--R                   - 122000896a b c  - 3081216a b  c  - 8400a b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                7   7              6 3 6              5 5 5
+--R                   - 2289106944a b c  - 7079718912a b c  - 5212250112a b c
+--R                 + 
+--R                                4 7 4             3 9 3           2 11 2
+--R                   - 1401565696a b c  - 131244544a b c  - 3106416a b  c
+--R                 + 
+--R                            13
+--R                   - 8400a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                7 2 6              6 4 5              5 6 4
+--R                   - 1526071296a b c  - 4974157824a b c  - 4176687104a b c
+--R                 + 
+--R                                4 8 3             3 10 2           2 12
+--R                   - 1279564800a b c  - 128163328a b  c  - 3098016a b  c
+--R                 + 
+--R                            14
+--R                   - 8400a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                8   6              7 3 5              6 5 4
+--R                   - 2289106944a b c  - 7079718912a b c  - 5212250112a b c
+--R                 + 
+--R                                5 7 3             4 9 2           3 11
+--R                   - 1401565696a b c  - 131244544a b c  - 3106416a b  c
+--R                 + 
+--R                          2 13
+--R                   - 8400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               8 2 5              7 4 4              6 6 3
+--R                   - 763035648a b c  - 2105561088a b c  - 1035563008a b c
+--R                 + 
+--R                               5 8 2           4 10         3 12
+--R                   - 122000896a b c  - 3081216a b  c - 8400a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           9   5              8 3 4              7 5 3
+--R               - 763035648a b c  - 2105561088a b c  - 1035563008a b c
+--R             + 
+--R                           6 7 2           5 9         4 11
+--R               - 122000896a b c  - 3081216a b c - 8400a b
+--R          *
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R      *
+--R         %DP
+--R     + 
+--R                                  8 2 10                7 4 9
+--R                   - 672619560960a b c   - 956288729088a b c
+--R                 + 
+--R                                6 6 8               5 8 7               4 10 6
+--R                   443847540736a b c  + 91071709184a b c  - 46395195392a b  c
+--R                 + 
+--R                              3 12 5             2 14 4             16 3
+--R                   1119633408a b  c  + 531202048a b  c  + 7463936a b  c
+--R                 + 
+--R                        18 2
+--R                   3008b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                  8 3 9                7 5 8
+--R                   - 672619560960a b c  - 956288729088a b c
+--R                 + 
+--R                                6 7 7               5 9 6               4 11 5
+--R                   443847540736a b c  + 91071709184a b c  - 46395195392a b  c
+--R                 + 
+--R                              3 13 4             2 15 3             17 2
+--R                   1119633408a b  c  + 531202048a b  c  + 7463936a b  c
+--R                 + 
+--R                        19
+--R                   3008b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                   9 2 9                 8 4 8
+--R                   - 1345239121920a b c  - 1912577458176a b c
+--R                 + 
+--R                                7 6 7                6 8 6               5 10 5
+--R                   887695081472a b c  + 182143418368a b c  - 92790390784a b  c
+--R                 + 
+--R                              4 12 4              3 14 3            2 16 2
+--R                   2239266816a b  c  + 1062404096a b  c  + 14927872a b  c
+--R                 + 
+--R                          18
+--R                   6016a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                  9 3 8                8 5 7
+--R                   - 672619560960a b c  - 956288729088a b c
+--R                 + 
+--R                                7 7 6               6 9 5               5 11 4
+--R                   443847540736a b c  + 91071709184a b c  - 46395195392a b  c
+--R                 + 
+--R                              4 13 3             3 15 2           2 17
+--R                   1119633408a b  c  + 531202048a b  c  + 7463936a b  c
+--R                 + 
+--R                          19
+--R                   3008a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                  10 2 8                9 4 7
+--R                   - 672619560960a  b c  - 956288729088a b c
+--R                 + 
+--R                                8 6 6               7 8 5               6 10 4
+--R                   443847540736a b c  + 91071709184a b c  - 46395195392a b  c
+--R                 + 
+--R                              5 12 3             4 14 2           3 16
+--R                   1119633408a b  c  + 531202048a b  c  + 7463936a b  c
+--R                 + 
+--R                        2 18
+--R                   3008a b
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R               ROOT
+--R                    a
+--R                 /
+--R                              4 5           3 2 4          2 4 3           6 2
+--R                      1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                    + 
+--R                           8
+--R                      4096b c
+--R              ,
+--R                  4
+--R            **
+--R               2
+--R         + 
+--R                        7 9             6 2 8             5 4 7            4 6 6
+--R               75984896a c  + 613402624a b c  + 362712320a b c  - 44023040a b c
+--R             + 
+--R                          3 8 5          2 10 4          12 3
+--R               - 18746864a b c  - 690296a b  c  - 2309a b  c
+--R          *
+--R              24
+--R             x
+--R         + 
+--R                        7   8             6 3 7             5 5 6
+--R               75984896a b c  + 613402624a b c  + 362712320a b c
+--R             + 
+--R                          4 7 5            3 9 4          2 11 3          13 2
+--R               - 44023040a b c  - 18746864a b c  - 690296a b  c  - 2309a b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                         8 8              7 2 7              6 4 6
+--R               227954688a c  + 1916192768a b c  + 1701539584a b c
+--R             + 
+--R                         5 6 5             4 8 4            3 10 3
+--R               230643200a b c  - 100263632a b c  - 20817752a b  c
+--R             + 
+--R                        2 12 2          14
+--R               - 697223a b  c  - 2309a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                         8   7              7 3 6              6 5 5
+--R               151969792a b c  + 1302790144a b c  + 1338827264a b c
+--R             + 
+--R                         5 7 4            4 9 3            3 11 2          2 13
+--R               274666240a b c  - 81516768a b c  - 20127456a b  c  - 694914a b  c
+--R             + 
+--R                        15
+--R               - 2309a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         9 7              8 2 6              7 4 5
+--R               227954688a c  + 1916192768a b c  + 1701539584a b c
+--R             + 
+--R                         6 6 4             5 8 3            4 10 2
+--R               230643200a b c  - 100263632a b c  - 20817752a b  c
+--R             + 
+--R                        3 12         2 14
+--R               - 697223a b  c - 2309a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                        9   6             8 3 5             7 5 4
+--R               75984896a b c  + 613402624a b c  + 362712320a b c
+--R             + 
+--R                          6 7 3            5 9 2          4 11         3 13
+--R               - 44023040a b c  - 18746864a b c  - 690296a b  c - 2309a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    10 6             9 2 5             8 4 4            7 6 3
+--R           75984896a  c  + 613402624a b c  + 362712320a b c  - 44023040a b c
+--R         + 
+--R                      6 8 2          5 10         4 12
+--R           - 18746864a b c  - 690296a b  c - 2309a b
+--R      *
+--R            2
+--R         %DO
+--R     + 
+--R                                8   10                7 3 9                6 5 8
+--R                   155617067008a b c   + 881034526720a b c  - 133449121792a b c
+--R                 + 
+--R                                  5 7 7               4 9 6              3 11 5
+--R                   - 194499575808a b c  + 50024153088a b c  + 1456553984a b  c
+--R                 + 
+--R                               2 13 4              15 3        17 2
+--R                   - 773509120a b  c  - 13769728a b  c  - 6016b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                8 2 9                7 4 8                6 6 7
+--R                   155617067008a b c  + 881034526720a b c  - 133449121792a b c
+--R                 + 
+--R                                  5 8 6               4 10 5              3 12 4
+--R                   - 194499575808a b c  + 50024153088a b  c  + 1456553984a b  c
+--R                 + 
+--R                               2 14 3              16 2        18
+--R                   - 773509120a b  c  - 13769728a b  c  - 6016b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                9   9                 8 3 8                7 5 7
+--R                   311234134016a b c  + 1762069053440a b c  - 266898243584a b c
+--R                 + 
+--R                                  6 7 6                5 9 5              4 11 4
+--R                   - 388999151616a b c  + 100048306176a b c  + 2913107968a b  c
+--R                 + 
+--R                                3 13 3            2 15 2           17
+--R                   - 1547018240a b  c  - 27539456a b  c  - 12032a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                9 2 8                8 4 7                7 6 6
+--R                   155617067008a b c  + 881034526720a b c  - 133449121792a b c
+--R                 + 
+--R                                  6 8 5               5 10 4              4 12 3
+--R                   - 194499575808a b c  + 50024153088a b  c  + 1456553984a b  c
+--R                 + 
+--R                               3 14 2            2 16           18
+--R                   - 773509120a b  c  - 13769728a b  c - 6016a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                10   8                9 3 7                8 5 6
+--R                   155617067008a  b c  + 881034526720a b c  - 133449121792a b c
+--R                 + 
+--R                                  7 7 5               6 9 4              5 11 3
+--R                   - 194499575808a b c  + 50024153088a b c  + 1456553984a b  c
+--R                 + 
+--R                               4 13 2            3 15         2 17
+--R                   - 773509120a b  c  - 13769728a b  c - 6016a b
+--R              *
+--R                  4
+--R                 x
+--R          *
+--R               ROOT
+--R                    a
+--R                 /
+--R                              4 5           3 2 4          2 4 3           6 2
+--R                      1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                    + 
+--R                           8
+--R                      4096b c
+--R              ,
+--R                  4
+--R            **
+--R               2
+--R         + 
+--R                           6   8             5 3 7           4 5 6
+--R               - 290435072a b c  - 397059072a b c  + 3764736a b c
+--R             + 
+--R                        3 7 5           2 9 4          11 3
+--R               23681920a b c  + 1164688a b c  + 4524a b  c
+--R          *
+--R              24
+--R             x
+--R         + 
+--R                           6 2 7             5 4 6           4 6 5
+--R               - 290435072a b c  - 397059072a b c  + 3764736a b c
+--R             + 
+--R                        3 8 4           2 10 3          12 2
+--R               23681920a b c  + 1164688a b  c  + 4524a b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                           7   7              6 3 6             5 5 5
+--R               - 871305216a b c  - 1481612288a b c  - 385764864a b c
+--R             + 
+--R                        4 7 4            3 9 3           2 11 2          13
+--R               74810496a b c  + 27175984a b c  + 1178260a b  c  + 4524a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                           7 2 6              6 4 5             5 6 4
+--R               - 580870144a b c  - 1084553216a b c  - 389529600a b c
+--R             + 
+--R                        4 8 3            3 10 2           2 12           14
+--R               51128576a b c  + 26011296a b  c  + 1173736a b  c + 4524a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           8   6              7 3 5             6 5 4
+--R               - 871305216a b c  - 1481612288a b c  - 385764864a b c
+--R             + 
+--R                        5 7 3            4 9 2           3 11         2 13
+--R               74810496a b c  + 27175984a b c  + 1178260a b  c + 4524a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                           8 2 5             7 4 4           6 6 3
+--R               - 290435072a b c  - 397059072a b c  + 3764736a b c
+--R             + 
+--R                        5 8 2           4 10         3 12
+--R               23681920a b c  + 1164688a b  c + 4524a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       9   5             8 3 4           7 5 3            6 7 2
+--R           - 290435072a b c  - 397059072a b c  + 3764736a b c  + 23681920a b c
+--R         + 
+--R                   5 9         4 11
+--R           1164688a b c + 4524a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b  %DO
+--R     + 
+--R                            8 2 10                7 4 9                6 6 8
+--R               672619560960a b c   + 956288729088a b c  - 443847540736a b c
+--R             + 
+--R                             5 8 7               4 10 6              3 12 5
+--R               - 91071709184a b c  + 46395195392a b  c  - 1119633408a b  c
+--R             + 
+--R                           2 14 4             16 3        18 2
+--R               - 531202048a b  c  - 7463936a b  c  - 3008b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                            8 3 9                7 5 8                6 7 7
+--R               672619560960a b c  + 956288729088a b c  - 443847540736a b c
+--R             + 
+--R                             5 9 6               4 11 5              3 13 4
+--R               - 91071709184a b c  + 46395195392a b  c  - 1119633408a b  c
+--R             + 
+--R                           2 15 3             17 2        19
+--R               - 531202048a b  c  - 7463936a b  c  - 3008b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                             9 2 9                 8 4 8                7 6 7
+--R               1345239121920a b c  + 1912577458176a b c  - 887695081472a b c
+--R             + 
+--R                              6 8 6               5 10 5              4 12 4
+--R               - 182143418368a b c  + 92790390784a b  c  - 2239266816a b  c
+--R             + 
+--R                            3 14 3            2 16 2          18
+--R               - 1062404096a b  c  - 14927872a b  c  - 6016a b  c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                            9 3 8                8 5 7                7 7 6
+--R               672619560960a b c  + 956288729088a b c  - 443847540736a b c
+--R             + 
+--R                             6 9 5               5 11 4              4 13 3
+--R               - 91071709184a b c  + 46395195392a b  c  - 1119633408a b  c
+--R             + 
+--R                           3 15 2           2 17           19
+--R               - 531202048a b  c  - 7463936a b  c - 3008a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                            10 2 8                9 4 7                8 6 6
+--R               672619560960a  b c  + 956288729088a b c  - 443847540736a b c
+--R             + 
+--R                             7 8 5               6 10 4              5 12 3
+--R               - 91071709184a b c  + 46395195392a b  c  - 1119633408a b  c
+--R             + 
+--R                           4 14 2           3 16         2 18
+--R               - 531202048a b  c  - 7463936a b  c - 3008a b
+--R          *
+--R              4
+--R             x
+--R      *
+--R          +------------------------------------------------------------------+2
+--R          |                                 a
+--R          |------------------------------------------------------------------
+--R         4|        4 5           3 2 4          2 4 3           6 2        8
+--R         \|1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c  + 4096b c
+--R     + 
+--R                      7 9             6 2 8             5 4 7            4 6 6
+--R           - 75984896a c  - 613402624a b c  - 362712320a b c  + 44023040a b c
+--R         + 
+--R                    3 8 5          2 10 4          12 3
+--R           18746864a b c  + 690296a b  c  + 2309a b  c
+--R      *
+--R          24
+--R         x
+--R     + 
+--R                      7   8             6 3 7             5 5 6            4 7 5
+--R           - 75984896a b c  - 613402624a b c  - 362712320a b c  + 44023040a b c
+--R         + 
+--R                    3 9 4          2 11 3          13 2
+--R           18746864a b c  + 690296a b  c  + 2309a b  c
+--R      *
+--R          20
+--R         x
+--R     + 
+--R                       8 8              7 2 7              6 4 6
+--R           - 227954688a c  - 1916192768a b c  - 1701539584a b c
+--R         + 
+--R                       5 6 5             4 8 4            3 10 3          2 12 2
+--R           - 230643200a b c  + 100263632a b c  + 20817752a b  c  + 697223a b  c
+--R         + 
+--R                  14
+--R           2309a b  c
+--R      *
+--R          16
+--R         x
+--R     + 
+--R                       8   7              7 3 6              6 5 5
+--R           - 151969792a b c  - 1302790144a b c  - 1338827264a b c
+--R         + 
+--R                       5 7 4            4 9 3            3 11 2          2 13
+--R           - 274666240a b c  + 81516768a b c  + 20127456a b  c  + 694914a b  c
+--R         + 
+--R                  15
+--R           2309a b
+--R      *
+--R          12
+--R         x
+--R     + 
+--R                       9 7              8 2 6              7 4 5
+--R           - 227954688a c  - 1916192768a b c  - 1701539584a b c
+--R         + 
+--R                       6 6 4             5 8 3            4 10 2          3 12
+--R           - 230643200a b c  + 100263632a b c  + 20817752a b  c  + 697223a b  c
+--R         + 
+--R                2 14
+--R           2309a b
+--R      *
+--R          8
+--R         x
+--R     + 
+--R                      9   6             8 3 5             7 5 4            6 7 3
+--R           - 75984896a b c  - 613402624a b c  - 362712320a b c  + 44023040a b c
+--R         + 
+--R                    5 9 2          4 11         3 13
+--R           18746864a b c  + 690296a b  c + 2309a b
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                  10 6             9 2 5             8 4 4            7 6 3
+--R       - 75984896a  c  - 613402624a b c  - 362712320a b c  + 44023040a b c
+--R     + 
+--R                6 8 2          5 10         4 12
+--R       18746864a b c  + 690296a b  c + 2309a b
+--R                                                    Type: Expression(Integer)
+--E 1195
+
+)clear all
+
+--S 1196 of 2282
+t0:=x^2/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1196
+
+--S 1197 of 2282
+r0:=-c^(1/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))/(2^(3/4)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4)*sqrt(b^2-4*a*c))+c^(1/4)*_
+   atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))/(2^(3/4)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4)*sqrt(b^2-4*a*c))+c^(1/4)*atan(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))/(2^(3/4)*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(1/4))-c^(1/4)*atanh(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))/(2^(3/4)*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R            +------------------+
+--R            | +-----------+                   4+-+4+-+
+--R       4+-+4| |          2                   x\|2 \|c
+--R       \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                       +--------------------+
+--R                                       |   +-----------+
+--R                                      4|   |          2
+--R                                      \|- \|- 4a c + b   - b
+--R     + 
+--R              +--------------------+
+--R              |   +-----------+                  4+-+4+-+
+--R         4+-+4|   |          2                  x\|2 \|c
+--R       - \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R     + 
+--R              +------------------+
+--R              | +-----------+                  4+-+4+-+
+--R         4+-+4| |          2                  x\|2 \|c
+--R       - \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R            +--------------------+
+--R            |   +-----------+                 4+-+4+-+
+--R       4+-+4|   |          2                 x\|2 \|c
+--R       \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R  /
+--R                         +--------------------+ +------------------+
+--R           +-----------+ |   +-----------+      | +-----------+
+--R     4+-+3 |          2 4|   |          2      4| |          2
+--R     \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1197
+
+--S 1198 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                                      6 2 4            5 4 3           4 6 2
+--R                             33554432a b c  - 25165824a b c  + 6291456a b c
+--R                           + 
+--R                                      3 8
+--R                             - 524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                                      6 2 4            5 4 3           4 6 2
+--R                             33554432a b c  - 25165824a b c  + 6291456a b c
+--R                           + 
+--R                                      3 8
+--R                             - 524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                              3       5
+--R                       (128a b c - 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                                        4 2 3          3 4 2         2 6
+--R                               - 262144a b c  + 196608a b c  - 49152a b c
+--R                             + 
+--R                                      8
+--R                               4096a b
+--R                        *
+--R                           x
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               2 2
+--R                         - 256a c x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                                      6 2 4            5 4 3           4 6 2
+--R                             33554432a b c  - 25165824a b c  + 6291456a b c
+--R                           + 
+--R                                      3 8
+--R                             - 524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                                      6 2 4            5 4 3           4 6 2
+--R                             33554432a b c  - 25165824a b c  + 6291456a b c
+--R                           + 
+--R                                      3 8
+--R                             - 524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                                        4 2 3          3 4 2         2 6
+--R                               - 262144a b c  + 196608a b c  - 49152a b c
+--R                             + 
+--R                                      8
+--R                               4096a b
+--R                        *
+--R                           x
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               2 2
+--R                         - 256a c x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                                3       5
+--R                       (- 128a b c + 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                    2
+--R                 c x
+--R     + 
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                                   6 2 4            5 4 3           4 6 2
+--R                          33554432a b c  - 25165824a b c  + 6291456a b c
+--R                        + 
+--R                                   3 8
+--R                          - 524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                                   6 2 4            5 4 3           4 6 2
+--R                          33554432a b c  - 25165824a b c  + 6291456a b c
+--R                        + 
+--R                                   3 8
+--R                          - 524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                             3       5
+--R                    (- 128a b c + 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                                4 2 3          3 4 2         2 6           8
+--R                        (262144a b c  - 196608a b c  + 49152a b c - 4096a b )x
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                          2 2
+--R                      256a c x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                                   6 2 4            5 4 3           4 6 2
+--R                          33554432a b c  - 25165824a b c  + 6291456a b c
+--R                        + 
+--R                                   3 8
+--R                          - 524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                                   6 2 4            5 4 3           4 6 2
+--R                          33554432a b c  - 25165824a b c  + 6291456a b c
+--R                        + 
+--R                                   3 8
+--R                          - 524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                                4 2 3          3 4 2         2 6           8
+--R                        (262144a b c  - 196608a b c  + 49152a b c - 4096a b )x
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                          2 2
+--R                      256a c x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                           3       5
+--R                    (128a b c - 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                 2
+--R              c x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                           4 3         3 2 2        2 4          6
+--R                    (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                           4 3         3 2 2        2 4          6
+--R                    (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                         2 2         2       4
+--R                    (256a c  - 128a b c + 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                            4   3          3 3 2         2 5           7
+--R                    (262144a b c  - 196608a b c  + 49152a b c - 4096a b )x
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |                          1
+--R                     |-----------------------------------------------------
+--R                     |        5 3           4 2 2          3 4          2 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                           4 3         3 2 2        2 4          6
+--R                    (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                           4 3         3 2 2        2 4          6
+--R                    (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                            4   3          3 3 2         2 5           7
+--R                    (262144a b c  - 196608a b c  + 49152a b c - 4096a b )x
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |                          1
+--R                     |-----------------------------------------------------
+--R                     |        5 3           4 2 2          3 4          2 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                           2 2         2       4
+--R                    (- 256a c  + 128a b c - 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                 2
+--R              c x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                              4 3         3 2 2        2 4          6
+--R                       (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                              4 3         3 2 2        2 4          6
+--R                       (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                              2 2         2       4
+--R                       (- 256a c  + 128a b c - 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                                 4   3          3 3 2         2 5           7
+--R                       (- 262144a b c  + 196608a b c  - 49152a b c + 4096a b )x
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                          1
+--R                        |-----------------------------------------------------
+--R                        |        5 3           4 2 2          3 4          2 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                              4 3         3 2 2        2 4          6
+--R                       (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                              4 3         3 2 2        2 4          6
+--R                       (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                                 4   3          3 3 2         2 5           7
+--R                       (- 262144a b c  + 196608a b c  - 49152a b c + 4096a b )x
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                          1
+--R                        |-----------------------------------------------------
+--R                        |        5 3           4 2 2          3 4          2 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                            2 2         2       4
+--R                       (256a c  - 128a b c + 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                    2
+--R                 c x
+--R     + 
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                                     6 2 4            5 4 3           4 6 2
+--R                          - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                        + 
+--R                                 3 8
+--R                          524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                                     6 2 4            5 4 3           4 6 2
+--R                          - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                        + 
+--R                                 3 8
+--R                          524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                           3       5
+--R                    (128a b c - 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                                  4 2 3          3 4 2         2 6           8
+--R                        (- 262144a b c  + 196608a b c  - 49152a b c + 4096a b )x
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                          2 2
+--R                      256a c x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                                     6 2 4            5 4 3           4 6 2
+--R                          - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                        + 
+--R                                 3 8
+--R                          524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                                     6 2 4            5 4 3           4 6 2
+--R                          - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                        + 
+--R                                 3 8
+--R                          524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                                  4 2 3          3 4 2         2 6           8
+--R                        (- 262144a b c  + 196608a b c  - 49152a b c + 4096a b )x
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                          2 2
+--R                      256a c x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                             3       5
+--R                    (- 128a b c + 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                 2
+--R              c x
+--R     + 
+--R       -
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                                        6 2 4            5 4 3           4 6 2
+--R                             - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                           + 
+--R                                    3 8
+--R                             524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                                        6 2 4            5 4 3           4 6 2
+--R                             - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                           + 
+--R                                    3 8
+--R                             524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                                3       5
+--R                       (- 128a b c + 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                                   4 2 3          3 4 2         2 6           8
+--R                           (262144a b c  - 196608a b c  + 49152a b c - 4096a b )
+--R                        *
+--R                           x
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               2 2
+--R                         - 256a c x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                                        6 2 4            5 4 3           4 6 2
+--R                             - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                           + 
+--R                                    3 8
+--R                             524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                                        6 2 4            5 4 3           4 6 2
+--R                             - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                           + 
+--R                                    3 8
+--R                             524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                                   4 2 3          3 4 2         2 6           8
+--R                           (262144a b c  - 196608a b c  + 49152a b c - 4096a b )
+--R                        *
+--R                           x
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               2 2
+--R                         - 256a c x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                              3       5
+--R                       (128a b c - 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                    2
+--R                 c x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                                        4 2 3         3 4 2         2 6
+--R                                 131072a b c  - 98304a b c  + 24576a b c
+--R                               + 
+--R                                          8
+--R                                 - 2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                               2 2
+--R                           128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                                 2 2
+--R                           - 128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R              /
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                                 2 2
+--R                           - 128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                                 2 2
+--R                           - 128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                 3      5
+--R                         (- 64a b c + 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                   - c x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                                  4 2 3         3 4 2         2 6           8
+--R                          (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                            2 2
+--R                        128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                              2 2
+--R                        - 128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R           /
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                              2 2
+--R                        - 128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                              2 2
+--R                        - 128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                              3      5
+--R                      (- 64a b c + 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                c x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                                  4 2 3         3 4 2         2 6           8
+--R                          (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                              2 2
+--R                        - 128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                            2 2
+--R                        128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R           /
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                            2 2
+--R                        128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                            2 2
+--R                        128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                              3      5
+--R                      (- 64a b c + 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                - c x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                                        4 2 3         3 4 2         2 6
+--R                                 131072a b c  - 98304a b c  + 24576a b c
+--R                               + 
+--R                                          8
+--R                                 - 2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                                 2 2
+--R                           - 128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                               2 2
+--R                           128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R              /
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                               2 2
+--R                           128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                               2 2
+--R                           128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                 3      5
+--R                         (- 64a b c + 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                   c x
+--R     + 
+--R         4
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                              4   3         3 3 2         2 5           7
+--R                      (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                             2 2        2      4
+--R                      (- 128a c  + 64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                             2 2        2      4
+--R                      (- 128a c  + 64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                                4   3         3 3 2         2 5           7
+--R                      (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R           /
+--R                           2 2        2      4
+--R                      (128a c  - 64a b c + 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                              4   3         3 3 2         2 5           7
+--R                      (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                              4   3         3 3 2         2 5           7
+--R                      (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                             2 2        2      4
+--R                      (- 128a c  + 64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                - c x
+--R     + 
+--R       -
+--R            4
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                                 4   3         3 3 2         2 5           7
+--R                         (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                      *
+--R                         ROOT
+--R                              1
+--R                           /
+--R                                        5 3           4 2 2          3 4
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6
+--R                                - 65536a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                2 2        2      4
+--R                         (- 128a c  + 64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                                2 2        2      4
+--R                         (- 128a c  + 64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                   4   3         3 3 2         2 5           7
+--R                         (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                      *
+--R                         ROOT
+--R                              1
+--R                           /
+--R                                        5 3           4 2 2          3 4
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6
+--R                                - 65536a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R              /
+--R                              2 2        2      4
+--R                         (128a c  - 64a b c + 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                 4   3         3 3 2         2 5           7
+--R                         (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                      *
+--R                         ROOT
+--R                              1
+--R                           /
+--R                                        5 3           4 2 2          3 4
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6
+--R                                - 65536a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                                 4   3         3 3 2         2 5           7
+--R                         (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                      *
+--R                         ROOT
+--R                              1
+--R                           /
+--R                                        5 3           4 2 2          3 4
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6
+--R                                - 65536a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                2 2        2      4
+--R                         (- 128a c  + 64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                   c x
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1198
+
+--S 1199 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R            4+-+3 |          2 4|   |          2      4| |          2
+--R            \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                                      6 2 4            5 4 3           4 6 2
+--R                             33554432a b c  - 25165824a b c  + 6291456a b c
+--R                           + 
+--R                                      3 8
+--R                             - 524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                                      6 2 4            5 4 3           4 6 2
+--R                             33554432a b c  - 25165824a b c  + 6291456a b c
+--R                           + 
+--R                                      3 8
+--R                             - 524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                              3       5
+--R                       (128a b c - 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                                        4 2 3          3 4 2         2 6
+--R                               - 262144a b c  + 196608a b c  - 49152a b c
+--R                             + 
+--R                                      8
+--R                               4096a b
+--R                        *
+--R                           x
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               2 2
+--R                         - 256a c x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                                      6 2 4            5 4 3           4 6 2
+--R                             33554432a b c  - 25165824a b c  + 6291456a b c
+--R                           + 
+--R                                      3 8
+--R                             - 524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                                      6 2 4            5 4 3           4 6 2
+--R                             33554432a b c  - 25165824a b c  + 6291456a b c
+--R                           + 
+--R                                      3 8
+--R                             - 524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                                        4 2 3          3 4 2         2 6
+--R                               - 262144a b c  + 196608a b c  - 49152a b c
+--R                             + 
+--R                                      8
+--R                               4096a b
+--R                        *
+--R                           x
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               2 2
+--R                         - 256a c x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                                3       5
+--R                       (- 128a b c + 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                    2
+--R                 c x
+--R     + 
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R         4+-+3 |          2 4|   |          2      4| |          2
+--R         \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                                   6 2 4            5 4 3           4 6 2
+--R                          33554432a b c  - 25165824a b c  + 6291456a b c
+--R                        + 
+--R                                   3 8
+--R                          - 524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                                   6 2 4            5 4 3           4 6 2
+--R                          33554432a b c  - 25165824a b c  + 6291456a b c
+--R                        + 
+--R                                   3 8
+--R                          - 524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                             3       5
+--R                    (- 128a b c + 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                                4 2 3          3 4 2         2 6           8
+--R                        (262144a b c  - 196608a b c  + 49152a b c - 4096a b )x
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                          2 2
+--R                      256a c x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                                   6 2 4            5 4 3           4 6 2
+--R                          33554432a b c  - 25165824a b c  + 6291456a b c
+--R                        + 
+--R                                   3 8
+--R                          - 524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                                   6 2 4            5 4 3           4 6 2
+--R                          33554432a b c  - 25165824a b c  + 6291456a b c
+--R                        + 
+--R                                   3 8
+--R                          - 524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                                4 2 3          3 4 2         2 6           8
+--R                        (262144a b c  - 196608a b c  + 49152a b c - 4096a b )x
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                          2 2
+--R                      256a c x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                           3       5
+--R                    (128a b c - 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                 2
+--R              c x
+--R     + 
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R         2\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                           4 3         3 2 2        2 4          6
+--R                    (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                           4 3         3 2 2        2 4          6
+--R                    (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                         2 2         2       4
+--R                    (256a c  - 128a b c + 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                            4   3          3 3 2         2 5           7
+--R                    (262144a b c  - 196608a b c  + 49152a b c - 4096a b )x
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |                          1
+--R                     |-----------------------------------------------------
+--R                     |        5 3           4 2 2          3 4          2 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                           4 3         3 2 2        2 4          6
+--R                    (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                           4 3         3 2 2        2 4          6
+--R                    (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                            4   3          3 3 2         2 5           7
+--R                    (262144a b c  - 196608a b c  + 49152a b c - 4096a b )x
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |                          1
+--R                     |-----------------------------------------------------
+--R                     |        5 3           4 2 2          3 4          2 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                           2 2         2       4
+--R                    (- 256a c  + 128a b c - 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                 2
+--R              c x
+--R     + 
+--R       -
+--R                                 +--------------------+ +------------------+
+--R                   +-----------+ |   +-----------+      | +-----------+
+--R             4+-+3 |          2 4|   |          2      4| |          2
+--R            2\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                              4 3         3 2 2        2 4          6
+--R                       (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                              4 3         3 2 2        2 4          6
+--R                       (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                              2 2         2       4
+--R                       (- 256a c  + 128a b c - 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                                 4   3          3 3 2         2 5           7
+--R                       (- 262144a b c  + 196608a b c  - 49152a b c + 4096a b )x
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                          1
+--R                        |-----------------------------------------------------
+--R                        |        5 3           4 2 2          3 4          2 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                              4 3         3 2 2        2 4          6
+--R                       (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                              4 3         3 2 2        2 4          6
+--R                       (16384a c  - 12288a b c  + 3072a b c - 256a b )
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                                 4   3          3 3 2         2 5           7
+--R                       (- 262144a b c  + 196608a b c  - 49152a b c + 4096a b )x
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                          1
+--R                        |-----------------------------------------------------
+--R                        |        5 3           4 2 2          3 4          2 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                            2 2         2       4
+--R                       (256a c  - 128a b c + 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                    2
+--R                 c x
+--R     + 
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R         4+-+3 |          2 4|   |          2      4| |          2
+--R         \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         log
+--R                                     6 2 4            5 4 3           4 6 2
+--R                          - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                        + 
+--R                                 3 8
+--R                          524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                                     6 2 4            5 4 3           4 6 2
+--R                          - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                        + 
+--R                                 3 8
+--R                          524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                           3       5
+--R                    (128a b c - 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                                  4 2 3          3 4 2         2 6           8
+--R                        (- 262144a b c  + 196608a b c  - 49152a b c + 4096a b )x
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                          2 2
+--R                      256a c x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                sin
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                                     6 2 4            5 4 3           4 6 2
+--R                          - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                        + 
+--R                                 3 8
+--R                          524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R                + 
+--R                                     6 2 4            5 4 3           4 6 2
+--R                          - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                        + 
+--R                                 3 8
+--R                          524288a b c
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                            4 3        3 4 2        2 6          8
+--R                      16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                 *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   **
+--R                      2
+--R                 *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   **
+--R                      2
+--R             *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                                  4 2 3          3 4 2         2 6           8
+--R                        (- 262144a b c  + 196608a b c  - 49152a b c + 4096a b )x
+--R                     *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                    + 
+--R                          2 2
+--R                      256a c x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    sin
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R                + 
+--R                             3       5
+--R                    (- 128a b c + 16b )x
+--R                 *
+--R                    ROOT
+--R                         c
+--R                      /
+--R                                   5 4           4 2 3          3 4 2
+--R                           1048576a c  - 1048576a b c  + 393216a b c
+--R                         + 
+--R                                   2 6           8
+--R                           - 65536a b c + 4096a b
+--R                   ,
+--R                       4
+--R                 *
+--R                    cos
+--R                         atan
+--R                                      3 2        2 2          4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                     1
+--R                                  /
+--R                                               5 3           4 2 2          3 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               2 6
+--R                                       - 65536a b
+--R                           /
+--R                              b
+--R                      /
+--R                         2
+--R             *
+--R                ROOT
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                       4
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R               ,
+--R                   4
+--R             *
+--R                cos
+--R                     atan
+--R                          sin
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                       /
+--R                          cos
+--R                               atan
+--R                                            3 2        2 2          4
+--R                                      (4096a c  - 2048a b c + 256a b )
+--R                                   *
+--R                                      ROOT
+--R                                           1
+--R                                        /
+--R                                                     5 3           4 2 2
+--R                                             4194304a c  - 3145728a b c
+--R                                           + 
+--R                                                    3 4          2 6
+--R                                             786432a b c - 65536a b
+--R                                 /
+--R                                    b
+--R                            /
+--R                               2
+--R                  /
+--R                     2
+--R            + 
+--R                 2
+--R              c x
+--R     + 
+--R       -
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R            4+-+3 |          2 4|   |          2      4| |          2
+--R            \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            log
+--R                                        6 2 4            5 4 3           4 6 2
+--R                             - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                           + 
+--R                                    3 8
+--R                             524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                                        6 2 4            5 4 3           4 6 2
+--R                             - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                           + 
+--R                                    3 8
+--R                             524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                                3       5
+--R                       (- 128a b c + 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                                   4 2 3          3 4 2         2 6           8
+--R                           (262144a b c  - 196608a b c  + 49152a b c - 4096a b )
+--R                        *
+--R                           x
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               2 2
+--R                         - 256a c x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   sin
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                                        6 2 4            5 4 3           4 6 2
+--R                             - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                           + 
+--R                                    3 8
+--R                             524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                   + 
+--R                                        6 2 4            5 4 3           4 6 2
+--R                             - 33554432a b c  + 25165824a b c  - 6291456a b c
+--R                           + 
+--R                                    3 8
+--R                             524288a b c
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               4 3        3 4 2        2 6          8
+--R                         16384a c  + 4096a b c  + 1024a b c - 256a b
+--R                    *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      **
+--R                         2
+--R                    *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                      **
+--R                         2
+--R                *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                                   4 2 3          3 4 2         2 6           8
+--R                           (262144a b c  - 196608a b c  + 49152a b c - 4096a b )
+--R                        *
+--R                           x
+--R                        *
+--R                           ROOT
+--R                                1
+--R                             /
+--R                                          5 3           4 2 2          3 4
+--R                                  4194304a c  - 3145728a b c  + 786432a b c
+--R                                + 
+--R                                          2 6
+--R                                  - 65536a b
+--R                       + 
+--R                               2 2
+--R                         - 256a c x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       sin
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                   + 
+--R                              3       5
+--R                       (128a b c - 16b )x
+--R                    *
+--R                       ROOT
+--R                            c
+--R                         /
+--R                                      5 4           4 2 3          3 4 2
+--R                              1048576a c  - 1048576a b c  + 393216a b c
+--R                            + 
+--R                                      2 6           8
+--R                              - 65536a b c + 4096a b
+--R                      ,
+--R                          4
+--R                    *
+--R                       cos
+--R                            atan
+--R                                         3 2        2 2          4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                        1
+--R                                     /
+--R                                                  5 3           4 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 3 4          2 6
+--R                                          786432a b c - 65536a b
+--R                              /
+--R                                 b
+--R                         /
+--R                            2
+--R                *
+--R                   ROOT
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                      + 
+--R                          4
+--R                       *
+--R                            ROOT
+--R                                 c
+--R                              /
+--R                                           5 4           4 2 3          3 4 2
+--R                                   1048576a c  - 1048576a b c  + 393216a b c
+--R                                 + 
+--R                                           2 6           8
+--R                                   - 65536a b c + 4096a b
+--R                           ,
+--R                               4
+--R                         **
+--R                            2
+--R                       *
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         **
+--R                            2
+--R                  ,
+--R                      4
+--R                *
+--R                   cos
+--R                        atan
+--R                             sin
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                          /
+--R                             cos
+--R                                  atan
+--R                                               3 2        2 2          4
+--R                                         (4096a c  - 2048a b c + 256a b )
+--R                                      *
+--R                                         ROOT
+--R                                              1
+--R                                           /
+--R                                                        5 3           4 2 2
+--R                                                4194304a c  - 3145728a b c
+--R                                              + 
+--R                                                       3 4          2 6
+--R                                                786432a b c - 65536a b
+--R                                    /
+--R                                       b
+--R                               /
+--R                                  2
+--R                     /
+--R                        2
+--R               + 
+--R                    2
+--R                 c x
+--R     + 
+--R       -
+--R                                 +--------------------+ +------------------+
+--R                   +-----------+ |   +-----------+      | +-----------+
+--R             4+-+3 |          2 4|   |          2      4| |          2
+--R            2\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                                        4 2 3         3 4 2         2 6
+--R                                 131072a b c  - 98304a b c  + 24576a b c
+--R                               + 
+--R                                          8
+--R                                 - 2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                               2 2
+--R                           128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                                 2 2
+--R                           - 128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R              /
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                                 2 2
+--R                           - 128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                                 2 2
+--R                           - 128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                 3      5
+--R                         (- 64a b c + 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                   - c x
+--R     + 
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R         2\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                                  4 2 3         3 4 2         2 6           8
+--R                          (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                            2 2
+--R                        128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                              2 2
+--R                        - 128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R           /
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                              2 2
+--R                        - 128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                              2 2
+--R                        - 128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                              3      5
+--R                      (- 64a b c + 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                c x
+--R     + 
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R         2\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         cos
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                                  4 2 3         3 4 2         2 6           8
+--R                          (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                              2 2
+--R                        - 128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                            2 2
+--R                        128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R           /
+--R                            3      5
+--R                      (64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                            2 2
+--R                        128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                                    4 2 3         3 4 2         2 6           8
+--R                          (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                          1
+--R                         |-----------------------------------------------------
+--R                         |        5 3           4 2 2          3 4          2 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                            2 2
+--R                        128a c
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                              3      5
+--R                      (- 64a b c + 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                - c x
+--R     + 
+--R       -
+--R                                 +--------------------+ +------------------+
+--R                   +-----------+ |   +-----------+      | +-----------+
+--R             4+-+3 |          2 4|   |          2      4| |          2
+--R            2\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            cos
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                                        4 2 3         3 4 2         2 6
+--R                                 131072a b c  - 98304a b c  + 24576a b c
+--R                               + 
+--R                                          8
+--R                                 - 2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                                 2 2
+--R                           - 128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                               2 2
+--R                           128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R              /
+--R                               3      5
+--R                         (64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                               2 2
+--R                           128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                                        4 2 3         3 4 2         2 6
+--R                               - 131072a b c  + 98304a b c  - 24576a b c
+--R                             + 
+--R                                      8
+--R                               2048a b
+--R                          *
+--R                             ROOT
+--R                                  1
+--R                               /
+--R                                            5 3           4 2 2          3 4
+--R                                    4194304a c  - 3145728a b c  + 786432a b c
+--R                                  + 
+--R                                            2 6
+--R                                    - 65536a b
+--R                         + 
+--R                               2 2
+--R                           128a c
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                 3      5
+--R                         (- 64a b c + 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                   c x
+--R     + 
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R         4\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  sin
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R            + 
+--R                4
+--R             *
+--R                  ROOT
+--R                       c
+--R                    /
+--R                                 5 4           4 2 3          3 4 2         2 6
+--R                         1048576a c  - 1048576a b c  + 393216a b c  - 65536a b c
+--R                       + 
+--R                                8
+--R                         4096a b
+--R                 ,
+--R                     4
+--R               **
+--R                  2
+--R             *
+--R                  cos
+--R                       atan
+--R                                    3 2        2 2          4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                   1
+--R                                /
+--R                                             5 3           4 2 2          3 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6
+--R                                     - 65536a b
+--R                         /
+--R                            b
+--R                    /
+--R                       2
+--R               **
+--R                  2
+--R        ,
+--R            4
+--R      *
+--R         sin
+--R              atan
+--R                   sin
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R                /
+--R                   cos
+--R                        atan
+--R                                     3 2        2 2          4
+--R                               (4096a c  - 2048a b c + 256a b )
+--R                            *
+--R                               ROOT
+--R                                    1
+--R                                 /
+--R                                              5 3           4 2 2          3 4
+--R                                      4194304a c  - 3145728a b c  + 786432a b c
+--R                                    + 
+--R                                              2 6
+--R                                      - 65536a b
+--R                          /
+--R                             b
+--R                     /
+--R                        2
+--R           /
+--R              2
+--R      *
+--R         atan
+--R                              4   3         3 3 2         2 5           7
+--R                      (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                             2 2        2      4
+--R                      (- 128a c  + 64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                             2 2        2      4
+--R                      (- 128a c  + 64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                                4   3         3 3 2         2 5           7
+--R                      (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R           /
+--R                           2 2        2      4
+--R                      (128a c  - 64a b c + 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                              4   3         3 3 2         2 5           7
+--R                      (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  sin
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                              4   3         3 3 2         2 5           7
+--R                      (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                          1
+--R                       |-----------------------------------------------------
+--R                       |        5 3           4 2 2          3 4          2 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                  + 
+--R                             2 2        2      4
+--R                      (- 128a c  + 64a b c - 8b )
+--R                   *
+--R                      ROOT
+--R                           c
+--R                        /
+--R                                     5 4           4 2 3          3 4 2
+--R                             1048576a c  - 1048576a b c  + 393216a b c
+--R                           + 
+--R                                     2 6           8
+--R                             - 65536a b c + 4096a b
+--R                     ,
+--R                         4
+--R                   *
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R               *
+--R                  ROOT
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           sin
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                     + 
+--R                         4
+--R                      *
+--R                           ROOT
+--R                                c
+--R                             /
+--R                                          5 4           4 2 3          3 4 2
+--R                                  1048576a c  - 1048576a b c  + 393216a b c
+--R                                + 
+--R                                          2 6           8
+--R                                  - 65536a b c + 4096a b
+--R                          ,
+--R                              4
+--R                        **
+--R                           2
+--R                      *
+--R                           cos
+--R                                atan
+--R                                             3 2        2 2          4
+--R                                       (4096a c  - 2048a b c + 256a b )
+--R                                    *
+--R                                       ROOT
+--R                                            1
+--R                                         /
+--R                                                      5 3           4 2 2
+--R                                              4194304a c  - 3145728a b c
+--R                                            + 
+--R                                                     3 4          2 6
+--R                                              786432a b c - 65536a b
+--R                                  /
+--R                                     b
+--R                             /
+--R                                2
+--R                        **
+--R                           2
+--R                 ,
+--R                     4
+--R               *
+--R                  cos
+--R                       atan
+--R                            sin
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                         /
+--R                            cos
+--R                                 atan
+--R                                              3 2        2 2          4
+--R                                        (4096a c  - 2048a b c + 256a b )
+--R                                     *
+--R                                        ROOT
+--R                                             1
+--R                                          /
+--R                                                       5 3           4 2 2
+--R                                               4194304a c  - 3145728a b c
+--R                                             + 
+--R                                                      3 4          2 6
+--R                                               786432a b c - 65536a b
+--R                                   /
+--R                                      b
+--R                              /
+--R                                 2
+--R                    /
+--R                       2
+--R              + 
+--R                - c x
+--R     + 
+--R       -
+--R                                 +--------------------+ +------------------+
+--R                   +-----------+ |   +-----------+      | +-----------+
+--R             4+-+3 |          2 4|   |          2      4| |          2
+--R            4\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     sin
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R               + 
+--R                   4
+--R                *
+--R                     ROOT
+--R                          c
+--R                       /
+--R                                    5 4           4 2 3          3 4 2
+--R                            1048576a c  - 1048576a b c  + 393216a b c
+--R                          + 
+--R                                    2 6           8
+--R                            - 65536a b c + 4096a b
+--R                    ,
+--R                        4
+--R                  **
+--R                     2
+--R                *
+--R                     cos
+--R                          atan
+--R                                       3 2        2 2          4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                      1
+--R                                   /
+--R                                                5 3           4 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4          2 6
+--R                                        786432a b c - 65536a b
+--R                            /
+--R                               b
+--R                       /
+--R                          2
+--R                  **
+--R                     2
+--R           ,
+--R               4
+--R         *
+--R            sin
+--R                 atan
+--R                      sin
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R                   /
+--R                      cos
+--R                           atan
+--R                                        3 2        2 2          4
+--R                                  (4096a c  - 2048a b c + 256a b )
+--R                               *
+--R                                  ROOT
+--R                                       1
+--R                                    /
+--R                                                 5 3           4 2 2
+--R                                         4194304a c  - 3145728a b c
+--R                                       + 
+--R                                                3 4          2 6
+--R                                         786432a b c - 65536a b
+--R                             /
+--R                                b
+--R                        /
+--R                           2
+--R              /
+--R                 2
+--R         *
+--R            atan
+--R                                 4   3         3 3 2         2 5           7
+--R                         (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                      *
+--R                         ROOT
+--R                              1
+--R                           /
+--R                                        5 3           4 2 2          3 4
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6
+--R                                - 65536a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                2 2        2      4
+--R                         (- 128a c  + 64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                                2 2        2      4
+--R                         (- 128a c  + 64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                   4   3         3 3 2         2 5           7
+--R                         (- 131072a b c  + 98304a b c  - 24576a b c + 2048a b )
+--R                      *
+--R                         ROOT
+--R                              1
+--R                           /
+--R                                        5 3           4 2 2          3 4
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6
+--R                                - 65536a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R              /
+--R                              2 2        2      4
+--R                         (128a c  - 64a b c + 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                 4   3         3 3 2         2 5           7
+--R                         (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                      *
+--R                         ROOT
+--R                              1
+--R                           /
+--R                                        5 3           4 2 2          3 4
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6
+--R                                - 65536a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     sin
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                                 4   3         3 3 2         2 5           7
+--R                         (131072a b c  - 98304a b c  + 24576a b c - 2048a b )
+--R                      *
+--R                         ROOT
+--R                              1
+--R                           /
+--R                                        5 3           4 2 2          3 4
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6
+--R                                - 65536a b
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         sin
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                     + 
+--R                                2 2        2      4
+--R                         (- 128a c  + 64a b c - 8b )
+--R                      *
+--R                         ROOT
+--R                              c
+--R                           /
+--R                                        5 4           4 2 3          3 4 2
+--R                                1048576a c  - 1048576a b c  + 393216a b c
+--R                              + 
+--R                                        2 6           8
+--R                                - 65536a b c + 4096a b
+--R                        ,
+--R                            4
+--R                      *
+--R                         cos
+--R                              atan
+--R                                           3 2        2 2          4
+--R                                     (4096a c  - 2048a b c + 256a b )
+--R                                  *
+--R                                     ROOT
+--R                                          1
+--R                                       /
+--R                                                    5 3           4 2 2
+--R                                            4194304a c  - 3145728a b c
+--R                                          + 
+--R                                                   3 4          2 6
+--R                                            786432a b c - 65536a b
+--R                                /
+--R                                   b
+--R                           /
+--R                              2
+--R                  *
+--R                     ROOT
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              sin
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                        + 
+--R                            4
+--R                         *
+--R                              ROOT
+--R                                   c
+--R                                /
+--R                                             5 4           4 2 3          3 4 2
+--R                                     1048576a c  - 1048576a b c  + 393216a b c
+--R                                   + 
+--R                                             2 6           8
+--R                                     - 65536a b c + 4096a b
+--R                             ,
+--R                                 4
+--R                           **
+--R                              2
+--R                         *
+--R                              cos
+--R                                   atan
+--R                                                3 2        2 2          4
+--R                                          (4096a c  - 2048a b c + 256a b )
+--R                                       *
+--R                                          ROOT
+--R                                               1
+--R                                            /
+--R                                                         5 3           4 2 2
+--R                                                 4194304a c  - 3145728a b c
+--R                                               + 
+--R                                                        3 4          2 6
+--R                                                 786432a b c - 65536a b
+--R                                     /
+--R                                        b
+--R                                /
+--R                                   2
+--R                           **
+--R                              2
+--R                    ,
+--R                        4
+--R                  *
+--R                     cos
+--R                          atan
+--R                               sin
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                            /
+--R                               cos
+--R                                    atan
+--R                                                 3 2        2 2          4
+--R                                           (4096a c  - 2048a b c + 256a b )
+--R                                        *
+--R                                           ROOT
+--R                                                1
+--R                                             /
+--R                                                          5 3           4 2 2
+--R                                                  4194304a c  - 3145728a b c
+--R                                                + 
+--R                                                         3 4          2 6
+--R                                                  786432a b c - 65536a b
+--R                                      /
+--R                                         b
+--R                                 /
+--R                                    2
+--R                       /
+--R                          2
+--R                 + 
+--R                   c x
+--R     + 
+--R               +------------------+
+--R               | +-----------+                   4+-+4+-+
+--R          4+-+4| |          2                   x\|2 \|c
+--R       - 4\|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                          +--------------------+
+--R                                          |   +-----------+
+--R                                         4|   |          2
+--R                                         \|- \|- 4a c + b   - b
+--R     + 
+--R             +--------------------+
+--R             |   +-----------+                  4+-+4+-+
+--R        4+-+4|   |          2                  x\|2 \|c
+--R       4\|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                         4| |          2
+--R                                         \|\|- 4a c + b   - b
+--R     + 
+--R             +------------------+
+--R             | +-----------+                  4+-+4+-+
+--R        4+-+4| |          2                  x\|2 \|c
+--R       4\|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                       +--------------------+
+--R                                       |   +-----------+
+--R                                      4|   |          2
+--R                                      \|- \|- 4a c + b   - b
+--R     + 
+--R               +--------------------+
+--R               |   +-----------+                 4+-+4+-+
+--R          4+-+4|   |          2                 x\|2 \|c
+--R       - 4\|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R  /
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R      4+-+3 |          2 4|   |          2      4| |          2
+--R     4\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1199
+
+--S 1200 of 2282
+--d0:=normalize(D(m0,x))
+--E 1200
+
+)clear all
+
+--S 1201 of 2282
+t0:=1/(a+b*x^4+c*x^8)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1201
+
+--S 1202 of 2282
+r0:=c^(3/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))/(2^(1/4)*_
+   (-b-sqrt(b^2-4*a*c))^(3/4)*sqrt(b^2-4*a*c))+c^(3/4)*atanh(2^(1/4)*_
+   c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))/(2^(1/4)*(-b-sqrt(b^2-_
+   4*a*c))^(3/4)*sqrt(b^2-4*a*c))-c^(3/4)*atan(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))/(2^(1/4)*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(3/4))-c^(3/4)*atanh(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))/(2^(1/4)*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R              +------------------+3
+--R              | +-----------+                    4+-+4+-+
+--R       4+-+3 4| |          2                    x\|2 \|c
+--R       \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                          +--------------------+
+--R                                          |   +-----------+
+--R                                         4|   |          2
+--R                                         \|- \|- 4a c + b   - b
+--R     + 
+--R                +--------------------+3
+--R                |   +-----------+                   4+-+4+-+
+--R         4+-+3 4|   |          2                   x\|2 \|c
+--R       - \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R              +------------------+3
+--R              | +-----------+                   4+-+4+-+
+--R       4+-+3 4| |          2                   x\|2 \|c
+--R       \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R                +--------------------+3
+--R                |   +-----------+                  4+-+4+-+
+--R         4+-+3 4|   |          2                  x\|2 \|c
+--R       - \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R  /
+--R                        +--------------------+3  +------------------+3
+--R          +-----------+ |   +-----------+        | +-----------+
+--R     4+-+ |          2 4|   |          2        4| |          2
+--R     \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1202
+
+--S 1203 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 2        4 2        3 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        5 2        4 2        3 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                          5   2        4 3        3 5
+--R                    (4096a b c  - 2048a b c + 256a b )
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |                    2 2       2     4
+--R                     |                 - a c  + 2a b c - b
+--R                     |-----------------------------------------------------
+--R                     |        9 3           8 2 2          7 4          6 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                + 
+--R                    2 2       2     4
+--R                  4a c  - 5a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 2        4 2        3 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             9 3           8 2 2          7 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               5 2        4 2        3 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                  2    2
+--R              (a c  - b c)x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 2        4 2        3 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                    2 2       2     4
+--R                         |                 - a c  + 2a b c - b
+--R                         |-----------------------------------------------------
+--R                         |        9 3           8 2 2          7 4          6 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           5 2        4 2        3 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                             5   2        4 3        3 5
+--R                       (4096a b c  - 2048a b c + 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                         2 2       2     4
+--R                     - 4a c  + 5a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 2        4 2        3 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                9 3           8 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4          6 6
+--R                                        786432a b c - 65536a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  5 2        4 2        3 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                     2    2
+--R                 (a c  - b c)x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               5 2        4 2        3 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        5 2        4 2        3 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                            5   2        4 3        3 5
+--R                    (- 4096a b c  + 2048a b c - 256a b )
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |                    2 2       2     4
+--R                     |                 - a c  + 2a b c - b
+--R                     |-----------------------------------------------------
+--R                     |        9 3           8 2 2          7 4          6 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                + 
+--R                    2 2       2     4
+--R                  4a c  - 5a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      5 2        4 2        3 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             9 3           8 2 2          7 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               5 2        4 2        3 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                  2    2
+--R              (a c  - b c)x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                5 2        4 2        3 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                    2 2       2     4
+--R                         |                 - a c  + 2a b c - b
+--R                         |-----------------------------------------------------
+--R                         |        9 3           8 2 2          7 4          6 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           5 2        4 2        3 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                               5   2        4 3        3 5
+--R                       (- 4096a b c  + 2048a b c - 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                         2 2       2     4
+--R                     - 4a c  + 5a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       5 2        4 2        3 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                9 3           8 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4          6 6
+--R                                        786432a b c - 65536a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  5 2        4 2        3 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                     2    2
+--R                 (a c  - b c)x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 2        4 2        3 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        5 2        4 2        3 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                  2 2
+--R                4a c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 2        4 2        3 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             9 3           8 2 2          7 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               5 2        4 2        3 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                            5 2 2        4 4        3 6
+--R                      (4096a b c  - 2048a b c + 256a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                    2 2       2     4
+--R                       |                 - a c  + 2a b c - b
+--R                       |-----------------------------------------------------
+--R                       |        9 3           8 2 2          7 4          6 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                  + 
+--R                          3     5
+--R                    - 5a b c + b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      5 2        4 2        3 4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                        2 2       2     4
+--R                                     - a c  + 2a b c - b
+--R                                  /
+--R                                               9 3           8 2 2          7 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               6 6
+--R                                       - 65536a b
+--R                            + 
+--R                                        3
+--R                              3a b c - b
+--R                         /
+--R                                 5 2        4 2        3 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                      2    2
+--R                (- a c  + b c)x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                5 2        4 2        3 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                    2 2       2     4
+--R                         |                 - a c  + 2a b c - b
+--R                         |-----------------------------------------------------
+--R                         |        9 3           8 2 2          7 4          6 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           5 2        4 2        3 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                     2 2
+--R                   4a c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       5 2        4 2        3 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                9 3           8 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4          6 6
+--R                                        786432a b c - 65536a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  5 2        4 2        3 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                               5 2 2        4 4        3 6
+--R                         (4096a b c  - 2048a b c + 256a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                     + 
+--R                             3     5
+--R                       - 5a b c + b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         5 2        4 2        3 4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                           2 2       2     4
+--R                                        - a c  + 2a b c - b
+--R                                     /
+--R                                                  9 3           8 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 7 4          6 6
+--R                                          786432a b c - 65536a b
+--R                               + 
+--R                                           3
+--R                                 3a b c - b
+--R                            /
+--R                                    5 2        4 2        3 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                       2    2
+--R                   (a c  - b c)x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               5 2        4 2        3 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        5 2        4 2        3 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                  2 2
+--R                4a c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      5 2        4 2        3 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             9 3           8 2 2          7 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               5 2        4 2        3 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                            5 2 2        4 4        3 6
+--R                      (4096a b c  - 2048a b c + 256a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                    2 2       2     4
+--R                       |                 - a c  + 2a b c - b
+--R                       |-----------------------------------------------------
+--R                       |        9 3           8 2 2          7 4          6 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                  + 
+--R                        3     5
+--R                    5a b c - b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                        5 2        4 2        3 4
+--R                                (- 4096a c  + 2048a b c - 256a b )
+--R                             *
+--R                                ROOT
+--R                                        2 2       2     4
+--R                                     - a c  + 2a b c - b
+--R                                  /
+--R                                               9 3           8 2 2          7 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               6 6
+--R                                       - 65536a b
+--R                            + 
+--R                                        3
+--R                              3a b c - b
+--R                         /
+--R                                 5 2        4 2        3 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                      2    2
+--R                (- a c  + b c)x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 2        4 2        3 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                    2 2       2     4
+--R                         |                 - a c  + 2a b c - b
+--R                         |-----------------------------------------------------
+--R                         |        9 3           8 2 2          7 4          6 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           5 2        4 2        3 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                     2 2
+--R                   4a c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 2        4 2        3 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                9 3           8 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4          6 6
+--R                                        786432a b c - 65536a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  5 2        4 2        3 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                               5 2 2        4 4        3 6
+--R                         (4096a b c  - 2048a b c + 256a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                     + 
+--R                           3     5
+--R                       5a b c - b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                           5 2        4 2        3 4
+--R                                   (- 4096a c  + 2048a b c - 256a b )
+--R                                *
+--R                                   ROOT
+--R                                           2 2       2     4
+--R                                        - a c  + 2a b c - b
+--R                                     /
+--R                                                  9 3           8 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 7 4          6 6
+--R                                          786432a b c - 65536a b
+--R                               + 
+--R                                           3
+--R                                 3a b c - b
+--R                            /
+--R                                    5 2        4 2        3 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                       2    2
+--R                   (a c  - b c)x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1203
+
+--S 1204 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            +--------------------+3  +------------------+3
+--R              +-----------+ |   +-----------+        | +-----------+
+--R         4+-+ |          2 4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 2        4 2        3 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        5 2        4 2        3 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                          5   2        4 3        3 5
+--R                    (4096a b c  - 2048a b c + 256a b )
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |                    2 2       2     4
+--R                     |                 - a c  + 2a b c - b
+--R                     |-----------------------------------------------------
+--R                     |        9 3           8 2 2          7 4          6 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                + 
+--R                    2 2       2     4
+--R                  4a c  - 5a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 2        4 2        3 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             9 3           8 2 2          7 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               5 2        4 2        3 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                  2    2
+--R              (a c  - b c)x
+--R     + 
+--R       -
+--R                               +--------------------+3  +------------------+3
+--R                 +-----------+ |   +-----------+        | +-----------+
+--R            4+-+ |          2 4|   |          2        4| |          2
+--R            \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 2        4 2        3 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                    2 2       2     4
+--R                         |                 - a c  + 2a b c - b
+--R                         |-----------------------------------------------------
+--R                         |        9 3           8 2 2          7 4          6 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           5 2        4 2        3 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                             5   2        4 3        3 5
+--R                       (4096a b c  - 2048a b c + 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                         2 2       2     4
+--R                     - 4a c  + 5a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 2        4 2        3 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                9 3           8 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4          6 6
+--R                                        786432a b c - 65536a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  5 2        4 2        3 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                     2    2
+--R                 (a c  - b c)x
+--R     + 
+--R                            +--------------------+3  +------------------+3
+--R              +-----------+ |   +-----------+        | +-----------+
+--R         4+-+ |          2 4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               5 2        4 2        3 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        5 2        4 2        3 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                            5   2        4 3        3 5
+--R                    (- 4096a b c  + 2048a b c - 256a b )
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |                    2 2       2     4
+--R                     |                 - a c  + 2a b c - b
+--R                     |-----------------------------------------------------
+--R                     |        9 3           8 2 2          7 4          6 6
+--R                    \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                + 
+--R                    2 2       2     4
+--R                  4a c  - 5a b c + b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      5 2        4 2        3 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             9 3           8 2 2          7 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               5 2        4 2        3 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                  2    2
+--R              (a c  - b c)x
+--R     + 
+--R       -
+--R                               +--------------------+3  +------------------+3
+--R                 +-----------+ |   +-----------+        | +-----------+
+--R            4+-+ |          2 4|   |          2        4| |          2
+--R            \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                5 2        4 2        3 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                    2 2       2     4
+--R                         |                 - a c  + 2a b c - b
+--R                         |-----------------------------------------------------
+--R                         |        9 3           8 2 2          7 4          6 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           5 2        4 2        3 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                               5   2        4 3        3 5
+--R                       (- 4096a b c  + 2048a b c - 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                         2 2       2     4
+--R                     - 4a c  + 5a b c - b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       5 2        4 2        3 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                9 3           8 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4          6 6
+--R                                        786432a b c - 65536a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  5 2        4 2        3 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                     2    2
+--R                 (a c  - b c)x
+--R     + 
+--R                            +--------------------+3  +------------------+3
+--R              +-----------+ |   +-----------+        | +-----------+
+--R         4+-+ |          2 4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 2        4 2        3 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        5 2        4 2        3 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                  2 2
+--R                4a c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 2        4 2        3 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             9 3           8 2 2          7 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               5 2        4 2        3 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                            5 2 2        4 4        3 6
+--R                      (4096a b c  - 2048a b c + 256a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                    2 2       2     4
+--R                       |                 - a c  + 2a b c - b
+--R                       |-----------------------------------------------------
+--R                       |        9 3           8 2 2          7 4          6 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                  + 
+--R                          3     5
+--R                    - 5a b c + b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      5 2        4 2        3 4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                        2 2       2     4
+--R                                     - a c  + 2a b c - b
+--R                                  /
+--R                                               9 3           8 2 2          7 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               6 6
+--R                                       - 65536a b
+--R                            + 
+--R                                        3
+--R                              3a b c - b
+--R                         /
+--R                                 5 2        4 2        3 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                      2    2
+--R                (- a c  + b c)x
+--R     + 
+--R       -
+--R                               +--------------------+3  +------------------+3
+--R                 +-----------+ |   +-----------+        | +-----------+
+--R            4+-+ |          2 4|   |          2        4| |          2
+--R            \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                5 2        4 2        3 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                    2 2       2     4
+--R                         |                 - a c  + 2a b c - b
+--R                         |-----------------------------------------------------
+--R                         |        9 3           8 2 2          7 4          6 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           5 2        4 2        3 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                     2 2
+--R                   4a c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       5 2        4 2        3 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                9 3           8 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4          6 6
+--R                                        786432a b c - 65536a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  5 2        4 2        3 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                               5 2 2        4 4        3 6
+--R                         (4096a b c  - 2048a b c + 256a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                     + 
+--R                             3     5
+--R                       - 5a b c + b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         5 2        4 2        3 4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                           2 2       2     4
+--R                                        - a c  + 2a b c - b
+--R                                     /
+--R                                                  9 3           8 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 7 4          6 6
+--R                                          786432a b c - 65536a b
+--R                               + 
+--R                                           3
+--R                                 3a b c - b
+--R                            /
+--R                                    5 2        4 2        3 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                       2    2
+--R                   (a c  - b c)x
+--R     + 
+--R                            +--------------------+3  +------------------+3
+--R              +-----------+ |   +-----------+        | +-----------+
+--R         4+-+ |          2 4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               5 2        4 2        3 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                   + 
+--R                               3
+--R                     3a b c - b
+--R                /
+--R                        5 2        4 2        3 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                  2 2
+--R                4a c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      5 2        4 2        3 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                      2 2       2     4
+--R                                   - a c  + 2a b c - b
+--R                                /
+--R                                             9 3           8 2 2          7 4
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6
+--R                                     - 65536a b
+--R                          + 
+--R                                      3
+--R                            3a b c - b
+--R                       /
+--R                               5 2        4 2        3 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                            5 2 2        4 4        3 6
+--R                      (4096a b c  - 2048a b c + 256a b )
+--R                   *
+--R                       +-----------------------------------------------------+
+--R                       |                    2 2       2     4
+--R                       |                 - a c  + 2a b c - b
+--R                       |-----------------------------------------------------
+--R                       |        9 3           8 2 2          7 4          6 6
+--R                      \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                  + 
+--R                        3     5
+--R                    5a b c - b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                        5 2        4 2        3 4
+--R                                (- 4096a c  + 2048a b c - 256a b )
+--R                             *
+--R                                ROOT
+--R                                        2 2       2     4
+--R                                     - a c  + 2a b c - b
+--R                                  /
+--R                                               9 3           8 2 2          7 4
+--R                                       4194304a c  - 3145728a b c  + 786432a b c
+--R                                     + 
+--R                                               6 6
+--R                                       - 65536a b
+--R                            + 
+--R                                        3
+--R                              3a b c - b
+--R                         /
+--R                                 5 2        4 2        3 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                      2    2
+--R                (- a c  + b c)x
+--R     + 
+--R       -
+--R                               +--------------------+3  +------------------+3
+--R                 +-----------+ |   +-----------+        | +-----------+
+--R            4+-+ |          2 4|   |          2        4| |          2
+--R            \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 2        4 2        3 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                         +-----------------------------------------------------+
+--R                         |                    2 2       2     4
+--R                         |                 - a c  + 2a b c - b
+--R                         |-----------------------------------------------------
+--R                         |        9 3           8 2 2          7 4          6 6
+--R                        \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                      + 
+--R                                  3
+--R                        3a b c - b
+--R                   /
+--R                           5 2        4 2        3 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                     2 2
+--R                   4a c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 2        4 2        3 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         2 2       2     4
+--R                                      - a c  + 2a b c - b
+--R                                   /
+--R                                                9 3           8 2 2
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4          6 6
+--R                                        786432a b c - 65536a b
+--R                             + 
+--R                                         3
+--R                               3a b c - b
+--R                          /
+--R                                  5 2        4 2        3 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                               5 2 2        4 4        3 6
+--R                         (4096a b c  - 2048a b c + 256a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |                    2 2       2     4
+--R                        |                 - a c  + 2a b c - b
+--R                        |-----------------------------------------------------
+--R                        |        9 3           8 2 2          7 4          6 6
+--R                       \|4194304a c  - 3145728a b c  + 786432a b c - 65536a b
+--R                     + 
+--R                           3     5
+--R                       5a b c - b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                           5 2        4 2        3 4
+--R                                   (- 4096a c  + 2048a b c - 256a b )
+--R                                *
+--R                                   ROOT
+--R                                           2 2       2     4
+--R                                        - a c  + 2a b c - b
+--R                                     /
+--R                                                  9 3           8 2 2
+--R                                          4194304a c  - 3145728a b c
+--R                                        + 
+--R                                                 7 4          6 6
+--R                                          786432a b c - 65536a b
+--R                               + 
+--R                                           3
+--R                                 3a b c - b
+--R                            /
+--R                                    5 2        4 2        3 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                       2    2
+--R                   (a c  - b c)x
+--R     + 
+--R                 +------------------+3
+--R                 | +-----------+                    4+-+4+-+
+--R          4+-+3 4| |          2                    x\|2 \|c
+--R       - 2\|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                             +--------------------+
+--R                                             |   +-----------+
+--R                                            4|   |          2
+--R                                            \|- \|- 4a c + b   - b
+--R     + 
+--R               +--------------------+3
+--R               |   +-----------+                   4+-+4+-+
+--R        4+-+3 4|   |          2                   x\|2 \|c
+--R       2\|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R     + 
+--R                 +------------------+3
+--R                 | +-----------+                   4+-+4+-+
+--R          4+-+3 4| |          2                   x\|2 \|c
+--R       - 2\|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R               +--------------------+3
+--R               |   +-----------+                  4+-+4+-+
+--R        4+-+3 4|   |          2                  x\|2 \|c
+--R       2\|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                            +------------------+
+--R                                            | +-----------+
+--R                                           4| |          2
+--R                                           \|\|- 4a c + b   - b
+--R  /
+--R                         +--------------------+3  +------------------+3
+--R           +-----------+ |   +-----------+        | +-----------+
+--R      4+-+ |          2 4|   |          2        4| |          2
+--R     2\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1204
+
+--S 1205 of 2282
+--d0:=normalize(D(m0,x))
+--E 1205
+
+)clear all
+
+--S 1206 of 2282
+t0:=1/(x^2*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R           10      6      2
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1206
+
+--S 1207 of 2282
+r0:=(-1)/(a*x)-1/2*c^(1/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+1/2*c^(1/4)*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(3/4)*a*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-1/2*c^(1/4)*atan(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(1/4))+1/2*c^(1/4)*atanh(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                     +------------------+
+--R            +-----------+            | +-----------+
+--R            |          2        4+-+4| |          2
+--R         (x\|- 4a c + b   - b x)\|c \|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                     +--------------------+
+--R            +-----------+            |   +-----------+
+--R            |          2        4+-+4|   |          2
+--R         (x\|- 4a c + b   + b x)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                       +------------------+
+--R              +-----------+            | +-----------+
+--R              |          2        4+-+4| |          2
+--R         (- x\|- 4a c + b   + b x)\|c \|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                       +--------------------+
+--R              +-----------+            |   +-----------+
+--R              |          2        4+-+4|   |          2
+--R         (- x\|- 4a c + b   - b x)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R       - 2\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R     2a x \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1207
+
+--S 1208 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                7 2        6 2        5 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                                10 5          9 2 4          8 4 3
+--R                         262144a  c  - 720896a b c  + 573440a b c
+--R                       + 
+--R                                  7 6 2         6 8         5 10
+--R                         - 200704a b c  + 32768a b c - 2048a b
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         5   5        4 3 4        3 5 3       2 7 2         9
+--R                     256a b c  - 1024a b c  + 1104a b c  - 504a b c  + 104a b c
+--R                   + 
+--R                         11
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                  7 2        6 2        5 4
+--R                            (4096a c  - 2048a b c + 256a b )
+--R                         *
+--R                            ROOT
+--R                                    4 4     3 2 3      2 4 2       6     8
+--R                                 - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       7 2        6 2        5 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                   2 6       2 5    4 4
+--R                 (a c  - 3a b c  + b c )x
+--R     + 
+--R         a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               7 2        6 2        5 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                             10 5          9 2 4          8 4 3          7 6 2
+--R                      262144a  c  - 720896a b c  + 573440a b c  - 200704a b c
+--R                    + 
+--R                            6 8         5 10
+--R                      32768a b c - 2048a b
+--R                 *
+--R                   +---------------------------------------------------------+
+--R                   |           4 4     3 2 3      2 4 2       6     8
+--R                   |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |---------------------------------------------------------
+--R                   |        13 3           12 2 2          11 4          10 6
+--R                  \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                + 
+--R                        5   5        4 3 4        3 5 3       2 7 2         9
+--R                  - 256a b c  + 1024a b c  - 1104a b c  + 504a b c  - 104a b c
+--R                + 
+--R                    11
+--R                  8b
+--R             *
+--R                ROOT
+--R                                 7 2        6 2        5 4
+--R                         (- 4096a c  + 2048a b c - 256a b )
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                2 6       2 5    4 4
+--R              (a c  - 3a b c  + b c )x
+--R     + 
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  7 2        6 2        5 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                                  10 5          9 2 4          8 4 3
+--R                         - 262144a  c  + 720896a b c  - 573440a b c
+--R                       + 
+--R                                7 6 2         6 8         5 10
+--R                         200704a b c  - 32768a b c + 2048a b
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         5   5        4 3 4        3 5 3       2 7 2         9
+--R                     256a b c  - 1024a b c  + 1104a b c  - 504a b c  + 104a b c
+--R                   + 
+--R                         11
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                    7 2        6 2        5 4
+--R                            (- 4096a c  + 2048a b c - 256a b )
+--R                         *
+--R                            ROOT
+--R                                    4 4     3 2 3      2 4 2       6     8
+--R                                 - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         7 2        6 2        5 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                   2 6       2 5    4 4
+--R                 (a c  - 3a b c  + b c )x
+--R     + 
+--R         a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2        6 2        5 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                               10 5          9 2 4          8 4 3          7 6 2
+--R                      - 262144a  c  + 720896a b c  - 573440a b c  + 200704a b c
+--R                    + 
+--R                              6 8         5 10
+--R                      - 32768a b c + 2048a b
+--R                 *
+--R                   +---------------------------------------------------------+
+--R                   |           4 4     3 2 3      2 4 2       6     8
+--R                   |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |---------------------------------------------------------
+--R                   |        13 3           12 2 2          11 4          10 6
+--R                  \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                + 
+--R                        5   5        4 3 4        3 5 3       2 7 2         9
+--R                  - 256a b c  + 1024a b c  - 1104a b c  + 504a b c  - 104a b c
+--R                + 
+--R                    11
+--R                  8b
+--R             *
+--R                ROOT
+--R                               7 2        6 2        5 4
+--R                         (4096a c  - 2048a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                2 6       2 5    4 4
+--R              (a c  - 3a b c  + b c )x
+--R     + 
+--R         a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2        6 2        5 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                       10 5
+--R                262144a  c
+--R             *
+--R                 +---------------------------------------------------------+
+--R                 |           4 4     3 2 3      2 4 2       6     8
+--R                 |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                 |---------------------------------------------------------
+--R                 |        13 3           12 2 2          11 4          10 6
+--R                \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R             *
+--R                ROOT
+--R                               7 2        6 2        5 4
+--R                         (4096a c  - 2048a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                               9 3 4          8 5 3          7 7 2         6 9
+--R                        720896a b c  - 573440a b c  + 200704a b c  - 32768a b c
+--R                      + 
+--R                             5 11
+--R                        2048a b
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |           4 4     3 2 3      2 4 2       6     8
+--R                     |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |---------------------------------------------------------
+--R                     |        13 3           12 2 2          11 4          10 6
+--R                    \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                  + 
+--R                          5 2 5        4 4 4        3 6 3       2 8 2
+--R                    - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                  + 
+--R                            10      12
+--R                    - 104a b  c + 8b
+--R               *
+--R                  ROOT
+--R                                 7 2        6 2        5 4
+--R                           (4096a c  - 2048a b c + 256a b )
+--R                        *
+--R                           ROOT
+--R                                   4 4     3 2 3      2 4 2       6     8
+--R                                - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             /
+--R                                          13 3           12 2 2          11 4
+--R                                  4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                + 
+--R                                          10 6
+--R                                  - 65536a  b
+--R                       + 
+--R                             2   2       3     5
+--R                         - 5a b c  + 5a b c - b
+--R                    /
+--R                            7 2        6 2        5 4
+--R                       2048a c  - 1024a b c + 128a b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      7 2        6 2        5 4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                        4 4     3 2 3      2 4 2       6     8
+--R                                     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                  /
+--R                                               13 3           12 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              11 4          10 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                  2   2       3     5
+--R                              - 5a b c  + 5a b c - b
+--R                         /
+--R                                 7 2        6 2        5 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                    2 6       2 5    4 4
+--R                (- a c  + 3a b c  - b c )x
+--R     + 
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                7 2        6 2        5 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                          10 5
+--R                   262144a  c
+--R                *
+--R                    +---------------------------------------------------------+
+--R                    |           4 4     3 2 3      2 4 2       6     8
+--R                    |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                    |---------------------------------------------------------
+--R                    |        13 3           12 2 2          11 4          10 6
+--R                   \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                *
+--R                   ROOT
+--R                                  7 2        6 2        5 4
+--R                            (4096a c  - 2048a b c + 256a b )
+--R                         *
+--R                            ROOT
+--R                                    4 4     3 2 3      2 4 2       6     8
+--R                                 - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       7 2        6 2        5 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                  9 3 4          8 5 3          7 7 2
+--R                           720896a b c  - 573440a b c  + 200704a b c
+--R                         + 
+--R                                   6 9         5 11
+--R                           - 32768a b c + 2048a b
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                             5 2 5        4 4 4        3 6 3       2 8 2
+--R                       - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                     + 
+--R                               10      12
+--R                       - 104a b  c + 8b
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         7 2        6 2        5 4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             4 4     3 2 3      2 4 2       6
+--R                                          - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                        + 
+--R                                             8
+--R                                          - b
+--R                                     /
+--R                                                  13 3           12 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 11 4          10 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                     2   2       3     5
+--R                                 - 5a b c  + 5a b c - b
+--R                            /
+--R                                    7 2        6 2        5 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                     2 6       2 5    4 4
+--R                   (a c  - 3a b c  + b c )x
+--R     + 
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  7 2        6 2        5 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                          10 5
+--R                   262144a  c
+--R                *
+--R                    +---------------------------------------------------------+
+--R                    |           4 4     3 2 3      2 4 2       6     8
+--R                    |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                    |---------------------------------------------------------
+--R                    |        13 3           12 2 2          11 4          10 6
+--R                   \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                *
+--R                   ROOT
+--R                                    7 2        6 2        5 4
+--R                            (- 4096a c  + 2048a b c - 256a b )
+--R                         *
+--R                            ROOT
+--R                                    4 4     3 2 3      2 4 2       6     8
+--R                                 - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         7 2        6 2        5 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                  9 3 4          8 5 3          7 7 2
+--R                           720896a b c  - 573440a b c  + 200704a b c
+--R                         + 
+--R                                   6 9         5 11
+--R                           - 32768a b c + 2048a b
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                           5 2 5        4 4 4        3 6 3       2 8 2
+--R                       256a b c  - 1024a b c  + 1104a b c  - 504a b c
+--R                     + 
+--R                             10      12
+--R                       104a b  c - 8b
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                           7 2        6 2        5 4
+--R                                   (- 4096a c  + 2048a b c - 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             4 4     3 2 3      2 4 2       6
+--R                                          - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                        + 
+--R                                             8
+--R                                          - b
+--R                                     /
+--R                                                  13 3           12 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 11 4          10 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                     2   2       3     5
+--R                                 - 5a b c  + 5a b c - b
+--R                            /
+--R                                    7 2        6 2        5 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                       2 6       2 5    4 4
+--R                   (- a c  + 3a b c  - b c )x
+--R     + 
+--R         a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               7 2        6 2        5 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                       10 5
+--R                262144a  c
+--R             *
+--R                 +---------------------------------------------------------+
+--R                 |           4 4     3 2 3      2 4 2       6     8
+--R                 |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                 |---------------------------------------------------------
+--R                 |        13 3           12 2 2          11 4          10 6
+--R                \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R             *
+--R                ROOT
+--R                                 7 2        6 2        5 4
+--R                         (- 4096a c  + 2048a b c - 256a b )
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                               9 3 4          8 5 3          7 7 2         6 9
+--R                        720896a b c  - 573440a b c  + 200704a b c  - 32768a b c
+--R                      + 
+--R                             5 11
+--R                        2048a b
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |           4 4     3 2 3      2 4 2       6     8
+--R                     |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |---------------------------------------------------------
+--R                     |        13 3           12 2 2          11 4          10 6
+--R                    \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                  + 
+--R                        5 2 5        4 4 4        3 6 3       2 8 2         10
+--R                    256a b c  - 1024a b c  + 1104a b c  - 504a b c  + 104a b  c
+--R                  + 
+--R                        12
+--R                    - 8b
+--R               *
+--R                  ROOT
+--R                                   7 2        6 2        5 4
+--R                           (- 4096a c  + 2048a b c - 256a b )
+--R                        *
+--R                           ROOT
+--R                                   4 4     3 2 3      2 4 2       6     8
+--R                                - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             /
+--R                                          13 3           12 2 2          11 4
+--R                                  4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                + 
+--R                                          10 6
+--R                                  - 65536a  b
+--R                       + 
+--R                             2   2       3     5
+--R                         - 5a b c  + 5a b c - b
+--R                    /
+--R                            7 2        6 2        5 4
+--R                       2048a c  - 1024a b c + 128a b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                        7 2        6 2        5 4
+--R                                (- 4096a c  + 2048a b c - 256a b )
+--R                             *
+--R                                ROOT
+--R                                        4 4     3 2 3      2 4 2       6     8
+--R                                     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                  /
+--R                                               13 3           12 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              11 4          10 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                  2   2       3     5
+--R                              - 5a b c  + 5a b c - b
+--R                         /
+--R                                 7 2        6 2        5 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                  2 6       2 5    4 4
+--R                (a c  - 3a b c  + b c )x
+--R     + 
+--R       - 2
+--R  /
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1208
+
+--S 1209 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              4+-+3 |          2 4|   |          2      4| |          2
+--R            a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                7 2        6 2        5 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                                10 5          9 2 4          8 4 3
+--R                         262144a  c  - 720896a b c  + 573440a b c
+--R                       + 
+--R                                  7 6 2         6 8         5 10
+--R                         - 200704a b c  + 32768a b c - 2048a b
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         5   5        4 3 4        3 5 3       2 7 2         9
+--R                     256a b c  - 1024a b c  + 1104a b c  - 504a b c  + 104a b c
+--R                   + 
+--R                         11
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                  7 2        6 2        5 4
+--R                            (4096a c  - 2048a b c + 256a b )
+--R                         *
+--R                            ROOT
+--R                                    4 4     3 2 3      2 4 2       6     8
+--R                                 - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       7 2        6 2        5 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                   2 6       2 5    4 4
+--R                 (a c  - 3a b c  + b c )x
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4|   |          2      4| |          2
+--R         a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               7 2        6 2        5 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                             10 5          9 2 4          8 4 3          7 6 2
+--R                      262144a  c  - 720896a b c  + 573440a b c  - 200704a b c
+--R                    + 
+--R                            6 8         5 10
+--R                      32768a b c - 2048a b
+--R                 *
+--R                   +---------------------------------------------------------+
+--R                   |           4 4     3 2 3      2 4 2       6     8
+--R                   |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |---------------------------------------------------------
+--R                   |        13 3           12 2 2          11 4          10 6
+--R                  \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                + 
+--R                        5   5        4 3 4        3 5 3       2 7 2         9
+--R                  - 256a b c  + 1024a b c  - 1104a b c  + 504a b c  - 104a b c
+--R                + 
+--R                    11
+--R                  8b
+--R             *
+--R                ROOT
+--R                                 7 2        6 2        5 4
+--R                         (- 4096a c  + 2048a b c - 256a b )
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                2 6       2 5    4 4
+--R              (a c  - 3a b c  + b c )x
+--R     + 
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              4+-+3 |          2 4|   |          2      4| |          2
+--R            a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  7 2        6 2        5 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                                  10 5          9 2 4          8 4 3
+--R                         - 262144a  c  + 720896a b c  - 573440a b c
+--R                       + 
+--R                                7 6 2         6 8         5 10
+--R                         200704a b c  - 32768a b c + 2048a b
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         5   5        4 3 4        3 5 3       2 7 2         9
+--R                     256a b c  - 1024a b c  + 1104a b c  - 504a b c  + 104a b c
+--R                   + 
+--R                         11
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                    7 2        6 2        5 4
+--R                            (- 4096a c  + 2048a b c - 256a b )
+--R                         *
+--R                            ROOT
+--R                                    4 4     3 2 3      2 4 2       6     8
+--R                                 - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         7 2        6 2        5 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                   2 6       2 5    4 4
+--R                 (a c  - 3a b c  + b c )x
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4|   |          2      4| |          2
+--R         a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2        6 2        5 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                               10 5          9 2 4          8 4 3          7 6 2
+--R                      - 262144a  c  + 720896a b c  - 573440a b c  + 200704a b c
+--R                    + 
+--R                              6 8         5 10
+--R                      - 32768a b c + 2048a b
+--R                 *
+--R                   +---------------------------------------------------------+
+--R                   |           4 4     3 2 3      2 4 2       6     8
+--R                   |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   |---------------------------------------------------------
+--R                   |        13 3           12 2 2          11 4          10 6
+--R                  \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                + 
+--R                        5   5        4 3 4        3 5 3       2 7 2         9
+--R                  - 256a b c  + 1024a b c  - 1104a b c  + 504a b c  - 104a b c
+--R                + 
+--R                    11
+--R                  8b
+--R             *
+--R                ROOT
+--R                               7 2        6 2        5 4
+--R                         (4096a c  - 2048a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                2 6       2 5    4 4
+--R              (a c  - 3a b c  + b c )x
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4|   |          2      4| |          2
+--R         a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2        6 2        5 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                       10 5
+--R                262144a  c
+--R             *
+--R                 +---------------------------------------------------------+
+--R                 |           4 4     3 2 3      2 4 2       6     8
+--R                 |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                 |---------------------------------------------------------
+--R                 |        13 3           12 2 2          11 4          10 6
+--R                \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R             *
+--R                ROOT
+--R                               7 2        6 2        5 4
+--R                         (4096a c  - 2048a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                               9 3 4          8 5 3          7 7 2         6 9
+--R                        720896a b c  - 573440a b c  + 200704a b c  - 32768a b c
+--R                      + 
+--R                             5 11
+--R                        2048a b
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |           4 4     3 2 3      2 4 2       6     8
+--R                     |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |---------------------------------------------------------
+--R                     |        13 3           12 2 2          11 4          10 6
+--R                    \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                  + 
+--R                          5 2 5        4 4 4        3 6 3       2 8 2
+--R                    - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                  + 
+--R                            10      12
+--R                    - 104a b  c + 8b
+--R               *
+--R                  ROOT
+--R                                 7 2        6 2        5 4
+--R                           (4096a c  - 2048a b c + 256a b )
+--R                        *
+--R                           ROOT
+--R                                   4 4     3 2 3      2 4 2       6     8
+--R                                - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             /
+--R                                          13 3           12 2 2          11 4
+--R                                  4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                + 
+--R                                          10 6
+--R                                  - 65536a  b
+--R                       + 
+--R                             2   2       3     5
+--R                         - 5a b c  + 5a b c - b
+--R                    /
+--R                            7 2        6 2        5 4
+--R                       2048a c  - 1024a b c + 128a b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      7 2        6 2        5 4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                        4 4     3 2 3      2 4 2       6     8
+--R                                     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                  /
+--R                                               13 3           12 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              11 4          10 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                  2   2       3     5
+--R                              - 5a b c  + 5a b c - b
+--R                         /
+--R                                 7 2        6 2        5 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                    2 6       2 5    4 4
+--R                (- a c  + 3a b c  - b c )x
+--R     + 
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              4+-+3 |          2 4|   |          2      4| |          2
+--R            a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                7 2        6 2        5 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                          10 5
+--R                   262144a  c
+--R                *
+--R                    +---------------------------------------------------------+
+--R                    |           4 4     3 2 3      2 4 2       6     8
+--R                    |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                    |---------------------------------------------------------
+--R                    |        13 3           12 2 2          11 4          10 6
+--R                   \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                *
+--R                   ROOT
+--R                                  7 2        6 2        5 4
+--R                            (4096a c  - 2048a b c + 256a b )
+--R                         *
+--R                            ROOT
+--R                                    4 4     3 2 3      2 4 2       6     8
+--R                                 - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       7 2        6 2        5 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                  9 3 4          8 5 3          7 7 2
+--R                           720896a b c  - 573440a b c  + 200704a b c
+--R                         + 
+--R                                   6 9         5 11
+--R                           - 32768a b c + 2048a b
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                             5 2 5        4 4 4        3 6 3       2 8 2
+--R                       - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                     + 
+--R                               10      12
+--R                       - 104a b  c + 8b
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         7 2        6 2        5 4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             4 4     3 2 3      2 4 2       6
+--R                                          - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                        + 
+--R                                             8
+--R                                          - b
+--R                                     /
+--R                                                  13 3           12 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 11 4          10 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                     2   2       3     5
+--R                                 - 5a b c  + 5a b c - b
+--R                            /
+--R                                    7 2        6 2        5 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                     2 6       2 5    4 4
+--R                   (a c  - 3a b c  + b c )x
+--R     + 
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              4+-+3 |          2 4|   |          2      4| |          2
+--R            a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  7 2        6 2        5 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8
+--R                               - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                            2   2       3     5
+--R                        - 5a b c  + 5a b c - b
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                          10 5
+--R                   262144a  c
+--R                *
+--R                    +---------------------------------------------------------+
+--R                    |           4 4     3 2 3      2 4 2       6     8
+--R                    |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                    |---------------------------------------------------------
+--R                    |        13 3           12 2 2          11 4          10 6
+--R                   \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                *
+--R                   ROOT
+--R                                    7 2        6 2        5 4
+--R                            (- 4096a c  + 2048a b c - 256a b )
+--R                         *
+--R                            ROOT
+--R                                    4 4     3 2 3      2 4 2       6     8
+--R                                 - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                              2   2       3     5
+--R                          - 5a b c  + 5a b c - b
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         7 2        6 2        5 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                         4 4     3 2 3      2 4 2       6     8
+--R                                      - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                   2   2       3     5
+--R                               - 5a b c  + 5a b c - b
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                  9 3 4          8 5 3          7 7 2
+--R                           720896a b c  - 573440a b c  + 200704a b c
+--R                         + 
+--R                                   6 9         5 11
+--R                           - 32768a b c + 2048a b
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                           5 2 5        4 4 4        3 6 3       2 8 2
+--R                       256a b c  - 1024a b c  + 1104a b c  - 504a b c
+--R                     + 
+--R                             10      12
+--R                       104a b  c - 8b
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                           7 2        6 2        5 4
+--R                                   (- 4096a c  + 2048a b c - 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             4 4     3 2 3      2 4 2       6
+--R                                          - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                        + 
+--R                                             8
+--R                                          - b
+--R                                     /
+--R                                                  13 3           12 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 11 4          10 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                     2   2       3     5
+--R                                 - 5a b c  + 5a b c - b
+--R                            /
+--R                                    7 2        6 2        5 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                       2 6       2 5    4 4
+--R                   (- a c  + 3a b c  - b c )x
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4|   |          2      4| |          2
+--R         a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               7 2        6 2        5 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                               4 4     3 2 3      2 4 2       6     8
+--R                            - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                         2   2       3     5
+--R                     - 5a b c  + 5a b c - b
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                       10 5
+--R                262144a  c
+--R             *
+--R                 +---------------------------------------------------------+
+--R                 |           4 4     3 2 3      2 4 2       6     8
+--R                 |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                 |---------------------------------------------------------
+--R                 |        13 3           12 2 2          11 4          10 6
+--R                \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R             *
+--R                ROOT
+--R                                 7 2        6 2        5 4
+--R                         (- 4096a c  + 2048a b c - 256a b )
+--R                      *
+--R                         ROOT
+--R                                 4 4     3 2 3      2 4 2       6     8
+--R                              - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                           2   2       3     5
+--R                       - 5a b c  + 5a b c - b
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                      4 4     3 2 3      2 4 2       6     8
+--R                                   - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                                2   2       3     5
+--R                            - 5a b c  + 5a b c - b
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                               9 3 4          8 5 3          7 7 2         6 9
+--R                        720896a b c  - 573440a b c  + 200704a b c  - 32768a b c
+--R                      + 
+--R                             5 11
+--R                        2048a b
+--R                   *
+--R                     +---------------------------------------------------------+
+--R                     |           4 4     3 2 3      2 4 2       6     8
+--R                     |        - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |---------------------------------------------------------
+--R                     |        13 3           12 2 2          11 4          10 6
+--R                    \|4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R                  + 
+--R                        5 2 5        4 4 4        3 6 3       2 8 2         10
+--R                    256a b c  - 1024a b c  + 1104a b c  - 504a b c  + 104a b  c
+--R                  + 
+--R                        12
+--R                    - 8b
+--R               *
+--R                  ROOT
+--R                                   7 2        6 2        5 4
+--R                           (- 4096a c  + 2048a b c - 256a b )
+--R                        *
+--R                           ROOT
+--R                                   4 4     3 2 3      2 4 2       6     8
+--R                                - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             /
+--R                                          13 3           12 2 2          11 4
+--R                                  4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                + 
+--R                                          10 6
+--R                                  - 65536a  b
+--R                       + 
+--R                             2   2       3     5
+--R                         - 5a b c  + 5a b c - b
+--R                    /
+--R                            7 2        6 2        5 4
+--R                       2048a c  - 1024a b c + 128a b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                        7 2        6 2        5 4
+--R                                (- 4096a c  + 2048a b c - 256a b )
+--R                             *
+--R                                ROOT
+--R                                        4 4     3 2 3      2 4 2       6     8
+--R                                     - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                  /
+--R                                               13 3           12 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              11 4          10 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                  2   2       3     5
+--R                              - 5a b c  + 5a b c - b
+--R                         /
+--R                                 7 2        6 2        5 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                  2 6       2 5    4 4
+--R                (a c  - 3a b c  + b c )x
+--R     + 
+--R                                    +------------------+
+--R             +-----------+          | +-----------+
+--R             |          2      4+-+4| |          2
+--R         (- \|- 4a c + b   + b)\|c \|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                    +--------------------+
+--R             +-----------+          |   +-----------+
+--R             |          2      4+-+4|   |          2
+--R         (- \|- 4a c + b   - b)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                  +------------------+
+--R           +-----------+          | +-----------+
+--R           |          2      4+-+4| |          2
+--R         (\|- 4a c + b   - b)\|c \|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                              +--------------------+
+--R       +-----------+          |   +-----------+                 4+-+4+-+
+--R       |          2      4+-+4|   |          2                 x\|2 \|c
+--R     (\|- 4a c + b   + b)\|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                                          +------------------+
+--R                                                          | +-----------+
+--R                                                         4| |          2
+--R                                                         \|\|- 4a c + b   - b
+--R  /
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4|   |          2      4| |          2
+--R     2a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1209
+
+--S 1210 of 2282
+--d0:=normalize(D(m0,x))
+--E 1210
+
+)clear all
+
+--S 1211 of 2282
+t0:=1/(x^4*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R           12      8      4
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1211
+
+--S 1212 of 2282
+r0:=(-1/3)/(a*x^3)+1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b-sqrt(b^2-_
+   4*a*c))^(3/4))+1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(1/4)*a*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))+1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(3/4))+1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                           +------------------+3
+--R              +-----------+                | +-----------+
+--R            3 |          2        3 4+-+3 4| |          2
+--R         (3x \|- 4a c + b   - 3b x )\|c   \|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+3
+--R              +-----------+                |   +-----------+
+--R            3 |          2        3 4+-+3 4|   |          2
+--R         (3x \|- 4a c + b   + 3b x )\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                           +------------------+3
+--R              +-----------+                | +-----------+
+--R            3 |          2        3 4+-+3 4| |          2
+--R         (3x \|- 4a c + b   - 3b x )\|c   \|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+3
+--R              +-----------+                |   +-----------+
+--R            3 |          2        3 4+-+3 4|   |          2
+--R         (3x \|- 4a c + b   + 3b x )\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R       - 2\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+3  +------------------+3
+--R                +-----------+ |   +-----------+        | +-----------+
+--R         3 4+-+ |          2 4|   |          2        4| |          2
+--R     6a x  \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1212
+
+--S 1213 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3
+--R         3a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             9 2        8 2        7 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                          10 3        9 2 2        8 4        7 6
+--R                    (8192a  c  - 8192a b c  + 2560a b c - 256a b )
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                      4   4      3 3 3      2 5 2       7     9
+--R                  - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    9 2        8 2        7 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                3 5     2 2 4       4 3    6 2
+--R              (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R       -
+--R                3
+--R            3a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  9 2        8 2        7 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                             10 3        9 2 2        8 4        7 6
+--R                       (8192a  c  - 8192a b c  + 2560a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       4   4      3 3 3      2 5 2       7     9
+--R                     4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         9 2        8 2        7 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                   3 5     2 2 4       4 3    6 2
+--R                 (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R             3
+--R         3a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               9 2        8 2        7 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                            10 3        9 2 2        8 4        7 6
+--R                    (- 8192a  c  + 8192a b c  - 2560a b c + 256a b )
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                      4   4      3 3 3      2 5 2       7     9
+--R                  - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      9 2        8 2        7 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                3 5     2 2 4       4 3    6 2
+--R              (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R       -
+--R                3
+--R            3a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                9 2        8 2        7 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                               10 3        9 2 2        8 4        7 6
+--R                       (- 8192a  c  + 8192a b c  - 2560a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       4   4      3 3 3      2 5 2       7     9
+--R                     4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       9 2        8 2        7 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                   3 5     2 2 4       4 3    6 2
+--R                 (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R       -
+--R                3
+--R            3a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  9 2        8 2        7 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                        10 3
+--R                   8192a  c
+--R                *
+--R                   ROOT
+--R                             6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                          - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                        + 
+--R                               10     12
+--R                          10a b  c - b
+--R                     /
+--R                                  17 3           16 2 2          15 4
+--R                          4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                        + 
+--R                                  14 6
+--R                          - 65536a  b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         9 2        8 2        7 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                               9 3 2        8 5        7 7
+--R                         (8192a b c  - 2560a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                        17 3           16 2 2          15 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        14 6
+--R                                - 65536a  b
+--R                     + 
+--R                           4 2 4      3 4 3      2 6 2       8     10
+--R                       - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                           9 2        8 2        7 4
+--R                                   (- 4096a c  + 2048a b c - 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             6 6      5 2 5      4 4 4
+--R                                          - a c  + 12a b c  - 46a b c
+--R                                        + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                     /
+--R                                                  17 3           16 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 15 4          14 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                   3   3      2 3 2       5     7
+--R                                 7a b c  - 14a b c  + 7a b c - b
+--R                            /
+--R                                    9 2        8 2        7 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                       3 5     2 2 4       4 3    6 2
+--R                   (- a c  + 6a b c  - 5a b c  + b c )x
+--R     + 
+--R             3
+--R         3a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               9 2        8 2        7 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                     10 3
+--R                8192a  c
+--R             *
+--R                ROOT
+--R                          6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                       - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                     + 
+--R                            10     12
+--R                       10a b  c - b
+--R                  /
+--R                             17 3           16 2 2          15 4          14 6
+--R                     4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      9 2        8 2        7 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                            9 3 2        8 5        7 7
+--R                      (8192a b c  - 2560a b c + 256a b )
+--R                   *
+--R                      ROOT
+--R                                6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                             - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                           + 
+--R                                  10     12
+--R                             10a b  c - b
+--R                        /
+--R                                     17 3           16 2 2          15 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     14 6
+--R                             - 65536a  b
+--R                  + 
+--R                        4 2 4      3 4 3      2 6 2       8     10
+--R                    - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                        9 2        8 2        7 4
+--R                                (- 4096a c  + 2048a b c - 256a b )
+--R                             *
+--R                                ROOT
+--R                                          6 6      5 2 5      4 4 4      3 6 3
+--R                                       - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                     + 
+--R                                            2 8 2        10     12
+--R                                       - 37a b c  + 10a b  c - b
+--R                                  /
+--R                                               17 3           16 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              15 4          14 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                3   3      2 3 2       5     7
+--R                              7a b c  - 14a b c  + 7a b c - b
+--R                         /
+--R                                 9 2        8 2        7 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                  3 5     2 2 4       4 3    6 2
+--R                (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R             3
+--R         3a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             9 2        8 2        7 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                     10 3
+--R                8192a  c
+--R             *
+--R                ROOT
+--R                          6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                       - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                     + 
+--R                            10     12
+--R                       10a b  c - b
+--R                  /
+--R                             17 3           16 2 2          15 4          14 6
+--R                     4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    9 2        8 2        7 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                            9 3 2        8 5        7 7
+--R                      (8192a b c  - 2560a b c + 256a b )
+--R                   *
+--R                      ROOT
+--R                                6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                             - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                           + 
+--R                                  10     12
+--R                             10a b  c - b
+--R                        /
+--R                                     17 3           16 2 2          15 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     14 6
+--R                             - 65536a  b
+--R                  + 
+--R                      4 2 4      3 4 3      2 6 2       8     10
+--R                    4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      9 2        8 2        7 4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                          6 6      5 2 5      4 4 4      3 6 3
+--R                                       - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                     + 
+--R                                            2 8 2        10     12
+--R                                       - 37a b c  + 10a b  c - b
+--R                                  /
+--R                                               17 3           16 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              15 4          14 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                3   3      2 3 2       5     7
+--R                              7a b c  - 14a b c  + 7a b c - b
+--R                         /
+--R                                 9 2        8 2        7 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                    3 5     2 2 4       4 3    6 2
+--R                (- a c  + 6a b c  - 5a b c  + b c )x
+--R     + 
+--R       -
+--R                3
+--R            3a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                9 2        8 2        7 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                        10 3
+--R                   8192a  c
+--R                *
+--R                   ROOT
+--R                             6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                          - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                        + 
+--R                               10     12
+--R                          10a b  c - b
+--R                     /
+--R                                  17 3           16 2 2          15 4
+--R                          4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                        + 
+--R                                  14 6
+--R                          - 65536a  b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       9 2        8 2        7 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                               9 3 2        8 5        7 7
+--R                         (8192a b c  - 2560a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                        17 3           16 2 2          15 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        14 6
+--R                                - 65536a  b
+--R                     + 
+--R                         4 2 4      3 4 3      2 6 2       8     10
+--R                       4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         9 2        8 2        7 4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             6 6      5 2 5      4 4 4
+--R                                          - a c  + 12a b c  - 46a b c
+--R                                        + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                     /
+--R                                                  17 3           16 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 15 4          14 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                   3   3      2 3 2       5     7
+--R                                 7a b c  - 14a b c  + 7a b c - b
+--R                            /
+--R                                    9 2        8 2        7 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                     3 5     2 2 4       4 3    6 2
+--R                   (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R       - 2
+--R  /
+--R         3
+--R     6a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1213
+
+--S 1214 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             9 2        8 2        7 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                          10 3        9 2 2        8 4        7 6
+--R                    (8192a  c  - 8192a b c  + 2560a b c - 256a b )
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                      4   4      3 3 3      2 5 2       7     9
+--R                  - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    9 2        8 2        7 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                3 5     2 2 4       4 3    6 2
+--R              (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R       -
+--R                                +--------------------+3  +------------------+3
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             4+-+ |          2 4|   |          2        4| |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  9 2        8 2        7 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                             10 3        9 2 2        8 4        7 6
+--R                       (8192a  c  - 8192a b c  + 2560a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       4   4      3 3 3      2 5 2       7     9
+--R                     4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         9 2        8 2        7 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                   3 5     2 2 4       4 3    6 2
+--R                 (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               9 2        8 2        7 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                            10 3        9 2 2        8 4        7 6
+--R                    (- 8192a  c  + 8192a b c  - 2560a b c + 256a b )
+--R                 *
+--R                    ROOT
+--R                              6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                           - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                         + 
+--R                                10     12
+--R                           10a b  c - b
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                      4   4      3 3 3      2 5 2       7     9
+--R                  - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      9 2        8 2        7 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                3 5     2 2 4       4 3    6 2
+--R              (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R       -
+--R                                +--------------------+3  +------------------+3
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             4+-+ |          2 4|   |          2        4| |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                9 2        8 2        7 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                               10 3        9 2 2        8 4        7 6
+--R                       (- 8192a  c  + 8192a b c  - 2560a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       4   4      3 3 3      2 5 2       7     9
+--R                     4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       9 2        8 2        7 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                   3 5     2 2 4       4 3    6 2
+--R                 (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R       -
+--R                                +--------------------+3  +------------------+3
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             4+-+ |          2 4|   |          2        4| |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  9 2        8 2        7 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                        10 3
+--R                   8192a  c
+--R                *
+--R                   ROOT
+--R                             6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                          - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                        + 
+--R                               10     12
+--R                          10a b  c - b
+--R                     /
+--R                                  17 3           16 2 2          15 4
+--R                          4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                        + 
+--R                                  14 6
+--R                          - 65536a  b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         9 2        8 2        7 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                               9 3 2        8 5        7 7
+--R                         (8192a b c  - 2560a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                        17 3           16 2 2          15 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        14 6
+--R                                - 65536a  b
+--R                     + 
+--R                           4 2 4      3 4 3      2 6 2       8     10
+--R                       - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                           9 2        8 2        7 4
+--R                                   (- 4096a c  + 2048a b c - 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             6 6      5 2 5      4 4 4
+--R                                          - a c  + 12a b c  - 46a b c
+--R                                        + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                     /
+--R                                                  17 3           16 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 15 4          14 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                   3   3      2 3 2       5     7
+--R                                 7a b c  - 14a b c  + 7a b c - b
+--R                            /
+--R                                    9 2        8 2        7 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                       3 5     2 2 4       4 3    6 2
+--R                   (- a c  + 6a b c  - 5a b c  + b c )x
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               9 2        8 2        7 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                     10 3
+--R                8192a  c
+--R             *
+--R                ROOT
+--R                          6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                       - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                     + 
+--R                            10     12
+--R                       10a b  c - b
+--R                  /
+--R                             17 3           16 2 2          15 4          14 6
+--R                     4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      9 2        8 2        7 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                            9 3 2        8 5        7 7
+--R                      (8192a b c  - 2560a b c + 256a b )
+--R                   *
+--R                      ROOT
+--R                                6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                             - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                           + 
+--R                                  10     12
+--R                             10a b  c - b
+--R                        /
+--R                                     17 3           16 2 2          15 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     14 6
+--R                             - 65536a  b
+--R                  + 
+--R                        4 2 4      3 4 3      2 6 2       8     10
+--R                    - 4a b c  + 25a b c  - 26a b c  + 9a b c - b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                        9 2        8 2        7 4
+--R                                (- 4096a c  + 2048a b c - 256a b )
+--R                             *
+--R                                ROOT
+--R                                          6 6      5 2 5      4 4 4      3 6 3
+--R                                       - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                     + 
+--R                                            2 8 2        10     12
+--R                                       - 37a b c  + 10a b  c - b
+--R                                  /
+--R                                               17 3           16 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              15 4          14 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                3   3      2 3 2       5     7
+--R                              7a b c  - 14a b c  + 7a b c - b
+--R                         /
+--R                                 9 2        8 2        7 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                  3 5     2 2 4       4 3    6 2
+--R                (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             9 2        8 2        7 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                 6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                              - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                            + 
+--R                                   10     12
+--R                              10a b  c - b
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                       3   3      2 3 2       5     7
+--R                     7a b c  - 14a b c  + 7a b c - b
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                     10 3
+--R                8192a  c
+--R             *
+--R                ROOT
+--R                          6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                       - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                     + 
+--R                            10     12
+--R                       10a b  c - b
+--R                  /
+--R                             17 3           16 2 2          15 4          14 6
+--R                     4194304a  c  - 3145728a  b c  + 786432a  b c - 65536a  b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    9 2        8 2        7 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                              3   3      2 3 2       5     7
+--R                            7a b c  - 14a b c  + 7a b c - b
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                            9 3 2        8 5        7 7
+--R                      (8192a b c  - 2560a b c + 256a b )
+--R                   *
+--R                      ROOT
+--R                                6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                             - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                           + 
+--R                                  10     12
+--R                             10a b  c - b
+--R                        /
+--R                                     17 3           16 2 2          15 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     14 6
+--R                             - 65536a  b
+--R                  + 
+--R                      4 2 4      3 4 3      2 6 2       8     10
+--R                    4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      9 2        8 2        7 4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                          6 6      5 2 5      4 4 4      3 6 3
+--R                                       - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                     + 
+--R                                            2 8 2        10     12
+--R                                       - 37a b c  + 10a b  c - b
+--R                                  /
+--R                                               17 3           16 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              15 4          14 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                3   3      2 3 2       5     7
+--R                              7a b c  - 14a b c  + 7a b c - b
+--R                         /
+--R                                 9 2        8 2        7 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                    3 5     2 2 4       4 3    6 2
+--R                (- a c  + 6a b c  - 5a b c  + b c )x
+--R     + 
+--R       -
+--R                                +--------------------+3  +------------------+3
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             4+-+ |          2 4|   |          2        4| |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                9 2        8 2        7 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                          3   3      2 3 2       5     7
+--R                        7a b c  - 14a b c  + 7a b c - b
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                        10 3
+--R                   8192a  c
+--R                *
+--R                   ROOT
+--R                             6 6      5 2 5      4 4 4      3 6 3      2 8 2
+--R                          - a c  + 12a b c  - 46a b c  + 62a b c  - 37a b c
+--R                        + 
+--R                               10     12
+--R                          10a b  c - b
+--R                     /
+--R                                  17 3           16 2 2          15 4
+--R                          4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                        + 
+--R                                  14 6
+--R                          - 65536a  b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       9 2        8 2        7 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           6 6      5 2 5      4 4 4      3 6 3
+--R                                        - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                      + 
+--R                                             2 8 2        10     12
+--R                                        - 37a b c  + 10a b  c - b
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                 3   3      2 3 2       5     7
+--R                               7a b c  - 14a b c  + 7a b c - b
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                               9 3 2        8 5        7 7
+--R                         (8192a b c  - 2560a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                   6 6      5 2 5      4 4 4      3 6 3
+--R                                - a c  + 12a b c  - 46a b c  + 62a b c
+--R                              + 
+--R                                     2 8 2        10     12
+--R                                - 37a b c  + 10a b  c - b
+--R                           /
+--R                                        17 3           16 2 2          15 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        14 6
+--R                                - 65536a  b
+--R                     + 
+--R                         4 2 4      3 4 3      2 6 2       8     10
+--R                       4a b c  - 25a b c  + 26a b c  - 9a b c + b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         9 2        8 2        7 4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             6 6      5 2 5      4 4 4
+--R                                          - a c  + 12a b c  - 46a b c
+--R                                        + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                     /
+--R                                                  17 3           16 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 15 4          14 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                   3   3      2 3 2       5     7
+--R                                 7a b c  - 14a b c  + 7a b c - b
+--R                            /
+--R                                    9 2        8 2        7 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                     3 5     2 2 4       4 3    6 2
+--R                   (a c  - 6a b c  + 5a b c  - b c )x
+--R     + 
+--R                                      +------------------+3
+--R             +-----------+            | +-----------+
+--R             |          2      4+-+3 4| |          2
+--R         (- \|- 4a c + b   + b)\|c   \|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                      +--------------------+3
+--R             +-----------+            |   +-----------+
+--R             |          2      4+-+3 4|   |          2
+--R         (- \|- 4a c + b   - b)\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                      +------------------+3
+--R             +-----------+            | +-----------+
+--R             |          2      4+-+3 4| |          2
+--R         (- \|- 4a c + b   + b)\|c   \|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                      +--------------------+3
+--R             +-----------+            |   +-----------+
+--R             |          2      4+-+3 4|   |          2
+--R         (- \|- 4a c + b   - b)\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                          +--------------------+3  +------------------+3
+--R            +-----------+ |   +-----------+        | +-----------+
+--R       4+-+ |          2 4|   |          2        4| |          2
+--R     2a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1214
+
+--S 1215 of 2282
+--d0:=normalize(D(m0,x))
+--E 1215
+
+)clear all
+
+--S 1216 of 2282
+t0:=x^m/(1+x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1216
+
+--S 1217 of 2282
+--r0:=-2*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),_
+--   -2*x^4/(1+%i*sqrt(3)))/((1+m)*(%i-sqrt(3))*sqrt(3))+2*x^(1+m)*_
+--   hypergeometric(1,1/4*(1+m),1/4*(5+m),-2*x^4/(1-%i*sqrt(3)))/_
+--   ((1+m)*sqrt(3)*(%i+sqrt(3)))
+--E 1217
+
+--S 1218 of 2282
+--a0:=integrate(t0,x)
+--E 1218
+
+--S 1219 of 2282
+--m0:=a0-r0
+--E 1219
+
+--S 1220 of 2282
+--d0:=normalize(D(m0,x))
+--E 1220
+
+)clear all
+
+--S 1221 of 2282
+t0:=x^11/(1+x^4+x^8)
+--R 
+--R
+--R             11
+--R            x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1221
+
+--S 1222 of 2282
+r0:=1/4*x^4-1/8*log(1+x^4+x^8)-1/4*atan((1+2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                          4      +-+
+--R           +-+     8    4              (2x  + 1)\|3       4 +-+
+--R        - \|3 log(x  + x  + 1) - 2atan(-------------) + 2x \|3
+--R                                             3
+--R   (2)  -------------------------------------------------------
+--R                                   +-+
+--R                                 8\|3
+--R                                                    Type: Expression(Integer)
+--E 1222
+
+--S 1223 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                          4      +-+
+--R           +-+     8    4              (2x  + 1)\|3       4 +-+
+--R        - \|3 log(x  + x  + 1) - 2atan(-------------) + 2x \|3
+--R                                             3
+--R   (3)  -------------------------------------------------------
+--R                                   +-+
+--R                                 8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1223
+
+--S 1224 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1224
+
+--S 1225 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1225
+
+)clear all
+
+--S 1226 of 2282
+t0:=x^9/(1+x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1226
+
+--S 1227 of 2282
+r0:=1/2*x^2+1/2*atan((1-2*x^2)/sqrt(3))/sqrt(3)-_
+   1/2*atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                  2      +-+            2      +-+
+--R               (2x  + 1)\|3          (2x  - 1)\|3      2 +-+
+--R        - atan(-------------) - atan(-------------) + x \|3
+--R                     3                     3
+--R   (2)  ----------------------------------------------------
+--R                                  +-+
+--R                                2\|3
+--R                                                    Type: Expression(Integer)
+--E 1227
+
+--S 1228 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2 +-+          6     2
+--R               x \|3          x  + 2x      2 +-+
+--R        - atan(------) - atan(--------) + x \|3
+--R                  3              +-+
+--R                                \|3
+--R   (3)  ----------------------------------------
+--R                            +-+
+--R                          2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1228
+
+--S 1229 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2      +-+            2      +-+          2 +-+          6     2
+--R        (2x  + 1)\|3          (2x  - 1)\|3          x \|3          x  + 2x
+--R   atan(-------------) + atan(-------------) - atan(------) - atan(--------)
+--R              3                     3                  3              +-+
+--R                                                                     \|3
+--R   -------------------------------------------------------------------------
+--R                                       +-+
+--R                                     2\|3
+--R                                                    Type: Expression(Integer)
+--E 1229
+
+--S 1230 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1230
+
+)clear all
+
+--S 1231 of 2282
+t0:=x^7/(1+x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1231
+
+--S 1232 of 2282
+r0:=1/8*log(1+x^4+x^8)-1/4*atan((1+2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                        4      +-+
+--R         +-+     8    4              (2x  + 1)\|3
+--R        \|3 log(x  + x  + 1) - 2atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           8\|3
+--R                                                    Type: Expression(Integer)
+--E 1232
+
+--S 1233 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        4      +-+
+--R         +-+     8    4              (2x  + 1)\|3
+--R        \|3 log(x  + x  + 1) - 2atan(-------------)
+--R                                           3
+--R   (3)  -------------------------------------------
+--R                             +-+
+--R                           8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1233
+
+--S 1234 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1234
+
+--S 1235 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1235
+
+)clear all
+
+--S 1236 of 2282
+t0:=x^5/(1+x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1236
+
+--S 1237 of 2282
+r0:=1/8*log(1-x^2+x^4)-1/8*log(1+x^2+x^4)-_
+   1/4*atan((1-2*x^2)/sqrt(3))/sqrt(3)+1/4*atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                2      +-+
+--R          +-+     4    2         +-+     4    2              (2x  + 1)\|3
+--R       - \|3 log(x  + x  + 1) + \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                                                   3
+--R     + 
+--R                2      +-+
+--R             (2x  - 1)\|3
+--R       2atan(-------------)
+--R                   3
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1237
+
+--S 1238 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                2      +-+
+--R          +-+     4    2         +-+     4    2              (2x  + 1)\|3
+--R       - \|3 log(x  + x  + 1) + \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                                                   3
+--R     + 
+--R                2      +-+
+--R             (2x  - 1)\|3
+--R       2atan(-------------)
+--R                   3
+--R  /
+--R       +-+
+--R     8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1238
+
+--S 1239 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1239
+
+--S 1240 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1240
+
+)clear all
+
+--S 1241 of 2282
+t0:=x^3/(1+x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1241
+
+--S 1242 of 2282
+r0:=1/2*atan((1+2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                4      +-+
+--R             (2x  + 1)\|3
+--R        atan(-------------)
+--R                   3
+--R   (2)  -------------------
+--R                 +-+
+--R               2\|3
+--R                                                    Type: Expression(Integer)
+--E 1242
+
+--S 1243 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                4      +-+
+--R             (2x  + 1)\|3
+--R        atan(-------------)
+--R                   3
+--R   (3)  -------------------
+--R                 +-+
+--R               2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1243
+
+--S 1244 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1244
+
+--S 1245 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1245
+
+)clear all
+
+--S 1246 of 2282
+t0:=x/(1+x^4+x^8)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1246
+
+--S 1247 of 2282
+r0:=-1/8*log(1-x^2+x^4)+1/8*log(1+x^2+x^4)-_
+   1/4*atan((1-2*x^2)/sqrt(3))/sqrt(3)+1/4*atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                              2      +-+
+--R        +-+     4    2         +-+     4    2              (2x  + 1)\|3
+--R       \|3 log(x  + x  + 1) - \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                                                 3
+--R     + 
+--R                2      +-+
+--R             (2x  - 1)\|3
+--R       2atan(-------------)
+--R                   3
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1247
+
+--S 1248 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                              2      +-+
+--R        +-+     4    2         +-+     4    2              (2x  + 1)\|3
+--R       \|3 log(x  + x  + 1) - \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                                                 3
+--R     + 
+--R                2      +-+
+--R             (2x  - 1)\|3
+--R       2atan(-------------)
+--R                   3
+--R  /
+--R       +-+
+--R     8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1248
+
+--S 1249 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1249
+
+--S 1250 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1250
+
+)clear all
+
+--S 1251 of 2282
+t0:=1/(x*(1+x^4+x^8))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         9    5
+--R        x  + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1251
+
+--S 1252 of 2282
+r0:=log(x)-1/8*log(1+x^4+x^8)-1/4*atan((1+2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                        4      +-+
+--R           +-+     8    4          +-+               (2x  + 1)\|3
+--R        - \|3 log(x  + x  + 1) + 8\|3 log(x) - 2atan(-------------)
+--R                                                           3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   8\|3
+--R                                                    Type: Expression(Integer)
+--E 1252
+
+--S 1253 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        4      +-+
+--R           +-+     8    4          +-+               (2x  + 1)\|3
+--R        - \|3 log(x  + x  + 1) + 8\|3 log(x) - 2atan(-------------)
+--R                                                           3
+--R   (3)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1253
+
+--S 1254 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1254
+
+--S 1255 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1255
+
+)clear all
+
+--S 1256 of 2282
+t0:=1/(x^3*(1+x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         11    7    3
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1256
+
+--S 1257 of 2282
+r0:=(-1/2)/x^2+1/2*atan((1-2*x^2)/sqrt(3))/sqrt(3)-_
+   1/2*atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                    2      +-+              2      +-+
+--R           2     (2x  + 1)\|3      2     (2x  - 1)\|3      +-+
+--R        - x atan(-------------) - x atan(-------------) - \|3
+--R                       3                       3
+--R   (2)  ------------------------------------------------------
+--R                                  2 +-+
+--R                                2x \|3
+--R                                                    Type: Expression(Integer)
+--E 1257
+
+--S 1258 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  2 +-+            6     2
+--R           2     x \|3      2     x  + 2x      +-+
+--R        - x atan(------) - x atan(--------) - \|3
+--R                    3                +-+
+--R                                    \|3
+--R   (3)  ------------------------------------------
+--R                            2 +-+
+--R                          2x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1258
+
+--S 1259 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2      +-+            2      +-+          2 +-+          6     2
+--R        (2x  + 1)\|3          (2x  - 1)\|3          x \|3          x  + 2x
+--R   atan(-------------) + atan(-------------) - atan(------) - atan(--------)
+--R              3                     3                  3              +-+
+--R                                                                     \|3
+--R   -------------------------------------------------------------------------
+--R                                       +-+
+--R                                     2\|3
+--R                                                    Type: Expression(Integer)
+--E 1259
+
+--S 1260 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1260
+
+)clear all
+
+--S 1261 of 2282
+t0:=1/(x^5*(1+x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         13    9    5
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1261
+
+--S 1262 of 2282
+r0:=(-1/4)/x^4-log(x)+1/8*log(1+x^4+x^8)-1/4*atan((1+2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                       4      +-+
+--R    4 +-+     8    4          4 +-+           4     (2x  + 1)\|3       +-+
+--R   x \|3 log(x  + x  + 1) - 8x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                          3
+--R   -----------------------------------------------------------------------
+--R                                     4 +-+
+--R                                   8x \|3
+--R                                                    Type: Expression(Integer)
+--E 1262
+
+--S 1263 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                       4      +-+
+--R    4 +-+     8    4          4 +-+           4     (2x  + 1)\|3       +-+
+--R   x \|3 log(x  + x  + 1) - 8x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                          3
+--R   -----------------------------------------------------------------------
+--R                                     4 +-+
+--R                                   8x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1263
+
+--S 1264 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1264
+
+--S 1265 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1265
+
+)clear all
+
+--S 1266 of 2282
+t0:=1/(x^7*(1+x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         15    11    7
+--R        x   + x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1266
+
+--S 1267 of 2282
+r0:=(-1/6)/x^6+1/2/x^2+1/8*log(1-x^2+x^4)-1/8*log(1+x^2+x^4)-_
+   1/4*atan((1-2*x^2)/sqrt(3))/sqrt(3)+1/4*atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           6 +-+     4    2          6 +-+     4    2
+--R       - 3x \|3 log(x  + x  + 1) + 3x \|3 log(x  - x  + 1)
+--R     + 
+--R                  2      +-+               2      +-+
+--R         6     (2x  + 1)\|3       6     (2x  - 1)\|3         4      +-+
+--R       6x atan(-------------) + 6x atan(-------------) + (12x  - 4)\|3
+--R                     3                        3
+--R  /
+--R        6 +-+
+--R     24x \|3
+--R                                                    Type: Expression(Integer)
+--E 1267
+
+--S 1268 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           6 +-+     4    2          6 +-+     4    2
+--R       - 3x \|3 log(x  + x  + 1) + 3x \|3 log(x  - x  + 1)
+--R     + 
+--R                  2      +-+               2      +-+
+--R         6     (2x  + 1)\|3       6     (2x  - 1)\|3         4      +-+
+--R       6x atan(-------------) + 6x atan(-------------) + (12x  - 4)\|3
+--R                     3                        3
+--R  /
+--R        6 +-+
+--R     24x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1268
+
+--S 1269 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1269
+
+--S 1270 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1270
+
+)clear all
+
+--S 1271 of 2282
+t0:=x^8/(1+x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1271
+
+--S 1272 of 2282
+r0:=x+1/4*atan(-2*x+sqrt(3))-1/4*atan(2*x+sqrt(3))+1/8*log(1-x+x^2)-_
+   1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)+1/8*log(1+x^2-x*sqrt(3))/sqrt(3)-_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R               +-+    2         +-+     2             +-+     2
+--R       - log(x\|3  + x  + 1) - \|3 log(x  + x + 1) + \|3 log(x  - x + 1)
+--R     + 
+--R                                              +-+                   +-+
+--R               +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       log(- x\|3  + x  + 1) - 2atan(------------) - 2atan(------------)
+--R                                           3                     3
+--R     + 
+--R           +-+      +-+           +-+      +-+            +-+
+--R       - 2\|3 atan(\|3  + 2x) + 2\|3 atan(\|3  - 2x) + 8x\|3
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1272
+
+--S 1273 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              2
+--R     + 
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3                  \|3               \|3
+--R                 sin(----------)  - x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3       2
+--R                 x\|3 cos(----------) + x
+--R                               2
+--R     + 
+--R                                               3                     3
+--R                                        atan(----)            atan(----)
+--R                     3                        +-+                   +-+
+--R              atan(----)                     \|3       +-+         \|3
+--R                    +-+            3sin(----------) + \|3 cos(----------)
+--R                   \|3                       2                     2
+--R       - 4sin(----------)atan(-----------------------------------------------)
+--R                   2                         3                  3
+--R                                      atan(----)         atan(----)
+--R                                            +-+                +-+
+--R                               +-+         \|3                \|3         +-+
+--R                              \|3 sin(----------) - 3cos(----------) - 2x\|3
+--R                                           2                  2
+--R     + 
+--R                                             3                     3
+--R                                      atan(----)            atan(----)
+--R                   3                        +-+                   +-+
+--R            atan(----)                     \|3       +-+         \|3
+--R                  +-+            3sin(----------) + \|3 cos(----------)
+--R                 \|3                       2                     2
+--R       4sin(----------)atan(-----------------------------------------------)
+--R                 2                         3                  3
+--R                                    atan(----)         atan(----)
+--R                                          +-+                +-+
+--R                             +-+         \|3                \|3         +-+
+--R                            \|3 sin(----------) - 3cos(----------) + 2x\|3
+--R                                         2                  2
+--R     + 
+--R                                                                   +-+
+--R          +-+     2             +-+     2                 (2x - 1)\|3
+--R       - \|3 log(x  + x + 1) + \|3 log(x  - x + 1) + atan(------------)
+--R                                                            2
+--R                                                          2x  - 2x - 1
+--R     + 
+--R                     +-+
+--R            (2x + 1)\|3        +-+
+--R       atan(------------) + 8x\|3
+--R              2
+--R            2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1273
+
+--S 1274 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              2
+--R     + 
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3                  \|3               \|3
+--R                 sin(----------)  - x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3       2
+--R                 x\|3 cos(----------) + x
+--R                               2
+--R     + 
+--R                                               3                     3
+--R                                        atan(----)            atan(----)
+--R                     3                        +-+                   +-+
+--R              atan(----)                     \|3       +-+         \|3
+--R                    +-+            3sin(----------) + \|3 cos(----------)
+--R                   \|3                       2                     2
+--R       - 4sin(----------)atan(-----------------------------------------------)
+--R                   2                         3                  3
+--R                                      atan(----)         atan(----)
+--R                                            +-+                +-+
+--R                               +-+         \|3                \|3         +-+
+--R                              \|3 sin(----------) - 3cos(----------) - 2x\|3
+--R                                           2                  2
+--R     + 
+--R                                             3                     3
+--R                                      atan(----)            atan(----)
+--R                   3                        +-+                   +-+
+--R            atan(----)                     \|3       +-+         \|3
+--R                  +-+            3sin(----------) + \|3 cos(----------)
+--R                 \|3                       2                     2
+--R       4sin(----------)atan(-----------------------------------------------)
+--R                 2                         3                  3
+--R                                    atan(----)         atan(----)
+--R                                          +-+                +-+
+--R                             +-+         \|3                \|3         +-+
+--R                            \|3 sin(----------) - 3cos(----------) + 2x\|3
+--R                                         2                  2
+--R     + 
+--R                                                                    +-+
+--R             +-+    2                +-+    2              (2x + 1)\|3
+--R       log(x\|3  + x  + 1) - log(- x\|3  + x  + 1) + 2atan(------------)
+--R                                                                 3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3       +-+      +-+           +-+      +-+
+--R       2atan(------------) + 2\|3 atan(\|3  + 2x) - 2\|3 atan(\|3  - 2x)
+--R                   3
+--R     + 
+--R                     +-+                  +-+
+--R            (2x - 1)\|3          (2x + 1)\|3
+--R       atan(------------) + atan(------------)
+--R              2                    2
+--R            2x  - 2x - 1         2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1274
+
+--S 1275 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                               3   8
+--R                        atan(----)
+--R                              +-+
+--R            4     2          \|3
+--R       (- 3x  + 3x )sin(----------)
+--R                             2
+--R     + 
+--R                                  3   2                        3   6
+--R                           atan(----)                   atan(----)
+--R                                 +-+                          +-+
+--R              4      2          \|3         6     4          \|3
+--R       ((- 12x  + 12x )cos(----------)  - 6x  + 6x )sin(----------)
+--R                                2                            2
+--R     + 
+--R                                         3              3   5
+--R                                  atan(----)     atan(----)
+--R                                        +-+            +-+
+--R            6     4     2  +-+         \|3            \|3
+--R       (- 8x  + 8x  + 4x )\|3 cos(----------)sin(----------)
+--R                                       2              2
+--R     + 
+--R                                     3   4                           3   2
+--R                              atan(----)                      atan(----)
+--R                                    +-+                             +-+
+--R                 4      2          \|3            6     4          \|3         8
+--R           (- 18x  + 18x )cos(----------)  + (- 6x  + 6x )cos(----------)  - 6x
+--R                                   2                               2
+--R         + 
+--R             6     4
+--R           6x  + 3x
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                               3   3
+--R                                        atan(----)
+--R                                              +-+
+--R                 6      4     2  +-+         \|3
+--R           (- 16x  + 16x  + 8x )\|3 cos(----------)
+--R                                             2
+--R         + 
+--R                                             3
+--R                                      atan(----)
+--R                                            +-+
+--R                8     6     4  +-+         \|3
+--R           (- 8x  + 8x  + 4x )\|3 cos(----------)
+--R                                           2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                     3   6                         3   4
+--R                              atan(----)                    atan(----)
+--R                                    +-+                           +-+
+--R                 4      2          \|3          6     4          \|3
+--R           (- 12x  + 12x )cos(----------)  + (6x  - 6x )cos(----------)
+--R                                   2                             2
+--R         + 
+--R                                            3   2
+--R                                     atan(----)
+--R                                           +-+
+--R                 8      6      4          \|3         10     8     6
+--R           (- 12x  + 12x  + 30x )cos(----------)  - 3x   + 3x  + 3x
+--R                                          2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                             3   5
+--R                                      atan(----)
+--R                                            +-+
+--R                6     4     2  +-+         \|3
+--R           (- 8x  + 8x  + 4x )\|3 cos(----------)
+--R                                           2
+--R         + 
+--R                                           3   3
+--R                                    atan(----)
+--R                                          +-+
+--R              8     6     4  +-+         \|3
+--R           (8x  - 8x  - 4x )\|3 cos(----------)
+--R                                         2
+--R         + 
+--R                                               3
+--R                                        atan(----)
+--R                                              +-+
+--R                10     8      6  +-+         \|3
+--R           (- 2x   + 2x  + 10x )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                               3   8                         3   6
+--R                        atan(----)                    atan(----)
+--R                              +-+                           +-+
+--R            4     2          \|3          6     4          \|3
+--R       (- 3x  + 3x )cos(----------)  + (6x  - 6x )cos(----------)
+--R                             2                             2
+--R     + 
+--R                                     3   4                                3   2
+--R                              atan(----)                           atan(----)
+--R                                    +-+                                  +-+
+--R            8     6     4          \|3          10     8     6          \|3
+--R       (- 6x  + 6x  + 3x )cos(----------)  + (3x   - 3x  - 3x )cos(----------)
+--R                                   2                                    2
+--R     + 
+--R         8
+--R       3x
+--R  /
+--R                                 3   8
+--R                          atan(----)
+--R                                +-+
+--R          4     2              \|3
+--R       (6x  - 6x  + 6)sin(----------)
+--R                               2
+--R     + 
+--R                                     3   2                                 3   6
+--R                              atan(----)                            atan(----)
+--R                                    +-+                                   +-+
+--R            4      2               \|3          6      4      2          \|3
+--R       ((24x  - 24x  + 24)cos(----------)  + 12x  - 12x  + 12x )sin(----------)
+--R                                   2                                     2
+--R     + 
+--R                                          3              3   5
+--R                                   atan(----)     atan(----)
+--R                                         +-+            +-+
+--R           6      4      2  +-+         \|3            \|3
+--R       (24x  - 24x  + 24x )\|3 cos(----------)sin(----------)
+--R                                        2              2
+--R     + 
+--R                                        3   4
+--R                                 atan(----)
+--R                                       +-+
+--R               4      2               \|3
+--R           (36x  - 36x  + 36)cos(----------)
+--R                                      2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               6      4      2          \|3          8      6      4
+--R           (12x  - 12x  + 12x )cos(----------)  + 18x  - 18x  + 18x
+--R                                        2
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   3
+--R                                       atan(----)
+--R                                             +-+
+--R               6      4      2  +-+         \|3
+--R           (48x  - 48x  + 48x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                              3
+--R                                       atan(----)
+--R                                             +-+
+--R               8      6      4  +-+         \|3
+--R           (24x  - 24x  + 24x )\|3 cos(----------)
+--R                                            2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                        3   6
+--R                                 atan(----)
+--R                                       +-+
+--R               4      2               \|3
+--R           (24x  - 24x  + 24)cos(----------)
+--R                                      2
+--R         + 
+--R                                            3   4
+--R                                     atan(----)
+--R                                           +-+
+--R                 6      4      2          \|3
+--R           (- 12x  + 12x  - 12x )cos(----------)
+--R                                          2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               8      6      4          \|3          10      8      6
+--R           (84x  - 84x  + 84x )cos(----------)  + 12x   - 12x  + 12x
+--R                                        2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   5
+--R                                       atan(----)
+--R                                             +-+
+--R               6      4      2  +-+         \|3
+--R           (24x  - 24x  + 24x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                                3   3
+--R                                         atan(----)
+--R                                               +-+
+--R                 8      6      4  +-+         \|3
+--R           (- 24x  + 24x  - 24x )\|3 cos(----------)
+--R                                              2
+--R         + 
+--R                                               3
+--R                                        atan(----)
+--R                                              +-+
+--R               10      8      6  +-+         \|3
+--R           (24x   - 24x  + 24x )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                 3   8                                    3   6
+--R                          atan(----)                               atan(----)
+--R                                +-+                                      +-+
+--R          4     2              \|3             6      4      2          \|3
+--R       (6x  - 6x  + 6)cos(----------)  + (- 12x  + 12x  - 12x )cos(----------)
+--R                               2                                        2
+--R     + 
+--R                                      3   4
+--R                               atan(----)
+--R                                     +-+
+--R           8      6      4          \|3
+--R       (18x  - 18x  + 18x )cos(----------)
+--R                                    2
+--R     + 
+--R                                         3   2
+--R                                  atan(----)
+--R                                        +-+
+--R             10      8      6          \|3         12     10     8
+--R       (- 12x   + 12x  - 12x )cos(----------)  + 6x   - 6x   + 6x
+--R                                       2
+--R                                                    Type: Expression(Integer)
+--E 1275
+
+)clear all
+
+--S 1276 of 2282
+t0:=x^6/(1+x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1276
+
+--S 1277 of 2282
+r0:=-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)+1/2*atan((1+2*x)/sqrt(3))/sqrt(3)+_
+   1/4*log(1+x^2-x*sqrt(3))/sqrt(3)-1/4*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                      +-+
+--R               +-+    2                +-+    2              (2x + 1)\|3
+--R       - log(x\|3  + x  + 1) + log(- x\|3  + x  + 1) + 2atan(------------)
+--R                                                                   3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3
+--R       2atan(------------)
+--R                   3
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1277
+
+--S 1278 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4     2      +-+     3                 +-+           3
+--R            (x  + 5x  + 1)\|3  - 6x  - 6x          x\|3           x  + 2x
+--R        log(-----------------------------) + 2atan(-----) + 2atan(-------)
+--R                      4    2                         3               +-+
+--R                     x  - x  + 1                                    \|3
+--R   (3)  ------------------------------------------------------------------
+--R                                         +-+
+--R                                       4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1278
+
+--S 1279 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   4     2      +-+     3
+--R             +-+    2            (x  + 5x  + 1)\|3  - 6x  - 6x
+--R       log(x\|3  + x  + 1) + log(-----------------------------)
+--R                                           4    2
+--R                                          x  - x  + 1
+--R     + 
+--R                                                +-+                   +-+
+--R                 +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       - log(- x\|3  + x  + 1) - 2atan(------------) - 2atan(------------)
+--R                                             3                     3
+--R     + 
+--R               +-+           3
+--R             x\|3           x  + 2x
+--R       2atan(-----) + 2atan(-------)
+--R               3               +-+
+--R                              \|3
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1279
+
+--S 1280 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1280
+
+)clear all
+
+--S 1281 of 2282
+t0:=x^4/(1+x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1281
+
+--S 1282 of 2282
+r0:=-1/4*atan(-2*x+sqrt(3))+1/4*atan(2*x+sqrt(3))-1/8*log(1-x+x^2)+_
+   1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)+1/8*log(1+x^2-x*sqrt(3))/sqrt(3)-_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R               +-+    2         +-+     2             +-+     2
+--R       - log(x\|3  + x  + 1) + \|3 log(x  + x + 1) - \|3 log(x  - x + 1)
+--R     + 
+--R                                              +-+                   +-+
+--R               +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       log(- x\|3  + x  + 1) - 2atan(------------) - 2atan(------------)
+--R                                           3                     3
+--R     + 
+--R         +-+      +-+           +-+      +-+
+--R       2\|3 atan(\|3  + 2x) - 2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1282
+
+--S 1283 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3                   \|3               \|3        2
+--R            log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                                           3
+--R                                    atan(----)
+--R                     3                    +-+
+--R              atan(----)                 \|3
+--R                    +-+         cos(----------)
+--R                   \|3                   2
+--R       - 4sin(----------)atan(-------------------)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------) - x
+--R                                       2
+--R     + 
+--R                                         3
+--R                                  atan(----)
+--R                   3                    +-+
+--R            atan(----)                 \|3
+--R                  +-+         cos(----------)
+--R                 \|3                   2            +-+     2
+--R       4sin(----------)atan(-------------------) + \|3 log(x  + x + 1)
+--R                 2                     3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------) + x
+--R                                     2
+--R     + 
+--R                                             +-+                  +-+
+--R          +-+     2                 (2x - 1)\|3          (2x + 1)\|3
+--R       - \|3 log(x  - x + 1) + atan(------------) + atan(------------)
+--R                                      2                    2
+--R                                    2x  - 2x - 1         2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1283
+
+--S 1284 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3                   \|3               \|3        2
+--R            log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                                           3
+--R                                    atan(----)
+--R                     3                    +-+
+--R              atan(----)                 \|3
+--R                    +-+         cos(----------)
+--R                   \|3                   2
+--R       - 4sin(----------)atan(-------------------)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------) - x
+--R                                       2
+--R     + 
+--R                                         3
+--R                                  atan(----)
+--R                   3                    +-+
+--R            atan(----)                 \|3
+--R                  +-+         cos(----------)
+--R                 \|3                   2                 +-+    2
+--R       4sin(----------)atan(-------------------) + log(x\|3  + x  + 1)
+--R                 2                     3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------) + x
+--R                                     2
+--R     + 
+--R                                                +-+                   +-+
+--R                 +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       - log(- x\|3  + x  + 1) + 2atan(------------) + 2atan(------------)
+--R                                             3                     3
+--R     + 
+--R                                                                     +-+
+--R           +-+      +-+           +-+      +-+              (2x - 1)\|3
+--R       - 2\|3 atan(\|3  + 2x) + 2\|3 atan(\|3  - 2x) + atan(------------)
+--R                                                              2
+--R                                                            2x  - 2x - 1
+--R     + 
+--R                     +-+
+--R            (2x + 1)\|3
+--R       atan(------------)
+--R              2
+--R            2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1284
+
+--S 1285 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                       3   4                    3   2                  3   2
+--R                atan(----)               atan(----)             atan(----)
+--R                      +-+                      +-+                    +-+
+--R           2         \|3            2         \|3         4          \|3
+--R       - 3x sin(----------)  + (- 6x cos(----------)  + 6x )sin(----------)
+--R                     2                        2                      2
+--R     + 
+--R                                         3              3
+--R                                  atan(----)     atan(----)
+--R                                        +-+            +-+
+--R            6     4     2  +-+         \|3            \|3
+--R       (- 4x  + 4x  - 4x )\|3 cos(----------)sin(----------)
+--R                                       2              2
+--R     + 
+--R                       3   4                 3   2
+--R                atan(----)            atan(----)
+--R                      +-+                   +-+
+--R           2         \|3         4         \|3         6
+--R       - 3x cos(----------)  - 6x cos(----------)  - 3x
+--R                     2                     2
+--R  /
+--R                                 3   4
+--R                          atan(----)
+--R                                +-+
+--R          4     2              \|3
+--R       (6x  - 6x  + 6)sin(----------)
+--R                               2
+--R     + 
+--R                                     3   2                                 3   2
+--R                              atan(----)                            atan(----)
+--R                                    +-+                                   +-+
+--R            4      2               \|3          6      4      2          \|3
+--R       ((12x  - 12x  + 12)cos(----------)  - 12x  + 12x  - 12x )sin(----------)
+--R                                   2                                     2
+--R     + 
+--R                                 3   4                                  3   2
+--R                          atan(----)                             atan(----)
+--R                                +-+                                    +-+
+--R          4     2              \|3           6      4      2          \|3
+--R       (6x  - 6x  + 6)cos(----------)  + (12x  - 12x  + 12x )cos(----------)
+--R                               2                                      2
+--R     + 
+--R         8     6     4
+--R       6x  - 6x  + 6x
+--R                                                    Type: Expression(Integer)
+--E 1285
+
+)clear all
+
+--S 1286 of 2282
+t0:=x^2/(1+x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1286
+
+--S 1287 of 2282
+r0:=-1/4*atan(-2*x+sqrt(3))+1/4*atan(2*x+sqrt(3))+1/8*log(1-x+x^2)-_
+   1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)-1/8*log(1+x^2-x*sqrt(3))/sqrt(3)+_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R             +-+    2         +-+     2             +-+     2
+--R       log(x\|3  + x  + 1) - \|3 log(x  + x + 1) + \|3 log(x  - x + 1)
+--R     + 
+--R                                                +-+                   +-+
+--R                 +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       - log(- x\|3  + x  + 1) - 2atan(------------) - 2atan(------------)
+--R                                             3                     3
+--R     + 
+--R         +-+      +-+           +-+      +-+
+--R       2\|3 atan(\|3  + 2x) - 2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1287
+
+--S 1288 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3                  \|3               \|3
+--R                 sin(----------)  + x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                   3
+--R                            atan(----)
+--R                                  +-+
+--R                     +-+         \|3       2
+--R                 - x\|3 cos(----------) + x
+--R                                 2
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                              3
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            2
+--R     + 
+--R                                              3                 3
+--R                                       atan(----)        atan(----)
+--R                   3                         +-+               +-+
+--R            atan(----)          +-+         \|3               \|3
+--R                  +-+          \|3 sin(----------) + cos(----------)
+--R                 \|3                        2                 2
+--R       4sin(----------)atan(------------------------------------------)
+--R                 2                     3                     3
+--R                                atan(----)            atan(----)
+--R                                      +-+                   +-+
+--R                                     \|3       +-+         \|3
+--R                            sin(----------) - \|3 cos(----------) - 2x
+--R                                     2                     2
+--R     + 
+--R                                                3                 3
+--R                                         atan(----)        atan(----)
+--R                     3                         +-+               +-+
+--R              atan(----)          +-+         \|3               \|3
+--R                    +-+          \|3 sin(----------) + cos(----------)
+--R                   \|3                        2                 2
+--R       - 4sin(----------)atan(------------------------------------------)
+--R                   2                     3                     3
+--R                                  atan(----)            atan(----)
+--R                                        +-+                   +-+
+--R                                       \|3       +-+         \|3
+--R                              sin(----------) - \|3 cos(----------) + 2x
+--R                                       2                     2
+--R     + 
+--R                                                                   +-+
+--R          +-+     2             +-+     2                 (2x - 1)\|3
+--R       - \|3 log(x  + x + 1) + \|3 log(x  - x + 1) + atan(------------)
+--R                                                            2
+--R                                                          2x  - 2x - 1
+--R     + 
+--R                     +-+
+--R            (2x + 1)\|3
+--R       atan(------------)
+--R              2
+--R            2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1288
+
+--S 1289 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3                  \|3               \|3
+--R                 sin(----------)  + x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                   3
+--R                            atan(----)
+--R                                  +-+
+--R                     +-+         \|3       2
+--R                 - x\|3 cos(----------) + x
+--R                                 2
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                              3
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            2
+--R     + 
+--R                                              3                 3
+--R                                       atan(----)        atan(----)
+--R                   3                         +-+               +-+
+--R            atan(----)          +-+         \|3               \|3
+--R                  +-+          \|3 sin(----------) + cos(----------)
+--R                 \|3                        2                 2
+--R       4sin(----------)atan(------------------------------------------)
+--R                 2                     3                     3
+--R                                atan(----)            atan(----)
+--R                                      +-+                   +-+
+--R                                     \|3       +-+         \|3
+--R                            sin(----------) - \|3 cos(----------) - 2x
+--R                                     2                     2
+--R     + 
+--R                                                3                 3
+--R                                         atan(----)        atan(----)
+--R                     3                         +-+               +-+
+--R              atan(----)          +-+         \|3               \|3
+--R                    +-+          \|3 sin(----------) + cos(----------)
+--R                   \|3                        2                 2
+--R       - 4sin(----------)atan(------------------------------------------)
+--R                   2                     3                     3
+--R                                  atan(----)            atan(----)
+--R                                        +-+                   +-+
+--R                                       \|3       +-+         \|3
+--R                              sin(----------) - \|3 cos(----------) + 2x
+--R                                       2                     2
+--R     + 
+--R                                                                      +-+
+--R               +-+    2                +-+    2              (2x + 1)\|3
+--R       - log(x\|3  + x  + 1) + log(- x\|3  + x  + 1) + 2atan(------------)
+--R                                                                   3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3       +-+      +-+           +-+      +-+
+--R       2atan(------------) - 2\|3 atan(\|3  + 2x) + 2\|3 atan(\|3  - 2x)
+--R                   3
+--R     + 
+--R                     +-+                  +-+
+--R            (2x - 1)\|3          (2x + 1)\|3
+--R       atan(------------) + atan(------------)
+--R              2                    2
+--R            2x  - 2x - 1         2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1289
+
+--S 1290 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                             3   8
+--R                      atan(----)
+--R                            +-+
+--R          4     2          \|3
+--R       (3x  - 3x )sin(----------)
+--R                           2
+--R     + 
+--R                                3   2                        3   6
+--R                         atan(----)                   atan(----)
+--R                               +-+                          +-+
+--R            4      2          \|3         6     4          \|3
+--R       ((12x  - 12x )cos(----------)  + 6x  - 6x )sin(----------)
+--R                              2                            2
+--R     + 
+--R                                       3              3   5
+--R                                atan(----)     atan(----)
+--R                                      +-+            +-+
+--R          6     4     2  +-+         \|3            \|3
+--R       (8x  - 8x  - 4x )\|3 cos(----------)sin(----------)
+--R                                     2              2
+--R     + 
+--R                                   3   4                         3   2
+--R                            atan(----)                    atan(----)
+--R                                  +-+                           +-+
+--R               4      2          \|3          6     4          \|3         8
+--R           (18x  - 18x )cos(----------)  + (6x  - 6x )cos(----------)  + 6x
+--R                                 2                             2
+--R         + 
+--R               6     4
+--R           - 6x  - 3x
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                             3   3
+--R                                      atan(----)
+--R                                            +-+
+--R               6      4     2  +-+         \|3
+--R           (16x  - 16x  - 8x )\|3 cos(----------)
+--R                                           2
+--R         + 
+--R                                           3
+--R                                    atan(----)
+--R                                          +-+
+--R              8     6     4  +-+         \|3
+--R           (8x  - 8x  - 4x )\|3 cos(----------)
+--R                                         2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                   3   6                           3   4
+--R                            atan(----)                      atan(----)
+--R                                  +-+                             +-+
+--R               4      2          \|3            6     4          \|3
+--R           (12x  - 12x )cos(----------)  + (- 6x  + 6x )cos(----------)
+--R                                 2                               2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               8      6      4          \|3         10     8     6
+--R           (12x  - 12x  - 30x )cos(----------)  + 3x   - 3x  - 3x
+--R                                        2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                           3   5
+--R                                    atan(----)
+--R                                          +-+
+--R              6     4     2  +-+         \|3
+--R           (8x  - 8x  - 4x )\|3 cos(----------)
+--R                                         2
+--R         + 
+--R                                             3   3
+--R                                      atan(----)
+--R                                            +-+
+--R                8     6     4  +-+         \|3
+--R           (- 8x  + 8x  + 4x )\|3 cos(----------)
+--R                                           2
+--R         + 
+--R                                             3
+--R                                      atan(----)
+--R                                            +-+
+--R              10     8      6  +-+         \|3
+--R           (2x   - 2x  - 10x )\|3 cos(----------)
+--R                                           2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                             3   8                           3   6
+--R                      atan(----)                      atan(----)
+--R                            +-+                             +-+
+--R          4     2          \|3            6     4          \|3
+--R       (3x  - 3x )cos(----------)  + (- 6x  + 6x )cos(----------)
+--R                           2                               2
+--R     + 
+--R                                   3   4                                  3   2
+--R                            atan(----)                             atan(----)
+--R                                  +-+                                    +-+
+--R          8     6     4          \|3            10     8     6          \|3
+--R       (6x  - 6x  - 3x )cos(----------)  + (- 3x   + 3x  + 3x )cos(----------)
+--R                                 2                                      2
+--R     + 
+--R           8
+--R       - 3x
+--R  /
+--R                                 3   8
+--R                          atan(----)
+--R                                +-+
+--R          4     2              \|3
+--R       (6x  - 6x  + 6)sin(----------)
+--R                               2
+--R     + 
+--R                                     3   2                                 3   6
+--R                              atan(----)                            atan(----)
+--R                                    +-+                                   +-+
+--R            4      2               \|3          6      4      2          \|3
+--R       ((24x  - 24x  + 24)cos(----------)  + 12x  - 12x  + 12x )sin(----------)
+--R                                   2                                     2
+--R     + 
+--R                                          3              3   5
+--R                                   atan(----)     atan(----)
+--R                                         +-+            +-+
+--R           6      4      2  +-+         \|3            \|3
+--R       (24x  - 24x  + 24x )\|3 cos(----------)sin(----------)
+--R                                        2              2
+--R     + 
+--R                                        3   4
+--R                                 atan(----)
+--R                                       +-+
+--R               4      2               \|3
+--R           (36x  - 36x  + 36)cos(----------)
+--R                                      2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               6      4      2          \|3          8      6      4
+--R           (12x  - 12x  + 12x )cos(----------)  + 18x  - 18x  + 18x
+--R                                        2
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   3
+--R                                       atan(----)
+--R                                             +-+
+--R               6      4      2  +-+         \|3
+--R           (48x  - 48x  + 48x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                              3
+--R                                       atan(----)
+--R                                             +-+
+--R               8      6      4  +-+         \|3
+--R           (24x  - 24x  + 24x )\|3 cos(----------)
+--R                                            2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                        3   6
+--R                                 atan(----)
+--R                                       +-+
+--R               4      2               \|3
+--R           (24x  - 24x  + 24)cos(----------)
+--R                                      2
+--R         + 
+--R                                            3   4
+--R                                     atan(----)
+--R                                           +-+
+--R                 6      4      2          \|3
+--R           (- 12x  + 12x  - 12x )cos(----------)
+--R                                          2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               8      6      4          \|3          10      8      6
+--R           (84x  - 84x  + 84x )cos(----------)  + 12x   - 12x  + 12x
+--R                                        2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   5
+--R                                       atan(----)
+--R                                             +-+
+--R               6      4      2  +-+         \|3
+--R           (24x  - 24x  + 24x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                                3   3
+--R                                         atan(----)
+--R                                               +-+
+--R                 8      6      4  +-+         \|3
+--R           (- 24x  + 24x  - 24x )\|3 cos(----------)
+--R                                              2
+--R         + 
+--R                                               3
+--R                                        atan(----)
+--R                                              +-+
+--R               10      8      6  +-+         \|3
+--R           (24x   - 24x  + 24x )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                 3   8                                    3   6
+--R                          atan(----)                               atan(----)
+--R                                +-+                                      +-+
+--R          4     2              \|3             6      4      2          \|3
+--R       (6x  - 6x  + 6)cos(----------)  + (- 12x  + 12x  - 12x )cos(----------)
+--R                               2                                        2
+--R     + 
+--R                                      3   4
+--R                               atan(----)
+--R                                     +-+
+--R           8      6      4          \|3
+--R       (18x  - 18x  + 18x )cos(----------)
+--R                                    2
+--R     + 
+--R                                         3   2
+--R                                  atan(----)
+--R                                        +-+
+--R             10      8      6          \|3         12     10     8
+--R       (- 12x   + 12x  - 12x )cos(----------)  + 6x   - 6x   + 6x
+--R                                       2
+--R                                                    Type: Expression(Integer)
+--E 1290
+
+)clear all
+
+--S 1291 of 2282
+t0:=1/(1+x^4+x^8)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1291
+
+--S 1292 of 2282
+r0:=-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)+1/2*atan((1+2*x)/sqrt(3))/sqrt(3)-_
+   1/4*log(1+x^2-x*sqrt(3))/sqrt(3)+1/4*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                    +-+
+--R             +-+    2                +-+    2              (2x + 1)\|3
+--R       log(x\|3  + x  + 1) - log(- x\|3  + x  + 1) + 2atan(------------)
+--R                                                                 3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3
+--R       2atan(------------)
+--R                   3
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1292
+
+--S 1293 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4     2      +-+     3                 +-+           3
+--R            (x  + 5x  + 1)\|3  + 6x  + 6x          x\|3           x  + 2x
+--R        log(-----------------------------) + 2atan(-----) + 2atan(-------)
+--R                      4    2                         3               +-+
+--R                     x  - x  + 1                                    \|3
+--R   (3)  ------------------------------------------------------------------
+--R                                         +-+
+--R                                       4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1293
+
+--S 1294 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     4     2      +-+     3
+--R               +-+    2            (x  + 5x  + 1)\|3  + 6x  + 6x
+--R       - log(x\|3  + x  + 1) + log(-----------------------------)
+--R                                             4    2
+--R                                            x  - x  + 1
+--R     + 
+--R                                              +-+                   +-+
+--R               +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       log(- x\|3  + x  + 1) - 2atan(------------) - 2atan(------------)
+--R                                           3                     3
+--R     + 
+--R               +-+           3
+--R             x\|3           x  + 2x
+--R       2atan(-----) + 2atan(-------)
+--R               3               +-+
+--R                              \|3
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1294
+
+--S 1295 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1295
+
+)clear all
+
+--S 1296 of 2282
+t0:=1/(x^2*(1+x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         10    6    2
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1296
+
+--S 1297 of 2282
+r0:=(-1)/x+1/4*atan(-2*x+sqrt(3))-1/4*atan(2*x+sqrt(3))-1/8*log(1-x+x^2)+_
+   1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)-1/8*log(1+x^2-x*sqrt(3))/sqrt(3)+_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R               +-+    2          +-+     2              +-+     2
+--R       x log(x\|3  + x  + 1) + x\|3 log(x  + x + 1) - x\|3 log(x  - x + 1)
+--R     + 
+--R                                                    +-+                     +-+
+--R                   +-+    2                (2x + 1)\|3             (2x - 1)\|3
+--R       - x log(- x\|3  + x  + 1) - 2x atan(------------) - 2x atan(------------)
+--R                                                 3                       3
+--R     + 
+--R            +-+      +-+            +-+      +-+           +-+
+--R       - 2x\|3 atan(\|3  + 2x) + 2x\|3 atan(\|3  - 2x) - 8\|3
+--R  /
+--R        +-+
+--R     8x\|3
+--R                                                    Type: Expression(Integer)
+--E 1297
+
+--S 1298 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                          3
+--R                   atan(----)
+--R                         +-+
+--R                        \|3
+--R            2x cos(----------)
+--R                        2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3                   \|3               \|3        2
+--R            log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                       3
+--R                atan(----)
+--R                      +-+
+--R                     \|3
+--R         2x cos(----------)
+--R                     2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R                                           3
+--R                                    atan(----)
+--R                     3                    +-+
+--R              atan(----)                 \|3
+--R                    +-+         cos(----------)
+--R                   \|3                   2
+--R       4x sin(----------)atan(-------------------)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------) - x
+--R                                       2
+--R     + 
+--R                                             3
+--R                                      atan(----)
+--R                       3                    +-+
+--R                atan(----)                 \|3
+--R                      +-+         cos(----------)
+--R                     \|3                   2             +-+     2
+--R       - 4x sin(----------)atan(-------------------) + x\|3 log(x  + x + 1)
+--R                     2                     3
+--R                                    atan(----)
+--R                                          +-+
+--R                                         \|3
+--R                                sin(----------) + x
+--R                                         2
+--R     + 
+--R                                                +-+                    +-+
+--R           +-+     2                   (2x - 1)\|3            (2x + 1)\|3
+--R       - x\|3 log(x  - x + 1) + x atan(------------) + x atan(------------)
+--R                                         2                      2
+--R                                       2x  - 2x - 1           2x  + 2x - 1
+--R     + 
+--R           +-+
+--R       - 8\|3
+--R  /
+--R        +-+
+--R     8x\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1298
+
+--S 1299 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3                   \|3               \|3        2
+--R            log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R                                         3
+--R                                  atan(----)
+--R                   3                    +-+
+--R            atan(----)                 \|3
+--R                  +-+         cos(----------)
+--R                 \|3                   2
+--R       4sin(----------)atan(-------------------)
+--R                 2                     3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------) - x
+--R                                     2
+--R     + 
+--R                                           3
+--R                                    atan(----)
+--R                     3                    +-+
+--R              atan(----)                 \|3
+--R                    +-+         cos(----------)
+--R                   \|3                   2                 +-+    2
+--R       - 4sin(----------)atan(-------------------) - log(x\|3  + x  + 1)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------) + x
+--R                                       2
+--R     + 
+--R                                              +-+                   +-+
+--R               +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       log(- x\|3  + x  + 1) + 2atan(------------) + 2atan(------------)
+--R                                           3                     3
+--R     + 
+--R                                                                   +-+
+--R         +-+      +-+           +-+      +-+              (2x - 1)\|3
+--R       2\|3 atan(\|3  + 2x) - 2\|3 atan(\|3  - 2x) + atan(------------)
+--R                                                            2
+--R                                                          2x  - 2x - 1
+--R     + 
+--R                     +-+
+--R            (2x + 1)\|3
+--R       atan(------------)
+--R              2
+--R            2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1299
+
+--S 1300 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                     3   4                  3   2                  3   2
+--R              atan(----)             atan(----)             atan(----)
+--R                    +-+                    +-+                    +-+
+--R         2         \|3          2         \|3         4          \|3
+--R       3x sin(----------)  + (6x cos(----------)  - 6x )sin(----------)
+--R                   2                      2                      2
+--R     + 
+--R                                       3              3                    3   4
+--R                                atan(----)     atan(----)           atan(----)
+--R                                      +-+            +-+                  +-+
+--R          6     4     2  +-+         \|3            \|3        2         \|3
+--R       (4x  - 4x  + 4x )\|3 cos(----------)sin(----------) + 3x cos(----------)
+--R                                     2              2                    2
+--R     + 
+--R                     3   2
+--R              atan(----)
+--R                    +-+
+--R         4         \|3         6
+--R       6x cos(----------)  + 3x
+--R                   2
+--R  /
+--R                                 3   4
+--R                          atan(----)
+--R                                +-+
+--R          4     2              \|3
+--R       (6x  - 6x  + 6)sin(----------)
+--R                               2
+--R     + 
+--R                                     3   2                                 3   2
+--R                              atan(----)                            atan(----)
+--R                                    +-+                                   +-+
+--R            4      2               \|3          6      4      2          \|3
+--R       ((12x  - 12x  + 12)cos(----------)  - 12x  + 12x  - 12x )sin(----------)
+--R                                   2                                     2
+--R     + 
+--R                                 3   4                                  3   2
+--R                          atan(----)                             atan(----)
+--R                                +-+                                    +-+
+--R          4     2              \|3           6      4      2          \|3
+--R       (6x  - 6x  + 6)cos(----------)  + (12x  - 12x  + 12x )cos(----------)
+--R                               2                                      2
+--R     + 
+--R         8     6     4
+--R       6x  - 6x  + 6x
+--R                                                    Type: Expression(Integer)
+--E 1300
+
+)clear all
+
+--S 1301 of 2282
+t0:=1/(x^4*(1+x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         12    8    4
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1301
+
+--S 1302 of 2282
+r0:=(-1/3)/x^3+1/4*atan(-2*x+sqrt(3))-1/4*atan(2*x+sqrt(3))+_
+   1/8*log(1-x+x^2)-1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)+1/8*log(1+x^2-x*sqrt(3))/sqrt(3)-_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           3      +-+    2          3 +-+     2
+--R       - 3x log(x\|3  + x  + 1) - 3x \|3 log(x  + x + 1)
+--R     + 
+--R                                                                            +-+
+--R         3 +-+     2              3        +-+    2          3     (2x + 1)\|3
+--R       3x \|3 log(x  - x + 1) + 3x log(- x\|3  + x  + 1) - 6x atan(------------)
+--R                                                                         3
+--R     + 
+--R                          +-+
+--R           3     (2x - 1)\|3       3 +-+      +-+           3 +-+      +-+
+--R       - 6x atan(------------) - 6x \|3 atan(\|3  + 2x) + 6x \|3 atan(\|3  - 2x)
+--R                       3
+--R     + 
+--R           +-+
+--R       - 8\|3
+--R  /
+--R        3 +-+
+--R     24x \|3
+--R                                                    Type: Expression(Integer)
+--E 1302
+
+--S 1303 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       3
+--R                atan(----)
+--R                      +-+
+--R           3         \|3
+--R         6x cos(----------)
+--R                     2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              2
+--R     + 
+--R       -
+--R                          3
+--R                   atan(----)
+--R                         +-+
+--R              3         \|3
+--R            6x cos(----------)
+--R                        2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3                  \|3               \|3
+--R                 sin(----------)  - x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3       2
+--R                 x\|3 cos(----------) + x
+--R                               2
+--R     + 
+--R       -
+--R                           3
+--R                    atan(----)
+--R                          +-+
+--R               3         \|3
+--R            12x sin(----------)
+--R                         2
+--R         *
+--R                                  3                     3
+--R                           atan(----)            atan(----)
+--R                                 +-+                   +-+
+--R                                \|3       +-+         \|3
+--R                      3sin(----------) + \|3 cos(----------)
+--R                                2                     2
+--R            atan(-----------------------------------------------)
+--R                                3                  3
+--R                         atan(----)         atan(----)
+--R                               +-+                +-+
+--R                  +-+         \|3                \|3         +-+
+--R                 \|3 sin(----------) - 3cos(----------) - 2x\|3
+--R                              2                  2
+--R     + 
+--R                                                3                     3
+--R                                         atan(----)            atan(----)
+--R                      3                        +-+                   +-+
+--R               atan(----)                     \|3       +-+         \|3
+--R                     +-+            3sin(----------) + \|3 cos(----------)
+--R          3         \|3                       2                     2
+--R       12x sin(----------)atan(-----------------------------------------------)
+--R                    2                         3                  3
+--R                                       atan(----)         atan(----)
+--R                                             +-+                +-+
+--R                                +-+         \|3                \|3         +-+
+--R                               \|3 sin(----------) - 3cos(----------) + 2x\|3
+--R                                            2                  2
+--R     + 
+--R                                                                            +-+
+--R           3 +-+     2              3 +-+     2              3     (2x - 1)\|3
+--R       - 3x \|3 log(x  + x + 1) + 3x \|3 log(x  - x + 1) + 3x atan(------------)
+--R                                                                     2
+--R                                                                   2x  - 2x - 1
+--R     + 
+--R                        +-+
+--R         3     (2x + 1)\|3       +-+
+--R       3x atan(------------) - 8\|3
+--R                 2
+--R               2x  + 2x - 1
+--R  /
+--R        3 +-+
+--R     24x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1303
+
+--S 1304 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              2
+--R     + 
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3                  \|3               \|3
+--R                 sin(----------)  - x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3       2
+--R                 x\|3 cos(----------) + x
+--R                               2
+--R     + 
+--R                                               3                     3
+--R                                        atan(----)            atan(----)
+--R                     3                        +-+                   +-+
+--R              atan(----)                     \|3       +-+         \|3
+--R                    +-+            3sin(----------) + \|3 cos(----------)
+--R                   \|3                       2                     2
+--R       - 4sin(----------)atan(-----------------------------------------------)
+--R                   2                         3                  3
+--R                                      atan(----)         atan(----)
+--R                                            +-+                +-+
+--R                               +-+         \|3                \|3         +-+
+--R                              \|3 sin(----------) - 3cos(----------) - 2x\|3
+--R                                           2                  2
+--R     + 
+--R                                             3                     3
+--R                                      atan(----)            atan(----)
+--R                   3                        +-+                   +-+
+--R            atan(----)                     \|3       +-+         \|3
+--R                  +-+            3sin(----------) + \|3 cos(----------)
+--R                 \|3                       2                     2
+--R       4sin(----------)atan(-----------------------------------------------)
+--R                 2                         3                  3
+--R                                    atan(----)         atan(----)
+--R                                          +-+                +-+
+--R                             +-+         \|3                \|3         +-+
+--R                            \|3 sin(----------) - 3cos(----------) + 2x\|3
+--R                                         2                  2
+--R     + 
+--R                                                                    +-+
+--R             +-+    2                +-+    2              (2x + 1)\|3
+--R       log(x\|3  + x  + 1) - log(- x\|3  + x  + 1) + 2atan(------------)
+--R                                                                 3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3       +-+      +-+           +-+      +-+
+--R       2atan(------------) + 2\|3 atan(\|3  + 2x) - 2\|3 atan(\|3  - 2x)
+--R                   3
+--R     + 
+--R                     +-+                  +-+
+--R            (2x - 1)\|3          (2x + 1)\|3
+--R       atan(------------) + atan(------------)
+--R              2                    2
+--R            2x  - 2x - 1         2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1304
+
+--S 1305 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                               3   8
+--R                        atan(----)
+--R                              +-+
+--R            4     2          \|3
+--R       (- 3x  + 3x )sin(----------)
+--R                             2
+--R     + 
+--R                                  3   2                        3   6
+--R                           atan(----)                   atan(----)
+--R                                 +-+                          +-+
+--R              4      2          \|3         6     4          \|3
+--R       ((- 12x  + 12x )cos(----------)  - 6x  + 6x )sin(----------)
+--R                                2                            2
+--R     + 
+--R                                         3              3   5
+--R                                  atan(----)     atan(----)
+--R                                        +-+            +-+
+--R            6     4     2  +-+         \|3            \|3
+--R       (- 8x  + 8x  + 4x )\|3 cos(----------)sin(----------)
+--R                                       2              2
+--R     + 
+--R                                     3   4                           3   2
+--R                              atan(----)                      atan(----)
+--R                                    +-+                             +-+
+--R                 4      2          \|3            6     4          \|3         8
+--R           (- 18x  + 18x )cos(----------)  + (- 6x  + 6x )cos(----------)  - 6x
+--R                                   2                               2
+--R         + 
+--R             6     4
+--R           6x  + 3x
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                               3   3
+--R                                        atan(----)
+--R                                              +-+
+--R                 6      4     2  +-+         \|3
+--R           (- 16x  + 16x  + 8x )\|3 cos(----------)
+--R                                             2
+--R         + 
+--R                                             3
+--R                                      atan(----)
+--R                                            +-+
+--R                8     6     4  +-+         \|3
+--R           (- 8x  + 8x  + 4x )\|3 cos(----------)
+--R                                           2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                     3   6                         3   4
+--R                              atan(----)                    atan(----)
+--R                                    +-+                           +-+
+--R                 4      2          \|3          6     4          \|3
+--R           (- 12x  + 12x )cos(----------)  + (6x  - 6x )cos(----------)
+--R                                   2                             2
+--R         + 
+--R                                            3   2
+--R                                     atan(----)
+--R                                           +-+
+--R                 8      6      4          \|3         10     8     6
+--R           (- 12x  + 12x  + 30x )cos(----------)  - 3x   + 3x  + 3x
+--R                                          2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                             3   5
+--R                                      atan(----)
+--R                                            +-+
+--R                6     4     2  +-+         \|3
+--R           (- 8x  + 8x  + 4x )\|3 cos(----------)
+--R                                           2
+--R         + 
+--R                                           3   3
+--R                                    atan(----)
+--R                                          +-+
+--R              8     6     4  +-+         \|3
+--R           (8x  - 8x  - 4x )\|3 cos(----------)
+--R                                         2
+--R         + 
+--R                                               3
+--R                                        atan(----)
+--R                                              +-+
+--R                10     8      6  +-+         \|3
+--R           (- 2x   + 2x  + 10x )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                               3   8                         3   6
+--R                        atan(----)                    atan(----)
+--R                              +-+                           +-+
+--R            4     2          \|3          6     4          \|3
+--R       (- 3x  + 3x )cos(----------)  + (6x  - 6x )cos(----------)
+--R                             2                             2
+--R     + 
+--R                                     3   4                                3   2
+--R                              atan(----)                           atan(----)
+--R                                    +-+                                  +-+
+--R            8     6     4          \|3          10     8     6          \|3
+--R       (- 6x  + 6x  + 3x )cos(----------)  + (3x   - 3x  - 3x )cos(----------)
+--R                                   2                                    2
+--R     + 
+--R         8
+--R       3x
+--R  /
+--R                                 3   8
+--R                          atan(----)
+--R                                +-+
+--R          4     2              \|3
+--R       (6x  - 6x  + 6)sin(----------)
+--R                               2
+--R     + 
+--R                                     3   2                                 3   6
+--R                              atan(----)                            atan(----)
+--R                                    +-+                                   +-+
+--R            4      2               \|3          6      4      2          \|3
+--R       ((24x  - 24x  + 24)cos(----------)  + 12x  - 12x  + 12x )sin(----------)
+--R                                   2                                     2
+--R     + 
+--R                                          3              3   5
+--R                                   atan(----)     atan(----)
+--R                                         +-+            +-+
+--R           6      4      2  +-+         \|3            \|3
+--R       (24x  - 24x  + 24x )\|3 cos(----------)sin(----------)
+--R                                        2              2
+--R     + 
+--R                                        3   4
+--R                                 atan(----)
+--R                                       +-+
+--R               4      2               \|3
+--R           (36x  - 36x  + 36)cos(----------)
+--R                                      2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               6      4      2          \|3          8      6      4
+--R           (12x  - 12x  + 12x )cos(----------)  + 18x  - 18x  + 18x
+--R                                        2
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   3
+--R                                       atan(----)
+--R                                             +-+
+--R               6      4      2  +-+         \|3
+--R           (48x  - 48x  + 48x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                              3
+--R                                       atan(----)
+--R                                             +-+
+--R               8      6      4  +-+         \|3
+--R           (24x  - 24x  + 24x )\|3 cos(----------)
+--R                                            2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                        3   6
+--R                                 atan(----)
+--R                                       +-+
+--R               4      2               \|3
+--R           (24x  - 24x  + 24)cos(----------)
+--R                                      2
+--R         + 
+--R                                            3   4
+--R                                     atan(----)
+--R                                           +-+
+--R                 6      4      2          \|3
+--R           (- 12x  + 12x  - 12x )cos(----------)
+--R                                          2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               8      6      4          \|3          10      8      6
+--R           (84x  - 84x  + 84x )cos(----------)  + 12x   - 12x  + 12x
+--R                                        2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   5
+--R                                       atan(----)
+--R                                             +-+
+--R               6      4      2  +-+         \|3
+--R           (24x  - 24x  + 24x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                                3   3
+--R                                         atan(----)
+--R                                               +-+
+--R                 8      6      4  +-+         \|3
+--R           (- 24x  + 24x  - 24x )\|3 cos(----------)
+--R                                              2
+--R         + 
+--R                                               3
+--R                                        atan(----)
+--R                                              +-+
+--R               10      8      6  +-+         \|3
+--R           (24x   - 24x  + 24x )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                 3   8                                    3   6
+--R                          atan(----)                               atan(----)
+--R                                +-+                                      +-+
+--R          4     2              \|3             6      4      2          \|3
+--R       (6x  - 6x  + 6)cos(----------)  + (- 12x  + 12x  - 12x )cos(----------)
+--R                               2                                        2
+--R     + 
+--R                                      3   4
+--R                               atan(----)
+--R                                     +-+
+--R           8      6      4          \|3
+--R       (18x  - 18x  + 18x )cos(----------)
+--R                                    2
+--R     + 
+--R                                         3   2
+--R                                  atan(----)
+--R                                        +-+
+--R             10      8      6          \|3         12     10     8
+--R       (- 12x   + 12x  - 12x )cos(----------)  + 6x   - 6x   + 6x
+--R                                       2
+--R                                                    Type: Expression(Integer)
+--E 1305
+
+)clear all
+
+--S 1306 of 2282
+t0:=1/(x^6*(1+x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         14    10    6
+--R        x   + x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1306
+
+--S 1307 of 2282
+r0:=(-1/5)/x^5+1/x-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)+_
+   1/2*atan((1+2*x)/sqrt(3))/sqrt(3)+1/4*log(1+x^2-x*sqrt(3))/sqrt(3)-_
+   1/4*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           5      +-+    2          5        +-+    2
+--R       - 5x log(x\|3  + x  + 1) + 5x log(- x\|3  + x  + 1)
+--R     + 
+--R                         +-+                      +-+
+--R          5     (2x + 1)\|3        5     (2x - 1)\|3         4      +-+
+--R       10x atan(------------) + 10x atan(------------) + (20x  - 4)\|3
+--R                      3                        3
+--R  /
+--R        5 +-+
+--R     20x \|3
+--R                                                    Type: Expression(Integer)
+--E 1307
+
+--S 1308 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4     2      +-+     3                    +-+
+--R         5    (x  + 5x  + 1)\|3  - 6x  - 6x       5     x\|3
+--R       5x log(-----------------------------) + 10x atan(-----)
+--R                        4    2                            3
+--R                       x  - x  + 1
+--R     + 
+--R                 3
+--R          5     x  + 2x        4      +-+
+--R       10x atan(-------) + (20x  - 4)\|3
+--R                   +-+
+--R                  \|3
+--R  /
+--R        5 +-+
+--R     20x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1308
+
+--S 1309 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   4     2      +-+     3
+--R             +-+    2            (x  + 5x  + 1)\|3  - 6x  - 6x
+--R       log(x\|3  + x  + 1) + log(-----------------------------)
+--R                                           4    2
+--R                                          x  - x  + 1
+--R     + 
+--R                                                +-+                   +-+
+--R                 +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       - log(- x\|3  + x  + 1) - 2atan(------------) - 2atan(------------)
+--R                                             3                     3
+--R     + 
+--R               +-+           3
+--R             x\|3           x  + 2x
+--R       2atan(-----) + 2atan(-------)
+--R               3               +-+
+--R                              \|3
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1309
+
+--S 1310 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1310
+
+)clear all
+
+--S 1311 of 2282
+t0:=1/(x^8*(1+x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         16    12    8
+--R        x   + x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1311
+
+--S 1312 of 2282
+r0:=(-1/7)/x^7+1/3/x^3-1/4*atan(-2*x+sqrt(3))+1/4*atan(2*x+sqrt(3))-_
+   1/8*log(1-x+x^2)+1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)+1/8*log(1+x^2-x*sqrt(3))/sqrt(3)-_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R            7      +-+    2           7 +-+     2
+--R       - 21x log(x\|3  + x  + 1) + 21x \|3 log(x  + x + 1)
+--R     + 
+--R            7 +-+     2               7        +-+    2
+--R       - 21x \|3 log(x  - x + 1) + 21x log(- x\|3  + x  + 1)
+--R     + 
+--R                           +-+                      +-+
+--R            7     (2x + 1)\|3        7     (2x - 1)\|3
+--R       - 42x atan(------------) - 42x atan(------------)
+--R                        3                        3
+--R     + 
+--R          7 +-+      +-+            7 +-+      +-+             4       +-+
+--R       42x \|3 atan(\|3  + 2x) - 42x \|3 atan(\|3  - 2x) + (56x  - 24)\|3
+--R  /
+--R         7 +-+
+--R     168x \|3
+--R                                                    Type: Expression(Integer)
+--E 1312
+
+--S 1313 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R            7         \|3
+--R         42x cos(----------)
+--R                      2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R       -
+--R                           3
+--R                    atan(----)
+--R                          +-+
+--R               7         \|3
+--R            42x cos(----------)
+--R                         2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3                   \|3               \|3        2
+--R            log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                                              3
+--R                                       atan(----)
+--R                        3                    +-+
+--R                 atan(----)                 \|3
+--R                       +-+         cos(----------)
+--R            7         \|3                   2
+--R       - 84x sin(----------)atan(-------------------)
+--R                      2                     3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 sin(----------) - x
+--R                                          2
+--R     + 
+--R                                            3
+--R                                     atan(----)
+--R                      3                    +-+
+--R               atan(----)                 \|3
+--R                     +-+         cos(----------)
+--R          7         \|3                   2              7 +-+     2
+--R       84x sin(----------)atan(-------------------) + 21x \|3 log(x  + x + 1)
+--R                    2                     3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------) + x
+--R                                        2
+--R     + 
+--R                                                     +-+
+--R            7 +-+     2               7     (2x - 1)\|3
+--R       - 21x \|3 log(x  - x + 1) + 21x atan(------------)
+--R                                              2
+--R                                            2x  - 2x - 1
+--R     + 
+--R                         +-+
+--R          7     (2x + 1)\|3         4       +-+
+--R       21x atan(------------) + (56x  - 24)\|3
+--R                  2
+--R                2x  + 2x - 1
+--R  /
+--R         7 +-+
+--R     168x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1313
+
+--S 1314 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3                   \|3               \|3        2
+--R            log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                                           3
+--R                                    atan(----)
+--R                     3                    +-+
+--R              atan(----)                 \|3
+--R                    +-+         cos(----------)
+--R                   \|3                   2
+--R       - 4sin(----------)atan(-------------------)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------) - x
+--R                                       2
+--R     + 
+--R                                         3
+--R                                  atan(----)
+--R                   3                    +-+
+--R            atan(----)                 \|3
+--R                  +-+         cos(----------)
+--R                 \|3                   2                 +-+    2
+--R       4sin(----------)atan(-------------------) + log(x\|3  + x  + 1)
+--R                 2                     3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------) + x
+--R                                     2
+--R     + 
+--R                                                +-+                   +-+
+--R                 +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       - log(- x\|3  + x  + 1) + 2atan(------------) + 2atan(------------)
+--R                                             3                     3
+--R     + 
+--R                                                                     +-+
+--R           +-+      +-+           +-+      +-+              (2x - 1)\|3
+--R       - 2\|3 atan(\|3  + 2x) + 2\|3 atan(\|3  - 2x) + atan(------------)
+--R                                                              2
+--R                                                            2x  - 2x - 1
+--R     + 
+--R                     +-+
+--R            (2x + 1)\|3
+--R       atan(------------)
+--R              2
+--R            2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1314
+
+--S 1315 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                       3   4                    3   2                  3   2
+--R                atan(----)               atan(----)             atan(----)
+--R                      +-+                      +-+                    +-+
+--R           2         \|3            2         \|3         4          \|3
+--R       - 3x sin(----------)  + (- 6x cos(----------)  + 6x )sin(----------)
+--R                     2                        2                      2
+--R     + 
+--R                                         3              3
+--R                                  atan(----)     atan(----)
+--R                                        +-+            +-+
+--R            6     4     2  +-+         \|3            \|3
+--R       (- 4x  + 4x  - 4x )\|3 cos(----------)sin(----------)
+--R                                       2              2
+--R     + 
+--R                       3   4                 3   2
+--R                atan(----)            atan(----)
+--R                      +-+                   +-+
+--R           2         \|3         4         \|3         6
+--R       - 3x cos(----------)  - 6x cos(----------)  - 3x
+--R                     2                     2
+--R  /
+--R                                 3   4
+--R                          atan(----)
+--R                                +-+
+--R          4     2              \|3
+--R       (6x  - 6x  + 6)sin(----------)
+--R                               2
+--R     + 
+--R                                     3   2                                 3   2
+--R                              atan(----)                            atan(----)
+--R                                    +-+                                   +-+
+--R            4      2               \|3          6      4      2          \|3
+--R       ((12x  - 12x  + 12)cos(----------)  - 12x  + 12x  - 12x )sin(----------)
+--R                                   2                                     2
+--R     + 
+--R                                 3   4                                  3   2
+--R                          atan(----)                             atan(----)
+--R                                +-+                                    +-+
+--R          4     2              \|3           6      4      2          \|3
+--R       (6x  - 6x  + 6)cos(----------)  + (12x  - 12x  + 12x )cos(----------)
+--R                               2                                      2
+--R     + 
+--R         8     6     4
+--R       6x  - 6x  + 6x
+--R                                                    Type: Expression(Integer)
+--E 1315
+
+)clear all
+
+--S 1316 of 2282
+t0:=x^m/(1-x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1316
+
+--S 1317 of 2282
+--r0:=-2*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),_
+--   2*x^4/(1+%i*sqrt(3)))/((1+m)*(%i-sqrt(3))*sqrt(3))+2*x^(1+m)*_
+--   hypergeometric(1,1/4*(1+m),1/4*(5+m),2*x^4/(1-%i*sqrt(3)))/_
+--   ((1+m)*sqrt(3)*(%i+sqrt(3)))
+--E 1317
+
+--S 1318 of 2282
+--a0:=integrate(t0,x)
+--E 1318
+
+--S 1319 of 2282
+--m0:=a0-r0
+--E 1319
+
+--S 1320 of 2282
+--d0:=normalize(D(m0,x))
+--E 1320
+
+)clear all
+
+--S 1321 of 2282
+t0:=x^11/(1-x^4+x^8)
+--R 
+--R
+--R             11
+--R            x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1321
+
+--S 1322 of 2282
+r0:=1/4*x^4+1/8*log(1-x^4+x^8)+1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                        4      +-+
+--R         +-+     8    4              (2x  - 1)\|3       4 +-+
+--R        \|3 log(x  - x  + 1) - 2atan(-------------) + 2x \|3
+--R                                           3
+--R   (2)  -----------------------------------------------------
+--R                                  +-+
+--R                                8\|3
+--R                                                    Type: Expression(Integer)
+--E 1322
+
+--S 1323 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        4      +-+
+--R         +-+     8    4              (2x  - 1)\|3       4 +-+
+--R        \|3 log(x  - x  + 1) - 2atan(-------------) + 2x \|3
+--R                                           3
+--R   (3)  -----------------------------------------------------
+--R                                  +-+
+--R                                8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1323
+
+--S 1324 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1324
+
+--S 1325 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1325
+
+)clear all
+
+--S 1326 of 2282
+t0:=x^9/(1-x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1326
+
+--S 1327 of 2282
+r0:=1/2*x^2+1/4*log(1+x^4-x^2*sqrt(3))/sqrt(3)-_
+   1/4*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R               2 +-+    4               2 +-+    4          2 +-+
+--R        - log(x \|3  + x  + 1) + log(- x \|3  + x  + 1) + 2x \|3
+--R   (2)  ---------------------------------------------------------
+--R                                    +-+
+--R                                  4\|3
+--R                                                    Type: Expression(Integer)
+--E 1327
+
+--S 1328 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              8     4      +-+     6     2
+--R            (x  + 5x  + 1)\|3  - 6x  - 6x       2 +-+
+--R        log(------------------------------) + 2x \|3
+--R                       8    4
+--R                      x  - x  + 1
+--R   (3)  ---------------------------------------------
+--R                              +-+
+--R                            4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1328
+
+--S 1329 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    8     4      +-+     6     2
+--R            2 +-+    4            (x  + 5x  + 1)\|3  - 6x  - 6x
+--R       log(x \|3  + x  + 1) + log(------------------------------)
+--R                                             8    4
+--R                                            x  - x  + 1
+--R     + 
+--R                2 +-+    4
+--R       - log(- x \|3  + x  + 1)
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1329
+
+--S 1330 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1330
+
+)clear all
+
+--S 1331 of 2282
+t0:=x^7/(1-x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1331
+
+--S 1332 of 2282
+r0:=1/8*log(1-x^4+x^8)-1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                        4      +-+
+--R         +-+     8    4              (2x  - 1)\|3
+--R        \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           8\|3
+--R                                                    Type: Expression(Integer)
+--E 1332
+
+--S 1333 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        4      +-+
+--R         +-+     8    4              (2x  - 1)\|3
+--R        \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                           3
+--R   (3)  -------------------------------------------
+--R                             +-+
+--R                           8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1333
+
+--S 1334 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1334
+
+--S 1335 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1335
+
+)clear all
+
+--S 1336 of 2282
+t0:=x^5/(1-x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1336
+
+--S 1337 of 2282
+r0:=-1/4*atan(-2*x^2+sqrt(3))+1/4*atan(2*x^2+sqrt(3))+_
+   1/8*log(1+x^4-x^2*sqrt(3))/sqrt(3)-1/8*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R              2 +-+    4               2 +-+    4          +-+      +-+     2
+--R       - log(x \|3  + x  + 1) + log(- x \|3  + x  + 1) + 2\|3 atan(\|3  + 2x )
+--R     + 
+--R           +-+      +-+     2
+--R       - 2\|3 atan(\|3  - 2x )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1337
+
+--S 1338 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         cos(----------)
+--R                  2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3         2         \|3               \|3        4
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R       -
+--R                       3
+--R                atan(----)
+--R                      +-+
+--R                     \|3
+--R            cos(----------)
+--R                     2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3         2         \|3               \|3        4
+--R            log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                                            3
+--R                                     atan(----)
+--R                     3                     +-+
+--R              atan(----)                  \|3
+--R                    +-+          cos(----------)
+--R                   \|3                    2
+--R       - 2sin(----------)atan(--------------------)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3       2
+--R                              sin(----------) - x
+--R                                       2
+--R     + 
+--R                                          3
+--R                                   atan(----)
+--R                   3                     +-+
+--R            atan(----)                  \|3
+--R                  +-+          cos(----------)
+--R                 \|3                    2
+--R       2sin(----------)atan(--------------------)
+--R                 2                     3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3       2
+--R                            sin(----------) + x
+--R                                     2
+--R  /
+--R       +-+
+--R     4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1338
+
+--S 1339 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3         2         \|3               \|3        4
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3         2         \|3               \|3        4
+--R            log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                                            3
+--R                                     atan(----)
+--R                     3                     +-+
+--R              atan(----)                  \|3
+--R                    +-+          cos(----------)
+--R                   \|3                    2
+--R       - 4sin(----------)atan(--------------------)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3       2
+--R                              sin(----------) - x
+--R                                       2
+--R     + 
+--R                                          3
+--R                                   atan(----)
+--R                   3                     +-+
+--R            atan(----)                  \|3
+--R                  +-+          cos(----------)
+--R                 \|3                    2                2 +-+    4
+--R       4sin(----------)atan(--------------------) + log(x \|3  + x  + 1)
+--R                 2                     3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3       2
+--R                            sin(----------) + x
+--R                                     2
+--R     + 
+--R                2 +-+    4          +-+      +-+     2      +-+      +-+     2
+--R       - log(- x \|3  + x  + 1) - 2\|3 atan(\|3  + 2x ) + 2\|3 atan(\|3  - 2x )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1339
+
+--S 1340 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                       3   4                    3   2                  3   2
+--R                atan(----)               atan(----)             atan(----)
+--R                      +-+                      +-+                    +-+
+--R           5         \|3            5         \|3         9          \|3
+--R       - 3x sin(----------)  + (- 6x cos(----------)  + 6x )sin(----------)
+--R                     2                        2                      2
+--R     + 
+--R                                          3              3
+--R                                   atan(----)     atan(----)
+--R                                         +-+            +-+
+--R            13     9     5  +-+         \|3            \|3
+--R       (- 4x   + 4x  - 4x )\|3 cos(----------)sin(----------)
+--R                                        2              2
+--R     + 
+--R                       3   4                 3   2
+--R                atan(----)            atan(----)
+--R                      +-+                   +-+
+--R           5         \|3         9         \|3         13
+--R       - 3x cos(----------)  - 6x cos(----------)  - 3x
+--R                     2                     2
+--R  /
+--R                                 3   4
+--R                          atan(----)
+--R                                +-+
+--R          8     4              \|3
+--R       (3x  - 3x  + 3)sin(----------)
+--R                               2
+--R     + 
+--R                                  3   2                               3   2
+--R                           atan(----)                          atan(----)
+--R                                 +-+                                 +-+
+--R           8     4              \|3         12     8     4          \|3
+--R       ((6x  - 6x  + 6)cos(----------)  - 6x   + 6x  - 6x )sin(----------)
+--R                                2                                   2
+--R     + 
+--R                                 3   4                                3   2
+--R                          atan(----)                           atan(----)
+--R                                +-+                                  +-+
+--R          8     4              \|3          12     8     4          \|3
+--R       (3x  - 3x  + 3)cos(----------)  + (6x   - 6x  + 6x )cos(----------)
+--R                               2                                    2
+--R     + 
+--R         16     12     8
+--R       3x   - 3x   + 3x
+--R                                                    Type: Expression(Integer)
+--E 1340
+
+)clear all
+
+--S 1341 of 2282
+t0:=x^3/(1-x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1341
+
+--S 1342 of 2282
+r0:=-1/2*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                4      +-+
+--R             (2x  - 1)\|3
+--R        atan(-------------)
+--R                   3
+--R   (2)  -------------------
+--R                 +-+
+--R               2\|3
+--R                                                    Type: Expression(Integer)
+--E 1342
+
+--S 1343 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                4      +-+
+--R             (2x  - 1)\|3
+--R        atan(-------------)
+--R                   3
+--R   (3)  -------------------
+--R                 +-+
+--R               2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1343
+
+--S 1344 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1344
+
+--S 1345 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1345
+
+)clear all
+
+--S 1346 of 2282
+t0:=x/(1-x^4+x^8)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1346
+
+--S 1347 of 2282
+r0:=-1/4*atan(-2*x^2+sqrt(3))+1/4*atan(2*x^2+sqrt(3))-_
+   1/8*log(1+x^4-x^2*sqrt(3))/sqrt(3)+1/8*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R            2 +-+    4               2 +-+    4          +-+      +-+     2
+--R       log(x \|3  + x  + 1) - log(- x \|3  + x  + 1) + 2\|3 atan(\|3  + 2x )
+--R     + 
+--R           +-+      +-+     2
+--R       - 2\|3 atan(\|3  - 2x )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1347
+
+--S 1348 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                       3
+--R                atan(----)
+--R                      +-+
+--R                     \|3
+--R            cos(----------)
+--R                     2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3        2         \|3               \|3
+--R                 sin(----------)  + x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                    2 +-+         \|3       4
+--R                 - x \|3 cos(----------) + x
+--R                                  2
+--R     + 
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         cos(----------)
+--R                  2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3        2         \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                               3
+--R                        atan(----)
+--R                              +-+
+--R               2 +-+         \|3       4
+--R              x \|3 cos(----------) + x
+--R                             2
+--R     + 
+--R                                              3                 3
+--R                                       atan(----)        atan(----)
+--R                   3                         +-+               +-+
+--R            atan(----)          +-+         \|3               \|3
+--R                  +-+          \|3 sin(----------) + cos(----------)
+--R                 \|3                        2                 2
+--R       2sin(----------)atan(-------------------------------------------)
+--R                 2                     3                     3
+--R                                atan(----)            atan(----)
+--R                                      +-+                   +-+
+--R                                     \|3       +-+         \|3        2
+--R                            sin(----------) - \|3 cos(----------) - 2x
+--R                                     2                     2
+--R     + 
+--R                                                3                 3
+--R                                         atan(----)        atan(----)
+--R                     3                         +-+               +-+
+--R              atan(----)          +-+         \|3               \|3
+--R                    +-+          \|3 sin(----------) + cos(----------)
+--R                   \|3                        2                 2
+--R       - 2sin(----------)atan(-------------------------------------------)
+--R                   2                     3                     3
+--R                                  atan(----)            atan(----)
+--R                                        +-+                   +-+
+--R                                       \|3       +-+         \|3        2
+--R                              sin(----------) - \|3 cos(----------) + 2x
+--R                                       2                     2
+--R  /
+--R       +-+
+--R     4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1348
+
+--S 1349 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3        2         \|3               \|3
+--R                 sin(----------)  + x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                    2 +-+         \|3       4
+--R                 - x \|3 cos(----------) + x
+--R                                  2
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3        2         \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                               3
+--R                        atan(----)
+--R                              +-+
+--R               2 +-+         \|3       4
+--R              x \|3 cos(----------) + x
+--R                             2
+--R     + 
+--R                                              3                 3
+--R                                       atan(----)        atan(----)
+--R                   3                         +-+               +-+
+--R            atan(----)          +-+         \|3               \|3
+--R                  +-+          \|3 sin(----------) + cos(----------)
+--R                 \|3                        2                 2
+--R       4sin(----------)atan(-------------------------------------------)
+--R                 2                     3                     3
+--R                                atan(----)            atan(----)
+--R                                      +-+                   +-+
+--R                                     \|3       +-+         \|3        2
+--R                            sin(----------) - \|3 cos(----------) - 2x
+--R                                     2                     2
+--R     + 
+--R                                                3                 3
+--R                                         atan(----)        atan(----)
+--R                     3                         +-+               +-+
+--R              atan(----)          +-+         \|3               \|3
+--R                    +-+          \|3 sin(----------) + cos(----------)
+--R                   \|3                        2                 2
+--R       - 4sin(----------)atan(-------------------------------------------)
+--R                   2                     3                     3
+--R                                  atan(----)            atan(----)
+--R                                        +-+                   +-+
+--R                                       \|3       +-+         \|3        2
+--R                              sin(----------) - \|3 cos(----------) + 2x
+--R                                       2                     2
+--R     + 
+--R              2 +-+    4               2 +-+    4          +-+      +-+     2
+--R       - log(x \|3  + x  + 1) + log(- x \|3  + x  + 1) - 2\|3 atan(\|3  + 2x )
+--R     + 
+--R         +-+      +-+     2
+--R       2\|3 atan(\|3  - 2x )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1349
+
+--S 1350 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                             3   8
+--R                      atan(----)
+--R                            +-+
+--R          9     5          \|3
+--R       (3x  - 3x )sin(----------)
+--R                           2
+--R     + 
+--R                                3   2                         3   6
+--R                         atan(----)                    atan(----)
+--R                               +-+                           +-+
+--R            9      5          \|3         13     9          \|3
+--R       ((12x  - 12x )cos(----------)  + 6x   - 6x )sin(----------)
+--R                              2                             2
+--R     + 
+--R                                        3              3   5
+--R                                 atan(----)     atan(----)
+--R                                       +-+            +-+
+--R          13     9     5  +-+         \|3            \|3
+--R       (8x   - 8x  - 4x )\|3 cos(----------)sin(----------)
+--R                                      2              2
+--R     + 
+--R                                   3   4                          3   2
+--R                            atan(----)                     atan(----)
+--R                                  +-+                            +-+
+--R               9      5          \|3          13     9          \|3         17
+--R           (18x  - 18x )cos(----------)  + (6x   - 6x )cos(----------)  + 6x
+--R                                 2                              2
+--R         + 
+--R               13     9
+--R           - 6x   - 3x
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   3
+--R                                       atan(----)
+--R                                             +-+
+--R               13      9     5  +-+         \|3
+--R           (16x   - 16x  - 8x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                             3
+--R                                      atan(----)
+--R                                            +-+
+--R              17     13     9  +-+         \|3
+--R           (8x   - 8x   - 4x )\|3 cos(----------)
+--R                                           2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                   3   6                            3   4
+--R                            atan(----)                       atan(----)
+--R                                  +-+                              +-+
+--R               9      5          \|3            13     9          \|3
+--R           (12x  - 12x )cos(----------)  + (- 6x   + 6x )cos(----------)
+--R                                 2                                2
+--R         + 
+--R                                            3   2
+--R                                     atan(----)
+--R                                           +-+
+--R               17      13      9          \|3         21     17     13
+--R           (12x   - 12x   - 30x )cos(----------)  + 3x   - 3x   - 3x
+--R                                          2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                            3   5
+--R                                     atan(----)
+--R                                           +-+
+--R              13     9     5  +-+         \|3
+--R           (8x   - 8x  - 4x )\|3 cos(----------)
+--R                                          2
+--R         + 
+--R                                               3   3
+--R                                        atan(----)
+--R                                              +-+
+--R                17     13     9  +-+         \|3
+--R           (- 8x   + 8x   + 4x )\|3 cos(----------)
+--R                                             2
+--R         + 
+--R                                               3
+--R                                        atan(----)
+--R                                              +-+
+--R              21     17      13  +-+         \|3
+--R           (2x   - 2x   - 10x  )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                             3   8                            3   6
+--R                      atan(----)                       atan(----)
+--R                            +-+                              +-+
+--R          9     5          \|3            13     9          \|3
+--R       (3x  - 3x )cos(----------)  + (- 6x   + 6x )cos(----------)
+--R                           2                                2
+--R     + 
+--R                                     3   4
+--R                              atan(----)
+--R                                    +-+
+--R          17     13     9          \|3
+--R       (6x   - 6x   - 3x )cos(----------)
+--R                                   2
+--R     + 
+--R                                        3   2
+--R                                 atan(----)
+--R                                       +-+
+--R            21     17     13          \|3         17
+--R       (- 3x   + 3x   + 3x  )cos(----------)  - 3x
+--R                                      2
+--R  /
+--R                                 3   8
+--R                          atan(----)
+--R                                +-+
+--R          8     4              \|3
+--R       (3x  - 3x  + 3)sin(----------)
+--R                               2
+--R     + 
+--R                                     3   2                               3   6
+--R                              atan(----)                          atan(----)
+--R                                    +-+                                 +-+
+--R            8      4               \|3         12     8     4          \|3
+--R       ((12x  - 12x  + 12)cos(----------)  + 6x   - 6x  + 6x )sin(----------)
+--R                                   2                                   2
+--R     + 
+--R                                           3              3   5
+--R                                    atan(----)     atan(----)
+--R                                          +-+            +-+
+--R           12      8      4  +-+         \|3            \|3
+--R       (12x   - 12x  + 12x )\|3 cos(----------)sin(----------)
+--R                                         2              2
+--R     + 
+--R                                        3   4
+--R                                 atan(----)
+--R                                       +-+
+--R               8      4               \|3
+--R           (18x  - 18x  + 18)cos(----------)
+--R                                      2
+--R         + 
+--R                                        3   2
+--R                                 atan(----)
+--R                                       +-+
+--R              12     8     4          \|3         16     12     8
+--R           (6x   - 6x  + 6x )cos(----------)  + 9x   - 9x   + 9x
+--R                                      2
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                               3   3
+--R                                        atan(----)
+--R                                              +-+
+--R               12      8      4  +-+         \|3
+--R           (24x   - 24x  + 24x )\|3 cos(----------)
+--R                                             2
+--R         + 
+--R                                                3
+--R                                         atan(----)
+--R                                               +-+
+--R               16      12      8  +-+         \|3
+--R           (12x   - 12x   + 12x )\|3 cos(----------)
+--R                                              2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                        3   6
+--R                                 atan(----)
+--R                                       +-+
+--R               8      4               \|3
+--R           (12x  - 12x  + 12)cos(----------)
+--R                                      2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R                12     8     4          \|3
+--R           (- 6x   + 6x  - 6x )cos(----------)
+--R                                        2
+--R         + 
+--R                                            3   2
+--R                                     atan(----)
+--R                                           +-+
+--R               16      12      8          \|3         20     16     12
+--R           (42x   - 42x   + 42x )cos(----------)  + 6x   - 6x   + 6x
+--R                                          2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                               3   5
+--R                                        atan(----)
+--R                                              +-+
+--R               12      8      4  +-+         \|3
+--R           (12x   - 12x  + 12x )\|3 cos(----------)
+--R                                             2
+--R         + 
+--R                                                  3   3
+--R                                           atan(----)
+--R                                                 +-+
+--R                 16      12      8  +-+         \|3
+--R           (- 12x   + 12x   - 12x )\|3 cos(----------)
+--R                                                2
+--R         + 
+--R                                                 3
+--R                                          atan(----)
+--R                                                +-+
+--R               20      16      12  +-+         \|3
+--R           (12x   - 12x   + 12x  )\|3 cos(----------)
+--R                                               2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                 3   8                                  3   6
+--R                          atan(----)                             atan(----)
+--R                                +-+                                    +-+
+--R          8     4              \|3            12     8     4          \|3
+--R       (3x  - 3x  + 3)cos(----------)  + (- 6x   + 6x  - 6x )cos(----------)
+--R                               2                                      2
+--R     + 
+--R                                     3   4
+--R                              atan(----)
+--R                                    +-+
+--R          16     12     8          \|3
+--R       (9x   - 9x   + 9x )cos(----------)
+--R                                   2
+--R     + 
+--R                                        3   2
+--R                                 atan(----)
+--R                                       +-+
+--R            20     16     12          \|3         24     20     16
+--R       (- 6x   + 6x   - 6x  )cos(----------)  + 3x   - 3x   + 3x
+--R                                      2
+--R                                                    Type: Expression(Integer)
+--E 1350
+
+)clear all
+
+--S 1351 of 2282
+t0:=1/(x*(1-x^4+x^8))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         9    5
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1351
+
+--S 1352 of 2282
+r0:=log(x)-1/8*log(1-x^4+x^8)-1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                        4      +-+
+--R           +-+     8    4          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 8\|3 log(x) + 2atan(-------------)
+--R                                                           3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   8\|3
+--R                                                    Type: Expression(Integer)
+--E 1352
+
+--S 1353 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        4      +-+
+--R           +-+     8    4          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 8\|3 log(x) + 2atan(-------------)
+--R                                                           3
+--R   (3)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1353
+
+--S 1354 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1354
+
+--S 1355 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1355
+
+)clear all
+
+--S 1356 of 2282
+t0:=1/(x^3*(1-x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         11    7    3
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1356
+
+--S 1357 of 2282
+r0:=(-1/2)/x^2-1/4*log(1+x^4-x^2*sqrt(3))/sqrt(3)+_
+   1/4*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R         2     2 +-+    4         2       2 +-+    4          +-+
+--R        x log(x \|3  + x  + 1) - x log(- x \|3  + x  + 1) - 2\|3
+--R   (2)  ---------------------------------------------------------
+--R                                   2 +-+
+--R                                 4x \|3
+--R                                                    Type: Expression(Integer)
+--E 1357
+
+--S 1358 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                8     4      +-+     6     2
+--R         2    (x  + 5x  + 1)\|3  + 6x  + 6x       +-+
+--R        x log(------------------------------) - 2\|3
+--R                         8    4
+--R                        x  - x  + 1
+--R   (3)  ---------------------------------------------
+--R                             2 +-+
+--R                           4x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1358
+
+--S 1359 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      8     4      +-+     6     2
+--R              2 +-+    4            (x  + 5x  + 1)\|3  + 6x  + 6x
+--R       - log(x \|3  + x  + 1) + log(------------------------------)
+--R                                               8    4
+--R                                              x  - x  + 1
+--R     + 
+--R              2 +-+    4
+--R       log(- x \|3  + x  + 1)
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1359
+
+--S 1360 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1360
+
+)clear all
+
+--S 1361 of 2282
+t0:=1/(x^5*(1-x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         13    9    5
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1361
+
+--S 1362 of 2282
+r0:=(-1/4)/x^4+log(x)-1/8*log(1-x^4+x^8)+1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                         4      +-+
+--R      4 +-+     8    4          4 +-+           4     (2x  - 1)\|3       +-+
+--R   - x \|3 log(x  - x  + 1) + 8x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                            3
+--R   -------------------------------------------------------------------------
+--R                                      4 +-+
+--R                                    8x \|3
+--R                                                    Type: Expression(Integer)
+--E 1362
+
+--S 1363 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                         4      +-+
+--R      4 +-+     8    4          4 +-+           4     (2x  - 1)\|3       +-+
+--R   - x \|3 log(x  - x  + 1) + 8x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                            3
+--R   -------------------------------------------------------------------------
+--R                                      4 +-+
+--R                                    8x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1363
+
+--S 1364 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1364
+
+--S 1365 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1365
+
+)clear all
+
+--S 1366 of 2282
+t0:=1/(x^7*(1-x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         15    11    7
+--R        x   - x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1366
+
+--S 1367 of 2282
+r0:=(-1/6)/x^6+(-1/2)/x^2+1/4*atan(-2*x^2+sqrt(3))-1/4*atan(2*x^2+sqrt(3))-_
+   1/8*log(1+x^4-x^2*sqrt(3))/sqrt(3)+1/8*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         6     2 +-+    4          6       2 +-+    4
+--R       3x log(x \|3  + x  + 1) - 3x log(- x \|3  + x  + 1)
+--R     + 
+--R           6 +-+      +-+     2      6 +-+      +-+     2          4      +-+
+--R       - 6x \|3 atan(\|3  + 2x ) + 6x \|3 atan(\|3  - 2x ) + (- 12x  - 4)\|3
+--R  /
+--R        6 +-+
+--R     24x \|3
+--R                                                    Type: Expression(Integer)
+--E 1367
+
+--S 1368 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                          3
+--R                   atan(----)
+--R                         +-+
+--R              6         \|3
+--R            3x cos(----------)
+--R                        2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3         2         \|3               \|3        4
+--R            log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                       3
+--R                atan(----)
+--R                      +-+
+--R           6         \|3
+--R         3x cos(----------)
+--R                     2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3         2         \|3               \|3        4
+--R         log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R                                            3
+--R                                     atan(----)
+--R                     3                     +-+
+--R              atan(----)                  \|3
+--R                    +-+          cos(----------)
+--R         6         \|3                    2
+--R       6x sin(----------)atan(--------------------)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3       2
+--R                              sin(----------) - x
+--R                                       2
+--R     + 
+--R                                              3
+--R                                       atan(----)
+--R                       3                     +-+
+--R                atan(----)                  \|3
+--R                      +-+          cos(----------)
+--R           6         \|3                    2                4      +-+
+--R       - 6x sin(----------)atan(--------------------) + (- 6x  - 2)\|3
+--R                     2                     3
+--R                                    atan(----)
+--R                                          +-+
+--R                                         \|3       2
+--R                                sin(----------) + x
+--R                                         2
+--R  /
+--R        6 +-+
+--R     12x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1368
+
+--S 1369 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3         2         \|3               \|3        4
+--R            log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3         2         \|3               \|3        4
+--R         log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R                                          3
+--R                                   atan(----)
+--R                   3                     +-+
+--R            atan(----)                  \|3
+--R                  +-+          cos(----------)
+--R                 \|3                    2
+--R       4sin(----------)atan(--------------------)
+--R                 2                     3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3       2
+--R                            sin(----------) - x
+--R                                     2
+--R     + 
+--R                                            3
+--R                                     atan(----)
+--R                     3                     +-+
+--R              atan(----)                  \|3
+--R                    +-+          cos(----------)
+--R                   \|3                    2                2 +-+    4
+--R       - 4sin(----------)atan(--------------------) - log(x \|3  + x  + 1)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3       2
+--R                              sin(----------) + x
+--R                                       2
+--R     + 
+--R              2 +-+    4          +-+      +-+     2      +-+      +-+     2
+--R       log(- x \|3  + x  + 1) + 2\|3 atan(\|3  + 2x ) - 2\|3 atan(\|3  - 2x )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1369
+
+--S 1370 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                     3   4                  3   2                  3   2
+--R              atan(----)             atan(----)             atan(----)
+--R                    +-+                    +-+                    +-+
+--R         5         \|3          5         \|3         9          \|3
+--R       3x sin(----------)  + (6x cos(----------)  - 6x )sin(----------)
+--R                   2                      2                      2
+--R     + 
+--R                                        3              3
+--R                                 atan(----)     atan(----)
+--R                                       +-+            +-+
+--R          13     9     5  +-+         \|3            \|3
+--R       (4x   - 4x  + 4x )\|3 cos(----------)sin(----------)
+--R                                      2              2
+--R     + 
+--R                     3   4                 3   2
+--R              atan(----)            atan(----)
+--R                    +-+                   +-+
+--R         5         \|3         9         \|3         13
+--R       3x cos(----------)  + 6x cos(----------)  + 3x
+--R                   2                     2
+--R  /
+--R                                 3   4
+--R                          atan(----)
+--R                                +-+
+--R          8     4              \|3
+--R       (3x  - 3x  + 3)sin(----------)
+--R                               2
+--R     + 
+--R                                  3   2                               3   2
+--R                           atan(----)                          atan(----)
+--R                                 +-+                                 +-+
+--R           8     4              \|3         12     8     4          \|3
+--R       ((6x  - 6x  + 6)cos(----------)  - 6x   + 6x  - 6x )sin(----------)
+--R                                2                                   2
+--R     + 
+--R                                 3   4                                3   2
+--R                          atan(----)                           atan(----)
+--R                                +-+                                  +-+
+--R          8     4              \|3          12     8     4          \|3
+--R       (3x  - 3x  + 3)cos(----------)  + (6x   - 6x  + 6x )cos(----------)
+--R                               2                                    2
+--R     + 
+--R         16     12     8
+--R       3x   - 3x   + 3x
+--R                                                    Type: Expression(Integer)
+--E 1370
+
+)clear all
+
+--S 1371 of 2282
+t0:=x^8/(1-x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1371
+
+--S 1372 of 2282
+r0:=x-1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*sqrt(1/3*(2-_
+   sqrt(3)))+1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))-1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))+1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))+1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*_
+   sqrt(1/3*(2+sqrt(3)))-1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+_
+   sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+1/8*log(1+x^2-x*sqrt(2+sqrt(3)))*_
+   sqrt(1/3*(2+sqrt(3)))-1/8*log(1+x^2+x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R          +--------+      +--------+
+--R          | +-+           | +-+         2
+--R       - \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R        +----------+      +----------+
+--R        |   +-+           |   +-+         2
+--R       \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +----------+        +----------+
+--R          |   +-+             |   +-+         2
+--R       - \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +--------+        +--------+
+--R        | +-+             | +-+         2
+--R       \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R           +----------+
+--R           |   +-+
+--R         2\|- \|3  + 2
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R              +----------+
+--R              |   +-+
+--R            2\|- \|3  + 2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R         +--------+                 +----------+                +--------+
+--R         | +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R           +--------+                 +----------+                +--------+
+--R           | +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R          +-+
+--R       8x\|3
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1372
+
+--S 1373 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                                                                      3
+--R                                                               atan(----)
+--R                                                                     +-+
+--R                                                                    \|3
+--R                                                           sin(----------)
+--R                                                                    2
+--R                                                      atan(---------------)
+--R                                                                      3
+--R             +-----------------------------------+             atan(----)
+--R             |           3   2              3   2                    +-+
+--R             |    atan(----)         atan(----)                     \|3
+--R             |          +-+                +-+             cos(----------)
+--R             |         \|3                \|3                       2
+--R            4|sin(----------)  + cos(----------)  cos(---------------------)
+--R            \|         2                  2                     2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                              +-----------------------------------+
+--R                              |           3   2              3   2
+--R                              |    atan(----)         atan(----)
+--R                              |          +-+                +-+
+--R                     +-+4+-+  |         \|3                \|3
+--R                   x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                             \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                     4+-+  |         \|3                \|3
+--R                   3x\|9  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R                                                                   3
+--R                                                            atan(----)
+--R                                                                  +-+
+--R                                                                 \|3
+--R                                                        sin(----------)
+--R                                                                 2
+--R                                                   atan(---------------)
+--R                                                                   3
+--R          +-----------------------------------+             atan(----)
+--R          |           3   2              3   2                    +-+
+--R          |    atan(----)         atan(----)                     \|3
+--R          |          +-+                +-+             cos(----------)
+--R          |         \|3                \|3                       2
+--R         4|sin(----------)  + cos(----------)  cos(---------------------)
+--R         \|         2                  2                     2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R              -
+--R                              +-----------------------------------+
+--R                              |           3   2              3   2
+--R                              |    atan(----)         atan(----)
+--R                              |          +-+                +-+
+--R                     +-+4+-+  |         \|3                \|3
+--R                   x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                             \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R              -
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                     4+-+  |         \|3                \|3
+--R                   3x\|9  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R       -
+--R                                                                        3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R               +-----------------------------------+             atan(----)
+--R               |           3   2              3   2                    +-+
+--R               |    atan(----)         atan(----)                     \|3
+--R               |          +-+                +-+             cos(----------)
+--R               |         \|3                \|3                       2
+--R            2 4|sin(----------)  + cos(----------)  sin(---------------------)
+--R              \|         2                  2                     2
+--R         *
+--R            atan
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                   -
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                           |         \|3                \|3
+--R                        3 4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                     *
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 sin(----------)
+--R                                          2
+--R                            atan(---------------)
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 cos(----------)
+--R                                          2
+--R                        cos(---------------------)
+--R                                      2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R                 + 
+--R                        +-+4+-+
+--R                   - 2x\|3 \|9
+--R     + 
+--R                                                                     3
+--R                                                              atan(----)
+--R                                                                    +-+
+--R                                                                   \|3
+--R                                                          sin(----------)
+--R                                                                   2
+--R                                                     atan(---------------)
+--R                                                                     3
+--R            +-----------------------------------+             atan(----)
+--R            |           3   2              3   2                    +-+
+--R            |    atan(----)         atan(----)                     \|3
+--R            |          +-+                +-+             cos(----------)
+--R            |         \|3                \|3                       2
+--R         2 4|sin(----------)  + cos(----------)  sin(---------------------)
+--R           \|         2                  2                     2
+--R      *
+--R         atan
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                -
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  cos(---------------------)
+--R                                2
+--R              + 
+--R                   +-+4+-+
+--R                2x\|3 \|9
+--R     + 
+--R         4+-+
+--R       2x\|9
+--R  /
+--R      4+-+
+--R     2\|9
+--R                                         Type: Union(Expression(Integer),...)
+--E 1373
+
+--S 1374 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                   +-----------------------------------+
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R              +-+  |         \|3                \|3
+--R            4\|3  4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            cos(---------------------)
+--R                          2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                              +-----------------------------------+
+--R                              |           3   2              3   2
+--R                              |    atan(----)         atan(----)
+--R                              |          +-+                +-+
+--R                     +-+4+-+  |         \|3                \|3
+--R                   x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                             \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                     4+-+  |         \|3                \|3
+--R                   3x\|9  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R                                                                         3
+--R                                                                  atan(----)
+--R                                                                        +-+
+--R                                                                       \|3
+--R                                                              sin(----------)
+--R                                                                       2
+--R                                                         atan(---------------)
+--R                                                                         3
+--R                +-----------------------------------+             atan(----)
+--R                |           3   2              3   2                    +-+
+--R                |    atan(----)         atan(----)                     \|3
+--R                |          +-+                +-+             cos(----------)
+--R           +-+  |         \|3                \|3                       2
+--R         4\|3  4|sin(----------)  + cos(----------)  cos(---------------------)
+--R               \|         2                  2                     2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R              -
+--R                              +-----------------------------------+
+--R                              |           3   2              3   2
+--R                              |    atan(----)         atan(----)
+--R                              |          +-+                +-+
+--R                     +-+4+-+  |         \|3                \|3
+--R                   x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                             \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R              -
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                     4+-+  |         \|3                \|3
+--R                   3x\|9  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R       -
+--R                   +-----------------------------------+
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R              +-+  |         \|3                \|3
+--R            8\|3  4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            sin(---------------------)
+--R                          2
+--R         *
+--R            atan
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                   -
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                           |         \|3                \|3
+--R                        3 4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                     *
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 sin(----------)
+--R                                          2
+--R                            atan(---------------)
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 cos(----------)
+--R                                          2
+--R                        cos(---------------------)
+--R                                      2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R                 + 
+--R                        +-+4+-+
+--R                   - 2x\|3 \|9
+--R     + 
+--R                                                                         3
+--R                                                                  atan(----)
+--R                                                                        +-+
+--R                                                                       \|3
+--R                                                              sin(----------)
+--R                                                                       2
+--R                                                         atan(---------------)
+--R                                                                         3
+--R                +-----------------------------------+             atan(----)
+--R                |           3   2              3   2                    +-+
+--R                |    atan(----)         atan(----)                     \|3
+--R                |          +-+                +-+             cos(----------)
+--R           +-+  |         \|3                \|3                       2
+--R         8\|3  4|sin(----------)  + cos(----------)  sin(---------------------)
+--R               \|         2                  2                     2
+--R      *
+--R         atan
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                -
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  cos(---------------------)
+--R                                2
+--R              + 
+--R                   +-+4+-+
+--R                2x\|3 \|9
+--R     + 
+--R            +--------+      +--------+
+--R       4+-+ | +-+           | +-+         2
+--R       \|9 \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R              +----------+      +----------+
+--R         4+-+ |   +-+           |   +-+         2
+--R       - \|9 \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R            +----------+        +----------+
+--R       4+-+ |   +-+             |   +-+         2
+--R       \|9 \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R              +--------+        +--------+
+--R         4+-+ | +-+             | +-+         2
+--R       - \|9 \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R                  +----------+
+--R             4+-+ |   +-+
+--R            2\|9 \|- \|3  + 2
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R               +----------+
+--R          4+-+ |   +-+
+--R         2\|9 \|- \|3  + 2
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R                  +--------+
+--R             4+-+ | +-+
+--R            2\|9 \|\|3  + 2
+--R         *
+--R                             +----------+                +--------+
+--R                    +-+      |   +-+           +-+       | +-+
+--R            atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R             +--------+                 +----------+                +--------+
+--R        4+-+ | +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|9 \|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+4+-+
+--R     8\|3 \|9
+--R                                                    Type: Expression(Integer)
+--E 1374
+
+--S 1375 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                 3   4                      3   2           3   2
+--R                          atan(----)                 atan(----)      atan(----)
+--R                                +-+                        +-+             +-+
+--R               8 4+-+2         \|3        8 4+-+2         \|3             \|3
+--R           - 3x  \|9  sin(----------) - 6x  \|9  cos(----------) sin(----------)
+--R                               2                          2               2
+--R         + 
+--R                                 3   4
+--R                          atan(----)
+--R                                +-+
+--R               8 4+-+2         \|3
+--R           - 3x  \|9  cos(----------)
+--R                               2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                      3   4
+--R                               atan(----)
+--R                                     +-+
+--R                    8 4+-+2         \|3
+--R               - 12x  \|9  sin(----------)
+--R                                    2
+--R             + 
+--R                                      3   2           3   2
+--R                               atan(----)      atan(----)
+--R                                     +-+             +-+
+--R                    8 4+-+2         \|3             \|3
+--R               - 24x  \|9  cos(----------) sin(----------)
+--R                                    2               2
+--R             + 
+--R                                      3   4
+--R                               atan(----)
+--R                                     +-+
+--R                    8 4+-+2         \|3
+--R               - 12x  \|9  cos(----------)
+--R                                    2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                3   2                   3   2
+--R                         atan(----)              atan(----)
+--R                               +-+                     +-+
+--R                   10         \|3          10         \|3
+--R             (- 18x  sin(----------)  - 18x  cos(----------) )
+--R                              2                       2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R               10      6      2  +-+         \|3
+--R           (24x   + 12x  - 12x )\|3 sin(----------)
+--R                                             2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R               10      6      2  +-+         \|3
+--R           (24x   + 12x  - 12x )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                                                                    3
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                             3     5
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                      3   4
+--R                               atan(----)
+--R                                     +-+
+--R                    8 4+-+2         \|3
+--R               - 18x  \|9  sin(----------)
+--R                                    2
+--R             + 
+--R                                      3   2           3   2
+--R                               atan(----)      atan(----)
+--R                                     +-+             +-+
+--R                    8 4+-+2         \|3             \|3
+--R               - 36x  \|9  cos(----------) sin(----------)
+--R                                    2               2
+--R             + 
+--R                                      3   4
+--R                               atan(----)
+--R                                     +-+
+--R                    8 4+-+2         \|3
+--R               - 18x  \|9  cos(----------)
+--R                                    2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                3   2                   3   2
+--R                         atan(----)              atan(----)
+--R                               +-+                     +-+
+--R                   10         \|3          10         \|3
+--R             (- 18x  sin(----------)  - 18x  cos(----------) )
+--R                              2                       2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                12     8     4 4+-+2         \|3
+--R           (- 6x   - 3x  + 3x )\|9  sin(----------)
+--R                                             2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                12     8     4 4+-+2         \|3
+--R           (- 6x   - 3x  + 3x )\|9  cos(----------)
+--R                                             2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (48x   + 24x  - 24x )\|3 sin(----------)
+--R                                                 2
+--R             + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (48x   + 24x  - 24x )\|3 cos(----------)
+--R                                                 2
+--R          *
+--R                                                                        3     3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                  12     8     4  +-+4+-+2         \|3
+--R               (8x   + 4x  - 4x )\|3 \|9  sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                  12     8     4  +-+4+-+2         \|3
+--R               (8x   + 4x  - 4x )\|3 \|9  cos(----------)
+--R                                                   2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3     3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                      3   4
+--R                               atan(----)
+--R                                     +-+
+--R                    8 4+-+2         \|3
+--R               - 12x  \|9  sin(----------)
+--R                                    2
+--R             + 
+--R                                      3   2           3   2
+--R                               atan(----)      atan(----)
+--R                                     +-+             +-+
+--R                    8 4+-+2         \|3             \|3
+--R               - 24x  \|9  cos(----------) sin(----------)
+--R                                    2               2
+--R             + 
+--R                                      3   4
+--R                               atan(----)
+--R                                     +-+
+--R                    8 4+-+2         \|3
+--R               - 12x  \|9  cos(----------)
+--R                                    2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                              3   2                   3   2
+--R                       atan(----)              atan(----)
+--R                             +-+                     +-+
+--R                 10         \|3          10         \|3
+--R             (18x  sin(----------)  + 18x  cos(----------) )
+--R                            2                       2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                      3   2
+--R                                               atan(----)
+--R                                                     +-+
+--R                     12      8      4 4+-+2         \|3
+--R               (- 12x   - 30x  + 30x )\|9  sin(----------)
+--R                                                    2
+--R             + 
+--R                                                      3   2
+--R                                               atan(----)
+--R                                                     +-+
+--R                     12      8      4 4+-+2         \|3
+--R               (- 12x   - 30x  + 30x )\|9  cos(----------)
+--R                                                    2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                  +-----------------------------------+2
+--R                                  |           3   2              3   2
+--R                                  |    atan(----)         atan(----)
+--R                                  |          +-+                +-+
+--R                14     10     6   |         \|3                \|3
+--R           (- 9x   - 9x   + 9x ) 4|sin(----------)  + cos(----------)
+--R                                 \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (24x   + 12x  - 12x )\|3 sin(----------)
+--R                                                 2
+--R             + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (24x   + 12x  - 12x )\|3 cos(----------)
+--R                                                 2
+--R          *
+--R                                                                        3     5
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                       3   2
+--R                                                atan(----)
+--R                                                      +-+
+--R                    12     8     4  +-+4+-+2         \|3
+--R               (- 8x   - 4x  + 4x )\|3 \|9  sin(----------)
+--R                                                     2
+--R             + 
+--R                                                       3   2
+--R                                                atan(----)
+--R                                                      +-+
+--R                    12     8     4  +-+4+-+2         \|3
+--R               (- 8x   - 4x  + 4x )\|3 \|9  cos(----------)
+--R                                                     2
+--R          *
+--R                                 3     3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                        +-----------------------------------+2
+--R                                        |           3   2              3   2
+--R                                        |    atan(----)         atan(----)
+--R                                        |          +-+                +-+
+--R                14      10      6  +-+  |         \|3                \|3
+--R             (6x   + 30x   - 30x )\|3  4|sin(----------)  + cos(----------)
+--R                                       \|         2                  2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                 3   4                      3   2           3   2
+--R                          atan(----)                 atan(----)      atan(----)
+--R                                +-+                        +-+             +-+
+--R               8 4+-+2         \|3        8 4+-+2         \|3             \|3
+--R           - 3x  \|9  sin(----------) - 6x  \|9  cos(----------) sin(----------)
+--R                               2                          2               2
+--R         + 
+--R                                 3   4
+--R                          atan(----)
+--R                                +-+
+--R               8 4+-+2         \|3
+--R           - 3x  \|9  cos(----------)
+--R                               2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                          3   2                   3   2
+--R                   atan(----)              atan(----)
+--R                         +-+                     +-+
+--R             10         \|3          10         \|3
+--R         (18x  sin(----------)  + 18x  cos(----------) )
+--R                        2                       2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                12     8     4 4+-+2         \|3
+--R           (- 6x   - 3x  + 3x )\|9  sin(----------)
+--R                                             2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                12     8     4 4+-+2         \|3
+--R           (- 6x   - 3x  + 3x )\|9  cos(----------)
+--R                                             2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                              +-----------------------------------+2
+--R                              |           3   2              3   2
+--R                              |    atan(----)         atan(----)
+--R                              |          +-+                +-+
+--R            14     10     6   |         \|3                \|3
+--R         (9x   + 9x   - 9x ) 4|sin(----------)  + cos(----------)
+--R                             \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R            12     8 4+-+2
+--R       (- 3x   + 3x )\|9
+--R  /
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                          3   2           3   2
+--R                                   atan(----)      atan(----)
+--R                                         +-+             +-+
+--R              8     4     4+-+2         \|3             \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------) sin(----------)
+--R                                        2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )sin(----------)
+--R                                             2
+--R             + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )cos(----------)
+--R                                             2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 36x   + 36x  - 36x )\|3 sin(----------)
+--R                                               2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 36x   + 36x  - 36x )\|3 cos(----------)
+--R                                               2
+--R      *
+--R                                                                    3
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                             3     5
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (18x  - 18x  + 18)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (36x  - 36x  + 36)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (18x  - 18x  + 18)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )sin(----------)
+--R                                             2
+--R             + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )cos(----------)
+--R                                             2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  cos(----------)
+--R                                           2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 72x   + 72x  - 72x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 72x   + 72x  - 72x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 12x   + 12x  - 12x )\|3 \|9  sin(----------)
+--R                                                        2
+--R             + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 12x   + 12x  - 12x )\|3 \|9  cos(----------)
+--R                                                        2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3     3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 18x   + 18x  - 18x )sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 18x   + 18x  - 18x )cos(----------)
+--R                                               2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                    3   2
+--R                                             atan(----)
+--R                                                   +-+
+--R                   12      8      4 4+-+2         \|3
+--R               (42x   - 42x  + 42x )\|9  sin(----------)
+--R                                                  2
+--R             + 
+--R                                                    3   2
+--R                                             atan(----)
+--R                                                   +-+
+--R                   12      8      4 4+-+2         \|3
+--R               (42x   - 42x  + 42x )\|9  cos(----------)
+--R                                                  2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                   +-----------------------------------+2
+--R                                   |           3   2              3   2
+--R                                   |    atan(----)         atan(----)
+--R                                   |          +-+                +-+
+--R               14      10      6   |         \|3                \|3
+--R           (18x   - 18x   + 18x ) 4|sin(----------)  + cos(----------)
+--R                                  \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 36x   + 36x  - 36x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 36x   + 36x  - 36x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     5
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (12x   - 12x  + 12x )\|3 \|9  sin(----------)
+--R                                                      2
+--R             + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (12x   - 12x  + 12x )\|3 \|9  cos(----------)
+--R                                                      2
+--R          *
+--R                                 3     3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                           +-----------------------------------+2
+--R                                           |           3   2              3   2
+--R                                           |    atan(----)         atan(----)
+--R                                           |          +-+                +-+
+--R                   14      10      6  +-+  |         \|3                \|3
+--R             (- 36x   + 36x   - 36x )\|3  4|sin(----------)  + cos(----------)
+--R                                          \|         2                  2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                          3   2           3   2
+--R                                   atan(----)      atan(----)
+--R                                         +-+             +-+
+--R              8     4     4+-+2         \|3             \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------) sin(----------)
+--R                                        2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R                 10      6      2          \|3
+--R           (- 18x   + 18x  - 18x )sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R                 10      6      2          \|3
+--R           (- 18x   + 18x  - 18x )cos(----------)
+--R                                           2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  cos(----------)
+--R                                           2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                   +-----------------------------------+2
+--R                                   |           3   2              3   2
+--R                                   |    atan(----)         atan(----)
+--R                                   |          +-+                +-+
+--R               14      10      6   |         \|3                \|3
+--R         (- 18x   + 18x   - 18x ) 4|sin(----------)  + cos(----------)
+--R                                  \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R          16     12     8 4+-+2
+--R       (3x   - 3x   + 3x )\|9
+--R                                                    Type: Expression(Integer)
+--E 1375
+
+)clear all
+
+--S 1376 of 2282
+t0:=x^6/(1-x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1376
+
+--S 1377 of 2282
+r0:=-1/2*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)-_
+   1/2*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)+_
+   1/4*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(6)-1/4*log(1+x^2+x*_
+   sqrt(2-sqrt(3)))/sqrt(6)+1/4*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(6)-_
+   1/4*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R               +--------+                   +----------+
+--R               | +-+         2              |   +-+         2
+--R       - log(x\|\|3  + 2  + x  + 1) - log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R               +----------+                     +--------+
+--R               |   +-+         2                | +-+         2
+--R       log(- x\|- \|3  + 2  + x  + 1) + log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R                        +----------+ +--------+                 +----------+
+--R               +-+      |   +-+      | +-+            +-+       |   +-+
+--R       2atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R                           +----------+                +--------+
+--R                  +-+      |   +-+           +-+       | +-+
+--R       - 2atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                         +----------+                +--------+
+--R                +-+      |   +-+           +-+       | +-+
+--R       2atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+
+--R     4\|6
+--R                                                    Type: Expression(Integer)
+--E 1377
+
+--S 1378 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-+ +-+      3      +-+ +-+    4     2
+--R       - \|2 \|3 log((x  + x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R        +-+ +-+        3      +-+ +-+    4     2
+--R       \|2 \|3 log((- x  - x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R                         +-+ +-+                          +-+ +-+
+--R           +-+ +-+      \|2 \|3  + 3x       +-+ +-+      \|2 \|3  - 3x
+--R       - 2\|2 \|3 atan(---------------) + 2\|2 \|3 atan(---------------)
+--R                        2 +-+ +-+                        2 +-+ +-+
+--R                       x \|2 \|3  + 3x                  x \|2 \|3  - 3x
+--R  /
+--R     24
+--R                                         Type: Union(Expression(Integer),...)
+--E 1378
+
+--S 1379 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +--------+                    +----------+
+--R              | +-+         2               |   +-+         2
+--R       6log(x\|\|3  + 2  + x  + 1) + 6log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                  +----------+                      +--------+
+--R                  |   +-+         2                 | +-+         2
+--R       - 6log(- x\|- \|3  + 2  + x  + 1) - 6log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R                           +----------+ +--------+                 +----------+
+--R                  +-+      |   +-+      | +-+            +-+       |   +-+
+--R       - 12atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R                         +----------+ +--------+                   +----------+
+--R                +-+      |   +-+      | +-+              +-+       |   +-+
+--R       12atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R                          +----------+                +--------+
+--R                 +-+      |   +-+           +-+       | +-+
+--R       12atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                            +----------+                +--------+
+--R                   +-+      |   +-+           +-+       | +-+
+--R       - 12atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R          +-+ +-+ +-+      3      +-+ +-+    4     2
+--R       - \|2 \|3 \|6 log((x  + x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R        +-+ +-+ +-+        3      +-+ +-+    4     2
+--R       \|2 \|3 \|6 log((- x  - x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R                           +-+ +-+                              +-+ +-+
+--R         +-+ +-+ +-+      \|2 \|3  + 3x       +-+ +-+ +-+      \|2 \|3  - 3x
+--R     - 2\|2 \|3 \|6 atan(---------------) + 2\|2 \|3 \|6 atan(---------------)
+--R                          2 +-+ +-+                            2 +-+ +-+
+--R                         x \|2 \|3  + 3x                      x \|2 \|3  - 3x
+--R  /
+--R        +-+
+--R     24\|6
+--R                                                    Type: Expression(Integer)
+--E 1379
+
+--S 1380 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                              +--------+                            +----------+
+--R         2 +-+    6    2  +-+ | +-+            2 +-+    6    2  +-+ |   +-+
+--R       (x \|3  - x  - x )\|6 \|\|3  + 2  + (- x \|3  - x  - x )\|6 \|- \|3  + 2
+--R     + 
+--R         6
+--R       6x
+--R  /
+--R       8     4
+--R     6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 1380
+
+)clear all
+
+--S 1381 of 2282
+t0:=x^4/(1-x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1381
+
+--S 1382 of 2282
+r0:=-1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))-_
+   1/8*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/8*log(1+x^2+x*sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))-_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))+_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))-_
+   1/8*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R          +-----------+      +--------+
+--R          |    +-+           | +-+         2
+--R       - \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R        +---------+      +----------+
+--R        |  +-+           |   +-+         2
+--R       \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +---------+        +----------+
+--R          |  +-+             |   +-+         2
+--R       - \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +-----------+        +--------+
+--R        |    +-+             | +-+         2
+--R       \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R           +---------+
+--R           |  +-+
+--R         2\|3\|3  + 6
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R              +---------+
+--R              |  +-+
+--R            2\|3\|3  + 6
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R         +-----------+                 +----------+                +--------+
+--R         |    +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R         +-----------+                 +----------+                +--------+
+--R         |    +-+             +-+      |   +-+           +-+       | +-+
+--R     - 2\|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-----------+ +---------+
+--R       |    +-+      |  +-+
+--R     8\|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 1382
+
+--S 1383 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                   3
+--R                                                            atan(----)
+--R                                                                  +-+
+--R                                                                 \|3
+--R                                                        sin(----------)
+--R                                                                 2
+--R                                                   atan(---------------)
+--R                                                                   3
+--R          +-----------------------------------+             atan(----)
+--R          |           3   2              3   2                    +-+
+--R          |    atan(----)         atan(----)                     \|3
+--R          |          +-+                +-+             cos(----------)
+--R          |         \|3                \|3                       2
+--R         4|sin(----------)  + cos(----------)  cos(---------------------)
+--R         \|         2                  2                     2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                   +-+4+-+  |         \|3                \|3
+--R                2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R             *
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R       -
+--R                                                                      3
+--R                                                               atan(----)
+--R                                                                     +-+
+--R                                                                    \|3
+--R                                                           sin(----------)
+--R                                                                    2
+--R                                                      atan(---------------)
+--R                                                                      3
+--R             +-----------------------------------+             atan(----)
+--R             |           3   2              3   2                    +-+
+--R             |    atan(----)         atan(----)                     \|3
+--R             |          +-+                +-+             cos(----------)
+--R             |         \|3                \|3                       2
+--R            4|sin(----------)  + cos(----------)  cos(---------------------)
+--R            \|         2                  2                     2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                                  +-----------------------------------+
+--R                                  |           3   2              3   2
+--R                                  |    atan(----)         atan(----)
+--R                                  |          +-+                +-+
+--R                         +-+4+-+  |         \|3                \|3
+--R                      2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                                 \|         2                  2
+--R                   *
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               cos(----------)
+--R                                        2
+--R                      sin(---------------------)
+--R                                    2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R       -
+--R                                                                        3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R               +-----------------------------------+             atan(----)
+--R               |           3   2              3   2                    +-+
+--R               |    atan(----)         atan(----)                     \|3
+--R               |          +-+                +-+             cos(----------)
+--R               |         \|3                \|3                       2
+--R            2 4|sin(----------)  + cos(----------)  sin(---------------------)
+--R              \|         2                  2                     2
+--R         *
+--R            atan
+--R                      +-----------------------------------+
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                       +-+4+-+
+--R                   - x\|3 \|9
+--R     + 
+--R                                                                     3
+--R                                                              atan(----)
+--R                                                                    +-+
+--R                                                                   \|3
+--R                                                          sin(----------)
+--R                                                                   2
+--R                                                     atan(---------------)
+--R                                                                     3
+--R            +-----------------------------------+             atan(----)
+--R            |           3   2              3   2                    +-+
+--R            |    atan(----)         atan(----)                     \|3
+--R            |          +-+                +-+             cos(----------)
+--R            |         \|3                \|3                       2
+--R         2 4|sin(----------)  + cos(----------)  sin(---------------------)
+--R           \|         2                  2                     2
+--R      *
+--R         atan
+--R                                                                          3
+--R                                                                   atan(----)
+--R                                                                         +-+
+--R                                                                        \|3
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                          3
+--R                 +-----------------------------------+             atan(----)
+--R                 |           3   2              3   2                    +-+
+--R                 |    atan(----)         atan(----)                     \|3
+--R                 |          +-+                +-+             cos(----------)
+--R                 |         \|3                \|3                       2
+--R              3 4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                \|         2                  2                     2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                  +-+4+-+
+--R                x\|3 \|9
+--R  /
+--R      4+-+
+--R     2\|9
+--R                                         Type: Union(Expression(Integer),...)
+--E 1383
+
+--S 1384 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +-----------------------------------+
+--R                                      |           3   2              3   2
+--R                                      |    atan(----)         atan(----)
+--R           +-----------+ +---------+  |          +-+                +-+
+--R           |    +-+      |  +-+       |         \|3                \|3
+--R         4\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                     \|         2                  2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                   +-+4+-+  |         \|3                \|3
+--R                2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R             *
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R       -
+--R                                         +-----------------------------------+
+--R                                         |           3   2              3   2
+--R                                         |    atan(----)         atan(----)
+--R              +-----------+ +---------+  |          +-+                +-+
+--R              |    +-+      |  +-+       |         \|3                \|3
+--R            4\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                        \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            cos(---------------------)
+--R                          2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                                  +-----------------------------------+
+--R                                  |           3   2              3   2
+--R                                  |    atan(----)         atan(----)
+--R                                  |          +-+                +-+
+--R                         +-+4+-+  |         \|3                \|3
+--R                      2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                                 \|         2                  2
+--R                   *
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               cos(----------)
+--R                                        2
+--R                      sin(---------------------)
+--R                                    2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R       -
+--R                                         +-----------------------------------+
+--R                                         |           3   2              3   2
+--R                                         |    atan(----)         atan(----)
+--R              +-----------+ +---------+  |          +-+                +-+
+--R              |    +-+      |  +-+       |         \|3                \|3
+--R            8\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                        \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            sin(---------------------)
+--R                          2
+--R         *
+--R            atan
+--R                      +-----------------------------------+
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                       +-+4+-+
+--R                   - x\|3 \|9
+--R     + 
+--R                                      +-----------------------------------+
+--R                                      |           3   2              3   2
+--R                                      |    atan(----)         atan(----)
+--R           +-----------+ +---------+  |          +-+                +-+
+--R           |    +-+      |  +-+       |         \|3                \|3
+--R         8\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                     \|         2                  2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R      *
+--R         atan
+--R                                                                          3
+--R                                                                   atan(----)
+--R                                                                         +-+
+--R                                                                        \|3
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                          3
+--R                 +-----------------------------------+             atan(----)
+--R                 |           3   2              3   2                    +-+
+--R                 |    atan(----)         atan(----)                     \|3
+--R                 |          +-+                +-+             cos(----------)
+--R                 |         \|3                \|3                       2
+--R              3 4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                \|         2                  2                     2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                  +-+4+-+
+--R                x\|3 \|9
+--R     + 
+--R            +-----------+      +--------+
+--R       4+-+ |    +-+           | +-+         2
+--R       \|9 \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R              +---------+      +----------+
+--R         4+-+ |  +-+           |   +-+         2
+--R       - \|9 \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R            +---------+        +----------+
+--R       4+-+ |  +-+             |   +-+         2
+--R       \|9 \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R              +-----------+        +--------+
+--R         4+-+ |    +-+             | +-+         2
+--R       - \|9 \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R                  +---------+
+--R             4+-+ |  +-+
+--R            2\|9 \|3\|3  + 6
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R               +---------+
+--R          4+-+ |  +-+
+--R         2\|9 \|3\|3  + 6
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R                  +-----------+
+--R             4+-+ |    +-+
+--R            2\|9 \|- 3\|3  + 6
+--R         *
+--R                             +----------+                +--------+
+--R                    +-+      |   +-+           +-+       | +-+
+--R            atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R           +-----------+                 +----------+                +--------+
+--R      4+-+ |    +-+             +-+      |   +-+           +-+       | +-+
+--R     2\|9 \|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R           +-----------+ +---------+
+--R      4+-+ |    +-+      |  +-+
+--R     8\|9 \|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 1384
+
+--S 1385 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                                +--------+ +---------+
+--R                     4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((- 3x  - 1)\|3  + 5x  + 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                +-----------+ +----------+
+--R                     4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((- 3x  - 1)\|3  - 5x  - 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                 +--------+ +---------+
+--R                     4      +-+      4     4+-+2 | +-+      |  +-+
+--R               ((- 6x  - 2)\|3  + 10x  + 4)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                 +-----------+ +----------+
+--R                     4      +-+      4     4+-+2 |    +-+      |   +-+
+--R               ((- 6x  - 2)\|3  - 10x  - 4)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2           3   2
+--R                 atan(----)      atan(----)
+--R                       +-+             +-+
+--R                      \|3             \|3
+--R             cos(----------) sin(----------)
+--R                      2               2
+--R         + 
+--R                                                +--------+ +---------+
+--R                     4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((- 3x  - 1)\|3  + 5x  + 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                +-----------+ +----------+
+--R                     4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((- 3x  - 1)\|3  - 5x  - 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                      +--------+ +---------+
+--R                          4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((- 12x  - 4)\|3  + 20x  + 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                 ((- 12x  - 4)\|3  - 20x  - 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                       +--------+ +---------+
+--R                          4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((- 24x  - 8)\|3  + 40x  + 16)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                 ((- 24x  - 8)\|3  - 40x  - 16)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2           3   2
+--R                     atan(----)      atan(----)
+--R                           +-+             +-+
+--R                          \|3             \|3
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                                                      +--------+ +---------+
+--R                          4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((- 12x  - 4)\|3  + 20x  + 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                 ((- 12x  - 4)\|3  - 20x  - 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                        6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                   ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                     +--------+ +---------+
+--R                        6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                   ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 24x   + 24x  - 24x )\|3 sin(----------)
+--R                                               2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 24x   + 24x  - 24x )\|3 cos(----------)
+--R                                               2
+--R      *
+--R                                                                    3
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                             3     5
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                       +--------+ +---------+
+--R                          4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((- 18x  - 6)\|3  + 30x  + 12)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                 ((- 18x  - 6)\|3  - 30x  - 12)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                        +--------+ +---------+
+--R                          4       +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((- 36x  - 12)\|3  + 60x  + 24)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                      +-----------+ +----------+
+--R                        4       +-+      4      4+-+2 |    +-+      |   +-+
+--R                 ((- 36x  - 12)\|3  - 60x  - 24)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2           3   2
+--R                     atan(----)      atan(----)
+--R                           +-+             +-+
+--R                          \|3             \|3
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                                                       +--------+ +---------+
+--R                          4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((- 18x  - 6)\|3  + 30x  + 12)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                 ((- 18x  - 6)\|3  - 30x  - 12)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                        6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                   ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                     +--------+ +---------+
+--R                        6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                   ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                       +--------+ +---------+
+--R                      8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((- 18x  - 6x )\|3  + 30x  + 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R             ((- 18x  - 6x )\|3  - 30x  - 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                       +--------+ +---------+
+--R                      8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((- 18x  - 6x )\|3  + 30x  + 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R             ((- 18x  - 6x )\|3  - 30x  - 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 48x   + 48x  - 48x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 48x   + 48x  - 48x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (16x   - 16x  + 16x )\|3 \|9  sin(----------)
+--R                                                      2
+--R             + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (16x   - 16x  + 16x )\|3 \|9  cos(----------)
+--R                                                      2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3     3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                      +--------+ +---------+
+--R                          4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((- 12x  - 4)\|3  + 20x  + 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                 ((- 12x  - 4)\|3  - 20x  - 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                       +--------+ +---------+
+--R                          4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((- 24x  - 8)\|3  + 40x  + 16)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                 ((- 24x  - 8)\|3  - 40x  - 16)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2           3   2
+--R                     atan(----)      atan(----)
+--R                           +-+             +-+
+--R                          \|3             \|3
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                                                      +--------+ +---------+
+--R                          4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((- 12x  - 4)\|3  + 20x  + 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                 ((- 12x  - 4)\|3  - 20x  - 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                       +--------+ +---------+
+--R                          6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                 ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                       +--------+ +---------+
+--R                          6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                 ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                        +--------+ +---------+
+--R                        8     4  +-+      8     4 4+-+2 | +-+      |  +-+
+--R                   ((12x  + 4x )\|3  - 20x  - 8x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                      +-----------+ +----------+
+--R                      8     4  +-+      8     4 4+-+2 |    +-+      |   +-+
+--R                 ((12x  + 4x )\|3  + 20x  + 8x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                        +--------+ +---------+
+--R                        8     4  +-+      8     4 4+-+2 | +-+      |  +-+
+--R                   ((12x  + 4x )\|3  - 20x  - 8x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                      +-----------+ +----------+
+--R                      8     4  +-+      8     4 4+-+2 |    +-+      |   +-+
+--R                 ((12x  + 4x )\|3  + 20x  + 8x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                   +--------+ +---------+
+--R                    10      6  +-+      10      6  | +-+      |  +-+
+--R               ((36x   + 12x )\|3  - 60x   - 24x )\|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                   +-----------+ +----------+
+--R                    10      6  +-+      10      6  |    +-+      |   +-+
+--R               ((36x   + 12x )\|3  + 60x   + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 24x   + 24x  - 24x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 24x   + 24x  - 24x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     5
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 16x   + 16x  - 16x )\|3 \|9  sin(----------)
+--R                                                        2
+--R             + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 16x   + 16x  - 16x )\|3 \|9  cos(----------)
+--R                                                        2
+--R          *
+--R                                 3     3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                           +-----------------------------------+2
+--R                                           |           3   2              3   2
+--R                                           |    atan(----)         atan(----)
+--R                                           |          +-+                +-+
+--R                   14      10      6  +-+  |         \|3                \|3
+--R             (- 24x   + 24x   - 24x )\|3  4|sin(----------)  + cos(----------)
+--R                                          \|         2                  2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                +--------+ +---------+
+--R                     4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((- 3x  - 1)\|3  + 5x  + 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                +-----------+ +----------+
+--R                     4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((- 3x  - 1)\|3  - 5x  - 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                 +--------+ +---------+
+--R                     4      +-+      4     4+-+2 | +-+      |  +-+
+--R               ((- 6x  - 2)\|3  + 10x  + 4)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                 +-----------+ +----------+
+--R                     4      +-+      4     4+-+2 |    +-+      |   +-+
+--R               ((- 6x  - 2)\|3  - 10x  - 4)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2           3   2
+--R                 atan(----)      atan(----)
+--R                       +-+             +-+
+--R                      \|3             \|3
+--R             cos(----------) sin(----------)
+--R                      2               2
+--R         + 
+--R                                                +--------+ +---------+
+--R                     4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((- 3x  - 1)\|3  + 5x  + 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                +-----------+ +----------+
+--R                     4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((- 3x  - 1)\|3  - 5x  - 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                                   +--------+ +---------+
+--R                      6      2  +-+      6      2  | +-+      |  +-+
+--R               ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                   +-----------+ +----------+
+--R                      6      2  +-+      6      2  |    +-+      |   +-+
+--R               ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                   +--------+ +---------+
+--R                      6      2  +-+      6      2  | +-+      |  +-+
+--R               ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                   +-----------+ +----------+
+--R                      6      2  +-+      6      2  |    +-+      |   +-+
+--R               ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                                       +--------+ +---------+
+--R                      8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((- 18x  - 6x )\|3  + 30x  + 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R             ((- 18x  - 6x )\|3  - 30x  - 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                       +--------+ +---------+
+--R                      8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((- 18x  - 6x )\|3  + 30x  + 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R             ((- 18x  - 6x )\|3  - 30x  - 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                                 +--------+ +---------+
+--R                  10      6  +-+      10      6  | +-+      |  +-+
+--R           ((- 36x   - 12x )\|3  + 60x   + 24x )\|\|3  + 2 \|3\|3  + 6
+--R         + 
+--R                                                 +-----------+ +----------+
+--R                  10      6  +-+      10      6  |    +-+      |   +-+
+--R           ((- 36x   - 12x )\|3  - 60x   - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R      *
+--R                                                                    3     2
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                             +--------+ +---------+
+--R             12    8  +-+     12     8 4+-+2 | +-+      |  +-+
+--R       ((- 3x   - x )\|3  + 5x   + 2x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R     + 
+--R                                             +-----------+ +----------+
+--R             12    8  +-+     12     8 4+-+2 |    +-+      |   +-+
+--R       ((- 3x   - x )\|3  - 5x   - 2x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R  /
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                             3   2           3   2
+--R                                      atan(----)      atan(----)
+--R                                            +-+             +-+
+--R               8      4      4+-+2         \|3             \|3
+--R           (12x  - 12x  + 12)\|9  cos(----------) sin(----------)
+--R                                           2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (48x  - 48x  + 48)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )cos(----------)
+--R                                               2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (36x  - 36x  + 36)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (72x  - 72x  + 72)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (36x  - 36x  + 36)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )cos(----------)
+--R                                               2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  sin(----------)
+--R                                              2
+--R         + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  cos(----------)
+--R                                              2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (48x  - 48x  + 48)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (72x   - 72x  + 72x )sin(----------)
+--R                                             2
+--R             + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (72x   - 72x  + 72x )cos(----------)
+--R                                             2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                      3   2
+--R                                               atan(----)
+--R                                                     +-+
+--R                     12      8      4 4+-+2         \|3
+--R               (- 24x   + 24x  - 24x )\|9  sin(----------)
+--R                                                    2
+--R             + 
+--R                                                      3   2
+--R                                               atan(----)
+--R                                                     +-+
+--R                     12      8      4 4+-+2         \|3
+--R               (- 24x   + 24x  - 24x )\|9  cos(----------)
+--R                                                    2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                     +-----------------------------------+2
+--R                                     |           3   2              3   2
+--R                                     |    atan(----)         atan(----)
+--R                                     |          +-+                +-+
+--R                 14      10      6   |         \|3                \|3
+--R           (- 72x   + 72x   - 72x ) 4|sin(----------)  + cos(----------)
+--R                                    \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                             3   2           3   2
+--R                                      atan(----)      atan(----)
+--R                                            +-+             +-+
+--R               8      4      4+-+2         \|3             \|3
+--R           (12x  - 12x  + 12)\|9  cos(----------) sin(----------)
+--R                                           2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                           3   2
+--R                                    atan(----)
+--R                                          +-+
+--R               10      6      2          \|3
+--R           (72x   - 72x  + 72x )sin(----------)
+--R                                         2
+--R         + 
+--R                                           3   2
+--R                                    atan(----)
+--R                                          +-+
+--R               10      6      2          \|3
+--R           (72x   - 72x  + 72x )cos(----------)
+--R                                         2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  sin(----------)
+--R                                              2
+--R         + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  cos(----------)
+--R                                              2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                 +-----------------------------------+2
+--R                                 |           3   2              3   2
+--R                                 |    atan(----)         atan(----)
+--R                                 |          +-+                +-+
+--R             14      10      6   |         \|3                \|3
+--R         (72x   - 72x   + 72x ) 4|sin(----------)  + cos(----------)
+--R                                \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R          16     12     8 4+-+2
+--R       (6x   - 6x   + 6x )\|9
+--R                                                    Type: Expression(Integer)
+--E 1385
+
+)clear all
+
+--S 1386 of 2282
+t0:=x^2/(1-x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1386
+
+--S 1387 of 2282
+r0:=-1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/8*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))-_
+   1/8*log(1+x^2+x*sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))-_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))-_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))+_
+   1/8*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R        +-----------+      +--------+
+--R        |    +-+           | +-+         2
+--R       \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R          +---------+      +----------+
+--R          |  +-+           |   +-+         2
+--R       - \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +---------+        +----------+
+--R        |  +-+             |   +-+         2
+--R       \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +-----------+        +--------+
+--R          |    +-+             | +-+         2
+--R       - \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R           +---------+
+--R           |  +-+
+--R         2\|3\|3  + 6
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R              +---------+
+--R              |  +-+
+--R            2\|3\|3  + 6
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R         +-----------+                 +----------+                +--------+
+--R         |    +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R         +-----------+                 +----------+                +--------+
+--R         |    +-+             +-+      |   +-+           +-+       | +-+
+--R     - 2\|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-----------+ +---------+
+--R       |    +-+      |  +-+
+--R     8\|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 1387
+
+--S 1388 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  0
+--R                                         Type: Union(Expression(Integer),...)
+--E 1388
+
+--S 1389 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +-----------+      +--------+
+--R          |    +-+           | +-+         2
+--R       - \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R        +---------+      +----------+
+--R        |  +-+           |   +-+         2
+--R       \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +---------+        +----------+
+--R          |  +-+             |   +-+         2
+--R       - \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +-----------+        +--------+
+--R        |    +-+             | +-+         2
+--R       \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R              +---------+
+--R              |  +-+
+--R            2\|3\|3  + 6
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R           +---------+
+--R           |  +-+
+--R         2\|3\|3  + 6
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R           +-----------+                 +----------+                +--------+
+--R           |    +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2\|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R         +-----------+                 +----------+                +--------+
+--R         |    +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-----------+ +---------+
+--R       |    +-+      |  +-+
+--R     8\|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 1389
+
+--S 1390 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                      +--------+ +---------+
+--R            6     2  +-+     6     2  | +-+      |  +-+
+--R       ((- x  - 3x )\|3  + 2x  + 5x )\|\|3  + 2 \|3\|3  + 6
+--R     + 
+--R                                      +-----------+ +----------+
+--R            6     2  +-+     6     2  |    +-+      |   +-+
+--R       ((- x  - 3x )\|3  - 2x  - 5x )\|- 3\|3  + 6 \|- \|3  + 2
+--R  /
+--R       8     4
+--R     6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 1390
+
+)clear all
+
+--S 1391 of 2282
+t0:=1/(1-x^4+x^8)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1391
+
+--S 1392 of 2282
+r0:=-1/2*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)-_
+   1/2*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/4*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(6)+1/4*log(1+x^2+x*_
+   sqrt(2-sqrt(3)))/sqrt(6)-1/4*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/4*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R             +--------+                   +----------+
+--R             | +-+         2              |   +-+         2
+--R       log(x\|\|3  + 2  + x  + 1) + log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                 +----------+                     +--------+
+--R                 |   +-+         2                | +-+         2
+--R       - log(- x\|- \|3  + 2  + x  + 1) - log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R                        +----------+ +--------+                 +----------+
+--R               +-+      |   +-+      | +-+            +-+       |   +-+
+--R       2atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R                           +----------+                +--------+
+--R                  +-+      |   +-+           +-+       | +-+
+--R       - 2atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                         +----------+                +--------+
+--R                +-+      |   +-+           +-+       | +-+
+--R       2atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+
+--R     4\|6
+--R                                                    Type: Expression(Integer)
+--E 1392
+
+--S 1393 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        +-+ +-+      3      +-+ +-+    4     2
+--R       \|2 \|3 log((x  + x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R          +-+ +-+        3      +-+ +-+    4     2
+--R       - \|2 \|3 log((- x  - x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R                        +-+ +-+                          +-+ +-+
+--R         +-+ +-+      x\|2 \|3  - 2       +-+ +-+      x\|2 \|3  + 2
+--R       2\|2 \|3 atan(---------------) - 2\|2 \|3 atan(---------------)
+--R                       +-+ +-+     2                    +-+ +-+     2
+--R                     x\|2 \|3  - 2x                   x\|2 \|3  + 2x
+--R  /
+--R     24
+--R                                         Type: Union(Expression(Integer),...)
+--E 1393
+
+--S 1394 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +--------+                    +----------+
+--R                | +-+         2               |   +-+         2
+--R       - 6log(x\|\|3  + 2  + x  + 1) - 6log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                +----------+                      +--------+
+--R                |   +-+         2                 | +-+         2
+--R       6log(- x\|- \|3  + 2  + x  + 1) + 6log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R                           +----------+ +--------+                 +----------+
+--R                  +-+      |   +-+      | +-+            +-+       |   +-+
+--R       - 12atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R                         +----------+ +--------+                   +----------+
+--R                +-+      |   +-+      | +-+              +-+       |   +-+
+--R       12atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R                          +----------+                +--------+
+--R                 +-+      |   +-+           +-+       | +-+
+--R       12atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                            +----------+                +--------+
+--R                   +-+      |   +-+           +-+       | +-+
+--R       - 12atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R        +-+ +-+ +-+      3      +-+ +-+    4     2
+--R       \|2 \|3 \|6 log((x  + x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R          +-+ +-+ +-+        3      +-+ +-+    4     2
+--R       - \|2 \|3 \|6 log((- x  - x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R                            +-+ +-+                              +-+ +-+
+--R         +-+ +-+ +-+      x\|2 \|3  - 2       +-+ +-+ +-+      x\|2 \|3  + 2
+--R       2\|2 \|3 \|6 atan(---------------) - 2\|2 \|3 \|6 atan(---------------)
+--R                           +-+ +-+     2                        +-+ +-+     2
+--R                         x\|2 \|3  - 2x                       x\|2 \|3  + 2x
+--R  /
+--R        +-+
+--R     24\|6
+--R                                                    Type: Expression(Integer)
+--E 1394
+
+--S 1395 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                         +--------+                           +----------+
+--R     4 +-+    4      +-+ | +-+            4 +-+    4      +-+ |   +-+
+--R   (x \|3  - x  - 1)\|6 \|\|3  + 2  + (- x \|3  - x  - 1)\|6 \|- \|3  + 2  + 6
+--R   ---------------------------------------------------------------------------
+--R                                    8     4
+--R                                  6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 1395
+
+)clear all
+
+--S 1396 of 2282
+t0:=1/(x^2*(1-x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         10    6    2
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1396
+
+--S 1397 of 2282
+r0:=(-1)/x-1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))+1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-_
+   sqrt(3)))*sqrt(1/3*(2-sqrt(3)))+1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))-1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*sqrt(1/3*_
+   (2-sqrt(3)))+1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*_
+   sqrt(1/3*(2+sqrt(3)))-1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+_
+   sqrt(3)))*sqrt(1/3*(2+sqrt(3)))-1/8*log(1+x^2-x*sqrt(2+sqrt(3)))*_
+   sqrt(1/3*(2+sqrt(3)))+1/8*log(1+x^2+x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R         +--------+      +--------+
+--R         | +-+           | +-+         2
+--R       x\|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R           +----------+      +----------+
+--R           |   +-+           |   +-+         2
+--R       - x\|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R         +----------+        +----------+
+--R         |   +-+             |   +-+         2
+--R       x\|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R           +--------+        +--------+
+--R           | +-+             | +-+         2
+--R       - x\|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R            +----------+
+--R            |   +-+
+--R         2x\|- \|3  + 2
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R               +----------+
+--R               |   +-+
+--R            2x\|- \|3  + 2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R          +--------+                 +----------+                +--------+
+--R          | +-+             +-+      |   +-+           +-+       | +-+
+--R       2x\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R            +--------+                 +----------+                +--------+
+--R            | +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2x\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R           +-+
+--R       - 8\|3
+--R  /
+--R        +-+
+--R     8x\|3
+--R                                                    Type: Expression(Integer)
+--E 1397
+
+--S 1398 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          1
+--R   (3)  - -
+--R          x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1398
+
+--S 1399 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +--------+      +--------+
+--R          | +-+           | +-+         2
+--R       - \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R        +----------+      +----------+
+--R        |   +-+           |   +-+         2
+--R       \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +----------+        +----------+
+--R          |   +-+             |   +-+         2
+--R       - \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +--------+        +--------+
+--R        | +-+             | +-+         2
+--R       \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R              +----------+
+--R              |   +-+
+--R            2\|- \|3  + 2
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R           +----------+
+--R           |   +-+
+--R         2\|- \|3  + 2
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R           +--------+                 +----------+                +--------+
+--R           | +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R         +--------+                 +----------+                +--------+
+--R         | +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 1399
+
+--S 1400 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           6    2
+--R          x  - x
+--R   (5)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1400
+
+)clear all
+
+--S 1401 of 2282
+t0:=1/(x^4*(1-x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         12    8    4
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1401
+
+--S 1402 of 2282
+r0:=(-1/3)/x^3+1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))-1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))+1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))-1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))-1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+_
+   sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+1/4*atan((2*x+sqrt(2-sqrt(3)))/_
+   sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))-1/8*log(1+x^2-x*sqrt(2+_
+   sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+1/8*log(1+x^2+x*sqrt(2+sqrt(3)))*_
+   sqrt(1/3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R           +--------+      +--------+
+--R         3 | +-+           | +-+         2
+--R       3x \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R             +----------+      +----------+
+--R           3 |   +-+           |   +-+         2
+--R       - 3x \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R           +----------+        +----------+
+--R         3 |   +-+             |   +-+         2
+--R       3x \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R             +--------+        +--------+
+--R           3 | +-+             | +-+         2
+--R       - 3x \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R                +----------+
+--R              3 |   +-+
+--R            6x \|- \|3  + 2
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R             +----------+
+--R           3 |   +-+
+--R         6x \|- \|3  + 2
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R             +--------+                 +----------+                +--------+
+--R           3 | +-+             +-+      |   +-+           +-+       | +-+
+--R       - 6x \|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R           +--------+                 +----------+                +--------+
+--R         3 | +-+             +-+      |   +-+           +-+       | +-+
+--R       6x \|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R           +-+
+--R       - 8\|3
+--R  /
+--R        3 +-+
+--R     24x \|3
+--R                                                    Type: Expression(Integer)
+--E 1402
+
+--S 1403 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                       3
+--R                                                                atan(----)
+--R                                                                      +-+
+--R                                                                     \|3
+--R                                                            sin(----------)
+--R                                                                     2
+--R                                                       atan(---------------)
+--R                                                                       3
+--R              +-----------------------------------+             atan(----)
+--R              |           3   2              3   2                    +-+
+--R              |    atan(----)         atan(----)                     \|3
+--R              |          +-+                +-+             cos(----------)
+--R           3  |         \|3                \|3                       2
+--R         3x  4|sin(----------)  + cos(----------)  cos(---------------------)
+--R             \|         2                  2                     2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                  +-+4+-+  |         \|3                \|3
+--R                x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R             *
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                  4+-+  |         \|3                \|3
+--R                3x\|9  4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R             *
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R       -
+--R                                                                          3
+--R                                                                   atan(----)
+--R                                                                         +-+
+--R                                                                        \|3
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                          3
+--R                 +-----------------------------------+             atan(----)
+--R                 |           3   2              3   2                    +-+
+--R                 |    atan(----)         atan(----)                     \|3
+--R                 |          +-+                +-+             cos(----------)
+--R              3  |         \|3                \|3                       2
+--R            3x  4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                \|         2                  2                     2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                                 +-----------------------------------+
+--R                                 |           3   2              3   2
+--R                                 |    atan(----)         atan(----)
+--R                                 |          +-+                +-+
+--R                        +-+4+-+  |         \|3                \|3
+--R                      x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                                \|         2                  2
+--R                   *
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               cos(----------)
+--R                                        2
+--R                      sin(---------------------)
+--R                                    2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                              +-----------------------------------+
+--R                              |           3   2              3   2
+--R                              |    atan(----)         atan(----)
+--R                              |          +-+                +-+
+--R                        4+-+  |         \|3                \|3
+--R                      3x\|9  4|sin(----------)  + cos(----------)
+--R                             \|         2                  2
+--R                   *
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               cos(----------)
+--R                                        2
+--R                      cos(---------------------)
+--R                                    2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R                                                                       3
+--R                                                                atan(----)
+--R                                                                      +-+
+--R                                                                     \|3
+--R                                                            sin(----------)
+--R                                                                     2
+--R                                                       atan(---------------)
+--R                                                                       3
+--R              +-----------------------------------+             atan(----)
+--R              |           3   2              3   2                    +-+
+--R              |    atan(----)         atan(----)                     \|3
+--R              |          +-+                +-+             cos(----------)
+--R           3  |         \|3                \|3                       2
+--R         6x  4|sin(----------)  + cos(----------)  sin(---------------------)
+--R             \|         2                  2                     2
+--R      *
+--R         atan
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                -
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  cos(---------------------)
+--R                                2
+--R              + 
+--R                     +-+4+-+
+--R                - 2x\|3 \|9
+--R     + 
+--R       -
+--R                                                                          3
+--R                                                                   atan(----)
+--R                                                                         +-+
+--R                                                                        \|3
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                          3
+--R                 +-----------------------------------+             atan(----)
+--R                 |           3   2              3   2                    +-+
+--R                 |    atan(----)         atan(----)                     \|3
+--R                 |          +-+                +-+             cos(----------)
+--R              3  |         \|3                \|3                       2
+--R            6x  4|sin(----------)  + cos(----------)  sin(---------------------)
+--R                \|         2                  2                     2
+--R         *
+--R            atan
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                   -
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                           |         \|3                \|3
+--R                        3 4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                     *
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 sin(----------)
+--R                                          2
+--R                            atan(---------------)
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 cos(----------)
+--R                                          2
+--R                        cos(---------------------)
+--R                                      2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R                 + 
+--R                      +-+4+-+
+--R                   2x\|3 \|9
+--R     + 
+--R          4+-+
+--R       - 2\|9
+--R  /
+--R       3 4+-+
+--R     6x  \|9
+--R                                         Type: Union(Expression(Integer),...)
+--E 1403
+
+--S 1404 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                         3
+--R                                                                  atan(----)
+--R                                                                        +-+
+--R                                                                       \|3
+--R                                                              sin(----------)
+--R                                                                       2
+--R                                                         atan(---------------)
+--R                                                                         3
+--R                +-----------------------------------+             atan(----)
+--R                |           3   2              3   2                    +-+
+--R                |    atan(----)         atan(----)                     \|3
+--R                |          +-+                +-+             cos(----------)
+--R           +-+  |         \|3                \|3                       2
+--R         4\|3  4|sin(----------)  + cos(----------)  cos(---------------------)
+--R               \|         2                  2                     2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                  +-+4+-+  |         \|3                \|3
+--R                x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R             *
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                  4+-+  |         \|3                \|3
+--R                3x\|9  4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R             *
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R       -
+--R                   +-----------------------------------+
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R              +-+  |         \|3                \|3
+--R            4\|3  4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            cos(---------------------)
+--R                          2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                                 +-----------------------------------+
+--R                                 |           3   2              3   2
+--R                                 |    atan(----)         atan(----)
+--R                                 |          +-+                +-+
+--R                        +-+4+-+  |         \|3                \|3
+--R                      x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                                \|         2                  2
+--R                   *
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               cos(----------)
+--R                                        2
+--R                      sin(---------------------)
+--R                                    2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                              +-----------------------------------+
+--R                              |           3   2              3   2
+--R                              |    atan(----)         atan(----)
+--R                              |          +-+                +-+
+--R                        4+-+  |         \|3                \|3
+--R                      3x\|9  4|sin(----------)  + cos(----------)
+--R                             \|         2                  2
+--R                   *
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               cos(----------)
+--R                                        2
+--R                      cos(---------------------)
+--R                                    2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R                                                                         3
+--R                                                                  atan(----)
+--R                                                                        +-+
+--R                                                                       \|3
+--R                                                              sin(----------)
+--R                                                                       2
+--R                                                         atan(---------------)
+--R                                                                         3
+--R                +-----------------------------------+             atan(----)
+--R                |           3   2              3   2                    +-+
+--R                |    atan(----)         atan(----)                     \|3
+--R                |          +-+                +-+             cos(----------)
+--R           +-+  |         \|3                \|3                       2
+--R         8\|3  4|sin(----------)  + cos(----------)  sin(---------------------)
+--R               \|         2                  2                     2
+--R      *
+--R         atan
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                -
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  cos(---------------------)
+--R                                2
+--R              + 
+--R                     +-+4+-+
+--R                - 2x\|3 \|9
+--R     + 
+--R       -
+--R                   +-----------------------------------+
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R              +-+  |         \|3                \|3
+--R            8\|3  4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            sin(---------------------)
+--R                          2
+--R         *
+--R            atan
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                   -
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                           |         \|3                \|3
+--R                        3 4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                     *
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 sin(----------)
+--R                                          2
+--R                            atan(---------------)
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 cos(----------)
+--R                                          2
+--R                        cos(---------------------)
+--R                                      2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R                 + 
+--R                      +-+4+-+
+--R                   2x\|3 \|9
+--R     + 
+--R              +--------+      +--------+
+--R         4+-+ | +-+           | +-+         2
+--R       - \|9 \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R            +----------+      +----------+
+--R       4+-+ |   +-+           |   +-+         2
+--R       \|9 \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R              +----------+        +----------+
+--R         4+-+ |   +-+             |   +-+         2
+--R       - \|9 \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R            +--------+        +--------+
+--R       4+-+ | +-+             | +-+         2
+--R       \|9 \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R               +----------+
+--R          4+-+ |   +-+
+--R         2\|9 \|- \|3  + 2
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R                  +----------+
+--R             4+-+ |   +-+
+--R            2\|9 \|- \|3  + 2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R             +--------+                 +----------+                +--------+
+--R        4+-+ | +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|9 \|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R             +--------+                 +----------+                +--------+
+--R        4+-+ | +-+             +-+      |   +-+           +-+       | +-+
+--R     - 2\|9 \|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+4+-+
+--R     8\|3 \|9
+--R                                                    Type: Expression(Integer)
+--E 1404
+
+--S 1405 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                               3   4                      3   2           3   2
+--R                        atan(----)                 atan(----)      atan(----)
+--R                              +-+                        +-+             +-+
+--R             8 4+-+2         \|3        8 4+-+2         \|3             \|3
+--R           3x  \|9  sin(----------) + 6x  \|9  cos(----------) sin(----------)
+--R                             2                          2               2
+--R         + 
+--R                               3   4
+--R                        atan(----)
+--R                              +-+
+--R             8 4+-+2         \|3
+--R           3x  \|9  cos(----------)
+--R                             2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               12x  \|9  sin(----------)
+--R                                  2
+--R             + 
+--R                                    3   2           3   2
+--R                             atan(----)      atan(----)
+--R                                   +-+             +-+
+--R                  8 4+-+2         \|3             \|3
+--R               24x  \|9  cos(----------) sin(----------)
+--R                                  2               2
+--R             + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               12x  \|9  cos(----------)
+--R                                  2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                              3   2                   3   2
+--R                       atan(----)              atan(----)
+--R                             +-+                     +-+
+--R                 10         \|3          10         \|3
+--R             (18x  sin(----------)  + 18x  cos(----------) )
+--R                            2                       2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 24x   - 12x  + 12x )\|3 sin(----------)
+--R                                               2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 24x   - 12x  + 12x )\|3 cos(----------)
+--R                                               2
+--R      *
+--R                                                                    3
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                             3     5
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               18x  \|9  sin(----------)
+--R                                  2
+--R             + 
+--R                                    3   2           3   2
+--R                             atan(----)      atan(----)
+--R                                   +-+             +-+
+--R                  8 4+-+2         \|3             \|3
+--R               36x  \|9  cos(----------) sin(----------)
+--R                                  2               2
+--R             + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               18x  \|9  cos(----------)
+--R                                  2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                              3   2                   3   2
+--R                       atan(----)              atan(----)
+--R                             +-+                     +-+
+--R                 10         \|3          10         \|3
+--R             (18x  sin(----------)  + 18x  cos(----------) )
+--R                            2                       2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (6x   + 3x  - 3x )\|9  sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (6x   + 3x  - 3x )\|9  cos(----------)
+--R                                           2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 48x   - 24x  + 24x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 48x   - 24x  + 24x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                       3   2
+--R                                                atan(----)
+--R                                                      +-+
+--R                    12     8     4  +-+4+-+2         \|3
+--R               (- 8x   - 4x  + 4x )\|3 \|9  sin(----------)
+--R                                                     2
+--R             + 
+--R                                                       3   2
+--R                                                atan(----)
+--R                                                      +-+
+--R                    12     8     4  +-+4+-+2         \|3
+--R               (- 8x   - 4x  + 4x )\|3 \|9  cos(----------)
+--R                                                     2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3     3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               12x  \|9  sin(----------)
+--R                                  2
+--R             + 
+--R                                    3   2           3   2
+--R                             atan(----)      atan(----)
+--R                                   +-+             +-+
+--R                  8 4+-+2         \|3             \|3
+--R               24x  \|9  cos(----------) sin(----------)
+--R                                  2               2
+--R             + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               12x  \|9  cos(----------)
+--R                                  2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                3   2                   3   2
+--R                         atan(----)              atan(----)
+--R                               +-+                     +-+
+--R                   10         \|3          10         \|3
+--R             (- 18x  sin(----------)  - 18x  cos(----------) )
+--R                              2                       2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                    3   2
+--R                                             atan(----)
+--R                                                   +-+
+--R                   12      8      4 4+-+2         \|3
+--R               (12x   + 30x  - 30x )\|9  sin(----------)
+--R                                                  2
+--R             + 
+--R                                                    3   2
+--R                                             atan(----)
+--R                                                   +-+
+--R                   12      8      4 4+-+2         \|3
+--R               (12x   + 30x  - 30x )\|9  cos(----------)
+--R                                                  2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                +-----------------------------------+2
+--R                                |           3   2              3   2
+--R                                |    atan(----)         atan(----)
+--R                                |          +-+                +-+
+--R              14     10     6   |         \|3                \|3
+--R           (9x   + 9x   - 9x ) 4|sin(----------)  + cos(----------)
+--R                               \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 24x   - 12x  + 12x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 24x   - 12x  + 12x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     5
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                  12     8     4  +-+4+-+2         \|3
+--R               (8x   + 4x  - 4x )\|3 \|9  sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                  12     8     4  +-+4+-+2         \|3
+--R               (8x   + 4x  - 4x )\|3 \|9  cos(----------)
+--R                                                   2
+--R          *
+--R                                 3     3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                          +-----------------------------------+2
+--R                                          |           3   2              3   2
+--R                                          |    atan(----)         atan(----)
+--R                                          |          +-+                +-+
+--R                  14      10      6  +-+  |         \|3                \|3
+--R             (- 6x   - 30x   + 30x )\|3  4|sin(----------)  + cos(----------)
+--R                                         \|         2                  2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                               3   4                      3   2           3   2
+--R                        atan(----)                 atan(----)      atan(----)
+--R                              +-+                        +-+             +-+
+--R             8 4+-+2         \|3        8 4+-+2         \|3             \|3
+--R           3x  \|9  sin(----------) + 6x  \|9  cos(----------) sin(----------)
+--R                             2                          2               2
+--R         + 
+--R                               3   4
+--R                        atan(----)
+--R                              +-+
+--R             8 4+-+2         \|3
+--R           3x  \|9  cos(----------)
+--R                             2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                            3   2                   3   2
+--R                     atan(----)              atan(----)
+--R                           +-+                     +-+
+--R               10         \|3          10         \|3
+--R         (- 18x  sin(----------)  - 18x  cos(----------) )
+--R                          2                       2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (6x   + 3x  - 3x )\|9  sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (6x   + 3x  - 3x )\|9  cos(----------)
+--R                                           2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                +-----------------------------------+2
+--R                                |           3   2              3   2
+--R                                |    atan(----)         atan(----)
+--R                                |          +-+                +-+
+--R              14     10     6   |         \|3                \|3
+--R         (- 9x   - 9x   + 9x ) 4|sin(----------)  + cos(----------)
+--R                               \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R          12     8 4+-+2
+--R       (3x   - 3x )\|9
+--R  /
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                          3   2           3   2
+--R                                   atan(----)      atan(----)
+--R                                         +-+             +-+
+--R              8     4     4+-+2         \|3             \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------) sin(----------)
+--R                                        2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )sin(----------)
+--R                                             2
+--R             + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )cos(----------)
+--R                                             2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 36x   + 36x  - 36x )\|3 sin(----------)
+--R                                               2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 36x   + 36x  - 36x )\|3 cos(----------)
+--R                                               2
+--R      *
+--R                                                                    3
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                             3     5
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (18x  - 18x  + 18)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (36x  - 36x  + 36)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (18x  - 18x  + 18)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )sin(----------)
+--R                                             2
+--R             + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )cos(----------)
+--R                                             2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  cos(----------)
+--R                                           2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 72x   + 72x  - 72x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 72x   + 72x  - 72x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 12x   + 12x  - 12x )\|3 \|9  sin(----------)
+--R                                                        2
+--R             + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 12x   + 12x  - 12x )\|3 \|9  cos(----------)
+--R                                                        2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3     3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 18x   + 18x  - 18x )sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 18x   + 18x  - 18x )cos(----------)
+--R                                               2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                    3   2
+--R                                             atan(----)
+--R                                                   +-+
+--R                   12      8      4 4+-+2         \|3
+--R               (42x   - 42x  + 42x )\|9  sin(----------)
+--R                                                  2
+--R             + 
+--R                                                    3   2
+--R                                             atan(----)
+--R                                                   +-+
+--R                   12      8      4 4+-+2         \|3
+--R               (42x   - 42x  + 42x )\|9  cos(----------)
+--R                                                  2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                   +-----------------------------------+2
+--R                                   |           3   2              3   2
+--R                                   |    atan(----)         atan(----)
+--R                                   |          +-+                +-+
+--R               14      10      6   |         \|3                \|3
+--R           (18x   - 18x   + 18x ) 4|sin(----------)  + cos(----------)
+--R                                  \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 36x   + 36x  - 36x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 36x   + 36x  - 36x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     5
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (12x   - 12x  + 12x )\|3 \|9  sin(----------)
+--R                                                      2
+--R             + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (12x   - 12x  + 12x )\|3 \|9  cos(----------)
+--R                                                      2
+--R          *
+--R                                 3     3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                           +-----------------------------------+2
+--R                                           |           3   2              3   2
+--R                                           |    atan(----)         atan(----)
+--R                                           |          +-+                +-+
+--R                   14      10      6  +-+  |         \|3                \|3
+--R             (- 36x   + 36x   - 36x )\|3  4|sin(----------)  + cos(----------)
+--R                                          \|         2                  2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                          3   2           3   2
+--R                                   atan(----)      atan(----)
+--R                                         +-+             +-+
+--R              8     4     4+-+2         \|3             \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------) sin(----------)
+--R                                        2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R                 10      6      2          \|3
+--R           (- 18x   + 18x  - 18x )sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R                 10      6      2          \|3
+--R           (- 18x   + 18x  - 18x )cos(----------)
+--R                                           2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  cos(----------)
+--R                                           2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                   +-----------------------------------+2
+--R                                   |           3   2              3   2
+--R                                   |    atan(----)         atan(----)
+--R                                   |          +-+                +-+
+--R               14      10      6   |         \|3                \|3
+--R         (- 18x   + 18x   - 18x ) 4|sin(----------)  + cos(----------)
+--R                                  \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R          16     12     8 4+-+2
+--R       (3x   - 3x   + 3x )\|9
+--R                                                    Type: Expression(Integer)
+--E 1405
+
+)clear all
+
+--S 1406 of 2282
+t0:=1/(x^6*(1-x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         14    10    6
+--R        x   - x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1406
+
+--S 1407 of 2282
+r0:=(-1/5)/x^5+(-1)/x+1/2*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/_
+   sqrt(6)-1/2*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/2*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/2*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/4*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(6)+1/4*log(1+x^2+x*_
+   sqrt(2-sqrt(3)))/sqrt(6)-1/4*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/4*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R                +--------+                      +----------+
+--R         5      | +-+         2          5      |   +-+         2
+--R       5x log(x\|\|3  + 2  + x  + 1) + 5x log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                    +----------+                        +--------+
+--R           5        |   +-+         2          5        | +-+         2
+--R       - 5x log(- x\|- \|3  + 2  + x  + 1) - 5x log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R               5
+--R            10x
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R            5
+--R         10x
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R                            +----------+                +--------+
+--R          5        +-+      |   +-+           +-+       | +-+
+--R       10x atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                              +----------+                +--------+
+--R            5        +-+      |   +-+           +-+       | +-+
+--R       - 10x atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R             4      +-+
+--R       (- 20x  - 4)\|6
+--R  /
+--R        5 +-+
+--R     20x \|6
+--R                                                    Type: Expression(Integer)
+--E 1407
+
+--S 1408 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         5 +-+ +-+      3      +-+ +-+    4     2
+--R       5x \|2 \|3 log((x  + x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R           5 +-+ +-+        3      +-+ +-+    4     2
+--R       - 5x \|2 \|3 log((- x  - x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R                          +-+ +-+                             +-+ +-+
+--R          5 +-+ +-+      \|2 \|3  + 3x        5 +-+ +-+      \|2 \|3  - 3x
+--R       10x \|2 \|3 atan(---------------) - 10x \|2 \|3 atan(---------------)
+--R                         2 +-+ +-+                           2 +-+ +-+
+--R                        x \|2 \|3  + 3x                     x \|2 \|3  - 3x
+--R     + 
+--R             4
+--R       - 120x  - 24
+--R  /
+--R         5
+--R     120x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1408
+
+--S 1409 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +--------+                    +----------+
+--R                | +-+         2               |   +-+         2
+--R       - 6log(x\|\|3  + 2  + x  + 1) - 6log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                +----------+                      +--------+
+--R                |   +-+         2                 | +-+         2
+--R       6log(- x\|- \|3  + 2  + x  + 1) + 6log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R       12atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R            12
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R                            +----------+                +--------+
+--R                   +-+      |   +-+           +-+       | +-+
+--R       - 12atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                          +----------+                +--------+
+--R                 +-+      |   +-+           +-+       | +-+
+--R       12atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R        +-+ +-+ +-+      3      +-+ +-+    4     2
+--R       \|2 \|3 \|6 log((x  + x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R          +-+ +-+ +-+        3      +-+ +-+    4     2
+--R       - \|2 \|3 \|6 log((- x  - x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R                           +-+ +-+                              +-+ +-+
+--R         +-+ +-+ +-+      \|2 \|3  + 3x       +-+ +-+ +-+      \|2 \|3  - 3x
+--R       2\|2 \|3 \|6 atan(---------------) - 2\|2 \|3 \|6 atan(---------------)
+--R                          2 +-+ +-+                            2 +-+ +-+
+--R                         x \|2 \|3  + 3x                      x \|2 \|3  - 3x
+--R  /
+--R        +-+
+--R     24\|6
+--R                                                    Type: Expression(Integer)
+--E 1409
+
+--S 1410 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                +--------+                          +----------+
+--R           2 +-+    6    2  +-+ | +-+          2 +-+    6    2  +-+ |   +-+
+--R       (- x \|3  + x  + x )\|6 \|\|3  + 2  + (x \|3  + x  + x )\|6 \|- \|3  + 2
+--R     + 
+--R           6
+--R       - 6x
+--R  /
+--R       8     4
+--R     6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 1410
+
+)clear all
+
+--S 1411 of 2282
+t0:=1/(x^8*(1-x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         16    12    8
+--R        x   - x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1411
+
+--S 1412 of 2282
+r0:=(-1/7)/x^7+(-1/3)/x^3+1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-_
+   sqrt(3)))/sqrt(3*(2-sqrt(3)))-1/4*atan((2*x+sqrt(2+sqrt(3)))/_
+   sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+1/8*log(1+x^2-x*sqrt(2-_
+   sqrt(3)))/sqrt(3*(2-sqrt(3)))-1/8*log(1+x^2+x*sqrt(2-sqrt(3)))/_
+   sqrt(3*(2-sqrt(3)))-1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/_
+   sqrt(3*(2+sqrt(3)))+1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/_
+   sqrt(3*(2+sqrt(3)))-1/8*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(3*(2+_
+   sqrt(3)))+1/8*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R            +-----------+      +--------+
+--R          7 |    +-+           | +-+         2
+--R       21x \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R              +---------+      +----------+
+--R            7 |  +-+           |   +-+         2
+--R       - 21x \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R            +---------+        +----------+
+--R          7 |  +-+             |   +-+         2
+--R       21x \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R              +-----------+        +--------+
+--R            7 |    +-+             | +-+         2
+--R       - 21x \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R                 +---------+
+--R               7 |  +-+
+--R            42x \|3\|3  + 6
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R              +---------+
+--R            7 |  +-+
+--R         42x \|3\|3  + 6
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R                 +-----------+
+--R               7 |    +-+
+--R            42x \|- 3\|3  + 6
+--R         *
+--R                             +----------+                +--------+
+--R                    +-+      |   +-+           +-+       | +-+
+--R            atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R              +-----------+
+--R            7 |    +-+
+--R         42x \|- 3\|3  + 6
+--R      *
+--R                          +----------+                +--------+
+--R                 +-+      |   +-+           +-+       | +-+
+--R         atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R                     +-----------+ +---------+
+--R             4       |    +-+      |  +-+
+--R       (- 56x  - 24)\|- 3\|3  + 6 \|3\|3  + 6
+--R  /
+--R           +-----------+ +---------+
+--R         7 |    +-+      |  +-+
+--R     168x \|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 1412
+
+--S 1413 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                                                                           3
+--R                                                                    atan(----)
+--R                                                                          +-+
+--R                                                                         \|3
+--R                                                                sin(----------)
+--R                                                                         2
+--R                                                           atan(---------------)
+--R                                                                           3
+--R                  +-----------------------------------+             atan(----)
+--R                  |           3   2              3   2                    +-+
+--R                  |    atan(----)         atan(----)                     \|3
+--R                  |          +-+                +-+             cos(----------)
+--R               7  |         \|3                \|3                       2
+--R            21x  4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                 \|         2                  2                     2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                               +-----------------------------------+
+--R                               |           3   2              3   2
+--R                               |    atan(----)         atan(----)
+--R                               |          +-+                +-+
+--R                      +-+4+-+  |         \|3                \|3
+--R                   2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                              \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R                                                                        3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R               +-----------------------------------+             atan(----)
+--R               |           3   2              3   2                    +-+
+--R               |    atan(----)         atan(----)                     \|3
+--R               |          +-+                +-+             cos(----------)
+--R            7  |         \|3                \|3                       2
+--R         21x  4|sin(----------)  + cos(----------)  cos(---------------------)
+--R              \|         2                  2                     2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R              -
+--R                               +-----------------------------------+
+--R                               |           3   2              3   2
+--R                               |    atan(----)         atan(----)
+--R                               |          +-+                +-+
+--R                      +-+4+-+  |         \|3                \|3
+--R                   2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                              \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R                                                                        3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R               +-----------------------------------+             atan(----)
+--R               |           3   2              3   2                    +-+
+--R               |    atan(----)         atan(----)                     \|3
+--R               |          +-+                +-+             cos(----------)
+--R            7  |         \|3                \|3                       2
+--R         42x  4|sin(----------)  + cos(----------)  sin(---------------------)
+--R              \|         2                  2                     2
+--R      *
+--R         atan
+--R                                                                          3
+--R                                                                   atan(----)
+--R                                                                         +-+
+--R                                                                        \|3
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                          3
+--R                 +-----------------------------------+             atan(----)
+--R                 |           3   2              3   2                    +-+
+--R                 |    atan(----)         atan(----)                     \|3
+--R                 |          +-+                +-+             cos(----------)
+--R                 |         \|3                \|3                       2
+--R              3 4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                \|         2                  2                     2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                    +-+4+-+
+--R                - x\|3 \|9
+--R     + 
+--R       -
+--R                                                                           3
+--R                                                                    atan(----)
+--R                                                                          +-+
+--R                                                                         \|3
+--R                                                                sin(----------)
+--R                                                                         2
+--R                                                           atan(---------------)
+--R                                                                           3
+--R                  +-----------------------------------+             atan(----)
+--R                  |           3   2              3   2                    +-+
+--R                  |    atan(----)         atan(----)                     \|3
+--R                  |          +-+                +-+             cos(----------)
+--R               7  |         \|3                \|3                       2
+--R            42x  4|sin(----------)  + cos(----------)  sin(---------------------)
+--R                 \|         2                  2                     2
+--R         *
+--R            atan
+--R                      +-----------------------------------+
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                     +-+4+-+
+--R                   x\|3 \|9
+--R     + 
+--R             4     4+-+
+--R       (- 14x  - 6)\|9
+--R  /
+--R        7 4+-+
+--R     42x  \|9
+--R                                         Type: Union(Expression(Integer),...)
+--E 1413
+
+--S 1414 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                         +-----------------------------------+
+--R                                         |           3   2              3   2
+--R                                         |    atan(----)         atan(----)
+--R              +-----------+ +---------+  |          +-+                +-+
+--R              |    +-+      |  +-+       |         \|3                \|3
+--R            4\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                        \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            cos(---------------------)
+--R                          2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                               +-----------------------------------+
+--R                               |           3   2              3   2
+--R                               |    atan(----)         atan(----)
+--R                               |          +-+                +-+
+--R                      +-+4+-+  |         \|3                \|3
+--R                   2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                              \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R                                      +-----------------------------------+
+--R                                      |           3   2              3   2
+--R                                      |    atan(----)         atan(----)
+--R           +-----------+ +---------+  |          +-+                +-+
+--R           |    +-+      |  +-+       |         \|3                \|3
+--R         4\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                     \|         2                  2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R              -
+--R                               +-----------------------------------+
+--R                               |           3   2              3   2
+--R                               |    atan(----)         atan(----)
+--R                               |          +-+                +-+
+--R                      +-+4+-+  |         \|3                \|3
+--R                   2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                              \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R                                      +-----------------------------------+
+--R                                      |           3   2              3   2
+--R                                      |    atan(----)         atan(----)
+--R           +-----------+ +---------+  |          +-+                +-+
+--R           |    +-+      |  +-+       |         \|3                \|3
+--R         8\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                     \|         2                  2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R      *
+--R         atan
+--R                                                                          3
+--R                                                                   atan(----)
+--R                                                                         +-+
+--R                                                                        \|3
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                          3
+--R                 +-----------------------------------+             atan(----)
+--R                 |           3   2              3   2                    +-+
+--R                 |    atan(----)         atan(----)                     \|3
+--R                 |          +-+                +-+             cos(----------)
+--R                 |         \|3                \|3                       2
+--R              3 4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                \|         2                  2                     2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                    +-+4+-+
+--R                - x\|3 \|9
+--R     + 
+--R       -
+--R                                         +-----------------------------------+
+--R                                         |           3   2              3   2
+--R                                         |    atan(----)         atan(----)
+--R              +-----------+ +---------+  |          +-+                +-+
+--R              |    +-+      |  +-+       |         \|3                \|3
+--R            8\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                        \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            sin(---------------------)
+--R                          2
+--R         *
+--R            atan
+--R                      +-----------------------------------+
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                     +-+4+-+
+--R                   x\|3 \|9
+--R     + 
+--R              +-----------+      +--------+
+--R         4+-+ |    +-+           | +-+         2
+--R       - \|9 \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R            +---------+      +----------+
+--R       4+-+ |  +-+           |   +-+         2
+--R       \|9 \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R              +---------+        +----------+
+--R         4+-+ |  +-+             |   +-+         2
+--R       - \|9 \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R            +-----------+        +--------+
+--R       4+-+ |    +-+             | +-+         2
+--R       \|9 \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R               +---------+
+--R          4+-+ |  +-+
+--R         2\|9 \|3\|3  + 6
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R                  +---------+
+--R             4+-+ |  +-+
+--R            2\|9 \|3\|3  + 6
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R               +-----------+
+--R          4+-+ |    +-+
+--R         2\|9 \|- 3\|3  + 6
+--R      *
+--R                          +----------+                +--------+
+--R                 +-+      |   +-+           +-+       | +-+
+--R         atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R       -
+--R                  +-----------+
+--R             4+-+ |    +-+
+--R            2\|9 \|- 3\|3  + 6
+--R         *
+--R                             +----------+                +--------+
+--R                    +-+      |   +-+           +-+       | +-+
+--R            atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R           +-----------+ +---------+
+--R      4+-+ |    +-+      |  +-+
+--R     8\|9 \|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 1414
+
+--S 1415 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                              +--------+ +---------+
+--R                   4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((3x  + 1)\|3  - 5x  - 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                              +-----------+ +----------+
+--R                   4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((3x  + 1)\|3  + 5x  + 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                               +--------+ +---------+
+--R                   4      +-+      4     4+-+2 | +-+      |  +-+
+--R               ((6x  + 2)\|3  - 10x  - 4)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                               +-----------+ +----------+
+--R                   4      +-+      4     4+-+2 |    +-+      |   +-+
+--R               ((6x  + 2)\|3  + 10x  + 4)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2           3   2
+--R                 atan(----)      atan(----)
+--R                       +-+             +-+
+--R                      \|3             \|3
+--R             cos(----------) sin(----------)
+--R                      2               2
+--R         + 
+--R                                              +--------+ +---------+
+--R                   4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((3x  + 1)\|3  - 5x  - 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                              +-----------+ +----------+
+--R                   4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((3x  + 1)\|3  + 5x  + 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                    +--------+ +---------+
+--R                        4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((12x  + 4)\|3  - 20x  - 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                   ((12x  + 4)\|3  + 20x  + 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                     +--------+ +---------+
+--R                        4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((24x  + 8)\|3  - 40x  - 16)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                   ((24x  + 8)\|3  + 40x  + 16)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2           3   2
+--R                     atan(----)      atan(----)
+--R                           +-+             +-+
+--R                          \|3             \|3
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                                                    +--------+ +---------+
+--R                        4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((12x  + 4)\|3  - 20x  - 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                   ((12x  + 4)\|3  + 20x  + 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                       +--------+ +---------+
+--R                          6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                 ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                       +--------+ +---------+
+--R                          6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                 ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R               10      6      2  +-+         \|3
+--R           (24x   - 24x  + 24x )\|3 sin(----------)
+--R                                             2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R               10      6      2  +-+         \|3
+--R           (24x   - 24x  + 24x )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                                                                    3
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                             3     5
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     +--------+ +---------+
+--R                        4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((18x  + 6)\|3  - 30x  - 12)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                   ((18x  + 6)\|3  + 30x  + 12)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                      +--------+ +---------+
+--R                        4       +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((36x  + 12)\|3  - 60x  - 24)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                      4       +-+      4      4+-+2 |    +-+      |   +-+
+--R                 ((36x  + 12)\|3  + 60x  + 24)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2           3   2
+--R                     atan(----)      atan(----)
+--R                           +-+             +-+
+--R                          \|3             \|3
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                                                     +--------+ +---------+
+--R                        4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((18x  + 6)\|3  - 30x  - 12)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                   ((18x  + 6)\|3  + 30x  + 12)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                       +--------+ +---------+
+--R                          6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                 ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                       +--------+ +---------+
+--R                          6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                 ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                    8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((18x  + 6x )\|3  - 30x  - 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R               ((18x  + 6x )\|3  + 30x  + 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                    8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((18x  + 6x )\|3  - 30x  - 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R               ((18x  + 6x )\|3  + 30x  + 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (48x   - 48x  + 48x )\|3 sin(----------)
+--R                                                 2
+--R             + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (48x   - 48x  + 48x )\|3 cos(----------)
+--R                                                 2
+--R          *
+--R                                                                        3     3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 16x   + 16x  - 16x )\|3 \|9  sin(----------)
+--R                                                        2
+--R             + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 16x   + 16x  - 16x )\|3 \|9  cos(----------)
+--R                                                        2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3     3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                    +--------+ +---------+
+--R                        4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((12x  + 4)\|3  - 20x  - 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                   ((12x  + 4)\|3  + 20x  + 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                     +--------+ +---------+
+--R                        4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((24x  + 8)\|3  - 40x  - 16)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                   ((24x  + 8)\|3  + 40x  + 16)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2           3   2
+--R                     atan(----)      atan(----)
+--R                           +-+             +-+
+--R                          \|3             \|3
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                                                    +--------+ +---------+
+--R                        4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((12x  + 4)\|3  - 20x  - 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                   ((12x  + 4)\|3  + 20x  + 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                        6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                   ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                     +--------+ +---------+
+--R                        6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                   ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                          +--------+ +---------+
+--R                          8     4  +-+      8     4 4+-+2 | +-+      |  +-+
+--R                   ((- 12x  - 4x )\|3  + 20x  + 8x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                            +-----------+
+--R                            8     4  +-+      8     4 4+-+2 |    +-+
+--R                     ((- 12x  - 4x )\|3  - 20x  - 8x )\|9  \|- 3\|3  + 6
+--R                  *
+--R                      +----------+
+--R                      |   +-+
+--R                     \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                          +--------+ +---------+
+--R                          8     4  +-+      8     4 4+-+2 | +-+      |  +-+
+--R                   ((- 12x  - 4x )\|3  + 20x  + 8x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                            +-----------+
+--R                            8     4  +-+      8     4 4+-+2 |    +-+
+--R                     ((- 12x  - 4x )\|3  - 20x  - 8x )\|9  \|- 3\|3  + 6
+--R                  *
+--R                      +----------+
+--R                      |   +-+
+--R                     \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                      10      6  +-+      10      6  | +-+      |  +-+
+--R               ((- 36x   - 12x )\|3  + 60x   + 24x )\|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                      10      6  +-+      10      6  |    +-+      |   +-+
+--R               ((- 36x   - 12x )\|3  - 60x   - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (24x   - 24x  + 24x )\|3 sin(----------)
+--R                                                 2
+--R             + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (24x   - 24x  + 24x )\|3 cos(----------)
+--R                                                 2
+--R          *
+--R                                                                        3     5
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (16x   - 16x  + 16x )\|3 \|9  sin(----------)
+--R                                                      2
+--R             + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (16x   - 16x  + 16x )\|3 \|9  cos(----------)
+--R                                                      2
+--R          *
+--R                                 3     3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                         +-----------------------------------+2
+--R                                         |           3   2              3   2
+--R                                         |    atan(----)         atan(----)
+--R                                         |          +-+                +-+
+--R                 14      10      6  +-+  |         \|3                \|3
+--R             (24x   - 24x   + 24x )\|3  4|sin(----------)  + cos(----------)
+--R                                        \|         2                  2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                              +--------+ +---------+
+--R                   4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((3x  + 1)\|3  - 5x  - 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                              +-----------+ +----------+
+--R                   4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((3x  + 1)\|3  + 5x  + 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                               +--------+ +---------+
+--R                   4      +-+      4     4+-+2 | +-+      |  +-+
+--R               ((6x  + 2)\|3  - 10x  - 4)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                               +-----------+ +----------+
+--R                   4      +-+      4     4+-+2 |    +-+      |   +-+
+--R               ((6x  + 2)\|3  + 10x  + 4)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2           3   2
+--R                 atan(----)      atan(----)
+--R                       +-+             +-+
+--R                      \|3             \|3
+--R             cos(----------) sin(----------)
+--R                      2               2
+--R         + 
+--R                                              +--------+ +---------+
+--R                   4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((3x  + 1)\|3  - 5x  - 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                              +-----------+ +----------+
+--R                   4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((3x  + 1)\|3  + 5x  + 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                                 +--------+ +---------+
+--R                    6      2  +-+      6      2  | +-+      |  +-+
+--R               ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                 +-----------+ +----------+
+--R                    6      2  +-+      6      2  |    +-+      |   +-+
+--R               ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                 +--------+ +---------+
+--R                    6      2  +-+      6      2  | +-+      |  +-+
+--R               ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                 +-----------+ +----------+
+--R                    6      2  +-+      6      2  |    +-+      |   +-+
+--R               ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                                     +--------+ +---------+
+--R                    8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((18x  + 6x )\|3  - 30x  - 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R               ((18x  + 6x )\|3  + 30x  + 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                    8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((18x  + 6x )\|3  - 30x  - 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R               ((18x  + 6x )\|3  + 30x  + 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                               +--------+ +---------+
+--R                10      6  +-+      10      6  | +-+      |  +-+
+--R           ((36x   + 12x )\|3  - 60x   - 24x )\|\|3  + 2 \|3\|3  + 6
+--R         + 
+--R                                               +-----------+ +----------+
+--R                10      6  +-+      10      6  |    +-+      |   +-+
+--R           ((36x   + 12x )\|3  + 60x   + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R      *
+--R                                                                    3     2
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                           +--------+ +---------+
+--R           12    8  +-+     12     8 4+-+2 | +-+      |  +-+
+--R       ((3x   + x )\|3  - 5x   - 2x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R     + 
+--R                                           +-----------+ +----------+
+--R           12    8  +-+     12     8 4+-+2 |    +-+      |   +-+
+--R       ((3x   + x )\|3  + 5x   + 2x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R  /
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                             3   2           3   2
+--R                                      atan(----)      atan(----)
+--R                                            +-+             +-+
+--R               8      4      4+-+2         \|3             \|3
+--R           (12x  - 12x  + 12)\|9  cos(----------) sin(----------)
+--R                                           2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (48x  - 48x  + 48)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )cos(----------)
+--R                                               2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (36x  - 36x  + 36)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (72x  - 72x  + 72)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (36x  - 36x  + 36)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )cos(----------)
+--R                                               2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  sin(----------)
+--R                                              2
+--R         + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  cos(----------)
+--R                                              2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (48x  - 48x  + 48)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (72x   - 72x  + 72x )sin(----------)
+--R                                             2
+--R             + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (72x   - 72x  + 72x )cos(----------)
+--R                                             2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                      3   2
+--R                                               atan(----)
+--R                                                     +-+
+--R                     12      8      4 4+-+2         \|3
+--R               (- 24x   + 24x  - 24x )\|9  sin(----------)
+--R                                                    2
+--R             + 
+--R                                                      3   2
+--R                                               atan(----)
+--R                                                     +-+
+--R                     12      8      4 4+-+2         \|3
+--R               (- 24x   + 24x  - 24x )\|9  cos(----------)
+--R                                                    2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                     +-----------------------------------+2
+--R                                     |           3   2              3   2
+--R                                     |    atan(----)         atan(----)
+--R                                     |          +-+                +-+
+--R                 14      10      6   |         \|3                \|3
+--R           (- 72x   + 72x   - 72x ) 4|sin(----------)  + cos(----------)
+--R                                    \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                             3   2           3   2
+--R                                      atan(----)      atan(----)
+--R                                            +-+             +-+
+--R               8      4      4+-+2         \|3             \|3
+--R           (12x  - 12x  + 12)\|9  cos(----------) sin(----------)
+--R                                           2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                           3   2
+--R                                    atan(----)
+--R                                          +-+
+--R               10      6      2          \|3
+--R           (72x   - 72x  + 72x )sin(----------)
+--R                                         2
+--R         + 
+--R                                           3   2
+--R                                    atan(----)
+--R                                          +-+
+--R               10      6      2          \|3
+--R           (72x   - 72x  + 72x )cos(----------)
+--R                                         2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  sin(----------)
+--R                                              2
+--R         + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  cos(----------)
+--R                                              2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                 +-----------------------------------+2
+--R                                 |           3   2              3   2
+--R                                 |    atan(----)         atan(----)
+--R                                 |          +-+                +-+
+--R             14      10      6   |         \|3                \|3
+--R         (72x   - 72x   + 72x ) 4|sin(----------)  + cos(----------)
+--R                                \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R          16     12     8 4+-+2
+--R       (6x   - 6x   + 6x )\|9
+--R                                                    Type: Expression(Integer)
+--E 1415
+
+)clear all
+
+--S 1416 of 2282
+t0:=x^m/(1+3*x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1416
+
+--S 1417 of 2282
+--r0:=2*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),-2*x^4/(3-sqrt(5)))/_
+--   ((1+m)*(3-sqrt(5))*sqrt(5))-2*x^(1+m)*hypergeometric(1,1/4*(1+m),_
+--   1/4*(5+m),-2*x^4/(3+sqrt(5)))/((1+m)*sqrt(5)*(3+sqrt(5)))
+--E 1417
+
+--S 1418 of 2282
+--a0:=integrate(t0,x)
+--E 1418
+
+--S 1419 of 2282
+--m0:=a0-r0
+--E 1419
+
+--S 1420 of 2282
+--d0:=normalize(D(m0,x))
+--E 1420
+
+)clear all
+
+--S 1421 of 2282
+t0:=x^11/(1+3*x^4+x^8)
+--R 
+--R
+--R              11
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1421
+
+--S 1422 of 2282
+r0:=1/4*x^4-1/40*log(3+2*x^4-sqrt(5))*(15-7*sqrt(5))-_
+   1/40*log(3+2*x^4+sqrt(5))*(15+7*sqrt(5))
+--R 
+--R
+--R   (2)
+--R        +-+           +-+     4           +-+             +-+     4           4
+--R   (- 7\|5  - 15)log(\|5  + 2x  + 3) + (7\|5  - 15)log(- \|5  + 2x  + 3) + 10x
+--R   ----------------------------------------------------------------------------
+--R                                        40
+--R                                                    Type: Expression(Integer)
+--E 1422
+
+--S 1423 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           8     4      +-+      4
+--R        (2x  + 6x  + 7)\|5  - 10x  - 15      +-+     8     4          4 +-+
+--R   7log(-------------------------------) - 3\|5 log(x  + 3x  + 1) + 2x \|5
+--R                   8     4
+--R                  x  + 3x  + 1
+--R   ------------------------------------------------------------------------
+--R                                       +-+
+--R                                     8\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1423
+
+--S 1424 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               8     4      +-+      4
+--R            (2x  + 6x  + 7)\|5  - 10x  - 15       +-+          +-+     4
+--R       7log(-------------------------------) + (3\|5  + 7)log(\|5  + 2x  + 3)
+--R                       8     4
+--R                      x  + 3x  + 1
+--R     + 
+--R           +-+     8     4           +-+            +-+     4
+--R       - 3\|5 log(x  + 3x  + 1) + (3\|5  - 7)log(- \|5  + 2x  + 3)
+--R  /
+--R       +-+
+--R     8\|5
+--R                                                    Type: Expression(Integer)
+--E 1424
+
+--S 1425 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1425
+
+)clear all
+
+--S 1426 of 2282
+t0:=x^9/(1+3*x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1426
+
+--S 1427 of 2282
+r0:=1/2*x^2+1/2*atan(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/5*(9-4*sqrt(5)))-_
+   1/2*atan(x^2*sqrt(2/(3+sqrt(5))))*sqrt(1/5*(9+4*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                             +--------+                        +----------+
+--R        +-----------+      2 | +-+          +---------+      2 |   +-+
+--R        |    +-+          x \|\|5  + 3      |  +-+          x \|- \|5  + 3
+--R       \|- 4\|5  + 9 atan(-------------) - \|4\|5  + 9 atan(---------------)
+--R                                +-+                                +-+
+--R                               \|2                                \|2
+--R     + 
+--R        2 +-+
+--R       x \|5
+--R  /
+--R       +-+
+--R     2\|5
+--R                                                    Type: Expression(Integer)
+--E 1427
+
+--S 1428 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         +----------+
+--R                                         |  +-+
+--R                               +-+       |9\|5  + 20
+--R           +----------+     (5\|5  - 15) |----------
+--R           |  +-+                        |     +-+
+--R           |9\|5  + 20                  \|  20\|5
+--R       - 2 |---------- atan(-------------------------)
+--R           |     +-+                   2 +-+
+--R          \|  20\|5                   x \|5
+--R     + 
+--R                                         +----------+
+--R                                         |  +-+
+--R                               +-+       |9\|5  - 20
+--R           +----------+     (5\|5  + 15) |----------
+--R           |  +-+                        |     +-+
+--R           |9\|5  - 20                  \|  20\|5         2
+--R       - 2 |---------- atan(-------------------------) + x
+--R           |     +-+                   2 +-+
+--R          \|  20\|5                   x \|5
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1428
+
+--S 1429 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +--------+
+--R          +-----------+      2 | +-+
+--R          |    +-+          x \|\|5  + 3
+--R       - \|- 4\|5  + 9 atan(-------------)
+--R                                  +-+
+--R                                 \|2
+--R     + 
+--R                                             +----------+
+--R                                             |  +-+
+--R                                   +-+       |9\|5  + 20
+--R               +----------+     (5\|5  - 15) |----------
+--R               |  +-+                        |     +-+
+--R           +-+ |9\|5  + 20                  \|  20\|5
+--R       - 2\|5  |---------- atan(-------------------------)
+--R               |     +-+                   2 +-+
+--R              \|  20\|5                   x \|5
+--R     + 
+--R                                             +----------+
+--R                                             |  +-+
+--R                                   +-+       |9\|5  - 20
+--R               +----------+     (5\|5  + 15) |----------
+--R               |  +-+                        |     +-+
+--R           +-+ |9\|5  - 20                  \|  20\|5
+--R       - 2\|5  |---------- atan(-------------------------)
+--R               |     +-+                   2 +-+
+--R              \|  20\|5                   x \|5
+--R     + 
+--R                           +----------+
+--R        +---------+      2 |   +-+
+--R        |  +-+          x \|- \|5  + 3
+--R       \|4\|5  + 9 atan(---------------)
+--R                               +-+
+--R                              \|2
+--R  /
+--R       +-+
+--R     2\|5
+--R                                                    Type: Expression(Integer)
+--E 1429
+
+--S 1430 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                      +----------+ +---------+
+--R           5       +-+ +-+     5 +-+  |   +-+      |  +-+
+--R       ((3x  + 2x)\|2 \|5  + 5x \|2 )\|- \|5  + 3 \|4\|5  + 9
+--R     + 
+--R                                        +-----------+ +--------+
+--R             5       +-+ +-+     5 +-+  |    +-+      | +-+           5
+--R       ((- 3x  - 2x)\|2 \|5  + 5x \|2 )\|- 4\|5  + 9 \|\|5  + 3  - 60x  - 20x
+--R  /
+--R        8      4
+--R     20x  + 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 1430
+
+)clear all
+
+--S 1431 of 2282
+t0:=x^7/(1+3*x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1431
+
+--S 1432 of 2282
+r0:=1/40*log(3+2*x^4-sqrt(5))*(5-3*sqrt(5))+1/40*log(3+2*x^4+sqrt(5))*_
+   (5+3*sqrt(5))
+--R 
+--R
+--R           +-+          +-+     4             +-+            +-+     4
+--R        (3\|5  + 5)log(\|5  + 2x  + 3) + (- 3\|5  + 5)log(- \|5  + 2x  + 3)
+--R   (2)  -------------------------------------------------------------------
+--R                                         40
+--R                                                    Type: Expression(Integer)
+--E 1432
+
+--S 1433 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                8     4      +-+      4
+--R             (2x  + 6x  + 7)\|5  + 10x  + 15     +-+     8     4
+--R        3log(-------------------------------) + \|5 log(x  + 3x  + 1)
+--R                        8     4
+--R                       x  + 3x  + 1
+--R   (3)  -------------------------------------------------------------
+--R                                      +-+
+--R                                    8\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1433
+
+--S 1434 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               8     4      +-+      4
+--R            (2x  + 6x  + 7)\|5  + 10x  + 15        +-+          +-+     4
+--R       3log(-------------------------------) + (- \|5  - 3)log(\|5  + 2x  + 3)
+--R                       8     4
+--R                      x  + 3x  + 1
+--R     + 
+--R        +-+     8     4            +-+            +-+     4
+--R       \|5 log(x  + 3x  + 1) + (- \|5  + 3)log(- \|5  + 2x  + 3)
+--R  /
+--R       +-+
+--R     8\|5
+--R                                                    Type: Expression(Integer)
+--E 1434
+
+--S 1435 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1435
+
+)clear all
+
+--S 1436 of 2282
+t0:=x^5/(1+3*x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1436
+
+--S 1437 of 2282
+r0:=-1/2*atan(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/10*(3-sqrt(5)))+_
+   1/2*atan(x^2*sqrt(2/(3+sqrt(5))))*sqrt(1/10*(3+sqrt(5)))
+--R 
+--R
+--R                               +--------+                       +----------+
+--R           +----------+      2 | +-+          +--------+      2 |   +-+
+--R           |   +-+          x \|\|5  + 3      | +-+          x \|- \|5  + 3
+--R        - \|- \|5  + 3 atan(-------------) + \|\|5  + 3 atan(---------------)
+--R                                  +-+                               +-+
+--R                                 \|2                               \|2
+--R   (2)  ---------------------------------------------------------------------
+--R                                          +--+
+--R                                        2\|10
+--R                                                    Type: Expression(Integer)
+--E 1437
+
+--S 1438 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                              +---------+                        +---------+
+--R                              |  +-+                             |  +-+
+--R                              |3\|5  + 5                         |3\|5  - 5
+--R           +---------+     10 |---------      +---------+     10 |---------
+--R           |  +-+             |     +-+       |  +-+             |     +-+
+--R           |3\|5  + 5        \|  40\|5        |3\|5  - 5        \|  40\|5
+--R   (3)  -  |--------- atan(--------------) +  |--------- atan(--------------)
+--R           |     +-+            2 +-+         |     +-+            2 +-+
+--R          \|  40\|5            x \|5         \|  40\|5            x \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1438
+
+--S 1439 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                    +---------+
+--R                                                                    |  +-+
+--R                                                                    |3\|5  + 5
+--R                            +--------+           +---------+     10 |---------
+--R        +----------+      2 | +-+                |  +-+             |     +-+
+--R        |   +-+          x \|\|5  + 3       +--+ |3\|5  + 5        \|  40\|5
+--R       \|- \|5  + 3 atan(-------------) - 2\|10  |--------- atan(--------------)
+--R                               +-+               |     +-+            2 +-+
+--R                              \|2               \|  40\|5            x \|5
+--R     + 
+--R                               +---------+
+--R                               |  +-+
+--R                               |3\|5  - 5
+--R            +---------+     10 |---------                        +----------+
+--R            |  +-+             |     +-+       +--------+      2 |   +-+
+--R       +--+ |3\|5  - 5        \|  40\|5        | +-+          x \|- \|5  + 3
+--R     2\|10  |--------- atan(--------------) - \|\|5  + 3 atan(---------------)
+--R            |     +-+            2 +-+                               +-+
+--R           \|  40\|5            x \|5                               \|2
+--R  /
+--R       +--+
+--R     2\|10
+--R                                                    Type: Expression(Integer)
+--E 1439
+
+--S 1440 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                          +----------+ +--------+
+--R           5 +-+ +-+ +--+ |   +-+      | +-+           5
+--R        - x \|2 \|5 \|10 \|- \|5  + 3 \|\|5  + 3  + 20x
+--R   (5)  ------------------------------------------------
+--R                           8      4
+--R                        20x  + 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 1440
+
+)clear all
+
+--S 1441 of 2282
+t0:=x^3/(1+3*x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1441
+
+--S 1442 of 2282
+r0:=-1/2*atanh((3+2*x^4)/sqrt(5))/sqrt(5)
+--R 
+--R
+--R                   4      +-+
+--R                (2x  + 3)\|5
+--R          atanh(-------------)
+--R                      5
+--R   (2)  - --------------------
+--R                    +-+
+--R                  2\|5
+--R                                                    Type: Expression(Integer)
+--E 1442
+
+--S 1443 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               8     4      +-+      4
+--R            (2x  + 6x  + 7)\|5  - 10x  - 15
+--R        log(-------------------------------)
+--R                       8     4
+--R                      x  + 3x  + 1
+--R   (3)  ------------------------------------
+--R                          +-+
+--R                        4\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1443
+
+--S 1444 of 2282
+m0:=a0-r0
+--R 
+--R
+--R               8     4      +-+      4                   4      +-+
+--R            (2x  + 6x  + 7)\|5  - 10x  - 15           (2x  + 3)\|5
+--R        log(-------------------------------) + 2atanh(-------------)
+--R                       8     4                              5
+--R                      x  + 3x  + 1
+--R   (4)  ------------------------------------------------------------
+--R                                      +-+
+--R                                    4\|5
+--R                                                    Type: Expression(Integer)
+--E 1444
+
+--S 1445 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1445
+
+)clear all
+
+--S 1446 of 2282
+t0:=x/(1+3*x^4+x^8)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1446
+
+--S 1447 of 2282
+r0:=1/2*atan(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/10*(3+sqrt(5)))-_
+   atan(x^2*sqrt(2/(3+sqrt(5))))/sqrt(10*(3+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                    +--------+                  +----------+
+--R    +--------+ +-----------+      2 | +-+                     2 |   +-+
+--R    | +-+      |   +-+           x \|\|5  + 3       +--+     x \|- \|5  + 3
+--R   \|\|5  + 3 \|10\|5  + 30 atan(-------------) - 2\|10 atan(---------------)
+--R                                       +-+                          +-+
+--R                                      \|2                          \|2
+--R   --------------------------------------------------------------------------
+--R                                     +-----------+
+--R                                +--+ |   +-+
+--R                              2\|10 \|10\|5  + 30
+--R                                                    Type: Expression(Integer)
+--E 1447
+
+--S 1448 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                   +---------+
+--R                                   |  +-+
+--R                         +-+       |3\|5  + 5
+--R      +---------+     (5\|5  - 15) |---------
+--R      |  +-+                       |     +-+
+--R      |3\|5  + 5                  \|  40\|5
+--R      |--------- atan(------------------------)
+--R      |     +-+                 2 +-+
+--R     \|  40\|5                 x \|5
+--R   + 
+--R                                   +---------+
+--R                                   |  +-+
+--R                         +-+       |3\|5  - 5
+--R      +---------+     (5\|5  + 15) |---------
+--R      |  +-+                       |     +-+
+--R      |3\|5  - 5                  \|  40\|5
+--R      |--------- atan(------------------------)
+--R      |     +-+                 2 +-+
+--R     \|  40\|5                 x \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1448
+
+--S 1449 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                          +--------+
+--R          +--------+ +-----------+      2 | +-+
+--R          | +-+      |   +-+           x \|\|5  + 3
+--R       - \|\|5  + 3 \|10\|5  + 30 atan(-------------)
+--R                                             +-+
+--R                                            \|2
+--R     + 
+--R                                                         +---------+
+--R                                                         |  +-+
+--R                                               +-+       |3\|5  + 5
+--R              +---------+                   (5\|5  - 15) |---------
+--R              |  +-+      +-----------+                  |     +-+
+--R         +--+ |3\|5  + 5  |   +-+                       \|  40\|5
+--R       2\|10  |--------- \|10\|5  + 30 atan(------------------------)
+--R              |     +-+                               2 +-+
+--R             \|  40\|5                               x \|5
+--R     + 
+--R                                                         +---------+
+--R                                                         |  +-+
+--R                                               +-+       |3\|5  - 5
+--R              +---------+                   (5\|5  + 15) |---------
+--R              |  +-+      +-----------+                  |     +-+
+--R         +--+ |3\|5  - 5  |   +-+                       \|  40\|5
+--R       2\|10  |--------- \|10\|5  + 30 atan(------------------------)
+--R              |     +-+                               2 +-+
+--R             \|  40\|5                               x \|5
+--R     + 
+--R                     +----------+
+--R                   2 |   +-+
+--R         +--+     x \|- \|5  + 3
+--R       2\|10 atan(---------------)
+--R                         +-+
+--R                        \|2
+--R  /
+--R            +-----------+
+--R       +--+ |   +-+
+--R     2\|10 \|10\|5  + 30
+--R                                                    Type: Expression(Integer)
+--E 1449
+
+--S 1450 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                     +----------+ +-----------+
+--R         5 +-+ +-+      5       +-+  |   +-+      |   +-+
+--R       (x \|2 \|5  + (3x  + 2x)\|2 )\|- \|5  + 3 \|10\|5  + 30
+--R     + 
+--R             5       +-+ +-+        5        +-+  +--+       +-+
+--R       ((- 2x  - 6x)\|2 \|5  + (- 6x  - 14x)\|2 )\|10  + 20x\|5  + 60x
+--R  /
+--R         8      4       +-+      8       4
+--R     (20x  + 60x  + 20)\|5  + 60x  + 180x  + 60
+--R                                                    Type: Expression(Integer)
+--E 1450
+
+)clear all
+
+--S 1451 of 2282
+t0:=1/(x*(1+3*x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         9     5
+--R        x  + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1451
+
+--S 1452 of 2282
+r0:=log(x)-1/40*log(3+2*x^4+sqrt(5))*(5-3*sqrt(5))-_
+   1/40*log(3+2*x^4-sqrt(5))*(5+3*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          +-+          +-+     4
+--R       (3\|5  - 5)log(\|5  + 2x  + 3) + 40log(x)
+--R     + 
+--R            +-+            +-+     4
+--R       (- 3\|5  - 5)log(- \|5  + 2x  + 3)
+--R  /
+--R     40
+--R                                                    Type: Expression(Integer)
+--E 1452
+
+--S 1453 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           8     4      +-+      4
+--R        (2x  + 6x  + 7)\|5  + 10x  + 15     +-+     8     4          +-+
+--R   3log(-------------------------------) - \|5 log(x  + 3x  + 1) + 8\|5 log(x)
+--R                   8     4
+--R                  x  + 3x  + 1
+--R   ---------------------------------------------------------------------------
+--R                                        +-+
+--R                                      8\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1453
+
+--S 1454 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               8     4      +-+      4
+--R            (2x  + 6x  + 7)\|5  + 10x  + 15      +-+          +-+     4
+--R       3log(-------------------------------) + (\|5  - 3)log(\|5  + 2x  + 3)
+--R                       8     4
+--R                      x  + 3x  + 1
+--R     + 
+--R          +-+     8     4          +-+            +-+     4
+--R       - \|5 log(x  + 3x  + 1) + (\|5  + 3)log(- \|5  + 2x  + 3)
+--R  /
+--R       +-+
+--R     8\|5
+--R                                                    Type: Expression(Integer)
+--E 1454
+
+--S 1455 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1455
+
+)clear all
+
+--S 1456 of 2282
+t0:=1/(x^3*(1+3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         11     7    3
+--R        x   + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1456
+
+--S 1457 of 2282
+r0:=(-1/2)/x^2-1/4*atan(x^2*sqrt(1/2*(3+sqrt(5))))*(3+sqrt(5))^(3/2)/_
+   sqrt(10)+1/2*atan(x^2*sqrt(2/(3+sqrt(5))))*sqrt(1/5*(9-4*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                           +--------+
+--R                         +--------+      2 | +-+
+--R            2 +-+     2  | +-+          x \|\|5  + 3
+--R       (- 3x \|5  - 5x )\|\|5  + 3 atan(-------------)
+--R                                              +-+
+--R                                             \|2
+--R     + 
+--R                                     +----------+
+--R                +-----------+      2 |   +-+
+--R         2 +--+ |    +-+          x \|- \|5  + 3       +-+ +--+
+--R       2x \|10 \|- 4\|5  + 9 atan(---------------) - 2\|5 \|10
+--R                                         +-+
+--R                                        \|2
+--R  /
+--R       2 +-+ +--+
+--R     4x \|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 1457
+
+--S 1458 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                            +----------+
+--R                                            |  +-+
+--R                                  +-+       |9\|5  + 20
+--R             +----------+     (15\|5  - 35) |----------
+--R             |  +-+                         |     +-+
+--R           2 |9\|5  + 20                   \|  20\|5
+--R       - 2x  |---------- atan(--------------------------)
+--R             |     +-+                   2 +-+
+--R            \|  20\|5                   x \|5
+--R     + 
+--R                                            +----------+
+--R                                            |  +-+
+--R                                  +-+       |9\|5  - 20
+--R             +----------+     (15\|5  + 35) |----------
+--R             |  +-+                         |     +-+
+--R           2 |9\|5  - 20                   \|  20\|5
+--R       - 2x  |---------- atan(--------------------------) - 1
+--R             |     +-+                   2 +-+
+--R            \|  20\|5                   x \|5
+--R  /
+--R       2
+--R     2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1458
+
+--S 1459 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     +--------+
+--R                   +--------+      2 | +-+
+--R          +-+      | +-+          x \|\|5  + 3
+--R       (3\|5  + 5)\|\|5  + 3 atan(-------------)
+--R                                        +-+
+--R                                       \|2
+--R     + 
+--R                                                   +----------+
+--R                                                   |  +-+
+--R                                         +-+       |9\|5  + 20
+--R                    +----------+     (15\|5  - 35) |----------
+--R                    |  +-+                         |     +-+
+--R           +-+ +--+ |9\|5  + 20                   \|  20\|5
+--R       - 4\|5 \|10  |---------- atan(--------------------------)
+--R                    |     +-+                   2 +-+
+--R                   \|  20\|5                   x \|5
+--R     + 
+--R                                                   +----------+
+--R                                                   |  +-+
+--R                                         +-+       |9\|5  - 20
+--R                    +----------+     (15\|5  + 35) |----------
+--R                    |  +-+                         |     +-+
+--R           +-+ +--+ |9\|5  - 20                   \|  20\|5
+--R       - 4\|5 \|10  |---------- atan(--------------------------)
+--R                    |     +-+                   2 +-+
+--R                   \|  20\|5                   x \|5
+--R     + 
+--R                                     +----------+
+--R                +-----------+      2 |   +-+
+--R           +--+ |    +-+          x \|- \|5  + 3
+--R       - 2\|10 \|- 4\|5  + 9 atan(---------------)
+--R                                         +-+
+--R                                        \|2
+--R  /
+--R       +-+ +--+
+--R     4\|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 1459
+
+--S 1460 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                        +-----------+ +----------+
+--R             5       +-+ +-+     5 +-+  |    +-+      |   +-+
+--R       ((- 3x  - 2x)\|2 \|5  - 5x \|2 )\|- 4\|5  + 9 \|- \|5  + 3
+--R     + 
+--R          5       +-+ +-+      5       +-+  +--+      5
+--R       ((x  + 3x)\|2 \|5  + (3x  + 7x)\|2 )\|10  - 20x  - 60x
+--R  /
+--R        8      4
+--R     20x  + 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 1460
+
+)clear all
+
+--S 1461 of 2282
+t0:=1/(x^5*(1+3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         13     9    5
+--R        x   + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1461
+
+--S 1462 of 2282
+r0:=(-1/4)/x^4-3*log(x)+1/40*log(3+2*x^4+sqrt(5))*(15-7*sqrt(5))+_
+   1/40*log(3+2*x^4-sqrt(5))*(15+7*sqrt(5))
+--R 
+--R
+--R   (2)
+--R            4 +-+      4      +-+     4            4
+--R       (- 7x \|5  + 15x )log(\|5  + 2x  + 3) - 120x log(x)
+--R     + 
+--R          4 +-+      4        +-+     4
+--R       (7x \|5  + 15x )log(- \|5  + 2x  + 3) - 10
+--R  /
+--R        4
+--R     40x
+--R                                                    Type: Expression(Integer)
+--E 1462
+
+--S 1463 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 8     4      +-+      4
+--R         4    (2x  + 6x  + 7)\|5  - 10x  - 15      4 +-+     8     4
+--R       7x log(-------------------------------) + 3x \|5 log(x  + 3x  + 1)
+--R                         8     4
+--R                        x  + 3x  + 1
+--R     + 
+--R            4 +-+           +-+
+--R       - 24x \|5 log(x) - 2\|5
+--R  /
+--R       4 +-+
+--R     8x \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1463
+
+--S 1464 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               8     4      +-+      4
+--R            (2x  + 6x  + 7)\|5  - 10x  - 15         +-+          +-+     4
+--R       7log(-------------------------------) + (- 3\|5  + 7)log(\|5  + 2x  + 3)
+--R                       8     4
+--R                      x  + 3x  + 1
+--R     + 
+--R         +-+     8     4             +-+            +-+     4
+--R       3\|5 log(x  + 3x  + 1) + (- 3\|5  - 7)log(- \|5  + 2x  + 3)
+--R  /
+--R       +-+
+--R     8\|5
+--R                                                    Type: Expression(Integer)
+--E 1464
+
+--S 1465 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1465
+
+)clear all
+
+--S 1466 of 2282
+t0:=1/(x^7*(1+3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         15     11    7
+--R        x   + 3x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1466
+
+--S 1467 of 2282
+r0:=(-1/6)/x^6+3/2/x^2-1/2*atan(x^2*sqrt(2/(3+sqrt(5))))*_
+   sqrt(1/10*(123-55*sqrt(5)))+1/2*atan(x^2*sqrt(1/2*(3+sqrt(5))))*_
+   sqrt(1/10*(123+55*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                 +--------+
+--R           +------------+      2 | +-+
+--R         6 |   +-+            x \|\|5  + 3
+--R       3x \|55\|5  + 123 atan(-------------)
+--R                                    +-+
+--R                                   \|2
+--R     + 
+--R                                     +----------+
+--R             +--------------+      2 |   +-+
+--R           6 |     +-+            x \|- \|5  + 3        4      +--+
+--R       - 3x \|- 55\|5  + 123 atan(---------------) + (9x  - 1)\|10
+--R                                         +-+
+--R                                        \|2
+--R  /
+--R       6 +--+
+--R     6x \|10
+--R                                                    Type: Expression(Integer)
+--E 1467
+
+--S 1468 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                             +------------+
+--R             +------------+        +-+       |   +-+
+--R           6 |   +-+            (9\|5  - 20)\|55\|5  + 123
+--R       - 3x \|55\|5  + 123 atan(---------------------------)
+--R                                           2 +--+
+--R                                          x \|10
+--R     + 
+--R                                             +--------------+
+--R           +--------------+        +-+       |     +-+
+--R         6 |     +-+            (9\|5  + 20)\|- 55\|5  + 123        4      +--+
+--R       3x \|- 55\|5  + 123 atan(-----------------------------) + (9x  - 1)\|10
+--R                                            2 +--+
+--R                                           x \|10
+--R  /
+--R       6 +--+
+--R     6x \|10
+--R                                         Type: Union(Expression(Integer),...)
+--E 1468
+
+--S 1469 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                          +------------+
+--R          +------------+        +-+       |   +-+
+--R          |   +-+            (9\|5  - 20)\|55\|5  + 123
+--R       - \|55\|5  + 123 atan(---------------------------)
+--R                                        2 +--+
+--R                                       x \|10
+--R     + 
+--R                                +--------+
+--R          +------------+      2 | +-+
+--R          |   +-+            x \|\|5  + 3
+--R       - \|55\|5  + 123 atan(-------------)
+--R                                   +-+
+--R                                  \|2
+--R     + 
+--R                                +----------+
+--R        +--------------+      2 |   +-+
+--R        |     +-+            x \|- \|5  + 3
+--R       \|- 55\|5  + 123 atan(---------------)
+--R                                    +-+
+--R                                   \|2
+--R     + 
+--R                                          +--------------+
+--R        +--------------+        +-+       |     +-+
+--R        |     +-+            (9\|5  + 20)\|- 55\|5  + 123
+--R       \|- 55\|5  + 123 atan(-----------------------------)
+--R                                         2 +--+
+--R                                        x \|10
+--R  /
+--R       +--+
+--R     2\|10
+--R                                                    Type: Expression(Integer)
+--E 1469
+
+--S 1470 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                            +--------+ +------------+
+--R         5 +-+ +-+        5       +-+  +--+ | +-+      |   +-+
+--R       (x \|2 \|5  + (- 3x  - 2x)\|2 )\|10 \|\|5  + 3 \|55\|5  + 123
+--R     + 
+--R                                          +--------------+ +----------+
+--R         5 +-+ +-+      5       +-+  +--+ |     +-+        |   +-+            5
+--R       (x \|2 \|5  + (3x  + 2x)\|2 )\|10 \|- 55\|5  + 123 \|- \|5  + 3  + 120x
+--R     + 
+--R       320x
+--R  /
+--R        8       4
+--R     40x  + 120x  + 40
+--R                                                    Type: Expression(Integer)
+--E 1470
+
+)clear all
+
+--S 1471 of 2282
+t0:=x^8/(1+3*x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1471
+
+--S 1472 of 2282
+r0:=x-1/2*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))*(123-55*sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))+1/2*atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))*_
+   (123-55*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-1/4*log(2*x^2-2*2^(1/4)*_
+   x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*(123-55*sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))+1/4*log(2*x^2+2*2^(1/4)*x*(3-sqrt(5))^(1/4)+_
+   sqrt(2*(3-sqrt(5))))*(123-55*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+_
+   1/2*atan(1-2^(3/4)*x/(3+sqrt(5))^(1/4))*(123+55*sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))-1/2*atan(1+2^(3/4)*x/(3+sqrt(5))^(1/4))*_
+   (123+55*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+1/4*log(2*x^2-2*2^(1/4)*_
+   x*(3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*(123+55*sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))-1/4*log(2*x^2+2*2^(1/4)*x*(3+sqrt(5))^(1/4)+_
+   sqrt(2*(3+sqrt(5))))*(123+55*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          +------------+     +---------+          +--------+
+--R         4|   +-+            |  +-+          4+-+4| +-+          2
+--R       - \|55\|5  + 123 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +------------+     +---------+          +--------+
+--R       4|   +-+            |  +-+          4+-+4| +-+          2
+--R       \|55\|5  + 123 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +--------------+           +----------+    +-----------+
+--R       4|     +-+             4+-+4|   +-+         |    +-+          2
+--R       \|- 55\|5  + 123 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R          +--------------+             +----------+    +-----------+
+--R         4|     +-+               4+-+4|   +-+         |    +-+          2
+--R       - \|- 55\|5  + 123 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                     +--------+3
+--R         +------------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       2\|55\|5  + 123 atan(----------------------------------------)
+--R                                                4
+--R     + 
+--R                                                     +--------+3
+--R         +------------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       2\|55\|5  + 123 atan(----------------------------------------)
+--R                                                4
+--R     + 
+--R                                                       +----------+3
+--R         +--------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|     +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       2\|- 55\|5  + 123 atan(------------------------------------------)
+--R                                                   4
+--R     + 
+--R                                                       +----------+3
+--R         +--------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|     +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       2\|- 55\|5  + 123 atan(------------------------------------------)
+--R                                                   4
+--R     + 
+--R          4+-+3 +-+
+--R       4x \|2  \|5
+--R  /
+--R      4+-+3 +-+
+--R     4\|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 1472
+
+--S 1473 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                 +-----------------+
+--R                 |  +-------------+
+--R                 |  |    +-+
+--R             +-+ |  |123\|5  + 275
+--R            \|2  |2 |-------------
+--R                 |  |        +-+
+--R                \| \|   3200\|5
+--R         *
+--R            log
+--R                                       +-----------------+
+--R                                       |  +-------------+
+--R                                       |  |    +-+
+--R                     +-+ +-+      +-+  |  |123\|5  + 275
+--R                 (3x\|2 \|5  - 5x\|2 ) |2 |-------------
+--R                                       |  |        +-+
+--R                                      \| \|   3200\|5
+--R               + 
+--R                                  +-------------+
+--R                                  |    +-+
+--R                       +-+        |123\|5  + 275     2
+--R                 (- 60\|5  + 140) |-------------  + x
+--R                                  |        +-+
+--R                                 \|   3200\|5
+--R     + 
+--R              +-----------------+
+--R              |  +-------------+
+--R              |  |    +-+
+--R          +-+ |  |123\|5  - 275
+--R         \|2  |2 |-------------
+--R              |  |        +-+
+--R             \| \|   3200\|5
+--R      *
+--R         log
+--R                                    +-----------------+
+--R                                    |  +-------------+
+--R                                    |  |    +-+
+--R                  +-+ +-+      +-+  |  |123\|5  - 275
+--R              (3x\|2 \|5  + 5x\|2 ) |2 |-------------
+--R                                    |  |        +-+
+--R                                   \| \|   3200\|5
+--R            + 
+--R                             +-------------+
+--R                             |    +-+
+--R                  +-+        |123\|5  - 275     2
+--R              (60\|5  + 140) |-------------  + x
+--R                             |        +-+
+--R                            \|   3200\|5
+--R     + 
+--R              +-------------------+
+--R              |    +-------------+
+--R              |    |    +-+
+--R          +-+ |    |123\|5  - 275
+--R         \|2  |- 2 |-------------
+--R              |    |        +-+
+--R             \|   \|   3200\|5
+--R      *
+--R         log
+--R                                    +-------------------+
+--R                                    |    +-------------+
+--R                                    |    |    +-+
+--R                  +-+ +-+      +-+  |    |123\|5  - 275
+--R              (3x\|2 \|5  + 5x\|2 ) |- 2 |-------------
+--R                                    |    |        +-+
+--R                                   \|   \|   3200\|5
+--R            + 
+--R                               +-------------+
+--R                               |    +-+
+--R                    +-+        |123\|5  - 275     2
+--R              (- 60\|5  - 140) |-------------  + x
+--R                               |        +-+
+--R                              \|   3200\|5
+--R     + 
+--R       -
+--R                 +-------------------+
+--R                 |    +-------------+
+--R                 |    |    +-+
+--R             +-+ |    |123\|5  + 275
+--R            \|2  |- 2 |-------------
+--R                 |    |        +-+
+--R                \|   \|   3200\|5
+--R         *
+--R            log
+--R                                       +-------------------+
+--R                                       |    +-------------+
+--R                                       |    |    +-+
+--R                     +-+ +-+      +-+  |    |123\|5  + 275
+--R                 (3x\|2 \|5  - 5x\|2 ) |- 2 |-------------
+--R                                       |    |        +-+
+--R                                      \|   \|   3200\|5
+--R               + 
+--R                                +-------------+
+--R                                |    +-+
+--R                     +-+        |123\|5  + 275     2
+--R                 (60\|5  - 140) |-------------  + x
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R              +-------------------+
+--R              |    +-------------+
+--R              |    |    +-+
+--R          +-+ |    |123\|5  + 275
+--R         \|2  |- 2 |-------------
+--R              |    |        +-+
+--R             \|   \|   3200\|5
+--R      *
+--R         log
+--R                                      +-------------------+
+--R                                      |    +-------------+
+--R                                      |    |    +-+
+--R                    +-+ +-+      +-+  |    |123\|5  + 275
+--R              (- 3x\|2 \|5  + 5x\|2 ) |- 2 |-------------
+--R                                      |    |        +-+
+--R                                     \|   \|   3200\|5
+--R            + 
+--R                             +-------------+
+--R                             |    +-+
+--R                  +-+        |123\|5  + 275     2
+--R              (60\|5  - 140) |-------------  + x
+--R                             |        +-+
+--R                            \|   3200\|5
+--R     + 
+--R       -
+--R                 +-------------------+
+--R                 |    +-------------+
+--R                 |    |    +-+
+--R             +-+ |    |123\|5  - 275
+--R            \|2  |- 2 |-------------
+--R                 |    |        +-+
+--R                \|   \|   3200\|5
+--R         *
+--R            log
+--R                                         +-------------------+
+--R                                         |    +-------------+
+--R                                         |    |    +-+
+--R                       +-+ +-+      +-+  |    |123\|5  - 275
+--R                 (- 3x\|2 \|5  - 5x\|2 ) |- 2 |-------------
+--R                                         |    |        +-+
+--R                                        \|   \|   3200\|5
+--R               + 
+--R                                  +-------------+
+--R                                  |    +-+
+--R                       +-+        |123\|5  - 275     2
+--R                 (- 60\|5  - 140) |-------------  + x
+--R                                  |        +-+
+--R                                 \|   3200\|5
+--R     + 
+--R       -
+--R                 +-----------------+
+--R                 |  +-------------+
+--R                 |  |    +-+
+--R             +-+ |  |123\|5  - 275
+--R            \|2  |2 |-------------
+--R                 |  |        +-+
+--R                \| \|   3200\|5
+--R         *
+--R            log
+--R                                         +-----------------+
+--R                                         |  +-------------+
+--R                                         |  |    +-+
+--R                       +-+ +-+      +-+  |  |123\|5  - 275
+--R                 (- 3x\|2 \|5  - 5x\|2 ) |2 |-------------
+--R                                         |  |        +-+
+--R                                        \| \|   3200\|5
+--R               + 
+--R                                +-------------+
+--R                                |    +-+
+--R                     +-+        |123\|5  - 275     2
+--R                 (60\|5  + 140) |-------------  + x
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R              +-----------------+
+--R              |  +-------------+
+--R              |  |    +-+
+--R          +-+ |  |123\|5  + 275
+--R         \|2  |2 |-------------
+--R              |  |        +-+
+--R             \| \|   3200\|5
+--R      *
+--R         log
+--R                                      +-----------------+
+--R                                      |  +-------------+
+--R                                      |  |    +-+
+--R                    +-+ +-+      +-+  |  |123\|5  + 275
+--R              (- 3x\|2 \|5  + 5x\|2 ) |2 |-------------
+--R                                      |  |        +-+
+--R                                     \| \|   3200\|5
+--R            + 
+--R                               +-------------+
+--R                               |    +-+
+--R                    +-+        |123\|5  + 275     2
+--R              (- 60\|5  + 140) |-------------  + x
+--R                               |        +-+
+--R                              \|   3200\|5
+--R     + 
+--R               +-------------------+
+--R               |    +-------------+
+--R               |    |    +-+
+--R           +-+ |    |123\|5  + 275
+--R         2\|2  |- 2 |-------------
+--R               |    |        +-+
+--R              \|   \|   3200\|5
+--R      *
+--R                                        +-------------------+
+--R                                        |    +-------------+
+--R                                        |    |    +-+
+--R                      +-+ +-+      +-+  |    |123\|5  + 275
+--R                   (5\|2 \|5  - 15\|2 ) |- 2 |-------------
+--R                                        |    |        +-+
+--R                                       \|   \|   3200\|5
+--R         atan(---------------------------------------------------)
+--R                                   +-------------------+
+--R                                   |    +-------------+
+--R                                   |    |    +-+
+--R                 +-+ +-+      +-+  |    |123\|5  + 275        +-+
+--R              (5\|2 \|5  - 15\|2 ) |- 2 |-------------   - 2x\|5
+--R                                   |    |        +-+
+--R                                  \|   \|   3200\|5
+--R     + 
+--R               +-------------------+
+--R               |    +-------------+
+--R               |    |    +-+
+--R           +-+ |    |123\|5  - 275
+--R         2\|2  |- 2 |-------------
+--R               |    |        +-+
+--R              \|   \|   3200\|5
+--R      *
+--R                                        +-------------------+
+--R                                        |    +-------------+
+--R                                        |    |    +-+
+--R                      +-+ +-+      +-+  |    |123\|5  - 275
+--R                   (5\|2 \|5  + 15\|2 ) |- 2 |-------------
+--R                                        |    |        +-+
+--R                                       \|   \|   3200\|5
+--R         atan(---------------------------------------------------)
+--R                                   +-------------------+
+--R                                   |    +-------------+
+--R                                   |    |    +-+
+--R                 +-+ +-+      +-+  |    |123\|5  - 275        +-+
+--R              (5\|2 \|5  + 15\|2 ) |- 2 |-------------   - 2x\|5
+--R                                   |    |        +-+
+--R                                  \|   \|   3200\|5
+--R     + 
+--R               +-----------------+
+--R               |  +-------------+
+--R               |  |    +-+
+--R           +-+ |  |123\|5  - 275
+--R         2\|2  |2 |-------------
+--R               |  |        +-+
+--R              \| \|   3200\|5
+--R      *
+--R                                        +-----------------+
+--R                                        |  +-------------+
+--R                                        |  |    +-+
+--R                      +-+ +-+      +-+  |  |123\|5  - 275
+--R                   (5\|2 \|5  + 15\|2 ) |2 |-------------
+--R                                        |  |        +-+
+--R                                       \| \|   3200\|5
+--R         atan(-------------------------------------------------)
+--R                                   +-----------------+
+--R                                   |  +-------------+
+--R                                   |  |    +-+
+--R                 +-+ +-+      +-+  |  |123\|5  - 275        +-+
+--R              (5\|2 \|5  + 15\|2 ) |2 |-------------   - 2x\|5
+--R                                   |  |        +-+
+--R                                  \| \|   3200\|5
+--R     + 
+--R               +-----------------+
+--R               |  +-------------+
+--R               |  |    +-+
+--R           +-+ |  |123\|5  + 275
+--R         2\|2  |2 |-------------
+--R               |  |        +-+
+--R              \| \|   3200\|5
+--R      *
+--R                                        +-----------------+
+--R                                        |  +-------------+
+--R                                        |  |    +-+
+--R                      +-+ +-+      +-+  |  |123\|5  + 275
+--R                   (5\|2 \|5  - 15\|2 ) |2 |-------------
+--R                                        |  |        +-+
+--R                                       \| \|   3200\|5
+--R         atan(-------------------------------------------------)
+--R                                   +-----------------+
+--R                                   |  +-------------+
+--R                                   |  |    +-+
+--R                 +-+ +-+      +-+  |  |123\|5  + 275        +-+
+--R              (5\|2 \|5  - 15\|2 ) |2 |-------------   - 2x\|5
+--R                                   |  |        +-+
+--R                                  \| \|   3200\|5
+--R     + 
+--R       -
+--R                  +-----------------+
+--R                  |  +-------------+
+--R                  |  |    +-+
+--R              +-+ |  |123\|5  + 275
+--R            2\|2  |2 |-------------
+--R                  |  |        +-+
+--R                 \| \|   3200\|5
+--R         *
+--R                                           +-----------------+
+--R                                           |  +-------------+
+--R                                           |  |    +-+
+--R                         +-+ +-+      +-+  |  |123\|5  + 275
+--R                      (5\|2 \|5  - 15\|2 ) |2 |-------------
+--R                                           |  |        +-+
+--R                                          \| \|   3200\|5
+--R            atan(-------------------------------------------------)
+--R                                      +-----------------+
+--R                                      |  +-------------+
+--R                                      |  |    +-+
+--R                    +-+ +-+      +-+  |  |123\|5  + 275        +-+
+--R                 (5\|2 \|5  - 15\|2 ) |2 |-------------   + 2x\|5
+--R                                      |  |        +-+
+--R                                     \| \|   3200\|5
+--R     + 
+--R       -
+--R                  +-----------------+
+--R                  |  +-------------+
+--R                  |  |    +-+
+--R              +-+ |  |123\|5  - 275
+--R            2\|2  |2 |-------------
+--R                  |  |        +-+
+--R                 \| \|   3200\|5
+--R         *
+--R                                           +-----------------+
+--R                                           |  +-------------+
+--R                                           |  |    +-+
+--R                         +-+ +-+      +-+  |  |123\|5  - 275
+--R                      (5\|2 \|5  + 15\|2 ) |2 |-------------
+--R                                           |  |        +-+
+--R                                          \| \|   3200\|5
+--R            atan(-------------------------------------------------)
+--R                                      +-----------------+
+--R                                      |  +-------------+
+--R                                      |  |    +-+
+--R                    +-+ +-+      +-+  |  |123\|5  - 275        +-+
+--R                 (5\|2 \|5  + 15\|2 ) |2 |-------------   + 2x\|5
+--R                                      |  |        +-+
+--R                                     \| \|   3200\|5
+--R     + 
+--R       -
+--R                  +-------------------+
+--R                  |    +-------------+
+--R                  |    |    +-+
+--R              +-+ |    |123\|5  - 275
+--R            2\|2  |- 2 |-------------
+--R                  |    |        +-+
+--R                 \|   \|   3200\|5
+--R         *
+--R                                           +-------------------+
+--R                                           |    +-------------+
+--R                                           |    |    +-+
+--R                         +-+ +-+      +-+  |    |123\|5  - 275
+--R                      (5\|2 \|5  + 15\|2 ) |- 2 |-------------
+--R                                           |    |        +-+
+--R                                          \|   \|   3200\|5
+--R            atan(---------------------------------------------------)
+--R                                      +-------------------+
+--R                                      |    +-------------+
+--R                                      |    |    +-+
+--R                    +-+ +-+      +-+  |    |123\|5  - 275        +-+
+--R                 (5\|2 \|5  + 15\|2 ) |- 2 |-------------   + 2x\|5
+--R                                      |    |        +-+
+--R                                     \|   \|   3200\|5
+--R     + 
+--R       -
+--R                  +-------------------+
+--R                  |    +-------------+
+--R                  |    |    +-+
+--R              +-+ |    |123\|5  + 275
+--R            2\|2  |- 2 |-------------
+--R                  |    |        +-+
+--R                 \|   \|   3200\|5
+--R         *
+--R                                           +-------------------+
+--R                                           |    +-------------+
+--R                                           |    |    +-+
+--R                         +-+ +-+      +-+  |    |123\|5  + 275
+--R                      (5\|2 \|5  - 15\|2 ) |- 2 |-------------
+--R                                           |    |        +-+
+--R                                          \|   \|   3200\|5
+--R            atan(---------------------------------------------------)
+--R                                      +-------------------+
+--R                                      |    +-------------+
+--R                                      |    |    +-+
+--R                    +-+ +-+      +-+  |    |123\|5  + 275        +-+
+--R                 (5\|2 \|5  - 15\|2 ) |- 2 |-------------   + 2x\|5
+--R                                      |    |        +-+
+--R                                     \|   \|   3200\|5
+--R     + 
+--R       8x
+--R  /
+--R     8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1473
+
+--S 1474 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                          +-----------------+
+--R                          |  +-------------+
+--R                          |  |    +-+
+--R             +-+4+-+3 +-+ |  |123\|5  + 275
+--R            \|2 \|2  \|5  |2 |-------------
+--R                          |  |        +-+
+--R                         \| \|   3200\|5
+--R         *
+--R            log
+--R                                       +-----------------+
+--R                                       |  +-------------+
+--R                                       |  |    +-+
+--R                     +-+ +-+      +-+  |  |123\|5  + 275
+--R                 (3x\|2 \|5  - 5x\|2 ) |2 |-------------
+--R                                       |  |        +-+
+--R                                      \| \|   3200\|5
+--R               + 
+--R                                  +-------------+
+--R                                  |    +-+
+--R                       +-+        |123\|5  + 275     2
+--R                 (- 60\|5  + 140) |-------------  + x
+--R                                  |        +-+
+--R                                 \|   3200\|5
+--R     + 
+--R                       +-----------------+
+--R                       |  +-------------+
+--R                       |  |    +-+
+--R          +-+4+-+3 +-+ |  |123\|5  - 275
+--R         \|2 \|2  \|5  |2 |-------------
+--R                       |  |        +-+
+--R                      \| \|   3200\|5
+--R      *
+--R         log
+--R                                    +-----------------+
+--R                                    |  +-------------+
+--R                                    |  |    +-+
+--R                  +-+ +-+      +-+  |  |123\|5  - 275
+--R              (3x\|2 \|5  + 5x\|2 ) |2 |-------------
+--R                                    |  |        +-+
+--R                                   \| \|   3200\|5
+--R            + 
+--R                             +-------------+
+--R                             |    +-+
+--R                  +-+        |123\|5  - 275     2
+--R              (60\|5  + 140) |-------------  + x
+--R                             |        +-+
+--R                            \|   3200\|5
+--R     + 
+--R                       +-------------------+
+--R                       |    +-------------+
+--R                       |    |    +-+
+--R          +-+4+-+3 +-+ |    |123\|5  - 275
+--R         \|2 \|2  \|5  |- 2 |-------------
+--R                       |    |        +-+
+--R                      \|   \|   3200\|5
+--R      *
+--R         log
+--R                                    +-------------------+
+--R                                    |    +-------------+
+--R                                    |    |    +-+
+--R                  +-+ +-+      +-+  |    |123\|5  - 275
+--R              (3x\|2 \|5  + 5x\|2 ) |- 2 |-------------
+--R                                    |    |        +-+
+--R                                   \|   \|   3200\|5
+--R            + 
+--R                               +-------------+
+--R                               |    +-+
+--R                    +-+        |123\|5  - 275     2
+--R              (- 60\|5  - 140) |-------------  + x
+--R                               |        +-+
+--R                              \|   3200\|5
+--R     + 
+--R       -
+--R                          +-------------------+
+--R                          |    +-------------+
+--R                          |    |    +-+
+--R             +-+4+-+3 +-+ |    |123\|5  + 275
+--R            \|2 \|2  \|5  |- 2 |-------------
+--R                          |    |        +-+
+--R                         \|   \|   3200\|5
+--R         *
+--R            log
+--R                                       +-------------------+
+--R                                       |    +-------------+
+--R                                       |    |    +-+
+--R                     +-+ +-+      +-+  |    |123\|5  + 275
+--R                 (3x\|2 \|5  - 5x\|2 ) |- 2 |-------------
+--R                                       |    |        +-+
+--R                                      \|   \|   3200\|5
+--R               + 
+--R                                +-------------+
+--R                                |    +-+
+--R                     +-+        |123\|5  + 275     2
+--R                 (60\|5  - 140) |-------------  + x
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R                       +-------------------+
+--R                       |    +-------------+
+--R                       |    |    +-+
+--R          +-+4+-+3 +-+ |    |123\|5  + 275
+--R         \|2 \|2  \|5  |- 2 |-------------
+--R                       |    |        +-+
+--R                      \|   \|   3200\|5
+--R      *
+--R         log
+--R                                      +-------------------+
+--R                                      |    +-------------+
+--R                                      |    |    +-+
+--R                    +-+ +-+      +-+  |    |123\|5  + 275
+--R              (- 3x\|2 \|5  + 5x\|2 ) |- 2 |-------------
+--R                                      |    |        +-+
+--R                                     \|   \|   3200\|5
+--R            + 
+--R                             +-------------+
+--R                             |    +-+
+--R                  +-+        |123\|5  + 275     2
+--R              (60\|5  - 140) |-------------  + x
+--R                             |        +-+
+--R                            \|   3200\|5
+--R     + 
+--R       -
+--R                          +-------------------+
+--R                          |    +-------------+
+--R                          |    |    +-+
+--R             +-+4+-+3 +-+ |    |123\|5  - 275
+--R            \|2 \|2  \|5  |- 2 |-------------
+--R                          |    |        +-+
+--R                         \|   \|   3200\|5
+--R         *
+--R            log
+--R                                         +-------------------+
+--R                                         |    +-------------+
+--R                                         |    |    +-+
+--R                       +-+ +-+      +-+  |    |123\|5  - 275
+--R                 (- 3x\|2 \|5  - 5x\|2 ) |- 2 |-------------
+--R                                         |    |        +-+
+--R                                        \|   \|   3200\|5
+--R               + 
+--R                                  +-------------+
+--R                                  |    +-+
+--R                       +-+        |123\|5  - 275     2
+--R                 (- 60\|5  - 140) |-------------  + x
+--R                                  |        +-+
+--R                                 \|   3200\|5
+--R     + 
+--R       -
+--R                          +-----------------+
+--R                          |  +-------------+
+--R                          |  |    +-+
+--R             +-+4+-+3 +-+ |  |123\|5  - 275
+--R            \|2 \|2  \|5  |2 |-------------
+--R                          |  |        +-+
+--R                         \| \|   3200\|5
+--R         *
+--R            log
+--R                                         +-----------------+
+--R                                         |  +-------------+
+--R                                         |  |    +-+
+--R                       +-+ +-+      +-+  |  |123\|5  - 275
+--R                 (- 3x\|2 \|5  - 5x\|2 ) |2 |-------------
+--R                                         |  |        +-+
+--R                                        \| \|   3200\|5
+--R               + 
+--R                                +-------------+
+--R                                |    +-+
+--R                     +-+        |123\|5  - 275     2
+--R                 (60\|5  + 140) |-------------  + x
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R                       +-----------------+
+--R                       |  +-------------+
+--R                       |  |    +-+
+--R          +-+4+-+3 +-+ |  |123\|5  + 275
+--R         \|2 \|2  \|5  |2 |-------------
+--R                       |  |        +-+
+--R                      \| \|   3200\|5
+--R      *
+--R         log
+--R                                      +-----------------+
+--R                                      |  +-------------+
+--R                                      |  |    +-+
+--R                    +-+ +-+      +-+  |  |123\|5  + 275
+--R              (- 3x\|2 \|5  + 5x\|2 ) |2 |-------------
+--R                                      |  |        +-+
+--R                                     \| \|   3200\|5
+--R            + 
+--R                               +-------------+
+--R                               |    +-+
+--R                    +-+        |123\|5  + 275     2
+--R              (- 60\|5  + 140) |-------------  + x
+--R                               |        +-+
+--R                              \|   3200\|5
+--R     + 
+--R                        +-------------------+
+--R                        |    +-------------+
+--R                        |    |    +-+
+--R           +-+4+-+3 +-+ |    |123\|5  + 275
+--R         2\|2 \|2  \|5  |- 2 |-------------
+--R                        |    |        +-+
+--R                       \|   \|   3200\|5
+--R      *
+--R                                        +-------------------+
+--R                                        |    +-------------+
+--R                                        |    |    +-+
+--R                      +-+ +-+      +-+  |    |123\|5  + 275
+--R                   (5\|2 \|5  - 15\|2 ) |- 2 |-------------
+--R                                        |    |        +-+
+--R                                       \|   \|   3200\|5
+--R         atan(---------------------------------------------------)
+--R                                   +-------------------+
+--R                                   |    +-------------+
+--R                                   |    |    +-+
+--R                 +-+ +-+      +-+  |    |123\|5  + 275        +-+
+--R              (5\|2 \|5  - 15\|2 ) |- 2 |-------------   - 2x\|5
+--R                                   |    |        +-+
+--R                                  \|   \|   3200\|5
+--R     + 
+--R                        +-------------------+
+--R                        |    +-------------+
+--R                        |    |    +-+
+--R           +-+4+-+3 +-+ |    |123\|5  - 275
+--R         2\|2 \|2  \|5  |- 2 |-------------
+--R                        |    |        +-+
+--R                       \|   \|   3200\|5
+--R      *
+--R                                        +-------------------+
+--R                                        |    +-------------+
+--R                                        |    |    +-+
+--R                      +-+ +-+      +-+  |    |123\|5  - 275
+--R                   (5\|2 \|5  + 15\|2 ) |- 2 |-------------
+--R                                        |    |        +-+
+--R                                       \|   \|   3200\|5
+--R         atan(---------------------------------------------------)
+--R                                   +-------------------+
+--R                                   |    +-------------+
+--R                                   |    |    +-+
+--R                 +-+ +-+      +-+  |    |123\|5  - 275        +-+
+--R              (5\|2 \|5  + 15\|2 ) |- 2 |-------------   - 2x\|5
+--R                                   |    |        +-+
+--R                                  \|   \|   3200\|5
+--R     + 
+--R                        +-----------------+
+--R                        |  +-------------+
+--R                        |  |    +-+
+--R           +-+4+-+3 +-+ |  |123\|5  - 275
+--R         2\|2 \|2  \|5  |2 |-------------
+--R                        |  |        +-+
+--R                       \| \|   3200\|5
+--R      *
+--R                                        +-----------------+
+--R                                        |  +-------------+
+--R                                        |  |    +-+
+--R                      +-+ +-+      +-+  |  |123\|5  - 275
+--R                   (5\|2 \|5  + 15\|2 ) |2 |-------------
+--R                                        |  |        +-+
+--R                                       \| \|   3200\|5
+--R         atan(-------------------------------------------------)
+--R                                   +-----------------+
+--R                                   |  +-------------+
+--R                                   |  |    +-+
+--R                 +-+ +-+      +-+  |  |123\|5  - 275        +-+
+--R              (5\|2 \|5  + 15\|2 ) |2 |-------------   - 2x\|5
+--R                                   |  |        +-+
+--R                                  \| \|   3200\|5
+--R     + 
+--R                        +-----------------+
+--R                        |  +-------------+
+--R                        |  |    +-+
+--R           +-+4+-+3 +-+ |  |123\|5  + 275
+--R         2\|2 \|2  \|5  |2 |-------------
+--R                        |  |        +-+
+--R                       \| \|   3200\|5
+--R      *
+--R                                        +-----------------+
+--R                                        |  +-------------+
+--R                                        |  |    +-+
+--R                      +-+ +-+      +-+  |  |123\|5  + 275
+--R                   (5\|2 \|5  - 15\|2 ) |2 |-------------
+--R                                        |  |        +-+
+--R                                       \| \|   3200\|5
+--R         atan(-------------------------------------------------)
+--R                                   +-----------------+
+--R                                   |  +-------------+
+--R                                   |  |    +-+
+--R                 +-+ +-+      +-+  |  |123\|5  + 275        +-+
+--R              (5\|2 \|5  - 15\|2 ) |2 |-------------   - 2x\|5
+--R                                   |  |        +-+
+--R                                  \| \|   3200\|5
+--R     + 
+--R       -
+--R                           +-----------------+
+--R                           |  +-------------+
+--R                           |  |    +-+
+--R              +-+4+-+3 +-+ |  |123\|5  + 275
+--R            2\|2 \|2  \|5  |2 |-------------
+--R                           |  |        +-+
+--R                          \| \|   3200\|5
+--R         *
+--R                                           +-----------------+
+--R                                           |  +-------------+
+--R                                           |  |    +-+
+--R                         +-+ +-+      +-+  |  |123\|5  + 275
+--R                      (5\|2 \|5  - 15\|2 ) |2 |-------------
+--R                                           |  |        +-+
+--R                                          \| \|   3200\|5
+--R            atan(-------------------------------------------------)
+--R                                      +-----------------+
+--R                                      |  +-------------+
+--R                                      |  |    +-+
+--R                    +-+ +-+      +-+  |  |123\|5  + 275        +-+
+--R                 (5\|2 \|5  - 15\|2 ) |2 |-------------   + 2x\|5
+--R                                      |  |        +-+
+--R                                     \| \|   3200\|5
+--R     + 
+--R       -
+--R                           +-----------------+
+--R                           |  +-------------+
+--R                           |  |    +-+
+--R              +-+4+-+3 +-+ |  |123\|5  - 275
+--R            2\|2 \|2  \|5  |2 |-------------
+--R                           |  |        +-+
+--R                          \| \|   3200\|5
+--R         *
+--R                                           +-----------------+
+--R                                           |  +-------------+
+--R                                           |  |    +-+
+--R                         +-+ +-+      +-+  |  |123\|5  - 275
+--R                      (5\|2 \|5  + 15\|2 ) |2 |-------------
+--R                                           |  |        +-+
+--R                                          \| \|   3200\|5
+--R            atan(-------------------------------------------------)
+--R                                      +-----------------+
+--R                                      |  +-------------+
+--R                                      |  |    +-+
+--R                    +-+ +-+      +-+  |  |123\|5  - 275        +-+
+--R                 (5\|2 \|5  + 15\|2 ) |2 |-------------   + 2x\|5
+--R                                      |  |        +-+
+--R                                     \| \|   3200\|5
+--R     + 
+--R       -
+--R                           +-------------------+
+--R                           |    +-------------+
+--R                           |    |    +-+
+--R              +-+4+-+3 +-+ |    |123\|5  - 275
+--R            2\|2 \|2  \|5  |- 2 |-------------
+--R                           |    |        +-+
+--R                          \|   \|   3200\|5
+--R         *
+--R                                           +-------------------+
+--R                                           |    +-------------+
+--R                                           |    |    +-+
+--R                         +-+ +-+      +-+  |    |123\|5  - 275
+--R                      (5\|2 \|5  + 15\|2 ) |- 2 |-------------
+--R                                           |    |        +-+
+--R                                          \|   \|   3200\|5
+--R            atan(---------------------------------------------------)
+--R                                      +-------------------+
+--R                                      |    +-------------+
+--R                                      |    |    +-+
+--R                    +-+ +-+      +-+  |    |123\|5  - 275        +-+
+--R                 (5\|2 \|5  + 15\|2 ) |- 2 |-------------   + 2x\|5
+--R                                      |    |        +-+
+--R                                     \|   \|   3200\|5
+--R     + 
+--R       -
+--R                           +-------------------+
+--R                           |    +-------------+
+--R                           |    |    +-+
+--R              +-+4+-+3 +-+ |    |123\|5  + 275
+--R            2\|2 \|2  \|5  |- 2 |-------------
+--R                           |    |        +-+
+--R                          \|   \|   3200\|5
+--R         *
+--R                                           +-------------------+
+--R                                           |    +-------------+
+--R                                           |    |    +-+
+--R                         +-+ +-+      +-+  |    |123\|5  + 275
+--R                      (5\|2 \|5  - 15\|2 ) |- 2 |-------------
+--R                                           |    |        +-+
+--R                                          \|   \|   3200\|5
+--R            atan(---------------------------------------------------)
+--R                                      +-------------------+
+--R                                      |    +-------------+
+--R                                      |    |    +-+
+--R                    +-+ +-+      +-+  |    |123\|5  + 275        +-+
+--R                 (5\|2 \|5  - 15\|2 ) |- 2 |-------------   + 2x\|5
+--R                                      |    |        +-+
+--R                                     \|   \|   3200\|5
+--R     + 
+--R         +------------+     +---------+          +--------+
+--R        4|   +-+            |  +-+          4+-+4| +-+          2
+--R       2\|55\|5  + 123 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R           +------------+     +---------+          +--------+
+--R          4|   +-+            |  +-+          4+-+4| +-+          2
+--R       - 2\|55\|5  + 123 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R           +--------------+           +----------+    +-----------+
+--R          4|     +-+             4+-+4|   +-+         |    +-+          2
+--R       - 2\|- 55\|5  + 123 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R         +--------------+             +----------+    +-----------+
+--R        4|     +-+               4+-+4|   +-+         |    +-+          2
+--R       2\|- 55\|5  + 123 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                       +--------+3
+--R           +------------+        4+-+3 +-+      4+-+3 4| +-+
+--R          4|   +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 4\|55\|5  + 123 atan(----------------------------------------)
+--R                                                  4
+--R     + 
+--R                                                       +--------+3
+--R           +------------+        4+-+3 +-+      4+-+3 4| +-+
+--R          4|   +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 4\|55\|5  + 123 atan(----------------------------------------)
+--R                                                  4
+--R     + 
+--R                                                         +----------+3
+--R           +--------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R          4|     +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 4\|- 55\|5  + 123 atan(------------------------------------------)
+--R                                                     4
+--R     + 
+--R                                                         +----------+3
+--R           +--------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R          4|     +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 4\|- 55\|5  + 123 atan(------------------------------------------)
+--R                                                     4
+--R  /
+--R      4+-+3 +-+
+--R     8\|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 1474
+
+--S 1475 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                            +----------+2
+--R                       8     4  +-+      4 4|   +-+
+--R                   ((4x  + 6x )\|5  - 10x )\|- \|5  + 3
+--R                 + 
+--R                                                       +-----------+
+--R                         8     4 4+-+2 +-+     4 4+-+2 |    +-+
+--R                   ((- 2x  - 3x )\|2  \|5  + 5x  \|2 )\|- 2\|5  + 6
+--R                 + 
+--R                        10     6     2 4+-+2 +-+       6      2 4+-+2
+--R                   (- 2x   - 6x  - 7x )\|2  \|5  + (10x  + 15x )\|2
+--R              *
+--R                  +--------+3
+--R                 4| +-+
+--R                 \|\|5  + 3
+--R             + 
+--R                                                              +----------+2
+--R                       10      6     2 4+-+2 +-+      6 4+-+24|   +-+
+--R                   ((6x   + 12x  + 2x )\|2  \|5  - 10x  \|2 )\|- \|5  + 3
+--R                 + 
+--R                                                      +-----------+
+--R                         10      6     2  +-+      6  |    +-+
+--R                   ((- 6x   - 12x  - 2x )\|5  + 10x )\|- 2\|5  + 6
+--R                 + 
+--R                        12      8      4      +-+      8      4
+--R                   (- 6x   - 21x  - 25x  - 3)\|5  + 25x  + 45x  + 5
+--R              *
+--R                  +--------+
+--R                 4| +-+
+--R                 \|\|5  + 3
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|5  + 6
+--R         + 
+--R                                           +----------+2
+--R                     10     2  +-+      6 4|   +-+
+--R               ((- 4x   + 4x )\|5  + 20x )\|- \|5  + 3
+--R             + 
+--R                                                   +-----------+
+--R                   10     2 4+-+2 +-+      6 4+-+2 |    +-+
+--R               ((2x   - 2x )\|2  \|5  - 10x  \|2 )\|- 2\|5  + 6
+--R             + 
+--R                  12     8     4     4+-+2 +-+         8      4     4+-+2
+--R               (2x   + 3x  + 3x  - 3)\|2  \|5  + (- 15x  - 15x  + 5)\|2
+--R          *
+--R              +--------+3
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                                     +----------+2
+--R                      8     4 4+-+2 +-+      8 4+-+24|   +-+
+--R               ((- 12x  - 8x )\|2  \|5  - 20x  \|2 )\|- \|5  + 3
+--R             + 
+--R                                         +-----------+
+--R                    8     4  +-+      8  |    +-+
+--R               ((12x  + 8x )\|5  + 20x )\|- 2\|5  + 6
+--R             + 
+--R                   10      6      2  +-+      10      2
+--R               (12x   + 16x  + 12x )\|5  + 20x   - 20x
+--R          *
+--R              +--------+
+--R             4| +-+
+--R             \|\|5  + 3
+--R      *
+--R          +------------+
+--R         4|   +-+
+--R         \|55\|5  + 123
+--R     + 
+--R                                                 +--------------+ +-----------+
+--R                   8     4 4+-+2 +-+     4 4+-+24|     +-+        |    +-+
+--R               ((2x  + 3x )\|2  \|5  + 5x  \|2 )\|- 55\|5  + 123 \|- 2\|5  + 6
+--R             + 
+--R                                                     +--------------+
+--R                     10     2 4+-+2 +-+      6 4+-+24|     +-+
+--R               ((- 2x   + 2x )\|2  \|5  - 10x  \|2 )\|- 55\|5  + 123
+--R          *
+--R              +----------+3
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                            +----------+2
+--R                  8      4 4|   +-+
+--R           (- 240x  - 80x )\|- \|5  + 3
+--R         + 
+--R                                                +--------------+ +-----------+
+--R                   10      6     2  +-+      6 4|     +-+        |    +-+
+--R               ((6x   + 12x  + 2x )\|5  + 10x )\|- 55\|5  + 123 \|- 2\|5  + 6
+--R             + 
+--R                                           +--------------+
+--R                      8     4  +-+      8 4|     +-+
+--R               ((- 12x  - 8x )\|5  + 20x )\|- 55\|5  + 123
+--R          *
+--R              +----------+
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                               +-----------+
+--R                8      4 4+-+2 |    +-+              6      2 4+-+2 +-+
+--R           (120x  + 40x )\|2  \|- 2\|5  + 6  + (- 60x  - 20x )\|2  \|5
+--R         + 
+--R                10       6      2 4+-+2
+--R           (120x   + 220x  + 60x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                          +--------------+ +-----------+
+--R                     8     4  +-+      4 4|     +-+        |    +-+
+--R               ((- 4x  - 6x )\|5  - 10x )\|- 55\|5  + 123 \|- 2\|5  + 6
+--R             + 
+--R                                         +--------------+
+--R                   10     2  +-+      6 4|     +-+
+--R               ((4x   - 4x )\|5  + 20x )\|- 55\|5  + 123
+--R          *
+--R              +----------+3
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                +----------+2
+--R                8      4 4+-+2 4|   +-+
+--R           (240x  + 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                                              +--------------+
+--R                       10      6     2 4+-+2 +-+      6 4+-+24|     +-+
+--R                 ((- 6x   - 12x  - 2x )\|2  \|5  - 10x  \|2 )\|- 55\|5  + 123
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                                                   +--------------+
+--R                    8     4 4+-+2 +-+      8 4+-+24|     +-+
+--R               ((12x  + 8x )\|2  \|5  - 20x  \|2 )\|- 55\|5  + 123
+--R          *
+--R              +----------+
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                            +-----------+
+--R                  8      4  |    +-+             6      2  +-+       10       6
+--R           (- 240x  - 80x )\|- 2\|5  + 6  + (120x  + 40x )\|5  - 240x   - 440x
+--R         + 
+--R                 2
+--R           - 120x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                                +--------------+
+--R                 10     6     2 4+-+2 +-+       6      2 4+-+2 4|     +-+
+--R             ((2x   + 6x  + 7x )\|2  \|5  + (10x  + 15x )\|2  )\|- 55\|5  + 123
+--R          *
+--R              +-----------+
+--R              |    +-+
+--R             \|- 2\|5  + 6
+--R         + 
+--R                   12     8     4     4+-+2 +-+         8      4     4+-+2
+--R             ((- 2x   - 3x  - 3x  + 3)\|2  \|5  + (- 15x  - 15x  + 5)\|2  )
+--R          *
+--R              +--------------+
+--R             4|     +-+
+--R             \|- 55\|5  + 123
+--R      *
+--R          +----------+3
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                                                       +----------+2
+--R               6      2  +-+       10       6       2 4|   +-+
+--R       ((- 120x  - 40x )\|5  - 240x   - 440x  - 120x )\|- \|5  + 3
+--R     + 
+--R                                                              +--------------+
+--R                 12      8      4      +-+      8      4     4|     +-+
+--R             ((6x   + 21x  + 25x  + 3)\|5  + 25x  + 45x  + 5)\|- 55\|5  + 123
+--R          *
+--R              +-----------+
+--R              |    +-+
+--R             \|- 2\|5  + 6
+--R         + 
+--R                                                        +--------------+
+--R                  10      6      2  +-+      10      2 4|     +-+
+--R           ((- 12x   - 16x  - 12x )\|5  + 20x   - 20x )\|- 55\|5  + 123
+--R      *
+--R          +----------+
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                                                               +-----------+
+--R            6      2 4+-+2 +-+        10       6      2 4+-+2  |    +-+
+--R       ((60x  + 20x )\|2  \|5  + (120x   + 220x  + 60x )\|2  )\|- 2\|5  + 6
+--R     + 
+--R            12       8       4      4+-+2
+--R       (120x   + 400x  + 240x  + 40)\|2
+--R  /
+--R                                  +----------+2
+--R               12       8      4 4|   +-+
+--R           (80x   + 240x  + 80x )\|- \|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                 12       8      4 4+-+2 |    +-+
+--R           (- 40x   - 120x  - 40x )\|2  \|- 2\|5  + 6
+--R         + 
+--R             10      6      2 4+-+2 +-+         14       10       6      2 4+-+2
+--R         (20x   + 60x  + 20x )\|2  \|5  + (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                          +----------+2
+--R                 12       8      4 4+-+2 4|   +-+
+--R           (- 80x   - 240x  - 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                  +-----------+
+--R               12       8      4  |    +-+              10       6      2  +-+
+--R           (80x   + 240x  + 80x )\|- 2\|5  + 6  + (- 40x   - 120x  - 40x )\|5
+--R         + 
+--R              14       10       6       2
+--R           80x   + 360x   + 440x  + 120x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R              10       6      2  +-+      14       10       6       2
+--R         ((40x   + 120x  + 40x )\|5  + 80x   + 360x   + 440x  + 120x )
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                 10      6      2 4+-+2 +-+
+--R           (- 20x   - 60x  - 20x )\|2  \|5
+--R         + 
+--R                 14       10       6      2 4+-+2
+--R           (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R             16       12       8       4      4+-+2
+--R       (- 40x   - 240x   - 440x  - 240x  - 40)\|2
+--R                                                    Type: Expression(Integer)
+--E 1475
+
+)clear all
+
+--S 1476 of 2282
+t0:=x^6/(1+3*x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1476
+
+--S 1477 of 2282
+r0:=1/4*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))*(3-sqrt(5))^(3/4)/(2^(1/4)*_
+   sqrt(5))-1/4*atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))*(3-sqrt(5))^(3/4)/_
+   (2^(1/4)*sqrt(5))-1/8*log(2*x^2-2*2^(1/4)*x*(3-sqrt(5))^(1/4)+_
+   sqrt(2*(3-sqrt(5))))*(3-sqrt(5))^(3/4)/(2^(1/4)*sqrt(5))+_
+   1/8*log(2*x^2+2*2^(1/4)*x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*_
+   (3-sqrt(5))^(3/4)/(2^(1/4)*sqrt(5))-1/4*atan(1-2^(3/4)*_
+   x/(3+sqrt(5))^(1/4))*(3+sqrt(5))^(3/4)/(2^(1/4)*sqrt(5))+_
+   1/4*atan(1+2^(3/4)*x/(3+sqrt(5))^(1/4))*(3+sqrt(5))^(3/4)/(2^(1/4)*_
+   sqrt(5))+1/8*log(2*x^2-2*2^(1/4)*x*(3+sqrt(5))^(1/4)+sqrt(2*(3+_
+   sqrt(5))))*(3+sqrt(5))^(3/4)/(2^(1/4)*sqrt(5))-1/8*log(2*x^2+_
+   2*2^(1/4)*x*(3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*(3+_
+   sqrt(5))^(3/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          +--------+3     +---------+          +--------+
+--R         4| +-+           |  +-+          4+-+4| +-+          2
+--R       - \|\|5  + 3  log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +--------+3     +---------+          +--------+
+--R       4| +-+           |  +-+          4+-+4| +-+          2
+--R       \|\|5  + 3  log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +----------+3           +----------+    +-----------+
+--R       4|   +-+            4+-+4|   +-+         |    +-+          2
+--R       \|- \|5  + 3  log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R          +----------+3             +----------+    +-----------+
+--R         4|   +-+              4+-+4|   +-+         |    +-+          2
+--R       - \|- \|5  + 3  log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                    +--------+3
+--R           +--------+3        4+-+3 +-+      4+-+3 4| +-+
+--R          4| +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 2\|\|5  + 3  atan(----------------------------------------)
+--R                                               4
+--R     + 
+--R                                                    +--------+3
+--R           +--------+3        4+-+3 +-+      4+-+3 4| +-+
+--R          4| +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 2\|\|5  + 3  atan(----------------------------------------)
+--R                                               4
+--R     + 
+--R                                                      +----------+3
+--R           +----------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R          4|   +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 2\|- \|5  + 3  atan(------------------------------------------)
+--R                                                  4
+--R     + 
+--R                                                      +----------+3
+--R           +----------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R          4|   +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 2\|- \|5  + 3  atan(------------------------------------------)
+--R                                                  4
+--R  /
+--R      4+-+ +-+
+--R     8\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 1477
+
+--S 1478 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +--------------+
+--R              |  +----------+
+--R              |  |  +-+
+--R          +-+ |  |9\|5  + 20
+--R         \|2  |2 |----------
+--R              |  |      +-+
+--R             \| \| 1600\|5
+--R      *
+--R         log
+--R                                                      +--------------+
+--R                                         +----------+ |  +----------+
+--R                                         |  +-+       |  |  +-+
+--R                    +-+ +-+         +-+  |9\|5  + 20  |  |9\|5  + 20
+--R              (600x\|2 \|5  - 1400x\|2 ) |----------  |2 |----------
+--R                                         |      +-+   |  |      +-+
+--R                                        \| 1600\|5   \| \| 1600\|5
+--R            + 
+--R                             +----------+
+--R                             |  +-+
+--R                  +-+        |9\|5  + 20     2 +-+
+--R              (60\|5  - 100) |----------  + x \|5
+--R                             |      +-+
+--R                            \| 1600\|5
+--R     + 
+--R              +--------------+
+--R              |  +----------+
+--R              |  |  +-+
+--R          +-+ |  |9\|5  - 20
+--R         \|2  |2 |----------
+--R              |  |      +-+
+--R             \| \| 1600\|5
+--R      *
+--R         log
+--R                                                      +--------------+
+--R                                         +----------+ |  +----------+
+--R                                         |  +-+       |  |  +-+
+--R                    +-+ +-+         +-+  |9\|5  - 20  |  |9\|5  - 20
+--R              (600x\|2 \|5  + 1400x\|2 ) |----------  |2 |----------
+--R                                         |      +-+   |  |      +-+
+--R                                        \| 1600\|5   \| \| 1600\|5
+--R            + 
+--R                             +----------+
+--R                             |  +-+
+--R                  +-+        |9\|5  - 20     2 +-+
+--R              (60\|5  + 100) |----------  + x \|5
+--R                             |      +-+
+--R                            \| 1600\|5
+--R     + 
+--R       -
+--R                 +----------------+
+--R                 |    +----------+
+--R                 |    |  +-+
+--R             +-+ |    |9\|5  - 20
+--R            \|2  |- 2 |----------
+--R                 |    |      +-+
+--R                \|   \| 1600\|5
+--R         *
+--R            log
+--R                                                         +----------------+
+--R                                            +----------+ |    +----------+
+--R                                            |  +-+       |    |  +-+
+--R                       +-+ +-+         +-+  |9\|5  - 20  |    |9\|5  - 20
+--R                 (600x\|2 \|5  + 1400x\|2 ) |----------  |- 2 |----------
+--R                                            |      +-+   |    |      +-+
+--R                                           \| 1600\|5   \|   \| 1600\|5
+--R               + 
+--R                                  +----------+
+--R                                  |  +-+
+--R                       +-+        |9\|5  - 20     2 +-+
+--R                 (- 60\|5  - 100) |----------  + x \|5
+--R                                  |      +-+
+--R                                 \| 1600\|5
+--R     + 
+--R       -
+--R                 +----------------+
+--R                 |    +----------+
+--R                 |    |  +-+
+--R             +-+ |    |9\|5  + 20
+--R            \|2  |- 2 |----------
+--R                 |    |      +-+
+--R                \|   \| 1600\|5
+--R         *
+--R            log
+--R                                                         +----------------+
+--R                                            +----------+ |    +----------+
+--R                                            |  +-+       |    |  +-+
+--R                       +-+ +-+         +-+  |9\|5  + 20  |    |9\|5  + 20
+--R                 (600x\|2 \|5  - 1400x\|2 ) |----------  |- 2 |----------
+--R                                            |      +-+   |    |      +-+
+--R                                           \| 1600\|5   \|   \| 1600\|5
+--R               + 
+--R                                  +----------+
+--R                                  |  +-+
+--R                       +-+        |9\|5  + 20     2 +-+
+--R                 (- 60\|5  + 100) |----------  + x \|5
+--R                                  |      +-+
+--R                                 \| 1600\|5
+--R     + 
+--R              +----------------+
+--R              |    +----------+
+--R              |    |  +-+
+--R          +-+ |    |9\|5  + 20
+--R         \|2  |- 2 |----------
+--R              |    |      +-+
+--R             \|   \| 1600\|5
+--R      *
+--R         log
+--R                                                        +----------------+
+--R                                           +----------+ |    +----------+
+--R                                           |  +-+       |    |  +-+
+--R                      +-+ +-+         +-+  |9\|5  + 20  |    |9\|5  + 20
+--R              (- 600x\|2 \|5  + 1400x\|2 ) |----------  |- 2 |----------
+--R                                           |      +-+   |    |      +-+
+--R                                          \| 1600\|5   \|   \| 1600\|5
+--R            + 
+--R                               +----------+
+--R                               |  +-+
+--R                    +-+        |9\|5  + 20     2 +-+
+--R              (- 60\|5  + 100) |----------  + x \|5
+--R                               |      +-+
+--R                              \| 1600\|5
+--R     + 
+--R              +----------------+
+--R              |    +----------+
+--R              |    |  +-+
+--R          +-+ |    |9\|5  - 20
+--R         \|2  |- 2 |----------
+--R              |    |      +-+
+--R             \|   \| 1600\|5
+--R      *
+--R         log
+--R                                                        +----------------+
+--R                                           +----------+ |    +----------+
+--R                                           |  +-+       |    |  +-+
+--R                      +-+ +-+         +-+  |9\|5  - 20  |    |9\|5  - 20
+--R              (- 600x\|2 \|5  - 1400x\|2 ) |----------  |- 2 |----------
+--R                                           |      +-+   |    |      +-+
+--R                                          \| 1600\|5   \|   \| 1600\|5
+--R            + 
+--R                               +----------+
+--R                               |  +-+
+--R                    +-+        |9\|5  - 20     2 +-+
+--R              (- 60\|5  - 100) |----------  + x \|5
+--R                               |      +-+
+--R                              \| 1600\|5
+--R     + 
+--R       -
+--R                 +--------------+
+--R                 |  +----------+
+--R                 |  |  +-+
+--R             +-+ |  |9\|5  - 20
+--R            \|2  |2 |----------
+--R                 |  |      +-+
+--R                \| \| 1600\|5
+--R         *
+--R            log
+--R                                                           +--------------+
+--R                                              +----------+ |  +----------+
+--R                                              |  +-+       |  |  +-+
+--R                         +-+ +-+         +-+  |9\|5  - 20  |  |9\|5  - 20
+--R                 (- 600x\|2 \|5  - 1400x\|2 ) |----------  |2 |----------
+--R                                              |      +-+   |  |      +-+
+--R                                             \| 1600\|5   \| \| 1600\|5
+--R               + 
+--R                                +----------+
+--R                                |  +-+
+--R                     +-+        |9\|5  - 20     2 +-+
+--R                 (60\|5  + 100) |----------  + x \|5
+--R                                |      +-+
+--R                               \| 1600\|5
+--R     + 
+--R       -
+--R                 +--------------+
+--R                 |  +----------+
+--R                 |  |  +-+
+--R             +-+ |  |9\|5  + 20
+--R            \|2  |2 |----------
+--R                 |  |      +-+
+--R                \| \| 1600\|5
+--R         *
+--R            log
+--R                                                           +--------------+
+--R                                              +----------+ |  +----------+
+--R                                              |  +-+       |  |  +-+
+--R                         +-+ +-+         +-+  |9\|5  + 20  |  |9\|5  + 20
+--R                 (- 600x\|2 \|5  + 1400x\|2 ) |----------  |2 |----------
+--R                                              |      +-+   |  |      +-+
+--R                                             \| 1600\|5   \| \| 1600\|5
+--R               + 
+--R                                +----------+
+--R                                |  +-+
+--R                     +-+        |9\|5  + 20     2 +-+
+--R                 (60\|5  - 100) |----------  + x \|5
+--R                                |      +-+
+--R                               \| 1600\|5
+--R     + 
+--R               +----------------+
+--R               |    +----------+
+--R               |    |  +-+
+--R           +-+ |    |9\|5  + 20
+--R         2\|2  |- 2 |----------
+--R               |    |      +-+
+--R              \|   \| 1600\|5
+--R      *
+--R                                                       +----------------+
+--R                                          +----------+ |    +----------+
+--R                                          |  +-+       |    |  +-+
+--R                       +-+ +-+       +-+  |9\|5  + 20  |    |9\|5  + 20
+--R                  (300\|2 \|5  - 700\|2 ) |----------  |- 2 |----------
+--R                                          |      +-+   |    |      +-+
+--R                                         \| 1600\|5   \|   \| 1600\|5
+--R         atan(---------------------------------------------------------------)
+--R                                                   +----------------+
+--R                                      +----------+ |    +----------+
+--R                                      |  +-+       |    |  +-+
+--R                   +-+ +-+       +-+  |9\|5  + 20  |    |9\|5  + 20       +-+
+--R              (300\|2 \|5  - 700\|2 ) |----------  |- 2 |----------   - x\|5
+--R                                      |      +-+   |    |      +-+
+--R                                     \| 1600\|5   \|   \| 1600\|5
+--R     + 
+--R               +----------------+
+--R               |    +----------+
+--R               |    |  +-+
+--R           +-+ |    |9\|5  - 20
+--R         2\|2  |- 2 |----------
+--R               |    |      +-+
+--R              \|   \| 1600\|5
+--R      *
+--R                                                       +----------------+
+--R                                          +----------+ |    +----------+
+--R                                          |  +-+       |    |  +-+
+--R                       +-+ +-+       +-+  |9\|5  - 20  |    |9\|5  - 20
+--R                  (300\|2 \|5  + 700\|2 ) |----------  |- 2 |----------
+--R                                          |      +-+   |    |      +-+
+--R                                         \| 1600\|5   \|   \| 1600\|5
+--R         atan(---------------------------------------------------------------)
+--R                                                   +----------------+
+--R                                      +----------+ |    +----------+
+--R                                      |  +-+       |    |  +-+
+--R                   +-+ +-+       +-+  |9\|5  - 20  |    |9\|5  - 20       +-+
+--R              (300\|2 \|5  + 700\|2 ) |----------  |- 2 |----------   - x\|5
+--R                                      |      +-+   |    |      +-+
+--R                                     \| 1600\|5   \|   \| 1600\|5
+--R     + 
+--R       -
+--R                  +--------------+
+--R                  |  +----------+
+--R                  |  |  +-+
+--R              +-+ |  |9\|5  - 20
+--R            2\|2  |2 |----------
+--R                  |  |      +-+
+--R                 \| \| 1600\|5
+--R         *
+--R                                                          +--------------+
+--R                                             +----------+ |  +----------+
+--R                                             |  +-+       |  |  +-+
+--R                          +-+ +-+       +-+  |9\|5  - 20  |  |9\|5  - 20
+--R                     (300\|2 \|5  + 700\|2 ) |----------  |2 |----------
+--R                                             |      +-+   |  |      +-+
+--R                                            \| 1600\|5   \| \| 1600\|5
+--R            atan(-------------------------------------------------------------)
+--R                                                      +--------------+
+--R                                         +----------+ |  +----------+
+--R                                         |  +-+       |  |  +-+
+--R                      +-+ +-+       +-+  |9\|5  - 20  |  |9\|5  - 20       +-+
+--R                 (300\|2 \|5  + 700\|2 ) |----------  |2 |----------   - x\|5
+--R                                         |      +-+   |  |      +-+
+--R                                        \| 1600\|5   \| \| 1600\|5
+--R     + 
+--R       -
+--R                  +--------------+
+--R                  |  +----------+
+--R                  |  |  +-+
+--R              +-+ |  |9\|5  + 20
+--R            2\|2  |2 |----------
+--R                  |  |      +-+
+--R                 \| \| 1600\|5
+--R         *
+--R                                                          +--------------+
+--R                                             +----------+ |  +----------+
+--R                                             |  +-+       |  |  +-+
+--R                          +-+ +-+       +-+  |9\|5  + 20  |  |9\|5  + 20
+--R                     (300\|2 \|5  - 700\|2 ) |----------  |2 |----------
+--R                                             |      +-+   |  |      +-+
+--R                                            \| 1600\|5   \| \| 1600\|5
+--R            atan(-------------------------------------------------------------)
+--R                                                      +--------------+
+--R                                         +----------+ |  +----------+
+--R                                         |  +-+       |  |  +-+
+--R                      +-+ +-+       +-+  |9\|5  + 20  |  |9\|5  + 20       +-+
+--R                 (300\|2 \|5  - 700\|2 ) |----------  |2 |----------   - x\|5
+--R                                         |      +-+   |  |      +-+
+--R                                        \| 1600\|5   \| \| 1600\|5
+--R     + 
+--R               +--------------+
+--R               |  +----------+
+--R               |  |  +-+
+--R           +-+ |  |9\|5  + 20
+--R         2\|2  |2 |----------
+--R               |  |      +-+
+--R              \| \| 1600\|5
+--R      *
+--R                                                       +--------------+
+--R                                          +----------+ |  +----------+
+--R                                          |  +-+       |  |  +-+
+--R                       +-+ +-+       +-+  |9\|5  + 20  |  |9\|5  + 20
+--R                  (300\|2 \|5  - 700\|2 ) |----------  |2 |----------
+--R                                          |      +-+   |  |      +-+
+--R                                         \| 1600\|5   \| \| 1600\|5
+--R         atan(-------------------------------------------------------------)
+--R                                                   +--------------+
+--R                                      +----------+ |  +----------+
+--R                                      |  +-+       |  |  +-+
+--R                   +-+ +-+       +-+  |9\|5  + 20  |  |9\|5  + 20       +-+
+--R              (300\|2 \|5  - 700\|2 ) |----------  |2 |----------   + x\|5
+--R                                      |      +-+   |  |      +-+
+--R                                     \| 1600\|5   \| \| 1600\|5
+--R     + 
+--R               +--------------+
+--R               |  +----------+
+--R               |  |  +-+
+--R           +-+ |  |9\|5  - 20
+--R         2\|2  |2 |----------
+--R               |  |      +-+
+--R              \| \| 1600\|5
+--R      *
+--R                                                       +--------------+
+--R                                          +----------+ |  +----------+
+--R                                          |  +-+       |  |  +-+
+--R                       +-+ +-+       +-+  |9\|5  - 20  |  |9\|5  - 20
+--R                  (300\|2 \|5  + 700\|2 ) |----------  |2 |----------
+--R                                          |      +-+   |  |      +-+
+--R                                         \| 1600\|5   \| \| 1600\|5
+--R         atan(-------------------------------------------------------------)
+--R                                                   +--------------+
+--R                                      +----------+ |  +----------+
+--R                                      |  +-+       |  |  +-+
+--R                   +-+ +-+       +-+  |9\|5  - 20  |  |9\|5  - 20       +-+
+--R              (300\|2 \|5  + 700\|2 ) |----------  |2 |----------   + x\|5
+--R                                      |      +-+   |  |      +-+
+--R                                     \| 1600\|5   \| \| 1600\|5
+--R     + 
+--R       -
+--R                  +----------------+
+--R                  |    +----------+
+--R                  |    |  +-+
+--R              +-+ |    |9\|5  - 20
+--R            2\|2  |- 2 |----------
+--R                  |    |      +-+
+--R                 \|   \| 1600\|5
+--R         *
+--R                                                        +----------------+
+--R                                           +----------+ |    +----------+
+--R                                           |  +-+       |    |  +-+
+--R                        +-+ +-+       +-+  |9\|5  - 20  |    |9\|5  - 20
+--R                   (300\|2 \|5  + 700\|2 ) |----------  |- 2 |----------
+--R                                           |      +-+   |    |      +-+
+--R                                          \| 1600\|5   \|   \| 1600\|5
+--R          atan(---------------------------------------------------------------)
+--R                                                    +----------------+
+--R                                       +----------+ |    +----------+
+--R                                       |  +-+       |    |  +-+
+--R                    +-+ +-+       +-+  |9\|5  - 20  |    |9\|5  - 20       +-+
+--R               (300\|2 \|5  + 700\|2 ) |----------  |- 2 |----------   + x\|5
+--R                                       |      +-+   |    |      +-+
+--R                                      \| 1600\|5   \|   \| 1600\|5
+--R     + 
+--R       -
+--R                  +----------------+
+--R                  |    +----------+
+--R                  |    |  +-+
+--R              +-+ |    |9\|5  + 20
+--R            2\|2  |- 2 |----------
+--R                  |    |      +-+
+--R                 \|   \| 1600\|5
+--R         *
+--R                                                        +----------------+
+--R                                           +----------+ |    +----------+
+--R                                           |  +-+       |    |  +-+
+--R                        +-+ +-+       +-+  |9\|5  + 20  |    |9\|5  + 20
+--R                   (300\|2 \|5  - 700\|2 ) |----------  |- 2 |----------
+--R                                           |      +-+   |    |      +-+
+--R                                          \| 1600\|5   \|   \| 1600\|5
+--R          atan(---------------------------------------------------------------)
+--R                                                    +----------------+
+--R                                       +----------+ |    +----------+
+--R                                       |  +-+       |    |  +-+
+--R                    +-+ +-+       +-+  |9\|5  + 20  |    |9\|5  + 20       +-+
+--R               (300\|2 \|5  - 700\|2 ) |----------  |- 2 |----------   + x\|5
+--R                                       |      +-+   |    |      +-+
+--R                                      \| 1600\|5   \|   \| 1600\|5
+--R  /
+--R     8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1478
+
+--S 1479 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +--------------+
+--R                      |  +----------+
+--R                      |  |  +-+
+--R          +-+4+-+ +-+ |  |9\|5  + 20
+--R         \|2 \|2 \|5  |2 |----------
+--R                      |  |      +-+
+--R                     \| \| 1600\|5
+--R      *
+--R         log
+--R                                                      +--------------+
+--R                                         +----------+ |  +----------+
+--R                                         |  +-+       |  |  +-+
+--R                    +-+ +-+         +-+  |9\|5  + 20  |  |9\|5  + 20
+--R              (600x\|2 \|5  - 1400x\|2 ) |----------  |2 |----------
+--R                                         |      +-+   |  |      +-+
+--R                                        \| 1600\|5   \| \| 1600\|5
+--R            + 
+--R                             +----------+
+--R                             |  +-+
+--R                  +-+        |9\|5  + 20     2 +-+
+--R              (60\|5  - 100) |----------  + x \|5
+--R                             |      +-+
+--R                            \| 1600\|5
+--R     + 
+--R                      +--------------+
+--R                      |  +----------+
+--R                      |  |  +-+
+--R          +-+4+-+ +-+ |  |9\|5  - 20
+--R         \|2 \|2 \|5  |2 |----------
+--R                      |  |      +-+
+--R                     \| \| 1600\|5
+--R      *
+--R         log
+--R                                                      +--------------+
+--R                                         +----------+ |  +----------+
+--R                                         |  +-+       |  |  +-+
+--R                    +-+ +-+         +-+  |9\|5  - 20  |  |9\|5  - 20
+--R              (600x\|2 \|5  + 1400x\|2 ) |----------  |2 |----------
+--R                                         |      +-+   |  |      +-+
+--R                                        \| 1600\|5   \| \| 1600\|5
+--R            + 
+--R                             +----------+
+--R                             |  +-+
+--R                  +-+        |9\|5  - 20     2 +-+
+--R              (60\|5  + 100) |----------  + x \|5
+--R                             |      +-+
+--R                            \| 1600\|5
+--R     + 
+--R       -
+--R                         +----------------+
+--R                         |    +----------+
+--R                         |    |  +-+
+--R             +-+4+-+ +-+ |    |9\|5  - 20
+--R            \|2 \|2 \|5  |- 2 |----------
+--R                         |    |      +-+
+--R                        \|   \| 1600\|5
+--R         *
+--R            log
+--R                                                         +----------------+
+--R                                            +----------+ |    +----------+
+--R                                            |  +-+       |    |  +-+
+--R                       +-+ +-+         +-+  |9\|5  - 20  |    |9\|5  - 20
+--R                 (600x\|2 \|5  + 1400x\|2 ) |----------  |- 2 |----------
+--R                                            |      +-+   |    |      +-+
+--R                                           \| 1600\|5   \|   \| 1600\|5
+--R               + 
+--R                                  +----------+
+--R                                  |  +-+
+--R                       +-+        |9\|5  - 20     2 +-+
+--R                 (- 60\|5  - 100) |----------  + x \|5
+--R                                  |      +-+
+--R                                 \| 1600\|5
+--R     + 
+--R       -
+--R                         +----------------+
+--R                         |    +----------+
+--R                         |    |  +-+
+--R             +-+4+-+ +-+ |    |9\|5  + 20
+--R            \|2 \|2 \|5  |- 2 |----------
+--R                         |    |      +-+
+--R                        \|   \| 1600\|5
+--R         *
+--R            log
+--R                                                         +----------------+
+--R                                            +----------+ |    +----------+
+--R                                            |  +-+       |    |  +-+
+--R                       +-+ +-+         +-+  |9\|5  + 20  |    |9\|5  + 20
+--R                 (600x\|2 \|5  - 1400x\|2 ) |----------  |- 2 |----------
+--R                                            |      +-+   |    |      +-+
+--R                                           \| 1600\|5   \|   \| 1600\|5
+--R               + 
+--R                                  +----------+
+--R                                  |  +-+
+--R                       +-+        |9\|5  + 20     2 +-+
+--R                 (- 60\|5  + 100) |----------  + x \|5
+--R                                  |      +-+
+--R                                 \| 1600\|5
+--R     + 
+--R                      +----------------+
+--R                      |    +----------+
+--R                      |    |  +-+
+--R          +-+4+-+ +-+ |    |9\|5  + 20
+--R         \|2 \|2 \|5  |- 2 |----------
+--R                      |    |      +-+
+--R                     \|   \| 1600\|5
+--R      *
+--R         log
+--R                                                        +----------------+
+--R                                           +----------+ |    +----------+
+--R                                           |  +-+       |    |  +-+
+--R                      +-+ +-+         +-+  |9\|5  + 20  |    |9\|5  + 20
+--R              (- 600x\|2 \|5  + 1400x\|2 ) |----------  |- 2 |----------
+--R                                           |      +-+   |    |      +-+
+--R                                          \| 1600\|5   \|   \| 1600\|5
+--R            + 
+--R                               +----------+
+--R                               |  +-+
+--R                    +-+        |9\|5  + 20     2 +-+
+--R              (- 60\|5  + 100) |----------  + x \|5
+--R                               |      +-+
+--R                              \| 1600\|5
+--R     + 
+--R                      +----------------+
+--R                      |    +----------+
+--R                      |    |  +-+
+--R          +-+4+-+ +-+ |    |9\|5  - 20
+--R         \|2 \|2 \|5  |- 2 |----------
+--R                      |    |      +-+
+--R                     \|   \| 1600\|5
+--R      *
+--R         log
+--R                                                        +----------------+
+--R                                           +----------+ |    +----------+
+--R                                           |  +-+       |    |  +-+
+--R                      +-+ +-+         +-+  |9\|5  - 20  |    |9\|5  - 20
+--R              (- 600x\|2 \|5  - 1400x\|2 ) |----------  |- 2 |----------
+--R                                           |      +-+   |    |      +-+
+--R                                          \| 1600\|5   \|   \| 1600\|5
+--R            + 
+--R                               +----------+
+--R                               |  +-+
+--R                    +-+        |9\|5  - 20     2 +-+
+--R              (- 60\|5  - 100) |----------  + x \|5
+--R                               |      +-+
+--R                              \| 1600\|5
+--R     + 
+--R       -
+--R                         +--------------+
+--R                         |  +----------+
+--R                         |  |  +-+
+--R             +-+4+-+ +-+ |  |9\|5  - 20
+--R            \|2 \|2 \|5  |2 |----------
+--R                         |  |      +-+
+--R                        \| \| 1600\|5
+--R         *
+--R            log
+--R                                                           +--------------+
+--R                                              +----------+ |  +----------+
+--R                                              |  +-+       |  |  +-+
+--R                         +-+ +-+         +-+  |9\|5  - 20  |  |9\|5  - 20
+--R                 (- 600x\|2 \|5  - 1400x\|2 ) |----------  |2 |----------
+--R                                              |      +-+   |  |      +-+
+--R                                             \| 1600\|5   \| \| 1600\|5
+--R               + 
+--R                                +----------+
+--R                                |  +-+
+--R                     +-+        |9\|5  - 20     2 +-+
+--R                 (60\|5  + 100) |----------  + x \|5
+--R                                |      +-+
+--R                               \| 1600\|5
+--R     + 
+--R       -
+--R                         +--------------+
+--R                         |  +----------+
+--R                         |  |  +-+
+--R             +-+4+-+ +-+ |  |9\|5  + 20
+--R            \|2 \|2 \|5  |2 |----------
+--R                         |  |      +-+
+--R                        \| \| 1600\|5
+--R         *
+--R            log
+--R                                                           +--------------+
+--R                                              +----------+ |  +----------+
+--R                                              |  +-+       |  |  +-+
+--R                         +-+ +-+         +-+  |9\|5  + 20  |  |9\|5  + 20
+--R                 (- 600x\|2 \|5  + 1400x\|2 ) |----------  |2 |----------
+--R                                              |      +-+   |  |      +-+
+--R                                             \| 1600\|5   \| \| 1600\|5
+--R               + 
+--R                                +----------+
+--R                                |  +-+
+--R                     +-+        |9\|5  + 20     2 +-+
+--R                 (60\|5  - 100) |----------  + x \|5
+--R                                |      +-+
+--R                               \| 1600\|5
+--R     + 
+--R                       +----------------+
+--R                       |    +----------+
+--R                       |    |  +-+
+--R           +-+4+-+ +-+ |    |9\|5  + 20
+--R         2\|2 \|2 \|5  |- 2 |----------
+--R                       |    |      +-+
+--R                      \|   \| 1600\|5
+--R      *
+--R                                                       +----------------+
+--R                                          +----------+ |    +----------+
+--R                                          |  +-+       |    |  +-+
+--R                       +-+ +-+       +-+  |9\|5  + 20  |    |9\|5  + 20
+--R                  (300\|2 \|5  - 700\|2 ) |----------  |- 2 |----------
+--R                                          |      +-+   |    |      +-+
+--R                                         \| 1600\|5   \|   \| 1600\|5
+--R         atan(---------------------------------------------------------------)
+--R                                                   +----------------+
+--R                                      +----------+ |    +----------+
+--R                                      |  +-+       |    |  +-+
+--R                   +-+ +-+       +-+  |9\|5  + 20  |    |9\|5  + 20       +-+
+--R              (300\|2 \|5  - 700\|2 ) |----------  |- 2 |----------   - x\|5
+--R                                      |      +-+   |    |      +-+
+--R                                     \| 1600\|5   \|   \| 1600\|5
+--R     + 
+--R                       +----------------+
+--R                       |    +----------+
+--R                       |    |  +-+
+--R           +-+4+-+ +-+ |    |9\|5  - 20
+--R         2\|2 \|2 \|5  |- 2 |----------
+--R                       |    |      +-+
+--R                      \|   \| 1600\|5
+--R      *
+--R                                                       +----------------+
+--R                                          +----------+ |    +----------+
+--R                                          |  +-+       |    |  +-+
+--R                       +-+ +-+       +-+  |9\|5  - 20  |    |9\|5  - 20
+--R                  (300\|2 \|5  + 700\|2 ) |----------  |- 2 |----------
+--R                                          |      +-+   |    |      +-+
+--R                                         \| 1600\|5   \|   \| 1600\|5
+--R         atan(---------------------------------------------------------------)
+--R                                                   +----------------+
+--R                                      +----------+ |    +----------+
+--R                                      |  +-+       |    |  +-+
+--R                   +-+ +-+       +-+  |9\|5  - 20  |    |9\|5  - 20       +-+
+--R              (300\|2 \|5  + 700\|2 ) |----------  |- 2 |----------   - x\|5
+--R                                      |      +-+   |    |      +-+
+--R                                     \| 1600\|5   \|   \| 1600\|5
+--R     + 
+--R       -
+--R                          +--------------+
+--R                          |  +----------+
+--R                          |  |  +-+
+--R              +-+4+-+ +-+ |  |9\|5  - 20
+--R            2\|2 \|2 \|5  |2 |----------
+--R                          |  |      +-+
+--R                         \| \| 1600\|5
+--R         *
+--R                                                          +--------------+
+--R                                             +----------+ |  +----------+
+--R                                             |  +-+       |  |  +-+
+--R                          +-+ +-+       +-+  |9\|5  - 20  |  |9\|5  - 20
+--R                     (300\|2 \|5  + 700\|2 ) |----------  |2 |----------
+--R                                             |      +-+   |  |      +-+
+--R                                            \| 1600\|5   \| \| 1600\|5
+--R            atan(-------------------------------------------------------------)
+--R                                                      +--------------+
+--R                                         +----------+ |  +----------+
+--R                                         |  +-+       |  |  +-+
+--R                      +-+ +-+       +-+  |9\|5  - 20  |  |9\|5  - 20       +-+
+--R                 (300\|2 \|5  + 700\|2 ) |----------  |2 |----------   - x\|5
+--R                                         |      +-+   |  |      +-+
+--R                                        \| 1600\|5   \| \| 1600\|5
+--R     + 
+--R       -
+--R                          +--------------+
+--R                          |  +----------+
+--R                          |  |  +-+
+--R              +-+4+-+ +-+ |  |9\|5  + 20
+--R            2\|2 \|2 \|5  |2 |----------
+--R                          |  |      +-+
+--R                         \| \| 1600\|5
+--R         *
+--R                                                          +--------------+
+--R                                             +----------+ |  +----------+
+--R                                             |  +-+       |  |  +-+
+--R                          +-+ +-+       +-+  |9\|5  + 20  |  |9\|5  + 20
+--R                     (300\|2 \|5  - 700\|2 ) |----------  |2 |----------
+--R                                             |      +-+   |  |      +-+
+--R                                            \| 1600\|5   \| \| 1600\|5
+--R            atan(-------------------------------------------------------------)
+--R                                                      +--------------+
+--R                                         +----------+ |  +----------+
+--R                                         |  +-+       |  |  +-+
+--R                      +-+ +-+       +-+  |9\|5  + 20  |  |9\|5  + 20       +-+
+--R                 (300\|2 \|5  - 700\|2 ) |----------  |2 |----------   - x\|5
+--R                                         |      +-+   |  |      +-+
+--R                                        \| 1600\|5   \| \| 1600\|5
+--R     + 
+--R                       +--------------+
+--R                       |  +----------+
+--R                       |  |  +-+
+--R           +-+4+-+ +-+ |  |9\|5  + 20
+--R         2\|2 \|2 \|5  |2 |----------
+--R                       |  |      +-+
+--R                      \| \| 1600\|5
+--R      *
+--R                                                       +--------------+
+--R                                          +----------+ |  +----------+
+--R                                          |  +-+       |  |  +-+
+--R                       +-+ +-+       +-+  |9\|5  + 20  |  |9\|5  + 20
+--R                  (300\|2 \|5  - 700\|2 ) |----------  |2 |----------
+--R                                          |      +-+   |  |      +-+
+--R                                         \| 1600\|5   \| \| 1600\|5
+--R         atan(-------------------------------------------------------------)
+--R                                                   +--------------+
+--R                                      +----------+ |  +----------+
+--R                                      |  +-+       |  |  +-+
+--R                   +-+ +-+       +-+  |9\|5  + 20  |  |9\|5  + 20       +-+
+--R              (300\|2 \|5  - 700\|2 ) |----------  |2 |----------   + x\|5
+--R                                      |      +-+   |  |      +-+
+--R                                     \| 1600\|5   \| \| 1600\|5
+--R     + 
+--R                       +--------------+
+--R                       |  +----------+
+--R                       |  |  +-+
+--R           +-+4+-+ +-+ |  |9\|5  - 20
+--R         2\|2 \|2 \|5  |2 |----------
+--R                       |  |      +-+
+--R                      \| \| 1600\|5
+--R      *
+--R                                                       +--------------+
+--R                                          +----------+ |  +----------+
+--R                                          |  +-+       |  |  +-+
+--R                       +-+ +-+       +-+  |9\|5  - 20  |  |9\|5  - 20
+--R                  (300\|2 \|5  + 700\|2 ) |----------  |2 |----------
+--R                                          |      +-+   |  |      +-+
+--R                                         \| 1600\|5   \| \| 1600\|5
+--R         atan(-------------------------------------------------------------)
+--R                                                   +--------------+
+--R                                      +----------+ |  +----------+
+--R                                      |  +-+       |  |  +-+
+--R                   +-+ +-+       +-+  |9\|5  - 20  |  |9\|5  - 20       +-+
+--R              (300\|2 \|5  + 700\|2 ) |----------  |2 |----------   + x\|5
+--R                                      |      +-+   |  |      +-+
+--R                                     \| 1600\|5   \| \| 1600\|5
+--R     + 
+--R       -
+--R                          +----------------+
+--R                          |    +----------+
+--R                          |    |  +-+
+--R              +-+4+-+ +-+ |    |9\|5  - 20
+--R            2\|2 \|2 \|5  |- 2 |----------
+--R                          |    |      +-+
+--R                         \|   \| 1600\|5
+--R         *
+--R                                                        +----------------+
+--R                                           +----------+ |    +----------+
+--R                                           |  +-+       |    |  +-+
+--R                        +-+ +-+       +-+  |9\|5  - 20  |    |9\|5  - 20
+--R                   (300\|2 \|5  + 700\|2 ) |----------  |- 2 |----------
+--R                                           |      +-+   |    |      +-+
+--R                                          \| 1600\|5   \|   \| 1600\|5
+--R          atan(---------------------------------------------------------------)
+--R                                                    +----------------+
+--R                                       +----------+ |    +----------+
+--R                                       |  +-+       |    |  +-+
+--R                    +-+ +-+       +-+  |9\|5  - 20  |    |9\|5  - 20       +-+
+--R               (300\|2 \|5  + 700\|2 ) |----------  |- 2 |----------   + x\|5
+--R                                       |      +-+   |    |      +-+
+--R                                      \| 1600\|5   \|   \| 1600\|5
+--R     + 
+--R       -
+--R                          +----------------+
+--R                          |    +----------+
+--R                          |    |  +-+
+--R              +-+4+-+ +-+ |    |9\|5  + 20
+--R            2\|2 \|2 \|5  |- 2 |----------
+--R                          |    |      +-+
+--R                         \|   \| 1600\|5
+--R         *
+--R                                                        +----------------+
+--R                                           +----------+ |    +----------+
+--R                                           |  +-+       |    |  +-+
+--R                        +-+ +-+       +-+  |9\|5  + 20  |    |9\|5  + 20
+--R                   (300\|2 \|5  - 700\|2 ) |----------  |- 2 |----------
+--R                                           |      +-+   |    |      +-+
+--R                                          \| 1600\|5   \|   \| 1600\|5
+--R          atan(---------------------------------------------------------------)
+--R                                                    +----------------+
+--R                                       +----------+ |    +----------+
+--R                                       |  +-+       |    |  +-+
+--R                    +-+ +-+       +-+  |9\|5  + 20  |    |9\|5  + 20       +-+
+--R               (300\|2 \|5  - 700\|2 ) |----------  |- 2 |----------   + x\|5
+--R                                       |      +-+   |    |      +-+
+--R                                      \| 1600\|5   \|   \| 1600\|5
+--R     + 
+--R        +--------+3     +---------+          +--------+
+--R       4| +-+           |  +-+          4+-+4| +-+          2
+--R       \|\|5  + 3  log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +--------+3     +---------+          +--------+
+--R         4| +-+           |  +-+          4+-+4| +-+          2
+--R       - \|\|5  + 3  log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +----------+3           +----------+    +-----------+
+--R         4|   +-+            4+-+4|   +-+         |    +-+          2
+--R       - \|- \|5  + 3  log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R        +----------+3             +----------+    +-----------+
+--R       4|   +-+              4+-+4|   +-+         |    +-+          2
+--R       \|- \|5  + 3  log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                  +--------+3
+--R         +--------+3        4+-+3 +-+      4+-+3 4| +-+
+--R        4| +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       2\|\|5  + 3  atan(----------------------------------------)
+--R                                             4
+--R     + 
+--R                                                  +--------+3
+--R         +--------+3        4+-+3 +-+      4+-+3 4| +-+
+--R        4| +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       2\|\|5  + 3  atan(----------------------------------------)
+--R                                             4
+--R     + 
+--R                                                    +----------+3
+--R         +----------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|   +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       2\|- \|5  + 3  atan(------------------------------------------)
+--R                                                4
+--R     + 
+--R                                                    +----------+3
+--R         +----------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|   +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       2\|- \|5  + 3  atan(------------------------------------------)
+--R                                                4
+--R  /
+--R      4+-+ +-+
+--R     8\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 1479
+
+--S 1480 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                                    +----------+2
+--R                     8     4 4+-+2 +-+      8 4+-+24|   +-+
+--R               ((- 6x  - 4x )\|2  \|5  - 10x  \|2 )\|- \|5  + 3
+--R             + 
+--R                                        +-----------+
+--R                   8     4  +-+      8  |    +-+           10     6     2  +-+
+--R               ((6x  + 4x )\|5  + 10x )\|- 2\|5  + 6  + (6x   + 8x  + 6x )\|5
+--R             + 
+--R                  10      2
+--R               10x   - 10x
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                    8     4  +-+      8  |    +-+           10      6      2
+--R             (((- 6x  - 4x )\|5  + 10x )\|- 2\|5  + 6  + 60x   + 60x  + 20x )
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                        +-----------+
+--R                 10      6      2 4+-+2 |    +-+
+--R           (- 30x   - 30x  - 10x )\|2  \|- 2\|5  + 6
+--R         + 
+--R                12     8     4     4+-+2 +-+         12      8      4 4+-+2
+--R           (- 9x   + 9x  - 3x  - 2)\|2  \|5  + (- 15x   - 75x  - 15x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                                  +-----------+
+--R                   8     4 4+-+2 +-+      8 4+-+2 |    +-+
+--R               ((6x  + 4x )\|2  \|5  - 10x  \|2 )\|- 2\|5  + 6
+--R             + 
+--R                     10      6      2 4+-+2
+--R               (- 60x   - 60x  - 20x )\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                 +-----------+
+--R               10      6      2  |    +-+            12      8     4      +-+
+--R           (60x   + 60x  + 20x )\|- 2\|5  + 6  + (18x   - 18x  + 6x  + 4)\|5
+--R         + 
+--R              12       8      4
+--R           30x   + 150x  + 30x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                     +-----------+
+--R                 10     6     2  +-+      10      2  |    +-+
+--R           ((- 6x   - 8x  - 6x )\|5  + 10x   - 10x )\|- 2\|5  + 6
+--R         + 
+--R                 12      8     4      +-+      12       8      4
+--R           (- 18x   + 18x  - 6x  - 4)\|5  + 30x   + 150x  + 30x
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R             12     8     4     4+-+2 +-+         12      8      4 4+-+2
+--R         ((9x   - 9x  + 3x  + 2)\|2  \|5  + (- 15x   - 75x  - 15x )\|2  )
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R              10      6 4+-+2
+--R       (- 120x   - 80x )\|2
+--R  /
+--R                                  +----------+2
+--R               12       8      4 4|   +-+
+--R           (80x   + 240x  + 80x )\|- \|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                 12       8      4 4+-+2 |    +-+
+--R           (- 40x   - 120x  - 40x )\|2  \|- 2\|5  + 6
+--R         + 
+--R             10      6      2 4+-+2 +-+         14       10       6      2 4+-+2
+--R         (20x   + 60x  + 20x )\|2  \|5  + (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                          +----------+2
+--R                 12       8      4 4+-+2 4|   +-+
+--R           (- 80x   - 240x  - 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                  +-----------+
+--R               12       8      4  |    +-+              10       6      2  +-+
+--R           (80x   + 240x  + 80x )\|- 2\|5  + 6  + (- 40x   - 120x  - 40x )\|5
+--R         + 
+--R              14       10       6       2
+--R           80x   + 360x   + 440x  + 120x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R              10       6      2  +-+      14       10       6       2
+--R         ((40x   + 120x  + 40x )\|5  + 80x   + 360x   + 440x  + 120x )
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                 10      6      2 4+-+2 +-+
+--R           (- 20x   - 60x  - 20x )\|2  \|5
+--R         + 
+--R                 14       10       6      2 4+-+2
+--R           (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R             16       12       8       4      4+-+2
+--R       (- 40x   - 240x   - 440x  - 240x  - 40)\|2
+--R                                                    Type: Expression(Integer)
+--E 1480
+
+)clear all
+
+--S 1481 of 2282
+t0:=x^4/(1+3*x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1481
+
+--S 1482 of 2282
+r0:=1/2*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))*(3-sqrt(5))^(1/4)/(2^(3/4)*_
+   sqrt(5))-1/2*atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))*_
+   (3-sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+1/4*log(2*x^2-2*2^(1/4)*_
+   x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*(3-sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))-1/4*log(2*x^2+2*2^(1/4)*x*(3-sqrt(5))^(1/4)+_
+   sqrt(2*(3-sqrt(5))))*(3-sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-_
+   1/2*atan(1-2^(3/4)*x/(3+sqrt(5))^(1/4))*(3+sqrt(5))^(1/4)/(2^(3/4)*_
+   sqrt(5))+1/2*atan(1+2^(3/4)*x/(3+sqrt(5))^(1/4))*(3+_
+   sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-1/4*log(2*x^2-2*2^(1/4)*x*_
+   (3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*(3+sqrt(5))^(1/4)/(2^(3/4)*_
+   sqrt(5))+1/4*log(2*x^2+2*2^(1/4)*x*(3+sqrt(5))^(1/4)+sqrt(2*_
+   (3+sqrt(5))))*(3+sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R        +--------+     +---------+          +--------+
+--R       4| +-+          |  +-+          4+-+4| +-+          2
+--R       \|\|5  + 3 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +--------+     +---------+          +--------+
+--R         4| +-+          |  +-+          4+-+4| +-+          2
+--R       - \|\|5  + 3 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +----------+           +----------+    +-----------+
+--R         4|   +-+           4+-+4|   +-+         |    +-+          2
+--R       - \|- \|5  + 3 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R        +----------+             +----------+    +-----------+
+--R       4|   +-+             4+-+4|   +-+         |    +-+          2
+--R       \|- \|5  + 3 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                   +--------+3
+--R           +--------+        4+-+3 +-+      4+-+3 4| +-+
+--R          4| +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 2\|\|5  + 3 atan(----------------------------------------)
+--R                                              4
+--R     + 
+--R                                                   +--------+3
+--R           +--------+        4+-+3 +-+      4+-+3 4| +-+
+--R          4| +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 2\|\|5  + 3 atan(----------------------------------------)
+--R                                              4
+--R     + 
+--R                                                     +----------+3
+--R           +----------+        4+-+3 +-+      4+-+3 4|   +-+
+--R          4|   +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 2\|- \|5  + 3 atan(------------------------------------------)
+--R                                                 4
+--R     + 
+--R                                                     +----------+3
+--R           +----------+        4+-+3 +-+      4+-+3 4|   +-+
+--R          4|   +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 2\|- \|5  + 3 atan(------------------------------------------)
+--R                                                 4
+--R  /
+--R      4+-+3 +-+
+--R     4\|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 1482
+
+--S 1483 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +-------------+               +-------------+
+--R            |  +---------+                |  +---------+       +---------+
+--R            |  |  +-+                     |  |  +-+            |  +-+
+--R        +-+ |  |3\|5  + 5         +-+ +-+ |  |3\|5  + 5        |3\|5  + 5     2
+--R       \|2  |2 |---------  log(2x\|2 \|5  |2 |---------   + 40 |---------  + x )
+--R            |  |      +-+                 |  |      +-+        |      +-+
+--R           \| \| 3200\|5                 \| \| 3200\|5        \| 3200\|5
+--R     + 
+--R       -
+--R                 +-------------+
+--R                 |  +---------+
+--R                 |  |  +-+
+--R             +-+ |  |3\|5  - 5
+--R            \|2  |2 |---------
+--R                 |  |      +-+
+--R                \| \| 3200\|5
+--R         *
+--R                           +-------------+
+--R                           |  +---------+       +---------+
+--R                           |  |  +-+            |  +-+
+--R                   +-+ +-+ |  |3\|5  - 5        |3\|5  - 5     2
+--R            log(2x\|2 \|5  |2 |---------   + 40 |---------  + x )
+--R                           |  |      +-+        |      +-+
+--R                          \| \| 3200\|5        \| 3200\|5
+--R     + 
+--R       -
+--R                 +---------------+
+--R                 |    +---------+
+--R                 |    |  +-+
+--R             +-+ |    |3\|5  - 5
+--R            \|2  |- 2 |---------
+--R                 |    |      +-+
+--R                \|   \| 3200\|5
+--R         *
+--R                           +---------------+
+--R                           |    +---------+       +---------+
+--R                           |    |  +-+            |  +-+
+--R                   +-+ +-+ |    |3\|5  - 5        |3\|5  - 5     2
+--R            log(2x\|2 \|5  |- 2 |---------   - 40 |---------  + x )
+--R                           |    |      +-+        |      +-+
+--R                          \|   \| 3200\|5        \| 3200\|5
+--R     + 
+--R              +---------------+
+--R              |    +---------+
+--R              |    |  +-+
+--R          +-+ |    |3\|5  + 5
+--R         \|2  |- 2 |---------
+--R              |    |      +-+
+--R             \|   \| 3200\|5
+--R      *
+--R                        +---------------+
+--R                        |    +---------+       +---------+
+--R                        |    |  +-+            |  +-+
+--R                +-+ +-+ |    |3\|5  + 5        |3\|5  + 5     2
+--R         log(2x\|2 \|5  |- 2 |---------   - 40 |---------  + x )
+--R                        |    |      +-+        |      +-+
+--R                       \|   \| 3200\|5        \| 3200\|5
+--R     + 
+--R       -
+--R                 +---------------+
+--R                 |    +---------+
+--R                 |    |  +-+
+--R             +-+ |    |3\|5  + 5
+--R            \|2  |- 2 |---------
+--R                 |    |      +-+
+--R                \|   \| 3200\|5
+--R         *
+--R                             +---------------+
+--R                             |    +---------+       +---------+
+--R                             |    |  +-+            |  +-+
+--R                     +-+ +-+ |    |3\|5  + 5        |3\|5  + 5     2
+--R            log(- 2x\|2 \|5  |- 2 |---------   - 40 |---------  + x )
+--R                             |    |      +-+        |      +-+
+--R                            \|   \| 3200\|5        \| 3200\|5
+--R     + 
+--R              +---------------+
+--R              |    +---------+
+--R              |    |  +-+
+--R          +-+ |    |3\|5  - 5
+--R         \|2  |- 2 |---------
+--R              |    |      +-+
+--R             \|   \| 3200\|5
+--R      *
+--R                          +---------------+
+--R                          |    +---------+       +---------+
+--R                          |    |  +-+            |  +-+
+--R                  +-+ +-+ |    |3\|5  - 5        |3\|5  - 5     2
+--R         log(- 2x\|2 \|5  |- 2 |---------   - 40 |---------  + x )
+--R                          |    |      +-+        |      +-+
+--R                         \|   \| 3200\|5        \| 3200\|5
+--R     + 
+--R              +-------------+
+--R              |  +---------+
+--R              |  |  +-+
+--R          +-+ |  |3\|5  - 5
+--R         \|2  |2 |---------
+--R              |  |      +-+
+--R             \| \| 3200\|5
+--R      *
+--R                          +-------------+
+--R                          |  +---------+       +---------+
+--R                          |  |  +-+            |  +-+
+--R                  +-+ +-+ |  |3\|5  - 5        |3\|5  - 5     2
+--R         log(- 2x\|2 \|5  |2 |---------   + 40 |---------  + x )
+--R                          |  |      +-+        |      +-+
+--R                         \| \| 3200\|5        \| 3200\|5
+--R     + 
+--R       -
+--R                 +-------------+
+--R                 |  +---------+
+--R                 |  |  +-+
+--R             +-+ |  |3\|5  + 5
+--R            \|2  |2 |---------
+--R                 |  |      +-+
+--R                \| \| 3200\|5
+--R         *
+--R                             +-------------+
+--R                             |  +---------+       +---------+
+--R                             |  |  +-+            |  +-+
+--R                     +-+ +-+ |  |3\|5  + 5        |3\|5  + 5     2
+--R            log(- 2x\|2 \|5  |2 |---------   + 40 |---------  + x )
+--R                             |  |      +-+        |      +-+
+--R                            \| \| 3200\|5        \| 3200\|5
+--R     + 
+--R                                             +---------------+
+--R                                             |    +---------+
+--R                                             |    |  +-+
+--R             +---------------+           +-+ |    |3\|5  + 5
+--R             |    +---------+          5\|2  |- 2 |---------
+--R             |    |  +-+                     |    |      +-+
+--R         +-+ |    |3\|5  + 5                \|   \| 3200\|5
+--R       2\|2  |- 2 |---------  atan(-------------------------------)
+--R             |    |      +-+             +---------------+
+--R            \|   \| 3200\|5              |    +---------+
+--R                                         |    |  +-+
+--R                                     +-+ |    |3\|5  + 5       +-+
+--R                                   5\|2  |- 2 |---------   - x\|5
+--R                                         |    |      +-+
+--R                                        \|   \| 3200\|5
+--R     + 
+--R                                               +---------------+
+--R                                               |    +---------+
+--R                                               |    |  +-+
+--R               +---------------+           +-+ |    |3\|5  - 5
+--R               |    +---------+          5\|2  |- 2 |---------
+--R               |    |  +-+                     |    |      +-+
+--R           +-+ |    |3\|5  - 5                \|   \| 3200\|5
+--R       - 2\|2  |- 2 |---------  atan(-------------------------------)
+--R               |    |      +-+             +---------------+
+--R              \|   \| 3200\|5              |    +---------+
+--R                                           |    |  +-+
+--R                                       +-+ |    |3\|5  - 5       +-+
+--R                                     5\|2  |- 2 |---------   - x\|5
+--R                                           |    |      +-+
+--R                                          \|   \| 3200\|5
+--R     + 
+--R                                             +-------------+
+--R                                             |  +---------+
+--R                                             |  |  +-+
+--R               +-------------+           +-+ |  |3\|5  - 5
+--R               |  +---------+          5\|2  |2 |---------
+--R               |  |  +-+                     |  |      +-+
+--R           +-+ |  |3\|5  - 5                \| \| 3200\|5
+--R       - 2\|2  |2 |---------  atan(-----------------------------)
+--R               |  |      +-+             +-------------+
+--R              \| \| 3200\|5              |  +---------+
+--R                                         |  |  +-+
+--R                                     +-+ |  |3\|5  - 5       +-+
+--R                                   5\|2  |2 |---------   - x\|5
+--R                                         |  |      +-+
+--R                                        \| \| 3200\|5
+--R     + 
+--R                                           +-------------+
+--R                                           |  +---------+
+--R                                           |  |  +-+
+--R             +-------------+           +-+ |  |3\|5  + 5
+--R             |  +---------+          5\|2  |2 |---------
+--R             |  |  +-+                     |  |      +-+
+--R         +-+ |  |3\|5  + 5                \| \| 3200\|5
+--R       2\|2  |2 |---------  atan(-----------------------------)
+--R             |  |      +-+             +-------------+
+--R            \| \| 3200\|5              |  +---------+
+--R                                       |  |  +-+
+--R                                   +-+ |  |3\|5  + 5       +-+
+--R                                 5\|2  |2 |---------   - x\|5
+--R                                       |  |      +-+
+--R                                      \| \| 3200\|5
+--R     + 
+--R                                             +-------------+
+--R                                             |  +---------+
+--R                                             |  |  +-+
+--R               +-------------+           +-+ |  |3\|5  + 5
+--R               |  +---------+          5\|2  |2 |---------
+--R               |  |  +-+                     |  |      +-+
+--R           +-+ |  |3\|5  + 5                \| \| 3200\|5
+--R       - 2\|2  |2 |---------  atan(-----------------------------)
+--R               |  |      +-+             +-------------+
+--R              \| \| 3200\|5              |  +---------+
+--R                                         |  |  +-+
+--R                                     +-+ |  |3\|5  + 5       +-+
+--R                                   5\|2  |2 |---------   + x\|5
+--R                                         |  |      +-+
+--R                                        \| \| 3200\|5
+--R     + 
+--R                                           +-------------+
+--R                                           |  +---------+
+--R                                           |  |  +-+
+--R             +-------------+           +-+ |  |3\|5  - 5
+--R             |  +---------+          5\|2  |2 |---------
+--R             |  |  +-+                     |  |      +-+
+--R         +-+ |  |3\|5  - 5                \| \| 3200\|5
+--R       2\|2  |2 |---------  atan(-----------------------------)
+--R             |  |      +-+             +-------------+
+--R            \| \| 3200\|5              |  +---------+
+--R                                       |  |  +-+
+--R                                   +-+ |  |3\|5  - 5       +-+
+--R                                 5\|2  |2 |---------   + x\|5
+--R                                       |  |      +-+
+--R                                      \| \| 3200\|5
+--R     + 
+--R                                             +---------------+
+--R                                             |    +---------+
+--R                                             |    |  +-+
+--R             +---------------+           +-+ |    |3\|5  - 5
+--R             |    +---------+          5\|2  |- 2 |---------
+--R             |    |  +-+                     |    |      +-+
+--R         +-+ |    |3\|5  - 5                \|   \| 3200\|5
+--R       2\|2  |- 2 |---------  atan(-------------------------------)
+--R             |    |      +-+             +---------------+
+--R            \|   \| 3200\|5              |    +---------+
+--R                                         |    |  +-+
+--R                                     +-+ |    |3\|5  - 5       +-+
+--R                                   5\|2  |- 2 |---------   + x\|5
+--R                                         |    |      +-+
+--R                                        \|   \| 3200\|5
+--R     + 
+--R                                               +---------------+
+--R                                               |    +---------+
+--R                                               |    |  +-+
+--R               +---------------+           +-+ |    |3\|5  + 5
+--R               |    +---------+          5\|2  |- 2 |---------
+--R               |    |  +-+                     |    |      +-+
+--R           +-+ |    |3\|5  + 5                \|   \| 3200\|5
+--R       - 2\|2  |- 2 |---------  atan(-------------------------------)
+--R               |    |      +-+             +---------------+
+--R              \|   \| 3200\|5              |    +---------+
+--R                                           |    |  +-+
+--R                                       +-+ |    |3\|5  + 5       +-+
+--R                                     5\|2  |- 2 |---------   + x\|5
+--R                                           |    |      +-+
+--R                                          \|   \| 3200\|5
+--R  /
+--R     8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1483
+
+--S 1484 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +-------------+
+--R                       |  +---------+
+--R                       |  |  +-+
+--R          +-+4+-+3 +-+ |  |3\|5  + 5
+--R         \|2 \|2  \|5  |2 |---------
+--R                       |  |      +-+
+--R                      \| \| 3200\|5
+--R      *
+--R                        +-------------+
+--R                        |  +---------+       +---------+
+--R                        |  |  +-+            |  +-+
+--R                +-+ +-+ |  |3\|5  + 5        |3\|5  + 5     2
+--R         log(2x\|2 \|5  |2 |---------   + 40 |---------  + x )
+--R                        |  |      +-+        |      +-+
+--R                       \| \| 3200\|5        \| 3200\|5
+--R     + 
+--R       -
+--R                          +-------------+
+--R                          |  +---------+
+--R                          |  |  +-+
+--R             +-+4+-+3 +-+ |  |3\|5  - 5
+--R            \|2 \|2  \|5  |2 |---------
+--R                          |  |      +-+
+--R                         \| \| 3200\|5
+--R         *
+--R                           +-------------+
+--R                           |  +---------+       +---------+
+--R                           |  |  +-+            |  +-+
+--R                   +-+ +-+ |  |3\|5  - 5        |3\|5  - 5     2
+--R            log(2x\|2 \|5  |2 |---------   + 40 |---------  + x )
+--R                           |  |      +-+        |      +-+
+--R                          \| \| 3200\|5        \| 3200\|5
+--R     + 
+--R       -
+--R                          +---------------+
+--R                          |    +---------+
+--R                          |    |  +-+
+--R             +-+4+-+3 +-+ |    |3\|5  - 5
+--R            \|2 \|2  \|5  |- 2 |---------
+--R                          |    |      +-+
+--R                         \|   \| 3200\|5
+--R         *
+--R                           +---------------+
+--R                           |    +---------+       +---------+
+--R                           |    |  +-+            |  +-+
+--R                   +-+ +-+ |    |3\|5  - 5        |3\|5  - 5     2
+--R            log(2x\|2 \|5  |- 2 |---------   - 40 |---------  + x )
+--R                           |    |      +-+        |      +-+
+--R                          \|   \| 3200\|5        \| 3200\|5
+--R     + 
+--R                       +---------------+
+--R                       |    +---------+
+--R                       |    |  +-+
+--R          +-+4+-+3 +-+ |    |3\|5  + 5
+--R         \|2 \|2  \|5  |- 2 |---------
+--R                       |    |      +-+
+--R                      \|   \| 3200\|5
+--R      *
+--R                        +---------------+
+--R                        |    +---------+       +---------+
+--R                        |    |  +-+            |  +-+
+--R                +-+ +-+ |    |3\|5  + 5        |3\|5  + 5     2
+--R         log(2x\|2 \|5  |- 2 |---------   - 40 |---------  + x )
+--R                        |    |      +-+        |      +-+
+--R                       \|   \| 3200\|5        \| 3200\|5
+--R     + 
+--R       -
+--R                          +---------------+
+--R                          |    +---------+
+--R                          |    |  +-+
+--R             +-+4+-+3 +-+ |    |3\|5  + 5
+--R            \|2 \|2  \|5  |- 2 |---------
+--R                          |    |      +-+
+--R                         \|   \| 3200\|5
+--R         *
+--R                             +---------------+
+--R                             |    +---------+       +---------+
+--R                             |    |  +-+            |  +-+
+--R                     +-+ +-+ |    |3\|5  + 5        |3\|5  + 5     2
+--R            log(- 2x\|2 \|5  |- 2 |---------   - 40 |---------  + x )
+--R                             |    |      +-+        |      +-+
+--R                            \|   \| 3200\|5        \| 3200\|5
+--R     + 
+--R                       +---------------+
+--R                       |    +---------+
+--R                       |    |  +-+
+--R          +-+4+-+3 +-+ |    |3\|5  - 5
+--R         \|2 \|2  \|5  |- 2 |---------
+--R                       |    |      +-+
+--R                      \|   \| 3200\|5
+--R      *
+--R                          +---------------+
+--R                          |    +---------+       +---------+
+--R                          |    |  +-+            |  +-+
+--R                  +-+ +-+ |    |3\|5  - 5        |3\|5  - 5     2
+--R         log(- 2x\|2 \|5  |- 2 |---------   - 40 |---------  + x )
+--R                          |    |      +-+        |      +-+
+--R                         \|   \| 3200\|5        \| 3200\|5
+--R     + 
+--R                       +-------------+
+--R                       |  +---------+
+--R                       |  |  +-+
+--R          +-+4+-+3 +-+ |  |3\|5  - 5
+--R         \|2 \|2  \|5  |2 |---------
+--R                       |  |      +-+
+--R                      \| \| 3200\|5
+--R      *
+--R                          +-------------+
+--R                          |  +---------+       +---------+
+--R                          |  |  +-+            |  +-+
+--R                  +-+ +-+ |  |3\|5  - 5        |3\|5  - 5     2
+--R         log(- 2x\|2 \|5  |2 |---------   + 40 |---------  + x )
+--R                          |  |      +-+        |      +-+
+--R                         \| \| 3200\|5        \| 3200\|5
+--R     + 
+--R       -
+--R                          +-------------+
+--R                          |  +---------+
+--R                          |  |  +-+
+--R             +-+4+-+3 +-+ |  |3\|5  + 5
+--R            \|2 \|2  \|5  |2 |---------
+--R                          |  |      +-+
+--R                         \| \| 3200\|5
+--R         *
+--R                             +-------------+
+--R                             |  +---------+       +---------+
+--R                             |  |  +-+            |  +-+
+--R                     +-+ +-+ |  |3\|5  + 5        |3\|5  + 5     2
+--R            log(- 2x\|2 \|5  |2 |---------   + 40 |---------  + x )
+--R                             |  |      +-+        |      +-+
+--R                            \| \| 3200\|5        \| 3200\|5
+--R     + 
+--R                                                      +---------------+
+--R                                                      |    +---------+
+--R                                                      |    |  +-+
+--R                      +---------------+           +-+ |    |3\|5  + 5
+--R                      |    +---------+          5\|2  |- 2 |---------
+--R                      |    |  +-+                     |    |      +-+
+--R         +-+4+-+3 +-+ |    |3\|5  + 5                \|   \| 3200\|5
+--R       2\|2 \|2  \|5  |- 2 |---------  atan(-------------------------------)
+--R                      |    |      +-+             +---------------+
+--R                     \|   \| 3200\|5              |    +---------+
+--R                                                  |    |  +-+
+--R                                              +-+ |    |3\|5  + 5       +-+
+--R                                            5\|2  |- 2 |---------   - x\|5
+--R                                                  |    |      +-+
+--R                                                 \|   \| 3200\|5
+--R     + 
+--R                                                        +---------------+
+--R                                                        |    +---------+
+--R                                                        |    |  +-+
+--R                        +---------------+           +-+ |    |3\|5  - 5
+--R                        |    +---------+          5\|2  |- 2 |---------
+--R                        |    |  +-+                     |    |      +-+
+--R           +-+4+-+3 +-+ |    |3\|5  - 5                \|   \| 3200\|5
+--R       - 2\|2 \|2  \|5  |- 2 |---------  atan(-------------------------------)
+--R                        |    |      +-+             +---------------+
+--R                       \|   \| 3200\|5              |    +---------+
+--R                                                    |    |  +-+
+--R                                                +-+ |    |3\|5  - 5       +-+
+--R                                              5\|2  |- 2 |---------   - x\|5
+--R                                                    |    |      +-+
+--R                                                   \|   \| 3200\|5
+--R     + 
+--R                                                      +-------------+
+--R                                                      |  +---------+
+--R                                                      |  |  +-+
+--R                        +-------------+           +-+ |  |3\|5  - 5
+--R                        |  +---------+          5\|2  |2 |---------
+--R                        |  |  +-+                     |  |      +-+
+--R           +-+4+-+3 +-+ |  |3\|5  - 5                \| \| 3200\|5
+--R       - 2\|2 \|2  \|5  |2 |---------  atan(-----------------------------)
+--R                        |  |      +-+             +-------------+
+--R                       \| \| 3200\|5              |  +---------+
+--R                                                  |  |  +-+
+--R                                              +-+ |  |3\|5  - 5       +-+
+--R                                            5\|2  |2 |---------   - x\|5
+--R                                                  |  |      +-+
+--R                                                 \| \| 3200\|5
+--R     + 
+--R                                                    +-------------+
+--R                                                    |  +---------+
+--R                                                    |  |  +-+
+--R                      +-------------+           +-+ |  |3\|5  + 5
+--R                      |  +---------+          5\|2  |2 |---------
+--R                      |  |  +-+                     |  |      +-+
+--R         +-+4+-+3 +-+ |  |3\|5  + 5                \| \| 3200\|5
+--R       2\|2 \|2  \|5  |2 |---------  atan(-----------------------------)
+--R                      |  |      +-+             +-------------+
+--R                     \| \| 3200\|5              |  +---------+
+--R                                                |  |  +-+
+--R                                            +-+ |  |3\|5  + 5       +-+
+--R                                          5\|2  |2 |---------   - x\|5
+--R                                                |  |      +-+
+--R                                               \| \| 3200\|5
+--R     + 
+--R                                                      +-------------+
+--R                                                      |  +---------+
+--R                                                      |  |  +-+
+--R                        +-------------+           +-+ |  |3\|5  + 5
+--R                        |  +---------+          5\|2  |2 |---------
+--R                        |  |  +-+                     |  |      +-+
+--R           +-+4+-+3 +-+ |  |3\|5  + 5                \| \| 3200\|5
+--R       - 2\|2 \|2  \|5  |2 |---------  atan(-----------------------------)
+--R                        |  |      +-+             +-------------+
+--R                       \| \| 3200\|5              |  +---------+
+--R                                                  |  |  +-+
+--R                                              +-+ |  |3\|5  + 5       +-+
+--R                                            5\|2  |2 |---------   + x\|5
+--R                                                  |  |      +-+
+--R                                                 \| \| 3200\|5
+--R     + 
+--R                                                    +-------------+
+--R                                                    |  +---------+
+--R                                                    |  |  +-+
+--R                      +-------------+           +-+ |  |3\|5  - 5
+--R                      |  +---------+          5\|2  |2 |---------
+--R                      |  |  +-+                     |  |      +-+
+--R         +-+4+-+3 +-+ |  |3\|5  - 5                \| \| 3200\|5
+--R       2\|2 \|2  \|5  |2 |---------  atan(-----------------------------)
+--R                      |  |      +-+             +-------------+
+--R                     \| \| 3200\|5              |  +---------+
+--R                                                |  |  +-+
+--R                                            +-+ |  |3\|5  - 5       +-+
+--R                                          5\|2  |2 |---------   + x\|5
+--R                                                |  |      +-+
+--R                                               \| \| 3200\|5
+--R     + 
+--R                                                      +---------------+
+--R                                                      |    +---------+
+--R                                                      |    |  +-+
+--R                      +---------------+           +-+ |    |3\|5  - 5
+--R                      |    +---------+          5\|2  |- 2 |---------
+--R                      |    |  +-+                     |    |      +-+
+--R         +-+4+-+3 +-+ |    |3\|5  - 5                \|   \| 3200\|5
+--R       2\|2 \|2  \|5  |- 2 |---------  atan(-------------------------------)
+--R                      |    |      +-+             +---------------+
+--R                     \|   \| 3200\|5              |    +---------+
+--R                                                  |    |  +-+
+--R                                              +-+ |    |3\|5  - 5       +-+
+--R                                            5\|2  |- 2 |---------   + x\|5
+--R                                                  |    |      +-+
+--R                                                 \|   \| 3200\|5
+--R     + 
+--R                                                        +---------------+
+--R                                                        |    +---------+
+--R                                                        |    |  +-+
+--R                        +---------------+           +-+ |    |3\|5  + 5
+--R                        |    +---------+          5\|2  |- 2 |---------
+--R                        |    |  +-+                     |    |      +-+
+--R           +-+4+-+3 +-+ |    |3\|5  + 5                \|   \| 3200\|5
+--R       - 2\|2 \|2  \|5  |- 2 |---------  atan(-------------------------------)
+--R                        |    |      +-+             +---------------+
+--R                       \|   \| 3200\|5              |    +---------+
+--R                                                    |    |  +-+
+--R                                                +-+ |    |3\|5  + 5       +-+
+--R                                              5\|2  |- 2 |---------   + x\|5
+--R                                                    |    |      +-+
+--R                                                   \|   \| 3200\|5
+--R     + 
+--R           +--------+     +---------+          +--------+
+--R          4| +-+          |  +-+          4+-+4| +-+          2
+--R       - 2\|\|5  + 3 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R         +--------+     +---------+          +--------+
+--R        4| +-+          |  +-+          4+-+4| +-+          2
+--R       2\|\|5  + 3 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R         +----------+           +----------+    +-----------+
+--R        4|   +-+           4+-+4|   +-+         |    +-+          2
+--R       2\|- \|5  + 3 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R           +----------+             +----------+    +-----------+
+--R          4|   +-+             4+-+4|   +-+         |    +-+          2
+--R       - 2\|- \|5  + 3 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                 +--------+3
+--R         +--------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4| +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       4\|\|5  + 3 atan(----------------------------------------)
+--R                                            4
+--R     + 
+--R                                                 +--------+3
+--R         +--------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4| +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       4\|\|5  + 3 atan(----------------------------------------)
+--R                                            4
+--R     + 
+--R                                                   +----------+3
+--R         +----------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|   +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       4\|- \|5  + 3 atan(------------------------------------------)
+--R                                               4
+--R     + 
+--R                                                   +----------+3
+--R         +----------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|   +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       4\|- \|5  + 3 atan(------------------------------------------)
+--R                                               4
+--R  /
+--R      4+-+3 +-+
+--R     8\|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 1484
+
+--S 1485 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                                            +----------+2
+--R                     10      6     2 4+-+2 +-+      6 4+-+24|   +-+
+--R               ((- 6x   - 12x  - 2x )\|2  \|5  + 10x  \|2 )\|- \|5  + 3
+--R             + 
+--R                                                +-----------+
+--R                   10      6     2  +-+      6  |    +-+
+--R               ((6x   + 12x  + 2x )\|5  - 10x )\|- 2\|5  + 6
+--R             + 
+--R                  12      8      4      +-+      8      4
+--R               (6x   + 21x  + 25x  + 3)\|5  - 25x  - 45x  - 5
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                                 +-----------+
+--R                    10      6     2  +-+      6  |    +-+           8
+--R             (((- 6x   - 12x  - 2x )\|5  - 10x )\|- 2\|5  + 6  + 40x )
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                        +-----------+
+--R                8 4+-+2 |    +-+           10      6 4+-+2 +-+
+--R           - 20x  \|2  \|- 2\|5  + 6 + (12x   + 18x )\|2  \|5
+--R         + 
+--R                 10      6 4+-+2
+--R           (- 40x   - 30x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                                          +-----------+
+--R                   10      6     2 4+-+2 +-+      6 4+-+2 |    +-+
+--R               ((6x   + 12x  + 2x )\|2  \|5  + 10x  \|2 )\|- 2\|5  + 6
+--R             + 
+--R                    8 4+-+2
+--R               - 40x  \|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                +-----------+
+--R              8 |    +-+              10      6  +-+      10      6
+--R           40x \|- 2\|5  + 6  + (- 24x   - 36x )\|5  + 80x   + 60x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                              +-----------+
+--R                 12      8      4      +-+      8      4      |    +-+
+--R           ((- 6x   - 21x  - 25x  - 3)\|5  - 25x  - 45x  - 5)\|- 2\|5  + 6
+--R         + 
+--R               10      6  +-+      10      6
+--R           (24x   + 36x )\|5  + 80x   + 60x
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                                                           +-----------+
+--R              10      6 4+-+2 +-+         10      6 4+-+2  |    +-+
+--R       ((- 12x   - 18x )\|2  \|5  + (- 40x   - 30x )\|2  )\|- 2\|5  + 6
+--R     + 
+--R             12      8      4 4+-+2
+--R       (- 60x   - 60x  + 20x )\|2
+--R  /
+--R                                  +----------+2
+--R               12       8      4 4|   +-+
+--R           (80x   + 240x  + 80x )\|- \|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                 12       8      4 4+-+2 |    +-+
+--R           (- 40x   - 120x  - 40x )\|2  \|- 2\|5  + 6
+--R         + 
+--R             10      6      2 4+-+2 +-+         14       10       6      2 4+-+2
+--R         (20x   + 60x  + 20x )\|2  \|5  + (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                          +----------+2
+--R                 12       8      4 4+-+2 4|   +-+
+--R           (- 80x   - 240x  - 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                  +-----------+
+--R               12       8      4  |    +-+              10       6      2  +-+
+--R           (80x   + 240x  + 80x )\|- 2\|5  + 6  + (- 40x   - 120x  - 40x )\|5
+--R         + 
+--R              14       10       6       2
+--R           80x   + 360x   + 440x  + 120x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R              10       6      2  +-+      14       10       6       2
+--R         ((40x   + 120x  + 40x )\|5  + 80x   + 360x   + 440x  + 120x )
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                 10      6      2 4+-+2 +-+
+--R           (- 20x   - 60x  - 20x )\|2  \|5
+--R         + 
+--R                 14       10       6      2 4+-+2
+--R           (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R             16       12       8       4      4+-+2
+--R       (- 40x   - 240x   - 440x  - 240x  - 40)\|2
+--R                                                    Type: Expression(Integer)
+--E 1485
+
+)clear all
+
+--S 1486 of 2282
+t0:=x^2/(1+3*x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1486
+
+--S 1487 of 2282
+r0:=-1/2*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))/(2^(1/4)*(3-sqrt(5))^(1/4)*_
+   sqrt(5))+1/2*atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))/(2^(1/4)*_
+   (3-sqrt(5))^(1/4)*sqrt(5))+1/4*log(2*x^2-2*2^(1/4)*x*(3-sqrt(5))^(1/4)+_
+   sqrt(2*(3-sqrt(5))))/(2^(1/4)*(3-sqrt(5))^(1/4)*sqrt(5))-_
+   1/4*log(2*x^2+2*2^(1/4)*x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))/_
+   (2^(1/4)*(3-sqrt(5))^(1/4)*sqrt(5))+1/2*atan(1-2^(3/4)*_
+   x/(3+sqrt(5))^(1/4))/(2^(1/4)*sqrt(5)*(3+sqrt(5))^(1/4))-_
+   1/2*atan(1+2^(3/4)*x/(3+sqrt(5))^(1/4))/(2^(1/4)*sqrt(5)*_
+   (3+sqrt(5))^(1/4))-1/4*log(2*x^2-2*2^(1/4)*x*(3+sqrt(5))^(1/4)+_
+   sqrt(2*(3+sqrt(5))))/(2^(1/4)*sqrt(5)*(3+sqrt(5))^(1/4))+_
+   1/4*log(2*x^2+2*2^(1/4)*x*(3+sqrt(5))^(1/4)+_
+   sqrt(2*(3+sqrt(5))))/(2^(1/4)*sqrt(5)*(3+sqrt(5))^(1/4))
+--R 
+--R
+--R   (2)
+--R        +----------+     +---------+          +--------+
+--R       4|   +-+          |  +-+          4+-+4| +-+          2
+--R       \|- \|5  + 3 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +----------+     +---------+          +--------+
+--R         4|   +-+          |  +-+          4+-+4| +-+          2
+--R       - \|- \|5  + 3 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +--------+           +----------+    +-----------+
+--R         4| +-+           4+-+4|   +-+         |    +-+          2
+--R       - \|\|5  + 3 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R        +--------+             +----------+    +-----------+
+--R       4| +-+             4+-+4|   +-+         |    +-+          2
+--R       \|\|5  + 3 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                   +--------+3
+--R         +----------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       2\|- \|5  + 3 atan(----------------------------------------)
+--R                                              4
+--R     + 
+--R                                                   +--------+3
+--R         +----------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       2\|- \|5  + 3 atan(----------------------------------------)
+--R                                              4
+--R     + 
+--R                                                 +----------+3
+--R         +--------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4| +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       2\|\|5  + 3 atan(------------------------------------------)
+--R                                             4
+--R     + 
+--R                                                 +----------+3
+--R         +--------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4| +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       2\|\|5  + 3 atan(------------------------------------------)
+--R                                             4
+--R  /
+--R               +----------+ +--------+
+--R      4+-+ +-+4|   +-+     4| +-+
+--R     4\|2 \|5 \|- \|5  + 3 \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 1487
+
+--S 1488 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +-------------+
+--R              |  +---------+
+--R              |  |  +-+
+--R          +-+ |  |3\|5  + 5
+--R         \|2  |2 |---------
+--R              |  |      +-+
+--R             \| \| 3200\|5
+--R      *
+--R         log
+--R                                                    +-------------+
+--R                                        +---------+ |  +---------+
+--R                                        |  +-+      |  |  +-+
+--R                    +-+ +-+        +-+  |3\|5  + 5  |  |3\|5  + 5
+--R              (200x\|2 \|5  - 600x\|2 ) |---------  |2 |---------
+--R                                        |      +-+  |  |      +-+
+--R                                       \| 3200\|5  \| \| 3200\|5
+--R            + 
+--R                             +---------+
+--R                             |  +-+
+--R                  +-+        |3\|5  + 5     2 +-+
+--R              (60\|5  - 100) |---------  + x \|5
+--R                             |      +-+
+--R                            \| 3200\|5
+--R     + 
+--R              +-------------+
+--R              |  +---------+
+--R              |  |  +-+
+--R          +-+ |  |3\|5  - 5
+--R         \|2  |2 |---------
+--R              |  |      +-+
+--R             \| \| 3200\|5
+--R      *
+--R         log
+--R                                                    +-------------+
+--R                                        +---------+ |  +---------+
+--R                                        |  +-+      |  |  +-+
+--R                    +-+ +-+        +-+  |3\|5  - 5  |  |3\|5  - 5
+--R              (200x\|2 \|5  + 600x\|2 ) |---------  |2 |---------
+--R                                        |      +-+  |  |      +-+
+--R                                       \| 3200\|5  \| \| 3200\|5
+--R            + 
+--R                             +---------+
+--R                             |  +-+
+--R                  +-+        |3\|5  - 5     2 +-+
+--R              (60\|5  + 100) |---------  + x \|5
+--R                             |      +-+
+--R                            \| 3200\|5
+--R     + 
+--R       -
+--R                 +---------------+
+--R                 |    +---------+
+--R                 |    |  +-+
+--R             +-+ |    |3\|5  - 5
+--R            \|2  |- 2 |---------
+--R                 |    |      +-+
+--R                \|   \| 3200\|5
+--R         *
+--R            log
+--R                                                       +---------------+
+--R                                           +---------+ |    +---------+
+--R                                           |  +-+      |    |  +-+
+--R                       +-+ +-+        +-+  |3\|5  - 5  |    |3\|5  - 5
+--R                 (200x\|2 \|5  + 600x\|2 ) |---------  |- 2 |---------
+--R                                           |      +-+  |    |      +-+
+--R                                          \| 3200\|5  \|   \| 3200\|5
+--R               + 
+--R                                  +---------+
+--R                                  |  +-+
+--R                       +-+        |3\|5  - 5     2 +-+
+--R                 (- 60\|5  - 100) |---------  + x \|5
+--R                                  |      +-+
+--R                                 \| 3200\|5
+--R     + 
+--R       -
+--R                 +---------------+
+--R                 |    +---------+
+--R                 |    |  +-+
+--R             +-+ |    |3\|5  + 5
+--R            \|2  |- 2 |---------
+--R                 |    |      +-+
+--R                \|   \| 3200\|5
+--R         *
+--R            log
+--R                                                       +---------------+
+--R                                           +---------+ |    +---------+
+--R                                           |  +-+      |    |  +-+
+--R                       +-+ +-+        +-+  |3\|5  + 5  |    |3\|5  + 5
+--R                 (200x\|2 \|5  - 600x\|2 ) |---------  |- 2 |---------
+--R                                           |      +-+  |    |      +-+
+--R                                          \| 3200\|5  \|   \| 3200\|5
+--R               + 
+--R                                  +---------+
+--R                                  |  +-+
+--R                       +-+        |3\|5  + 5     2 +-+
+--R                 (- 60\|5  + 100) |---------  + x \|5
+--R                                  |      +-+
+--R                                 \| 3200\|5
+--R     + 
+--R              +---------------+
+--R              |    +---------+
+--R              |    |  +-+
+--R          +-+ |    |3\|5  + 5
+--R         \|2  |- 2 |---------
+--R              |    |      +-+
+--R             \|   \| 3200\|5
+--R      *
+--R         log
+--R                                                      +---------------+
+--R                                          +---------+ |    +---------+
+--R                                          |  +-+      |    |  +-+
+--R                      +-+ +-+        +-+  |3\|5  + 5  |    |3\|5  + 5
+--R              (- 200x\|2 \|5  + 600x\|2 ) |---------  |- 2 |---------
+--R                                          |      +-+  |    |      +-+
+--R                                         \| 3200\|5  \|   \| 3200\|5
+--R            + 
+--R                               +---------+
+--R                               |  +-+
+--R                    +-+        |3\|5  + 5     2 +-+
+--R              (- 60\|5  + 100) |---------  + x \|5
+--R                               |      +-+
+--R                              \| 3200\|5
+--R     + 
+--R              +---------------+
+--R              |    +---------+
+--R              |    |  +-+
+--R          +-+ |    |3\|5  - 5
+--R         \|2  |- 2 |---------
+--R              |    |      +-+
+--R             \|   \| 3200\|5
+--R      *
+--R         log
+--R                                                      +---------------+
+--R                                          +---------+ |    +---------+
+--R                                          |  +-+      |    |  +-+
+--R                      +-+ +-+        +-+  |3\|5  - 5  |    |3\|5  - 5
+--R              (- 200x\|2 \|5  - 600x\|2 ) |---------  |- 2 |---------
+--R                                          |      +-+  |    |      +-+
+--R                                         \| 3200\|5  \|   \| 3200\|5
+--R            + 
+--R                               +---------+
+--R                               |  +-+
+--R                    +-+        |3\|5  - 5     2 +-+
+--R              (- 60\|5  - 100) |---------  + x \|5
+--R                               |      +-+
+--R                              \| 3200\|5
+--R     + 
+--R       -
+--R                 +-------------+
+--R                 |  +---------+
+--R                 |  |  +-+
+--R             +-+ |  |3\|5  - 5
+--R            \|2  |2 |---------
+--R                 |  |      +-+
+--R                \| \| 3200\|5
+--R         *
+--R            log
+--R                                                         +-------------+
+--R                                             +---------+ |  +---------+
+--R                                             |  +-+      |  |  +-+
+--R                         +-+ +-+        +-+  |3\|5  - 5  |  |3\|5  - 5
+--R                 (- 200x\|2 \|5  - 600x\|2 ) |---------  |2 |---------
+--R                                             |      +-+  |  |      +-+
+--R                                            \| 3200\|5  \| \| 3200\|5
+--R               + 
+--R                                +---------+
+--R                                |  +-+
+--R                     +-+        |3\|5  - 5     2 +-+
+--R                 (60\|5  + 100) |---------  + x \|5
+--R                                |      +-+
+--R                               \| 3200\|5
+--R     + 
+--R       -
+--R                 +-------------+
+--R                 |  +---------+
+--R                 |  |  +-+
+--R             +-+ |  |3\|5  + 5
+--R            \|2  |2 |---------
+--R                 |  |      +-+
+--R                \| \| 3200\|5
+--R         *
+--R            log
+--R                                                         +-------------+
+--R                                             +---------+ |  +---------+
+--R                                             |  +-+      |  |  +-+
+--R                         +-+ +-+        +-+  |3\|5  + 5  |  |3\|5  + 5
+--R                 (- 200x\|2 \|5  + 600x\|2 ) |---------  |2 |---------
+--R                                             |      +-+  |  |      +-+
+--R                                            \| 3200\|5  \| \| 3200\|5
+--R               + 
+--R                                +---------+
+--R                                |  +-+
+--R                     +-+        |3\|5  + 5     2 +-+
+--R                 (60\|5  - 100) |---------  + x \|5
+--R                                |      +-+
+--R                               \| 3200\|5
+--R     + 
+--R               +---------------+
+--R               |    +---------+
+--R               |    |  +-+
+--R           +-+ |    |3\|5  + 5
+--R         2\|2  |- 2 |---------
+--R               |    |      +-+
+--R              \|   \| 3200\|5
+--R      *
+--R                                                      +---------------+
+--R                                          +---------+ |    +---------+
+--R                                          |  +-+      |    |  +-+
+--R                       +-+ +-+       +-+  |3\|5  + 5  |    |3\|5  + 5
+--R                  (100\|2 \|5  - 300\|2 ) |---------  |- 2 |---------
+--R                                          |      +-+  |    |      +-+
+--R                                         \| 3200\|5  \|   \| 3200\|5
+--R         atan(-------------------------------------------------------------)
+--R                                                  +---------------+
+--R                                      +---------+ |    +---------+
+--R                                      |  +-+      |    |  +-+
+--R                   +-+ +-+       +-+  |3\|5  + 5  |    |3\|5  + 5       +-+
+--R              (100\|2 \|5  - 300\|2 ) |---------  |- 2 |---------   - x\|5
+--R                                      |      +-+  |    |      +-+
+--R                                     \| 3200\|5  \|   \| 3200\|5
+--R     + 
+--R               +---------------+
+--R               |    +---------+
+--R               |    |  +-+
+--R           +-+ |    |3\|5  - 5
+--R         2\|2  |- 2 |---------
+--R               |    |      +-+
+--R              \|   \| 3200\|5
+--R      *
+--R                                                      +---------------+
+--R                                          +---------+ |    +---------+
+--R                                          |  +-+      |    |  +-+
+--R                       +-+ +-+       +-+  |3\|5  - 5  |    |3\|5  - 5
+--R                  (100\|2 \|5  + 300\|2 ) |---------  |- 2 |---------
+--R                                          |      +-+  |    |      +-+
+--R                                         \| 3200\|5  \|   \| 3200\|5
+--R         atan(-------------------------------------------------------------)
+--R                                                  +---------------+
+--R                                      +---------+ |    +---------+
+--R                                      |  +-+      |    |  +-+
+--R                   +-+ +-+       +-+  |3\|5  - 5  |    |3\|5  - 5       +-+
+--R              (100\|2 \|5  + 300\|2 ) |---------  |- 2 |---------   - x\|5
+--R                                      |      +-+  |    |      +-+
+--R                                     \| 3200\|5  \|   \| 3200\|5
+--R     + 
+--R       -
+--R                  +-------------+
+--R                  |  +---------+
+--R                  |  |  +-+
+--R              +-+ |  |3\|5  - 5
+--R            2\|2  |2 |---------
+--R                  |  |      +-+
+--R                 \| \| 3200\|5
+--R         *
+--R                                                         +-------------+
+--R                                             +---------+ |  +---------+
+--R                                             |  +-+      |  |  +-+
+--R                          +-+ +-+       +-+  |3\|5  - 5  |  |3\|5  - 5
+--R                     (100\|2 \|5  + 300\|2 ) |---------  |2 |---------
+--R                                             |      +-+  |  |      +-+
+--R                                            \| 3200\|5  \| \| 3200\|5
+--R            atan(-----------------------------------------------------------)
+--R                                                     +-------------+
+--R                                         +---------+ |  +---------+
+--R                                         |  +-+      |  |  +-+
+--R                      +-+ +-+       +-+  |3\|5  - 5  |  |3\|5  - 5       +-+
+--R                 (100\|2 \|5  + 300\|2 ) |---------  |2 |---------   - x\|5
+--R                                         |      +-+  |  |      +-+
+--R                                        \| 3200\|5  \| \| 3200\|5
+--R     + 
+--R       -
+--R                  +-------------+
+--R                  |  +---------+
+--R                  |  |  +-+
+--R              +-+ |  |3\|5  + 5
+--R            2\|2  |2 |---------
+--R                  |  |      +-+
+--R                 \| \| 3200\|5
+--R         *
+--R                                                         +-------------+
+--R                                             +---------+ |  +---------+
+--R                                             |  +-+      |  |  +-+
+--R                          +-+ +-+       +-+  |3\|5  + 5  |  |3\|5  + 5
+--R                     (100\|2 \|5  - 300\|2 ) |---------  |2 |---------
+--R                                             |      +-+  |  |      +-+
+--R                                            \| 3200\|5  \| \| 3200\|5
+--R            atan(-----------------------------------------------------------)
+--R                                                     +-------------+
+--R                                         +---------+ |  +---------+
+--R                                         |  +-+      |  |  +-+
+--R                      +-+ +-+       +-+  |3\|5  + 5  |  |3\|5  + 5       +-+
+--R                 (100\|2 \|5  - 300\|2 ) |---------  |2 |---------   - x\|5
+--R                                         |      +-+  |  |      +-+
+--R                                        \| 3200\|5  \| \| 3200\|5
+--R     + 
+--R               +-------------+
+--R               |  +---------+
+--R               |  |  +-+
+--R           +-+ |  |3\|5  + 5
+--R         2\|2  |2 |---------
+--R               |  |      +-+
+--R              \| \| 3200\|5
+--R      *
+--R                                                      +-------------+
+--R                                          +---------+ |  +---------+
+--R                                          |  +-+      |  |  +-+
+--R                       +-+ +-+       +-+  |3\|5  + 5  |  |3\|5  + 5
+--R                  (100\|2 \|5  - 300\|2 ) |---------  |2 |---------
+--R                                          |      +-+  |  |      +-+
+--R                                         \| 3200\|5  \| \| 3200\|5
+--R         atan(-----------------------------------------------------------)
+--R                                                  +-------------+
+--R                                      +---------+ |  +---------+
+--R                                      |  +-+      |  |  +-+
+--R                   +-+ +-+       +-+  |3\|5  + 5  |  |3\|5  + 5       +-+
+--R              (100\|2 \|5  - 300\|2 ) |---------  |2 |---------   + x\|5
+--R                                      |      +-+  |  |      +-+
+--R                                     \| 3200\|5  \| \| 3200\|5
+--R     + 
+--R               +-------------+
+--R               |  +---------+
+--R               |  |  +-+
+--R           +-+ |  |3\|5  - 5
+--R         2\|2  |2 |---------
+--R               |  |      +-+
+--R              \| \| 3200\|5
+--R      *
+--R                                                      +-------------+
+--R                                          +---------+ |  +---------+
+--R                                          |  +-+      |  |  +-+
+--R                       +-+ +-+       +-+  |3\|5  - 5  |  |3\|5  - 5
+--R                  (100\|2 \|5  + 300\|2 ) |---------  |2 |---------
+--R                                          |      +-+  |  |      +-+
+--R                                         \| 3200\|5  \| \| 3200\|5
+--R         atan(-----------------------------------------------------------)
+--R                                                  +-------------+
+--R                                      +---------+ |  +---------+
+--R                                      |  +-+      |  |  +-+
+--R                   +-+ +-+       +-+  |3\|5  - 5  |  |3\|5  - 5       +-+
+--R              (100\|2 \|5  + 300\|2 ) |---------  |2 |---------   + x\|5
+--R                                      |      +-+  |  |      +-+
+--R                                     \| 3200\|5  \| \| 3200\|5
+--R     + 
+--R       -
+--R                  +---------------+
+--R                  |    +---------+
+--R                  |    |  +-+
+--R              +-+ |    |3\|5  - 5
+--R            2\|2  |- 2 |---------
+--R                  |    |      +-+
+--R                 \|   \| 3200\|5
+--R         *
+--R                                                         +---------------+
+--R                                             +---------+ |    +---------+
+--R                                             |  +-+      |    |  +-+
+--R                          +-+ +-+       +-+  |3\|5  - 5  |    |3\|5  - 5
+--R                     (100\|2 \|5  + 300\|2 ) |---------  |- 2 |---------
+--R                                             |      +-+  |    |      +-+
+--R                                            \| 3200\|5  \|   \| 3200\|5
+--R            atan(-------------------------------------------------------------)
+--R                                                     +---------------+
+--R                                         +---------+ |    +---------+
+--R                                         |  +-+      |    |  +-+
+--R                      +-+ +-+       +-+  |3\|5  - 5  |    |3\|5  - 5       +-+
+--R                 (100\|2 \|5  + 300\|2 ) |---------  |- 2 |---------   + x\|5
+--R                                         |      +-+  |    |      +-+
+--R                                        \| 3200\|5  \|   \| 3200\|5
+--R     + 
+--R       -
+--R                  +---------------+
+--R                  |    +---------+
+--R                  |    |  +-+
+--R              +-+ |    |3\|5  + 5
+--R            2\|2  |- 2 |---------
+--R                  |    |      +-+
+--R                 \|   \| 3200\|5
+--R         *
+--R                                                         +---------------+
+--R                                             +---------+ |    +---------+
+--R                                             |  +-+      |    |  +-+
+--R                          +-+ +-+       +-+  |3\|5  + 5  |    |3\|5  + 5
+--R                     (100\|2 \|5  - 300\|2 ) |---------  |- 2 |---------
+--R                                             |      +-+  |    |      +-+
+--R                                            \| 3200\|5  \|   \| 3200\|5
+--R            atan(-------------------------------------------------------------)
+--R                                                     +---------------+
+--R                                         +---------+ |    +---------+
+--R                                         |  +-+      |    |  +-+
+--R                      +-+ +-+       +-+  |3\|5  + 5  |    |3\|5  + 5       +-+
+--R                 (100\|2 \|5  - 300\|2 ) |---------  |- 2 |---------   + x\|5
+--R                                         |      +-+  |    |      +-+
+--R                                        \| 3200\|5  \|   \| 3200\|5
+--R  /
+--R     8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1488
+
+--S 1489 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +-------------+
+--R                                              |  +---------+
+--R                      +----------+ +--------+ |  |  +-+
+--R          +-+4+-+ +-+4|   +-+     4| +-+      |  |3\|5  + 5
+--R         \|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |2 |---------
+--R                                              |  |      +-+
+--R                                             \| \| 3200\|5
+--R      *
+--R         log
+--R                                                    +-------------+
+--R                                        +---------+ |  +---------+
+--R                                        |  +-+      |  |  +-+
+--R                    +-+ +-+        +-+  |3\|5  + 5  |  |3\|5  + 5
+--R              (200x\|2 \|5  - 600x\|2 ) |---------  |2 |---------
+--R                                        |      +-+  |  |      +-+
+--R                                       \| 3200\|5  \| \| 3200\|5
+--R            + 
+--R                             +---------+
+--R                             |  +-+
+--R                  +-+        |3\|5  + 5     2 +-+
+--R              (60\|5  - 100) |---------  + x \|5
+--R                             |      +-+
+--R                            \| 3200\|5
+--R     + 
+--R                                              +-------------+
+--R                                              |  +---------+
+--R                      +----------+ +--------+ |  |  +-+
+--R          +-+4+-+ +-+4|   +-+     4| +-+      |  |3\|5  - 5
+--R         \|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |2 |---------
+--R                                              |  |      +-+
+--R                                             \| \| 3200\|5
+--R      *
+--R         log
+--R                                                    +-------------+
+--R                                        +---------+ |  +---------+
+--R                                        |  +-+      |  |  +-+
+--R                    +-+ +-+        +-+  |3\|5  - 5  |  |3\|5  - 5
+--R              (200x\|2 \|5  + 600x\|2 ) |---------  |2 |---------
+--R                                        |      +-+  |  |      +-+
+--R                                       \| 3200\|5  \| \| 3200\|5
+--R            + 
+--R                             +---------+
+--R                             |  +-+
+--R                  +-+        |3\|5  - 5     2 +-+
+--R              (60\|5  + 100) |---------  + x \|5
+--R                             |      +-+
+--R                            \| 3200\|5
+--R     + 
+--R       -
+--R                                                 +---------------+
+--R                                                 |    +---------+
+--R                         +----------+ +--------+ |    |  +-+
+--R             +-+4+-+ +-+4|   +-+     4| +-+      |    |3\|5  - 5
+--R            \|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |- 2 |---------
+--R                                                 |    |      +-+
+--R                                                \|   \| 3200\|5
+--R         *
+--R            log
+--R                                                       +---------------+
+--R                                           +---------+ |    +---------+
+--R                                           |  +-+      |    |  +-+
+--R                       +-+ +-+        +-+  |3\|5  - 5  |    |3\|5  - 5
+--R                 (200x\|2 \|5  + 600x\|2 ) |---------  |- 2 |---------
+--R                                           |      +-+  |    |      +-+
+--R                                          \| 3200\|5  \|   \| 3200\|5
+--R               + 
+--R                                  +---------+
+--R                                  |  +-+
+--R                       +-+        |3\|5  - 5     2 +-+
+--R                 (- 60\|5  - 100) |---------  + x \|5
+--R                                  |      +-+
+--R                                 \| 3200\|5
+--R     + 
+--R       -
+--R                                                 +---------------+
+--R                                                 |    +---------+
+--R                         +----------+ +--------+ |    |  +-+
+--R             +-+4+-+ +-+4|   +-+     4| +-+      |    |3\|5  + 5
+--R            \|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |- 2 |---------
+--R                                                 |    |      +-+
+--R                                                \|   \| 3200\|5
+--R         *
+--R            log
+--R                                                       +---------------+
+--R                                           +---------+ |    +---------+
+--R                                           |  +-+      |    |  +-+
+--R                       +-+ +-+        +-+  |3\|5  + 5  |    |3\|5  + 5
+--R                 (200x\|2 \|5  - 600x\|2 ) |---------  |- 2 |---------
+--R                                           |      +-+  |    |      +-+
+--R                                          \| 3200\|5  \|   \| 3200\|5
+--R               + 
+--R                                  +---------+
+--R                                  |  +-+
+--R                       +-+        |3\|5  + 5     2 +-+
+--R                 (- 60\|5  + 100) |---------  + x \|5
+--R                                  |      +-+
+--R                                 \| 3200\|5
+--R     + 
+--R                                              +---------------+
+--R                                              |    +---------+
+--R                      +----------+ +--------+ |    |  +-+
+--R          +-+4+-+ +-+4|   +-+     4| +-+      |    |3\|5  + 5
+--R         \|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |- 2 |---------
+--R                                              |    |      +-+
+--R                                             \|   \| 3200\|5
+--R      *
+--R         log
+--R                                                      +---------------+
+--R                                          +---------+ |    +---------+
+--R                                          |  +-+      |    |  +-+
+--R                      +-+ +-+        +-+  |3\|5  + 5  |    |3\|5  + 5
+--R              (- 200x\|2 \|5  + 600x\|2 ) |---------  |- 2 |---------
+--R                                          |      +-+  |    |      +-+
+--R                                         \| 3200\|5  \|   \| 3200\|5
+--R            + 
+--R                               +---------+
+--R                               |  +-+
+--R                    +-+        |3\|5  + 5     2 +-+
+--R              (- 60\|5  + 100) |---------  + x \|5
+--R                               |      +-+
+--R                              \| 3200\|5
+--R     + 
+--R                                              +---------------+
+--R                                              |    +---------+
+--R                      +----------+ +--------+ |    |  +-+
+--R          +-+4+-+ +-+4|   +-+     4| +-+      |    |3\|5  - 5
+--R         \|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |- 2 |---------
+--R                                              |    |      +-+
+--R                                             \|   \| 3200\|5
+--R      *
+--R         log
+--R                                                      +---------------+
+--R                                          +---------+ |    +---------+
+--R                                          |  +-+      |    |  +-+
+--R                      +-+ +-+        +-+  |3\|5  - 5  |    |3\|5  - 5
+--R              (- 200x\|2 \|5  - 600x\|2 ) |---------  |- 2 |---------
+--R                                          |      +-+  |    |      +-+
+--R                                         \| 3200\|5  \|   \| 3200\|5
+--R            + 
+--R                               +---------+
+--R                               |  +-+
+--R                    +-+        |3\|5  - 5     2 +-+
+--R              (- 60\|5  - 100) |---------  + x \|5
+--R                               |      +-+
+--R                              \| 3200\|5
+--R     + 
+--R       -
+--R                                                 +-------------+
+--R                                                 |  +---------+
+--R                         +----------+ +--------+ |  |  +-+
+--R             +-+4+-+ +-+4|   +-+     4| +-+      |  |3\|5  - 5
+--R            \|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |2 |---------
+--R                                                 |  |      +-+
+--R                                                \| \| 3200\|5
+--R         *
+--R            log
+--R                                                         +-------------+
+--R                                             +---------+ |  +---------+
+--R                                             |  +-+      |  |  +-+
+--R                         +-+ +-+        +-+  |3\|5  - 5  |  |3\|5  - 5
+--R                 (- 200x\|2 \|5  - 600x\|2 ) |---------  |2 |---------
+--R                                             |      +-+  |  |      +-+
+--R                                            \| 3200\|5  \| \| 3200\|5
+--R               + 
+--R                                +---------+
+--R                                |  +-+
+--R                     +-+        |3\|5  - 5     2 +-+
+--R                 (60\|5  + 100) |---------  + x \|5
+--R                                |      +-+
+--R                               \| 3200\|5
+--R     + 
+--R       -
+--R                                                 +-------------+
+--R                                                 |  +---------+
+--R                         +----------+ +--------+ |  |  +-+
+--R             +-+4+-+ +-+4|   +-+     4| +-+      |  |3\|5  + 5
+--R            \|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |2 |---------
+--R                                                 |  |      +-+
+--R                                                \| \| 3200\|5
+--R         *
+--R            log
+--R                                                         +-------------+
+--R                                             +---------+ |  +---------+
+--R                                             |  +-+      |  |  +-+
+--R                         +-+ +-+        +-+  |3\|5  + 5  |  |3\|5  + 5
+--R                 (- 200x\|2 \|5  + 600x\|2 ) |---------  |2 |---------
+--R                                             |      +-+  |  |      +-+
+--R                                            \| 3200\|5  \| \| 3200\|5
+--R               + 
+--R                                +---------+
+--R                                |  +-+
+--R                     +-+        |3\|5  + 5     2 +-+
+--R                 (60\|5  - 100) |---------  + x \|5
+--R                                |      +-+
+--R                               \| 3200\|5
+--R     + 
+--R                                               +---------------+
+--R                                               |    +---------+
+--R                       +----------+ +--------+ |    |  +-+
+--R           +-+4+-+ +-+4|   +-+     4| +-+      |    |3\|5  + 5
+--R         2\|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |- 2 |---------
+--R                                               |    |      +-+
+--R                                              \|   \| 3200\|5
+--R      *
+--R                                                      +---------------+
+--R                                          +---------+ |    +---------+
+--R                                          |  +-+      |    |  +-+
+--R                       +-+ +-+       +-+  |3\|5  + 5  |    |3\|5  + 5
+--R                  (100\|2 \|5  - 300\|2 ) |---------  |- 2 |---------
+--R                                          |      +-+  |    |      +-+
+--R                                         \| 3200\|5  \|   \| 3200\|5
+--R         atan(-------------------------------------------------------------)
+--R                                                  +---------------+
+--R                                      +---------+ |    +---------+
+--R                                      |  +-+      |    |  +-+
+--R                   +-+ +-+       +-+  |3\|5  + 5  |    |3\|5  + 5       +-+
+--R              (100\|2 \|5  - 300\|2 ) |---------  |- 2 |---------   - x\|5
+--R                                      |      +-+  |    |      +-+
+--R                                     \| 3200\|5  \|   \| 3200\|5
+--R     + 
+--R                                               +---------------+
+--R                                               |    +---------+
+--R                       +----------+ +--------+ |    |  +-+
+--R           +-+4+-+ +-+4|   +-+     4| +-+      |    |3\|5  - 5
+--R         2\|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |- 2 |---------
+--R                                               |    |      +-+
+--R                                              \|   \| 3200\|5
+--R      *
+--R                                                      +---------------+
+--R                                          +---------+ |    +---------+
+--R                                          |  +-+      |    |  +-+
+--R                       +-+ +-+       +-+  |3\|5  - 5  |    |3\|5  - 5
+--R                  (100\|2 \|5  + 300\|2 ) |---------  |- 2 |---------
+--R                                          |      +-+  |    |      +-+
+--R                                         \| 3200\|5  \|   \| 3200\|5
+--R         atan(-------------------------------------------------------------)
+--R                                                  +---------------+
+--R                                      +---------+ |    +---------+
+--R                                      |  +-+      |    |  +-+
+--R                   +-+ +-+       +-+  |3\|5  - 5  |    |3\|5  - 5       +-+
+--R              (100\|2 \|5  + 300\|2 ) |---------  |- 2 |---------   - x\|5
+--R                                      |      +-+  |    |      +-+
+--R                                     \| 3200\|5  \|   \| 3200\|5
+--R     + 
+--R       -
+--R                                                  +-------------+
+--R                                                  |  +---------+
+--R                          +----------+ +--------+ |  |  +-+
+--R              +-+4+-+ +-+4|   +-+     4| +-+      |  |3\|5  - 5
+--R            2\|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |2 |---------
+--R                                                  |  |      +-+
+--R                                                 \| \| 3200\|5
+--R         *
+--R                                                         +-------------+
+--R                                             +---------+ |  +---------+
+--R                                             |  +-+      |  |  +-+
+--R                          +-+ +-+       +-+  |3\|5  - 5  |  |3\|5  - 5
+--R                     (100\|2 \|5  + 300\|2 ) |---------  |2 |---------
+--R                                             |      +-+  |  |      +-+
+--R                                            \| 3200\|5  \| \| 3200\|5
+--R            atan(-----------------------------------------------------------)
+--R                                                     +-------------+
+--R                                         +---------+ |  +---------+
+--R                                         |  +-+      |  |  +-+
+--R                      +-+ +-+       +-+  |3\|5  - 5  |  |3\|5  - 5       +-+
+--R                 (100\|2 \|5  + 300\|2 ) |---------  |2 |---------   - x\|5
+--R                                         |      +-+  |  |      +-+
+--R                                        \| 3200\|5  \| \| 3200\|5
+--R     + 
+--R       -
+--R                                                  +-------------+
+--R                                                  |  +---------+
+--R                          +----------+ +--------+ |  |  +-+
+--R              +-+4+-+ +-+4|   +-+     4| +-+      |  |3\|5  + 5
+--R            2\|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |2 |---------
+--R                                                  |  |      +-+
+--R                                                 \| \| 3200\|5
+--R         *
+--R                                                         +-------------+
+--R                                             +---------+ |  +---------+
+--R                                             |  +-+      |  |  +-+
+--R                          +-+ +-+       +-+  |3\|5  + 5  |  |3\|5  + 5
+--R                     (100\|2 \|5  - 300\|2 ) |---------  |2 |---------
+--R                                             |      +-+  |  |      +-+
+--R                                            \| 3200\|5  \| \| 3200\|5
+--R            atan(-----------------------------------------------------------)
+--R                                                     +-------------+
+--R                                         +---------+ |  +---------+
+--R                                         |  +-+      |  |  +-+
+--R                      +-+ +-+       +-+  |3\|5  + 5  |  |3\|5  + 5       +-+
+--R                 (100\|2 \|5  - 300\|2 ) |---------  |2 |---------   - x\|5
+--R                                         |      +-+  |  |      +-+
+--R                                        \| 3200\|5  \| \| 3200\|5
+--R     + 
+--R                                               +-------------+
+--R                                               |  +---------+
+--R                       +----------+ +--------+ |  |  +-+
+--R           +-+4+-+ +-+4|   +-+     4| +-+      |  |3\|5  + 5
+--R         2\|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |2 |---------
+--R                                               |  |      +-+
+--R                                              \| \| 3200\|5
+--R      *
+--R                                                      +-------------+
+--R                                          +---------+ |  +---------+
+--R                                          |  +-+      |  |  +-+
+--R                       +-+ +-+       +-+  |3\|5  + 5  |  |3\|5  + 5
+--R                  (100\|2 \|5  - 300\|2 ) |---------  |2 |---------
+--R                                          |      +-+  |  |      +-+
+--R                                         \| 3200\|5  \| \| 3200\|5
+--R         atan(-----------------------------------------------------------)
+--R                                                  +-------------+
+--R                                      +---------+ |  +---------+
+--R                                      |  +-+      |  |  +-+
+--R                   +-+ +-+       +-+  |3\|5  + 5  |  |3\|5  + 5       +-+
+--R              (100\|2 \|5  - 300\|2 ) |---------  |2 |---------   + x\|5
+--R                                      |      +-+  |  |      +-+
+--R                                     \| 3200\|5  \| \| 3200\|5
+--R     + 
+--R                                               +-------------+
+--R                                               |  +---------+
+--R                       +----------+ +--------+ |  |  +-+
+--R           +-+4+-+ +-+4|   +-+     4| +-+      |  |3\|5  - 5
+--R         2\|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |2 |---------
+--R                                               |  |      +-+
+--R                                              \| \| 3200\|5
+--R      *
+--R                                                      +-------------+
+--R                                          +---------+ |  +---------+
+--R                                          |  +-+      |  |  +-+
+--R                       +-+ +-+       +-+  |3\|5  - 5  |  |3\|5  - 5
+--R                  (100\|2 \|5  + 300\|2 ) |---------  |2 |---------
+--R                                          |      +-+  |  |      +-+
+--R                                         \| 3200\|5  \| \| 3200\|5
+--R         atan(-----------------------------------------------------------)
+--R                                                  +-------------+
+--R                                      +---------+ |  +---------+
+--R                                      |  +-+      |  |  +-+
+--R                   +-+ +-+       +-+  |3\|5  - 5  |  |3\|5  - 5       +-+
+--R              (100\|2 \|5  + 300\|2 ) |---------  |2 |---------   + x\|5
+--R                                      |      +-+  |  |      +-+
+--R                                     \| 3200\|5  \| \| 3200\|5
+--R     + 
+--R       -
+--R                                                  +---------------+
+--R                                                  |    +---------+
+--R                          +----------+ +--------+ |    |  +-+
+--R              +-+4+-+ +-+4|   +-+     4| +-+      |    |3\|5  - 5
+--R            2\|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |- 2 |---------
+--R                                                  |    |      +-+
+--R                                                 \|   \| 3200\|5
+--R         *
+--R                                                         +---------------+
+--R                                             +---------+ |    +---------+
+--R                                             |  +-+      |    |  +-+
+--R                          +-+ +-+       +-+  |3\|5  - 5  |    |3\|5  - 5
+--R                     (100\|2 \|5  + 300\|2 ) |---------  |- 2 |---------
+--R                                             |      +-+  |    |      +-+
+--R                                            \| 3200\|5  \|   \| 3200\|5
+--R            atan(-------------------------------------------------------------)
+--R                                                     +---------------+
+--R                                         +---------+ |    +---------+
+--R                                         |  +-+      |    |  +-+
+--R                      +-+ +-+       +-+  |3\|5  - 5  |    |3\|5  - 5       +-+
+--R                 (100\|2 \|5  + 300\|2 ) |---------  |- 2 |---------   + x\|5
+--R                                         |      +-+  |    |      +-+
+--R                                        \| 3200\|5  \|   \| 3200\|5
+--R     + 
+--R       -
+--R                                                  +---------------+
+--R                                                  |    +---------+
+--R                          +----------+ +--------+ |    |  +-+
+--R              +-+4+-+ +-+4|   +-+     4| +-+      |    |3\|5  + 5
+--R            2\|2 \|2 \|5 \|- \|5  + 3 \|\|5  + 3  |- 2 |---------
+--R                                                  |    |      +-+
+--R                                                 \|   \| 3200\|5
+--R         *
+--R                                                         +---------------+
+--R                                             +---------+ |    +---------+
+--R                                             |  +-+      |    |  +-+
+--R                          +-+ +-+       +-+  |3\|5  + 5  |    |3\|5  + 5
+--R                     (100\|2 \|5  - 300\|2 ) |---------  |- 2 |---------
+--R                                             |      +-+  |    |      +-+
+--R                                            \| 3200\|5  \|   \| 3200\|5
+--R            atan(-------------------------------------------------------------)
+--R                                                     +---------------+
+--R                                         +---------+ |    +---------+
+--R                                         |  +-+      |    |  +-+
+--R                      +-+ +-+       +-+  |3\|5  + 5  |    |3\|5  + 5       +-+
+--R                 (100\|2 \|5  - 300\|2 ) |---------  |- 2 |---------   + x\|5
+--R                                         |      +-+  |    |      +-+
+--R                                        \| 3200\|5  \|   \| 3200\|5
+--R     + 
+--R           +----------+     +---------+          +--------+
+--R          4|   +-+          |  +-+          4+-+4| +-+          2
+--R       - 2\|- \|5  + 3 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R         +----------+     +---------+          +--------+
+--R        4|   +-+          |  +-+          4+-+4| +-+          2
+--R       2\|- \|5  + 3 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R         +--------+           +----------+    +-----------+
+--R        4| +-+           4+-+4|   +-+         |    +-+          2
+--R       2\|\|5  + 3 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R           +--------+             +----------+    +-----------+
+--R          4| +-+             4+-+4|   +-+         |    +-+          2
+--R       - 2\|\|5  + 3 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                     +--------+3
+--R           +----------+        4+-+3 +-+      4+-+3 4| +-+
+--R          4|   +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 4\|- \|5  + 3 atan(----------------------------------------)
+--R                                                4
+--R     + 
+--R                                                     +--------+3
+--R           +----------+        4+-+3 +-+      4+-+3 4| +-+
+--R          4|   +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 4\|- \|5  + 3 atan(----------------------------------------)
+--R                                                4
+--R     + 
+--R                                                   +----------+3
+--R           +--------+        4+-+3 +-+      4+-+3 4|   +-+
+--R          4| +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 4\|\|5  + 3 atan(------------------------------------------)
+--R                                               4
+--R     + 
+--R                                                   +----------+3
+--R           +--------+        4+-+3 +-+      4+-+3 4|   +-+
+--R          4| +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 4\|\|5  + 3 atan(------------------------------------------)
+--R                                               4
+--R  /
+--R               +----------+ +--------+
+--R      4+-+ +-+4|   +-+     4| +-+
+--R     8\|2 \|5 \|- \|5  + 3 \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 1489
+
+--S 1490 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                              +-----------+
+--R                      6 4+-+2 |    +-+            12     8      4     4+-+2 +-+
+--R                   20x  \|2  \|- 2\|5  + 6 + (- 6x   - 9x  - 17x  - 3)\|2  \|5
+--R                 + 
+--R                      8      4     4+-+2
+--R                   (5x  + 45x  + 5)\|2
+--R              *
+--R                  +----------+2
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                           +-----------+
+--R                      8     4  +-+      8  |    +-+           6 +-+       6
+--R               ((- 12x  - 8x )\|5  + 20x )\|- 2\|5  + 6  + 40x \|5  - 120x
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                    8     4  +-+      8  |    +-+
+--R               ((12x  + 8x )\|5  + 20x )\|- 2\|5  + 6
+--R             + 
+--R                   10      6      2  +-+      10      2
+--R               (12x   + 16x  + 12x )\|5  + 20x   - 20x
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                 8      4 4+-+2 +-+      4 4+-+2
+--R           (- 16x  - 24x )\|2  \|5  + 40x  \|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                     12     8      4     4+-+2 +-+      8      4     4+-+2
+--R                 ((6x   + 9x  + 17x  + 3)\|2  \|5  + (5x  + 45x  + 5)\|2  )
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                     10      2 4+-+2
+--R               (- 40x   + 40x )\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                                        +-----------+
+--R                  10      6      2  +-+      10      2  |    +-+
+--R           ((- 12x   - 16x  - 12x )\|5  + 20x   - 20x )\|- 2\|5  + 6
+--R         + 
+--R                 12      8      4      +-+      12      8       4
+--R           (- 36x   - 44x  - 12x  - 8)\|5  + 60x   + 60x  - 100x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                +-----------+
+--R                 6 +-+       6  |    +-+            12      8      4      +-+
+--R           (- 40x \|5  - 120x )\|- 2\|5  + 6  + (36x   + 44x  + 12x  + 8)\|5
+--R         + 
+--R              12      8       4
+--R           60x   + 60x  - 100x
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                                            +-----------+
+--R            8      4 4+-+2 +-+      4 4+-+2 |    +-+            6 4+-+2
+--R       ((16x  + 24x )\|2  \|5  + 40x  \|2 )\|- 2\|5  + 6  + 160x  \|2
+--R  /
+--R                                           +-----------+
+--R                   12       8      4 4+-+2 |    +-+
+--R               (40x   + 120x  + 40x )\|2  \|- 2\|5  + 6
+--R             + 
+--R                     10      6      2 4+-+2 +-+
+--R               (- 20x   - 60x  - 20x )\|2  \|5
+--R             + 
+--R                   14       10       6      2 4+-+2
+--R               (40x   + 180x   + 220x  + 60x )\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R               12       8      4  +-+       12       8       4
+--R           (80x   + 240x  + 80x )\|5  - 240x   - 720x  - 240x
+--R      *
+--R          +--------+2 +---------+
+--R         4| +-+       |  +-+
+--R         \|\|5  + 3  \|2\|5  + 6
+--R     + 
+--R                       10      6      2 4+-+2 +-+
+--R                   (20x   + 60x  + 20x )\|2  \|5
+--R                 + 
+--R                       14       10       6      2 4+-+2
+--R                   (40x   + 180x   + 220x  + 60x )\|2
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                   16       12       8       4      4+-+2
+--R               (40x   + 240x   + 440x  + 240x  + 40)\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R               14       10      6  +-+       14       10       6       2
+--R           (80x   + 240x   + 80x )\|5  - 240x   - 880x   - 720x  - 160x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                                   +-----------+
+--R                  12       8      4  +-+       12       8       4  |    +-+
+--R           ((- 80x   - 240x  - 80x )\|5  - 240x   - 720x  - 240x )\|- 2\|5  + 6
+--R         + 
+--R                 14       10      6  +-+       14       10       6       2
+--R           (- 80x   - 240x   - 80x )\|5  - 240x   - 880x   - 720x  - 160x
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R            12       8       4 4+-+2
+--R       (320x   + 960x  + 320x )\|2
+--R                                                    Type: Expression(Integer)
+--E 1490
+
+)clear all
+
+--S 1491 of 2282
+t0:=1/(1+3*x^4+x^8)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1491
+
+--S 1492 of 2282
+r0a:=1/20*atan(1-x*sqrt(-1+sqrt(5)))*sqrt(-20+10*sqrt(5))-_
+   1/20*atan(1+x*sqrt(-1+sqrt(5)))*sqrt(-20+10*sqrt(5))+_
+   1/40*log(1+2*x^2+sqrt(5)-2*x*sqrt(1+sqrt(5)))*sqrt(-20+10*sqrt(5))-_
+   1/40*log(1+2*x^2+sqrt(5)+2*x*sqrt(1+sqrt(5)))*sqrt(-20+10*sqrt(5))-_
+   1/20*atan(1-x*sqrt(1+sqrt(5)))*sqrt(20+10*sqrt(5))+_
+   1/20*atan(1+x*sqrt(1+sqrt(5)))*sqrt(20+10*sqrt(5))-_
+   1/40*log(-1+2*x^2+sqrt(5)-2*x*sqrt(-1+sqrt(5)))*sqrt(20+10*sqrt(5))+_
+   1/40*log(-1+2*x^2+sqrt(5)+2*x*sqrt(-1+sqrt(5)))*sqrt(20+10*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          +-----------+       +--------+
+--R          |   +-+             | +-+         +-+     2
+--R       - \|10\|5  - 20 log(2x\|\|5  + 1  + \|5  + 2x  + 1)
+--R     + 
+--R        +-----------+       +--------+
+--R        |   +-+             | +-+         +-+     2
+--R       \|10\|5  + 20 log(2x\|\|5  - 1  + \|5  + 2x  - 1)
+--R     + 
+--R          +-----------+         +--------+
+--R          |   +-+               | +-+         +-+     2
+--R       - \|10\|5  + 20 log(- 2x\|\|5  - 1  + \|5  + 2x  - 1)
+--R     + 
+--R        +-----------+         +--------+
+--R        |   +-+               | +-+         +-+     2
+--R       \|10\|5  - 20 log(- 2x\|\|5  + 1  + \|5  + 2x  + 1)
+--R     + 
+--R         +-----------+       +--------+
+--R         |   +-+             | +-+
+--R       2\|10\|5  + 20 atan(x\|\|5  + 1  + 1)
+--R     + 
+--R         +-----------+       +--------+
+--R         |   +-+             | +-+
+--R       2\|10\|5  + 20 atan(x\|\|5  + 1  - 1)
+--R     + 
+--R           +-----------+       +--------+
+--R           |   +-+             | +-+
+--R       - 2\|10\|5  - 20 atan(x\|\|5  - 1  + 1)
+--R     + 
+--R           +-----------+       +--------+
+--R           |   +-+             | +-+
+--R       - 2\|10\|5  - 20 atan(x\|\|5  - 1  - 1)
+--R  /
+--R     40
+--R                                                    Type: Expression(Integer)
+--E 1492
+
+--S 1493 of 2282
+r0b:=-atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))/(2^(3/4)*(3-sqrt(5))^(3/4)*_
+   sqrt(5))+atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))/(2^(3/4)*_
+   (3-sqrt(5))^(3/4)*sqrt(5))-1/2*log(2*x^2-2*2^(1/4)*x*_
+   (3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))/(2^(3/4)*(3-sqrt(5))^(3/4)*_
+   sqrt(5))+1/2*log(2*x^2+2*2^(1/4)*x*(3-sqrt(5))^(1/4)+_
+   sqrt(2*(3-sqrt(5))))/(2^(3/4)*(3-sqrt(5))^(3/4)*sqrt(5))+_
+   atan(1-2^(3/4)*x/(3+sqrt(5))^(1/4))/(2^(3/4)*sqrt(5)*_
+   (3+sqrt(5))^(3/4))-atan(1+2^(3/4)*x/(3+sqrt(5))^(1/4))/(2^(3/4)*_
+   sqrt(5)*(3+sqrt(5))^(3/4))+1/2*log(2*x^2-2*2^(1/4)*x*(3+_
+   sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))/(2^(3/4)*sqrt(5)*_
+   (3+sqrt(5))^(3/4))-1/2*log(2*x^2+2*2^(1/4)*x*(3+sqrt(5))^(1/4)+_
+   sqrt(2*(3+sqrt(5))))/(2^(3/4)*sqrt(5)*(3+sqrt(5))^(3/4))
+--R 
+--R
+--R   (3)
+--R          +----------+3     +---------+          +--------+
+--R         4|   +-+           |  +-+          4+-+4| +-+          2
+--R       - \|- \|5  + 3  log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +----------+3     +---------+          +--------+
+--R       4|   +-+           |  +-+          4+-+4| +-+          2
+--R       \|- \|5  + 3  log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +--------+3           +----------+    +-----------+
+--R       4| +-+            4+-+4|   +-+         |    +-+          2
+--R       \|\|5  + 3  log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R          +--------+3             +----------+    +-----------+
+--R         4| +-+              4+-+4|   +-+         |    +-+          2
+--R       - \|\|5  + 3  log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                    +--------+3
+--R         +----------+3        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       2\|- \|5  + 3  atan(----------------------------------------)
+--R                                               4
+--R     + 
+--R                                                    +--------+3
+--R         +----------+3        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       2\|- \|5  + 3  atan(----------------------------------------)
+--R                                               4
+--R     + 
+--R                                                  +----------+3
+--R         +--------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R        4| +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       2\|\|5  + 3  atan(------------------------------------------)
+--R                                              4
+--R     + 
+--R                                                  +----------+3
+--R         +--------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R        4| +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       2\|\|5  + 3  atan(------------------------------------------)
+--R                                              4
+--R  /
+--R                +----------+3  +--------+3
+--R      4+-+3 +-+4|   +-+       4| +-+
+--R     2\|2  \|5 \|- \|5  + 3   \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 1493
+
+--S 1494 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R              +--------------+
+--R              |  +----------+
+--R              |  |  +-+
+--R          +-+ |  |9\|5  + 20
+--R         \|2  |2 |----------
+--R              |  |      +-+
+--R             \| \| 1600\|5
+--R      *
+--R         log
+--R                                    +--------------+
+--R                                    |  +----------+
+--R                                    |  |  +-+
+--R                  +-+ +-+      +-+  |  |9\|5  + 20
+--R              (3x\|2 \|5  - 5x\|2 ) |2 |----------
+--R                                    |  |      +-+
+--R                                   \| \| 1600\|5
+--R            + 
+--R                               +----------+
+--R                               |  +-+
+--R                    +-+        |9\|5  + 20     2
+--R              (- 60\|5  + 140) |----------  + x
+--R                               |      +-+
+--R                              \| 1600\|5
+--R     + 
+--R       -
+--R                 +--------------+
+--R                 |  +----------+
+--R                 |  |  +-+
+--R             +-+ |  |9\|5  - 20
+--R            \|2  |2 |----------
+--R                 |  |      +-+
+--R                \| \| 1600\|5
+--R         *
+--R            log
+--R                                       +--------------+
+--R                                       |  +----------+
+--R                                       |  |  +-+
+--R                     +-+ +-+      +-+  |  |9\|5  - 20
+--R                 (3x\|2 \|5  + 5x\|2 ) |2 |----------
+--R                                       |  |      +-+
+--R                                      \| \| 1600\|5
+--R               + 
+--R                                +----------+
+--R                                |  +-+
+--R                     +-+        |9\|5  - 20     2
+--R                 (60\|5  + 140) |----------  + x
+--R                                |      +-+
+--R                               \| 1600\|5
+--R     + 
+--R       -
+--R                 +----------------+
+--R                 |    +----------+
+--R                 |    |  +-+
+--R             +-+ |    |9\|5  - 20
+--R            \|2  |- 2 |----------
+--R                 |    |      +-+
+--R                \|   \| 1600\|5
+--R         *
+--R            log
+--R                                       +----------------+
+--R                                       |    +----------+
+--R                                       |    |  +-+
+--R                     +-+ +-+      +-+  |    |9\|5  - 20
+--R                 (3x\|2 \|5  + 5x\|2 ) |- 2 |----------
+--R                                       |    |      +-+
+--R                                      \|   \| 1600\|5
+--R               + 
+--R                                  +----------+
+--R                                  |  +-+
+--R                       +-+        |9\|5  - 20     2
+--R                 (- 60\|5  - 140) |----------  + x
+--R                                  |      +-+
+--R                                 \| 1600\|5
+--R     + 
+--R              +----------------+
+--R              |    +----------+
+--R              |    |  +-+
+--R          +-+ |    |9\|5  + 20
+--R         \|2  |- 2 |----------
+--R              |    |      +-+
+--R             \|   \| 1600\|5
+--R      *
+--R         log
+--R                                    +----------------+
+--R                                    |    +----------+
+--R                                    |    |  +-+
+--R                  +-+ +-+      +-+  |    |9\|5  + 20
+--R              (3x\|2 \|5  - 5x\|2 ) |- 2 |----------
+--R                                    |    |      +-+
+--R                                   \|   \| 1600\|5
+--R            + 
+--R                             +----------+
+--R                             |  +-+
+--R                  +-+        |9\|5  + 20     2
+--R              (60\|5  - 140) |----------  + x
+--R                             |      +-+
+--R                            \| 1600\|5
+--R     + 
+--R       -
+--R                 +----------------+
+--R                 |    +----------+
+--R                 |    |  +-+
+--R             +-+ |    |9\|5  + 20
+--R            \|2  |- 2 |----------
+--R                 |    |      +-+
+--R                \|   \| 1600\|5
+--R         *
+--R            log
+--R                                         +----------------+
+--R                                         |    +----------+
+--R                                         |    |  +-+
+--R                       +-+ +-+      +-+  |    |9\|5  + 20
+--R                 (- 3x\|2 \|5  + 5x\|2 ) |- 2 |----------
+--R                                         |    |      +-+
+--R                                        \|   \| 1600\|5
+--R               + 
+--R                                +----------+
+--R                                |  +-+
+--R                     +-+        |9\|5  + 20     2
+--R                 (60\|5  - 140) |----------  + x
+--R                                |      +-+
+--R                               \| 1600\|5
+--R     + 
+--R              +----------------+
+--R              |    +----------+
+--R              |    |  +-+
+--R          +-+ |    |9\|5  - 20
+--R         \|2  |- 2 |----------
+--R              |    |      +-+
+--R             \|   \| 1600\|5
+--R      *
+--R         log
+--R                                      +----------------+
+--R                                      |    +----------+
+--R                                      |    |  +-+
+--R                    +-+ +-+      +-+  |    |9\|5  - 20
+--R              (- 3x\|2 \|5  - 5x\|2 ) |- 2 |----------
+--R                                      |    |      +-+
+--R                                     \|   \| 1600\|5
+--R            + 
+--R                               +----------+
+--R                               |  +-+
+--R                    +-+        |9\|5  - 20     2
+--R              (- 60\|5  - 140) |----------  + x
+--R                               |      +-+
+--R                              \| 1600\|5
+--R     + 
+--R              +--------------+
+--R              |  +----------+
+--R              |  |  +-+
+--R          +-+ |  |9\|5  - 20
+--R         \|2  |2 |----------
+--R              |  |      +-+
+--R             \| \| 1600\|5
+--R      *
+--R         log
+--R                                      +--------------+
+--R                                      |  +----------+
+--R                                      |  |  +-+
+--R                    +-+ +-+      +-+  |  |9\|5  - 20
+--R              (- 3x\|2 \|5  - 5x\|2 ) |2 |----------
+--R                                      |  |      +-+
+--R                                     \| \| 1600\|5
+--R            + 
+--R                             +----------+
+--R                             |  +-+
+--R                  +-+        |9\|5  - 20     2
+--R              (60\|5  + 140) |----------  + x
+--R                             |      +-+
+--R                            \| 1600\|5
+--R     + 
+--R       -
+--R                 +--------------+
+--R                 |  +----------+
+--R                 |  |  +-+
+--R             +-+ |  |9\|5  + 20
+--R            \|2  |2 |----------
+--R                 |  |      +-+
+--R                \| \| 1600\|5
+--R         *
+--R            log
+--R                                         +--------------+
+--R                                         |  +----------+
+--R                                         |  |  +-+
+--R                       +-+ +-+      +-+  |  |9\|5  + 20
+--R                 (- 3x\|2 \|5  + 5x\|2 ) |2 |----------
+--R                                         |  |      +-+
+--R                                        \| \| 1600\|5
+--R               + 
+--R                                  +----------+
+--R                                  |  +-+
+--R                       +-+        |9\|5  + 20     2
+--R                 (- 60\|5  + 140) |----------  + x
+--R                                  |      +-+
+--R                                 \| 1600\|5
+--R     + 
+--R       -
+--R                  +----------------+
+--R                  |    +----------+
+--R                  |    |  +-+
+--R              +-+ |    |9\|5  + 20
+--R            2\|2  |- 2 |----------
+--R                  |    |      +-+
+--R                 \|   \| 1600\|5
+--R         *
+--R                                           +----------------+
+--R                                           |    +----------+
+--R                                           |    |  +-+
+--R                         +-+ +-+      +-+  |    |9\|5  + 20
+--R                      (5\|2 \|5  - 15\|2 ) |- 2 |----------
+--R                                           |    |      +-+
+--R                                          \|   \| 1600\|5
+--R            atan(------------------------------------------------)
+--R                                      +----------------+
+--R                                      |    +----------+
+--R                                      |    |  +-+
+--R                    +-+ +-+      +-+  |    |9\|5  + 20        +-+
+--R                 (5\|2 \|5  - 15\|2 ) |- 2 |----------   - 2x\|5
+--R                                      |    |      +-+
+--R                                     \|   \| 1600\|5
+--R     + 
+--R       -
+--R                  +----------------+
+--R                  |    +----------+
+--R                  |    |  +-+
+--R              +-+ |    |9\|5  - 20
+--R            2\|2  |- 2 |----------
+--R                  |    |      +-+
+--R                 \|   \| 1600\|5
+--R         *
+--R                                           +----------------+
+--R                                           |    +----------+
+--R                                           |    |  +-+
+--R                         +-+ +-+      +-+  |    |9\|5  - 20
+--R                      (5\|2 \|5  + 15\|2 ) |- 2 |----------
+--R                                           |    |      +-+
+--R                                          \|   \| 1600\|5
+--R            atan(------------------------------------------------)
+--R                                      +----------------+
+--R                                      |    +----------+
+--R                                      |    |  +-+
+--R                    +-+ +-+      +-+  |    |9\|5  - 20        +-+
+--R                 (5\|2 \|5  + 15\|2 ) |- 2 |----------   - 2x\|5
+--R                                      |    |      +-+
+--R                                     \|   \| 1600\|5
+--R     + 
+--R       -
+--R                  +--------------+
+--R                  |  +----------+
+--R                  |  |  +-+
+--R              +-+ |  |9\|5  - 20
+--R            2\|2  |2 |----------
+--R                  |  |      +-+
+--R                 \| \| 1600\|5
+--R         *
+--R                                           +--------------+
+--R                                           |  +----------+
+--R                                           |  |  +-+
+--R                         +-+ +-+      +-+  |  |9\|5  - 20
+--R                      (5\|2 \|5  + 15\|2 ) |2 |----------
+--R                                           |  |      +-+
+--R                                          \| \| 1600\|5
+--R            atan(----------------------------------------------)
+--R                                      +--------------+
+--R                                      |  +----------+
+--R                                      |  |  +-+
+--R                    +-+ +-+      +-+  |  |9\|5  - 20        +-+
+--R                 (5\|2 \|5  + 15\|2 ) |2 |----------   - 2x\|5
+--R                                      |  |      +-+
+--R                                     \| \| 1600\|5
+--R     + 
+--R       -
+--R                  +--------------+
+--R                  |  +----------+
+--R                  |  |  +-+
+--R              +-+ |  |9\|5  + 20
+--R            2\|2  |2 |----------
+--R                  |  |      +-+
+--R                 \| \| 1600\|5
+--R         *
+--R                                           +--------------+
+--R                                           |  +----------+
+--R                                           |  |  +-+
+--R                         +-+ +-+      +-+  |  |9\|5  + 20
+--R                      (5\|2 \|5  - 15\|2 ) |2 |----------
+--R                                           |  |      +-+
+--R                                          \| \| 1600\|5
+--R            atan(----------------------------------------------)
+--R                                      +--------------+
+--R                                      |  +----------+
+--R                                      |  |  +-+
+--R                    +-+ +-+      +-+  |  |9\|5  + 20        +-+
+--R                 (5\|2 \|5  - 15\|2 ) |2 |----------   - 2x\|5
+--R                                      |  |      +-+
+--R                                     \| \| 1600\|5
+--R     + 
+--R               +--------------+
+--R               |  +----------+
+--R               |  |  +-+
+--R           +-+ |  |9\|5  + 20
+--R         2\|2  |2 |----------
+--R               |  |      +-+
+--R              \| \| 1600\|5
+--R      *
+--R                                        +--------------+
+--R                                        |  +----------+
+--R                                        |  |  +-+
+--R                      +-+ +-+      +-+  |  |9\|5  + 20
+--R                   (5\|2 \|5  - 15\|2 ) |2 |----------
+--R                                        |  |      +-+
+--R                                       \| \| 1600\|5
+--R         atan(----------------------------------------------)
+--R                                   +--------------+
+--R                                   |  +----------+
+--R                                   |  |  +-+
+--R                 +-+ +-+      +-+  |  |9\|5  + 20        +-+
+--R              (5\|2 \|5  - 15\|2 ) |2 |----------   + 2x\|5
+--R                                   |  |      +-+
+--R                                  \| \| 1600\|5
+--R     + 
+--R               +--------------+
+--R               |  +----------+
+--R               |  |  +-+
+--R           +-+ |  |9\|5  - 20
+--R         2\|2  |2 |----------
+--R               |  |      +-+
+--R              \| \| 1600\|5
+--R      *
+--R                                        +--------------+
+--R                                        |  +----------+
+--R                                        |  |  +-+
+--R                      +-+ +-+      +-+  |  |9\|5  - 20
+--R                   (5\|2 \|5  + 15\|2 ) |2 |----------
+--R                                        |  |      +-+
+--R                                       \| \| 1600\|5
+--R         atan(----------------------------------------------)
+--R                                   +--------------+
+--R                                   |  +----------+
+--R                                   |  |  +-+
+--R                 +-+ +-+      +-+  |  |9\|5  - 20        +-+
+--R              (5\|2 \|5  + 15\|2 ) |2 |----------   + 2x\|5
+--R                                   |  |      +-+
+--R                                  \| \| 1600\|5
+--R     + 
+--R               +----------------+
+--R               |    +----------+
+--R               |    |  +-+
+--R           +-+ |    |9\|5  - 20
+--R         2\|2  |- 2 |----------
+--R               |    |      +-+
+--R              \|   \| 1600\|5
+--R      *
+--R                                        +----------------+
+--R                                        |    +----------+
+--R                                        |    |  +-+
+--R                      +-+ +-+      +-+  |    |9\|5  - 20
+--R                   (5\|2 \|5  + 15\|2 ) |- 2 |----------
+--R                                        |    |      +-+
+--R                                       \|   \| 1600\|5
+--R         atan(------------------------------------------------)
+--R                                   +----------------+
+--R                                   |    +----------+
+--R                                   |    |  +-+
+--R                 +-+ +-+      +-+  |    |9\|5  - 20        +-+
+--R              (5\|2 \|5  + 15\|2 ) |- 2 |----------   + 2x\|5
+--R                                   |    |      +-+
+--R                                  \|   \| 1600\|5
+--R     + 
+--R               +----------------+
+--R               |    +----------+
+--R               |    |  +-+
+--R           +-+ |    |9\|5  + 20
+--R         2\|2  |- 2 |----------
+--R               |    |      +-+
+--R              \|   \| 1600\|5
+--R      *
+--R                                        +----------------+
+--R                                        |    +----------+
+--R                                        |    |  +-+
+--R                      +-+ +-+      +-+  |    |9\|5  + 20
+--R                   (5\|2 \|5  - 15\|2 ) |- 2 |----------
+--R                                        |    |      +-+
+--R                                       \|   \| 1600\|5
+--R         atan(------------------------------------------------)
+--R                                   +----------------+
+--R                                   |    +----------+
+--R                                   |    |  +-+
+--R                 +-+ +-+      +-+  |    |9\|5  + 20        +-+
+--R              (5\|2 \|5  - 15\|2 ) |- 2 |----------   + 2x\|5
+--R                                   |    |      +-+
+--R                                  \|   \| 1600\|5
+--R  /
+--R     8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1494
+
+--S 1495 of 2282
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R               +--------------+
+--R               |  +----------+
+--R               |  |  +-+
+--R           +-+ |  |9\|5  + 20
+--R         5\|2  |2 |----------
+--R               |  |      +-+
+--R              \| \| 1600\|5
+--R      *
+--R         log
+--R                                    +--------------+
+--R                                    |  +----------+
+--R                                    |  |  +-+
+--R                  +-+ +-+      +-+  |  |9\|5  + 20
+--R              (3x\|2 \|5  - 5x\|2 ) |2 |----------
+--R                                    |  |      +-+
+--R                                   \| \| 1600\|5
+--R            + 
+--R                               +----------+
+--R                               |  +-+
+--R                    +-+        |9\|5  + 20     2
+--R              (- 60\|5  + 140) |----------  + x
+--R                               |      +-+
+--R                              \| 1600\|5
+--R     + 
+--R       -
+--R                  +--------------+
+--R                  |  +----------+
+--R                  |  |  +-+
+--R              +-+ |  |9\|5  - 20
+--R            5\|2  |2 |----------
+--R                  |  |      +-+
+--R                 \| \| 1600\|5
+--R         *
+--R            log
+--R                                       +--------------+
+--R                                       |  +----------+
+--R                                       |  |  +-+
+--R                     +-+ +-+      +-+  |  |9\|5  - 20
+--R                 (3x\|2 \|5  + 5x\|2 ) |2 |----------
+--R                                       |  |      +-+
+--R                                      \| \| 1600\|5
+--R               + 
+--R                                +----------+
+--R                                |  +-+
+--R                     +-+        |9\|5  - 20     2
+--R                 (60\|5  + 140) |----------  + x
+--R                                |      +-+
+--R                               \| 1600\|5
+--R     + 
+--R       -
+--R                  +----------------+
+--R                  |    +----------+
+--R                  |    |  +-+
+--R              +-+ |    |9\|5  - 20
+--R            5\|2  |- 2 |----------
+--R                  |    |      +-+
+--R                 \|   \| 1600\|5
+--R         *
+--R            log
+--R                                       +----------------+
+--R                                       |    +----------+
+--R                                       |    |  +-+
+--R                     +-+ +-+      +-+  |    |9\|5  - 20
+--R                 (3x\|2 \|5  + 5x\|2 ) |- 2 |----------
+--R                                       |    |      +-+
+--R                                      \|   \| 1600\|5
+--R               + 
+--R                                  +----------+
+--R                                  |  +-+
+--R                       +-+        |9\|5  - 20     2
+--R                 (- 60\|5  - 140) |----------  + x
+--R                                  |      +-+
+--R                                 \| 1600\|5
+--R     + 
+--R               +----------------+
+--R               |    +----------+
+--R               |    |  +-+
+--R           +-+ |    |9\|5  + 20
+--R         5\|2  |- 2 |----------
+--R               |    |      +-+
+--R              \|   \| 1600\|5
+--R      *
+--R         log
+--R                                    +----------------+
+--R                                    |    +----------+
+--R                                    |    |  +-+
+--R                  +-+ +-+      +-+  |    |9\|5  + 20
+--R              (3x\|2 \|5  - 5x\|2 ) |- 2 |----------
+--R                                    |    |      +-+
+--R                                   \|   \| 1600\|5
+--R            + 
+--R                             +----------+
+--R                             |  +-+
+--R                  +-+        |9\|5  + 20     2
+--R              (60\|5  - 140) |----------  + x
+--R                             |      +-+
+--R                            \| 1600\|5
+--R     + 
+--R       -
+--R                  +----------------+
+--R                  |    +----------+
+--R                  |    |  +-+
+--R              +-+ |    |9\|5  + 20
+--R            5\|2  |- 2 |----------
+--R                  |    |      +-+
+--R                 \|   \| 1600\|5
+--R         *
+--R            log
+--R                                         +----------------+
+--R                                         |    +----------+
+--R                                         |    |  +-+
+--R                       +-+ +-+      +-+  |    |9\|5  + 20
+--R                 (- 3x\|2 \|5  + 5x\|2 ) |- 2 |----------
+--R                                         |    |      +-+
+--R                                        \|   \| 1600\|5
+--R               + 
+--R                                +----------+
+--R                                |  +-+
+--R                     +-+        |9\|5  + 20     2
+--R                 (60\|5  - 140) |----------  + x
+--R                                |      +-+
+--R                               \| 1600\|5
+--R     + 
+--R               +----------------+
+--R               |    +----------+
+--R               |    |  +-+
+--R           +-+ |    |9\|5  - 20
+--R         5\|2  |- 2 |----------
+--R               |    |      +-+
+--R              \|   \| 1600\|5
+--R      *
+--R         log
+--R                                      +----------------+
+--R                                      |    +----------+
+--R                                      |    |  +-+
+--R                    +-+ +-+      +-+  |    |9\|5  - 20
+--R              (- 3x\|2 \|5  - 5x\|2 ) |- 2 |----------
+--R                                      |    |      +-+
+--R                                     \|   \| 1600\|5
+--R            + 
+--R                               +----------+
+--R                               |  +-+
+--R                    +-+        |9\|5  - 20     2
+--R              (- 60\|5  - 140) |----------  + x
+--R                               |      +-+
+--R                              \| 1600\|5
+--R     + 
+--R               +--------------+
+--R               |  +----------+
+--R               |  |  +-+
+--R           +-+ |  |9\|5  - 20
+--R         5\|2  |2 |----------
+--R               |  |      +-+
+--R              \| \| 1600\|5
+--R      *
+--R         log
+--R                                      +--------------+
+--R                                      |  +----------+
+--R                                      |  |  +-+
+--R                    +-+ +-+      +-+  |  |9\|5  - 20
+--R              (- 3x\|2 \|5  - 5x\|2 ) |2 |----------
+--R                                      |  |      +-+
+--R                                     \| \| 1600\|5
+--R            + 
+--R                             +----------+
+--R                             |  +-+
+--R                  +-+        |9\|5  - 20     2
+--R              (60\|5  + 140) |----------  + x
+--R                             |      +-+
+--R                            \| 1600\|5
+--R     + 
+--R       -
+--R                  +--------------+
+--R                  |  +----------+
+--R                  |  |  +-+
+--R              +-+ |  |9\|5  + 20
+--R            5\|2  |2 |----------
+--R                  |  |      +-+
+--R                 \| \| 1600\|5
+--R         *
+--R            log
+--R                                         +--------------+
+--R                                         |  +----------+
+--R                                         |  |  +-+
+--R                       +-+ +-+      +-+  |  |9\|5  + 20
+--R                 (- 3x\|2 \|5  + 5x\|2 ) |2 |----------
+--R                                         |  |      +-+
+--R                                        \| \| 1600\|5
+--R               + 
+--R                                  +----------+
+--R                                  |  +-+
+--R                       +-+        |9\|5  + 20     2
+--R                 (- 60\|5  + 140) |----------  + x
+--R                                  |      +-+
+--R                                 \| 1600\|5
+--R     + 
+--R       -
+--R                   +----------------+
+--R                   |    +----------+
+--R                   |    |  +-+
+--R               +-+ |    |9\|5  + 20
+--R            10\|2  |- 2 |----------
+--R                   |    |      +-+
+--R                  \|   \| 1600\|5
+--R         *
+--R                                           +----------------+
+--R                                           |    +----------+
+--R                                           |    |  +-+
+--R                         +-+ +-+      +-+  |    |9\|5  + 20
+--R                      (5\|2 \|5  - 15\|2 ) |- 2 |----------
+--R                                           |    |      +-+
+--R                                          \|   \| 1600\|5
+--R            atan(------------------------------------------------)
+--R                                      +----------------+
+--R                                      |    +----------+
+--R                                      |    |  +-+
+--R                    +-+ +-+      +-+  |    |9\|5  + 20        +-+
+--R                 (5\|2 \|5  - 15\|2 ) |- 2 |----------   - 2x\|5
+--R                                      |    |      +-+
+--R                                     \|   \| 1600\|5
+--R     + 
+--R       -
+--R                   +----------------+
+--R                   |    +----------+
+--R                   |    |  +-+
+--R               +-+ |    |9\|5  - 20
+--R            10\|2  |- 2 |----------
+--R                   |    |      +-+
+--R                  \|   \| 1600\|5
+--R         *
+--R                                           +----------------+
+--R                                           |    +----------+
+--R                                           |    |  +-+
+--R                         +-+ +-+      +-+  |    |9\|5  - 20
+--R                      (5\|2 \|5  + 15\|2 ) |- 2 |----------
+--R                                           |    |      +-+
+--R                                          \|   \| 1600\|5
+--R            atan(------------------------------------------------)
+--R                                      +----------------+
+--R                                      |    +----------+
+--R                                      |    |  +-+
+--R                    +-+ +-+      +-+  |    |9\|5  - 20        +-+
+--R                 (5\|2 \|5  + 15\|2 ) |- 2 |----------   - 2x\|5
+--R                                      |    |      +-+
+--R                                     \|   \| 1600\|5
+--R     + 
+--R       -
+--R                   +--------------+
+--R                   |  +----------+
+--R                   |  |  +-+
+--R               +-+ |  |9\|5  - 20
+--R            10\|2  |2 |----------
+--R                   |  |      +-+
+--R                  \| \| 1600\|5
+--R         *
+--R                                           +--------------+
+--R                                           |  +----------+
+--R                                           |  |  +-+
+--R                         +-+ +-+      +-+  |  |9\|5  - 20
+--R                      (5\|2 \|5  + 15\|2 ) |2 |----------
+--R                                           |  |      +-+
+--R                                          \| \| 1600\|5
+--R            atan(----------------------------------------------)
+--R                                      +--------------+
+--R                                      |  +----------+
+--R                                      |  |  +-+
+--R                    +-+ +-+      +-+  |  |9\|5  - 20        +-+
+--R                 (5\|2 \|5  + 15\|2 ) |2 |----------   - 2x\|5
+--R                                      |  |      +-+
+--R                                     \| \| 1600\|5
+--R     + 
+--R       -
+--R                   +--------------+
+--R                   |  +----------+
+--R                   |  |  +-+
+--R               +-+ |  |9\|5  + 20
+--R            10\|2  |2 |----------
+--R                   |  |      +-+
+--R                  \| \| 1600\|5
+--R         *
+--R                                           +--------------+
+--R                                           |  +----------+
+--R                                           |  |  +-+
+--R                         +-+ +-+      +-+  |  |9\|5  + 20
+--R                      (5\|2 \|5  - 15\|2 ) |2 |----------
+--R                                           |  |      +-+
+--R                                          \| \| 1600\|5
+--R            atan(----------------------------------------------)
+--R                                      +--------------+
+--R                                      |  +----------+
+--R                                      |  |  +-+
+--R                    +-+ +-+      +-+  |  |9\|5  + 20        +-+
+--R                 (5\|2 \|5  - 15\|2 ) |2 |----------   - 2x\|5
+--R                                      |  |      +-+
+--R                                     \| \| 1600\|5
+--R     + 
+--R                +--------------+
+--R                |  +----------+
+--R                |  |  +-+
+--R            +-+ |  |9\|5  + 20
+--R         10\|2  |2 |----------
+--R                |  |      +-+
+--R               \| \| 1600\|5
+--R      *
+--R                                        +--------------+
+--R                                        |  +----------+
+--R                                        |  |  +-+
+--R                      +-+ +-+      +-+  |  |9\|5  + 20
+--R                   (5\|2 \|5  - 15\|2 ) |2 |----------
+--R                                        |  |      +-+
+--R                                       \| \| 1600\|5
+--R         atan(----------------------------------------------)
+--R                                   +--------------+
+--R                                   |  +----------+
+--R                                   |  |  +-+
+--R                 +-+ +-+      +-+  |  |9\|5  + 20        +-+
+--R              (5\|2 \|5  - 15\|2 ) |2 |----------   + 2x\|5
+--R                                   |  |      +-+
+--R                                  \| \| 1600\|5
+--R     + 
+--R                +--------------+
+--R                |  +----------+
+--R                |  |  +-+
+--R            +-+ |  |9\|5  - 20
+--R         10\|2  |2 |----------
+--R                |  |      +-+
+--R               \| \| 1600\|5
+--R      *
+--R                                        +--------------+
+--R                                        |  +----------+
+--R                                        |  |  +-+
+--R                      +-+ +-+      +-+  |  |9\|5  - 20
+--R                   (5\|2 \|5  + 15\|2 ) |2 |----------
+--R                                        |  |      +-+
+--R                                       \| \| 1600\|5
+--R         atan(----------------------------------------------)
+--R                                   +--------------+
+--R                                   |  +----------+
+--R                                   |  |  +-+
+--R                 +-+ +-+      +-+  |  |9\|5  - 20        +-+
+--R              (5\|2 \|5  + 15\|2 ) |2 |----------   + 2x\|5
+--R                                   |  |      +-+
+--R                                  \| \| 1600\|5
+--R     + 
+--R                +----------------+
+--R                |    +----------+
+--R                |    |  +-+
+--R            +-+ |    |9\|5  - 20
+--R         10\|2  |- 2 |----------
+--R                |    |      +-+
+--R               \|   \| 1600\|5
+--R      *
+--R                                        +----------------+
+--R                                        |    +----------+
+--R                                        |    |  +-+
+--R                      +-+ +-+      +-+  |    |9\|5  - 20
+--R                   (5\|2 \|5  + 15\|2 ) |- 2 |----------
+--R                                        |    |      +-+
+--R                                       \|   \| 1600\|5
+--R         atan(------------------------------------------------)
+--R                                   +----------------+
+--R                                   |    +----------+
+--R                                   |    |  +-+
+--R                 +-+ +-+      +-+  |    |9\|5  - 20        +-+
+--R              (5\|2 \|5  + 15\|2 ) |- 2 |----------   + 2x\|5
+--R                                   |    |      +-+
+--R                                  \|   \| 1600\|5
+--R     + 
+--R                +----------------+
+--R                |    +----------+
+--R                |    |  +-+
+--R            +-+ |    |9\|5  + 20
+--R         10\|2  |- 2 |----------
+--R                |    |      +-+
+--R               \|   \| 1600\|5
+--R      *
+--R                                        +----------------+
+--R                                        |    +----------+
+--R                                        |    |  +-+
+--R                      +-+ +-+      +-+  |    |9\|5  + 20
+--R                   (5\|2 \|5  - 15\|2 ) |- 2 |----------
+--R                                        |    |      +-+
+--R                                       \|   \| 1600\|5
+--R         atan(------------------------------------------------)
+--R                                   +----------------+
+--R                                   |    +----------+
+--R                                   |    |  +-+
+--R                 +-+ +-+      +-+  |    |9\|5  + 20        +-+
+--R              (5\|2 \|5  - 15\|2 ) |- 2 |----------   + 2x\|5
+--R                                   |    |      +-+
+--R                                  \|   \| 1600\|5
+--R     + 
+--R        +-----------+       +--------+
+--R        |   +-+             | +-+         +-+     2
+--R       \|10\|5  - 20 log(2x\|\|5  + 1  + \|5  + 2x  + 1)
+--R     + 
+--R          +-----------+       +--------+
+--R          |   +-+             | +-+         +-+     2
+--R       - \|10\|5  + 20 log(2x\|\|5  - 1  + \|5  + 2x  - 1)
+--R     + 
+--R        +-----------+         +--------+
+--R        |   +-+               | +-+         +-+     2
+--R       \|10\|5  + 20 log(- 2x\|\|5  - 1  + \|5  + 2x  - 1)
+--R     + 
+--R          +-----------+         +--------+
+--R          |   +-+               | +-+         +-+     2
+--R       - \|10\|5  - 20 log(- 2x\|\|5  + 1  + \|5  + 2x  + 1)
+--R     + 
+--R           +-----------+       +--------+
+--R           |   +-+             | +-+
+--R       - 2\|10\|5  + 20 atan(x\|\|5  + 1  + 1)
+--R     + 
+--R           +-----------+       +--------+
+--R           |   +-+             | +-+
+--R       - 2\|10\|5  + 20 atan(x\|\|5  + 1  - 1)
+--R     + 
+--R         +-----------+       +--------+
+--R         |   +-+             | +-+
+--R       2\|10\|5  - 20 atan(x\|\|5  - 1  + 1)
+--R     + 
+--R         +-----------+       +--------+
+--R         |   +-+             | +-+
+--R       2\|10\|5  - 20 atan(x\|\|5  - 1  - 1)
+--R  /
+--R     40
+--R                                                    Type: Expression(Integer)
+--E 1495
+
+--S 1496 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (6)
+--R                                                      +--------+
+--R                6    4    2  +-+    6     4    2      | +-+
+--R           ((- x  + x  - x )\|5  + x  - 3x  - x  - 2)\|\|5  + 1
+--R         + 
+--R                                                      +--------+
+--R                4    2      +-+     6    4     2      | +-+
+--R           ((- x  + x  - 1)\|5  + 2x  + x  + 3x  - 1)\|\|5  - 1
+--R      *
+--R          +-----------+
+--R          |   +-+
+--R         \|10\|5  + 20
+--R     + 
+--R                                                    +--------+
+--R              4    2      +-+     6    4     2      | +-+
+--R           ((x  + x  + 1)\|5  - 2x  + x  - 3x  - 1)\|\|5  + 1
+--R         + 
+--R                                                    +--------+
+--R              6    4    2  +-+    6     4    2      | +-+
+--R           ((x  + x  + x )\|5  + x  + 3x  - x  + 2)\|\|5  - 1
+--R      *
+--R          +-----------+
+--R          |   +-+
+--R         \|10\|5  - 20
+--R     + 
+--R       40
+--R  /
+--R        8       4
+--R     40x  + 120x  + 40
+--R                                                    Type: Expression(Integer)
+--E 1496
+
+--S 1497 of 2282
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R                                                  +--------------+
+--R                                                  |  +----------+
+--R                       +----------+3  +--------+3 |  |  +-+
+--R          +-+4+-+3 +-+4|   +-+       4| +-+       |  |9\|5  + 20
+--R         \|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |2 |----------
+--R                                                  |  |      +-+
+--R                                                 \| \| 1600\|5
+--R      *
+--R         log
+--R                                    +--------------+
+--R                                    |  +----------+
+--R                                    |  |  +-+
+--R                  +-+ +-+      +-+  |  |9\|5  + 20
+--R              (3x\|2 \|5  - 5x\|2 ) |2 |----------
+--R                                    |  |      +-+
+--R                                   \| \| 1600\|5
+--R            + 
+--R                               +----------+
+--R                               |  +-+
+--R                    +-+        |9\|5  + 20     2
+--R              (- 60\|5  + 140) |----------  + x
+--R                               |      +-+
+--R                              \| 1600\|5
+--R     + 
+--R       -
+--R                                                     +--------------+
+--R                                                     |  +----------+
+--R                          +----------+3  +--------+3 |  |  +-+
+--R             +-+4+-+3 +-+4|   +-+       4| +-+       |  |9\|5  - 20
+--R            \|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |2 |----------
+--R                                                     |  |      +-+
+--R                                                    \| \| 1600\|5
+--R         *
+--R            log
+--R                                       +--------------+
+--R                                       |  +----------+
+--R                                       |  |  +-+
+--R                     +-+ +-+      +-+  |  |9\|5  - 20
+--R                 (3x\|2 \|5  + 5x\|2 ) |2 |----------
+--R                                       |  |      +-+
+--R                                      \| \| 1600\|5
+--R               + 
+--R                                +----------+
+--R                                |  +-+
+--R                     +-+        |9\|5  - 20     2
+--R                 (60\|5  + 140) |----------  + x
+--R                                |      +-+
+--R                               \| 1600\|5
+--R     + 
+--R       -
+--R                                                     +----------------+
+--R                                                     |    +----------+
+--R                          +----------+3  +--------+3 |    |  +-+
+--R             +-+4+-+3 +-+4|   +-+       4| +-+       |    |9\|5  - 20
+--R            \|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |- 2 |----------
+--R                                                     |    |      +-+
+--R                                                    \|   \| 1600\|5
+--R         *
+--R            log
+--R                                       +----------------+
+--R                                       |    +----------+
+--R                                       |    |  +-+
+--R                     +-+ +-+      +-+  |    |9\|5  - 20
+--R                 (3x\|2 \|5  + 5x\|2 ) |- 2 |----------
+--R                                       |    |      +-+
+--R                                      \|   \| 1600\|5
+--R               + 
+--R                                  +----------+
+--R                                  |  +-+
+--R                       +-+        |9\|5  - 20     2
+--R                 (- 60\|5  - 140) |----------  + x
+--R                                  |      +-+
+--R                                 \| 1600\|5
+--R     + 
+--R                                                  +----------------+
+--R                                                  |    +----------+
+--R                       +----------+3  +--------+3 |    |  +-+
+--R          +-+4+-+3 +-+4|   +-+       4| +-+       |    |9\|5  + 20
+--R         \|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |- 2 |----------
+--R                                                  |    |      +-+
+--R                                                 \|   \| 1600\|5
+--R      *
+--R         log
+--R                                    +----------------+
+--R                                    |    +----------+
+--R                                    |    |  +-+
+--R                  +-+ +-+      +-+  |    |9\|5  + 20
+--R              (3x\|2 \|5  - 5x\|2 ) |- 2 |----------
+--R                                    |    |      +-+
+--R                                   \|   \| 1600\|5
+--R            + 
+--R                             +----------+
+--R                             |  +-+
+--R                  +-+        |9\|5  + 20     2
+--R              (60\|5  - 140) |----------  + x
+--R                             |      +-+
+--R                            \| 1600\|5
+--R     + 
+--R       -
+--R                                                     +----------------+
+--R                                                     |    +----------+
+--R                          +----------+3  +--------+3 |    |  +-+
+--R             +-+4+-+3 +-+4|   +-+       4| +-+       |    |9\|5  + 20
+--R            \|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |- 2 |----------
+--R                                                     |    |      +-+
+--R                                                    \|   \| 1600\|5
+--R         *
+--R            log
+--R                                         +----------------+
+--R                                         |    +----------+
+--R                                         |    |  +-+
+--R                       +-+ +-+      +-+  |    |9\|5  + 20
+--R                 (- 3x\|2 \|5  + 5x\|2 ) |- 2 |----------
+--R                                         |    |      +-+
+--R                                        \|   \| 1600\|5
+--R               + 
+--R                                +----------+
+--R                                |  +-+
+--R                     +-+        |9\|5  + 20     2
+--R                 (60\|5  - 140) |----------  + x
+--R                                |      +-+
+--R                               \| 1600\|5
+--R     + 
+--R                                                  +----------------+
+--R                                                  |    +----------+
+--R                       +----------+3  +--------+3 |    |  +-+
+--R          +-+4+-+3 +-+4|   +-+       4| +-+       |    |9\|5  - 20
+--R         \|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |- 2 |----------
+--R                                                  |    |      +-+
+--R                                                 \|   \| 1600\|5
+--R      *
+--R         log
+--R                                      +----------------+
+--R                                      |    +----------+
+--R                                      |    |  +-+
+--R                    +-+ +-+      +-+  |    |9\|5  - 20
+--R              (- 3x\|2 \|5  - 5x\|2 ) |- 2 |----------
+--R                                      |    |      +-+
+--R                                     \|   \| 1600\|5
+--R            + 
+--R                               +----------+
+--R                               |  +-+
+--R                    +-+        |9\|5  - 20     2
+--R              (- 60\|5  - 140) |----------  + x
+--R                               |      +-+
+--R                              \| 1600\|5
+--R     + 
+--R                                                  +--------------+
+--R                                                  |  +----------+
+--R                       +----------+3  +--------+3 |  |  +-+
+--R          +-+4+-+3 +-+4|   +-+       4| +-+       |  |9\|5  - 20
+--R         \|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |2 |----------
+--R                                                  |  |      +-+
+--R                                                 \| \| 1600\|5
+--R      *
+--R         log
+--R                                      +--------------+
+--R                                      |  +----------+
+--R                                      |  |  +-+
+--R                    +-+ +-+      +-+  |  |9\|5  - 20
+--R              (- 3x\|2 \|5  - 5x\|2 ) |2 |----------
+--R                                      |  |      +-+
+--R                                     \| \| 1600\|5
+--R            + 
+--R                             +----------+
+--R                             |  +-+
+--R                  +-+        |9\|5  - 20     2
+--R              (60\|5  + 140) |----------  + x
+--R                             |      +-+
+--R                            \| 1600\|5
+--R     + 
+--R       -
+--R                                                     +--------------+
+--R                                                     |  +----------+
+--R                          +----------+3  +--------+3 |  |  +-+
+--R             +-+4+-+3 +-+4|   +-+       4| +-+       |  |9\|5  + 20
+--R            \|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |2 |----------
+--R                                                     |  |      +-+
+--R                                                    \| \| 1600\|5
+--R         *
+--R            log
+--R                                         +--------------+
+--R                                         |  +----------+
+--R                                         |  |  +-+
+--R                       +-+ +-+      +-+  |  |9\|5  + 20
+--R                 (- 3x\|2 \|5  + 5x\|2 ) |2 |----------
+--R                                         |  |      +-+
+--R                                        \| \| 1600\|5
+--R               + 
+--R                                  +----------+
+--R                                  |  +-+
+--R                       +-+        |9\|5  + 20     2
+--R                 (- 60\|5  + 140) |----------  + x
+--R                                  |      +-+
+--R                                 \| 1600\|5
+--R     + 
+--R       -
+--R                                                      +----------------+
+--R                                                      |    +----------+
+--R                           +----------+3  +--------+3 |    |  +-+
+--R              +-+4+-+3 +-+4|   +-+       4| +-+       |    |9\|5  + 20
+--R            2\|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |- 2 |----------
+--R                                                      |    |      +-+
+--R                                                     \|   \| 1600\|5
+--R         *
+--R                                           +----------------+
+--R                                           |    +----------+
+--R                                           |    |  +-+
+--R                         +-+ +-+      +-+  |    |9\|5  + 20
+--R                      (5\|2 \|5  - 15\|2 ) |- 2 |----------
+--R                                           |    |      +-+
+--R                                          \|   \| 1600\|5
+--R            atan(------------------------------------------------)
+--R                                      +----------------+
+--R                                      |    +----------+
+--R                                      |    |  +-+
+--R                    +-+ +-+      +-+  |    |9\|5  + 20        +-+
+--R                 (5\|2 \|5  - 15\|2 ) |- 2 |----------   - 2x\|5
+--R                                      |    |      +-+
+--R                                     \|   \| 1600\|5
+--R     + 
+--R       -
+--R                                                      +----------------+
+--R                                                      |    +----------+
+--R                           +----------+3  +--------+3 |    |  +-+
+--R              +-+4+-+3 +-+4|   +-+       4| +-+       |    |9\|5  - 20
+--R            2\|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |- 2 |----------
+--R                                                      |    |      +-+
+--R                                                     \|   \| 1600\|5
+--R         *
+--R                                           +----------------+
+--R                                           |    +----------+
+--R                                           |    |  +-+
+--R                         +-+ +-+      +-+  |    |9\|5  - 20
+--R                      (5\|2 \|5  + 15\|2 ) |- 2 |----------
+--R                                           |    |      +-+
+--R                                          \|   \| 1600\|5
+--R            atan(------------------------------------------------)
+--R                                      +----------------+
+--R                                      |    +----------+
+--R                                      |    |  +-+
+--R                    +-+ +-+      +-+  |    |9\|5  - 20        +-+
+--R                 (5\|2 \|5  + 15\|2 ) |- 2 |----------   - 2x\|5
+--R                                      |    |      +-+
+--R                                     \|   \| 1600\|5
+--R     + 
+--R       -
+--R                                                      +--------------+
+--R                                                      |  +----------+
+--R                           +----------+3  +--------+3 |  |  +-+
+--R              +-+4+-+3 +-+4|   +-+       4| +-+       |  |9\|5  - 20
+--R            2\|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |2 |----------
+--R                                                      |  |      +-+
+--R                                                     \| \| 1600\|5
+--R         *
+--R                                           +--------------+
+--R                                           |  +----------+
+--R                                           |  |  +-+
+--R                         +-+ +-+      +-+  |  |9\|5  - 20
+--R                      (5\|2 \|5  + 15\|2 ) |2 |----------
+--R                                           |  |      +-+
+--R                                          \| \| 1600\|5
+--R            atan(----------------------------------------------)
+--R                                      +--------------+
+--R                                      |  +----------+
+--R                                      |  |  +-+
+--R                    +-+ +-+      +-+  |  |9\|5  - 20        +-+
+--R                 (5\|2 \|5  + 15\|2 ) |2 |----------   - 2x\|5
+--R                                      |  |      +-+
+--R                                     \| \| 1600\|5
+--R     + 
+--R       -
+--R                                                      +--------------+
+--R                                                      |  +----------+
+--R                           +----------+3  +--------+3 |  |  +-+
+--R              +-+4+-+3 +-+4|   +-+       4| +-+       |  |9\|5  + 20
+--R            2\|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |2 |----------
+--R                                                      |  |      +-+
+--R                                                     \| \| 1600\|5
+--R         *
+--R                                           +--------------+
+--R                                           |  +----------+
+--R                                           |  |  +-+
+--R                         +-+ +-+      +-+  |  |9\|5  + 20
+--R                      (5\|2 \|5  - 15\|2 ) |2 |----------
+--R                                           |  |      +-+
+--R                                          \| \| 1600\|5
+--R            atan(----------------------------------------------)
+--R                                      +--------------+
+--R                                      |  +----------+
+--R                                      |  |  +-+
+--R                    +-+ +-+      +-+  |  |9\|5  + 20        +-+
+--R                 (5\|2 \|5  - 15\|2 ) |2 |----------   - 2x\|5
+--R                                      |  |      +-+
+--R                                     \| \| 1600\|5
+--R     + 
+--R                                                   +--------------+
+--R                                                   |  +----------+
+--R                        +----------+3  +--------+3 |  |  +-+
+--R           +-+4+-+3 +-+4|   +-+       4| +-+       |  |9\|5  + 20
+--R         2\|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |2 |----------
+--R                                                   |  |      +-+
+--R                                                  \| \| 1600\|5
+--R      *
+--R                                        +--------------+
+--R                                        |  +----------+
+--R                                        |  |  +-+
+--R                      +-+ +-+      +-+  |  |9\|5  + 20
+--R                   (5\|2 \|5  - 15\|2 ) |2 |----------
+--R                                        |  |      +-+
+--R                                       \| \| 1600\|5
+--R         atan(----------------------------------------------)
+--R                                   +--------------+
+--R                                   |  +----------+
+--R                                   |  |  +-+
+--R                 +-+ +-+      +-+  |  |9\|5  + 20        +-+
+--R              (5\|2 \|5  - 15\|2 ) |2 |----------   + 2x\|5
+--R                                   |  |      +-+
+--R                                  \| \| 1600\|5
+--R     + 
+--R                                                   +--------------+
+--R                                                   |  +----------+
+--R                        +----------+3  +--------+3 |  |  +-+
+--R           +-+4+-+3 +-+4|   +-+       4| +-+       |  |9\|5  - 20
+--R         2\|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |2 |----------
+--R                                                   |  |      +-+
+--R                                                  \| \| 1600\|5
+--R      *
+--R                                        +--------------+
+--R                                        |  +----------+
+--R                                        |  |  +-+
+--R                      +-+ +-+      +-+  |  |9\|5  - 20
+--R                   (5\|2 \|5  + 15\|2 ) |2 |----------
+--R                                        |  |      +-+
+--R                                       \| \| 1600\|5
+--R         atan(----------------------------------------------)
+--R                                   +--------------+
+--R                                   |  +----------+
+--R                                   |  |  +-+
+--R                 +-+ +-+      +-+  |  |9\|5  - 20        +-+
+--R              (5\|2 \|5  + 15\|2 ) |2 |----------   + 2x\|5
+--R                                   |  |      +-+
+--R                                  \| \| 1600\|5
+--R     + 
+--R                                                   +----------------+
+--R                                                   |    +----------+
+--R                        +----------+3  +--------+3 |    |  +-+
+--R           +-+4+-+3 +-+4|   +-+       4| +-+       |    |9\|5  - 20
+--R         2\|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |- 2 |----------
+--R                                                   |    |      +-+
+--R                                                  \|   \| 1600\|5
+--R      *
+--R                                        +----------------+
+--R                                        |    +----------+
+--R                                        |    |  +-+
+--R                      +-+ +-+      +-+  |    |9\|5  - 20
+--R                   (5\|2 \|5  + 15\|2 ) |- 2 |----------
+--R                                        |    |      +-+
+--R                                       \|   \| 1600\|5
+--R         atan(------------------------------------------------)
+--R                                   +----------------+
+--R                                   |    +----------+
+--R                                   |    |  +-+
+--R                 +-+ +-+      +-+  |    |9\|5  - 20        +-+
+--R              (5\|2 \|5  + 15\|2 ) |- 2 |----------   + 2x\|5
+--R                                   |    |      +-+
+--R                                  \|   \| 1600\|5
+--R     + 
+--R                                                   +----------------+
+--R                                                   |    +----------+
+--R                        +----------+3  +--------+3 |    |  +-+
+--R           +-+4+-+3 +-+4|   +-+       4| +-+       |    |9\|5  + 20
+--R         2\|2 \|2  \|5 \|- \|5  + 3   \|\|5  + 3   |- 2 |----------
+--R                                                   |    |      +-+
+--R                                                  \|   \| 1600\|5
+--R      *
+--R                                        +----------------+
+--R                                        |    +----------+
+--R                                        |    |  +-+
+--R                      +-+ +-+      +-+  |    |9\|5  + 20
+--R                   (5\|2 \|5  - 15\|2 ) |- 2 |----------
+--R                                        |    |      +-+
+--R                                       \|   \| 1600\|5
+--R         atan(------------------------------------------------)
+--R                                   +----------------+
+--R                                   |    +----------+
+--R                                   |    |  +-+
+--R                 +-+ +-+      +-+  |    |9\|5  + 20        +-+
+--R              (5\|2 \|5  - 15\|2 ) |- 2 |----------   + 2x\|5
+--R                                   |    |      +-+
+--R                                  \|   \| 1600\|5
+--R     + 
+--R         +----------+3     +---------+          +--------+
+--R        4|   +-+           |  +-+          4+-+4| +-+          2
+--R       4\|- \|5  + 3  log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R           +----------+3     +---------+          +--------+
+--R          4|   +-+           |  +-+          4+-+4| +-+          2
+--R       - 4\|- \|5  + 3  log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R           +--------+3           +----------+    +-----------+
+--R          4| +-+            4+-+4|   +-+         |    +-+          2
+--R       - 4\|\|5  + 3  log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R         +--------+3             +----------+    +-----------+
+--R        4| +-+              4+-+4|   +-+         |    +-+          2
+--R       4\|\|5  + 3  log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                      +--------+3
+--R           +----------+3        4+-+3 +-+      4+-+3 4| +-+
+--R          4|   +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 8\|- \|5  + 3  atan(----------------------------------------)
+--R                                                 4
+--R     + 
+--R                                                      +--------+3
+--R           +----------+3        4+-+3 +-+      4+-+3 4| +-+
+--R          4|   +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 8\|- \|5  + 3  atan(----------------------------------------)
+--R                                                 4
+--R     + 
+--R                                                    +----------+3
+--R           +--------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R          4| +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 8\|\|5  + 3  atan(------------------------------------------)
+--R                                                4
+--R     + 
+--R                                                    +----------+3
+--R           +--------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R          4| +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 8\|\|5  + 3  atan(------------------------------------------)
+--R                                                4
+--R  /
+--R                +----------+3  +--------+3
+--R      4+-+3 +-+4|   +-+       4| +-+
+--R     8\|2  \|5 \|- \|5  + 3   \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 1497
+
+--S 1498 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (8)
+--R                              +-----------+
+--R                      4 4+-+2 |    +-+          10     6     2 4+-+2 +-+
+--R                   10x  \|2  \|- 2\|5  + 6 + (4x   + 6x  - 5x )\|2  \|5
+--R                 + 
+--R                       6      2 4+-+2
+--R                   (20x  + 15x )\|2
+--R              *
+--R                  +----------+2
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                +-----------+
+--R                   10      6     2  +-+      6  |    +-+           4 +-+      4
+--R             ((- 6x   - 12x  - 2x )\|5  - 10x )\|- 2\|5  + 6  + 20x \|5  - 60x
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                                +-----------+
+--R                   10      6     2  +-+      6  |    +-+
+--R               ((6x   + 12x  + 2x )\|5  - 10x )\|- 2\|5  + 6
+--R             + 
+--R                  12      8      4      +-+      8      4
+--R               (6x   + 21x  + 25x  + 3)\|5  - 25x  - 45x  - 5
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                 10      6     2 4+-+2 +-+       10      6      2 4+-+2
+--R           (- 18x   - 46x  - 6x )\|2  \|5  + (30x   + 90x  + 10x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                       10     6     2 4+-+2 +-+       6      2 4+-+2
+--R                 ((- 4x   - 6x  + 5x )\|2  \|5  + (20x  + 15x )\|2  )
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                   8      4      4+-+2
+--R               (50x  + 90x  + 10)\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                                              +-----------+
+--R                 12      8      4      +-+      8      4      |    +-+
+--R           ((- 6x   - 21x  - 25x  - 3)\|5  - 25x  - 45x  - 5)\|- 2\|5  + 6
+--R         + 
+--R               10      6  +-+      10       6      2
+--R           (24x   + 76x )\|5  - 40x   - 180x  - 40x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                               +-----------+
+--R                 4 +-+      4  |    +-+              10      6  +-+      10
+--R           (- 20x \|5  - 60x )\|- 2\|5  + 6  + (- 24x   - 76x )\|5  - 40x
+--R         + 
+--R                 6      2
+--R           - 180x  - 40x
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R              10      6     2 4+-+2 +-+       10      6      2 4+-+2
+--R         ((18x   + 46x  + 6x )\|2  \|5  + (30x   + 90x  + 10x )\|2  )
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R          4 4+-+2
+--R       80x  \|2
+--R  /
+--R                                          +-----------+
+--R                   12      8      4 4+-+2 |    +-+
+--R               (20x   + 60x  + 20x )\|2  \|- 2\|5  + 6
+--R             + 
+--R                     10      6      2 4+-+2 +-+
+--R               (- 10x   - 30x  - 10x )\|2  \|5
+--R             + 
+--R                   14      10       6      2 4+-+2
+--R               (20x   + 90x   + 110x  + 30x )\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R               12       8      4  +-+       12       8       4
+--R           (40x   + 120x  + 40x )\|5  - 120x   - 360x  - 120x
+--R      *
+--R          +--------+2 +---------+
+--R         4| +-+       |  +-+
+--R         \|\|5  + 3  \|2\|5  + 6
+--R     + 
+--R                       10      6      2 4+-+2 +-+
+--R                   (10x   + 30x  + 10x )\|2  \|5
+--R                 + 
+--R                       14      10       6      2 4+-+2
+--R                   (20x   + 90x   + 110x  + 30x )\|2
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                   16       12       8       4      4+-+2
+--R               (20x   + 120x   + 220x  + 120x  + 20)\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R               14       10      6  +-+       14       10       6      2
+--R           (40x   + 120x   + 40x )\|5  - 120x   - 440x   - 360x  - 80x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                                   +-----------+
+--R                  12       8      4  +-+       12       8       4  |    +-+
+--R           ((- 40x   - 120x  - 40x )\|5  - 120x   - 360x  - 120x )\|- 2\|5  + 6
+--R         + 
+--R                 14       10      6  +-+       14       10       6      2
+--R           (- 40x   - 120x   - 40x )\|5  - 120x   - 440x   - 360x  - 80x
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R            12       8       4 4+-+2
+--R       (160x   + 480x  + 160x )\|2
+--R                                                    Type: Expression(Integer)
+--E 1498
+
+)clear all
+
+--S 1499 of 2282
+t0:=1/(x^2*(1+3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         10     6    2
+--R        x   + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1499
+
+--S 1500 of 2282
+r0:=(-1)/x-1/4*atan(1-2^(3/4)*x/(3+sqrt(5))^(1/4))*_
+   (246-110*sqrt(5))^(1/4)/sqrt(5)+1/4*atan(1+2^(3/4)*_
+   x/(3+sqrt(5))^(1/4))*(246-110*sqrt(5))^(1/4)/sqrt(5)+_
+   1/8*log(2*x^2-2*2^(1/4)*x*(3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*_
+   (246-110*sqrt(5))^(1/4)/sqrt(5)-1/8*log(2*x^2+2*2^(1/4)*x*_
+   (3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*(246-110*sqrt(5))^(1/4)/sqrt(5)+_
+   1/4*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))*(246+110*sqrt(5))^(1/4)/sqrt(5)-_
+   1/4*atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))*(246+110*sqrt(5))^(1/4)/sqrt(5)-_
+   1/8*log(2*x^2-2*2^(1/4)*x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*_
+   (246+110*sqrt(5))^(1/4)/sqrt(5)+1/8*log(2*x^2+2*2^(1/4)*x*_
+   (3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*(246+110*sqrt(5))^(1/4)/sqrt(5)
+--R 
+--R
+--R   (2)
+--R           +---------------+     +---------+          +--------+
+--R          4|      +-+            |  +-+          4+-+4| +-+          2
+--R       - x\|- 110\|5  + 246 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R         +---------------+     +---------+          +--------+
+--R        4|      +-+            |  +-+          4+-+4| +-+          2
+--R       x\|- 110\|5  + 246 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R         +-------------+           +----------+    +-----------+
+--R        4|    +-+             4+-+4|   +-+         |    +-+          2
+--R       x\|110\|5  + 246 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R           +-------------+             +----------+    +-----------+
+--R          4|    +-+               4+-+4|   +-+         |    +-+          2
+--R       - x\|110\|5  + 246 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                           +--------+3
+--R            +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R           4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 2x\|- 110\|5  + 246 atan(----------------------------------------)
+--R                                                      4
+--R     + 
+--R                                                           +--------+3
+--R            +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R           4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 2x\|- 110\|5  + 246 atan(----------------------------------------)
+--R                                                      4
+--R     + 
+--R                                                         +----------+3
+--R            +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R           4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 2x\|110\|5  + 246 atan(------------------------------------------)
+--R                                                     4
+--R     + 
+--R                                                         +----------+3
+--R            +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R           4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 2x\|110\|5  + 246 atan(------------------------------------------)
+--R                                                     4
+--R     + 
+--R           +-+
+--R       - 8\|5
+--R  /
+--R        +-+
+--R     8x\|5
+--R                                                    Type: Expression(Integer)
+--E 1500
+
+--S 1501 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                  +-----------------+
+--R                  |  +-------------+
+--R                  |  |    +-+
+--R              +-+ |  |123\|5  + 275
+--R            x\|2  |2 |-------------
+--R                  |  |        +-+
+--R                 \| \|   3200\|5
+--R         *
+--R            log
+--R                                                             +-----------------+
+--R                                             +-------------+ |  +-------------+
+--R                                             |    +-+        |  |    +-+
+--R                        +-+ +-+         +-+  |123\|5  + 275  |  |123\|5  + 275
+--R                 (4200x\|2 \|5  - 9400x\|2 ) |-------------  |2 |-------------
+--R                                             |        +-+    |  |        +-+
+--R                                            \|   3200\|5    \| \|   3200\|5
+--R               + 
+--R                                 +-------------+
+--R                                 |    +-+
+--R                      +-+        |123\|5  + 275     2 +-+
+--R                 (360\|5  - 800) |-------------  + x \|5
+--R                                 |        +-+
+--R                                \|   3200\|5
+--R     + 
+--R       -
+--R                  +-----------------+
+--R                  |  +-------------+
+--R                  |  |    +-+
+--R              +-+ |  |123\|5  - 275
+--R            x\|2  |2 |-------------
+--R                  |  |        +-+
+--R                 \| \|   3200\|5
+--R         *
+--R            log
+--R                                                             +-----------------+
+--R                                             +-------------+ |  +-------------+
+--R                                             |    +-+        |  |    +-+
+--R                        +-+ +-+         +-+  |123\|5  - 275  |  |123\|5  - 275
+--R                 (4200x\|2 \|5  + 9400x\|2 ) |-------------  |2 |-------------
+--R                                             |        +-+    |  |        +-+
+--R                                            \|   3200\|5    \| \|   3200\|5
+--R               + 
+--R                                 +-------------+
+--R                                 |    +-+
+--R                      +-+        |123\|5  - 275     2 +-+
+--R                 (360\|5  + 800) |-------------  + x \|5
+--R                                 |        +-+
+--R                                \|   3200\|5
+--R     + 
+--R               +-------------------+
+--R               |    +-------------+
+--R               |    |    +-+
+--R           +-+ |    |123\|5  - 275
+--R         x\|2  |- 2 |-------------
+--R               |    |        +-+
+--R              \|   \|   3200\|5
+--R      *
+--R         log
+--R                                                          +-------------------+
+--R                                          +-------------+ |    +-------------+
+--R                                          |    +-+        |    |    +-+
+--R                     +-+ +-+         +-+  |123\|5  - 275  |    |123\|5  - 275
+--R              (4200x\|2 \|5  + 9400x\|2 ) |-------------  |- 2 |-------------
+--R                                          |        +-+    |    |        +-+
+--R                                         \|   3200\|5    \|   \|   3200\|5
+--R            + 
+--R                                +-------------+
+--R                                |    +-+
+--R                     +-+        |123\|5  - 275     2 +-+
+--R              (- 360\|5  - 800) |-------------  + x \|5
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R               +-------------------+
+--R               |    +-------------+
+--R               |    |    +-+
+--R           +-+ |    |123\|5  + 275
+--R         x\|2  |- 2 |-------------
+--R               |    |        +-+
+--R              \|   \|   3200\|5
+--R      *
+--R         log
+--R                                                          +-------------------+
+--R                                          +-------------+ |    +-------------+
+--R                                          |    +-+        |    |    +-+
+--R                     +-+ +-+         +-+  |123\|5  + 275  |    |123\|5  + 275
+--R              (4200x\|2 \|5  - 9400x\|2 ) |-------------  |- 2 |-------------
+--R                                          |        +-+    |    |        +-+
+--R                                         \|   3200\|5    \|   \|   3200\|5
+--R            + 
+--R                                +-------------+
+--R                                |    +-+
+--R                     +-+        |123\|5  + 275     2 +-+
+--R              (- 360\|5  + 800) |-------------  + x \|5
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R       -
+--R                  +-------------------+
+--R                  |    +-------------+
+--R                  |    |    +-+
+--R              +-+ |    |123\|5  + 275
+--R            x\|2  |- 2 |-------------
+--R                  |    |        +-+
+--R                 \|   \|   3200\|5
+--R         *
+--R            log
+--R                                                 +-------------+
+--R                                                 |    +-+
+--R                            +-+ +-+         +-+  |123\|5  + 275
+--R                   (- 4200x\|2 \|5  + 9400x\|2 ) |-------------
+--R                                                 |        +-+
+--R                                                \|   3200\|5
+--R                *
+--R                    +-------------------+
+--R                    |    +-------------+
+--R                    |    |    +-+
+--R                    |    |123\|5  + 275
+--R                    |- 2 |-------------
+--R                    |    |        +-+
+--R                   \|   \|   3200\|5
+--R               + 
+--R                                   +-------------+
+--R                                   |    +-+
+--R                        +-+        |123\|5  + 275     2 +-+
+--R                 (- 360\|5  + 800) |-------------  + x \|5
+--R                                   |        +-+
+--R                                  \|   3200\|5
+--R     + 
+--R       -
+--R                  +-------------------+
+--R                  |    +-------------+
+--R                  |    |    +-+
+--R              +-+ |    |123\|5  - 275
+--R            x\|2  |- 2 |-------------
+--R                  |    |        +-+
+--R                 \|   \|   3200\|5
+--R         *
+--R            log
+--R                                                 +-------------+
+--R                                                 |    +-+
+--R                            +-+ +-+         +-+  |123\|5  - 275
+--R                   (- 4200x\|2 \|5  - 9400x\|2 ) |-------------
+--R                                                 |        +-+
+--R                                                \|   3200\|5
+--R                *
+--R                    +-------------------+
+--R                    |    +-------------+
+--R                    |    |    +-+
+--R                    |    |123\|5  - 275
+--R                    |- 2 |-------------
+--R                    |    |        +-+
+--R                   \|   \|   3200\|5
+--R               + 
+--R                                   +-------------+
+--R                                   |    +-+
+--R                        +-+        |123\|5  - 275     2 +-+
+--R                 (- 360\|5  - 800) |-------------  + x \|5
+--R                                   |        +-+
+--R                                  \|   3200\|5
+--R     + 
+--R               +-----------------+
+--R               |  +-------------+
+--R               |  |    +-+
+--R           +-+ |  |123\|5  - 275
+--R         x\|2  |2 |-------------
+--R               |  |        +-+
+--R              \| \|   3200\|5
+--R      *
+--R         log
+--R                                                            +-----------------+
+--R                                            +-------------+ |  +-------------+
+--R                                            |    +-+        |  |    +-+
+--R                       +-+ +-+         +-+  |123\|5  - 275  |  |123\|5  - 275
+--R              (- 4200x\|2 \|5  - 9400x\|2 ) |-------------  |2 |-------------
+--R                                            |        +-+    |  |        +-+
+--R                                           \|   3200\|5    \| \|   3200\|5
+--R            + 
+--R                              +-------------+
+--R                              |    +-+
+--R                   +-+        |123\|5  - 275     2 +-+
+--R              (360\|5  + 800) |-------------  + x \|5
+--R                              |        +-+
+--R                             \|   3200\|5
+--R     + 
+--R               +-----------------+
+--R               |  +-------------+
+--R               |  |    +-+
+--R           +-+ |  |123\|5  + 275
+--R         x\|2  |2 |-------------
+--R               |  |        +-+
+--R              \| \|   3200\|5
+--R      *
+--R         log
+--R                                                            +-----------------+
+--R                                            +-------------+ |  +-------------+
+--R                                            |    +-+        |  |    +-+
+--R                       +-+ +-+         +-+  |123\|5  + 275  |  |123\|5  + 275
+--R              (- 4200x\|2 \|5  + 9400x\|2 ) |-------------  |2 |-------------
+--R                                            |        +-+    |  |        +-+
+--R                                           \|   3200\|5    \| \|   3200\|5
+--R            + 
+--R                              +-------------+
+--R                              |    +-+
+--R                   +-+        |123\|5  + 275     2 +-+
+--R              (360\|5  - 800) |-------------  + x \|5
+--R                              |        +-+
+--R                             \|   3200\|5
+--R     + 
+--R       -
+--R                   +-------------------+
+--R                   |    +-------------+
+--R                   |    |    +-+
+--R               +-+ |    |123\|5  + 275
+--R            2x\|2  |- 2 |-------------
+--R                   |    |        +-+
+--R                  \|   \|   3200\|5
+--R         *
+--R            atan
+--R                                                           +-------------------+
+--R                                           +-------------+ |    +-------------+
+--R                                           |    +-+        |    |    +-+
+--R                       +-+ +-+        +-+  |123\|5  + 275  |    |123\|5  + 275
+--R                 (2100\|2 \|5  - 4700\|2 ) |-------------  |- 2 |-------------
+--R                                           |        +-+    |    |        +-+
+--R                                          \|   3200\|5    \|   \|   3200\|5
+--R              /
+--R                                               +-------------+
+--R                                               |    +-+
+--R                           +-+ +-+        +-+  |123\|5  + 275
+--R                     (2100\|2 \|5  - 4700\|2 ) |-------------
+--R                                               |        +-+
+--R                                              \|   3200\|5
+--R                  *
+--R                      +-------------------+
+--R                      |    +-------------+
+--R                      |    |    +-+
+--R                      |    |123\|5  + 275
+--R                      |- 2 |-------------
+--R                      |    |        +-+
+--R                     \|   \|   3200\|5
+--R                 + 
+--R                       +-+
+--R                   - x\|5
+--R     + 
+--R       -
+--R                   +-------------------+
+--R                   |    +-------------+
+--R                   |    |    +-+
+--R               +-+ |    |123\|5  - 275
+--R            2x\|2  |- 2 |-------------
+--R                   |    |        +-+
+--R                  \|   \|   3200\|5
+--R         *
+--R            atan
+--R                                                           +-------------------+
+--R                                           +-------------+ |    +-------------+
+--R                                           |    +-+        |    |    +-+
+--R                       +-+ +-+        +-+  |123\|5  - 275  |    |123\|5  - 275
+--R                 (2100\|2 \|5  + 4700\|2 ) |-------------  |- 2 |-------------
+--R                                           |        +-+    |    |        +-+
+--R                                          \|   3200\|5    \|   \|   3200\|5
+--R              /
+--R                                               +-------------+
+--R                                               |    +-+
+--R                           +-+ +-+        +-+  |123\|5  - 275
+--R                     (2100\|2 \|5  + 4700\|2 ) |-------------
+--R                                               |        +-+
+--R                                              \|   3200\|5
+--R                  *
+--R                      +-------------------+
+--R                      |    +-------------+
+--R                      |    |    +-+
+--R                      |    |123\|5  - 275
+--R                      |- 2 |-------------
+--R                      |    |        +-+
+--R                     \|   \|   3200\|5
+--R                 + 
+--R                       +-+
+--R                   - x\|5
+--R     + 
+--R                +-----------------+
+--R                |  +-------------+
+--R                |  |    +-+
+--R            +-+ |  |123\|5  - 275
+--R         2x\|2  |2 |-------------
+--R                |  |        +-+
+--R               \| \|   3200\|5
+--R      *
+--R         atan
+--R                                                        +-----------------+
+--R                                        +-------------+ |  +-------------+
+--R                                        |    +-+        |  |    +-+
+--R                    +-+ +-+        +-+  |123\|5  - 275  |  |123\|5  - 275
+--R              (2100\|2 \|5  + 4700\|2 ) |-------------  |2 |-------------
+--R                                        |        +-+    |  |        +-+
+--R                                       \|   3200\|5    \| \|   3200\|5
+--R           /
+--R                                                          +-----------------+
+--R                                          +-------------+ |  +-------------+
+--R                                          |    +-+        |  |    +-+
+--R                      +-+ +-+        +-+  |123\|5  - 275  |  |123\|5  - 275
+--R                (2100\|2 \|5  + 4700\|2 ) |-------------  |2 |-------------
+--R                                          |        +-+    |  |        +-+
+--R                                         \|   3200\|5    \| \|   3200\|5
+--R              + 
+--R                    +-+
+--R                - x\|5
+--R     + 
+--R                +-----------------+
+--R                |  +-------------+
+--R                |  |    +-+
+--R            +-+ |  |123\|5  + 275
+--R         2x\|2  |2 |-------------
+--R                |  |        +-+
+--R               \| \|   3200\|5
+--R      *
+--R         atan
+--R                                                        +-----------------+
+--R                                        +-------------+ |  +-------------+
+--R                                        |    +-+        |  |    +-+
+--R                    +-+ +-+        +-+  |123\|5  + 275  |  |123\|5  + 275
+--R              (2100\|2 \|5  - 4700\|2 ) |-------------  |2 |-------------
+--R                                        |        +-+    |  |        +-+
+--R                                       \|   3200\|5    \| \|   3200\|5
+--R           /
+--R                                                          +-----------------+
+--R                                          +-------------+ |  +-------------+
+--R                                          |    +-+        |  |    +-+
+--R                      +-+ +-+        +-+  |123\|5  + 275  |  |123\|5  + 275
+--R                (2100\|2 \|5  - 4700\|2 ) |-------------  |2 |-------------
+--R                                          |        +-+    |  |        +-+
+--R                                         \|   3200\|5    \| \|   3200\|5
+--R              + 
+--R                    +-+
+--R                - x\|5
+--R     + 
+--R       -
+--R                   +-----------------+
+--R                   |  +-------------+
+--R                   |  |    +-+
+--R               +-+ |  |123\|5  + 275
+--R            2x\|2  |2 |-------------
+--R                   |  |        +-+
+--R                  \| \|   3200\|5
+--R         *
+--R            atan
+--R                                                           +-----------------+
+--R                                           +-------------+ |  +-------------+
+--R                                           |    +-+        |  |    +-+
+--R                       +-+ +-+        +-+  |123\|5  + 275  |  |123\|5  + 275
+--R                 (2100\|2 \|5  - 4700\|2 ) |-------------  |2 |-------------
+--R                                           |        +-+    |  |        +-+
+--R                                          \|   3200\|5    \| \|   3200\|5
+--R              /
+--R                                                             +-----------------+
+--R                                             +-------------+ |  +-------------+
+--R                                             |    +-+        |  |    +-+
+--R                         +-+ +-+        +-+  |123\|5  + 275  |  |123\|5  + 275
+--R                   (2100\|2 \|5  - 4700\|2 ) |-------------  |2 |-------------
+--R                                             |        +-+    |  |        +-+
+--R                                            \|   3200\|5    \| \|   3200\|5
+--R                 + 
+--R                     +-+
+--R                   x\|5
+--R     + 
+--R       -
+--R                   +-----------------+
+--R                   |  +-------------+
+--R                   |  |    +-+
+--R               +-+ |  |123\|5  - 275
+--R            2x\|2  |2 |-------------
+--R                   |  |        +-+
+--R                  \| \|   3200\|5
+--R         *
+--R            atan
+--R                                                           +-----------------+
+--R                                           +-------------+ |  +-------------+
+--R                                           |    +-+        |  |    +-+
+--R                       +-+ +-+        +-+  |123\|5  - 275  |  |123\|5  - 275
+--R                 (2100\|2 \|5  + 4700\|2 ) |-------------  |2 |-------------
+--R                                           |        +-+    |  |        +-+
+--R                                          \|   3200\|5    \| \|   3200\|5
+--R              /
+--R                                                             +-----------------+
+--R                                             +-------------+ |  +-------------+
+--R                                             |    +-+        |  |    +-+
+--R                         +-+ +-+        +-+  |123\|5  - 275  |  |123\|5  - 275
+--R                   (2100\|2 \|5  + 4700\|2 ) |-------------  |2 |-------------
+--R                                             |        +-+    |  |        +-+
+--R                                            \|   3200\|5    \| \|   3200\|5
+--R                 + 
+--R                     +-+
+--R                   x\|5
+--R     + 
+--R                +-------------------+
+--R                |    +-------------+
+--R                |    |    +-+
+--R            +-+ |    |123\|5  - 275
+--R         2x\|2  |- 2 |-------------
+--R                |    |        +-+
+--R               \|   \|   3200\|5
+--R      *
+--R         atan
+--R                                                        +-------------------+
+--R                                        +-------------+ |    +-------------+
+--R                                        |    +-+        |    |    +-+
+--R                    +-+ +-+        +-+  |123\|5  - 275  |    |123\|5  - 275
+--R              (2100\|2 \|5  + 4700\|2 ) |-------------  |- 2 |-------------
+--R                                        |        +-+    |    |        +-+
+--R                                       \|   3200\|5    \|   \|   3200\|5
+--R           /
+--R                                                          +-------------------+
+--R                                          +-------------+ |    +-------------+
+--R                                          |    +-+        |    |    +-+
+--R                      +-+ +-+        +-+  |123\|5  - 275  |    |123\|5  - 275
+--R                (2100\|2 \|5  + 4700\|2 ) |-------------  |- 2 |-------------
+--R                                          |        +-+    |    |        +-+
+--R                                         \|   3200\|5    \|   \|   3200\|5
+--R              + 
+--R                  +-+
+--R                x\|5
+--R     + 
+--R                +-------------------+
+--R                |    +-------------+
+--R                |    |    +-+
+--R            +-+ |    |123\|5  + 275
+--R         2x\|2  |- 2 |-------------
+--R                |    |        +-+
+--R               \|   \|   3200\|5
+--R      *
+--R         atan
+--R                                                        +-------------------+
+--R                                        +-------------+ |    +-------------+
+--R                                        |    +-+        |    |    +-+
+--R                    +-+ +-+        +-+  |123\|5  + 275  |    |123\|5  + 275
+--R              (2100\|2 \|5  - 4700\|2 ) |-------------  |- 2 |-------------
+--R                                        |        +-+    |    |        +-+
+--R                                       \|   3200\|5    \|   \|   3200\|5
+--R           /
+--R                                                          +-------------------+
+--R                                          +-------------+ |    +-------------+
+--R                                          |    +-+        |    |    +-+
+--R                      +-+ +-+        +-+  |123\|5  + 275  |    |123\|5  + 275
+--R                (2100\|2 \|5  - 4700\|2 ) |-------------  |- 2 |-------------
+--R                                          |        +-+    |    |        +-+
+--R                                         \|   3200\|5    \|   \|   3200\|5
+--R              + 
+--R                  +-+
+--R                x\|5
+--R     + 
+--R       - 8
+--R  /
+--R     8x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1501
+
+--S 1502 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                     +-----------------+
+--R                     |  +-------------+
+--R                     |  |    +-+
+--R             +-+ +-+ |  |123\|5  + 275
+--R            \|2 \|5  |2 |-------------
+--R                     |  |        +-+
+--R                    \| \|   3200\|5
+--R         *
+--R            log
+--R                                                             +-----------------+
+--R                                             +-------------+ |  +-------------+
+--R                                             |    +-+        |  |    +-+
+--R                        +-+ +-+         +-+  |123\|5  + 275  |  |123\|5  + 275
+--R                 (4200x\|2 \|5  - 9400x\|2 ) |-------------  |2 |-------------
+--R                                             |        +-+    |  |        +-+
+--R                                            \|   3200\|5    \| \|   3200\|5
+--R               + 
+--R                                 +-------------+
+--R                                 |    +-+
+--R                      +-+        |123\|5  + 275     2 +-+
+--R                 (360\|5  - 800) |-------------  + x \|5
+--R                                 |        +-+
+--R                                \|   3200\|5
+--R     + 
+--R       -
+--R                     +-----------------+
+--R                     |  +-------------+
+--R                     |  |    +-+
+--R             +-+ +-+ |  |123\|5  - 275
+--R            \|2 \|5  |2 |-------------
+--R                     |  |        +-+
+--R                    \| \|   3200\|5
+--R         *
+--R            log
+--R                                                             +-----------------+
+--R                                             +-------------+ |  +-------------+
+--R                                             |    +-+        |  |    +-+
+--R                        +-+ +-+         +-+  |123\|5  - 275  |  |123\|5  - 275
+--R                 (4200x\|2 \|5  + 9400x\|2 ) |-------------  |2 |-------------
+--R                                             |        +-+    |  |        +-+
+--R                                            \|   3200\|5    \| \|   3200\|5
+--R               + 
+--R                                 +-------------+
+--R                                 |    +-+
+--R                      +-+        |123\|5  - 275     2 +-+
+--R                 (360\|5  + 800) |-------------  + x \|5
+--R                                 |        +-+
+--R                                \|   3200\|5
+--R     + 
+--R                  +-------------------+
+--R                  |    +-------------+
+--R                  |    |    +-+
+--R          +-+ +-+ |    |123\|5  - 275
+--R         \|2 \|5  |- 2 |-------------
+--R                  |    |        +-+
+--R                 \|   \|   3200\|5
+--R      *
+--R         log
+--R                                                          +-------------------+
+--R                                          +-------------+ |    +-------------+
+--R                                          |    +-+        |    |    +-+
+--R                     +-+ +-+         +-+  |123\|5  - 275  |    |123\|5  - 275
+--R              (4200x\|2 \|5  + 9400x\|2 ) |-------------  |- 2 |-------------
+--R                                          |        +-+    |    |        +-+
+--R                                         \|   3200\|5    \|   \|   3200\|5
+--R            + 
+--R                                +-------------+
+--R                                |    +-+
+--R                     +-+        |123\|5  - 275     2 +-+
+--R              (- 360\|5  - 800) |-------------  + x \|5
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R                  +-------------------+
+--R                  |    +-------------+
+--R                  |    |    +-+
+--R          +-+ +-+ |    |123\|5  + 275
+--R         \|2 \|5  |- 2 |-------------
+--R                  |    |        +-+
+--R                 \|   \|   3200\|5
+--R      *
+--R         log
+--R                                                          +-------------------+
+--R                                          +-------------+ |    +-------------+
+--R                                          |    +-+        |    |    +-+
+--R                     +-+ +-+         +-+  |123\|5  + 275  |    |123\|5  + 275
+--R              (4200x\|2 \|5  - 9400x\|2 ) |-------------  |- 2 |-------------
+--R                                          |        +-+    |    |        +-+
+--R                                         \|   3200\|5    \|   \|   3200\|5
+--R            + 
+--R                                +-------------+
+--R                                |    +-+
+--R                     +-+        |123\|5  + 275     2 +-+
+--R              (- 360\|5  + 800) |-------------  + x \|5
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R       -
+--R                     +-------------------+
+--R                     |    +-------------+
+--R                     |    |    +-+
+--R             +-+ +-+ |    |123\|5  + 275
+--R            \|2 \|5  |- 2 |-------------
+--R                     |    |        +-+
+--R                    \|   \|   3200\|5
+--R         *
+--R            log
+--R                                                 +-------------+
+--R                                                 |    +-+
+--R                            +-+ +-+         +-+  |123\|5  + 275
+--R                   (- 4200x\|2 \|5  + 9400x\|2 ) |-------------
+--R                                                 |        +-+
+--R                                                \|   3200\|5
+--R                *
+--R                    +-------------------+
+--R                    |    +-------------+
+--R                    |    |    +-+
+--R                    |    |123\|5  + 275
+--R                    |- 2 |-------------
+--R                    |    |        +-+
+--R                   \|   \|   3200\|5
+--R               + 
+--R                                   +-------------+
+--R                                   |    +-+
+--R                        +-+        |123\|5  + 275     2 +-+
+--R                 (- 360\|5  + 800) |-------------  + x \|5
+--R                                   |        +-+
+--R                                  \|   3200\|5
+--R     + 
+--R       -
+--R                     +-------------------+
+--R                     |    +-------------+
+--R                     |    |    +-+
+--R             +-+ +-+ |    |123\|5  - 275
+--R            \|2 \|5  |- 2 |-------------
+--R                     |    |        +-+
+--R                    \|   \|   3200\|5
+--R         *
+--R            log
+--R                                                 +-------------+
+--R                                                 |    +-+
+--R                            +-+ +-+         +-+  |123\|5  - 275
+--R                   (- 4200x\|2 \|5  - 9400x\|2 ) |-------------
+--R                                                 |        +-+
+--R                                                \|   3200\|5
+--R                *
+--R                    +-------------------+
+--R                    |    +-------------+
+--R                    |    |    +-+
+--R                    |    |123\|5  - 275
+--R                    |- 2 |-------------
+--R                    |    |        +-+
+--R                   \|   \|   3200\|5
+--R               + 
+--R                                   +-------------+
+--R                                   |    +-+
+--R                        +-+        |123\|5  - 275     2 +-+
+--R                 (- 360\|5  - 800) |-------------  + x \|5
+--R                                   |        +-+
+--R                                  \|   3200\|5
+--R     + 
+--R                  +-----------------+
+--R                  |  +-------------+
+--R                  |  |    +-+
+--R          +-+ +-+ |  |123\|5  - 275
+--R         \|2 \|5  |2 |-------------
+--R                  |  |        +-+
+--R                 \| \|   3200\|5
+--R      *
+--R         log
+--R                                                            +-----------------+
+--R                                            +-------------+ |  +-------------+
+--R                                            |    +-+        |  |    +-+
+--R                       +-+ +-+         +-+  |123\|5  - 275  |  |123\|5  - 275
+--R              (- 4200x\|2 \|5  - 9400x\|2 ) |-------------  |2 |-------------
+--R                                            |        +-+    |  |        +-+
+--R                                           \|   3200\|5    \| \|   3200\|5
+--R            + 
+--R                              +-------------+
+--R                              |    +-+
+--R                   +-+        |123\|5  - 275     2 +-+
+--R              (360\|5  + 800) |-------------  + x \|5
+--R                              |        +-+
+--R                             \|   3200\|5
+--R     + 
+--R                  +-----------------+
+--R                  |  +-------------+
+--R                  |  |    +-+
+--R          +-+ +-+ |  |123\|5  + 275
+--R         \|2 \|5  |2 |-------------
+--R                  |  |        +-+
+--R                 \| \|   3200\|5
+--R      *
+--R         log
+--R                                                            +-----------------+
+--R                                            +-------------+ |  +-------------+
+--R                                            |    +-+        |  |    +-+
+--R                       +-+ +-+         +-+  |123\|5  + 275  |  |123\|5  + 275
+--R              (- 4200x\|2 \|5  + 9400x\|2 ) |-------------  |2 |-------------
+--R                                            |        +-+    |  |        +-+
+--R                                           \|   3200\|5    \| \|   3200\|5
+--R            + 
+--R                              +-------------+
+--R                              |    +-+
+--R                   +-+        |123\|5  + 275     2 +-+
+--R              (360\|5  - 800) |-------------  + x \|5
+--R                              |        +-+
+--R                             \|   3200\|5
+--R     + 
+--R       -
+--R                      +-------------------+
+--R                      |    +-------------+
+--R                      |    |    +-+
+--R              +-+ +-+ |    |123\|5  + 275
+--R            2\|2 \|5  |- 2 |-------------
+--R                      |    |        +-+
+--R                     \|   \|   3200\|5
+--R         *
+--R            atan
+--R                                                           +-------------------+
+--R                                           +-------------+ |    +-------------+
+--R                                           |    +-+        |    |    +-+
+--R                       +-+ +-+        +-+  |123\|5  + 275  |    |123\|5  + 275
+--R                 (2100\|2 \|5  - 4700\|2 ) |-------------  |- 2 |-------------
+--R                                           |        +-+    |    |        +-+
+--R                                          \|   3200\|5    \|   \|   3200\|5
+--R              /
+--R                                               +-------------+
+--R                                               |    +-+
+--R                           +-+ +-+        +-+  |123\|5  + 275
+--R                     (2100\|2 \|5  - 4700\|2 ) |-------------
+--R                                               |        +-+
+--R                                              \|   3200\|5
+--R                  *
+--R                      +-------------------+
+--R                      |    +-------------+
+--R                      |    |    +-+
+--R                      |    |123\|5  + 275
+--R                      |- 2 |-------------
+--R                      |    |        +-+
+--R                     \|   \|   3200\|5
+--R                 + 
+--R                       +-+
+--R                   - x\|5
+--R     + 
+--R       -
+--R                      +-------------------+
+--R                      |    +-------------+
+--R                      |    |    +-+
+--R              +-+ +-+ |    |123\|5  - 275
+--R            2\|2 \|5  |- 2 |-------------
+--R                      |    |        +-+
+--R                     \|   \|   3200\|5
+--R         *
+--R            atan
+--R                                                           +-------------------+
+--R                                           +-------------+ |    +-------------+
+--R                                           |    +-+        |    |    +-+
+--R                       +-+ +-+        +-+  |123\|5  - 275  |    |123\|5  - 275
+--R                 (2100\|2 \|5  + 4700\|2 ) |-------------  |- 2 |-------------
+--R                                           |        +-+    |    |        +-+
+--R                                          \|   3200\|5    \|   \|   3200\|5
+--R              /
+--R                                               +-------------+
+--R                                               |    +-+
+--R                           +-+ +-+        +-+  |123\|5  - 275
+--R                     (2100\|2 \|5  + 4700\|2 ) |-------------
+--R                                               |        +-+
+--R                                              \|   3200\|5
+--R                  *
+--R                      +-------------------+
+--R                      |    +-------------+
+--R                      |    |    +-+
+--R                      |    |123\|5  - 275
+--R                      |- 2 |-------------
+--R                      |    |        +-+
+--R                     \|   \|   3200\|5
+--R                 + 
+--R                       +-+
+--R                   - x\|5
+--R     + 
+--R                   +-----------------+
+--R                   |  +-------------+
+--R                   |  |    +-+
+--R           +-+ +-+ |  |123\|5  - 275
+--R         2\|2 \|5  |2 |-------------
+--R                   |  |        +-+
+--R                  \| \|   3200\|5
+--R      *
+--R         atan
+--R                                                        +-----------------+
+--R                                        +-------------+ |  +-------------+
+--R                                        |    +-+        |  |    +-+
+--R                    +-+ +-+        +-+  |123\|5  - 275  |  |123\|5  - 275
+--R              (2100\|2 \|5  + 4700\|2 ) |-------------  |2 |-------------
+--R                                        |        +-+    |  |        +-+
+--R                                       \|   3200\|5    \| \|   3200\|5
+--R           /
+--R                                                          +-----------------+
+--R                                          +-------------+ |  +-------------+
+--R                                          |    +-+        |  |    +-+
+--R                      +-+ +-+        +-+  |123\|5  - 275  |  |123\|5  - 275
+--R                (2100\|2 \|5  + 4700\|2 ) |-------------  |2 |-------------
+--R                                          |        +-+    |  |        +-+
+--R                                         \|   3200\|5    \| \|   3200\|5
+--R              + 
+--R                    +-+
+--R                - x\|5
+--R     + 
+--R                   +-----------------+
+--R                   |  +-------------+
+--R                   |  |    +-+
+--R           +-+ +-+ |  |123\|5  + 275
+--R         2\|2 \|5  |2 |-------------
+--R                   |  |        +-+
+--R                  \| \|   3200\|5
+--R      *
+--R         atan
+--R                                                        +-----------------+
+--R                                        +-------------+ |  +-------------+
+--R                                        |    +-+        |  |    +-+
+--R                    +-+ +-+        +-+  |123\|5  + 275  |  |123\|5  + 275
+--R              (2100\|2 \|5  - 4700\|2 ) |-------------  |2 |-------------
+--R                                        |        +-+    |  |        +-+
+--R                                       \|   3200\|5    \| \|   3200\|5
+--R           /
+--R                                                          +-----------------+
+--R                                          +-------------+ |  +-------------+
+--R                                          |    +-+        |  |    +-+
+--R                      +-+ +-+        +-+  |123\|5  + 275  |  |123\|5  + 275
+--R                (2100\|2 \|5  - 4700\|2 ) |-------------  |2 |-------------
+--R                                          |        +-+    |  |        +-+
+--R                                         \|   3200\|5    \| \|   3200\|5
+--R              + 
+--R                    +-+
+--R                - x\|5
+--R     + 
+--R       -
+--R                      +-----------------+
+--R                      |  +-------------+
+--R                      |  |    +-+
+--R              +-+ +-+ |  |123\|5  + 275
+--R            2\|2 \|5  |2 |-------------
+--R                      |  |        +-+
+--R                     \| \|   3200\|5
+--R         *
+--R            atan
+--R                                                           +-----------------+
+--R                                           +-------------+ |  +-------------+
+--R                                           |    +-+        |  |    +-+
+--R                       +-+ +-+        +-+  |123\|5  + 275  |  |123\|5  + 275
+--R                 (2100\|2 \|5  - 4700\|2 ) |-------------  |2 |-------------
+--R                                           |        +-+    |  |        +-+
+--R                                          \|   3200\|5    \| \|   3200\|5
+--R              /
+--R                                                             +-----------------+
+--R                                             +-------------+ |  +-------------+
+--R                                             |    +-+        |  |    +-+
+--R                         +-+ +-+        +-+  |123\|5  + 275  |  |123\|5  + 275
+--R                   (2100\|2 \|5  - 4700\|2 ) |-------------  |2 |-------------
+--R                                             |        +-+    |  |        +-+
+--R                                            \|   3200\|5    \| \|   3200\|5
+--R                 + 
+--R                     +-+
+--R                   x\|5
+--R     + 
+--R       -
+--R                      +-----------------+
+--R                      |  +-------------+
+--R                      |  |    +-+
+--R              +-+ +-+ |  |123\|5  - 275
+--R            2\|2 \|5  |2 |-------------
+--R                      |  |        +-+
+--R                     \| \|   3200\|5
+--R         *
+--R            atan
+--R                                                           +-----------------+
+--R                                           +-------------+ |  +-------------+
+--R                                           |    +-+        |  |    +-+
+--R                       +-+ +-+        +-+  |123\|5  - 275  |  |123\|5  - 275
+--R                 (2100\|2 \|5  + 4700\|2 ) |-------------  |2 |-------------
+--R                                           |        +-+    |  |        +-+
+--R                                          \|   3200\|5    \| \|   3200\|5
+--R              /
+--R                                                             +-----------------+
+--R                                             +-------------+ |  +-------------+
+--R                                             |    +-+        |  |    +-+
+--R                         +-+ +-+        +-+  |123\|5  - 275  |  |123\|5  - 275
+--R                   (2100\|2 \|5  + 4700\|2 ) |-------------  |2 |-------------
+--R                                             |        +-+    |  |        +-+
+--R                                            \|   3200\|5    \| \|   3200\|5
+--R                 + 
+--R                     +-+
+--R                   x\|5
+--R     + 
+--R                   +-------------------+
+--R                   |    +-------------+
+--R                   |    |    +-+
+--R           +-+ +-+ |    |123\|5  - 275
+--R         2\|2 \|5  |- 2 |-------------
+--R                   |    |        +-+
+--R                  \|   \|   3200\|5
+--R      *
+--R         atan
+--R                                                        +-------------------+
+--R                                        +-------------+ |    +-------------+
+--R                                        |    +-+        |    |    +-+
+--R                    +-+ +-+        +-+  |123\|5  - 275  |    |123\|5  - 275
+--R              (2100\|2 \|5  + 4700\|2 ) |-------------  |- 2 |-------------
+--R                                        |        +-+    |    |        +-+
+--R                                       \|   3200\|5    \|   \|   3200\|5
+--R           /
+--R                                                          +-------------------+
+--R                                          +-------------+ |    +-------------+
+--R                                          |    +-+        |    |    +-+
+--R                      +-+ +-+        +-+  |123\|5  - 275  |    |123\|5  - 275
+--R                (2100\|2 \|5  + 4700\|2 ) |-------------  |- 2 |-------------
+--R                                          |        +-+    |    |        +-+
+--R                                         \|   3200\|5    \|   \|   3200\|5
+--R              + 
+--R                  +-+
+--R                x\|5
+--R     + 
+--R                   +-------------------+
+--R                   |    +-------------+
+--R                   |    |    +-+
+--R           +-+ +-+ |    |123\|5  + 275
+--R         2\|2 \|5  |- 2 |-------------
+--R                   |    |        +-+
+--R                  \|   \|   3200\|5
+--R      *
+--R         atan
+--R                                                        +-------------------+
+--R                                        +-------------+ |    +-------------+
+--R                                        |    +-+        |    |    +-+
+--R                    +-+ +-+        +-+  |123\|5  + 275  |    |123\|5  + 275
+--R              (2100\|2 \|5  - 4700\|2 ) |-------------  |- 2 |-------------
+--R                                        |        +-+    |    |        +-+
+--R                                       \|   3200\|5    \|   \|   3200\|5
+--R           /
+--R                                                          +-------------------+
+--R                                          +-------------+ |    +-------------+
+--R                                          |    +-+        |    |    +-+
+--R                      +-+ +-+        +-+  |123\|5  + 275  |    |123\|5  + 275
+--R                (2100\|2 \|5  - 4700\|2 ) |-------------  |- 2 |-------------
+--R                                          |        +-+    |    |        +-+
+--R                                         \|   3200\|5    \|   \|   3200\|5
+--R              + 
+--R                  +-+
+--R                x\|5
+--R     + 
+--R        +---------------+     +---------+          +--------+
+--R       4|      +-+            |  +-+          4+-+4| +-+          2
+--R       \|- 110\|5  + 246 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +---------------+     +---------+          +--------+
+--R         4|      +-+            |  +-+          4+-+4| +-+          2
+--R       - \|- 110\|5  + 246 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +-------------+           +----------+    +-----------+
+--R         4|    +-+             4+-+4|   +-+         |    +-+          2
+--R       - \|110\|5  + 246 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R        +-------------+             +----------+    +-----------+
+--R       4|    +-+               4+-+4|   +-+         |    +-+          2
+--R       \|110\|5  + 246 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                        +--------+3
+--R         +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       2\|- 110\|5  + 246 atan(----------------------------------------)
+--R                                                   4
+--R     + 
+--R                                                        +--------+3
+--R         +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       2\|- 110\|5  + 246 atan(----------------------------------------)
+--R                                                   4
+--R     + 
+--R                                                      +----------+3
+--R         +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       2\|110\|5  + 246 atan(------------------------------------------)
+--R                                                  4
+--R     + 
+--R                                                      +----------+3
+--R         +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       2\|110\|5  + 246 atan(------------------------------------------)
+--R                                                  4
+--R  /
+--R       +-+
+--R     8\|5
+--R                                                    Type: Expression(Integer)
+--E 1502
+
+--S 1503 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                                       +-----------+
+--R                         8     4 4+-+3 +-+     4 4+-+3 |    +-+
+--R                   ((- 2x  - 3x )\|2  \|5  - 5x  \|2 )\|- 2\|5  + 6
+--R                 + 
+--R                      10     2 4+-+3 +-+      6 4+-+3
+--R                   (2x   - 2x )\|2  \|5  + 10x  \|2
+--R              *
+--R                  +----------+3
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                       +-----------+
+--R                         10     2 4+-+ +-+      6 4+-+ |    +-+
+--R                   ((- 2x   + 2x )\|2 \|5  - 10x  \|2)\|- 2\|5  + 6
+--R                 + 
+--R                        12      8 4+-+ +-+      8 4+-+
+--R                   (- 8x   - 12x )\|2 \|5  - 20x  \|2
+--R              *
+--R                  +----------+
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|5  + 6
+--R         + 
+--R                                                    +-----------+
+--R                       8     4 4+-+ +-+      4 4+-+ |    +-+
+--R                   ((4x  + 6x )\|2 \|5  + 10x  \|2)\|- 2\|5  + 6
+--R                 + 
+--R                        10     2 4+-+ +-+      6 4+-+
+--R                   (- 4x   + 4x )\|2 \|5  - 20x  \|2
+--R              *
+--R                  +----------+3
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                       +-----------+
+--R                       10     2 4+-+3 +-+      6 4+-+3 |    +-+
+--R                   ((2x   - 2x )\|2  \|5  + 10x  \|2 )\|- 2\|5  + 6
+--R                 + 
+--R                      12      8 4+-+3 +-+      8 4+-+3
+--R                   (8x   + 12x )\|2  \|5  + 20x  \|2
+--R              *
+--R                  +----------+
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                       10     6     2 4+-+3 +-+         6      2 4+-+3
+--R                 ((- 2x   - 6x  - 7x )\|2  \|5  + (- 10x  - 15x )\|2  )
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                  12     8     4     4+-+3 +-+       8      4     4+-+3
+--R               (2x   + 3x  + 3x  - 3)\|2  \|5  + (15x  + 15x  - 5)\|2
+--R          *
+--R              +----------+3
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                       12     8     4     4+-+ +-+         8      4     4+-+
+--R                 ((- 2x   - 3x  - 3x  + 3)\|2 \|5  + (- 15x  - 15x  + 5)\|2 )
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                    14      10      6 4+-+ +-+         10      6 4+-+
+--R               (- 8x   - 24x   - 28x )\|2 \|5  + (- 40x   - 60x )\|2
+--R          *
+--R              +----------+
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R      *
+--R          +-------------+
+--R         4|    +-+
+--R         \|110\|5  + 246
+--R     + 
+--R                                                    +---------------+
+--R                       8     4 4+-+ +-+      4 4+-+4|      +-+
+--R                 ((- 4x  - 6x )\|2 \|5  + 10x  \|2)\|- 110\|5  + 246
+--R              *
+--R                  +----------+2
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                 +---------------+ +-----------+
+--R                   8     4 4+-+3 +-+     4 4+-+34|      +-+        |    +-+
+--R               ((2x  + 3x )\|2  \|5  - 5x  \|2 )\|- 110\|5  + 246 \|- 2\|5  + 6
+--R             + 
+--R                     10     6     2 4+-+3 +-+         6      2 4+-+3
+--R                 ((2x   + 6x  + 7x )\|2  \|5  + (- 10x  - 15x )\|2  )
+--R              *
+--R                  +---------------+
+--R                 4|      +-+
+--R                 \|- 110\|5  + 246
+--R          *
+--R              +--------+3
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                                       +---------------+
+--R                       10     2 4+-+3 +-+      6 4+-+34|      +-+
+--R                 ((- 2x   + 2x )\|2  \|5  + 10x  \|2 )\|- 110\|5  + 246
+--R              *
+--R                  +----------+2
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                 +---------------+ +-----------+
+--R                   10     2 4+-+ +-+      6 4+-+4|      +-+        |    +-+
+--R               ((2x   - 2x )\|2 \|5  - 10x  \|2)\|- 110\|5  + 246 \|- 2\|5  + 6
+--R             + 
+--R                     12     8     4     4+-+ +-+         8      4     4+-+
+--R                 ((2x   + 3x  + 3x  - 3)\|2 \|5  + (- 15x  - 15x  + 5)\|2 )
+--R              *
+--R                  +---------------+
+--R                 4|      +-+
+--R                 \|- 110\|5  + 246
+--R          *
+--R              +--------+
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                   +----------+2                  +-----------+
+--R                 10       6 4+-+2 4|   +-+            10       6  |    +-+
+--R           (- 80x   - 240x )\|2   \|- \|5  + 3  + (80x   + 240x )\|- 2\|5  + 6
+--R         + 
+--R                 8       4  +-+      12       8       4
+--R           (- 40x  - 120x )\|5  + 80x   + 360x  + 360x
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                             +---------------+ +----------+2
+--R               10     2 4+-+ +-+      6 4+-+4|      +-+       4|   +-+
+--R           ((4x   - 4x )\|2 \|5  - 20x  \|2)\|- 110\|5  + 246 \|- \|5  + 3
+--R         + 
+--R                                                 +---------------+ +-----------+
+--R                 10     2 4+-+3 +-+      6 4+-+34|      +-+        |    +-+
+--R           ((- 2x   + 2x )\|2  \|5  + 10x  \|2 )\|- 110\|5  + 246 \|- 2\|5  + 6
+--R         + 
+--R                   12     8     4     4+-+3 +-+       8      4     4+-+3
+--R             ((- 2x   - 3x  - 3x  + 3)\|2  \|5  + (15x  + 15x  - 5)\|2  )
+--R          *
+--R              +---------------+
+--R             4|      +-+
+--R             \|- 110\|5  + 246
+--R      *
+--R          +--------+3
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                            +----------+2                          +-----------+
+--R                10       6 4|   +-+               10       6 4+-+2 |    +-+
+--R           (160x   + 480x )\|- \|5  + 3   + (- 80x   - 240x )\|2  \|- 2\|5  + 6
+--R         + 
+--R               8       4 4+-+2 +-+         12       8       4 4+-+2
+--R           (40x  + 120x )\|2  \|5  + (- 80x   - 360x  - 360x )\|2
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                    +---------------+
+--R                   12      8 4+-+3 +-+      8 4+-+34|      +-+
+--R             ((- 8x   - 12x )\|2  \|5  + 20x  \|2 )\|- 110\|5  + 246
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                              +---------------+ +-----------+
+--R               12      8 4+-+ +-+      8 4+-+4|      +-+        |    +-+
+--R           ((8x   + 12x )\|2 \|5  - 20x  \|2)\|- 110\|5  + 246 \|- 2\|5  + 6
+--R         + 
+--R                 14      10      6 4+-+ +-+         10      6 4+-+
+--R             ((8x   + 24x   + 28x )\|2 \|5  + (- 40x   - 60x )\|2 )
+--R          *
+--R              +---------------+
+--R             4|      +-+
+--R             \|- 110\|5  + 246
+--R      *
+--R          +--------+
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                8       4 4+-+2 +-+         12       8       4 4+-+2
+--R         ((- 40x  - 120x )\|2  \|5  + (- 80x   - 360x  - 360x )\|2  )
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                                                    +-----------+
+--R            8       4  +-+      12       8       4  |    +-+           14
+--R       ((40x  + 120x )\|5  + 80x   + 360x  + 360x )\|- 2\|5  + 6  + 80x
+--R     + 
+--R           10       6       2
+--R       480x   + 800x  + 240x
+--R  /
+--R                                        +----------+2
+--R               12       8      4 4+-+2 4|   +-+
+--R           (80x   + 240x  + 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                    +-----------+
+--R                 12       8      4  |    +-+            10       6      2  +-+
+--R           (- 80x   - 240x  - 80x )\|- 2\|5  + 6  + (40x   + 120x  + 40x )\|5
+--R         + 
+--R                14       10       6       2
+--R           - 80x   - 360x   - 440x  - 120x
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                      +----------+2
+--R                  12       8       4 4|   +-+
+--R           (- 160x   - 480x  - 160x )\|- \|5  + 3
+--R         + 
+--R                                       +-----------+
+--R               12       8      4 4+-+2 |    +-+
+--R           (80x   + 240x  + 80x )\|2  \|- 2\|5  + 6
+--R         + 
+--R                 10       6      2 4+-+2 +-+
+--R           (- 40x   - 120x  - 40x )\|2  \|5
+--R         + 
+--R               14       10       6       2 4+-+2
+--R           (80x   + 360x   + 440x  + 120x )\|2
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                 10       6      2 4+-+2 +-+
+--R             (40x   + 120x  + 40x )\|2  \|5
+--R           + 
+--R                 14       10       6       2 4+-+2
+--R             (80x   + 360x   + 440x  + 120x )\|2
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                10       6      2  +-+      14       10       6       2
+--R         ((- 40x   - 120x  - 40x )\|5  - 80x   - 360x   - 440x  - 120x )
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R            16       12       8       4
+--R       - 80x   - 480x   - 880x  - 480x  - 80
+--R                                                    Type: Expression(Integer)
+--E 1503
+
+)clear all
+
+--S 1504 of 2282
+t0:=1/(x^4*(1+3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         12     8    4
+--R        x   + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1504
+
+--S 1505 of 2282
+r0:=(-1/3)/x^3-1/2*atan(1-2^(3/4)*x/(3+sqrt(5))^(1/4))*_
+   (843-377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+1/2*atan(1+2^(3/4)*_
+   x/(3+sqrt(5))^(1/4))*(843-377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-_
+   1/4*log(2*x^2-2*2^(1/4)*x*(3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*_
+   (843-377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+1/4*log(2*x^2+2*2^(1/4)*x*_
+   (3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*(843-377*sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))+1/2*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))*_
+   (843+377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-1/2*atan(1+2^(3/4)*_
+   x/(3-sqrt(5))^(1/4))*(843+377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+_
+   1/4*log(2*x^2-2*2^(1/4)*x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*_
+   (843+377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-1/4*log(2*x^2+2*2^(1/4)*x*_
+   (3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*_
+   (843+377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R            +---------------+     +---------+          +--------+
+--R         3 4|      +-+            |  +-+          4+-+4| +-+          2
+--R       3x  \|- 377\|5  + 843 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R              +---------------+     +---------+          +--------+
+--R           3 4|      +-+            |  +-+          4+-+4| +-+          2
+--R       - 3x  \|- 377\|5  + 843 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R              +-------------+           +----------+    +-----------+
+--R           3 4|    +-+             4+-+4|   +-+         |    +-+          2
+--R       - 3x  \|377\|5  + 843 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R            +-------------+             +----------+    +-----------+
+--R         3 4|    +-+               4+-+4|   +-+         |    +-+          2
+--R       3x  \|377\|5  + 843 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                             +--------+3
+--R              +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R           3 4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 6x  \|- 377\|5  + 843 atan(----------------------------------------)
+--R                                                        4
+--R     + 
+--R                                                             +--------+3
+--R              +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R           3 4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 6x  \|- 377\|5  + 843 atan(----------------------------------------)
+--R                                                        4
+--R     + 
+--R                                                           +----------+3
+--R              +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R           3 4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 6x  \|377\|5  + 843 atan(------------------------------------------)
+--R                                                       4
+--R     + 
+--R                                                           +----------+3
+--R              +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R           3 4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 6x  \|377\|5  + 843 atan(------------------------------------------)
+--R                                                       4
+--R     + 
+--R          4+-+3 +-+
+--R       - 4\|2  \|5
+--R  /
+--R        3 4+-+3 +-+
+--R     12x  \|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 1505
+
+--S 1506 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                    +------------------+
+--R                    |  +--------------+
+--R                    |  |    +-+
+--R              3 +-+ |  |843\|5  + 1885
+--R            3x \|2  |2 |--------------
+--R                    |  |        +-+
+--R                   \| \|   3200\|5
+--R         *
+--R            log
+--R                                        +------------------+
+--R                                        |  +--------------+
+--R                                        |  |    +-+
+--R                     +-+ +-+       +-+  |  |843\|5  + 1885
+--R                 (7x\|2 \|5  - 15x\|2 ) |2 |--------------
+--R                                        |  |        +-+
+--R                                       \| \|   3200\|5
+--R               + 
+--R                                   +--------------+
+--R                                   |    +-+
+--R                        +-+        |843\|5  + 1885     2
+--R                 (- 420\|5  + 940) |--------------  + x
+--R                                   |        +-+
+--R                                  \|   3200\|5
+--R     + 
+--R                 +------------------+
+--R                 |  +--------------+
+--R                 |  |    +-+
+--R           3 +-+ |  |843\|5  - 1885
+--R         3x \|2  |2 |--------------
+--R                 |  |        +-+
+--R                \| \|   3200\|5
+--R      *
+--R         log
+--R                                     +------------------+
+--R                                     |  +--------------+
+--R                                     |  |    +-+
+--R                  +-+ +-+       +-+  |  |843\|5  - 1885
+--R              (7x\|2 \|5  + 15x\|2 ) |2 |--------------
+--R                                     |  |        +-+
+--R                                    \| \|   3200\|5
+--R            + 
+--R                              +--------------+
+--R                              |    +-+
+--R                   +-+        |843\|5  - 1885     2
+--R              (420\|5  + 940) |--------------  + x
+--R                              |        +-+
+--R                             \|   3200\|5
+--R     + 
+--R                 +--------------------+
+--R                 |    +--------------+
+--R                 |    |    +-+
+--R           3 +-+ |    |843\|5  - 1885
+--R         3x \|2  |- 2 |--------------
+--R                 |    |        +-+
+--R                \|   \|   3200\|5
+--R      *
+--R         log
+--R                                     +--------------------+
+--R                                     |    +--------------+
+--R                                     |    |    +-+
+--R                  +-+ +-+       +-+  |    |843\|5  - 1885
+--R              (7x\|2 \|5  + 15x\|2 ) |- 2 |--------------
+--R                                     |    |        +-+
+--R                                    \|   \|   3200\|5
+--R            + 
+--R                                +--------------+
+--R                                |    +-+
+--R                     +-+        |843\|5  - 1885     2
+--R              (- 420\|5  - 940) |--------------  + x
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R       -
+--R                    +--------------------+
+--R                    |    +--------------+
+--R                    |    |    +-+
+--R              3 +-+ |    |843\|5  + 1885
+--R            3x \|2  |- 2 |--------------
+--R                    |    |        +-+
+--R                   \|   \|   3200\|5
+--R         *
+--R            log
+--R                                        +--------------------+
+--R                                        |    +--------------+
+--R                                        |    |    +-+
+--R                     +-+ +-+       +-+  |    |843\|5  + 1885
+--R                 (7x\|2 \|5  - 15x\|2 ) |- 2 |--------------
+--R                                        |    |        +-+
+--R                                       \|   \|   3200\|5
+--R               + 
+--R                                 +--------------+
+--R                                 |    +-+
+--R                      +-+        |843\|5  + 1885     2
+--R                 (420\|5  - 940) |--------------  + x
+--R                                 |        +-+
+--R                                \|   3200\|5
+--R     + 
+--R                 +--------------------+
+--R                 |    +--------------+
+--R                 |    |    +-+
+--R           3 +-+ |    |843\|5  + 1885
+--R         3x \|2  |- 2 |--------------
+--R                 |    |        +-+
+--R                \|   \|   3200\|5
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |    +--------------+
+--R                                       |    |    +-+
+--R                    +-+ +-+       +-+  |    |843\|5  + 1885
+--R              (- 7x\|2 \|5  + 15x\|2 ) |- 2 |--------------
+--R                                       |    |        +-+
+--R                                      \|   \|   3200\|5
+--R            + 
+--R                              +--------------+
+--R                              |    +-+
+--R                   +-+        |843\|5  + 1885     2
+--R              (420\|5  - 940) |--------------  + x
+--R                              |        +-+
+--R                             \|   3200\|5
+--R     + 
+--R       -
+--R                    +--------------------+
+--R                    |    +--------------+
+--R                    |    |    +-+
+--R              3 +-+ |    |843\|5  - 1885
+--R            3x \|2  |- 2 |--------------
+--R                    |    |        +-+
+--R                   \|   \|   3200\|5
+--R         *
+--R            log
+--R                                          +--------------------+
+--R                                          |    +--------------+
+--R                                          |    |    +-+
+--R                       +-+ +-+       +-+  |    |843\|5  - 1885
+--R                 (- 7x\|2 \|5  - 15x\|2 ) |- 2 |--------------
+--R                                          |    |        +-+
+--R                                         \|   \|   3200\|5
+--R               + 
+--R                                   +--------------+
+--R                                   |    +-+
+--R                        +-+        |843\|5  - 1885     2
+--R                 (- 420\|5  - 940) |--------------  + x
+--R                                   |        +-+
+--R                                  \|   3200\|5
+--R     + 
+--R       -
+--R                    +------------------+
+--R                    |  +--------------+
+--R                    |  |    +-+
+--R              3 +-+ |  |843\|5  - 1885
+--R            3x \|2  |2 |--------------
+--R                    |  |        +-+
+--R                   \| \|   3200\|5
+--R         *
+--R            log
+--R                                          +------------------+
+--R                                          |  +--------------+
+--R                                          |  |    +-+
+--R                       +-+ +-+       +-+  |  |843\|5  - 1885
+--R                 (- 7x\|2 \|5  - 15x\|2 ) |2 |--------------
+--R                                          |  |        +-+
+--R                                         \| \|   3200\|5
+--R               + 
+--R                                 +--------------+
+--R                                 |    +-+
+--R                      +-+        |843\|5  - 1885     2
+--R                 (420\|5  + 940) |--------------  + x
+--R                                 |        +-+
+--R                                \|   3200\|5
+--R     + 
+--R                 +------------------+
+--R                 |  +--------------+
+--R                 |  |    +-+
+--R           3 +-+ |  |843\|5  + 1885
+--R         3x \|2  |2 |--------------
+--R                 |  |        +-+
+--R                \| \|   3200\|5
+--R      *
+--R         log
+--R                                       +------------------+
+--R                                       |  +--------------+
+--R                                       |  |    +-+
+--R                    +-+ +-+       +-+  |  |843\|5  + 1885
+--R              (- 7x\|2 \|5  + 15x\|2 ) |2 |--------------
+--R                                       |  |        +-+
+--R                                      \| \|   3200\|5
+--R            + 
+--R                                +--------------+
+--R                                |    +-+
+--R                     +-+        |843\|5  + 1885     2
+--R              (- 420\|5  + 940) |--------------  + x
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R                 +--------------------+
+--R                 |    +--------------+
+--R                 |    |    +-+
+--R           3 +-+ |    |843\|5  + 1885
+--R         6x \|2  |- 2 |--------------
+--R                 |    |        +-+
+--R                \|   \|   3200\|5
+--R      *
+--R                                         +--------------------+
+--R                                         |    +--------------+
+--R                                         |    |    +-+
+--R                       +-+ +-+      +-+  |    |843\|5  + 1885
+--R                   (15\|2 \|5  - 35\|2 ) |- 2 |--------------
+--R                                         |    |        +-+
+--R                                        \|   \|   3200\|5
+--R         atan(-----------------------------------------------------)
+--R                                    +--------------------+
+--R                                    |    +--------------+
+--R                                    |    |    +-+
+--R                  +-+ +-+      +-+  |    |843\|5  + 1885        +-+
+--R              (15\|2 \|5  - 35\|2 ) |- 2 |--------------   - 2x\|5
+--R                                    |    |        +-+
+--R                                   \|   \|   3200\|5
+--R     + 
+--R                 +--------------------+
+--R                 |    +--------------+
+--R                 |    |    +-+
+--R           3 +-+ |    |843\|5  - 1885
+--R         6x \|2  |- 2 |--------------
+--R                 |    |        +-+
+--R                \|   \|   3200\|5
+--R      *
+--R                                         +--------------------+
+--R                                         |    +--------------+
+--R                                         |    |    +-+
+--R                       +-+ +-+      +-+  |    |843\|5  - 1885
+--R                   (15\|2 \|5  + 35\|2 ) |- 2 |--------------
+--R                                         |    |        +-+
+--R                                        \|   \|   3200\|5
+--R         atan(-----------------------------------------------------)
+--R                                    +--------------------+
+--R                                    |    +--------------+
+--R                                    |    |    +-+
+--R                  +-+ +-+      +-+  |    |843\|5  - 1885        +-+
+--R              (15\|2 \|5  + 35\|2 ) |- 2 |--------------   - 2x\|5
+--R                                    |    |        +-+
+--R                                   \|   \|   3200\|5
+--R     + 
+--R                 +------------------+
+--R                 |  +--------------+
+--R                 |  |    +-+
+--R           3 +-+ |  |843\|5  - 1885
+--R         6x \|2  |2 |--------------
+--R                 |  |        +-+
+--R                \| \|   3200\|5
+--R      *
+--R                                         +------------------+
+--R                                         |  +--------------+
+--R                                         |  |    +-+
+--R                       +-+ +-+      +-+  |  |843\|5  - 1885
+--R                   (15\|2 \|5  + 35\|2 ) |2 |--------------
+--R                                         |  |        +-+
+--R                                        \| \|   3200\|5
+--R         atan(---------------------------------------------------)
+--R                                    +------------------+
+--R                                    |  +--------------+
+--R                                    |  |    +-+
+--R                  +-+ +-+      +-+  |  |843\|5  - 1885        +-+
+--R              (15\|2 \|5  + 35\|2 ) |2 |--------------   - 2x\|5
+--R                                    |  |        +-+
+--R                                   \| \|   3200\|5
+--R     + 
+--R                 +------------------+
+--R                 |  +--------------+
+--R                 |  |    +-+
+--R           3 +-+ |  |843\|5  + 1885
+--R         6x \|2  |2 |--------------
+--R                 |  |        +-+
+--R                \| \|   3200\|5
+--R      *
+--R                                         +------------------+
+--R                                         |  +--------------+
+--R                                         |  |    +-+
+--R                       +-+ +-+      +-+  |  |843\|5  + 1885
+--R                   (15\|2 \|5  - 35\|2 ) |2 |--------------
+--R                                         |  |        +-+
+--R                                        \| \|   3200\|5
+--R         atan(---------------------------------------------------)
+--R                                    +------------------+
+--R                                    |  +--------------+
+--R                                    |  |    +-+
+--R                  +-+ +-+      +-+  |  |843\|5  + 1885        +-+
+--R              (15\|2 \|5  - 35\|2 ) |2 |--------------   - 2x\|5
+--R                                    |  |        +-+
+--R                                   \| \|   3200\|5
+--R     + 
+--R       -
+--R                    +------------------+
+--R                    |  +--------------+
+--R                    |  |    +-+
+--R              3 +-+ |  |843\|5  + 1885
+--R            6x \|2  |2 |--------------
+--R                    |  |        +-+
+--R                   \| \|   3200\|5
+--R         *
+--R                                            +------------------+
+--R                                            |  +--------------+
+--R                                            |  |    +-+
+--R                          +-+ +-+      +-+  |  |843\|5  + 1885
+--R                      (15\|2 \|5  - 35\|2 ) |2 |--------------
+--R                                            |  |        +-+
+--R                                           \| \|   3200\|5
+--R            atan(---------------------------------------------------)
+--R                                       +------------------+
+--R                                       |  +--------------+
+--R                                       |  |    +-+
+--R                     +-+ +-+      +-+  |  |843\|5  + 1885        +-+
+--R                 (15\|2 \|5  - 35\|2 ) |2 |--------------   + 2x\|5
+--R                                       |  |        +-+
+--R                                      \| \|   3200\|5
+--R     + 
+--R       -
+--R                    +------------------+
+--R                    |  +--------------+
+--R                    |  |    +-+
+--R              3 +-+ |  |843\|5  - 1885
+--R            6x \|2  |2 |--------------
+--R                    |  |        +-+
+--R                   \| \|   3200\|5
+--R         *
+--R                                            +------------------+
+--R                                            |  +--------------+
+--R                                            |  |    +-+
+--R                          +-+ +-+      +-+  |  |843\|5  - 1885
+--R                      (15\|2 \|5  + 35\|2 ) |2 |--------------
+--R                                            |  |        +-+
+--R                                           \| \|   3200\|5
+--R            atan(---------------------------------------------------)
+--R                                       +------------------+
+--R                                       |  +--------------+
+--R                                       |  |    +-+
+--R                     +-+ +-+      +-+  |  |843\|5  - 1885        +-+
+--R                 (15\|2 \|5  + 35\|2 ) |2 |--------------   + 2x\|5
+--R                                       |  |        +-+
+--R                                      \| \|   3200\|5
+--R     + 
+--R       -
+--R                    +--------------------+
+--R                    |    +--------------+
+--R                    |    |    +-+
+--R              3 +-+ |    |843\|5  - 1885
+--R            6x \|2  |- 2 |--------------
+--R                    |    |        +-+
+--R                   \|   \|   3200\|5
+--R         *
+--R                                            +--------------------+
+--R                                            |    +--------------+
+--R                                            |    |    +-+
+--R                          +-+ +-+      +-+  |    |843\|5  - 1885
+--R                      (15\|2 \|5  + 35\|2 ) |- 2 |--------------
+--R                                            |    |        +-+
+--R                                           \|   \|   3200\|5
+--R            atan(-----------------------------------------------------)
+--R                                       +--------------------+
+--R                                       |    +--------------+
+--R                                       |    |    +-+
+--R                     +-+ +-+      +-+  |    |843\|5  - 1885        +-+
+--R                 (15\|2 \|5  + 35\|2 ) |- 2 |--------------   + 2x\|5
+--R                                       |    |        +-+
+--R                                      \|   \|   3200\|5
+--R     + 
+--R       -
+--R                    +--------------------+
+--R                    |    +--------------+
+--R                    |    |    +-+
+--R              3 +-+ |    |843\|5  + 1885
+--R            6x \|2  |- 2 |--------------
+--R                    |    |        +-+
+--R                   \|   \|   3200\|5
+--R         *
+--R                                            +--------------------+
+--R                                            |    +--------------+
+--R                                            |    |    +-+
+--R                          +-+ +-+      +-+  |    |843\|5  + 1885
+--R                      (15\|2 \|5  - 35\|2 ) |- 2 |--------------
+--R                                            |    |        +-+
+--R                                           \|   \|   3200\|5
+--R            atan(-----------------------------------------------------)
+--R                                       +--------------------+
+--R                                       |    +--------------+
+--R                                       |    |    +-+
+--R                     +-+ +-+      +-+  |    |843\|5  + 1885        +-+
+--R                 (15\|2 \|5  - 35\|2 ) |- 2 |--------------   + 2x\|5
+--R                                       |    |        +-+
+--R                                      \|   \|   3200\|5
+--R     + 
+--R       - 8
+--R  /
+--R        3
+--R     24x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1506
+
+--S 1507 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                          +------------------+
+--R                          |  +--------------+
+--R                          |  |    +-+
+--R             +-+4+-+3 +-+ |  |843\|5  + 1885
+--R            \|2 \|2  \|5  |2 |--------------
+--R                          |  |        +-+
+--R                         \| \|   3200\|5
+--R         *
+--R            log
+--R                                        +------------------+
+--R                                        |  +--------------+
+--R                                        |  |    +-+
+--R                     +-+ +-+       +-+  |  |843\|5  + 1885
+--R                 (7x\|2 \|5  - 15x\|2 ) |2 |--------------
+--R                                        |  |        +-+
+--R                                       \| \|   3200\|5
+--R               + 
+--R                                   +--------------+
+--R                                   |    +-+
+--R                        +-+        |843\|5  + 1885     2
+--R                 (- 420\|5  + 940) |--------------  + x
+--R                                   |        +-+
+--R                                  \|   3200\|5
+--R     + 
+--R                       +------------------+
+--R                       |  +--------------+
+--R                       |  |    +-+
+--R          +-+4+-+3 +-+ |  |843\|5  - 1885
+--R         \|2 \|2  \|5  |2 |--------------
+--R                       |  |        +-+
+--R                      \| \|   3200\|5
+--R      *
+--R         log
+--R                                     +------------------+
+--R                                     |  +--------------+
+--R                                     |  |    +-+
+--R                  +-+ +-+       +-+  |  |843\|5  - 1885
+--R              (7x\|2 \|5  + 15x\|2 ) |2 |--------------
+--R                                     |  |        +-+
+--R                                    \| \|   3200\|5
+--R            + 
+--R                              +--------------+
+--R                              |    +-+
+--R                   +-+        |843\|5  - 1885     2
+--R              (420\|5  + 940) |--------------  + x
+--R                              |        +-+
+--R                             \|   3200\|5
+--R     + 
+--R                       +--------------------+
+--R                       |    +--------------+
+--R                       |    |    +-+
+--R          +-+4+-+3 +-+ |    |843\|5  - 1885
+--R         \|2 \|2  \|5  |- 2 |--------------
+--R                       |    |        +-+
+--R                      \|   \|   3200\|5
+--R      *
+--R         log
+--R                                     +--------------------+
+--R                                     |    +--------------+
+--R                                     |    |    +-+
+--R                  +-+ +-+       +-+  |    |843\|5  - 1885
+--R              (7x\|2 \|5  + 15x\|2 ) |- 2 |--------------
+--R                                     |    |        +-+
+--R                                    \|   \|   3200\|5
+--R            + 
+--R                                +--------------+
+--R                                |    +-+
+--R                     +-+        |843\|5  - 1885     2
+--R              (- 420\|5  - 940) |--------------  + x
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R       -
+--R                          +--------------------+
+--R                          |    +--------------+
+--R                          |    |    +-+
+--R             +-+4+-+3 +-+ |    |843\|5  + 1885
+--R            \|2 \|2  \|5  |- 2 |--------------
+--R                          |    |        +-+
+--R                         \|   \|   3200\|5
+--R         *
+--R            log
+--R                                        +--------------------+
+--R                                        |    +--------------+
+--R                                        |    |    +-+
+--R                     +-+ +-+       +-+  |    |843\|5  + 1885
+--R                 (7x\|2 \|5  - 15x\|2 ) |- 2 |--------------
+--R                                        |    |        +-+
+--R                                       \|   \|   3200\|5
+--R               + 
+--R                                 +--------------+
+--R                                 |    +-+
+--R                      +-+        |843\|5  + 1885     2
+--R                 (420\|5  - 940) |--------------  + x
+--R                                 |        +-+
+--R                                \|   3200\|5
+--R     + 
+--R                       +--------------------+
+--R                       |    +--------------+
+--R                       |    |    +-+
+--R          +-+4+-+3 +-+ |    |843\|5  + 1885
+--R         \|2 \|2  \|5  |- 2 |--------------
+--R                       |    |        +-+
+--R                      \|   \|   3200\|5
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |    +--------------+
+--R                                       |    |    +-+
+--R                    +-+ +-+       +-+  |    |843\|5  + 1885
+--R              (- 7x\|2 \|5  + 15x\|2 ) |- 2 |--------------
+--R                                       |    |        +-+
+--R                                      \|   \|   3200\|5
+--R            + 
+--R                              +--------------+
+--R                              |    +-+
+--R                   +-+        |843\|5  + 1885     2
+--R              (420\|5  - 940) |--------------  + x
+--R                              |        +-+
+--R                             \|   3200\|5
+--R     + 
+--R       -
+--R                          +--------------------+
+--R                          |    +--------------+
+--R                          |    |    +-+
+--R             +-+4+-+3 +-+ |    |843\|5  - 1885
+--R            \|2 \|2  \|5  |- 2 |--------------
+--R                          |    |        +-+
+--R                         \|   \|   3200\|5
+--R         *
+--R            log
+--R                                          +--------------------+
+--R                                          |    +--------------+
+--R                                          |    |    +-+
+--R                       +-+ +-+       +-+  |    |843\|5  - 1885
+--R                 (- 7x\|2 \|5  - 15x\|2 ) |- 2 |--------------
+--R                                          |    |        +-+
+--R                                         \|   \|   3200\|5
+--R               + 
+--R                                   +--------------+
+--R                                   |    +-+
+--R                        +-+        |843\|5  - 1885     2
+--R                 (- 420\|5  - 940) |--------------  + x
+--R                                   |        +-+
+--R                                  \|   3200\|5
+--R     + 
+--R       -
+--R                          +------------------+
+--R                          |  +--------------+
+--R                          |  |    +-+
+--R             +-+4+-+3 +-+ |  |843\|5  - 1885
+--R            \|2 \|2  \|5  |2 |--------------
+--R                          |  |        +-+
+--R                         \| \|   3200\|5
+--R         *
+--R            log
+--R                                          +------------------+
+--R                                          |  +--------------+
+--R                                          |  |    +-+
+--R                       +-+ +-+       +-+  |  |843\|5  - 1885
+--R                 (- 7x\|2 \|5  - 15x\|2 ) |2 |--------------
+--R                                          |  |        +-+
+--R                                         \| \|   3200\|5
+--R               + 
+--R                                 +--------------+
+--R                                 |    +-+
+--R                      +-+        |843\|5  - 1885     2
+--R                 (420\|5  + 940) |--------------  + x
+--R                                 |        +-+
+--R                                \|   3200\|5
+--R     + 
+--R                       +------------------+
+--R                       |  +--------------+
+--R                       |  |    +-+
+--R          +-+4+-+3 +-+ |  |843\|5  + 1885
+--R         \|2 \|2  \|5  |2 |--------------
+--R                       |  |        +-+
+--R                      \| \|   3200\|5
+--R      *
+--R         log
+--R                                       +------------------+
+--R                                       |  +--------------+
+--R                                       |  |    +-+
+--R                    +-+ +-+       +-+  |  |843\|5  + 1885
+--R              (- 7x\|2 \|5  + 15x\|2 ) |2 |--------------
+--R                                       |  |        +-+
+--R                                      \| \|   3200\|5
+--R            + 
+--R                                +--------------+
+--R                                |    +-+
+--R                     +-+        |843\|5  + 1885     2
+--R              (- 420\|5  + 940) |--------------  + x
+--R                                |        +-+
+--R                               \|   3200\|5
+--R     + 
+--R                        +--------------------+
+--R                        |    +--------------+
+--R                        |    |    +-+
+--R           +-+4+-+3 +-+ |    |843\|5  + 1885
+--R         2\|2 \|2  \|5  |- 2 |--------------
+--R                        |    |        +-+
+--R                       \|   \|   3200\|5
+--R      *
+--R                                         +--------------------+
+--R                                         |    +--------------+
+--R                                         |    |    +-+
+--R                       +-+ +-+      +-+  |    |843\|5  + 1885
+--R                   (15\|2 \|5  - 35\|2 ) |- 2 |--------------
+--R                                         |    |        +-+
+--R                                        \|   \|   3200\|5
+--R         atan(-----------------------------------------------------)
+--R                                    +--------------------+
+--R                                    |    +--------------+
+--R                                    |    |    +-+
+--R                  +-+ +-+      +-+  |    |843\|5  + 1885        +-+
+--R              (15\|2 \|5  - 35\|2 ) |- 2 |--------------   - 2x\|5
+--R                                    |    |        +-+
+--R                                   \|   \|   3200\|5
+--R     + 
+--R                        +--------------------+
+--R                        |    +--------------+
+--R                        |    |    +-+
+--R           +-+4+-+3 +-+ |    |843\|5  - 1885
+--R         2\|2 \|2  \|5  |- 2 |--------------
+--R                        |    |        +-+
+--R                       \|   \|   3200\|5
+--R      *
+--R                                         +--------------------+
+--R                                         |    +--------------+
+--R                                         |    |    +-+
+--R                       +-+ +-+      +-+  |    |843\|5  - 1885
+--R                   (15\|2 \|5  + 35\|2 ) |- 2 |--------------
+--R                                         |    |        +-+
+--R                                        \|   \|   3200\|5
+--R         atan(-----------------------------------------------------)
+--R                                    +--------------------+
+--R                                    |    +--------------+
+--R                                    |    |    +-+
+--R                  +-+ +-+      +-+  |    |843\|5  - 1885        +-+
+--R              (15\|2 \|5  + 35\|2 ) |- 2 |--------------   - 2x\|5
+--R                                    |    |        +-+
+--R                                   \|   \|   3200\|5
+--R     + 
+--R                        +------------------+
+--R                        |  +--------------+
+--R                        |  |    +-+
+--R           +-+4+-+3 +-+ |  |843\|5  - 1885
+--R         2\|2 \|2  \|5  |2 |--------------
+--R                        |  |        +-+
+--R                       \| \|   3200\|5
+--R      *
+--R                                         +------------------+
+--R                                         |  +--------------+
+--R                                         |  |    +-+
+--R                       +-+ +-+      +-+  |  |843\|5  - 1885
+--R                   (15\|2 \|5  + 35\|2 ) |2 |--------------
+--R                                         |  |        +-+
+--R                                        \| \|   3200\|5
+--R         atan(---------------------------------------------------)
+--R                                    +------------------+
+--R                                    |  +--------------+
+--R                                    |  |    +-+
+--R                  +-+ +-+      +-+  |  |843\|5  - 1885        +-+
+--R              (15\|2 \|5  + 35\|2 ) |2 |--------------   - 2x\|5
+--R                                    |  |        +-+
+--R                                   \| \|   3200\|5
+--R     + 
+--R                        +------------------+
+--R                        |  +--------------+
+--R                        |  |    +-+
+--R           +-+4+-+3 +-+ |  |843\|5  + 1885
+--R         2\|2 \|2  \|5  |2 |--------------
+--R                        |  |        +-+
+--R                       \| \|   3200\|5
+--R      *
+--R                                         +------------------+
+--R                                         |  +--------------+
+--R                                         |  |    +-+
+--R                       +-+ +-+      +-+  |  |843\|5  + 1885
+--R                   (15\|2 \|5  - 35\|2 ) |2 |--------------
+--R                                         |  |        +-+
+--R                                        \| \|   3200\|5
+--R         atan(---------------------------------------------------)
+--R                                    +------------------+
+--R                                    |  +--------------+
+--R                                    |  |    +-+
+--R                  +-+ +-+      +-+  |  |843\|5  + 1885        +-+
+--R              (15\|2 \|5  - 35\|2 ) |2 |--------------   - 2x\|5
+--R                                    |  |        +-+
+--R                                   \| \|   3200\|5
+--R     + 
+--R       -
+--R                           +------------------+
+--R                           |  +--------------+
+--R                           |  |    +-+
+--R              +-+4+-+3 +-+ |  |843\|5  + 1885
+--R            2\|2 \|2  \|5  |2 |--------------
+--R                           |  |        +-+
+--R                          \| \|   3200\|5
+--R         *
+--R                                            +------------------+
+--R                                            |  +--------------+
+--R                                            |  |    +-+
+--R                          +-+ +-+      +-+  |  |843\|5  + 1885
+--R                      (15\|2 \|5  - 35\|2 ) |2 |--------------
+--R                                            |  |        +-+
+--R                                           \| \|   3200\|5
+--R            atan(---------------------------------------------------)
+--R                                       +------------------+
+--R                                       |  +--------------+
+--R                                       |  |    +-+
+--R                     +-+ +-+      +-+  |  |843\|5  + 1885        +-+
+--R                 (15\|2 \|5  - 35\|2 ) |2 |--------------   + 2x\|5
+--R                                       |  |        +-+
+--R                                      \| \|   3200\|5
+--R     + 
+--R       -
+--R                           +------------------+
+--R                           |  +--------------+
+--R                           |  |    +-+
+--R              +-+4+-+3 +-+ |  |843\|5  - 1885
+--R            2\|2 \|2  \|5  |2 |--------------
+--R                           |  |        +-+
+--R                          \| \|   3200\|5
+--R         *
+--R                                            +------------------+
+--R                                            |  +--------------+
+--R                                            |  |    +-+
+--R                          +-+ +-+      +-+  |  |843\|5  - 1885
+--R                      (15\|2 \|5  + 35\|2 ) |2 |--------------
+--R                                            |  |        +-+
+--R                                           \| \|   3200\|5
+--R            atan(---------------------------------------------------)
+--R                                       +------------------+
+--R                                       |  +--------------+
+--R                                       |  |    +-+
+--R                     +-+ +-+      +-+  |  |843\|5  - 1885        +-+
+--R                 (15\|2 \|5  + 35\|2 ) |2 |--------------   + 2x\|5
+--R                                       |  |        +-+
+--R                                      \| \|   3200\|5
+--R     + 
+--R       -
+--R                           +--------------------+
+--R                           |    +--------------+
+--R                           |    |    +-+
+--R              +-+4+-+3 +-+ |    |843\|5  - 1885
+--R            2\|2 \|2  \|5  |- 2 |--------------
+--R                           |    |        +-+
+--R                          \|   \|   3200\|5
+--R         *
+--R                                            +--------------------+
+--R                                            |    +--------------+
+--R                                            |    |    +-+
+--R                          +-+ +-+      +-+  |    |843\|5  - 1885
+--R                      (15\|2 \|5  + 35\|2 ) |- 2 |--------------
+--R                                            |    |        +-+
+--R                                           \|   \|   3200\|5
+--R            atan(-----------------------------------------------------)
+--R                                       +--------------------+
+--R                                       |    +--------------+
+--R                                       |    |    +-+
+--R                     +-+ +-+      +-+  |    |843\|5  - 1885        +-+
+--R                 (15\|2 \|5  + 35\|2 ) |- 2 |--------------   + 2x\|5
+--R                                       |    |        +-+
+--R                                      \|   \|   3200\|5
+--R     + 
+--R       -
+--R                           +--------------------+
+--R                           |    +--------------+
+--R                           |    |    +-+
+--R              +-+4+-+3 +-+ |    |843\|5  + 1885
+--R            2\|2 \|2  \|5  |- 2 |--------------
+--R                           |    |        +-+
+--R                          \|   \|   3200\|5
+--R         *
+--R                                            +--------------------+
+--R                                            |    +--------------+
+--R                                            |    |    +-+
+--R                          +-+ +-+      +-+  |    |843\|5  + 1885
+--R                      (15\|2 \|5  - 35\|2 ) |- 2 |--------------
+--R                                            |    |        +-+
+--R                                           \|   \|   3200\|5
+--R            atan(-----------------------------------------------------)
+--R                                       +--------------------+
+--R                                       |    +--------------+
+--R                                       |    |    +-+
+--R                     +-+ +-+      +-+  |    |843\|5  + 1885        +-+
+--R                 (15\|2 \|5  - 35\|2 ) |- 2 |--------------   + 2x\|5
+--R                                       |    |        +-+
+--R                                      \|   \|   3200\|5
+--R     + 
+--R           +---------------+     +---------+          +--------+
+--R          4|      +-+            |  +-+          4+-+4| +-+          2
+--R       - 2\|- 377\|5  + 843 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R         +---------------+     +---------+          +--------+
+--R        4|      +-+            |  +-+          4+-+4| +-+          2
+--R       2\|- 377\|5  + 843 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R         +-------------+           +----------+    +-----------+
+--R        4|    +-+             4+-+4|   +-+         |    +-+          2
+--R       2\|377\|5  + 843 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R           +-------------+             +----------+    +-----------+
+--R          4|    +-+               4+-+4|   +-+         |    +-+          2
+--R       - 2\|377\|5  + 843 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                        +--------+3
+--R         +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       4\|- 377\|5  + 843 atan(----------------------------------------)
+--R                                                   4
+--R     + 
+--R                                                        +--------+3
+--R         +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       4\|- 377\|5  + 843 atan(----------------------------------------)
+--R                                                   4
+--R     + 
+--R                                                      +----------+3
+--R         +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       4\|377\|5  + 843 atan(------------------------------------------)
+--R                                                  4
+--R     + 
+--R                                                      +----------+3
+--R         +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       4\|377\|5  + 843 atan(------------------------------------------)
+--R                                                  4
+--R  /
+--R      4+-+3 +-+
+--R     8\|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 1507
+
+--S 1508 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                                       +-----------+
+--R                         8     4 4+-+2 +-+     4 4+-+2 |    +-+
+--R                   ((- 2x  - 3x )\|2  \|5  - 5x  \|2 )\|- 2\|5  + 6
+--R                 + 
+--R                      10     2 4+-+2 +-+      6 4+-+2
+--R                   (2x   - 2x )\|2  \|5  + 10x  \|2
+--R              *
+--R                  +----------+3
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                      +-----------+
+--R                         10      6     2  +-+      6  |    +-+
+--R                   ((- 6x   - 12x  - 2x )\|5  - 10x )\|- 2\|5  + 6
+--R                 + 
+--R                       8     4  +-+      8
+--R                   (12x  + 8x )\|5  - 20x
+--R              *
+--R                  +----------+
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|5  + 6
+--R         + 
+--R                                            +-----------+
+--R                       8     4  +-+      4  |    +-+             10     2  +-+
+--R                   ((4x  + 6x )\|5  + 10x )\|- 2\|5  + 6  + (- 4x   + 4x )\|5
+--R                 + 
+--R                        6
+--R                   - 20x
+--R              *
+--R                  +----------+3
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                              +-----------+
+--R                       10      6     2 4+-+2 +-+      6 4+-+2 |    +-+
+--R                   ((6x   + 12x  + 2x )\|2  \|5  + 10x  \|2 )\|- 2\|5  + 6
+--R                 + 
+--R                         8     4 4+-+2 +-+      8 4+-+2
+--R                   (- 12x  - 8x )\|2  \|5  + 20x  \|2
+--R              *
+--R                  +----------+
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                       10     6     2 4+-+2 +-+         6      2 4+-+2
+--R                 ((- 2x   - 6x  - 7x )\|2  \|5  + (- 10x  - 15x )\|2  )
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                  12     8     4     4+-+2 +-+       8      4     4+-+2
+--R               (2x   + 3x  + 3x  - 3)\|2  \|5  + (15x  + 15x  - 5)\|2
+--R          *
+--R              +----------+3
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                                                  +-----------+
+--R                     12      8      4      +-+      8      4      |    +-+
+--R               ((- 6x   - 21x  - 25x  - 3)\|5  - 25x  - 45x  - 5)\|- 2\|5  + 6
+--R             + 
+--R                   10      6      2  +-+      10      2
+--R               (12x   + 16x  + 12x )\|5  - 20x   + 20x
+--R          *
+--R              +----------+
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R      *
+--R          +-------------+
+--R         4|    +-+
+--R         \|377\|5  + 843
+--R     + 
+--R                                          +---------------+ +----------+2
+--R                     8     4  +-+      4 4|      +-+       4|   +-+
+--R               ((- 4x  - 6x )\|5  + 10x )\|- 377\|5  + 843 \|- \|5  + 3
+--R             + 
+--R                                                 +---------------+ +-----------+
+--R                   8     4 4+-+2 +-+     4 4+-+24|      +-+        |    +-+
+--R               ((2x  + 3x )\|2  \|5  - 5x  \|2 )\|- 377\|5  + 843 \|- 2\|5  + 6
+--R             + 
+--R                     10     6     2 4+-+2 +-+         6      2 4+-+2
+--R                 ((2x   + 6x  + 7x )\|2  \|5  + (- 10x  - 15x )\|2  )
+--R              *
+--R                  +---------------+
+--R                 4|      +-+
+--R                 \|- 377\|5  + 843
+--R          *
+--R              +--------+3
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                                              +---------------+
+--R                       10      6     2 4+-+2 +-+      6 4+-+24|      +-+
+--R                 ((- 6x   - 12x  - 2x )\|2  \|5  + 10x  \|2 )\|- 377\|5  + 843
+--R              *
+--R                  +----------+2
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                +---------------+ +-----------+
+--R                   10      6     2  +-+      6 4|      +-+        |    +-+
+--R               ((6x   + 12x  + 2x )\|5  - 10x )\|- 377\|5  + 843 \|- 2\|5  + 6
+--R             + 
+--R                                                              +---------------+
+--R                 12      8      4      +-+      8      4     4|      +-+
+--R             ((6x   + 21x  + 25x  + 3)\|5  - 25x  - 45x  - 5)\|- 377\|5  + 843
+--R          *
+--R              +--------+
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                            +----------+2                       +-----------+
+--R                 8       4 4|   +-+             8       4 4+-+2 |    +-+
+--R           (- 80x  - 240x )\|- \|5  + 3   + (40x  + 120x )\|2  \|- 2\|5  + 6
+--R         + 
+--R                 6      2 4+-+2 +-+       10       6       2 4+-+2
+--R           (- 20x  - 60x )\|2  \|5  + (40x   + 180x  + 180x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                     +---------------+ +----------+2
+--R               10     2  +-+      6 4|      +-+       4|   +-+
+--R           ((4x   - 4x )\|5  - 20x )\|- 377\|5  + 843 \|- \|5  + 3
+--R         + 
+--R                                                 +---------------+ +-----------+
+--R                 10     2 4+-+2 +-+      6 4+-+24|      +-+        |    +-+
+--R           ((- 2x   + 2x )\|2  \|5  + 10x  \|2 )\|- 377\|5  + 843 \|- 2\|5  + 6
+--R         + 
+--R                   12     8     4     4+-+2 +-+       8      4     4+-+2
+--R             ((- 2x   - 3x  - 3x  + 3)\|2  \|5  + (15x  + 15x  - 5)\|2  )
+--R          *
+--R              +---------------+
+--R             4|      +-+
+--R             \|- 377\|5  + 843
+--R      *
+--R          +--------+3
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                +----------+2                   +-----------+
+--R               8       4 4+-+2 4|   +-+              8       4  |    +-+
+--R           (80x  + 240x )\|2   \|- \|5  + 3  + (- 80x  - 240x )\|- 2\|5  + 6
+--R         + 
+--R               6       2  +-+      10       6       2
+--R           (40x  + 120x )\|5  - 80x   - 360x  - 360x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                               +---------------+ +----------+2
+--R                8     4 4+-+2 +-+      8 4+-+24|      +-+       4|   +-+
+--R           ((12x  + 8x )\|2  \|5  + 20x  \|2 )\|- 377\|5  + 843 \|- \|5  + 3
+--R         + 
+--R                                       +---------------+ +-----------+
+--R                  8     4  +-+      8 4|      +-+        |    +-+
+--R           ((- 12x  - 8x )\|5  - 20x )\|- 377\|5  + 843 \|- 2\|5  + 6
+--R         + 
+--R                                                        +---------------+
+--R                  10      6      2  +-+      10      2 4|      +-+
+--R           ((- 12x   - 16x  - 12x )\|5  - 20x   + 20x )\|- 377\|5  + 843
+--R      *
+--R          +--------+
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                      +----------+2
+--R              6       2  +-+      10       6       2 4|   +-+
+--R       ((- 40x  - 120x )\|5  - 80x   - 360x  - 360x )\|- \|5  + 3
+--R     + 
+--R                                                               +-----------+
+--R            6      2 4+-+2 +-+       10       6       2 4+-+2  |    +-+
+--R       ((20x  + 60x )\|2  \|5  + (40x   + 180x  + 180x )\|2  )\|- 2\|5  + 6
+--R     + 
+--R           12       8       4       4+-+2
+--R       (40x   + 240x  + 400x  + 120)\|2
+--R  /
+--R                                  +----------+2
+--R               12       8      4 4|   +-+
+--R           (80x   + 240x  + 80x )\|- \|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                 12       8      4 4+-+2 |    +-+
+--R           (- 40x   - 120x  - 40x )\|2  \|- 2\|5  + 6
+--R         + 
+--R             10      6      2 4+-+2 +-+         14       10       6      2 4+-+2
+--R         (20x   + 60x  + 20x )\|2  \|5  + (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                          +----------+2
+--R                 12       8      4 4+-+2 4|   +-+
+--R           (- 80x   - 240x  - 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                  +-----------+
+--R               12       8      4  |    +-+              10       6      2  +-+
+--R           (80x   + 240x  + 80x )\|- 2\|5  + 6  + (- 40x   - 120x  - 40x )\|5
+--R         + 
+--R              14       10       6       2
+--R           80x   + 360x   + 440x  + 120x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R              10       6      2  +-+      14       10       6       2
+--R         ((40x   + 120x  + 40x )\|5  + 80x   + 360x   + 440x  + 120x )
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                 10      6      2 4+-+2 +-+
+--R           (- 20x   - 60x  - 20x )\|2  \|5
+--R         + 
+--R                 14       10       6      2 4+-+2
+--R           (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R             16       12       8       4      4+-+2
+--R       (- 40x   - 240x   - 440x  - 240x  - 40)\|2
+--R                                                    Type: Expression(Integer)
+--E 1508
+
+)clear all
+
+--S 1509 of 2282
+t0:=x^m/(1-3*x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1509
+
+--S 1510 of 2282
+--r0:=2*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),2*x^4/(3-sqrt(5)))/_
+--   ((1+m)*(3-sqrt(5))*sqrt(5))-2*x^(1+m)*hypergeometric(1,1/4*(1+m),_
+--   1/4*(5+m),2*x^4/(3+sqrt(5)))/((1+m)*sqrt(5)*(3+sqrt(5)))
+--E 1510
+
+--S 1511 of 2282
+--a0:=integrate(t0,x)
+--E 1511
+
+--S 1512 of 2282
+--m0:=a0-r0
+--E 1512
+
+--S 1513 of 2282
+--d0:=normalize(D(m0,x))
+--E 1513
+
+)clear all
+
+--S 1514 of 2282
+t0:=x^11/(1-3*x^4+x^8)
+--R 
+--R
+--R              11
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1514
+
+--S 1515 of 2282
+r0:=1/4*x^4+1/40*log(3-2*x^4-sqrt(5))*(15-7*sqrt(5))+_
+   1/40*log(3-2*x^4+sqrt(5))*(15+7*sqrt(5))
+--R 
+--R
+--R   (2)
+--R      +-+           +-+     4             +-+             +-+     4           4
+--R   (7\|5  + 15)log(\|5  - 2x  + 3) + (- 7\|5  + 15)log(- \|5  - 2x  + 3) + 10x
+--R   ----------------------------------------------------------------------------
+--R                                        40
+--R                                                    Type: Expression(Integer)
+--E 1515
+
+--S 1516 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           8     4      +-+      4
+--R        (2x  - 6x  + 7)\|5  - 10x  + 15      +-+     8     4          4 +-+
+--R   7log(-------------------------------) + 3\|5 log(x  - 3x  + 1) + 2x \|5
+--R                   8     4
+--R                  x  - 3x  + 1
+--R   ------------------------------------------------------------------------
+--R                                       +-+
+--R                                     8\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1516
+
+--S 1517 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               8     4      +-+      4
+--R            (2x  - 6x  + 7)\|5  - 10x  + 15         +-+          +-+     4
+--R       7log(-------------------------------) + (- 3\|5  - 7)log(\|5  - 2x  + 3)
+--R                       8     4
+--R                      x  - 3x  + 1
+--R     + 
+--R         +-+     8     4             +-+            +-+     4
+--R       3\|5 log(x  - 3x  + 1) + (- 3\|5  + 7)log(- \|5  - 2x  + 3)
+--R  /
+--R       +-+
+--R     8\|5
+--R                                                    Type: Expression(Integer)
+--E 1517
+
+--S 1518 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1518
+
+)clear all
+
+--S 1519 of 2282
+t0:=x^9/(1-3*x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1519
+
+--S 1520 of 2282
+r0:=1/2*x^2+1/2*atanh(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/5*(9-4*sqrt(5)))-_
+   1/2*atanh(x^2*sqrt(2/(3+sqrt(5))))*sqrt(1/5*(9+4*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                              +--------+                         +----------+
+--R        +-----------+       2 | +-+          +---------+       2 |   +-+
+--R        |    +-+           x \|\|5  + 3      |  +-+           x \|- \|5  + 3
+--R       \|- 4\|5  + 9 atanh(-------------) - \|4\|5  + 9 atanh(---------------)
+--R                                 +-+                                 +-+
+--R                                \|2                                 \|2
+--R     + 
+--R        2 +-+
+--R       x \|5
+--R  /
+--R       +-+
+--R     2\|5
+--R                                                    Type: Expression(Integer)
+--E 1520
+
+--S 1521 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4     2      +-+      2
+--R            (2x  - 2x  + 3)\|5  - 10x  + 5
+--R       2log(------------------------------)
+--R                       4    2
+--R                      x  - x  - 1
+--R     + 
+--R               4     2      +-+      2
+--R            (2x  + 2x  + 3)\|5  - 10x  - 5     +-+     4    2
+--R       2log(------------------------------) - \|5 log(x  + x  - 1)
+--R                       4    2
+--R                      x  + x  - 1
+--R     + 
+--R        +-+     4    2          2 +-+
+--R       \|5 log(x  - x  - 1) + 2x \|5
+--R  /
+--R       +-+
+--R     4\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1521
+
+--S 1522 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------+
+--R           +-----------+       2 | +-+
+--R           |    +-+           x \|\|5  + 3
+--R       - 2\|- 4\|5  + 9 atanh(-------------)
+--R                                    +-+
+--R                                   \|2
+--R     + 
+--R                             +----------+
+--R         +---------+       2 |   +-+
+--R         |  +-+           x \|- \|5  + 3
+--R       2\|4\|5  + 9 atanh(---------------)
+--R                                 +-+
+--R                                \|2
+--R     + 
+--R               4     2      +-+      2
+--R            (2x  - 2x  + 3)\|5  - 10x  + 5
+--R       2log(------------------------------)
+--R                       4    2
+--R                      x  - x  - 1
+--R     + 
+--R               4     2      +-+      2
+--R            (2x  + 2x  + 3)\|5  - 10x  - 5     +-+     4    2
+--R       2log(------------------------------) - \|5 log(x  + x  - 1)
+--R                       4    2
+--R                      x  + x  - 1
+--R     + 
+--R        +-+     4    2
+--R       \|5 log(x  - x  - 1)
+--R  /
+--R       +-+
+--R     4\|5
+--R                                                    Type: Expression(Integer)
+--E 1522
+
+--S 1523 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R              13      11      9      7      5       +-+ +-+
+--R           (3x   - 10x   + 19x  - 10x  - 11x  - 2x)\|2 \|5
+--R         + 
+--R              13      11      9      7     5      3  +-+
+--R           (5x   - 30x   + 35x  - 10x  + 5x  + 20x )\|2
+--R      *
+--R          +----------+ +---------+
+--R          |   +-+      |  +-+
+--R         \|- \|5  + 3 \|4\|5  + 9
+--R     + 
+--R                13      11      9      7      5       +-+ +-+
+--R           (- 3x   - 10x   - 19x  - 10x  + 11x  + 2x)\|2 \|5
+--R         + 
+--R              13      11      9      7     5      3  +-+
+--R           (5x   + 30x   + 35x  + 10x  + 5x  - 20x )\|2
+--R      *
+--R          +-----------+ +--------+
+--R          |    +-+      | +-+
+--R         \|- 4\|5  + 9 \|\|5  + 3
+--R     + 
+--R            11      7      3  +-+      13       9      5
+--R       (120x   + 80x  - 40x )\|5  - 60x   - 400x  + 80x  + 20x
+--R  /
+--R         14      10      6      2  +-+      16      12       8      4
+--R     (40x   - 80x   - 80x  + 40x )\|5  - 20x   - 80x   + 380x  - 80x  - 20
+--R                                                    Type: Expression(Integer)
+--E 1523
+
+)clear all
+
+--S 1524 of 2282
+t0:=x^7/(1-3*x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1524
+
+--S 1525 of 2282
+r0:=1/40*log(3-2*x^4-sqrt(5))*(5-3*sqrt(5))+_
+   1/40*log(3-2*x^4+sqrt(5))*(5+3*sqrt(5))
+--R 
+--R
+--R           +-+          +-+     4             +-+            +-+     4
+--R        (3\|5  + 5)log(\|5  - 2x  + 3) + (- 3\|5  + 5)log(- \|5  - 2x  + 3)
+--R   (2)  -------------------------------------------------------------------
+--R                                         40
+--R                                                    Type: Expression(Integer)
+--E 1525
+
+--S 1526 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                8     4      +-+      4
+--R             (2x  - 6x  + 7)\|5  - 10x  + 15     +-+     8     4
+--R        3log(-------------------------------) + \|5 log(x  - 3x  + 1)
+--R                        8     4
+--R                       x  - 3x  + 1
+--R   (3)  -------------------------------------------------------------
+--R                                      +-+
+--R                                    8\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1526
+
+--S 1527 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               8     4      +-+      4
+--R            (2x  - 6x  + 7)\|5  - 10x  + 15        +-+          +-+     4
+--R       3log(-------------------------------) + (- \|5  - 3)log(\|5  - 2x  + 3)
+--R                       8     4
+--R                      x  - 3x  + 1
+--R     + 
+--R        +-+     8     4            +-+            +-+     4
+--R       \|5 log(x  - 3x  + 1) + (- \|5  + 3)log(- \|5  - 2x  + 3)
+--R  /
+--R       +-+
+--R     8\|5
+--R                                                    Type: Expression(Integer)
+--E 1527
+
+--S 1528 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1528
+
+)clear all
+
+--S 1529 of 2282
+t0:=x^5/(1-3*x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1529
+
+--S 1530 of 2282
+r0:=1/2*atanh(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/10*(3-sqrt(5)))-_
+   1/2*atanh(x^2*sqrt(2/(3+sqrt(5))))*sqrt(1/10*(3+sqrt(5)))
+--R 
+--R
+--R                              +--------+                        +----------+
+--R         +----------+       2 | +-+          +--------+       2 |   +-+
+--R         |   +-+           x \|\|5  + 3      | +-+           x \|- \|5  + 3
+--R        \|- \|5  + 3 atanh(-------------) - \|\|5  + 3 atanh(---------------)
+--R                                 +-+                                +-+
+--R                                \|2                                \|2
+--R   (2)  ---------------------------------------------------------------------
+--R                                          +--+
+--R                                        2\|10
+--R                                                    Type: Expression(Integer)
+--E 1530
+
+--S 1531 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              4     2      +-+      2               4     2      +-+      2
+--R           (2x  - 2x  + 3)\|5  - 10x  + 5        (2x  + 2x  + 3)\|5  - 10x  - 5
+--R       log(------------------------------) + log(------------------------------)
+--R                      4    2                                4    2
+--R                     x  - x  - 1                           x  + x  - 1
+--R     + 
+--R          +-+     4    2         +-+     4    2
+--R       - \|5 log(x  + x  - 1) + \|5 log(x  - x  - 1)
+--R  /
+--R       +-+
+--R     8\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1531
+
+--S 1532 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    +--------+
+--R               +----------+       2 | +-+
+--R           +-+ |   +-+           x \|\|5  + 3
+--R       - 4\|5 \|- \|5  + 3 atanh(-------------)
+--R                                       +-+
+--R                                      \|2
+--R     + 
+--R                                +----------+
+--R             +--------+       2 |   +-+
+--R         +-+ | +-+           x \|- \|5  + 3
+--R       4\|5 \|\|5  + 3 atanh(---------------)
+--R                                    +-+
+--R                                   \|2
+--R     + 
+--R                   4     2      +-+      2
+--R        +--+    (2x  - 2x  + 3)\|5  - 10x  + 5
+--R       \|10 log(------------------------------)
+--R                           4    2
+--R                          x  - x  - 1
+--R     + 
+--R                   4     2      +-+      2
+--R        +--+    (2x  + 2x  + 3)\|5  - 10x  - 5     +-+ +--+     4    2
+--R       \|10 log(------------------------------) - \|5 \|10 log(x  + x  - 1)
+--R                           4    2
+--R                          x  + x  - 1
+--R     + 
+--R        +-+ +--+     4    2
+--R       \|5 \|10 log(x  - x  - 1)
+--R  /
+--R       +-+ +--+
+--R     8\|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 1532
+
+--S 1533 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                                                +----------+
+--R            13     9    5  +-+ +-+         11      7  +-+  +--+ |   +-+
+--R         ((x   + 7x  + x )\|2 \|5  + (- 10x   - 10x )\|2 )\|10 \|- \|5  + 3
+--R      *
+--R          +--------+
+--R          | +-+
+--R         \|\|5  + 3
+--R     + 
+--R           11      7  +-+      13       9      5
+--R       (40x   + 40x )\|5  - 20x   - 140x  - 20x
+--R  /
+--R         14      10      6      2  +-+      16      12       8      4
+--R     (40x   - 80x   - 80x  + 40x )\|5  - 20x   - 80x   + 380x  - 80x  - 20
+--R                                                    Type: Expression(Integer)
+--E 1533
+
+)clear all
+
+--S 1534 of 2282
+t0:=x^3/(1-3*x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1534
+
+--S 1535 of 2282
+r0:=1/2*atanh((3-2*x^4)/sqrt(5))/sqrt(5)
+--R 
+--R
+--R                   4      +-+
+--R                (2x  - 3)\|5
+--R          atanh(-------------)
+--R                      5
+--R   (2)  - --------------------
+--R                    +-+
+--R                  2\|5
+--R                                                    Type: Expression(Integer)
+--E 1535
+
+--S 1536 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               8     4      +-+      4
+--R            (2x  - 6x  + 7)\|5  - 10x  + 15
+--R        log(-------------------------------)
+--R                       8     4
+--R                      x  - 3x  + 1
+--R   (3)  ------------------------------------
+--R                          +-+
+--R                        4\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1536
+
+--S 1537 of 2282
+m0:=a0-r0
+--R 
+--R
+--R               8     4      +-+      4                   4      +-+
+--R            (2x  - 6x  + 7)\|5  - 10x  + 15           (2x  - 3)\|5
+--R        log(-------------------------------) + 2atanh(-------------)
+--R                       8     4                              5
+--R                      x  - 3x  + 1
+--R   (4)  ------------------------------------------------------------
+--R                                      +-+
+--R                                    4\|5
+--R                                                    Type: Expression(Integer)
+--E 1537
+
+--S 1538 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1538
+
+)clear all
+
+--S 1539 of 2282
+t0:=x/(1-3*x^4+x^8)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1539
+
+--S 1540 of 2282
+r0:=1/2*atanh(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/10*(3+sqrt(5)))-_
+   atanh(x^2*sqrt(2/(3+sqrt(5))))/sqrt(10*(3+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                     +--------+                   +----------+
+--R    +--------+ +-----------+       2 | +-+                      2 |   +-+
+--R    | +-+      |   +-+            x \|\|5  + 3       +--+      x \|- \|5  + 3
+--R   \|\|5  + 3 \|10\|5  + 30 atanh(-------------) - 2\|10 atanh(---------------)
+--R                                        +-+                           +-+
+--R                                       \|2                           \|2
+--R   ----------------------------------------------------------------------------
+--R                                      +-----------+
+--R                                 +--+ |   +-+
+--R                               2\|10 \|10\|5  + 30
+--R                                                    Type: Expression(Integer)
+--E 1540
+
+--S 1541 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              4     2      +-+      2               4     2      +-+      2
+--R           (2x  - 2x  + 3)\|5  + 10x  - 5        (2x  + 2x  + 3)\|5  + 10x  + 5
+--R       log(------------------------------) + log(------------------------------)
+--R                      4    2                                4    2
+--R                     x  - x  - 1                           x  + x  - 1
+--R     + 
+--R          +-+     4    2         +-+     4    2
+--R       - \|5 log(x  + x  - 1) + \|5 log(x  - x  - 1)
+--R  /
+--R       +-+
+--R     8\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1541
+
+--S 1542 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                +--------+
+--R               +--------+ +-----------+       2 | +-+
+--R           +-+ | +-+      |   +-+            x \|\|5  + 3
+--R       - 4\|5 \|\|5  + 3 \|10\|5  + 30 atanh(-------------)
+--R                                                   +-+
+--R                                                  \|2
+--R     + 
+--R                          +----------+
+--R                        2 |   +-+
+--R         +-+ +--+      x \|- \|5  + 3
+--R       8\|5 \|10 atanh(---------------)
+--R                              +-+
+--R                             \|2
+--R     + 
+--R                       4     2      +-+      2
+--R            +--+    (2x  - 2x  + 3)\|5  + 10x  - 5
+--R           \|10 log(------------------------------)
+--R                               4    2
+--R                              x  - x  - 1
+--R         + 
+--R                       4     2      +-+      2
+--R            +--+    (2x  + 2x  + 3)\|5  + 10x  + 5     +-+ +--+     4    2
+--R           \|10 log(------------------------------) - \|5 \|10 log(x  + x  - 1)
+--R                               4    2
+--R                              x  + x  - 1
+--R         + 
+--R            +-+ +--+     4    2
+--R           \|5 \|10 log(x  - x  - 1)
+--R      *
+--R          +-----------+
+--R          |   +-+
+--R         \|10\|5  + 30
+--R  /
+--R                +-----------+
+--R       +-+ +--+ |   +-+
+--R     8\|5 \|10 \|10\|5  + 30
+--R                                                    Type: Expression(Integer)
+--E 1542
+
+--S 1543 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R               13     11     9     7    5     3  +-+ +-+
+--R           (- x   - 6x   - 7x  - 2x  - x  + 4x )\|2 \|5
+--R         + 
+--R                13      11      9      7      5       +-+
+--R           (- 3x   - 10x   - 19x  - 10x  + 11x  + 2x)\|2
+--R      *
+--R          +----------+ +-----------+
+--R          |   +-+      |   +-+
+--R         \|- \|5  + 3 \|10\|5  + 30
+--R     + 
+--R              13      11     9      7      5      3       +-+ +-+
+--R           (2x   + 12x   + 8x  - 16x  - 40x  - 28x  - 6x)\|2 \|5
+--R         + 
+--R              13      11      9      7      5      3        +-+
+--R           (6x   + 20x   + 28x  - 40x  - 92x  - 60x  - 14x)\|2
+--R      *
+--R          +--+
+--R         \|10
+--R     + 
+--R           9       7       5       3        +-+      9       7       5       3
+--R       (20x  + 120x  + 140x  + 120x  + 20x)\|5  + 60x  + 200x  + 420x  + 200x
+--R     + 
+--R       60x
+--R  /
+--R           16       14      12       10       8       6      4       2       +-+
+--R       (20x   + 120x   + 80x   - 240x   - 380x  - 240x  + 80x  + 120x  + 20)\|5
+--R     + 
+--R          16       14       12       10        8       6       4       2
+--R       60x   + 200x   + 240x   - 400x   - 1140x  - 400x  + 240x  + 200x  + 60
+--R                                                    Type: Expression(Integer)
+--E 1543
+
+)clear all
+
+--S 1544 of 2282
+t0:=1/(x*(1-3*x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         9     5
+--R        x  - 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1544
+
+--S 1545 of 2282
+r0:=log(x)-1/40*log(3-2*x^4+sqrt(5))*(5-3*sqrt(5))-_
+   1/40*log(3-2*x^4-sqrt(5))*(5+3*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          +-+          +-+     4
+--R       (3\|5  - 5)log(\|5  - 2x  + 3) + 40log(x)
+--R     + 
+--R            +-+            +-+     4
+--R       (- 3\|5  - 5)log(- \|5  - 2x  + 3)
+--R  /
+--R     40
+--R                                                    Type: Expression(Integer)
+--E 1545
+
+--S 1546 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           8     4      +-+      4
+--R        (2x  - 6x  + 7)\|5  - 10x  + 15     +-+     8     4          +-+
+--R   3log(-------------------------------) - \|5 log(x  - 3x  + 1) + 8\|5 log(x)
+--R                   8     4
+--R                  x  - 3x  + 1
+--R   ---------------------------------------------------------------------------
+--R                                        +-+
+--R                                      8\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1546
+
+--S 1547 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               8     4      +-+      4
+--R            (2x  - 6x  + 7)\|5  - 10x  + 15      +-+          +-+     4
+--R       3log(-------------------------------) + (\|5  - 3)log(\|5  - 2x  + 3)
+--R                       8     4
+--R                      x  - 3x  + 1
+--R     + 
+--R          +-+     8     4          +-+            +-+     4
+--R       - \|5 log(x  - 3x  + 1) + (\|5  + 3)log(- \|5  - 2x  + 3)
+--R  /
+--R       +-+
+--R     8\|5
+--R                                                    Type: Expression(Integer)
+--E 1547
+
+--S 1548 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1548
+
+)clear all
+
+--S 1549 of 2282
+t0:=1/(x^3*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         11     7    3
+--R        x   - 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1549
+
+--S 1550 of 2282
+r0:=(-1/2)/x^2+1/4*atanh(x^2*sqrt(1/2*(3+sqrt(5))))*_
+   (3+sqrt(5))^(3/2)/sqrt(10)-1/2*atanh(x^2*sqrt(2/(3+sqrt(5))))*_
+   sqrt(1/5*(9-4*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                          +--------+
+--R                       +--------+       2 | +-+
+--R          2 +-+     2  | +-+           x \|\|5  + 3
+--R       (3x \|5  + 5x )\|\|5  + 3 atanh(-------------)
+--R                                             +-+
+--R                                            \|2
+--R     + 
+--R                                        +----------+
+--R                  +-----------+       2 |   +-+
+--R           2 +--+ |    +-+           x \|- \|5  + 3       +-+ +--+
+--R       - 2x \|10 \|- 4\|5  + 9 atanh(---------------) - 2\|5 \|10
+--R                                            +-+
+--R                                           \|2
+--R  /
+--R       2 +-+ +--+
+--R     4x \|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 1550
+
+--S 1551 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 4     2      +-+      2
+--R         2    (2x  - 2x  + 3)\|5  + 10x  - 5
+--R       2x log(------------------------------)
+--R                         4    2
+--R                        x  - x  - 1
+--R     + 
+--R                 4     2      +-+      2
+--R         2    (2x  + 2x  + 3)\|5  + 10x  + 5     2 +-+     4    2
+--R       2x log(------------------------------) - x \|5 log(x  + x  - 1)
+--R                         4    2
+--R                        x  + x  - 1
+--R     + 
+--R        2 +-+     4    2          +-+
+--R       x \|5 log(x  - x  - 1) - 2\|5
+--R  /
+--R       2 +-+
+--R     4x \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1551
+
+--S 1552 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                        +--------+
+--R                     +--------+       2 | +-+
+--R            +-+      | +-+           x \|\|5  + 3
+--R       (- 3\|5  - 5)\|\|5  + 3 atanh(-------------)
+--R                                           +-+
+--R                                          \|2
+--R     + 
+--R                                    +----------+
+--R              +-----------+       2 |   +-+
+--R         +--+ |    +-+           x \|- \|5  + 3
+--R       2\|10 \|- 4\|5  + 9 atanh(---------------)
+--R                                        +-+
+--R                                       \|2
+--R     + 
+--R                    4     2      +-+      2
+--R         +--+    (2x  - 2x  + 3)\|5  + 10x  - 5
+--R       2\|10 log(------------------------------)
+--R                            4    2
+--R                           x  - x  - 1
+--R     + 
+--R                    4     2      +-+      2
+--R         +--+    (2x  + 2x  + 3)\|5  + 10x  + 5     +-+ +--+     4    2
+--R       2\|10 log(------------------------------) - \|5 \|10 log(x  + x  - 1)
+--R                            4    2
+--R                           x  + x  - 1
+--R     + 
+--R        +-+ +--+     4    2
+--R       \|5 \|10 log(x  - x  - 1)
+--R  /
+--R       +-+ +--+
+--R     4\|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 1552
+
+--S 1553 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                13      11      9      7      5       +-+ +-+
+--R           (- 3x   - 10x   - 19x  - 10x  + 11x  + 2x)\|2 \|5
+--R         + 
+--R                13      11      9      7     5      3  +-+
+--R           (- 5x   - 30x   - 35x  - 10x  - 5x  + 20x )\|2
+--R      *
+--R          +-----------+ +----------+
+--R          |    +-+      |   +-+
+--R         \|- 4\|5  + 9 \|- \|5  + 3
+--R     + 
+--R             13     11     9     7      5      3       +-+ +-+
+--R           (x   + 6x   + 4x  - 8x  - 20x  - 14x  - 3x)\|2 \|5
+--R         + 
+--R              13      11      9      7      5      3       +-+
+--R           (3x   + 10x   + 14x  - 20x  - 46x  - 30x  - 7x)\|2
+--R      *
+--R          +--+
+--R         \|10
+--R     + 
+--R             11      7       3  +-+      13      9       5
+--R       (- 40x   + 80x  + 120x )\|5  - 20x   - 80x  + 400x  + 60x
+--R  /
+--R         14      10      6      2  +-+      16      12       8      4
+--R     (40x   - 80x   - 80x  + 40x )\|5  + 20x   + 80x   - 380x  + 80x  + 20
+--R                                                    Type: Expression(Integer)
+--E 1553
+
+)clear all
+
+--S 1554 of 2282
+t0:=1/(x^5*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         13     9    5
+--R        x   - 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1554
+
+--S 1555 of 2282
+r0:=(-1/4)/x^4+3*log(x)-1/40*log(3-2*x^4+sqrt(5))*(15-7*sqrt(5))-_
+   1/40*log(3-2*x^4-sqrt(5))*(15+7*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          4 +-+      4      +-+     4            4
+--R       (7x \|5  - 15x )log(\|5  - 2x  + 3) + 120x log(x)
+--R     + 
+--R            4 +-+      4        +-+     4
+--R       (- 7x \|5  - 15x )log(- \|5  - 2x  + 3) - 10
+--R  /
+--R        4
+--R     40x
+--R                                                    Type: Expression(Integer)
+--E 1555
+
+--S 1556 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 8     4      +-+      4
+--R         4    (2x  - 6x  + 7)\|5  - 10x  + 15      4 +-+     8     4
+--R       7x log(-------------------------------) - 3x \|5 log(x  - 3x  + 1)
+--R                         8     4
+--R                        x  - 3x  + 1
+--R     + 
+--R          4 +-+           +-+
+--R       24x \|5 log(x) - 2\|5
+--R  /
+--R       4 +-+
+--R     8x \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1556
+
+--S 1557 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               8     4      +-+      4
+--R            (2x  - 6x  + 7)\|5  - 10x  + 15       +-+          +-+     4
+--R       7log(-------------------------------) + (3\|5  - 7)log(\|5  - 2x  + 3)
+--R                       8     4
+--R                      x  - 3x  + 1
+--R     + 
+--R           +-+     8     4           +-+            +-+     4
+--R       - 3\|5 log(x  - 3x  + 1) + (3\|5  + 7)log(- \|5  - 2x  + 3)
+--R  /
+--R       +-+
+--R     8\|5
+--R                                                    Type: Expression(Integer)
+--E 1557
+
+--S 1558 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1558
+
+)clear all
+
+--S 1559 of 2282
+t0:=1/(x^7*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         15     11    7
+--R        x   - 3x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1559
+
+--S 1560 of 2282
+r0:=(-1/6)/x^6+(-3/2)/x^2-1/2*atanh(x^2*sqrt(2/(3+sqrt(5))))*_
+   sqrt(1/10*(123-55*sqrt(5)))+1/2*atanh(x^2*sqrt(1/2*(3+sqrt(5))))*_
+   sqrt(1/10*(123+55*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                  +--------+
+--R           +------------+       2 | +-+
+--R         6 |   +-+             x \|\|5  + 3
+--R       3x \|55\|5  + 123 atanh(-------------)
+--R                                     +-+
+--R                                    \|2
+--R     + 
+--R                                      +----------+
+--R             +--------------+       2 |   +-+
+--R           6 |     +-+             x \|- \|5  + 3          4      +--+
+--R       - 3x \|- 55\|5  + 123 atanh(---------------) + (- 9x  - 1)\|10
+--R                                          +-+
+--R                                         \|2
+--R  /
+--R       6 +--+
+--R     6x \|10
+--R                                                    Type: Expression(Integer)
+--E 1560
+
+--S 1561 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  4     2      +-+      2
+--R          6    (2x  - 2x  + 3)\|5  + 10x  - 5
+--R       33x log(------------------------------)
+--R                          4    2
+--R                         x  - x  - 1
+--R     + 
+--R                  4     2      +-+      2
+--R          6    (2x  + 2x  + 3)\|5  + 10x  + 5       6 +-+     4    2
+--R       33x log(------------------------------) - 15x \|5 log(x  + x  - 1)
+--R                          4    2
+--R                         x  + x  - 1
+--R     + 
+--R          6 +-+     4    2              4      +-+
+--R       15x \|5 log(x  - x  - 1) + (- 36x  - 4)\|5
+--R  /
+--R        6 +-+
+--R     24x \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1561
+
+--S 1562 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +--------+
+--R               +------------+       2 | +-+
+--R           +-+ |   +-+             x \|\|5  + 3
+--R       - 4\|5 \|55\|5  + 123 atanh(-------------)
+--R                                         +-+
+--R                                        \|2
+--R     + 
+--R                                      +----------+
+--R             +--------------+       2 |   +-+
+--R         +-+ |     +-+             x \|- \|5  + 3
+--R       4\|5 \|- 55\|5  + 123 atanh(---------------)
+--R                                          +-+
+--R                                         \|2
+--R     + 
+--R                     4     2      +-+      2
+--R          +--+    (2x  - 2x  + 3)\|5  + 10x  - 5
+--R       11\|10 log(------------------------------)
+--R                             4    2
+--R                            x  - x  - 1
+--R     + 
+--R                     4     2      +-+      2
+--R          +--+    (2x  + 2x  + 3)\|5  + 10x  + 5      +-+ +--+     4    2
+--R       11\|10 log(------------------------------) - 5\|5 \|10 log(x  + x  - 1)
+--R                             4    2
+--R                            x  + x  - 1
+--R     + 
+--R         +-+ +--+     4    2
+--R       5\|5 \|10 log(x  - x  - 1)
+--R  /
+--R       +-+ +--+
+--R     8\|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 1562
+
+--S 1563 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R               13     11     9     7    5     3  +-+ +-+
+--R           (- x   + 6x   - 7x  + 2x  - x  - 4x )\|2 \|5
+--R         + 
+--R              13      11      9      7      5       +-+
+--R           (3x   - 10x   + 19x  - 10x  - 11x  - 2x)\|2
+--R      *
+--R               +--------+ +------------+
+--R          +--+ | +-+      |   +-+
+--R         \|10 \|\|5  + 3 \|55\|5  + 123
+--R     + 
+--R               13     11     9     7    5     3  +-+ +-+
+--R           (- x   - 6x   - 7x  - 2x  - x  + 4x )\|2 \|5
+--R         + 
+--R                13      11      9      7      5       +-+
+--R           (- 3x   - 10x   - 19x  - 10x  + 11x  + 2x)\|2
+--R      *
+--R               +--------------+ +----------+
+--R          +--+ |     +-+        |   +-+
+--R         \|10 \|- 55\|5  + 123 \|- \|5  + 3
+--R     + 
+--R              11       7       3  +-+       13       9        5
+--R       (- 240x   + 400x  + 640x )\|5  - 120x   - 520x  + 2120x  + 320x
+--R  /
+--R         14       10       6      2  +-+      16       12       8       4
+--R     (80x   - 160x   - 160x  + 80x )\|5  + 40x   + 160x   - 760x  + 160x  + 40
+--R                                                    Type: Expression(Integer)
+--E 1563
+
+)clear all
+
+--S 1564 of 2282
+t0:=x^8/(1-3*x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1564
+
+--S 1565 of 2282
+r0:=x+1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(123-55*sqrt(5))^(1/4)/_
+   (2^(1/4)*sqrt(5))+1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (123-55*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))-1/2*atan(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(123+55*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))-_
+   1/2*atanh(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*(123+55*sqrt(5))^(1/4)/_
+   (2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                       +--------+
+--R        +--------------+        4+-+3 4| +-+
+--R       4|     +-+             x \|2   \|\|5  + 3
+--R       \|- 55\|5  + 123 atanh(------------------)
+--R                                       2
+--R     + 
+--R                                    +----------+
+--R          +------------+       4+-+4|   +-+
+--R         4|   +-+             x\|2 \|- \|5  + 3
+--R       - \|55\|5  + 123 atanh(------------------)
+--R                                      +-+
+--R                                     \|2
+--R     + 
+--R                                      +--------+
+--R        +--------------+       4+-+3 4| +-+
+--R       4|     +-+            x \|2   \|\|5  + 3
+--R       \|- 55\|5  + 123 atan(------------------)
+--R                                      2
+--R     + 
+--R                                   +----------+
+--R          +------------+      4+-+4|   +-+
+--R         4|   +-+            x\|2 \|- \|5  + 3       4+-+ +-+
+--R       - \|55\|5  + 123 atan(------------------) + 2x\|2 \|5
+--R                                     +-+
+--R                                    \|2
+--R  /
+--R      4+-+ +-+
+--R     2\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 1565
+
+--S 1566 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +----------+                +----------+
+--R          |  +-+             +-+      |  +-+            +--+
+--R       - \|5\|5  + 11 log((3\|5  - 5)\|5\|5  + 11  + 2x\|10 )
+--R     + 
+--R        +----------+                +----------+
+--R        |  +-+             +-+      |  +-+            +--+
+--R       \|5\|5  - 11 log((3\|5  + 5)\|5\|5  - 11  + 2x\|10 )
+--R     + 
+--R          +----------+                  +----------+
+--R          |  +-+               +-+      |  +-+            +--+
+--R       - \|5\|5  - 11 log((- 3\|5  - 5)\|5\|5  - 11  + 2x\|10 )
+--R     + 
+--R        +----------+                  +----------+
+--R        |  +-+               +-+      |  +-+            +--+
+--R       \|5\|5  + 11 log((- 3\|5  + 5)\|5\|5  + 11  + 2x\|10 )
+--R     + 
+--R                                      +----------+
+--R         +----------+        +-+      |  +-+
+--R         |  +-+           (3\|5  - 5)\|5\|5  + 11
+--R       2\|5\|5  + 11 atan(------------------------)
+--R                                      +--+
+--R                                   2x\|10
+--R     + 
+--R                                        +----------+
+--R           +----------+        +-+      |  +-+
+--R           |  +-+           (3\|5  + 5)\|5\|5  - 11        +--+
+--R       - 2\|5\|5  - 11 atan(------------------------) + 4x\|10
+--R                                        +--+
+--R                                     2x\|10
+--R  /
+--R       +--+
+--R     4\|10
+--R                                         Type: Union(Expression(Integer),...)
+--E 1566
+
+--S 1567 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +----------+                +----------+
+--R         4+-+ +-+ |  +-+             +-+      |  +-+            +--+
+--R       - \|2 \|5 \|5\|5  + 11 log((3\|5  - 5)\|5\|5  + 11  + 2x\|10 )
+--R     + 
+--R                +----------+                +----------+
+--R       4+-+ +-+ |  +-+             +-+      |  +-+            +--+
+--R       \|2 \|5 \|5\|5  - 11 log((3\|5  + 5)\|5\|5  - 11  + 2x\|10 )
+--R     + 
+--R                  +----------+                  +----------+
+--R         4+-+ +-+ |  +-+               +-+      |  +-+            +--+
+--R       - \|2 \|5 \|5\|5  - 11 log((- 3\|5  - 5)\|5\|5  - 11  + 2x\|10 )
+--R     + 
+--R                +----------+                  +----------+
+--R       4+-+ +-+ |  +-+               +-+      |  +-+            +--+
+--R       \|2 \|5 \|5\|5  + 11 log((- 3\|5  + 5)\|5\|5  + 11  + 2x\|10 )
+--R     + 
+--R                                               +--------+
+--R                +--------------+        4+-+3 4| +-+
+--R           +--+4|     +-+             x \|2   \|\|5  + 3
+--R       - 2\|10 \|- 55\|5  + 123 atanh(------------------)
+--R                                               2
+--R     + 
+--R                                        +----------+
+--R              +------------+       4+-+4|   +-+
+--R         +--+4|   +-+             x\|2 \|- \|5  + 3
+--R       2\|10 \|55\|5  + 123 atanh(------------------)
+--R                                          +-+
+--R                                         \|2
+--R     + 
+--R                                              +----------+
+--R                 +----------+        +-+      |  +-+
+--R        4+-+ +-+ |  +-+           (3\|5  - 5)\|5\|5  + 11
+--R       2\|2 \|5 \|5\|5  + 11 atan(------------------------)
+--R                                              +--+
+--R                                           2x\|10
+--R     + 
+--R                                                +----------+
+--R                   +----------+        +-+      |  +-+
+--R          4+-+ +-+ |  +-+           (3\|5  + 5)\|5\|5  - 11
+--R       - 2\|2 \|5 \|5\|5  - 11 atan(------------------------)
+--R                                                +--+
+--R                                             2x\|10
+--R     + 
+--R                                              +--------+
+--R                +--------------+       4+-+3 4| +-+
+--R           +--+4|     +-+            x \|2   \|\|5  + 3
+--R       - 2\|10 \|- 55\|5  + 123 atan(------------------)
+--R                                              2
+--R     + 
+--R                                       +----------+
+--R              +------------+      4+-+4|   +-+
+--R         +--+4|   +-+            x\|2 \|- \|5  + 3
+--R       2\|10 \|55\|5  + 123 atan(------------------)
+--R                                         +-+
+--R                                        \|2
+--R  /
+--R      4+-+ +-+ +--+
+--R     4\|2 \|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 1567
+
+--S 1568 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                               +----------+ +------------+
+--R             4      +-+     4 4|   +-+     4|   +-+
+--R       ((- 3x  + 2)\|5  - 5x )\|- \|5  + 3 \|55\|5  + 123
+--R     + 
+--R                             +--------------+ +--------+
+--R           4      +-+     4 4|     +-+       4| +-+            4      4+-+2
+--R       ((3x  - 2)\|5  - 5x )\|- 55\|5  + 123 \|\|5  + 3  + (30x  - 10)\|2
+--R  /
+--R         8      4      4+-+2
+--R     (10x  - 30x  + 10)\|2
+--R                                                    Type: Expression(Integer)
+--E 1568
+
+)clear all
+
+--S 1569 of 2282
+t0:=x^6/(1-3*x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1569
+
+--S 1570 of 2282
+r0:=-1/4*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(144-64*sqrt(5))^(1/4)/sqrt(5)+_
+   1/4*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*(144-64*sqrt(5))^(1/4)/sqrt(5)+_
+   1/2*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*(3+sqrt(5))^(3/4)/_
+   (2^(3/4)*sqrt(5))-1/2*atanh(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (3+sqrt(5))^(3/4)/(2^(3/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                             +--------+
+--R              +--------------+        4+-+3 4| +-+
+--R       4+-+3 4|     +-+             x \|2   \|\|5  + 3
+--R       \|2   \|- 64\|5  + 144 atanh(------------------)
+--R                                             2
+--R     + 
+--R                                  +----------+
+--R           +--------+3       4+-+4|   +-+
+--R          4| +-+            x\|2 \|- \|5  + 3
+--R       - 2\|\|5  + 3  atanh(------------------)
+--R                                    +-+
+--R                                   \|2
+--R     + 
+--R                                              +--------+
+--R                +--------------+       4+-+3 4| +-+
+--R         4+-+3 4|     +-+            x \|2   \|\|5  + 3
+--R       - \|2   \|- 64\|5  + 144 atan(------------------)
+--R                                              2
+--R     + 
+--R                               +----------+
+--R         +--------+3      4+-+4|   +-+
+--R        4| +-+           x\|2 \|- \|5  + 3
+--R       2\|\|5  + 3  atan(------------------)
+--R                                 +-+
+--R                                \|2
+--R  /
+--R      4+-+3 +-+
+--R     4\|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 1570
+
+--S 1571 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +---------+                +---------+
+--R          |  +-+                     |  +-+
+--R          |2\|5  + 5        +-+      |2\|5  + 5      +-+
+--R       -  |--------- log((5\|5  - 5) |---------  + x\|5 )
+--R          |     +-+                  |     +-+
+--R         \|  20\|5                  \|  20\|5
+--R     + 
+--R        +-----------+                +-----------+
+--R        |    +-+                     |    +-+
+--R        |- 2\|5  + 5        +-+      |- 2\|5  + 5      +-+
+--R        |----------- log((5\|5  + 5) |-----------  + x\|5 )
+--R        |      +-+                   |      +-+
+--R       \|   20\|5                   \|   20\|5
+--R     + 
+--R          +-----------+                  +-----------+
+--R          |    +-+                       |    +-+
+--R          |- 2\|5  + 5          +-+      |- 2\|5  + 5      +-+
+--R       -  |----------- log((- 5\|5  - 5) |-----------  + x\|5 )
+--R          |      +-+                     |      +-+
+--R         \|   20\|5                     \|   20\|5
+--R     + 
+--R        +---------+                  +---------+
+--R        |  +-+                       |  +-+
+--R        |2\|5  + 5          +-+      |2\|5  + 5      +-+
+--R        |--------- log((- 5\|5  + 5) |---------  + x\|5 )
+--R        |     +-+                    |     +-+
+--R       \|  20\|5                    \|  20\|5
+--R     + 
+--R                                       +---------+
+--R                                       |  +-+
+--R                              +-+      |2\|5  + 5
+--R           +---------+     (5\|5  - 5) |---------
+--R           |  +-+                      |     +-+
+--R           |2\|5  + 5                 \|  20\|5
+--R       - 2 |--------- atan(-----------------------)
+--R           |     +-+                  +-+
+--R          \|  20\|5                 x\|5
+--R     + 
+--R                                       +-----------+
+--R                                       |    +-+
+--R                              +-+      |- 2\|5  + 5
+--R         +-----------+     (5\|5  + 5) |-----------
+--R         |    +-+                      |      +-+
+--R         |- 2\|5  + 5                 \|   20\|5
+--R       2 |----------- atan(-------------------------)
+--R         |      +-+                    +-+
+--R        \|   20\|5                   x\|5
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1571
+
+--S 1572 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    +---------+                +---------+
+--R                    |  +-+                     |  +-+
+--R          4+-+3 +-+ |2\|5  + 5        +-+      |2\|5  + 5      +-+
+--R       - 2\|2  \|5  |--------- log((5\|5  - 5) |---------  + x\|5 )
+--R                    |     +-+                  |     +-+
+--R                   \|  20\|5                  \|  20\|5
+--R     + 
+--R                  +-----------+                +-----------+
+--R                  |    +-+                     |    +-+
+--R        4+-+3 +-+ |- 2\|5  + 5        +-+      |- 2\|5  + 5      +-+
+--R       2\|2  \|5  |----------- log((5\|5  + 5) |-----------  + x\|5 )
+--R                  |      +-+                   |      +-+
+--R                 \|   20\|5                   \|   20\|5
+--R     + 
+--R                    +-----------+                  +-----------+
+--R                    |    +-+                       |    +-+
+--R          4+-+3 +-+ |- 2\|5  + 5          +-+      |- 2\|5  + 5      +-+
+--R       - 2\|2  \|5  |----------- log((- 5\|5  - 5) |-----------  + x\|5 )
+--R                    |      +-+                     |      +-+
+--R                   \|   20\|5                     \|   20\|5
+--R     + 
+--R                  +---------+                  +---------+
+--R                  |  +-+                       |  +-+
+--R        4+-+3 +-+ |2\|5  + 5          +-+      |2\|5  + 5      +-+
+--R       2\|2  \|5  |--------- log((- 5\|5  + 5) |---------  + x\|5 )
+--R                  |     +-+                    |     +-+
+--R                 \|  20\|5                    \|  20\|5
+--R     + 
+--R                                               +--------+
+--R                +--------------+        4+-+3 4| +-+
+--R         4+-+3 4|     +-+             x \|2   \|\|5  + 3
+--R       - \|2   \|- 64\|5  + 144 atanh(------------------)
+--R                                               2
+--R     + 
+--R                                +----------+
+--R         +--------+3       4+-+4|   +-+
+--R        4| +-+            x\|2 \|- \|5  + 3
+--R       2\|\|5  + 3  atanh(------------------)
+--R                                  +-+
+--R                                 \|2
+--R     + 
+--R                                            +--------+
+--R              +--------------+       4+-+3 4| +-+
+--R       4+-+3 4|     +-+            x \|2   \|\|5  + 3
+--R       \|2   \|- 64\|5  + 144 atan(------------------)
+--R                                            2
+--R     + 
+--R                                                +---------+
+--R                                                |  +-+
+--R                                       +-+      |2\|5  + 5
+--R                    +---------+     (5\|5  - 5) |---------
+--R                    |  +-+                      |     +-+
+--R          4+-+3 +-+ |2\|5  + 5                 \|  20\|5
+--R       - 4\|2  \|5  |--------- atan(-----------------------)
+--R                    |     +-+                  +-+
+--R                   \|  20\|5                 x\|5
+--R     + 
+--R                                                +-----------+
+--R                                                |    +-+
+--R                                       +-+      |- 2\|5  + 5
+--R                  +-----------+     (5\|5  + 5) |-----------
+--R                  |    +-+                      |      +-+
+--R        4+-+3 +-+ |- 2\|5  + 5                 \|   20\|5
+--R       4\|2  \|5  |----------- atan(-------------------------)
+--R                  |      +-+                    +-+
+--R                 \|   20\|5                   x\|5
+--R     + 
+--R                                 +----------+
+--R           +--------+3      4+-+4|   +-+
+--R          4| +-+           x\|2 \|- \|5  + 3
+--R       - 2\|\|5  + 3  atan(------------------)
+--R                                   +-+
+--R                                  \|2
+--R  /
+--R      4+-+3 +-+
+--R     4\|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 1572
+
+--S 1573 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                               +----------+3
+--R                 6     2 4+-+2 +-+     6 4+-+24|   +-+
+--R           ((- 3x  + 2x )\|2  \|5  - 5x  \|2 )\|- \|5  + 3
+--R         + 
+--R                                           +--------------+
+--R               6     2 4+-+ +-+     6 4+-+4|     +-+
+--R           ((3x  - 2x )\|2 \|5  - 5x  \|2)\|- 64\|5  + 144
+--R      *
+--R          +--------+3
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R          6
+--R       40x
+--R  /
+--R        8       4
+--R     40x  - 120x  + 40
+--R                                                    Type: Expression(Integer)
+--E 1573
+
+)clear all
+
+--S 1574 of 2282
+t0:=x^4/(1-3*x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1574
+
+--S 1575 of 2282
+r0:=1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(3-sqrt(5))^(1/4)/(2^(1/4)*_
+   sqrt(5))+1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*(3-sqrt(5))^(1/4)/_
+   (2^(1/4)*sqrt(5))-1/2*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))-1/2*atanh(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                   +--------+
+--R        +----------+        4+-+3 4| +-+
+--R       4|   +-+           x \|2   \|\|5  + 3
+--R       \|- \|5  + 3 atanh(------------------)
+--R                                   2
+--R     + 
+--R                                +----------+
+--R          +--------+       4+-+4|   +-+
+--R         4| +-+           x\|2 \|- \|5  + 3
+--R       - \|\|5  + 3 atanh(------------------)
+--R                                  +-+
+--R                                 \|2
+--R     + 
+--R                                +--------+                         +----------+
+--R      +----------+       4+-+3 4| +-+         +--------+      4+-+4|   +-+
+--R     4|   +-+          x \|2   \|\|5  + 3    4| +-+          x\|2 \|- \|5  + 3
+--R     \|- \|5  + 3 atan(------------------) - \|\|5  + 3 atan(------------------)
+--R                                2                                    +-+
+--R                                                                    \|2
+--R  /
+--R      4+-+ +-+
+--R     2\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 1575
+
+--S 1576 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +--------+          +--------+
+--R          | +-+               | +-+
+--R          |\|5  + 5       +-+ |\|5  + 5
+--R       -  |-------- log(2\|5  |--------  + x)
+--R          |    +-+            |    +-+
+--R         \| 40\|5            \| 40\|5
+--R     + 
+--R        +----------+          +----------+
+--R        |   +-+               |   +-+
+--R        |- \|5  + 5       +-+ |- \|5  + 5
+--R        |---------- log(2\|5  |----------  + x)
+--R        |     +-+             |     +-+
+--R       \|  40\|5             \|  40\|5
+--R     + 
+--R          +----------+            +----------+
+--R          |   +-+                 |   +-+
+--R          |- \|5  + 5         +-+ |- \|5  + 5
+--R       -  |---------- log(- 2\|5  |----------  + x)
+--R          |     +-+               |     +-+
+--R         \|  40\|5               \|  40\|5
+--R     + 
+--R        +--------+            +--------+
+--R        | +-+                 | +-+
+--R        |\|5  + 5         +-+ |\|5  + 5
+--R        |-------- log(- 2\|5  |--------  + x)
+--R        |    +-+              |    +-+
+--R       \| 40\|5              \| 40\|5
+--R     + 
+--R                            +--------+                             +----------+
+--R                            | +-+                                  |   +-+
+--R                        +-+ |\|5  + 5                          +-+ |- \|5  + 5
+--R       +--------+     2\|5  |--------       +----------+     2\|5  |----------
+--R       | +-+                |    +-+        |   +-+                |     +-+
+--R       |\|5  + 5           \| 40\|5         |- \|5  + 5           \|  40\|5
+--R     2 |-------- atan(----------------) - 2 |---------- atan(------------------)
+--R       |    +-+               x             |     +-+                 x
+--R      \| 40\|5                             \|  40\|5
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1576
+
+--S 1577 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +--------+          +--------+
+--R                  | +-+               | +-+
+--R         4+-+ +-+ |\|5  + 5       +-+ |\|5  + 5
+--R       - \|2 \|5  |-------- log(2\|5  |--------  + x)
+--R                  |    +-+            |    +-+
+--R                 \| 40\|5            \| 40\|5
+--R     + 
+--R                +----------+          +----------+
+--R                |   +-+               |   +-+
+--R       4+-+ +-+ |- \|5  + 5       +-+ |- \|5  + 5
+--R       \|2 \|5  |---------- log(2\|5  |----------  + x)
+--R                |     +-+             |     +-+
+--R               \|  40\|5             \|  40\|5
+--R     + 
+--R                  +----------+            +----------+
+--R                  |   +-+                 |   +-+
+--R         4+-+ +-+ |- \|5  + 5         +-+ |- \|5  + 5
+--R       - \|2 \|5  |---------- log(- 2\|5  |----------  + x)
+--R                  |     +-+               |     +-+
+--R                 \|  40\|5               \|  40\|5
+--R     + 
+--R                +--------+            +--------+
+--R                | +-+                 | +-+
+--R       4+-+ +-+ |\|5  + 5         +-+ |\|5  + 5
+--R       \|2 \|5  |-------- log(- 2\|5  |--------  + x)
+--R                |    +-+              |    +-+
+--R               \| 40\|5              \| 40\|5
+--R     + 
+--R                                     +--------+
+--R          +----------+        4+-+3 4| +-+
+--R         4|   +-+           x \|2   \|\|5  + 3
+--R       - \|- \|5  + 3 atanh(------------------)
+--R                                     2
+--R     + 
+--R                              +----------+
+--R        +--------+       4+-+4|   +-+
+--R       4| +-+           x\|2 \|- \|5  + 3
+--R       \|\|5  + 3 atanh(------------------)
+--R                                +-+
+--R                               \|2
+--R     + 
+--R                                    +--------+
+--R          +----------+       4+-+3 4| +-+
+--R         4|   +-+          x \|2   \|\|5  + 3
+--R       - \|- \|5  + 3 atan(------------------)
+--R                                    2
+--R     + 
+--R                                      +--------+
+--R                                      | +-+
+--R                                  +-+ |\|5  + 5
+--R                 +--------+     2\|5  |--------
+--R                 | +-+                |    +-+
+--R        4+-+ +-+ |\|5  + 5           \| 40\|5
+--R       2\|2 \|5  |-------- atan(----------------)
+--R                 |    +-+               x
+--R                \| 40\|5
+--R     + 
+--R                                          +----------+
+--R                                          |   +-+
+--R                                      +-+ |- \|5  + 5
+--R                   +----------+     2\|5  |----------
+--R                   |   +-+                |     +-+
+--R          4+-+ +-+ |- \|5  + 5           \|  40\|5
+--R       - 2\|2 \|5  |---------- atan(------------------)
+--R                   |     +-+                 x
+--R                  \|  40\|5
+--R     + 
+--R                             +----------+
+--R        +--------+      4+-+4|   +-+
+--R       4| +-+          x\|2 \|- \|5  + 3
+--R       \|\|5  + 3 atan(------------------)
+--R                               +-+
+--R                              \|2
+--R  /
+--R      4+-+ +-+
+--R     2\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 1577
+
+--S 1578 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +----------+ +--------+
+--R           4 4|   +-+     4| +-+        4 4+-+2
+--R        - x  \|- \|5  + 3 \|\|5  + 3 + x  \|2
+--R   (5)  --------------------------------------
+--R                    8     4     4+-+2
+--R                  (x  - 3x  + 1)\|2
+--R                                                    Type: Expression(Integer)
+--E 1578
+
+)clear all
+
+--S 1579 of 2282
+t0:=x^2/(1-3*x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1579
+
+--S 1580 of 2282
+--r0a:=1/20*atan(1/2*x*sqrt(-2+2*sqrt(5)))*sqrt(-10+10*sqrt(5))-
+--  1/20*atanh(1/2*x*sqrt(-2+2*sqrt(5)))*sqrt(-10+10*sqrt(5))-
+--  1/20*atan(1/2*x*sqrt(2+2*sqrt(5)))*sqrt(10+10*sqrt(5))+
+--  1/20*atanh(1/2*x*sqrt(2+2*sqrt(5)))*sqrt(10+10*sqrt(5))
+--E 1580
+
+--S 1581 of 2282
+r0b:=atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))/(2^(3/4)*sqrt(5)*_
+   (3+sqrt(5))^(1/4))-atanh(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))/(2^(3/4)*_
+   sqrt(5)*(3+sqrt(5))^(1/4))-1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))+_
+   1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*(3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                        +--------+               +----------+
+--R              +--------+2        4+-+3 4| +-+               4+-+4|   +-+
+--R       4+-+2 4| +-+            x \|2   \|\|5  + 3          x\|2 \|- \|5  + 3
+--R       \|2   \|\|5  + 3  atanh(------------------ - 2atanh(------------------)
+--R                                        2                          +-+
+--R                                                                  \|2
+--R     + 
+--R                                         +--------+              +----------+
+--R                +--------+2       4+-+3 4| +-+              4+-+4|   +-+
+--R         4+-+2 4| +-+           x \|2   \|\|5  + 3         x\|2 \|- \|5  + 3
+--R       - \|2   \|\|5  + 3  atan(------------------ + 2atan(------------------)
+--R                                         2                         +-+
+--R                                                                  \|2
+--R  /
+--R                +--------+
+--R      4+-+3 +-+4| +-+
+--R     2\|2  \|5 \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 1581
+
+--S 1582 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        +--------+                +--------+
+--R        | +-+                     | +-+
+--R        |\|5  + 5        +-+      |\|5  + 5      +-+
+--R        |-------- log((5\|5  - 5) |--------  + x\|5 )
+--R        |    +-+                  |    +-+
+--R       \| 40\|5                  \| 40\|5
+--R     + 
+--R          +----------+                +----------+
+--R          |   +-+                     |   +-+
+--R          |- \|5  + 5        +-+      |- \|5  + 5      +-+
+--R       -  |---------- log((5\|5  + 5) |----------  + x\|5 )
+--R          |     +-+                   |     +-+
+--R         \|  40\|5                   \|  40\|5
+--R     + 
+--R        +----------+                  +----------+
+--R        |   +-+                       |   +-+
+--R        |- \|5  + 5          +-+      |- \|5  + 5      +-+
+--R        |---------- log((- 5\|5  - 5) |----------  + x\|5 )
+--R        |     +-+                     |     +-+
+--R       \|  40\|5                     \|  40\|5
+--R     + 
+--R          +--------+                  +--------+
+--R          | +-+                       | +-+
+--R          |\|5  + 5          +-+      |\|5  + 5      +-+
+--R       -  |-------- log((- 5\|5  + 5) |--------  + x\|5 )
+--R          |    +-+                    |    +-+
+--R         \| 40\|5                    \| 40\|5
+--R     + 
+--R                                    +--------+
+--R                                    | +-+
+--R                           +-+      |\|5  + 5
+--R         +--------+     (5\|5  - 5) |--------
+--R         | +-+                      |    +-+
+--R         |\|5  + 5                 \| 40\|5
+--R       2 |-------- atan(----------------------)
+--R         |    +-+                  +-+
+--R        \| 40\|5                 x\|5
+--R     + 
+--R                                        +----------+
+--R                                        |   +-+
+--R                               +-+      |- \|5  + 5
+--R           +----------+     (5\|5  + 5) |----------
+--R           |   +-+                      |     +-+
+--R           |- \|5  + 5                 \|  40\|5
+--R       - 2 |---------- atan(------------------------)
+--R           |     +-+                    +-+
+--R          \|  40\|5                   x\|5
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1582
+
+--S 1583 of 2282
+--m0a:=a0-r0a
+--E 1583
+
+--S 1584 of 2282
+--d0a:=normalize(D(m0a,x))
+--E 1584
+
+--S 1585 of 2282
+m0b:=a0-r0b
+--R 
+--R
+--R   (4)
+--R                 +--------+                           +--------+
+--R                 | +-+      +--------+                | +-+
+--R       4+-+3 +-+ |\|5  + 5 4| +-+            +-+      |\|5  + 5      +-+
+--R       \|2  \|5  |-------- \|\|5  + 3 log((5\|5  - 5) |--------  + x\|5 )
+--R                 |    +-+                             |    +-+
+--R                \| 40\|5                             \| 40\|5
+--R     + 
+--R                   +----------+                           +----------+
+--R                   |   +-+      +--------+                |   +-+
+--R         4+-+3 +-+ |- \|5  + 5 4| +-+            +-+      |- \|5  + 5      +-+
+--R       - \|2  \|5  |---------- \|\|5  + 3 log((5\|5  + 5) |----------  + x\|5 )
+--R                   |     +-+                              |     +-+
+--R                  \|  40\|5                              \|  40\|5
+--R     + 
+--R                 +----------+                             +----------+
+--R                 |   +-+      +--------+                  |   +-+
+--R       4+-+3 +-+ |- \|5  + 5 4| +-+              +-+      |- \|5  + 5      +-+
+--R       \|2  \|5  |---------- \|\|5  + 3 log((- 5\|5  - 5) |----------  + x\|5 )
+--R                 |     +-+                                |     +-+
+--R                \|  40\|5                                \|  40\|5
+--R     + 
+--R                   +--------+                             +--------+
+--R                   | +-+      +--------+                  | +-+
+--R         4+-+3 +-+ |\|5  + 5 4| +-+              +-+      |\|5  + 5      +-+
+--R       - \|2  \|5  |-------- \|\|5  + 3 log((- 5\|5  + 5) |--------  + x\|5 )
+--R                   |    +-+                               |    +-+
+--R                  \| 40\|5                               \| 40\|5
+--R     + 
+--R                                          +--------+               +----------+
+--R                +--------+2        4+-+3 4| +-+               4+-+4|   +-+
+--R         4+-+2 4| +-+            x \|2   \|\|5  + 3          x\|2 \|- \|5  + 3
+--R       - \|2   \|\|5  + 3  atanh(------------------ + 2atanh(------------------)
+--R                                          2                          +-+
+--R                                                                    \|2
+--R     + 
+--R                                       +--------+
+--R              +--------+2       4+-+3 4| +-+
+--R       4+-+2 4| +-+           x \|2   \|\|5  + 3
+--R       \|2   \|\|5  + 3  atan(------------------)
+--R                                       2
+--R     + 
+--R                                                        +--------+
+--R                                                        | +-+
+--R                                               +-+      |\|5  + 5
+--R                  +--------+                (5\|5  - 5) |--------
+--R                  | +-+      +--------+                 |    +-+
+--R        4+-+3 +-+ |\|5  + 5 4| +-+                     \| 40\|5
+--R       2\|2  \|5  |-------- \|\|5  + 3 atan(----------------------)
+--R                  |    +-+                             +-+
+--R                 \| 40\|5                            x\|5
+--R     + 
+--R                                                            +----------+
+--R                                                            |   +-+
+--R                                                   +-+      |- \|5  + 5
+--R                    +----------+                (5\|5  + 5) |----------
+--R                    |   +-+      +--------+                 |     +-+
+--R          4+-+3 +-+ |- \|5  + 5 4| +-+                     \|  40\|5
+--R       - 2\|2  \|5  |---------- \|\|5  + 3 atan(------------------------)
+--R                    |     +-+                               +-+
+--R                   \|  40\|5                              x\|5
+--R     + 
+--R                     +----------+
+--R                4+-+4|   +-+
+--R               x\|2 \|- \|5  + 3
+--R       - 2atan(------------------)
+--R                       +-+
+--R                      \|2
+--R  /
+--R                +--------+
+--R      4+-+3 +-+4| +-+
+--R     2\|2  \|5 \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 1585
+
+--S 1586 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (5)
+--R                                                    +--------+
+--R             6     4     2  +-+     6      4     2 4| +-+
+--R       ((- 3x  + 5x  - 3x )\|5  + 5x  - 15x  + 5x )\|\|5  + 3
+--R     + 
+--R                                     +----------+3
+--R          6    2  +-+ +-+     4 +-+ 4|   +-+
+--R       ((x  + x )\|2 \|5  + 5x \|2 )\|- \|5  + 3
+--R  /
+--R                                                              +--------+
+--R         8      6     4      2  +-+      8      6     4      4| +-+
+--R     ((5x  - 15x  + 5x  + 10x )\|5  - 15x  + 25x  - 5x  + 10)\|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 1586
+
+)clear all
+
+--S 1587 of 2282
+t0:=1/(1-3*x^4+x^8)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1587
+
+--S 1588 of 2282
+r0:=-atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))/(2^(1/4)*sqrt(5)*_
+   (3+sqrt(5))^(3/4))-atanh(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))/(2^(1/4)*_
+   sqrt(5)*(3+sqrt(5))^(3/4))+1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (9+4*sqrt(5))^(1/4)/sqrt(5)+1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (9+4*sqrt(5))^(1/4)/sqrt(5)
+--R 
+--R
+--R   (2)
+--R                                                   +--------+
+--R            +--------+3  +---------+        4+-+3 4| +-+
+--R       4+-+4| +-+       4|  +-+           x \|2   \|\|5  + 3
+--R       \|2 \|\|5  + 3   \|4\|5  + 9 atanh(------------------)
+--R                                                   2
+--R     + 
+--R                      +----------+
+--R                 4+-+4|   +-+
+--R                x\|2 \|- \|5  + 3
+--R       - 2atanh(------------------)
+--R                        +-+
+--R                       \|2
+--R     + 
+--R                                                  +--------+
+--R            +--------+3  +---------+       4+-+3 4| +-+
+--R       4+-+4| +-+       4|  +-+          x \|2   \|\|5  + 3
+--R       \|2 \|\|5  + 3   \|4\|5  + 9 atan(------------------)
+--R                                                  2
+--R     + 
+--R                     +----------+
+--R                4+-+4|   +-+
+--R               x\|2 \|- \|5  + 3
+--R       - 2atan(------------------)
+--R                       +-+
+--R                      \|2
+--R  /
+--R               +--------+3
+--R      4+-+ +-+4| +-+
+--R     2\|2 \|5 \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 1588
+
+--S 1589 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        +---------+                +---------+
+--R        |  +-+                     |  +-+
+--R        |2\|5  + 5        +-+      |2\|5  + 5
+--R        |--------- log((3\|5  - 5) |---------  + x)
+--R        |     +-+                  |     +-+
+--R       \|  20\|5                  \|  20\|5
+--R     + 
+--R          +-----------+                +-----------+
+--R          |    +-+                     |    +-+
+--R          |- 2\|5  + 5        +-+      |- 2\|5  + 5
+--R       -  |----------- log((3\|5  + 5) |-----------  + x)
+--R          |      +-+                   |      +-+
+--R         \|   20\|5                   \|   20\|5
+--R     + 
+--R        +-----------+                  +-----------+
+--R        |    +-+                       |    +-+
+--R        |- 2\|5  + 5          +-+      |- 2\|5  + 5
+--R        |----------- log((- 3\|5  - 5) |-----------  + x)
+--R        |      +-+                     |      +-+
+--R       \|   20\|5                     \|   20\|5
+--R     + 
+--R          +---------+                  +---------+
+--R          |  +-+                       |  +-+
+--R          |2\|5  + 5          +-+      |2\|5  + 5
+--R       -  |--------- log((- 3\|5  + 5) |---------  + x)
+--R          |     +-+                    |     +-+
+--R         \|  20\|5                    \|  20\|5
+--R     + 
+--R                                       +---------+
+--R                                       |  +-+
+--R                              +-+      |2\|5  + 5
+--R           +---------+     (3\|5  - 5) |---------
+--R           |  +-+                      |     +-+
+--R           |2\|5  + 5                 \|  20\|5
+--R       - 2 |--------- atan(-----------------------)
+--R           |     +-+                  x
+--R          \|  20\|5
+--R     + 
+--R                                       +-----------+
+--R                                       |    +-+
+--R                              +-+      |- 2\|5  + 5
+--R         +-----------+     (3\|5  + 5) |-----------
+--R         |    +-+                      |      +-+
+--R         |- 2\|5  + 5                 \|   20\|5
+--R       2 |----------- atan(-------------------------)
+--R         |      +-+                    x
+--R        \|   20\|5
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1589
+
+--S 1590 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +---------+                            +---------+
+--R                |  +-+      +--------+3                |  +-+
+--R       4+-+ +-+ |2\|5  + 5 4| +-+             +-+      |2\|5  + 5
+--R       \|2 \|5  |--------- \|\|5  + 3  log((3\|5  - 5) |---------  + x)
+--R                |     +-+                              |     +-+
+--R               \|  20\|5                              \|  20\|5
+--R     + 
+--R                  +-----------+                            +-----------+
+--R                  |    +-+      +--------+3                |    +-+
+--R         4+-+ +-+ |- 2\|5  + 5 4| +-+             +-+      |- 2\|5  + 5
+--R       - \|2 \|5  |----------- \|\|5  + 3  log((3\|5  + 5) |-----------  + x)
+--R                  |      +-+                               |      +-+
+--R                 \|   20\|5                               \|   20\|5
+--R     + 
+--R                +-----------+                              +-----------+
+--R                |    +-+      +--------+3                  |    +-+
+--R       4+-+ +-+ |- 2\|5  + 5 4| +-+               +-+      |- 2\|5  + 5
+--R       \|2 \|5  |----------- \|\|5  + 3  log((- 3\|5  - 5) |-----------  + x)
+--R                |      +-+                                 |      +-+
+--R               \|   20\|5                                 \|   20\|5
+--R     + 
+--R                  +---------+                              +---------+
+--R                  |  +-+      +--------+3                  |  +-+
+--R         4+-+ +-+ |2\|5  + 5 4| +-+               +-+      |2\|5  + 5
+--R       - \|2 \|5  |--------- \|\|5  + 3  log((- 3\|5  + 5) |---------  + x)
+--R                  |     +-+                                |     +-+
+--R                 \|  20\|5                                \|  20\|5
+--R     + 
+--R                                                     +--------+
+--R              +--------+3  +---------+        4+-+3 4| +-+
+--R         4+-+4| +-+       4|  +-+           x \|2   \|\|5  + 3
+--R       - \|2 \|\|5  + 3   \|4\|5  + 9 atanh(------------------)
+--R                                                     2
+--R     + 
+--R                    +----------+
+--R               4+-+4|   +-+
+--R              x\|2 \|- \|5  + 3
+--R       2atanh(------------------)
+--R                      +-+
+--R                     \|2
+--R     + 
+--R                                                    +--------+
+--R              +--------+3  +---------+       4+-+3 4| +-+
+--R         4+-+4| +-+       4|  +-+          x \|2   \|\|5  + 3
+--R       - \|2 \|\|5  + 3   \|4\|5  + 9 atan(------------------)
+--R                                                    2
+--R     + 
+--R                                                           +---------+
+--R                                                           |  +-+
+--R                                                  +-+      |2\|5  + 5
+--R                   +---------+                 (3\|5  - 5) |---------
+--R                   |  +-+      +--------+3                 |     +-+
+--R          4+-+ +-+ |2\|5  + 5 4| +-+                      \|  20\|5
+--R       - 2\|2 \|5  |--------- \|\|5  + 3  atan(-----------------------)
+--R                   |     +-+                              x
+--R                  \|  20\|5
+--R     + 
+--R                                                           +-----------+
+--R                                                           |    +-+
+--R                                                  +-+      |- 2\|5  + 5
+--R                 +-----------+                 (3\|5  + 5) |-----------
+--R                 |    +-+      +--------+3                 |      +-+
+--R        4+-+ +-+ |- 2\|5  + 5 4| +-+                      \|   20\|5
+--R       2\|2 \|5  |----------- \|\|5  + 3  atan(-------------------------)
+--R                 |      +-+                                x
+--R                \|   20\|5
+--R     + 
+--R                   +----------+
+--R              4+-+4|   +-+
+--R             x\|2 \|- \|5  + 3
+--R       2atan(------------------)
+--R                     +-+
+--R                    \|2
+--R  /
+--R               +--------+3
+--R      4+-+ +-+4| +-+
+--R     2\|2 \|5 \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 1590
+
+--S 1591 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                            +--------+ +---------+
+--R           4      +-+      4| +-+     4|  +-+
+--R       ((4x  - 6)\|5  - 10)\|\|5  + 3 \|4\|5  + 9
+--R     + 
+--R                                         +----------+ +--------+
+--R             4     4+-+3 +-+     4 4+-+34|   +-+     4| +-+          4+-+ +-+
+--R       ((- 3x  + 2)\|2  \|5  - 5x  \|2 )\|- \|5  + 3 \|\|5  + 3  + 10\|2 \|5
+--R     + 
+--R         4+-+
+--R       30\|2
+--R  /
+--R         8      4      4+-+ +-+       8      4      4+-+
+--R     (10x  - 30x  + 10)\|2 \|5  + (30x  - 90x  + 30)\|2
+--R                                                    Type: Expression(Integer)
+--E 1591
+
+)clear all
+
+--S 1592 of 2282
+t0:=1/(x^2*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         10     6    2
+--R        x   - 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1592
+
+--S 1593 of 2282
+r0:=(-1)/x+1/4*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (984-440*sqrt(5))^(1/4)/sqrt(5)-1/4*atanh(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(984-440*sqrt(5))^(1/4)/sqrt(5)-_
+   1/4*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(3+sqrt(5))^(5/4)/(2^(1/4)*_
+   sqrt(5))+1/4*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*(3+sqrt(5))^(5/4)/_
+   (2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                             +--------+
+--R                    +--------+        4+-+3 4| +-+
+--R          +-+      4| +-+           x \|2   \|\|5  + 3
+--R       (x\|5  + 3x)\|\|5  + 3 atanh(------------------)
+--R                                             2
+--R     + 
+--R                                            +----------+
+--R               +---------------+       4+-+4|   +-+
+--R          4+-+4|      +-+             x\|2 \|- \|5  + 3
+--R       - x\|2 \|- 440\|5  + 984 atanh(------------------)
+--R                                              +-+
+--R                                             \|2
+--R     + 
+--R                                              +--------+
+--R                      +--------+       4+-+3 4| +-+
+--R            +-+      4| +-+          x \|2   \|\|5  + 3
+--R       (- x\|5  - 3x)\|\|5  + 3 atan(------------------)
+--R                                              2
+--R     + 
+--R                                         +----------+
+--R             +---------------+      4+-+4|   +-+
+--R        4+-+4|      +-+            x\|2 \|- \|5  + 3      4+-+ +-+
+--R       x\|2 \|- 440\|5  + 984 atan(------------------) - 4\|2 \|5
+--R                                           +-+
+--R                                          \|2
+--R  /
+--R       4+-+ +-+
+--R     4x\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 1593
+
+--S 1594 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +----------+                +----------+
+--R           |  +-+             +-+      |  +-+           +--+
+--R       - x\|5\|5  + 11 log((2\|5  - 5)\|5\|5  + 11  + x\|10 )
+--R     + 
+--R           +----------+                +----------+
+--R           |  +-+             +-+      |  +-+           +--+
+--R       - x\|5\|5  - 11 log((2\|5  + 5)\|5\|5  - 11  + x\|10 )
+--R     + 
+--R         +----------+                  +----------+
+--R         |  +-+               +-+      |  +-+           +--+
+--R       x\|5\|5  - 11 log((- 2\|5  - 5)\|5\|5  - 11  + x\|10 )
+--R     + 
+--R         +----------+                  +----------+
+--R         |  +-+               +-+      |  +-+           +--+
+--R       x\|5\|5  + 11 log((- 2\|5  + 5)\|5\|5  + 11  + x\|10 )
+--R     + 
+--R                                         +----------+
+--R            +----------+        +-+      |  +-+
+--R            |  +-+           (2\|5  - 5)\|5\|5  + 11
+--R       - 2x\|5\|5  + 11 atan(------------------------)
+--R                                        +--+
+--R                                      x\|10
+--R     + 
+--R                                         +----------+
+--R            +----------+        +-+      |  +-+
+--R            |  +-+           (2\|5  + 5)\|5\|5  - 11       +--+
+--R       - 2x\|5\|5  - 11 atan(------------------------) - 4\|10
+--R                                        +--+
+--R                                      x\|10
+--R  /
+--R        +--+
+--R     4x\|10
+--R                                         Type: Union(Expression(Integer),...)
+--E 1594
+
+--S 1595 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +----------+                +----------+
+--R         4+-+ +-+ |  +-+             +-+      |  +-+           +--+
+--R       - \|2 \|5 \|5\|5  + 11 log((2\|5  - 5)\|5\|5  + 11  + x\|10 )
+--R     + 
+--R                  +----------+                +----------+
+--R         4+-+ +-+ |  +-+             +-+      |  +-+           +--+
+--R       - \|2 \|5 \|5\|5  - 11 log((2\|5  + 5)\|5\|5  - 11  + x\|10 )
+--R     + 
+--R                +----------+                  +----------+
+--R       4+-+ +-+ |  +-+               +-+      |  +-+           +--+
+--R       \|2 \|5 \|5\|5  - 11 log((- 2\|5  - 5)\|5\|5  - 11  + x\|10 )
+--R     + 
+--R                +----------+                  +----------+
+--R       4+-+ +-+ |  +-+               +-+      |  +-+           +--+
+--R       \|2 \|5 \|5\|5  + 11 log((- 2\|5  + 5)\|5\|5  + 11  + x\|10 )
+--R     + 
+--R                                                  +--------+
+--R                         +--------+        4+-+3 4| +-+
+--R           +-+      +--+4| +-+           x \|2   \|\|5  + 3
+--R       (- \|5  - 3)\|10 \|\|5  + 3 atanh(------------------)
+--R                                                  2
+--R     + 
+--R                                              +----------+
+--R                 +---------------+       4+-+4|   +-+
+--R       4+-+ +--+4|      +-+             x\|2 \|- \|5  + 3
+--R       \|2 \|10 \|- 440\|5  + 984 atanh(------------------)
+--R                                                +-+
+--R                                               \|2
+--R     + 
+--R                                                +----------+
+--R                   +----------+        +-+      |  +-+
+--R          4+-+ +-+ |  +-+           (2\|5  - 5)\|5\|5  + 11
+--R       - 2\|2 \|5 \|5\|5  + 11 atan(------------------------)
+--R                                               +--+
+--R                                             x\|10
+--R     + 
+--R                                                +----------+
+--R                   +----------+        +-+      |  +-+
+--R          4+-+ +-+ |  +-+           (2\|5  + 5)\|5\|5  - 11
+--R       - 2\|2 \|5 \|5\|5  - 11 atan(------------------------)
+--R                                               +--+
+--R                                             x\|10
+--R     + 
+--R                                               +--------+
+--R                       +--------+       4+-+3 4| +-+
+--R         +-+      +--+4| +-+          x \|2   \|\|5  + 3
+--R       (\|5  + 3)\|10 \|\|5  + 3 atan(------------------)
+--R                                               2
+--R     + 
+--R                                               +----------+
+--R                   +---------------+      4+-+4|   +-+
+--R         4+-+ +--+4|      +-+            x\|2 \|- \|5  + 3
+--R       - \|2 \|10 \|- 440\|5  + 984 atan(------------------)
+--R                                                 +-+
+--R                                                \|2
+--R  /
+--R      4+-+ +-+ +--+
+--R     4\|2 \|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 1595
+
+--S 1596 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                         +---------------+ +----------+3
+--R             6     2 4+-+ +-+     6 4+-+4|      +-+       4|   +-+
+--R       ((- 3x  + 2x )\|2 \|5  - 5x  \|2)\|- 440\|5  + 984 \|- \|5  + 3
+--R     + 
+--R           6      2  +-+      6      2
+--R       (12x  - 28x )\|5  - 20x  + 60x
+--R  /
+--R        8       4
+--R     40x  - 120x  + 40
+--R                                                    Type: Expression(Integer)
+--E 1596
+
+)clear all
+
+--S 1597 of 2282
+t0:=1/(x^4*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         12     8    4
+--R        x   - 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1597
+
+--S 1598 of 2282
+r0:=(-1/3)/x^3-1/2*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (843-377*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))-1/2*atanh(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(843-377*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))+_
+   1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(843+377*sqrt(5))^(1/4)/_
+   (2^(1/4)*sqrt(5))+1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (843+377*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                          +--------+
+--R            +-------------+        4+-+3 4| +-+
+--R         3 4|    +-+             x \|2   \|\|5  + 3
+--R       3x  \|377\|5  + 843 atanh(------------------)
+--R                                          2
+--R     + 
+--R                                           +----------+
+--R              +---------------+       4+-+4|   +-+
+--R           3 4|      +-+             x\|2 \|- \|5  + 3
+--R       - 3x  \|- 377\|5  + 843 atanh(------------------)
+--R                                             +-+
+--R                                            \|2
+--R     + 
+--R                                         +--------+
+--R            +-------------+       4+-+3 4| +-+
+--R         3 4|    +-+            x \|2   \|\|5  + 3
+--R       3x  \|377\|5  + 843 atan(------------------)
+--R                                         2
+--R     + 
+--R                                          +----------+
+--R              +---------------+      4+-+4|   +-+
+--R           3 4|      +-+            x\|2 \|- \|5  + 3     4+-+ +-+
+--R       - 3x  \|- 377\|5  + 843 atan(------------------ - 2\|2 \|5
+--R                                            +-+
+--R                                           \|2
+--R  /
+--R       3 4+-+ +-+
+--R     6x  \|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 1598
+
+--S 1599 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-----------+                 +-----------+
+--R           |   +-+                       |   +-+
+--R         3 |29\|5  + 65        +-+       |29\|5  + 65
+--R       3x  |----------- log((7\|5  - 15) |-----------  + x)
+--R           |      +-+                    |      +-+
+--R          \|   40\|5                    \|   40\|5
+--R     + 
+--R             +-------------+                 +-------------+
+--R             |     +-+                       |     +-+
+--R           3 |- 29\|5  + 65        +-+       |- 29\|5  + 65
+--R       - 3x  |------------- log((7\|5  + 15) |-------------  + x)
+--R             |       +-+                     |       +-+
+--R            \|    40\|5                     \|    40\|5
+--R     + 
+--R           +-------------+                   +-------------+
+--R           |     +-+                         |     +-+
+--R         3 |- 29\|5  + 65          +-+       |- 29\|5  + 65
+--R       3x  |------------- log((- 7\|5  - 15) |-------------  + x)
+--R           |       +-+                       |       +-+
+--R          \|    40\|5                       \|    40\|5
+--R     + 
+--R             +-----------+                   +-----------+
+--R             |   +-+                         |   +-+
+--R           3 |29\|5  + 65          +-+       |29\|5  + 65
+--R       - 3x  |----------- log((- 7\|5  + 15) |-----------  + x)
+--R             |      +-+                      |      +-+
+--R            \|   40\|5                      \|   40\|5
+--R     + 
+--R                                            +-----------+
+--R                                            |   +-+
+--R                                  +-+       |29\|5  + 65
+--R             +-----------+     (7\|5  - 15) |-----------
+--R             |   +-+                        |      +-+
+--R           3 |29\|5  + 65                  \|   40\|5
+--R       - 6x  |----------- atan(--------------------------)
+--R             |      +-+                     x
+--R            \|   40\|5
+--R     + 
+--R                                            +-------------+
+--R                                            |     +-+
+--R                                  +-+       |- 29\|5  + 65
+--R           +-------------+     (7\|5  + 15) |-------------
+--R           |     +-+                        |       +-+
+--R         3 |- 29\|5  + 65                  \|    40\|5
+--R       6x  |------------- atan(----------------------------) - 2
+--R           |       +-+                       x
+--R          \|    40\|5
+--R  /
+--R       3
+--R     6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1599
+
+--S 1600 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-----------+                 +-----------+
+--R                |   +-+                       |   +-+
+--R       4+-+ +-+ |29\|5  + 65        +-+       |29\|5  + 65
+--R       \|2 \|5  |----------- log((7\|5  - 15) |-----------  + x)
+--R                |      +-+                    |      +-+
+--R               \|   40\|5                    \|   40\|5
+--R     + 
+--R                  +-------------+                 +-------------+
+--R                  |     +-+                       |     +-+
+--R         4+-+ +-+ |- 29\|5  + 65        +-+       |- 29\|5  + 65
+--R       - \|2 \|5  |------------- log((7\|5  + 15) |-------------  + x)
+--R                  |       +-+                     |       +-+
+--R                 \|    40\|5                     \|    40\|5
+--R     + 
+--R                +-------------+                   +-------------+
+--R                |     +-+                         |     +-+
+--R       4+-+ +-+ |- 29\|5  + 65          +-+       |- 29\|5  + 65
+--R       \|2 \|5  |------------- log((- 7\|5  - 15) |-------------  + x)
+--R                |       +-+                       |       +-+
+--R               \|    40\|5                       \|    40\|5
+--R     + 
+--R                  +-----------+                   +-----------+
+--R                  |   +-+                         |   +-+
+--R         4+-+ +-+ |29\|5  + 65          +-+       |29\|5  + 65
+--R       - \|2 \|5  |----------- log((- 7\|5  + 15) |-----------  + x)
+--R                  |      +-+                      |      +-+
+--R                 \|   40\|5                      \|   40\|5
+--R     + 
+--R                                        +--------+
+--R          +-------------+        4+-+3 4| +-+
+--R         4|    +-+             x \|2   \|\|5  + 3
+--R       - \|377\|5  + 843 atanh(------------------)
+--R                                        2
+--R     + 
+--R                                     +----------+
+--R        +---------------+       4+-+4|   +-+
+--R       4|      +-+             x\|2 \|- \|5  + 3
+--R       \|- 377\|5  + 843 atanh(------------------)
+--R                                       +-+
+--R                                      \|2
+--R     + 
+--R                                       +--------+
+--R          +-------------+       4+-+3 4| +-+
+--R         4|    +-+            x \|2   \|\|5  + 3
+--R       - \|377\|5  + 843 atan(------------------)
+--R                                       2
+--R     + 
+--R                                                  +-----------+
+--R                                                  |   +-+
+--R                                        +-+       |29\|5  + 65
+--R                   +-----------+     (7\|5  - 15) |-----------
+--R                   |   +-+                        |      +-+
+--R          4+-+ +-+ |29\|5  + 65                  \|   40\|5
+--R       - 2\|2 \|5  |----------- atan(--------------------------)
+--R                   |      +-+                     x
+--R                  \|   40\|5
+--R     + 
+--R                                                  +-------------+
+--R                                                  |     +-+
+--R                                        +-+       |- 29\|5  + 65
+--R                 +-------------+     (7\|5  + 15) |-------------
+--R                 |     +-+                        |       +-+
+--R        4+-+ +-+ |- 29\|5  + 65                  \|    40\|5
+--R       2\|2 \|5  |------------- atan(----------------------------)
+--R                 |       +-+                       x
+--R                \|    40\|5
+--R     + 
+--R                                    +----------+
+--R        +---------------+      4+-+4|   +-+
+--R       4|      +-+            x\|2 \|- \|5  + 3
+--R       \|- 377\|5  + 843 atan(------------------)
+--R                                      +-+
+--R                                     \|2
+--R  /
+--R      4+-+ +-+
+--R     2\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 1600
+
+--S 1601 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                             +--------+ +-------------+
+--R           4      +-+     4 4| +-+     4|    +-+
+--R       ((3x  - 2)\|5  - 5x )\|\|5  + 3 \|377\|5  + 843
+--R     + 
+--R                             +---------------+ +----------+
+--R           4      +-+     4 4|      +-+       4|   +-+              4      4+-+2
+--R     ((- 3x  + 2)\|5  - 5x )\|- 377\|5  + 843 \|- \|5  + 3  + (- 10x  + 30)\|2
+--R  /
+--R         8      4      4+-+2
+--R     (10x  - 30x  + 10)\|2
+--R                                                    Type: Expression(Integer)
+--E 1601
+
+)clear all
+
+--S 1602 of 2282
+t0:=1/(x^6*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         14     10    6
+--R        x   - 3x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1602
+
+--S 1603 of 2282
+r0:=(-1/5)/x^5+(-3)/x+1/4*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (46224-20672*sqrt(5))^(1/4)/sqrt(5)-1/4*atanh(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(46224-20672*sqrt(5))^(1/4)/sqrt(5)-_
+   1/4*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(46224+20672*sqrt(5))^(1/4)/_
+   sqrt(5)+1/4*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (46224+20672*sqrt(5))^(1/4)/sqrt(5)
+--R 
+--R
+--R   (2)
+--R                                              +--------+
+--R            +-----------------+        4+-+3 4| +-+
+--R         5 4|      +-+               x \|2   \|\|5  + 3
+--R       5x  \|20672\|5  + 46224 atanh(------------------)
+--R                                              2
+--R     + 
+--R                                               +----------+
+--R              +-------------------+       4+-+4|   +-+
+--R           5 4|        +-+               x\|2 \|- \|5  + 3
+--R       - 5x  \|- 20672\|5  + 46224 atanh(------------------)
+--R                                                 +-+
+--R                                                \|2
+--R     + 
+--R                                               +--------+
+--R              +-----------------+       4+-+3 4| +-+
+--R           5 4|      +-+              x \|2   \|\|5  + 3
+--R       - 5x  \|20672\|5  + 46224 atan(------------------)
+--R                                               2
+--R     + 
+--R                                            +----------+
+--R            +-------------------+      4+-+4|   +-+
+--R         5 4|        +-+              x\|2 \|- \|5  + 3          4      +-+
+--R       5x  \|- 20672\|5  + 46224 atan(------------------ + (- 60x  - 4)\|5
+--R                                              +-+
+--R                                             \|2
+--R  /
+--R        5 +-+
+--R     20x \|5
+--R                                                    Type: Expression(Integer)
+--E 1603
+
+--S 1604 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-----------+                  +-----------+
+--R           |   +-+                        |   +-+
+--R         5 |38\|5  + 85         +-+       |38\|5  + 85      +-+
+--R       5x  |----------- log((25\|5  - 55) |-----------  + x\|5 )
+--R           |      +-+                     |      +-+
+--R          \|   20\|5                     \|   20\|5
+--R     + 
+--R             +-------------+                  +-------------+
+--R             |     +-+                        |     +-+
+--R           5 |- 38\|5  + 85         +-+       |- 38\|5  + 85      +-+
+--R       - 5x  |------------- log((25\|5  + 55) |-------------  + x\|5 )
+--R             |       +-+                      |       +-+
+--R            \|    20\|5                      \|    20\|5
+--R     + 
+--R           +-------------+                    +-------------+
+--R           |     +-+                          |     +-+
+--R         5 |- 38\|5  + 85           +-+       |- 38\|5  + 85      +-+
+--R       5x  |------------- log((- 25\|5  - 55) |-------------  + x\|5 )
+--R           |       +-+                        |       +-+
+--R          \|    20\|5                        \|    20\|5
+--R     + 
+--R             +-----------+                    +-----------+
+--R             |   +-+                          |   +-+
+--R           5 |38\|5  + 85           +-+       |38\|5  + 85      +-+
+--R       - 5x  |----------- log((- 25\|5  + 55) |-----------  + x\|5 )
+--R             |      +-+                       |      +-+
+--R            \|   20\|5                       \|   20\|5
+--R     + 
+--R                                            +-----------+
+--R                                            |   +-+
+--R                                  +-+       |38\|5  + 85
+--R            +-----------+     (25\|5  - 55) |-----------
+--R            |   +-+                         |      +-+
+--R          5 |38\|5  + 85                   \|   20\|5
+--R       10x  |----------- atan(---------------------------)
+--R            |      +-+                     +-+
+--R           \|   20\|5                    x\|5
+--R     + 
+--R                                                +-------------+
+--R                                                |     +-+
+--R                                      +-+       |- 38\|5  + 85
+--R              +-------------+     (25\|5  + 55) |-------------
+--R              |     +-+                         |       +-+
+--R            5 |- 38\|5  + 85                   \|    20\|5            4
+--R       - 10x  |------------- atan(-----------------------------) - 30x  - 2
+--R              |       +-+                       +-+
+--R             \|    20\|5                      x\|5
+--R  /
+--R        5
+--R     10x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1604
+
+--S 1605 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             +-----------+                  +-----------+
+--R             |   +-+                        |   +-+
+--R         +-+ |38\|5  + 85         +-+       |38\|5  + 85      +-+
+--R       2\|5  |----------- log((25\|5  - 55) |-----------  + x\|5 )
+--R             |      +-+                     |      +-+
+--R            \|   20\|5                     \|   20\|5
+--R     + 
+--R               +-------------+                  +-------------+
+--R               |     +-+                        |     +-+
+--R           +-+ |- 38\|5  + 85         +-+       |- 38\|5  + 85      +-+
+--R       - 2\|5  |------------- log((25\|5  + 55) |-------------  + x\|5 )
+--R               |       +-+                      |       +-+
+--R              \|    20\|5                      \|    20\|5
+--R     + 
+--R             +-------------+                    +-------------+
+--R             |     +-+                          |     +-+
+--R         +-+ |- 38\|5  + 85           +-+       |- 38\|5  + 85      +-+
+--R       2\|5  |------------- log((- 25\|5  - 55) |-------------  + x\|5 )
+--R             |       +-+                        |       +-+
+--R            \|    20\|5                        \|    20\|5
+--R     + 
+--R               +-----------+                    +-----------+
+--R               |   +-+                          |   +-+
+--R           +-+ |38\|5  + 85           +-+       |38\|5  + 85      +-+
+--R       - 2\|5  |----------- log((- 25\|5  + 55) |-----------  + x\|5 )
+--R               |      +-+                       |      +-+
+--R              \|   20\|5                       \|   20\|5
+--R     + 
+--R                                            +--------+
+--R          +-----------------+        4+-+3 4| +-+
+--R         4|      +-+               x \|2   \|\|5  + 3
+--R       - \|20672\|5  + 46224 atanh(------------------)
+--R                                            2
+--R     + 
+--R                                         +----------+
+--R        +-------------------+       4+-+4|   +-+
+--R       4|        +-+               x\|2 \|- \|5  + 3
+--R       \|- 20672\|5  + 46224 atanh(------------------)
+--R                                           +-+
+--R                                          \|2
+--R     + 
+--R                                         +--------+
+--R        +-----------------+       4+-+3 4| +-+
+--R       4|      +-+              x \|2   \|\|5  + 3
+--R       \|20672\|5  + 46224 atan(------------------)
+--R                                         2
+--R     + 
+--R                                             +-----------+
+--R                                             |   +-+
+--R                                   +-+       |38\|5  + 85
+--R             +-----------+     (25\|5  - 55) |-----------
+--R             |   +-+                         |      +-+
+--R         +-+ |38\|5  + 85                   \|   20\|5
+--R       4\|5  |----------- atan(---------------------------)
+--R             |      +-+                     +-+
+--R            \|   20\|5                    x\|5
+--R     + 
+--R                                                 +-------------+
+--R                                                 |     +-+
+--R                                       +-+       |- 38\|5  + 85
+--R               +-------------+     (25\|5  + 55) |-------------
+--R               |     +-+                         |       +-+
+--R           +-+ |- 38\|5  + 85                   \|    20\|5
+--R       - 4\|5  |------------- atan(-----------------------------)
+--R               |       +-+                       +-+
+--R              \|    20\|5                      x\|5
+--R     + 
+--R                                          +----------+
+--R          +-------------------+      4+-+4|   +-+
+--R         4|        +-+              x\|2 \|- \|5  + 3
+--R       - \|- 20672\|5  + 46224 atan(------------------)
+--R                                            +-+
+--R                                           \|2
+--R  /
+--R       +-+
+--R     4\|5
+--R                                                    Type: Expression(Integer)
+--E 1605
+
+--S 1606 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +--------+3  +-----------------+
+--R           6     2 4+-+ +-+     6 4+-+4| +-+       4|      +-+
+--R       ((3x  - 2x )\|2 \|5  - 5x  \|2)\|\|5  + 3   \|20672\|5  + 46224
+--R     + 
+--R                                         +-------------------+ +----------+3
+--R             6     2 4+-+ +-+     6 4+-+4|        +-+         4|   +-+
+--R       ((- 3x  + 2x )\|2 \|5  - 5x  \|2)\|- 20672\|5  + 46224 \|- \|5  + 3
+--R     + 
+--R             6       2
+--R       - 120x  + 320x
+--R  /
+--R        8       4
+--R     40x  - 120x  + 40
+--R                                                    Type: Expression(Integer)
+--E 1606
+
+)clear all
+
+--S 1607 of 2282
+t0:=1/(x^8*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         16     12    8
+--R        x   - 3x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1607
+
+--S 1608 of 2282
+r0:=(-1/7)/x^7+(-1)/x^3-1/2*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (39603-17711*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))-1/2*atanh(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(39603-17711*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))+_
+   1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (39603+17711*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))+_
+   1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (39603+17711*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                              +--------+
+--R            +-----------------+        4+-+3 4| +-+
+--R         7 4|      +-+               x \|2   \|\|5  + 3
+--R       7x  \|17711\|5  + 39603 atanh(------------------)
+--R                                              2
+--R     + 
+--R                                               +----------+
+--R              +-------------------+       4+-+4|   +-+
+--R           7 4|        +-+               x\|2 \|- \|5  + 3
+--R       - 7x  \|- 17711\|5  + 39603 atanh(------------------)
+--R                                                 +-+
+--R                                                \|2
+--R     + 
+--R                                             +--------+
+--R            +-----------------+       4+-+3 4| +-+
+--R         7 4|      +-+              x \|2   \|\|5  + 3
+--R       7x  \|17711\|5  + 39603 atan(------------------)
+--R                                             2
+--R     + 
+--R                                            +----------+
+--R            +-------------------+      4+-+4|   +-+
+--R         7 4|        +-+              x\|2 \|- \|5  + 3          4     4+-+ +-+
+--R     - 7x  \|- 17711\|5  + 39603 atan(------------------ + (- 14x  - 2)\|2 \|5
+--R                                              +-+
+--R                                             \|2
+--R  /
+--R        7 4+-+ +-+
+--R     14x  \|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 1608
+
+--S 1609 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-------------+                  +-------------+
+--R           |    +-+                         |    +-+
+--R         7 |199\|5  + 445         +-+       |199\|5  + 445
+--R       7x  |------------- log((18\|5  - 40) |-------------  + x)
+--R           |       +-+                      |       +-+
+--R          \|    40\|5                      \|    40\|5
+--R     + 
+--R             +---------------+                  +---------------+
+--R             |      +-+                         |      +-+
+--R           7 |- 199\|5  + 445         +-+       |- 199\|5  + 445
+--R       - 7x  |--------------- log((18\|5  + 40) |---------------  + x)
+--R             |        +-+                       |        +-+
+--R            \|     40\|5                       \|     40\|5
+--R     + 
+--R           +---------------+                    +---------------+
+--R           |      +-+                           |      +-+
+--R         7 |- 199\|5  + 445           +-+       |- 199\|5  + 445
+--R       7x  |--------------- log((- 18\|5  - 40) |---------------  + x)
+--R           |        +-+                         |        +-+
+--R          \|     40\|5                         \|     40\|5
+--R     + 
+--R             +-------------+                    +-------------+
+--R             |    +-+                           |    +-+
+--R           7 |199\|5  + 445           +-+       |199\|5  + 445
+--R       - 7x  |------------- log((- 18\|5  + 40) |-------------  + x)
+--R             |       +-+                        |       +-+
+--R            \|    40\|5                        \|    40\|5
+--R     + 
+--R                                                +-------------+
+--R                                                |    +-+
+--R                                      +-+       |199\|5  + 445
+--R              +-------------+     (18\|5  - 40) |-------------
+--R              |    +-+                          |       +-+
+--R            7 |199\|5  + 445                   \|    40\|5
+--R       - 14x  |------------- atan(-----------------------------)
+--R              |       +-+                       x
+--R             \|    40\|5
+--R     + 
+--R                                                +---------------+
+--R                                                |      +-+
+--R                                      +-+       |- 199\|5  + 445
+--R            +---------------+     (18\|5  + 40) |---------------
+--R            |      +-+                          |        +-+
+--R          7 |- 199\|5  + 445                   \|     40\|5             4
+--R       14x  |--------------- atan(-------------------------------) - 14x  - 2
+--R            |        +-+                         x
+--R           \|     40\|5
+--R  /
+--R        7
+--R     14x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1609
+
+--S 1610 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-------------+                  +-------------+
+--R                |    +-+                         |    +-+
+--R       4+-+ +-+ |199\|5  + 445         +-+       |199\|5  + 445
+--R       \|2 \|5  |------------- log((18\|5  - 40) |-------------  + x)
+--R                |       +-+                      |       +-+
+--R               \|    40\|5                      \|    40\|5
+--R     + 
+--R                  +---------------+                  +---------------+
+--R                  |      +-+                         |      +-+
+--R         4+-+ +-+ |- 199\|5  + 445         +-+       |- 199\|5  + 445
+--R       - \|2 \|5  |--------------- log((18\|5  + 40) |---------------  + x)
+--R                  |        +-+                       |        +-+
+--R                 \|     40\|5                       \|     40\|5
+--R     + 
+--R                +---------------+                    +---------------+
+--R                |      +-+                           |      +-+
+--R       4+-+ +-+ |- 199\|5  + 445           +-+       |- 199\|5  + 445
+--R       \|2 \|5  |--------------- log((- 18\|5  - 40) |---------------  + x)
+--R                |        +-+                         |        +-+
+--R               \|     40\|5                         \|     40\|5
+--R     + 
+--R                  +-------------+                    +-------------+
+--R                  |    +-+                           |    +-+
+--R         4+-+ +-+ |199\|5  + 445           +-+       |199\|5  + 445
+--R       - \|2 \|5  |------------- log((- 18\|5  + 40) |-------------  + x)
+--R                  |       +-+                        |       +-+
+--R                 \|    40\|5                        \|    40\|5
+--R     + 
+--R                                            +--------+
+--R          +-----------------+        4+-+3 4| +-+
+--R         4|      +-+               x \|2   \|\|5  + 3
+--R       - \|17711\|5  + 39603 atanh(------------------)
+--R                                            2
+--R     + 
+--R                                         +----------+
+--R        +-------------------+       4+-+4|   +-+
+--R       4|        +-+               x\|2 \|- \|5  + 3
+--R       \|- 17711\|5  + 39603 atanh(------------------)
+--R                                           +-+
+--R                                          \|2
+--R     + 
+--R                                           +--------+
+--R          +-----------------+       4+-+3 4| +-+
+--R         4|      +-+              x \|2   \|\|5  + 3
+--R       - \|17711\|5  + 39603 atan(------------------)
+--R                                           2
+--R     + 
+--R                                                     +-------------+
+--R                                                     |    +-+
+--R                                           +-+       |199\|5  + 445
+--R                   +-------------+     (18\|5  - 40) |-------------
+--R                   |    +-+                          |       +-+
+--R          4+-+ +-+ |199\|5  + 445                   \|    40\|5
+--R       - 2\|2 \|5  |------------- atan(-----------------------------)
+--R                   |       +-+                       x
+--R                  \|    40\|5
+--R     + 
+--R                                                     +---------------+
+--R                                                     |      +-+
+--R                                           +-+       |- 199\|5  + 445
+--R                 +---------------+     (18\|5  + 40) |---------------
+--R                 |      +-+                          |        +-+
+--R        4+-+ +-+ |- 199\|5  + 445                   \|     40\|5
+--R       2\|2 \|5  |--------------- atan(-------------------------------)
+--R                 |        +-+                         x
+--R                \|     40\|5
+--R     + 
+--R                                        +----------+
+--R        +-------------------+      4+-+4|   +-+
+--R       4|        +-+              x\|2 \|- \|5  + 3
+--R       \|- 17711\|5  + 39603 atan(------------------)
+--R                                          +-+
+--R                                         \|2
+--R  /
+--R      4+-+ +-+
+--R     2\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 1610
+
+--S 1611 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                             +--------+ +-----------------+
+--R           4      +-+     4 4| +-+     4|      +-+
+--R       ((3x  - 2)\|5  - 5x )\|\|5  + 3 \|17711\|5  + 39603
+--R     + 
+--R                               +-------------------+ +----------+
+--R             4      +-+     4 4|        +-+         4|   +-+
+--R       ((- 3x  + 2)\|5  - 5x )\|- 17711\|5  + 39603 \|- \|5  + 3
+--R     + 
+--R             4      4+-+2
+--R       (- 30x  + 80)\|2
+--R  /
+--R         8      4      4+-+2
+--R     (10x  - 30x  + 10)\|2
+--R                                                    Type: Expression(Integer)
+--E 1611
+
+)clear all
+
+--S 1612 of 2282
+t0:=x^3/(2+3*x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1612
+
+--S 1613 of 2282
+r0:=-1/2*atanh(3+2*x^4)
+--R 
+--R
+--R                  4
+--R          atanh(2x  + 3)
+--R   (2)  - --------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 1613
+
+--S 1614 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4             4
+--R        - log(x  + 2) + log(x  + 1)
+--R   (3)  ---------------------------
+--R                     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1614
+
+--S 1615 of 2282
+m0:=a0-r0
+--R 
+--R
+--R               4             4                 4
+--R        - log(x  + 2) + log(x  + 1) + 2atanh(2x  + 3)
+--R   (4)  ---------------------------------------------
+--R                              4
+--R                                                    Type: Expression(Integer)
+--E 1615
+
+--S 1616 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1616
+
+)clear all
+
+--S 1617 of 2282
+t0:=x^11/(2+3*x^4+x^8)
+--R 
+--R
+--R              11
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1617
+
+--S 1618 of 2282
+r0:=1/4*x^4+1/4*log(1+x^4)-log(2+x^4)
+--R 
+--R
+--R                4             4         4
+--R        - 4log(x  + 2) + log(x  + 1) + x
+--R   (2)  ---------------------------------
+--R                        4
+--R                                                    Type: Expression(Integer)
+--E 1618
+
+--S 1619 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                4             4         4
+--R        - 4log(x  + 2) + log(x  + 1) + x
+--R   (3)  ---------------------------------
+--R                        4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1619
+
+--S 1620 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1620
+
+--S 1621 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1621
+
+)clear all
+
+--S 1622 of 2282
+t0:=x^9/(2+x^5+x^10)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         10    5
+--R        x   + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1622
+
+--S 1623 of 2282
+r0:=1/10*log(2+x^5+x^10)-1/5*atan((1+2*x^5)/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                                         5      +-+
+--R         +-+     10    5              (2x  + 1)\|7
+--R        \|7 log(x   + x  + 2) - 2atan(-------------)
+--R                                            7
+--R   (2)  --------------------------------------------
+--R                              +-+
+--R                           10\|7
+--R                                                    Type: Expression(Integer)
+--E 1623
+
+--S 1624 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                         5      +-+
+--R         +-+     10    5              (2x  + 1)\|7
+--R        \|7 log(x   + x  + 2) - 2atan(-------------)
+--R                                            7
+--R   (3)  --------------------------------------------
+--R                              +-+
+--R                           10\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 1624
+
+--S 1625 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1625
+
+--S 1626 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1626
+
+)clear all
+
+--S 1627 of 2282
+t0:=x^4/(2+x^5+x^10)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         10    5
+--R        x   + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1627
+
+--S 1628 of 2282
+r0:=2/5*atan((1+2*x^5)/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                 5      +-+
+--R              (2x  + 1)\|7
+--R        2atan(-------------)
+--R                    7
+--R   (2)  --------------------
+--R                  +-+
+--R                5\|7
+--R                                                    Type: Expression(Integer)
+--E 1628
+
+--S 1629 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 5      +-+
+--R              (2x  + 1)\|7
+--R        2atan(-------------)
+--R                    7
+--R   (3)  --------------------
+--R                  +-+
+--R                5\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 1629
+
+--S 1630 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1630
+
+--S 1631 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1631
+
+)clear all
+
+--S 1632 of 2282
+t0:=1/(x*(1+x^5+x^10))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         11    6
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1632
+
+--S 1633 of 2282
+r0:=log(x)-1/10*log(1+x^5+x^10)-1/5*atan((1+2*x^5)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                          5      +-+
+--R           +-+     10    5           +-+               (2x  + 1)\|3
+--R        - \|3 log(x   + x  + 1) + 10\|3 log(x) - 2atan(-------------)
+--R                                                             3
+--R   (2)  -------------------------------------------------------------
+--R                                       +-+
+--R                                    10\|3
+--R                                                    Type: Expression(Integer)
+--E 1633
+
+--S 1634 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                          5      +-+
+--R           +-+     10    5           +-+               (2x  + 1)\|3
+--R        - \|3 log(x   + x  + 1) + 10\|3 log(x) - 2atan(-------------)
+--R                                                             3
+--R   (3)  -------------------------------------------------------------
+--R                                       +-+
+--R                                    10\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1634
+
+--S 1635 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1635
+
+--S 1636 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1636
+
+)clear all
+
+--S 1637 of 2282
+t0:=1/(x^6*(1+x^5+x^10))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         16    11    6
+--R        x   + x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1637
+
+--S 1638 of 2282
+r0:=(-1/5)/x^5-log(x)+1/10*log(1+x^5+x^10)-1/5*atan((1+2*x^5)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                         5      +-+
+--R    5 +-+     10    5           5 +-+           5     (2x  + 1)\|3       +-+
+--R   x \|3 log(x   + x  + 1) - 10x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                            3
+--R   -------------------------------------------------------------------------
+--R                                       5 +-+
+--R                                    10x \|3
+--R                                                    Type: Expression(Integer)
+--E 1638
+
+--S 1639 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                         5      +-+
+--R    5 +-+     10    5           5 +-+           5     (2x  + 1)\|3       +-+
+--R   x \|3 log(x   + x  + 1) - 10x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                            3
+--R   -------------------------------------------------------------------------
+--R                                       5 +-+
+--R                                    10x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1639
+
+--S 1640 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1640
+
+--S 1641 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1641
+
+)clear all
+
+--S 1642 of 2282
+t0:=1/(x+x^6+x^11)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         11    6
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1642
+
+--S 1643 of 2282
+r0:=log(x)-1/10*log(1+x^5+x^10)-1/5*atan((1+2*x^5)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                          5      +-+
+--R           +-+     10    5           +-+               (2x  + 1)\|3
+--R        - \|3 log(x   + x  + 1) + 10\|3 log(x) - 2atan(-------------)
+--R                                                             3
+--R   (2)  -------------------------------------------------------------
+--R                                       +-+
+--R                                    10\|3
+--R                                                    Type: Expression(Integer)
+--E 1643
+
+--S 1644 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                          5      +-+
+--R           +-+     10    5           +-+               (2x  + 1)\|3
+--R        - \|3 log(x   + x  + 1) + 10\|3 log(x) - 2atan(-------------)
+--R                                                             3
+--R   (3)  -------------------------------------------------------------
+--R                                       +-+
+--R                                    10\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1644
+
+--S 1645 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1645
+
+--S 1646 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1646
+
+)clear all
+
+--S 1647 of 2282
+t0:=x^(-1+4*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            4n - 1
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1647
+
+--S 1648 of 2282
+r0:=-b*x^n/(c^2*n)+1/2*x^(2*n)/(c*n)+b^2*log(b+c*x^n)/(c^3*n)
+--R 
+--R
+--R          2       n         2 2n         n
+--R        2b log(c x  + b) + c x   - 2b c x
+--R   (2)  ----------------------------------
+--R                         3
+--R                       2c n
+--R                                                    Type: Expression(Integer)
+--E 1648
+
+--S 1649 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2        n log(x)         2   n log(x) 2          n log(x)
+--R        2b log(c %e         + b) + c (%e        )  - 2b c %e
+--R   (3)  ------------------------------------------------------------
+--R                                      3
+--R                                    2c n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1649
+
+--S 1650 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         2        n log(x)          2       n         2   n log(x) 2
+--R       2b log(c %e         + b) - 2b log(c x  + b) + c (%e        )
+--R     + 
+--R                n log(x)    2 2n         n
+--R       - 2b c %e         - c x   + 2b c x
+--R  /
+--R       3
+--R     2c n
+--R                                                    Type: Expression(Integer)
+--E 1650
+
+--S 1651 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1651
+
+)clear all
+
+--S 1652 of 2282
+t0:=x^(-1+3*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            3n - 1
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1652
+
+--S 1653 of 2282
+r0:=x^n/(c*n)-b*log(b+c*x^n)/(c^2*n)
+--R 
+--R
+--R                   n           n
+--R        - b log(c x  + b) + c x
+--R   (2)  ------------------------
+--R                    2
+--R                   c n
+--R                                                    Type: Expression(Integer)
+--E 1653
+
+--S 1654 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    n log(x)            n log(x)
+--R        - b log(c %e         + b) + c %e
+--R   (3)  ----------------------------------------
+--R                            2
+--R                           c n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1654
+
+--S 1655 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                    n log(x)                 n            n log(x)      n
+--R        - b log(c %e         + b) + b log(c x  + b) + c %e         - c x
+--R   (4)  -----------------------------------------------------------------
+--R                                        2
+--R                                       c n
+--R                                                    Type: Expression(Integer)
+--E 1655
+
+--S 1656 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1656
+
+)clear all
+
+--S 1657 of 2282
+t0:=x^(-1+2*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            2n - 1
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1657
+
+--S 1658 of 2282
+r0:=log(b+c*x^n)/(c*n)
+--R 
+--R
+--R               n
+--R        log(c x  + b)
+--R   (2)  -------------
+--R             c n
+--R                                                    Type: Expression(Integer)
+--E 1658
+
+--S 1659 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                n log(x)
+--R        log(c %e         + b)
+--R   (3)  ---------------------
+--R                 c n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1659
+
+--S 1660 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                n log(x)               n
+--R        log(c %e         + b) - log(c x  + b)
+--R   (4)  -------------------------------------
+--R                         c n
+--R                                                    Type: Expression(Integer)
+--E 1660
+
+--S 1661 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1661
+
+)clear all
+
+--S 1662 of 2282
+t0:=x^(-1+n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 1
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1662
+
+--S 1663 of 2282
+r0:=log(x)/b-log(b+c*x^n)/(b*n)
+--R 
+--R
+--R                 n
+--R        - log(c x  + b) + n log(x)
+--R   (2)  --------------------------
+--R                    b n
+--R                                                    Type: Expression(Integer)
+--E 1663
+
+--S 1664 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  n log(x)
+--R        - log(c %e         + b) + n log(x)
+--R   (3)  ----------------------------------
+--R                        b n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1664
+
+--S 1665 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                  n log(x)               n
+--R        - log(c %e         + b) + log(c x  + b)
+--R   (4)  ---------------------------------------
+--R                          b n
+--R                                                    Type: Expression(Integer)
+--E 1665
+
+--S 1666 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1666
+
+)clear all
+
+--S 1667 of 2282
+t0:=x^(-1-n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - n - 1
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1667
+
+--S 1668 of 2282
+r0:=(-1/2)/(b*n*x^(2*n))+c/(b^2*n*x^n)+c^2*log(x)/b^3-c^2*log(b+c*x^n)/(b^3*n)
+--R 
+--R
+--R            2 n 2n       n           2         n         2n    2 n
+--R        - 2c x x  log(c x  + b) + (2c n log(x)x  + 2b c)x   - b x
+--R   (2)  ----------------------------------------------------------
+--R                                  3   n 2n
+--R                                2b n x x
+--R                                                    Type: Expression(Integer)
+--E 1668
+
+--S 1669 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2   n log(x) 2        n log(x)          2           n log(x) 2
+--R       - 2c (%e        ) log(c %e         + b) + 2c n log(x)(%e        )
+--R     + 
+--R              n log(x)    2
+--R       2b c %e         - b
+--R  /
+--R       3     n log(x) 2
+--R     2b n (%e        )
+--R                                         Type: Union(Expression(Integer),...)
+--E 1669
+
+--S 1670 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2 n 2n   n log(x) 2        n log(x)
+--R       - 2c x x  (%e        ) log(c %e         + b)
+--R     + 
+--R         2 n 2n   n log(x) 2       n                 2n    2 n    n log(x) 2
+--R       2c x x  (%e        ) log(c x  + b) + (- 2b c x   + b x )(%e        )
+--R     + 
+--R             n 2n  n log(x)    2 n 2n
+--R       2b c x x  %e         - b x x
+--R  /
+--R       3   n 2n   n log(x) 2
+--R     2b n x x  (%e        )
+--R                                                    Type: Expression(Integer)
+--E 1670
+
+--S 1671 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1671
+
+)clear all
+
+--S 1672 of 2282
+t0:=x^(-1-2*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - 2n - 1
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1672
+
+--S 1673 of 2282
+r0:=(-1/3)/(b*n*x^(3*n))+1/2*c/(b^2*n*x^(2*n))-c^2/(b^3*n*x^n)-_
+   c^3*log(x)/b^4+c^3*log(b+c*x^n)/(b^4*n)
+--R 
+--R
+--R   (2)
+--R         3 n 2n 3n       n              3         n       2  2n     2   n  3n
+--R       6c x x  x  log(c x  + b) + ((- 6c n log(x)x  - 6b c )x   + 3b c x )x
+--R     + 
+--R           3 n 2n
+--R       - 2b x x
+--R  /
+--R       4   n 2n 3n
+--R     6b n x x  x
+--R                                                    Type: Expression(Integer)
+--E 1673
+
+--S 1674 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3   n log(x) 3        n log(x)          3           n log(x) 3
+--R       6c (%e        ) log(c %e         + b) - 6c n log(x)(%e        )
+--R     + 
+--R             2   n log(x) 2     2    n log(x)     3
+--R       - 6b c (%e        )  + 3b c %e         - 2b
+--R  /
+--R       4     n log(x) 3
+--R     6b n (%e        )
+--R                                         Type: Union(Expression(Integer),...)
+--E 1674
+
+--S 1675 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         3 n 2n 3n   n log(x) 3        n log(x)
+--R       6c x x  x  (%e        ) log(c %e         + b)
+--R     + 
+--R           3 n 2n 3n   n log(x) 3       n
+--R       - 6c x x  x  (%e        ) log(c x  + b)
+--R     + 
+--R             2 2n     2   n  3n     3 n 2n    n log(x) 3
+--R       ((6b c x   - 3b c x )x   + 2b x x  )(%e        )
+--R     + 
+--R             2 n 2n 3n   n log(x) 2     2   n 2n 3n  n log(x)     3 n 2n 3n
+--R       - 6b c x x  x  (%e        )  + 3b c x x  x  %e         - 2b x x  x
+--R  /
+--R       4   n 2n 3n   n log(x) 3
+--R     6b n x x  x  (%e        )
+--R                                                    Type: Expression(Integer)
+--E 1675
+
+--S 1676 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1676
+
+)clear all
+
+--S 1677 of 2282
+t0:=x^(-1-3*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - 3n - 1
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1677
+
+--S 1678 of 2282
+r0:=(-1/4)/(b*n*x^(4*n))+1/3*c/(b^2*n*x^(3*n))-1/2*c^2/(b^3*n*x^(2*n))+_
+   c^3/(b^4*n*x^n)+c^4*log(x)/b^5-c^4*log(b+c*x^n)/(b^5*n)
+--R 
+--R
+--R   (2)
+--R            4 n 2n 3n 4n       n
+--R       - 12c x x  x  x  log(c x  + b)
+--R     + 
+--R           4         n        3  2n     2 2 n  3n     3   n 2n  4n     4 n 2n 3n
+--R     (((12c n log(x)x  + 12b c )x   - 6b c x )x   + 4b c x x  )x   - 3b x x  x
+--R  /
+--R        5   n 2n 3n 4n
+--R     12b n x x  x  x
+--R                                                    Type: Expression(Integer)
+--E 1678
+
+--S 1679 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4   n log(x) 4        n log(x)           4           n log(x) 4
+--R       - 12c (%e        ) log(c %e         + b) + 12c n log(x)(%e        )
+--R     + 
+--R            3   n log(x) 3     2 2   n log(x) 2     3    n log(x)     4
+--R       12b c (%e        )  - 6b c (%e        )  + 4b c %e         - 3b
+--R  /
+--R        5     n log(x) 4
+--R     12b n (%e        )
+--R                                         Type: Union(Expression(Integer),...)
+--E 1679
+
+--S 1680 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            4 n 2n 3n 4n   n log(x) 4        n log(x)
+--R       - 12c x x  x  x  (%e        ) log(c %e         + b)
+--R     + 
+--R          4 n 2n 3n 4n   n log(x) 4       n
+--R       12c x x  x  x  (%e        ) log(c x  + b)
+--R     + 
+--R                 3 2n     2 2 n  3n     3   n 2n  4n     4 n 2n 3n    n log(x) 4
+--R       (((- 12b c x   + 6b c x )x   - 4b c x x  )x   + 3b x x  x  )(%e        )
+--R     + 
+--R            3 n 2n 3n 4n   n log(x) 3     2 2 n 2n 3n 4n   n log(x) 2
+--R       12b c x x  x  x  (%e        )  - 6b c x x  x  x  (%e        )
+--R     + 
+--R         3   n 2n 3n 4n  n log(x)     4 n 2n 3n 4n
+--R       4b c x x  x  x  %e         - 3b x x  x  x
+--R  /
+--R        5   n 2n 3n 4n   n log(x) 4
+--R     12b n x x  x  x  (%e        )
+--R                                                    Type: Expression(Integer)
+--E 1680
+
+--S 1681 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1681
+
+)clear all
+
+--S 1682 of 2282
+t0:=x^(-1+1/4*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 4
+--R            -----
+--R              4
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1682
+
+--S 1683 of 2282
+r0:=(-4/3)/(b*n*x^(3/4*n))+c^(3/4)*log(-b^(1/4)*c^(1/4)*x^(1/4*n)*sqrt(2)+_
+   sqrt(b)+x^(1/2*n)*sqrt(c))/(b^(7/4)*n*sqrt(2))-c^(3/4)*_
+   log(b^(1/4)*c^(1/4)*x^(1/4*n)*sqrt(2)+sqrt(b)+x^(1/2*n)*_
+   sqrt(c))/(b^(7/4)*n*sqrt(2))+c^(3/4)*atan(1-c^(1/4)*x^(1/4*n)*_
+   sqrt(2)/b^(1/4))*sqrt(2)/(b^(7/4)*n)-c^(3/4)*atan(1+c^(1/4)*_
+   x^(1/4*n)*sqrt(2)/b^(1/4))*sqrt(2)/(b^(7/4)*n)
+--R 
+--R
+--R   (2)
+--R           3n               n            n
+--R           --               -            -
+--R            4 4+-+3     +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       - 3x   \|c  log(\|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R         3n                 n            n
+--R         --                 -            -
+--R          4 4+-+3       +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       3x   \|c  log(- \|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R                             n                                  n
+--R           3n                -                3n                -
+--R           --            +-+ 4 4+-+  4+-+     --            +-+ 4 4+-+  4+-+
+--R            4 4+-+3     \|2 x  \|c + \|b       4 4+-+3     \|2 x  \|c - \|b
+--R       - 6x   \|c  atan(----------------- - 6x   \|c  atan(-----------------)
+--R                               4+-+                               4+-+
+--R                               \|b                                \|b
+--R     + 
+--R           +-+4+-+3
+--R       - 4\|2 \|b
+--R  /
+--R              3n
+--R              --
+--R          +-+  4 4+-+3
+--R     3b n\|2 x   \|b
+--R                                                    Type: Expression(Integer)
+--E 1683
+
+--S 1684 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                     +------+   (n - 4)log(x) 3
+--R                     |    3     -------------
+--R                  3  |   c            4
+--R            3b n x   |- ---- (%e             )
+--R                    4|   7 4
+--R                    \|  b n
+--R         *
+--R                      (n - 4)log(x)        +------+
+--R                      -------------        |    3
+--R                            4          2   |   c
+--R                c x %e              + b n  |- ----
+--R                                          4|   7 4
+--R                                          \|  b n
+--R            log(----------------------------------)
+--R                                 x
+--R     + 
+--R                                                    (n - 4)log(x)        +------+
+--R                                                    -------------        |    3
+--R                                                          4          2   |   c
+--R                +------+   (n - 4)log(x) 3    c x %e              - b n  |- ----
+--R                |    3     -------------                                4|   7 4
+--R             3  |   c            4                                      \|  b n
+--R       3b n x   |- ---- (%e             ) log(----------------------------------)
+--R               4|   7 4                                        x
+--R               \|  b n
+--R     + 
+--R                                                        +------+
+--R                                                        |    3
+--R                                                    2   |   c
+--R                +------+   (n - 4)log(x) 3         b n  |- ----
+--R                |    3     -------------               4|   7 4
+--R             3  |   c            4                     \|  b n
+--R       6b n x   |- ---- (%e             ) atan(------------------- - 4
+--R               4|   7 4                              (n - 4)log(x)
+--R               \|  b n                               -------------
+--R                                                           4
+--R                                               c x %e
+--R  /
+--R               (n - 4)log(x) 3
+--R               -------------
+--R           3         4
+--R     3b n x (%e             )
+--R                                         Type: Union(Expression(Integer),...)
+--E 1684
+
+--S 1685 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        3n  +------+        (n - 4)log(x) 3
+--R                        --  |    3          -------------
+--R                  3 +-+  4  |   c   4+-+3         4
+--R            3b n x \|2 x    |- ---- \|b  (%e             )
+--R                           4|   7 4
+--R                           \|  b n
+--R         *
+--R                      (n - 4)log(x)        +------+
+--R                      -------------        |    3
+--R                            4          2   |   c
+--R                c x %e              + b n  |- ----
+--R                                          4|   7 4
+--R                                          \|  b n
+--R            log(----------------------------------)
+--R                                 x
+--R     + 
+--R                     3n  +------+        (n - 4)log(x) 3
+--R                     --  |    3          -------------
+--R               3 +-+  4  |   c   4+-+3         4
+--R         3b n x \|2 x    |- ---- \|b  (%e             )
+--R                        4|   7 4
+--R                        \|  b n
+--R      *
+--R                   (n - 4)log(x)        +------+
+--R                   -------------        |    3
+--R                         4          2   |   c
+--R             c x %e              - b n  |- ----
+--R                                       4|   7 4
+--R                                       \|  b n
+--R         log(----------------------------------)
+--R                              x
+--R     + 
+--R                                                                    +------+
+--R                                                                    |    3
+--R                                                                2   |   c
+--R                   3n  +------+        (n - 4)log(x) 3         b n  |- ----
+--R                   --  |    3          -------------               4|   7 4
+--R             3 +-+  4  |   c   4+-+3         4                     \|  b n
+--R       6b n x \|2 x    |- ---- \|b  (%e             ) atan(-------------------)
+--R                      4|   7 4                                   (n - 4)log(x)
+--R                      \|  b n                                    -------------
+--R                                                                       4
+--R                                                           c x %e
+--R     + 
+--R           3n         (n - 4)log(x) 3         n            n
+--R           --         -------------           -            -
+--R         3  4 4+-+3         4             +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       3x x   \|c  (%e             ) log(\|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R             3n         (n - 4)log(x) 3           n            n
+--R             --         -------------             -            -
+--R           3  4 4+-+3         4               +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       - 3x x   \|c  (%e             ) log(- \|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R                                 n
+--R               3n                -
+--R               --            +-+ 4 4+-+  4+-+
+--R             3  4 4+-+3     \|2 x  \|c + \|b
+--R           6x x   \|c  atan(-----------------)
+--R                                   4+-+
+--R                                   \|b
+--R         + 
+--R                                 n
+--R               3n                -
+--R               --            +-+ 4 4+-+  4+-+
+--R             3  4 4+-+3     \|2 x  \|c - \|b      3 +-+4+-+3
+--R           6x x   \|c  atan(----------------- + 4x \|2 \|b
+--R                                   4+-+
+--R                                   \|b
+--R      *
+--R            (n - 4)log(x) 3
+--R            -------------
+--R                  4
+--R         (%e             )
+--R     + 
+--R               3n
+--R               --
+--R           +-+  4 4+-+3
+--R       - 4\|2 x   \|b
+--R  /
+--R                 3n         (n - 4)log(x) 3
+--R                 --         -------------
+--R           3 +-+  4 4+-+3         4
+--R     3b n x \|2 x   \|b  (%e             )
+--R                                                    Type: Expression(Integer)
+--E 1685
+
+--S 1686 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1686
+
+)clear all
+
+--S 1687 of 2282
+t0:=x^(-1+1/3*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 3
+--R            -----
+--R              3
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1687
+
+--S 1688 of 2282
+r0:=(-3/2)/(b*n*x^(2/3*n))-c^(2/3)*log(b^(1/3)+c^(1/3)*x^(1/3*n))/_
+   (b^(5/3)*n)+1/2*c^(2/3)*log(b^(2/3)-b^(1/3)*c^(1/3)*x^(1/3*n)+_
+   c^(2/3)*x^(2/3*n))/(b^(5/3)*n)+c^(2/3)*atan((b^(1/3)-_
+   2*c^(1/3)*x^(1/3*n))/(b^(1/3)*sqrt(3)))*sqrt(3)/(b^(5/3)*n)
+--R 
+--R
+--R   (2)
+--R        2n           2n         n                     2n           n
+--R        --           --         -                     --           -
+--R         3 3+-+2      3 3+-+2   3 3+-+3+-+  3+-+2      3 3+-+2     3 3+-+  3+-+
+--R       x   \|c  log(x   \|c  - x  \|b \|c + \|b   - 2x   \|c  log(x  \|c + \|b )
+--R     + 
+--R                              n
+--R               2n             -
+--R               --             3 3+-+  3+-+
+--R           +-+  3 3+-+2     2x  \|c - \|b     3+-+2
+--R       - 2\|3 x   \|c  atan(-------------- - 3\|b
+--R                                +-+3+-+
+--R                               \|3 \|b
+--R  /
+--R           2n
+--R           --
+--R            3 3+-+2
+--R     2b n x   \|b
+--R                                                    Type: Expression(Integer)
+--E 1688
+
+--S 1689 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                +----+   (n - 3)log(x) 2
+--R                |   2    -------------
+--R             2  |  c           3
+--R            x   |- -- (%e             )
+--R               3|   2
+--R               \|  b
+--R         *
+--R                     (n - 3)log(x) 2          +----+  (n - 3)log(x)      +----+2
+--R                     -------------            |   2   -------------      |   2
+--R               2 2         3                  |  c          3         2  |  c
+--R              c x (%e             )  + b c x  |- -- %e             + b   |- --
+--R                                             3|   2                     3|   2
+--R                                             \|  b                      \|  b
+--R          log(-----------------------------------------------------------------)
+--R                                               2
+--R                                              x
+--R     + 
+--R                                              (n - 3)log(x)      +----+
+--R                                              -------------      |   2
+--R                                                    3            |  c
+--R            +----+   (n - 3)log(x) 2    c x %e              - b  |- --
+--R            |   2    -------------                              3|   2
+--R         2  |  c           3                                    \|  b
+--R       2x   |- -- (%e             ) log(------------------------------)
+--R           3|   2                                      x
+--R           \|  b
+--R     + 
+--R                                                    (n - 3)log(x)      +----+
+--R                                                    -------------      |   2
+--R                                                          3            |  c
+--R                +----+   (n - 3)log(x) 2     2c x %e              + b  |- --
+--R                |   2    -------------                                3|   2
+--R         2 +-+  |  c           3                                      \|  b
+--R     - 2x \|3   |- -- (%e             ) atan(------------------------------- - 3
+--R               3|   2                                         +----+
+--R               \|  b                                          |   2
+--R                                                         +-+  |  c
+--R                                                       b\|3   |- --
+--R                                                             3|   2
+--R                                                             \|  b
+--R  /
+--R               (n - 3)log(x) 2
+--R               -------------
+--R           2         3
+--R     2b n x (%e             )
+--R                                         Type: Union(Expression(Integer),...)
+--E 1689
+
+--S 1690 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R               2n  +----+        (n - 3)log(x) 2
+--R               --  |   2         -------------
+--R             2  3  |  c  3+-+2         3
+--R            x x    |- -- \|b  (%e             )
+--R                  3|   2
+--R                  \|  b
+--R         *
+--R                     (n - 3)log(x) 2          +----+  (n - 3)log(x)      +----+2
+--R                     -------------            |   2   -------------      |   2
+--R               2 2         3                  |  c          3         2  |  c
+--R              c x (%e             )  + b c x  |- -- %e             + b   |- --
+--R                                             3|   2                     3|   2
+--R                                             \|  b                      \|  b
+--R          log(-----------------------------------------------------------------)
+--R                                               2
+--R                                              x
+--R     + 
+--R                                                      (n - 3)log(x)      +----+
+--R                                                      -------------      |   2
+--R                                                            3            |  c
+--R           2n  +----+        (n - 3)log(x) 2    c x %e              - b  |- --
+--R           --  |   2         -------------                              3|   2
+--R         2  3  |  c  3+-+2         3                                    \|  b
+--R       2x x    |- -- \|b  (%e             ) log(------------------------------)
+--R              3|   2                                           x
+--R              \|  b
+--R     + 
+--R       -
+--R                    2n  +----+        (n - 3)log(x) 2
+--R                    --  |   2         -------------
+--R              2 +-+  3  |  c  3+-+2         3
+--R            2x \|3 x    |- -- \|b  (%e             )
+--R                       3|   2
+--R                       \|  b
+--R         *
+--R                        (n - 3)log(x)      +----+
+--R                        -------------      |   2
+--R                              3            |  c
+--R                 2c x %e              + b  |- --
+--R                                          3|   2
+--R                                          \|  b
+--R            atan(-------------------------------)
+--R                                  +----+
+--R                                  |   2
+--R                             +-+  |  c
+--R                           b\|3   |- --
+--R                                 3|   2
+--R                                 \|  b
+--R     + 
+--R            2n         (n - 3)log(x) 2     2n         n
+--R            --         -------------       --         -
+--R          2  3 3+-+2         3              3 3+-+2   3 3+-+3+-+  3+-+2
+--R       - x x   \|c  (%e             ) log(x   \|c  - x  \|b \|c + \|b  )
+--R     + 
+--R           2n         (n - 3)log(x) 2     n
+--R           --         -------------       -
+--R         2  3 3+-+2         3             3 3+-+  3+-+
+--R       2x x   \|c  (%e             ) log(x  \|c + \|b )
+--R     + 
+--R                               n
+--R                2n             -                          (n - 3)log(x) 2
+--R                --             3 3+-+  3+-+               -------------
+--R          2 +-+  3 3+-+2     2x  \|c - \|b      2 3+-+2         3
+--R       (2x \|3 x   \|c  atan(-------------- + 3x  \|b )(%e             )
+--R                                 +-+3+-+
+--R                                \|3 \|b
+--R     + 
+--R           2n
+--R           --
+--R            3 3+-+2
+--R       - 3x   \|b
+--R  /
+--R             2n         (n - 3)log(x) 2
+--R             --         -------------
+--R           2  3 3+-+2         3
+--R     2b n x x   \|b  (%e             )
+--R                                                    Type: Expression(Integer)
+--E 1690
+
+--S 1691 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1691
+
+)clear all
+
+--S 1692 of 2282
+t0:=x^(-1+1/2*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 2
+--R            -----
+--R              2
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1692
+
+--S 1693 of 2282
+r0:=(-2)/(b*n*x^(1/2*n))-2*atan(x^(1/2*n)*sqrt(c)/sqrt(b))*sqrt(c)/(b^(3/2)*n)
+--R 
+--R
+--R                       n
+--R            n          -
+--R            -          2 +-+
+--R            2 +-+     x \|c       +-+
+--R        - 2x \|c atan(------) - 2\|b
+--R                        +-+
+--R                       \|b
+--R   (2)  -----------------------------
+--R                       n
+--R                       -
+--R                       2 +-+
+--R                  b n x \|b
+--R                                                    Type: Expression(Integer)
+--E 1693
+
+--S 1694 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    (n - 2)log(x)
+--R             +---+  -------------
+--R             |  c         2
+--R           x |- - %e
+--R            \|  b
+--R        *
+--R                      (n - 2)log(x) 2               (n - 2)log(x)
+--R                      -------------          +---+  -------------
+--R                  2         2                |  c         2
+--R               c x (%e             )  - 2b x |- - %e              - b
+--R                                            \|  b
+--R           log(------------------------------------------------------)
+--R                                    (n - 2)log(x) 2
+--R                                    -------------
+--R                                2         2
+--R                             c x (%e             )  + b
+--R       + 
+--R         - 2
+--R    /
+--R               (n - 2)log(x)
+--R               -------------
+--R                     2
+--R       b n x %e
+--R     ,
+--R                                      (n - 2)log(x)
+--R              (n - 2)log(x)           -------------
+--R         +-+  -------------                 2
+--R         |c         2           c x %e
+--R    - 2x |- %e             atan(-------------------) - 2
+--R        \|b                              +-+
+--R                                         |c
+--R                                       b |-
+--R                                        \|b
+--R    ----------------------------------------------------]
+--R                            (n - 2)log(x)
+--R                            -------------
+--R                                  2
+--R                    b n x %e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1694
+
+--S 1695 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            n            (n - 2)log(x)
+--R            - +---+      -------------
+--R            2 |  c  +-+        2
+--R         x x  |- - \|b %e
+--R             \|  b
+--R      *
+--R                    (n - 2)log(x) 2               (n - 2)log(x)
+--R                    -------------          +---+  -------------
+--R                2         2                |  c         2
+--R             c x (%e             )  - 2b x |- - %e              - b
+--R                                          \|  b
+--R         log(------------------------------------------------------)
+--R                                  (n - 2)log(x) 2
+--R                                  -------------
+--R                              2         2
+--R                           c x (%e             )  + b
+--R     + 
+--R                       n
+--R            n          -                 (n - 2)log(x)     n
+--R            -          2 +-+             -------------     -
+--R            2 +-+     x \|c        +-+         2           2 +-+
+--R       (2x x \|c atan(------) + 2x\|b )%e              - 2x \|b
+--R                        +-+
+--R                       \|b
+--R  /
+--R            n      (n - 2)log(x)
+--R            -      -------------
+--R            2 +-+        2
+--R     b n x x \|b %e
+--R                                                    Type: Expression(Integer)
+--E 1695
+
+--S 1696 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1696
+
+--S 1697 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                (n - 2)log(x)
+--R             n          (n - 2)log(x)           -------------
+--R             -     +-+  -------------                 2
+--R             2 +-+ |c         2           c x %e
+--R       - 2x x \|b  |- %e             atan(-------------------)
+--R                  \|b                              +-+
+--R                                                   |c
+--R                                                 b |-
+--R                                                  \|b
+--R     + 
+--R                       n
+--R            n          -                 (n - 2)log(x)     n
+--R            -          2 +-+             -------------     -
+--R            2 +-+     x \|c        +-+         2           2 +-+
+--R       (2x x \|c atan(------) + 2x\|b )%e              - 2x \|b
+--R                        +-+
+--R                       \|b
+--R  /
+--R            n      (n - 2)log(x)
+--R            -      -------------
+--R            2 +-+        2
+--R     b n x x \|b %e
+--R                                                    Type: Expression(Integer)
+--E 1697
+
+--S 1698 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1698
+
+)clear all
+
+--S 1699 of 2282
+t0:=x^(-1-1/2*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - n - 2
+--R           -------
+--R              2
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1699
+
+--S 1700 of 2282
+r0:=(-2/3)/(b*n*x^(3/2*n))+2*c/(b^2*n*x^(1/2*n))+2*c^(3/2)*atan(x^(1/2*n)*_
+   sqrt(c)/sqrt(b))/(b^(5/2)*n)
+--R 
+--R
+--R                          n
+--R            n 3n          -             3n       n
+--R            - --          2 +-+         --       -
+--R            2  2 +-+     x \|c           2       2  +-+
+--R        6c x x  \|c atan(------) + (6c x   - 2b x )\|b
+--R                           +-+
+--R                          \|b
+--R   (2)  -----------------------------------------------
+--R                               n 3n
+--R                               - --
+--R                           2   2  2 +-+
+--R                         3b n x x  \|b
+--R                                                    Type: Expression(Integer)
+--E 1700
+
+--S 1701 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            (- n - 2)log(x) 2               (- n - 2)log(x)
+--R                            ---------------          +---+  ---------------
+--R                        2          2                 |  c          2
+--R            +---+    b x (%e               )  - 2b x |- - %e                - c
+--R            |  c                                    \|  b
+--R         3c |- - log(----------------------------------------------------------)
+--R           \|  b                           (- n - 2)log(x) 2
+--R                                           ---------------
+--R                                       2          2
+--R                                    b x (%e               )  + c
+--R       + 
+--R                   (- n - 2)log(x) 3          (- n - 2)log(x)
+--R                   ---------------            ---------------
+--R               3          2                          2
+--R         - 2b x (%e               )  + 6c x %e
+--R    /
+--R         2
+--R       3b n
+--R     ,
+--R
+--R                          (- n - 2)log(x)
+--R                          ---------------            (- n - 2)log(x) 3
+--R              +-+                2                   ---------------
+--R              |c      x %e                       3          2
+--R         - 6c |- atan(-------------------) - 2b x (%e               )
+--R             \|b               +-+
+--R                               |c
+--R                               |-
+--R                              \|b
+--R       + 
+--R                (- n - 2)log(x)
+--R                ---------------
+--R                       2
+--R         6c x %e
+--R    /
+--R         2
+--R       3b n
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1701
+
+--S 1702 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             n 3n
+--R             - -- +---+
+--R             2  2 |  c  +-+
+--R         3c x x   |- - \|b
+--R                 \|  b
+--R      *
+--R                    (- n - 2)log(x) 2               (- n - 2)log(x)
+--R                    ---------------          +---+  ---------------
+--R                2          2                 |  c          2
+--R             b x (%e               )  - 2b x |- - %e                - c
+--R                                            \|  b
+--R         log(----------------------------------------------------------)
+--R                                   (- n - 2)log(x) 2
+--R                                   ---------------
+--R                               2          2
+--R                            b x (%e               )  + c
+--R     + 
+--R               n 3n       (- n - 2)log(x) 3         n 3n      (- n - 2)log(x)
+--R               - --       ---------------           - --      ---------------
+--R             3 2  2 +-+          2                  2  2 +-+         2
+--R       - 2b x x x  \|b (%e               )  + 6c x x x  \|b %e
+--R     + 
+--R                           n
+--R             n 3n          -               3n       n
+--R             - --          2 +-+           --       -
+--R             2  2 +-+     x \|c             2       2  +-+
+--R       - 6c x x  \|c atan(------) + (- 6c x   + 2b x )\|b
+--R                            +-+
+--R                           \|b
+--R  /
+--R           n 3n
+--R           - --
+--R       2   2  2 +-+
+--R     3b n x x  \|b
+--R                                                    Type: Expression(Integer)
+--E 1702
+
+--S 1703 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1703
+
+--S 1704 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  (- n - 2)log(x)
+--R             n 3n                 ---------------
+--R             - --     +-+                2
+--R             2  2 +-+ |c      x %e
+--R       - 6c x x  \|b  |- atan(-------------------)
+--R                     \|b               +-+
+--R                                       |c
+--R                                       |-
+--R                                      \|b
+--R     + 
+--R               n 3n       (- n - 2)log(x) 3         n 3n      (- n - 2)log(x)
+--R               - --       ---------------           - --      ---------------
+--R             3 2  2 +-+          2                  2  2 +-+         2
+--R       - 2b x x x  \|b (%e               )  + 6c x x x  \|b %e
+--R     + 
+--R                           n
+--R             n 3n          -               3n       n
+--R             - --          2 +-+           --       -
+--R             2  2 +-+     x \|c             2       2  +-+
+--R       - 6c x x  \|c atan(------) + (- 6c x   + 2b x )\|b
+--R                            +-+
+--R                           \|b
+--R  /
+--R           n 3n
+--R           - --
+--R       2   2  2 +-+
+--R     3b n x x  \|b
+--R                                                    Type: Expression(Integer)
+--E 1704
+
+--S 1705 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1705
+
+)clear all
+
+--S 1706 of 2282
+t0:=x^(-1-1/3*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - n - 3
+--R           -------
+--R              3
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1706
+
+--S 1707 of 2282
+r0:=(-3/4)/(b*n*x^(4/3*n))+3*c/(b^2*n*x^(1/3*n))-c^(4/3)*log(b^(1/3)+_
+   c^(1/3)*x^(1/3*n))/(b^(7/3)*n)+1/2*c^(4/3)*log(b^(2/3)-b^(1/3)*_
+   c^(1/3)*x^(1/3*n)+c^(2/3)*x^(2/3*n))/(b^(7/3)*n)-c^(4/3)*_
+   atan((b^(1/3)-2*c^(1/3)*x^(1/3*n))/(b^(1/3)*sqrt(3)))*sqrt(3)/(b^(7/3)*n)
+--R 
+--R
+--R   (2)
+--R           n 4n          2n         n
+--R           - --          --         -
+--R           3  3 3+-+      3 3+-+2   3 3+-+3+-+  3+-+2
+--R       2c x x   \|c log(x   \|c  - x  \|b \|c + \|b  )
+--R     + 
+--R                                                                 n
+--R             n 4n          n                     n 4n            -
+--R             - --          -                     - --            3 3+-+  3+-+
+--R             3  3 3+-+     3 3+-+  3+-+      +-+ 3  3 3+-+     2x  \|c - \|b
+--R       - 4c x x   \|c log(x  \|c + \|b  + 4c\|3 x x   \|c atan(--------------)
+--R                                                                   +-+3+-+
+--R                                                                  \|3 \|b
+--R     + 
+--R             4n       n
+--R             --       -
+--R              3       3 3+-+
+--R       (12c x   - 3b x )\|b
+--R  /
+--R           n 4n
+--R           - --
+--R       2   3  3 3+-+
+--R     4b n x x   \|b
+--R                                                    Type: Expression(Integer)
+--E 1707
+
+--S 1708 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                +---+
+--R                |  c
+--R            2c 3|- -
+--R               \|  b
+--R         *
+--R                     (- n - 3)log(x) 2             (- n - 3)log(x)
+--R                     ---------------        +---+  ---------------   +---+2
+--R                 2          3               |  c          3          |  c
+--R                x (%e               )  + x 3|- - %e               + 3|- -
+--R                                           \|  b                    \|  b
+--R            log(-----------------------------------------------------------)
+--R                                              2
+--R                                             x
+--R     + 
+--R                        (- n - 3)log(x)
+--R                        ---------------    +---+
+--R                               3           |  c
+--R           +---+    x %e                - 3|- -
+--R           |  c                           \|  b
+--R       4c 3|- - log(----------------------------)
+--R          \|  b                   x
+--R     + 
+--R                                (- n - 3)log(x)
+--R                                ---------------    +---+
+--R                                       3           |  c
+--R                 +---+     2x %e                + 3|- -
+--R            +-+  |  c                             \|  b
+--R       - 4c\|3  3|- - atan(-----------------------------)
+--R                \|  b                      +---+
+--R                                      +-+  |  c
+--R                                     \|3  3|- -
+--R                                          \|  b
+--R     + 
+--R                 (- n - 3)log(x) 4           (- n - 3)log(x)
+--R                 ---------------             ---------------
+--R             4          3                           3
+--R       - 3b x (%e               )  + 12c x %e
+--R  /
+--R       2
+--R     4b n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1708
+
+--S 1709 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                n 4n
+--R                - --  +---+
+--R                3  3  |  c 3+-+
+--R            2c x x   3|- - \|b
+--R                     \|  b
+--R         *
+--R                     (- n - 3)log(x) 2             (- n - 3)log(x)
+--R                     ---------------        +---+  ---------------   +---+2
+--R                 2          3               |  c          3          |  c
+--R                x (%e               )  + x 3|- - %e               + 3|- -
+--R                                           \|  b                    \|  b
+--R            log(-----------------------------------------------------------)
+--R                                              2
+--R                                             x
+--R     + 
+--R                                  (- n - 3)log(x)
+--R                                  ---------------    +---+
+--R           n 4n                          3           |  c
+--R           - --  +---+        x %e                - 3|- -
+--R           3  3  |  c 3+-+                          \|  b
+--R       4c x x   3|- - \|b log(----------------------------)
+--R                \|  b                       x
+--R     + 
+--R                                         (- n - 3)log(x)
+--R                                         ---------------    +---+
+--R                n 4n                            3           |  c
+--R                - --  +---+         2x %e                + 3|- -
+--R            +-+ 3  3  |  c 3+-+                            \|  b
+--R       - 4c\|3 x x   3|- - \|b atan(-----------------------------)
+--R                     \|  b                          +---+
+--R                                               +-+  |  c
+--R                                              \|3  3|- -
+--R                                                   \|  b
+--R     + 
+--R             n 4n          2n         n
+--R             - --          --         -
+--R             3  3 3+-+      3 3+-+2   3 3+-+3+-+  3+-+2
+--R       - 2c x x   \|c log(x   \|c  - x  \|b \|c + \|b  )
+--R     + 
+--R           n 4n          n                    n 4n        (- n - 3)log(x) 4
+--R           - --          -                    - --        ---------------
+--R           3  3 3+-+     3 3+-+  3+-+       4 3  3 3+-+          3
+--R       4c x x   \|c log(x  \|c + \|b  - 3b x x x   \|b (%e               )
+--R     + 
+--R                                                                 n
+--R              n 4n       (- n - 3)log(x)         n 4n            -
+--R              - --       ---------------         - --            3 3+-+  3+-+
+--R              3  3 3+-+         3            +-+ 3  3 3+-+     2x  \|c - \|b
+--R       12c x x x   \|b %e               - 4c\|3 x x   \|c atan(--------------)
+--R                                                                   +-+3+-+
+--R                                                                  \|3 \|b
+--R     + 
+--R               4n       n
+--R               --       -
+--R                3       3 3+-+
+--R       (- 12c x   + 3b x )\|b
+--R  /
+--R           n 4n
+--R           - --
+--R       2   3  3 3+-+
+--R     4b n x x   \|b
+--R                                                    Type: Expression(Integer)
+--E 1709
+
+--S 1710 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1710
+
+)clear all
+
+--S 1711 of 2282
+t0:=x^(-1-1/4*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - n - 4
+--R           -------
+--R              4
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1711
+
+--S 1712 of 2282
+r0:=(-4/5)/(b*n*x^(5/4*n))+4*c/(b^2*n*x^(1/4*n))+c^(5/4)*log(-b^(1/4)*_
+   c^(1/4)*x^(1/4*n)*sqrt(2)+sqrt(b)+x^(1/2*n)*sqrt(c))/(b^(9/4)*n*_
+   sqrt(2))-c^(5/4)*log(b^(1/4)*c^(1/4)*x^(1/4*n)*sqrt(2)+sqrt(b)+_
+   x^(1/2*n)*sqrt(c))/(b^(9/4)*n*sqrt(2))-c^(5/4)*atan(1-c^(1/4)*_
+   x^(1/4*n)*sqrt(2)/b^(1/4))*sqrt(2)/(b^(9/4)*n)+c^(5/4)*_
+   atan(1+c^(1/4)*x^(1/4*n)*sqrt(2)/b^(1/4))*sqrt(2)/(b^(9/4)*n)
+--R 
+--R
+--R   (2)
+--R             n 5n              n            n
+--R             - --              -            -
+--R             4  4 4+-+     +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       - 5c x x   \|c log(\|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R           n 5n                n            n
+--R           - --                -            -
+--R           4  4 4+-+       +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       5c x x   \|c log(- \|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R                               n
+--R            n 5n               -
+--R            - --           +-+ 4 4+-+  4+-+
+--R            4  4 4+-+     \|2 x  \|c + \|b
+--R       10c x x   \|c atan(-----------------)
+--R                                 4+-+
+--R                                 \|b
+--R     + 
+--R                               n
+--R            n 5n               -                       5n          n
+--R            - --           +-+ 4 4+-+  4+-+            --          -
+--R            4  4 4+-+     \|2 x  \|c - \|b         +-+  4      +-+ 4 4+-+
+--R       10c x x   \|c atan(----------------- + (20c\|2 x   - 4b\|2 x )\|b
+--R                                 4+-+
+--R                                 \|b
+--R  /
+--R              n 5n
+--R              - --
+--R       2  +-+ 4  4 4+-+
+--R     5b n\|2 x x   \|b
+--R                                                    Type: Expression(Integer)
+--E 1712
+
+--S 1713 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 (- n - 4)log(x)        +------+
+--R                                 ---------------        |    5
+--R                                        4           2   |   c
+--R               +------+    c x %e                + b n  |- ----
+--R               |    5                                  4|   9 4
+--R           2   |   c                                   \|  b n
+--R       - 5b n  |- ---- log(------------------------------------)
+--R              4|   9 4                       x
+--R              \|  b n
+--R     + 
+--R                               (- n - 4)log(x)        +------+
+--R                               ---------------        |    5
+--R                                      4           2   |   c
+--R             +------+    c x %e                - b n  |- ----
+--R             |    5                                  4|   9 4
+--R         2   |   c                                   \|  b n
+--R       5b n  |- ---- log(------------------------------------)
+--R            4|   9 4                       x
+--R            \|  b n
+--R     + 
+--R                                     +------+
+--R                                     |    5
+--R                                 2   |   c
+--R              +------+          b n  |- ----               (- n - 4)log(x) 5
+--R              |    5                4|   9 4               ---------------
+--R          2   |   c                 \|  b n            5          4
+--R       10b n  |- ---- atan(--------------------- - 4b x (%e               )
+--R             4|   9 4            (- n - 4)log(x)
+--R             \|  b n             ---------------
+--R                                        4
+--R                           c x %e
+--R     + 
+--R               (- n - 4)log(x)
+--R               ---------------
+--R                      4
+--R       20c x %e
+--R  /
+--R       2
+--R     5b n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1713
+
+--S 1714 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              (- n - 4)log(x)        +------+
+--R                                              ---------------        |    5
+--R                                                     4           2   |   c
+--R                  n 5n  +------+        c x %e                + b n  |- ----
+--R                  - --  |    5                                      4|   9 4
+--R           2  +-+ 4  4  |   c   4+-+                                \|  b n
+--R       - 5b n\|2 x x    |- ---- \|b log(------------------------------------)
+--R                       4|   9 4                           x
+--R                       \|  b n
+--R     + 
+--R                                            (- n - 4)log(x)        +------+
+--R                                            ---------------        |    5
+--R                                                   4           2   |   c
+--R                n 5n  +------+        c x %e                - b n  |- ----
+--R                - --  |    5                                      4|   9 4
+--R         2  +-+ 4  4  |   c   4+-+                                \|  b n
+--R       5b n\|2 x x    |- ---- \|b log(------------------------------------)
+--R                     4|   9 4                           x
+--R                     \|  b n
+--R     + 
+--R                                                  +------+
+--R                                                  |    5
+--R                                              2   |   c
+--R                 n 5n  +------+              b n  |- ----
+--R                 - --  |    5                    4|   9 4
+--R          2  +-+ 4  4  |   c   4+-+              \|  b n
+--R       10b n\|2 x x    |- ---- \|b atan(---------------------)
+--R                      4|   9 4                (- n - 4)log(x)
+--R                      \|  b n                 ---------------
+--R                                                     4
+--R                                        c x %e
+--R     + 
+--R           n 5n              n            n
+--R           - --              -            -
+--R           4  4 4+-+     +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       5c x x   \|c log(\|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R             n 5n                n            n
+--R             - --                -            -
+--R             4  4 4+-+       +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       - 5c x x   \|c log(- \|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R                   n 5n        (- n - 4)log(x) 5
+--R                   - --        ---------------
+--R             5 +-+ 4  4 4+-+          4
+--R       - 4b x \|2 x x   \|b (%e               )
+--R     + 
+--R                 n 5n       (- n - 4)log(x)
+--R                 - --       ---------------
+--R             +-+ 4  4 4+-+         4
+--R       20c x\|2 x x   \|b %e
+--R     + 
+--R                                 n
+--R              n 5n               -
+--R              - --           +-+ 4 4+-+  4+-+
+--R              4  4 4+-+     \|2 x  \|c + \|b
+--R       - 10c x x   \|c atan(-----------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R                                 n
+--R              n 5n               -                         5n          n
+--R              - --           +-+ 4 4+-+  4+-+              --          -
+--R              4  4 4+-+     \|2 x  \|c - \|b           +-+  4      +-+ 4 4+-+
+--R       - 10c x x   \|c atan(----------------- + (- 20c\|2 x   + 4b\|2 x )\|b
+--R                                   4+-+
+--R                                   \|b
+--R  /
+--R              n 5n
+--R              - --
+--R       2  +-+ 4  4 4+-+
+--R     5b n\|2 x x   \|b
+--R                                                    Type: Expression(Integer)
+--E 1714
+
+--S 1715 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1715
+
+)clear all
+
+--S 1716 of 2282
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^2
+--R 
+--R
+--R         2  2 3+-+2      3+-+    2 p
+--R   (1)  x (b  \|x  + 2a b\|x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1716
+
+--S 1717 of 2282
+r0:=15120*a^8*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/_
+   (b^9*(2+p)*(3+p)*(4+p)*(5+2*p)*(7+2*p)*(9+2*p)*(3+8*p+4*p^2))-_
+   7560*a^7*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(1+p)/(b^9*(1+p)*(2+p)*_
+   (3+p)*(4+p)*(3+2*p)*(5+2*p)*(7+2*p)*(9+2*p))+7560*a^6*(a+b*x^(1/3))*_
+   (a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(2/3)/(b^7*(2+p)*(3+p)*(4+p)*_
+   (3+2*p)*(5+2*p)*(7+2*p)*(9+2*p))-2520*a^5*(a+b*x^(1/3))*(a^2+_
+   2*a*b*x^(1/3)+b^2*x^(2/3))^p*x/(b^6*(2+p)*(3+p)*(4+p)*(5+2*p)*_
+   (7+2*p)*(9+2*p))+1260*a^4*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+_
+   b^2*x^(2/3))^p*x^(4/3)/(b^5*(3+p)*(4+p)*(5+2*p)*(7+2*p)*(9+2*p))-_
+   252*a^3*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(5/3)/_
+   (b^4*(3+p)*(4+p)*(7+2*p)*(9+2*p))+84*a^2*(a+b*x^(1/3))*(a^2+_
+   2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^2/(b^3*(4+p)*(7+2*p)*(9+2*p))-_
+   12*a*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(7/3)/_
+   (b^2*(4+p)*(9+2*p))+3*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*_
+   x^(8/3)/(b*(9+2*p))
+--R 
+--R
+--R   (2)
+--R                7         7   2 3+-+2      3+-+    2 p + 1
+--R       (- 15120a p - 7560a )(b  \|x  + 2a b\|x  + a )
+--R     + 
+--R                        8 8         8 7          8 6           8 5           8 4
+--R                   48a b p  + 672a b p  + 3864a b p  + 11760a b p  + 20307a b p
+--R                 + 
+--R                           8 3          8 2          8
+--R                   19698a b p  + 9801a b p  + 1890a b p
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          4 5 5         4 5 4         4 5 3         4 5 2
+--R                   - 2016a b p  - 10080a b p  - 17640a b p  - 12600a b p
+--R                 + 
+--R                          4 5
+--R                   - 3024a b p
+--R              *
+--R                 x
+--R             + 
+--R                     7 2 2         7 2         7 2
+--R               15120a b p  + 22680a b p + 7560a b
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                         2 7 7        2 7 6        2 7 5         2 7 4
+--R                   - 192a b p  - 2016a b p  - 8400a b p  - 17640a b p
+--R                 + 
+--R                           2 7 3         2 7 2        2 7
+--R                   - 19488a b p  - 10584a b p  - 2160a b p
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                     5 4 4         5 4 3         5 4 2        5 4
+--R               (5040a b p  + 15120a b p  + 13860a b p  + 3780a b p)x
+--R             + 
+--R                     8            8
+--R               15120a b p + 15120a b
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R                  9 8       9 7        9 6         9 5         9 4          9 3
+--R               48b p  + 864b p  + 6552b p  + 27216b p  + 67347b p  + 100926b p
+--R             + 
+--R                     9 2         9         9
+--R               88593b p  + 41094b p + 7560b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   3 6 6        3 6 5         3 6 4         3 6 3         3 6 2
+--R               672a b p  + 5040a b p  + 14280a b p  + 18900a b p  + 11508a b p
+--R             + 
+--R                    3 6
+--R               2520a b p
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    6 3 3         6 3 2        6 3            9          9
+--R           (- 10080a b p  - 15120a b p  - 5040a b p)x + 15120a p + 15120a
+--R      *
+--R           2 3+-+2      3+-+    2 p
+--R         (b  \|x  + 2a b\|x  + a )
+--R  /
+--R          9 9       9 8        9 7         9 6          9 5          9 4
+--R       32b p  + 720b p  + 6960b p  + 37800b p  + 126546b p  + 269325b p
+--R     + 
+--R              9 3          9 2          9          9
+--R       361840b p  + 293175b p  + 128322b p + 22680b
+--R                                                    Type: Expression(Integer)
+--E 1717
+
+--S 1718 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      8 8         8 7          8 6           8 5           8 4
+--R                 48a b p  + 672a b p  + 3864a b p  + 11760a b p  + 20307a b p
+--R               + 
+--R                         8 3          8 2          8
+--R                 19698a b p  + 9801a b p  + 1890a b p
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4 5 5         4 5 4         4 5 3         4 5 2
+--R                 - 2016a b p  - 10080a b p  - 17640a b p  - 12600a b p
+--R               + 
+--R                        4 5
+--R                 - 3024a b p
+--R            *
+--R               x
+--R           + 
+--R                   7 2 2        7 2
+--R             15120a b p  + 7560a b p
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                       2 7 7        2 7 6        2 7 5         2 7 4
+--R                 - 192a b p  - 2016a b p  - 8400a b p  - 17640a b p
+--R               + 
+--R                         2 7 3         2 7 2        2 7
+--R                 - 19488a b p  - 10584a b p  - 2160a b p
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                   5 4 4         5 4 3         5 4 2        5 4            8
+--R             (5040a b p  + 15120a b p  + 13860a b p  + 3780a b p)x - 15120a b p
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R                9 8       9 7        9 6         9 5         9 4          9 3
+--R             48b p  + 864b p  + 6552b p  + 27216b p  + 67347b p  + 100926b p
+--R           + 
+--R                   9 2         9         9
+--R             88593b p  + 41094b p + 7560b
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                 3 6 6        3 6 5         3 6 4         3 6 3         3 6 2
+--R             672a b p  + 5040a b p  + 14280a b p  + 18900a b p  + 11508a b p
+--R           + 
+--R                  3 6
+--R             2520a b p
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                  6 3 3         6 3 2        6 3           9
+--R         (- 10080a b p  - 15120a b p  - 5040a b p)x + 7560a
+--R    *
+--R                2 3+-+2      3+-+    2
+--R         p log(b  \|x  + 2a b\|x  + a )
+--R       %e
+--R  /
+--R          9 9       9 8        9 7         9 6          9 5          9 4
+--R       32b p  + 720b p  + 6960b p  + 37800b p  + 126546b p  + 269325b p
+--R     + 
+--R              9 3          9 2          9          9
+--R       361840b p  + 293175b p  + 128322b p + 22680b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1718
+
+--S 1719 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        8 8         8 7          8 6           8 5           8 4
+--R                   48a b p  + 672a b p  + 3864a b p  + 11760a b p  + 20307a b p
+--R                 + 
+--R                           8 3          8 2          8
+--R                   19698a b p  + 9801a b p  + 1890a b p
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          4 5 5         4 5 4         4 5 3         4 5 2
+--R                   - 2016a b p  - 10080a b p  - 17640a b p  - 12600a b p
+--R                 + 
+--R                          4 5
+--R                   - 3024a b p
+--R              *
+--R                 x
+--R             + 
+--R                     7 2 2        7 2
+--R               15120a b p  + 7560a b p
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                         2 7 7        2 7 6        2 7 5         2 7 4
+--R                   - 192a b p  - 2016a b p  - 8400a b p  - 17640a b p
+--R                 + 
+--R                           2 7 3         2 7 2        2 7
+--R                   - 19488a b p  - 10584a b p  - 2160a b p
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                   5 4 4         5 4 3         5 4 2        5 4            8
+--R             (5040a b p  + 15120a b p  + 13860a b p  + 3780a b p)x - 15120a b p
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R                  9 8       9 7        9 6         9 5         9 4          9 3
+--R               48b p  + 864b p  + 6552b p  + 27216b p  + 67347b p  + 100926b p
+--R             + 
+--R                     9 2         9         9
+--R               88593b p  + 41094b p + 7560b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   3 6 6        3 6 5         3 6 4         3 6 3         3 6 2
+--R               672a b p  + 5040a b p  + 14280a b p  + 18900a b p  + 11508a b p
+--R             + 
+--R                    3 6
+--R               2520a b p
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    6 3 3         6 3 2        6 3           9
+--R           (- 10080a b p  - 15120a b p  - 5040a b p)x + 7560a
+--R      *
+--R                  2 3+-+2      3+-+    2
+--R           p log(b  \|x  + 2a b\|x  + a )
+--R         %e
+--R     + 
+--R              7         7   2 3+-+2      3+-+    2 p + 1
+--R       (15120a p + 7560a )(b  \|x  + 2a b\|x  + a )
+--R     + 
+--R                          8 8         8 7          8 6           8 5
+--R                   - 48a b p  - 672a b p  - 3864a b p  - 11760a b p
+--R                 + 
+--R                             8 4           8 3          8 2          8
+--R                   - 20307a b p  - 19698a b p  - 9801a b p  - 1890a b p
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        4 5 5         4 5 4         4 5 3         4 5 2
+--R                   2016a b p  + 10080a b p  + 17640a b p  + 12600a b p
+--R                 + 
+--R                        4 5
+--R                   3024a b p
+--R              *
+--R                 x
+--R             + 
+--R                       7 2 2         7 2         7 2
+--R               - 15120a b p  - 22680a b p - 7560a b
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                       2 7 7        2 7 6        2 7 5         2 7 4
+--R                   192a b p  + 2016a b p  + 8400a b p  + 17640a b p
+--R                 + 
+--R                         2 7 3         2 7 2        2 7
+--R                   19488a b p  + 10584a b p  + 2160a b p
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                       5 4 4         5 4 3         5 4 2        5 4
+--R               (- 5040a b p  - 15120a b p  - 13860a b p  - 3780a b p)x
+--R             + 
+--R                       8            8
+--R               - 15120a b p - 15120a b
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R                    9 8       9 7        9 6         9 5         9 4
+--R               - 48b p  - 864b p  - 6552b p  - 27216b p  - 67347b p
+--R             + 
+--R                        9 3         9 2         9         9
+--R               - 100926b p  - 88593b p  - 41094b p - 7560b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     3 6 6        3 6 5         3 6 4         3 6 3
+--R               - 672a b p  - 5040a b p  - 14280a b p  - 18900a b p
+--R             + 
+--R                       3 6 2        3 6
+--R               - 11508a b p  - 2520a b p
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                  6 3 3         6 3 2        6 3            9          9
+--R           (10080a b p  + 15120a b p  + 5040a b p)x - 15120a p - 15120a
+--R      *
+--R           2 3+-+2      3+-+    2 p
+--R         (b  \|x  + 2a b\|x  + a )
+--R  /
+--R          9 9       9 8        9 7         9 6          9 5          9 4
+--R       32b p  + 720b p  + 6960b p  + 37800b p  + 126546b p  + 269325b p
+--R     + 
+--R              9 3          9 2          9          9
+--R       361840b p  + 293175b p  + 128322b p + 22680b
+--R                                                    Type: Expression(Integer)
+--E 1719
+
+--S 1720 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1720
+
+)clear all
+
+--S 1721 of 2282
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x
+--R 
+--R
+--R            2 3+-+2      3+-+    2 p
+--R   (1)  x (b  \|x  + 2a b\|x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1721
+
+--S 1722 of 2282
+r0:=-90*a^5*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(b^6*(2+p)*_
+   (3+p)*(5+2*p)*(3+8*p+4*p^2))+45*a^4*(a^2+2*a*b*x^(1/3)+b^2*_
+   x^(2/3))^(1+p)/(b^6*(1+p)*(2+p)*(3+p)*(3+2*p)*(5+2*p))-_
+   45*a^3*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(2/3)/_
+   (b^4*(2+p)*(3+p)*(3+2*p)*(5+2*p))+15*a^2*(a+b*x^(1/3))*(a^2+_
+   2*a*b*x^(1/3)+b^2*x^(2/3))^p*x/(b^3*(2+p)*(3+p)*(5+2*p))-_
+   15/2*a*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(4/3)/_
+   (b^2*(3+p)*(5+2*p))+3/2*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*_
+   x^(2/3))^p*x^(5/3)/(b*(3+p))
+--R 
+--R
+--R   (2)
+--R            4       4   2 3+-+2      3+-+    2 p + 1
+--R       (180a p + 90a )(b  \|x  + 2a b\|x  + a )
+--R     + 
+--R                     5 5         5 4         5 3         5 2        5
+--R               (24a b p  + 120a b p  + 210a b p  + 150a b p  + 36a b p)x
+--R             + 
+--R                     4 2 2       4 2       4 2
+--R               - 180a b p  - 270a b p - 90a b
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                       2 4 4       2 4 3       2 4 2      2 4          5
+--R                 (- 60a b p  - 180a b p  - 165a b p  - 45a b p)x - 180a b p
+--R               + 
+--R                       5
+--R                 - 180a b
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R               6 5       6 4       6 3       6 2       6       6  2
+--R           (24b p  + 180b p  + 510b p  + 675b p  + 411b p + 90b )x
+--R         + 
+--R                3 3 3       3 3 2      3 3          6        6
+--R           (120a b p  + 180a b p  + 60a b p)x - 180a p - 180a
+--R      *
+--R           2 3+-+2      3+-+    2 p
+--R         (b  \|x  + 2a b\|x  + a )
+--R  /
+--R        6 6       6 5       6 4        6 3        6 2       6        6
+--R     16b p  + 168b p  + 700b p  + 1470b p  + 1624b p  + 882b p + 180b
+--R                                                    Type: Expression(Integer)
+--E 1722
+
+--S 1723 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   5 5         5 4         5 3         5 2        5
+--R             (24a b p  + 120a b p  + 210a b p  + 150a b p  + 36a b p)x
+--R           + 
+--R                   4 2 2      4 2
+--R             - 180a b p  - 90a b p
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                2 4 4       2 4 3       2 4 2      2 4          5    3+-+
+--R         ((- 60a b p  - 180a b p  - 165a b p  - 45a b p)x + 180a b p)\|x
+--R       + 
+--R             6 5       6 4       6 3       6 2       6       6  2
+--R         (24b p  + 180b p  + 510b p  + 675b p  + 411b p + 90b )x
+--R       + 
+--R              3 3 3       3 3 2      3 3         6
+--R         (120a b p  + 180a b p  + 60a b p)x - 90a
+--R    *
+--R                2 3+-+2      3+-+    2
+--R         p log(b  \|x  + 2a b\|x  + a )
+--R       %e
+--R  /
+--R        6 6       6 5       6 4        6 3        6 2       6        6
+--R     16b p  + 168b p  + 700b p  + 1470b p  + 1624b p  + 882b p + 180b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1723
+
+--S 1724 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     5 5         5 4         5 3         5 2        5
+--R               (24a b p  + 120a b p  + 210a b p  + 150a b p  + 36a b p)x
+--R             + 
+--R                     4 2 2      4 2
+--R               - 180a b p  - 90a b p
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                  2 4 4       2 4 3       2 4 2      2 4          5    3+-+
+--R           ((- 60a b p  - 180a b p  - 165a b p  - 45a b p)x + 180a b p)\|x
+--R         + 
+--R               6 5       6 4       6 3       6 2       6       6  2
+--R           (24b p  + 180b p  + 510b p  + 675b p  + 411b p + 90b )x
+--R         + 
+--R                3 3 3       3 3 2      3 3         6
+--R           (120a b p  + 180a b p  + 60a b p)x - 90a
+--R      *
+--R                  2 3+-+2      3+-+    2
+--R           p log(b  \|x  + 2a b\|x  + a )
+--R         %e
+--R     + 
+--R              4       4   2 3+-+2      3+-+    2 p + 1
+--R       (- 180a p - 90a )(b  \|x  + 2a b\|x  + a )
+--R     + 
+--R                       5 5         5 4         5 3         5 2        5
+--R               (- 24a b p  - 120a b p  - 210a b p  - 150a b p  - 36a b p)x
+--R             + 
+--R                   4 2 2       4 2       4 2
+--R               180a b p  + 270a b p + 90a b
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                  2 4 4       2 4 3       2 4 2      2 4          5          5
+--R             ((60a b p  + 180a b p  + 165a b p  + 45a b p)x + 180a b p + 180a b)
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R                 6 5       6 4       6 3       6 2       6       6  2
+--R           (- 24b p  - 180b p  - 510b p  - 675b p  - 411b p - 90b )x
+--R         + 
+--R                  3 3 3       3 3 2      3 3          6        6
+--R           (- 120a b p  - 180a b p  - 60a b p)x + 180a p + 180a
+--R      *
+--R           2 3+-+2      3+-+    2 p
+--R         (b  \|x  + 2a b\|x  + a )
+--R  /
+--R        6 6       6 5       6 4        6 3        6 2       6        6
+--R     16b p  + 168b p  + 700b p  + 1470b p  + 1624b p  + 882b p + 180b
+--R                                                    Type: Expression(Integer)
+--E 1724
+
+--S 1725 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1725
+
+)clear all
+
+--S 1726 of 2282
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p
+--R 
+--R
+--R          2 3+-+2      3+-+    2 p
+--R   (1)  (b  \|x  + 2a b\|x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1726
+
+--S 1727 of 2282
+r0:=6*a^2*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(b^3*(3+8*p+_
+   4*p^2))-3*a*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(1+p)/(b^3*(1+p)*(3+2*p))+_
+   3*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(2/3)/(b*(3+2*p))
+--R 
+--R
+--R   (2)
+--R                      2 3+-+2      3+-+    2 p + 1
+--R       (- 6a p - 3a)(b  \|x  + 2a b\|x  + a )
+--R     + 
+--R                2 2       2        2 3+-+2      2        2  3+-+
+--R           (6a b p  + 9a b p + 3a b )\|x   + (6a b p + 6a b)\|x
+--R         + 
+--R              3 2     3      3       3      3
+--R           (6b p  + 9b p + 3b )x + 6a p + 6a
+--R      *
+--R           2 3+-+2      3+-+    2 p
+--R         (b  \|x  + 2a b\|x  + a )
+--R  /
+--R       3 3      3 2      3      3
+--R     4b p  + 12b p  + 11b p + 3b
+--R                                                    Type: Expression(Integer)
+--E 1727
+
+--S 1728 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 2       2  3+-+2     2   3+-+      3 2     3      3       3
+--R       ((6a b p  + 3a b p)\|x   - 6a b p\|x  + (6b p  + 9b p + 3b )x + 3a )
+--R    *
+--R                2 3+-+2      3+-+    2
+--R         p log(b  \|x  + 2a b\|x  + a )
+--R       %e
+--R  /
+--R       3 3      3 2      3      3
+--R     4b p  + 12b p  + 11b p + 3b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1728
+
+--S 1729 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               2 2       2  3+-+2     2   3+-+      3 2     3      3       3
+--R         ((6a b p  + 3a b p)\|x   - 6a b p\|x  + (6b p  + 9b p + 3b )x + 3a )
+--R      *
+--R                  2 3+-+2      3+-+    2
+--R           p log(b  \|x  + 2a b\|x  + a )
+--R         %e
+--R     + 
+--R                    2 3+-+2      3+-+    2 p + 1
+--R       (6a p + 3a)(b  \|x  + 2a b\|x  + a )
+--R     + 
+--R                  2 2       2        2 3+-+2        2        2  3+-+
+--R           (- 6a b p  - 9a b p - 3a b )\|x   + (- 6a b p - 6a b)\|x
+--R         + 
+--R                3 2     3      3       3      3
+--R           (- 6b p  - 9b p - 3b )x - 6a p - 6a
+--R      *
+--R           2 3+-+2      3+-+    2 p
+--R         (b  \|x  + 2a b\|x  + a )
+--R  /
+--R       3 3      3 2      3      3
+--R     4b p  + 12b p  + 11b p + 3b
+--R                                                    Type: Expression(Integer)
+--E 1729
+
+--S 1730 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1730
+
+)clear all
+
+--S 1731 of 2282
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/x
+--R 
+--R
+--R          2 3+-+2      3+-+    2 p
+--R        (b  \|x  + 2a b\|x  + a )
+--R   (1)  --------------------------
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 1731
+
+--S 1732 of 2282
+--r0:=3/2*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*hypergeometric(-2*p,-2*p,1-2*p,_
+--   -a/(b*x^(1/3)))/(p*((a+b*x^(1/3))/(b*x^(1/3)))^(2*p))
+--E 1732
+
+--S 1733 of 2282
+--a0:=integrate(t0,x)
+--E 1733
+
+--S 1734 of 2282
+--m0:=a0-r0
+--E 1734
+
+--S 1735 of 2282
+--d0:=normalize(D(m0,x))
+--E 1735
+
+)clear all
+
+--S 1736 of 2282
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/x^2
+--R 
+--R
+--R          2 3+-+2      3+-+    2 p
+--R        (b  \|x  + 2a b\|x  + a )
+--R   (1)  --------------------------
+--R                     2
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 1736
+
+--S 1737 of 2282
+--r0:=-(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(a*x)+b*(1-p)*_
+--   (a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(a^2*x^(2/3))-_
+--   b^2*(1-2*p)*(1-p)*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/_
+--   (a^3*x^(1/3))+b^3*(1-2*p)*(1-p)*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*_
+--   hypergeometric(-2*p,-2*p,1-2*p,-a/(b*x^(1/3)))/(a^3*((a+b*x^(1/3))/_
+--   (b*x^(1/3)))^(2*p))
+--E 1737
+
+--S 1738 of 2282
+--a0:=integrate(t0,x)
+--E 1738
+
+--S 1739 of 2282
+--m0:=a0-r0
+--E 1739
+
+--S 1740 of 2282
+--d0:=normalize(D(m0,x))
+--E 1740
+
+)clear all
+
+--S 1741 of 2282
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/x^2-2/3*b^3*(1-2*p)*(1-p)*p*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(a^3*x)
+--R 
+--R
+--R              3 3     3 2     3        3   2 3+-+2      3+-+    2 p
+--R        ((- 4b p  + 6b p  - 2b p)x + 3a )(b  \|x  + 2a b\|x  + a )
+--R   (1)  -----------------------------------------------------------
+--R                                     3 2
+--R                                   3a x
+--R                                                    Type: Expression(Integer)
+--E 1741
+
+--S 1742 of 2282
+r0:=-(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(a*x)+b*(1-p)*_
+   (a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(a^2*x^(2/3))-_
+   b^2*(1-2*p)*(1-p)*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/_
+   (a^3*x^(1/3))
+--R 
+--R
+--R   (2)
+--R                 3 2     3     3      3 3+-+2          2 2       2   3+-+
+--R           ((- 2b p  + 3b p - b )x - a )\|x   + (- 2a b p  + 2a b p)x\|x
+--R         + 
+--R              2
+--R           - a b p x
+--R    *
+--R         2 3+-+2      3+-+    2 p
+--R       (b  \|x  + 2a b\|x  + a )
+--R  /
+--R      3  3+-+2
+--R     a x \|x
+--R                                                    Type: Expression(Integer)
+--E 1742
+
+--S 1743 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 2       2  3+-+2    2   3+-+        3 2     3     3      3
+--R       ((- 2a b p  + 2a b p)\|x   - a b p\|x  + (- 2b p  + 3b p - b )x - a )
+--R    *
+--R                2 3+-+2      3+-+    2
+--R         p log(b  \|x  + 2a b\|x  + a )
+--R       %e
+--R  /
+--R      3
+--R     a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1743
+
+--S 1744 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3 2     3     3      3 3+-+2          2 2       2   3+-+
+--R           ((- 2b p  + 3b p - b )x - a )\|x   + (- 2a b p  + 2a b p)x\|x
+--R         + 
+--R              2
+--R           - a b p x
+--R      *
+--R                  2 3+-+2      3+-+    2
+--R           p log(b  \|x  + 2a b\|x  + a )
+--R         %e
+--R     + 
+--R              3 2     3     3      3 3+-+2        2 2       2   3+-+    2
+--R         (((2b p  - 3b p + b )x + a )\|x   + (2a b p  - 2a b p)x\|x  + a b p x)
+--R      *
+--R           2 3+-+2      3+-+    2 p
+--R         (b  \|x  + 2a b\|x  + a )
+--R  /
+--R      3  3+-+2
+--R     a x \|x
+--R                                                    Type: Expression(Integer)
+--E 1744
+
+--S 1745 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1745
+
+)clear all
+
+--S 1746 of 2282
+t0:=(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(7/2)
+--R 
+--R
+--R   (1)
+--R           5         2 4 3+-+2       4 2        5 3+-+    6 2      3 3     6
+--R       ((6a b x + 15a b )\|x   + (15a b x + 6a b )\|x  + a x  + 20a b x + b )
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R        |a  \|x  + 2a b\|x  + b
+--R        |-----------------------
+--R        |         3+-+2
+--R       \|         \|x
+--R  /
+--R      2
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 1746
+
+--S 1747 of 2282
+r0:=-35*a*b^3*(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)-105/4*b^3*(a+b/x^(1/3))*_
+   (a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)+21*b^2*(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3))^(5/2)*x^(1/3)+7/2*b*(a+b/x^(1/3))*(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3))^(5/2)*x^(2/3)+(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(7/2)*x-_
+   105*a^3*b^3*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))-105/2*a^2*b^3*_
+   (a+b/x^(1/3))*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))-105*a^4*b^3*_
+   log(1/x^(1/3))*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/(a+b/x^(1/3))
+--R 
+--R
+--R   (2)
+--R               4 3 2      1         6   2       3 4      7 3+-+2
+--R         - 420a b x log(----) + (42a b x  - 420a b x - 3b )\|x
+--R                        3+-+
+--R                        \|x
+--R       + 
+--R              5 2 2       2 5  3+-+     7 3       4 3 2        6
+--R         (252a b x  - 126a b x)\|x  + 4a x  - 105a b x  - 28a b x
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R        |a  \|x  + 2a b\|x  + b
+--R        |-----------------------
+--R        |         3+-+2
+--R       \|         \|x
+--R  /
+--R          3+-+2       2
+--R     4b x \|x   + 4a x
+--R                                                    Type: Expression(Integer)
+--E 1747
+
+--S 1748 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4 3 3+-+    3+-+         5 2        2 5 3+-+2      7 2        6 3+-+
+--R       420a b x\|x log(\|x ) + (252a b x - 126a b )\|x   + (4a x  - 28a b )\|x
+--R     + 
+--R          6   2       3 4      7
+--R       42a b x  - 420a b x - 3b
+--R  /
+--R       3+-+
+--R     4x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1748
+
+--S 1749 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               4 3 2 3+-+      1           5 2 2       2 5  3+-+2
+--R           420a b x  \|x log(---- + (- 252a b x  + 126a b x)\|x
+--R                             3+-+
+--R                             \|x
+--R         + 
+--R                7 3       4 3 2        6  3+-+      6   3       3 4 2     7
+--R           (- 4a x  + 105a b x  + 28a b x)\|x  - 42a b x  + 420a b x  + 3b x
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         3+-+2
+--R         \|         \|x
+--R     + 
+--R            5 3 2 3+-+      4 4 2     3+-+         6 2 2       3 5      8 3+-+2
+--R       (420a b x  \|x + 420a b x )log(\|x ) + (294a b x  - 546a b x - 3b )\|x
+--R     + 
+--R          8 3       5 3 2       2 6  3+-+      7   3       4 4 2        7
+--R       (4a x  + 252a b x  - 154a b x)\|x  + 46a b x  - 420a b x  - 31a b x
+--R  /
+--R         2 3+-+      2
+--R     4a x  \|x + 4b x
+--R                                                    Type: Expression(Integer)
+--E 1749
+
+--S 1750 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R              8   3       5 4 2      2 7  3+-+2
+--R           (9a b x  + 126a b x  + 36a b x)\|x
+--R         + 
+--R             7 2 3       4 5 2       8  3+-+    9 4      6 3 3      3 6 2    9
+--R         (36a b x  + 126a b x  + 9a b x)\|x  + a x  + 84a b x  + 84a b x  + b x
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         3+-+2
+--R         \|         \|x
+--R     + 
+--R             9   3       6 4 2       3 7     10 3+-+2
+--R       (- 10a b x  - 210a b x  - 120a b x - b  )\|x
+--R     + 
+--R             8 2 3       5 5 2      2 8  3+-+    10 4       7 3 3       4 6 2
+--R       (- 45a b x  - 252a b x  - 45a b x)\|x  - a  x  - 120a b x  - 210a b x
+--R     + 
+--R              9
+--R       - 10a b x
+--R  /
+--R                                      +-----------------------+
+--R                                      | 2 3+-+2      3+-+    2
+--R            3 3+-+2   2 3 3+-+   2 4  |a  \|x  + 2a b\|x  + b
+--R     (2a b x  \|x  + b x  \|x + a x ) |-----------------------
+--R                                      |         3+-+2
+--R                                     \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1750
+
+)clear all
+
+--S 1751 of 2282
+t0:=(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(5/2)
+--R 
+--R
+--R   (1)
+--R                                                  +-----------------------+
+--R                                                  | 2 3+-+2      3+-+    2
+--R      2 2 3+-+2    4        3 3+-+     3       4  |a  \|x  + 2a b\|x  + b
+--R   (6a b  \|x  + (a x + 4a b )\|x  + 4a b x + b ) |-----------------------
+--R                                                  |         3+-+2
+--R                                                 \|         \|x
+--R   ------------------------------------------------------------------------
+--R                                      3+-+
+--R                                     x\|x
+--R                                                    Type: Expression(Integer)
+--E 1751
+
+--S 1752 of 2282
+r0:=10*b^2*(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)*x^(1/3)+_
+   5/2*b*(a+b/x^(1/3))*(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)*x^(2/3)+_
+   (a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(5/2)*x-30*a*b^3*sqrt(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3))-15*b^3*(a+b/x^(1/3))*sqrt(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3))-30*a^2*b^3*log(1/x^(1/3))*sqrt(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3))/(a+b/x^(1/3))
+--R 
+--R
+--R   (2)
+--R              2 3 3+-+2      1       5       2 3 3+-+2       4           4 3+-+
+--R         - 60a b  \|x  log(---- + (2a x + 20a b )\|x   + (15a b x - 30a b )\|x
+--R                           3+-+
+--R                           \|x
+--R       + 
+--R            3 2      5
+--R         60a b x - 3b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R        |a  \|x  + 2a b\|x  + b
+--R        |-----------------------
+--R        |         3+-+2
+--R       \|         \|x
+--R  /
+--R        3+-+2     3+-+
+--R     2a \|x   + 2b\|x
+--R                                                    Type: Expression(Integer)
+--E 1752
+
+--S 1753 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      2 3 3+-+2    3+-+     5  3+-+2       4           4 3+-+      3 2      5
+--R   60a b  \|x  log(\|x  + 2a x \|x   + (15a b x - 30a b )\|x  + 60a b x - 3b
+--R   --------------------------------------------------------------------------
+--R                                      3+-+2
+--R                                     2\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1753
+
+--S 1754 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2 3        1           4           4 3+-+2         3 2      5 3+-+
+--R           60a b x log(----) + (- 15a b x + 30a b )\|x   + (- 60a b x + 3b )\|x
+--R                       3+-+
+--R                       \|x
+--R         + 
+--R               5 2      2 3
+--R           - 2a x  - 20a b x
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         3+-+2
+--R         \|         \|x
+--R     + 
+--R           2 4 3+-+2     3 3      3+-+        5         2 4 3+-+2
+--R       (60a b  \|x  + 60a b x)log(\|x ) + (17a b x - 30a b )\|x
+--R     + 
+--R           4 2         5 3+-+     6 2      3 3      6
+--R       (75a b x - 33a b )\|x  + 2a x  + 60a b x - 3b
+--R  /
+--R        3+-+2
+--R     2b \|x   + 2a x
+--R                                                    Type: Expression(Integer)
+--E 1754
+
+--S 1755 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R              6   2      3 4     7 3+-+2       5 2 2      2 5  3+-+    7 3
+--R           (7a b x  + 35a b x + b )\|x   + (21a b x  + 21a b x)\|x  + a x
+--R         + 
+--R              4 3 2       6
+--R           35a b x  + 7a b x
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         3+-+2
+--R         \|         \|x
+--R     + 
+--R            7   2      4 4        7 3+-+2         6 2 2      3 5     8 3+-+
+--R       (- 8a b x  - 70a b x - 8a b )\|x   + (- 28a b x  - 56a b x - b )\|x
+--R     + 
+--R          8 3      5 3 2      2 6
+--R       - a x  - 56a b x  - 28a b x
+--R  /
+--R                                      +-----------------------+
+--R                                      | 2 3+-+2      3+-+    2
+--R            2 3+-+2   2 2 3+-+   2 3  |a  \|x  + 2a b\|x  + b
+--R     (2a b x  \|x  + b x  \|x + a x ) |-----------------------
+--R                                      |         3+-+2
+--R                                     \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1755
+
+)clear all
+
+--S 1756 of 2282
+t0:=(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)
+--R 
+--R
+--R                                  +-----------------------+
+--R                                  | 2 3+-+2      3+-+    2
+--R          2 3+-+2      3+-+    2  |a  \|x  + 2a b\|x  + b
+--R        (a  \|x  + 2a b\|x  + b ) |-----------------------
+--R                                  |         3+-+2
+--R                                 \|         \|x
+--R   (1)  ---------------------------------------------------
+--R                               3+-+2
+--R                               \|x
+--R                                                    Type: Expression(Integer)
+--E 1756
+
+--S 1757 of 2282
+r0:=9*a*b^3*x^(1/3)*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/(a*b+b^2/x^(1/3))+_
+   9/2*a^2*b^2*x^(2/3)*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/(a*b+_
+   b^2/x^(1/3))+a^3*x*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/(a+b/x^(1/3))+_
+   b^4*log(x)*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/(a*b+b^2/x^(1/3))
+--R 
+--R
+--R   (2)
+--R                                                   +-----------------------+
+--R                                                   | 2 3+-+2      3+-+    2
+--R         2 3+-+2     3           3  3+-+     2     |a  \|x  + 2a b\|x  + b
+--R   (18a b  \|x  + (2b log(x) + 2a x)\|x  + 9a b x) |-----------------------
+--R                                                   |         3+-+2
+--R                                                  \|         \|x
+--R   -------------------------------------------------------------------------
+--R                                    3+-+
+--R                                  2a\|x  + 2b
+--R                                                    Type: Expression(Integer)
+--E 1757
+
+--S 1758 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3    3+-+      2  3+-+2        2 3+-+    3
+--R        6b log(\|x ) + 9a b \|x   + 18a b  \|x + 2a x
+--R   (3)  ---------------------------------------------
+--R                              2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1758
+
+--S 1759 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 2 3+-+2       3           3  3+-+     2
+--R         (- 18a b  \|x  + (- 2b log(x) - 2a x)\|x  - 9a b x)
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         3+-+2
+--R         \|         \|x
+--R     + 
+--R            3 3+-+    4     3+-+       2 2 3+-+2     4         3 3+-+      3
+--R       (6a b  \|x + 6b )log(\|x ) + 27a b  \|x  + (2a x + 18a b )\|x  + 11a b x
+--R  /
+--R       3+-+
+--R     2a\|x  + 2b
+--R                                                    Type: Expression(Integer)
+--E 1759
+
+--S 1760 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R             4          4 3+-+2       3 2     5 3+-+    5 2      2 3
+--R         ((5a b x + 5a b )\|x   + (10a b x + b )\|x  + a x  + 10a b x)
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         3+-+2
+--R         \|         \|x
+--R     + 
+--R            5         2 4 3+-+2         4 2        5 3+-+    6 2      3 3     6
+--R       (- 6a b x - 15a b )\|x   + (- 15a b x - 6a b )\|x  - a x  - 20a b x - b
+--R  /
+--R                                     +-----------------------+
+--R                                     | 2 3+-+2      3+-+    2
+--R             3+-+2    2 3+-+    2 2  |a  \|x  + 2a b\|x  + b
+--R     (2a b x \|x   + b x\|x  + a x ) |-----------------------
+--R                                     |         3+-+2
+--R                                    \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1760
+
+)clear all
+
+--S 1761 of 2282
+t0:=(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(1/2)
+--R 
+--R
+--R         +-----------------------+
+--R         | 2 3+-+2      3+-+    2
+--R         |a  \|x  + 2a b\|x  + b
+--R   (1)   |-----------------------
+--R         |         3+-+2
+--R        \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1761
+
+--S 1762 of 2282
+r0:=-1/2*(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)*x/a^2+3/2*(a+b/x^(1/3))*x*_
+   sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/a
+--R 
+--R
+--R                                       +-----------------------+
+--R                                       | 2 3+-+2      3+-+    2
+--R           2  3+-+2        3+-+    2   |a  \|x  + 2a b\|x  + b
+--R        (2a x \|x   + a b x\|x  - b x) |-----------------------
+--R                                       |         3+-+2
+--R                                      \|         \|x
+--R   (2)  --------------------------------------------------------
+--R                                  2 3+-+2
+--R                                2a  \|x
+--R                                                    Type: Expression(Integer)
+--E 1762
+
+--S 1763 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3+-+2
+--R        3b \|x   + 2a x
+--R   (3)  ---------------
+--R               2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1763
+
+--S 1764 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                        +-----------------------+
+--R                                        | 2 3+-+2      3+-+    2
+--R            2  3+-+2        3+-+    2   |a  \|x  + 2a b\|x  + b       3  3+-+2
+--R       (- 2a x \|x   - a b x\|x  + b x) |-----------------------  + 2a x \|x
+--R                                        |         3+-+2
+--R                                       \|         \|x
+--R     + 
+--R         2   3+-+
+--R       3a b x\|x
+--R  /
+--R       2 3+-+2
+--R     2a  \|x
+--R                                                    Type: Expression(Integer)
+--E 1764
+
+--S 1765 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                        +-----------------------+
+--R                        | 2 3+-+2      3+-+    2
+--R            3+-+        |a  \|x  + 2a b\|x  + b      2 3+-+2   2 3+-+
+--R        (a x\|x  + b x) |-----------------------  - b  \|x  - a x\|x  - 2a b x
+--R                        |         3+-+2
+--R                       \|         \|x
+--R   (5)  ----------------------------------------------------------------------
+--R                                  +-----------------------+
+--R                                  | 2 3+-+2      3+-+    2
+--R                             3+-+ |a  \|x  + 2a b\|x  + b
+--R                            x\|x  |-----------------------
+--R                                  |         3+-+2
+--R                                 \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1765
+
+)clear all
+
+--S 1766 of 2282
+t0:=1/(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(1/2)
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R         +-----------------------+
+--R         | 2 3+-+2      3+-+    2
+--R         |a  \|x  + 2a b\|x  + b
+--R         |-----------------------
+--R         |         3+-+2
+--R        \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1766
+
+--S 1767 of 2282
+r0:=-3/2*b*(a+b/x^(1/3))*x^(2/3)/(a^2*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3)))+_
+   (a+b/x^(1/3))*x/(a*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3)))-_
+   3*b^3*(a+b/x^(1/3))*log(a+b/x^(1/3))/(a^4*sqrt(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3)))+3*b^3*(a+b/x^(1/3))*log(1/x^(1/3))/(a^4*_
+   sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3)))+3*b^2*x^(1/3)*sqrt(a^2+_
+   b^2/x^(2/3)+2*a*b/x^(1/3))/a^4
+--R 
+--R
+--R   (2)
+--R                               3+-+
+--R              3 3+-+    4     a\|x  + b         3 3+-+    4       1
+--R       (- 6a b  \|x - 6b )log(---------) + (6a b  \|x + 6b )log(----)
+--R                                 3+-+                           3+-+
+--R                                 \|x                            \|x
+--R     + 
+--R         2 2 3+-+2     4         3 3+-+    3        4
+--R       3a b  \|x  + (2a x + 12a b )\|x  - a b x + 6b
+--R  /
+--R              +-----------------------+
+--R              | 2 3+-+2      3+-+    2
+--R       4 3+-+ |a  \|x  + 2a b\|x  + b
+--R     2a  \|x  |-----------------------
+--R              |         3+-+2
+--R             \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1767
+
+--S 1768 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3     3+-+          2  3+-+2       2 3+-+    3
+--R        - 6b log(a\|x  + b) - 3a b \|x   + 6a b  \|x + 2a x
+--R   (3)  ---------------------------------------------------
+--R                                  4
+--R                                2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1768
+
+--S 1769 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3 3+-+     3+-+           2 3+-+2    3 3+-+     2
+--R         (- 6b  \|x log(a\|x  + b + 6a b  \|x  + 2a x\|x  - 3a b x)
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         3+-+2
+--R         \|         \|x
+--R     + 
+--R                             3+-+
+--R            3 3+-+    4     a\|x  + b           3 3+-+    4       1
+--R       (6a b  \|x + 6b )log(---------) + (- 6a b  \|x - 6b )log(----)
+--R                               3+-+                             3+-+
+--R                               \|x                              \|x
+--R     + 
+--R           2 2 3+-+2       4         3 3+-+    3        4
+--R       - 3a b  \|x  + (- 2a x - 12a b )\|x  + a b x - 6b
+--R  /
+--R              +-----------------------+
+--R              | 2 3+-+2      3+-+    2
+--R       4 3+-+ |a  \|x  + 2a b\|x  + b
+--R     2a  \|x  |-----------------------
+--R              |         3+-+2
+--R             \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1769
+
+--S 1770 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                    +-----------------------+
+--R                                    | 2 3+-+2      3+-+    2
+--R         2 3+-+2   2 3+-+           |a  \|x  + 2a b\|x  + b         2 3+-+2
+--R       (b  \|x  + a x\|x  + 2a b x) |-----------------------  - 3a b  \|x
+--R                                    |         3+-+2
+--R                                   \|         \|x
+--R     + 
+--R           3     3 3+-+     2
+--R       (- a x - b )\|x  - 3a b x
+--R  /
+--R                                            +-----------------------+
+--R                                            | 2 3+-+2      3+-+    2
+--R          2 3+-+2    3     3 3+-+     2     |a  \|x  + 2a b\|x  + b
+--R     (3a b  \|x  + (a x + b )\|x  + 3a b x) |-----------------------
+--R                                            |         3+-+2
+--R                                           \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1770
+
+)clear all
+
+--S 1771 of 2282
+t0:=1/(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(3/2)
+--R 
+--R
+--R                                 1
+--R   (1)  ---------------------------------------------------
+--R                                  +-----------------------+
+--R          2 3+-+2      3+-+    2  | 2 3+-+2      3+-+    2
+--R        (b  \|x  + 2a b\|x  + a )\|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1771
+
+--S 1772 of 2282
+r0:=-3/2*(a+b*x^(1/3))*x^(2/3)/(b*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(3/2))-_
+   3*x^(1/3)/(b^2*sqrt(a^2+2*a*b*x^(1/3)+b^2*x^(2/3)))+3*(a+b*x^(1/3))*_
+   log(a+b*x^(1/3))/(b^3*sqrt(a^2+2*a*b*x^(1/3)+b^2*x^(2/3)))
+--R 
+--R
+--R   (2)
+--R             2 3+-+2     2 3+-+     3      3      3+-+             2 3+-+2
+--R       (18a b  \|x  + 18a b\|x  + 6b x + 6a )log(b\|x  + a) - 15a b  \|x
+--R     + 
+--R           2 3+-+     3
+--R       - 6a b\|x  - 9b x
+--R  /
+--R                                    +-----------------------+
+--R        5 3+-+2      4 3+-+    2 3  | 2 3+-+2      3+-+    2
+--R     (2b  \|x  + 4a b  \|x + 2a b )\|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1772
+
+--S 1773 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 3+-+2       3+-+     2      3+-+             3+-+     2
+--R        (6b  \|x  + 12a b\|x  + 6a )log(b\|x  + a) + 12a b\|x  + 9a
+--R   (3)  ------------------------------------------------------------
+--R                          5 3+-+2      4 3+-+    2 3
+--R                        2b  \|x  + 4a b  \|x + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1773
+
+--S 1774 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2 3+-+2       3+-+     2      3+-+             3+-+     2
+--R         ((6b  \|x  + 12a b\|x  + 6a )log(b\|x  + a) + 12a b\|x  + 9a )
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R               2 3+-+2     2 3+-+     3      3      3+-+             2 3+-+2
+--R       (- 18a b  \|x  - 18a b\|x  - 6b x - 6a )log(b\|x  + a) + 15a b  \|x
+--R     + 
+--R         2 3+-+     3
+--R       6a b\|x  + 9b x
+--R  /
+--R                                    +-----------------------+
+--R        5 3+-+2      4 3+-+    2 3  | 2 3+-+2      3+-+    2
+--R     (2b  \|x  + 4a b  \|x + 2a b )\|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1774
+
+--S 1775 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R            4      3  3+-+2        3     4 3+-+     2 2
+--R         ((b x + 4a b)\|x   + (4a b x + a )\|x  + 6a b x)
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R              4      4  3+-+2         2 3     5 3+-+    5 2      3 2
+--R       (- 5a b x - 5a b)\|x   + (- 10a b x - a )\|x  - b x  - 10a b x
+--R  /
+--R           7 2      3 4      6  3+-+2        6 2      4 3     7 3+-+      2 5 2
+--R         (b x  + 35a b x + 7a b)\|x   + (7a b x  + 35a b x + a )\|x  + 21a b x
+--R       + 
+--R            5 2
+--R         21a b x
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1775
+
+)clear all
+
+--S 1776 of 2282
+t0:=1/(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(5/2)
+--R 
+--R
+--R   (1)
+--R                                      1
+--R   -----------------------------------------------------------------------
+--R                                                 +-----------------------+
+--R      2 2 3+-+2    4      3  3+-+       3     4  | 2 3+-+2      3+-+    2
+--R   (6a b  \|x  + (b x + 4a b)\|x  + 4a b x + a )\|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1776
+
+--S 1777 of 2282
+r0:=3/4*(a+b*x^(1/3))*x/(a*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(5/2))+_
+   1/4*x/(a^2*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(3/2))
+--R 
+--R
+--R   (2)
+--R        2 2  3+-+2     4 2      3    3+-+       3 2     4
+--R     15a b x \|x   + (b x  + 13a b x)\|x  + 7a b x  + 4a x
+--R  /
+--R               3 5       6 2 3+-+2       4 4       7  3+-+     2 6 2      5 3
+--R           (24a b x + 60a b )\|x   + (60a b x + 24a b)\|x  + 4a b x  + 80a b x
+--R         + 
+--R             8
+--R           4a
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1777
+
+--S 1778 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         2 3+-+2      3+-+    2
+--R                     - 6b  \|x  - 4a b\|x  - a
+--R   (3)  ---------------------------------------------------
+--R           2 5 3+-+2     7       3 4 3+-+        6      4 3
+--R        24a b  \|x  + (4b x + 16a b )\|x  + 16a b x + 4a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1778
+
+--S 1779 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2 8 2       5 5       8 2 3+-+2
+--R           (- 6a b x  - 186a b x - 45a b )\|x
+--R         + 
+--R                 3 7 2       6 4       9  3+-+       4 6 2       7 3     10
+--R           (- 40a b x  - 185a b x - 10a b)\|x  - 115a b x  - 116a b x - a
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R           11 3       3 8 2      6 5  3+-+2
+--R       (- b  x  - 119a b x  - 91a b x)\|x
+--R     + 
+--R               10 3       4 7 2      7 4  3+-+      2 9 3       5 6 2     8 3
+--R       (- 11a b  x  - 175a b x  - 29a b x)\|x  - 49a b x  - 161a b x  - 4a b x
+--R  /
+--R              4 11 2        7 8        10 5 3+-+2
+--R         (180a b  x  + 1008a b x + 180a  b )\|x
+--R       + 
+--R            2 13 3       5 10 2       8 7       11 4 3+-+      3 12 3
+--R         (4a b  x  + 480a b  x  + 840a b x + 40a  b )\|x  + 40a b  x
+--R       + 
+--R             6 9 2       9 6      12 3
+--R         840a b x  + 480a b x + 4a  b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1779
+
+--S 1780 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                   2 15 5        5 12 4         8 9 3         11 6 2       14 3
+--R               136a b  x  + 6188a b  x  + 24310a b x  + 12376a  b x  + 680a  b x
+--R             + 
+--R                17
+--R               a
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                17 6       3 14 5         6 11 4         9 8 3        12 5 2
+--R               b  x  + 680a b  x  + 12376a b  x  + 24310a b x  + 6188a  b x
+--R             + 
+--R                   15 2
+--R               136a  b x
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R                16 6        4 13 5         7 10 4         10 7 3        13 4 2
+--R           17a b  x  + 2380a b  x  + 19448a b  x  + 19448a  b x  + 2380a  b x
+--R         + 
+--R              16
+--R           17a  b x
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R              18 6       3 15 5         6 12 4         9 9 3         12 6 2
+--R           - b  x  - 816a b  x  - 18564a b  x  - 48620a b x  - 18564a  b x
+--R         + 
+--R                 15 3     18
+--R           - 816a  b x - a
+--R      *
+--R         3+-+2
+--R         \|x
+--R     + 
+--R                  17 6        4 14 5         7 11 4         10 8 3        13 5 2
+--R           - 18a b  x  - 3060a b  x  - 31824a b  x  - 43758a  b x  - 8568a  b x
+--R         + 
+--R                 16 2
+--R           - 153a  b x
+--R      *
+--R         3+-+
+--R         \|x
+--R     + 
+--R             2 16 6        5 13 5         8 10 4         11 7 3        14 4 2
+--R       - 153a b  x  - 8568a b  x  - 43758a b  x  - 31824a  b x  - 3060a  b x
+--R     + 
+--R            17
+--R       - 18a  b x
+--R  /
+--R                  21 7        4 18 6          7 15 5          10 12 4
+--R             22a b  x  + 7315a b  x  + 170544a b  x  + 646646a  b  x
+--R           + 
+--R                    13 9 3         16 6 2        19 3     22
+--R             497420a  b x  + 74613a  b x  + 1540a  b x + a
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                 2 20 7         5 17 6          8 14 5          11 11 4
+--R             231a b  x  + 26334a b  x  + 319770a b  x  + 705432a  b  x
+--R           + 
+--R                    14 8 3         17 5 2       20 2
+--R             319770a  b x  + 26334a  b x  + 231a  b x
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R          22 8        3 19 7         6 16 6          9 13 5          12 10 4
+--R         b  x  + 1540a b  x  + 74613a b  x  + 497420a b  x  + 646646a  b  x
+--R       + 
+--R                15 7 3        18 4 2      21
+--R         170544a  b x  + 7315a  b x  + 22a  b x
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1780
+
+)clear all
+
+--S 1781 of 2282
+t0:=1/(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(7/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R             5       4 2 3+-+2       2 4      5  3+-+    6 2      3 3     6
+--R       ((6a b x + 15a b )\|x   + (15a b x + 6a b)\|x  + b x  + 20a b x + a )
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1781
+
+--S 1782 of 2282
+r0:=1/20*(-a-b*x^(1/3))/(b^3*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(5/2))-_
+   1/5*x^(1/3)/(b^2*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(5/2))-_
+   1/2*(a+b*x^(1/3))*x^(2/3)/(b*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(7/2))
+--R 
+--R
+--R   (2)
+--R              2 5       5 2 3+-+2         7 2       3 4       6  3+-+        6 2
+--R       (- 181a b x - 55a b )\|x   + (- 15b x  - 215a b x - 11a b)\|x  - 81a b x
+--R     + 
+--R             4 3     7
+--R       - 145a b x - a
+--R  /
+--R              2 11 2        5 8        8 5 3+-+2
+--R         (900a b  x  + 5040a b x + 900a b )\|x
+--R       + 
+--R             13 3        3 10 2        6 7        9 4 3+-+         12 3
+--R         (20b  x  + 2400a b  x  + 4200a b x + 200a b )\|x  + 200a b  x
+--R       + 
+--R              4 9 2        7 6       10 3
+--R         4200a b x  + 2400a b x + 20a  b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1782
+
+--S 1783 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 3+-+2      3+-+    2
+--R     - 15b  \|x  - 6a b\|x  - a
+--R  /
+--R              8        4 5 3+-+2        2 7        5 4 3+-+      9 2       3 6
+--R       (120a b x + 300a b )\|x   + (300a b x + 120a b )\|x  + 20b x  + 400a b x
+--R     + 
+--R          6 3
+--R       20a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1783
+
+--S 1784 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    11 3        4 8 2        7 5        10 2 3+-+2
+--R           (- 156a b  x  - 3915a b x  - 3312a b x - 120a  b )\|x
+--R         + 
+--R                  2 10 3        5 7 2        8 4       11  3+-+      12 4
+--R           (- 736a b  x  - 5160a b x  - 1605a b x - 16a  b)\|x  - 15b  x
+--R         + 
+--R                  3 9 3        6 6 2       9 3     12
+--R           - 2080a b x  - 4872a b x  - 540a b x - a
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R            2 11 3        5 8 2        8 5        11 2 3+-+2
+--R       (892a b  x  + 9075a b x  + 4917a b x + 136a  b )\|x
+--R     + 
+--R           13 4        3 10 3         6 7 2        9 4       12  3+-+
+--R       (15b  x  + 2816a b  x  + 10032a b x  + 2145a b x + 17a  b)\|x
+--R     + 
+--R             12 4        4 9 3        7 6 2       10 3     13
+--R       171a b  x  + 5995a b x  + 8184a b x  + 660a  b x + a
+--R  /
+--R                    2 17 4         5 14 3          8 11 2         11 8
+--R               2400a b  x  + 87360a b  x  + 257400a b  x  + 87360a  b x
+--R             + 
+--R                    14 5
+--R               2400a  b
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                19 5         3 16 4          6 13 3          9 10 2
+--R             20b  x  + 11200a b  x  + 160160a b  x  + 228800a b  x
+--R           + 
+--R                   12 7        15 4
+--R             36400a  b x + 320a  b
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R               18 5         4 15 4          7 12 3          10 9 2         13 6
+--R         320a b  x  + 36400a b  x  + 228800a b  x  + 160160a  b x  + 11200a  b x
+--R       + 
+--R            16 3
+--R         20a  b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1784
+
+--S 1785 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                27 9        3 24 8          6 21 7           9 18 6
+--R               b  x  + 2925a b  x  + 296010a b  x  + 4686825a b  x
+--R             + 
+--R                        12 15 5            15 12 4           18 9 3
+--R               17383860a  b  x  + 17383860a  b  x  + 4686825a  b x
+--R             + 
+--R                      21 6 2        24 3     27
+--R               296010a  b x  + 2925a  b x + a
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                    26 9         4 23 8          7 20 7           10 17 6
+--R               27a b  x  + 17550a b  x  + 888030a b  x  + 8436285a  b  x
+--R             + 
+--R                        13 14 5            16 11 4           19 8 3
+--R               20058300a  b  x  + 13037895a  b  x  + 2220075a  b x
+--R             + 
+--R                     22 5 2       25 2
+--R               80730a  b x  + 351a  b x
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R               2 25 9         5 22 8           8 19 7            11 16 6
+--R           351a b  x  + 80730a b  x  + 2220075a b  x  + 13037895a  b  x
+--R         + 
+--R                    14 13 5           17 10 4          20 7 3         23 4 2
+--R           20058300a  b  x  + 8436285a  b  x  + 888030a  b x  + 17550a  b x
+--R         + 
+--R              26
+--R           27a  b x
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R                  27 9         4 24 8           7 21 7            10 18 6
+--R           - 28a b  x  - 20475a b  x  - 1184040a b  x  - 13123110a  b  x
+--R         + 
+--R                      13 15 5            16 12 4           19 9 3
+--R           - 37442160a  b  x  - 30421755a  b  x  - 6906900a  b x
+--R         + 
+--R                    22 6 2        25 3     28
+--R           - 376740a  b x  - 3276a  b x - a
+--R      *
+--R         3+-+2
+--R         \|x
+--R     + 
+--R                 2 26 9         5 23 8           8 20 7            11 17 6
+--R           - 378a b  x  - 98280a b  x  - 3108105a b  x  - 21474180a  b  x
+--R         + 
+--R                      14 14 5            17 11 4           20 8 3         23 5 2
+--R           - 40116600a  b  x  - 21474180a  b  x  - 3108105a  b x  - 98280a  b x
+--R         + 
+--R                 26 2
+--R           - 378a  b x
+--R      *
+--R         3+-+
+--R         \|x
+--R     + 
+--R          28 10        3 25 9          6 22 8           9 19 7
+--R       - b  x   - 3276a b  x  - 376740a b  x  - 6906900a b  x
+--R     + 
+--R                  12 16 6            15 13 5            18 10 4           21 7 3
+--R       - 30421755a  b  x  - 37442160a  b  x  - 13123110a  b  x  - 1184040a  b x
+--R     + 
+--R               24 4 2      27
+--R       - 20475a  b x  - 28a  b x
+--R  /
+--R                  33 11         4 30 10           7 27 9             10 24 8
+--R             34a b  x   + 46376a b  x   + 5379616a b  x  + 131128140a  b  x
+--R           + 
+--R                       13 21 7              16 18 6              19 15 5
+--R             927983760a  b  x  + 2203961430a  b  x  + 1855967520a  b  x
+--R           + 
+--R                       22 12 4            25 9 3           28 6 2        31 3
+--R             548354040a  b  x  + 52451256a  b x  + 1344904a  b x  + 5984a  b x
+--R           + 
+--R              34
+--R             a
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                 2 32 11          5 29 10            8 26 9             11 23 8
+--R             561a b  x   + 278256a b  x   + 18156204a b  x  + 286097760a  b  x
+--R           + 
+--R                        14 20 7              17 17 6              20 14 5
+--R             1391975640a  b  x  + 2333606220a  b  x  + 1391975640a  b  x
+--R           + 
+--R                       23 11 4            26 8 3          29 5 2       32 2
+--R             286097760a  b  x  + 18156204a  b x  + 278256a  b x  + 561a  b x
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R          34 12        3 31 11           6 28 10            9 25 9
+--R         b  x   + 5984a b  x   + 1344904a b  x   + 52451256a b  x
+--R       + 
+--R                   12 22 8              15 19 7              18 16 6
+--R         548354040a  b  x  + 1855967520a  b  x  + 2203961430a  b  x
+--R       + 
+--R                   21 13 5             24 10 4           27 7 3         30 4 2
+--R         927983760a  b  x  + 131128140a  b  x  + 5379616a  b x  + 46376a  b x
+--R       + 
+--R            33
+--R         34a  b x
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1785
+
+)clear all
+
+--S 1786 of 2282
+t0:=1/(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(9/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R           8 2      3 5       6 2 3+-+2        7 2      4 4      7  3+-+
+--R         (b x  + 56a b x + 28a b )\|x   + (8a b x  + 70a b x + 8a b)\|x
+--R       + 
+--R            2 6 2      5 3     8
+--R         28a b x  + 56a b x + a
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1786
+
+--S 1787 of 2282
+r0:=1/56*(-a-b*x^(1/3))/(b^3*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(7/2))-_
+   3/28*x^(1/3)/(b^2*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(7/2))-_
+   3/8*(a+b*x^(1/3))*x^(2/3)/(b*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(9/2))
+--R 
+--R
+--R   (2)
+--R                8 2        4 5        7 2 3+-+2
+--R       (- 204a b x  - 1281a b x - 105a b )\|x
+--R     + 
+--R            2 7 2       5 4       8  3+-+      9 3        3 6 2       6 3     9
+--R     (- 645a b x  - 903a b x - 15a b)\|x  - 28b x  - 1155a b x  - 399a b x - a
+--R  /
+--R             17 4         3 14 3          6 11 2          9 8         12 5 3+-+2
+--R         (56b  x  + 20384a b  x  + 168168a b  x  + 112112a b x + 5096a  b )\|x
+--R       + 
+--R                  16 4         4 13 3          7 10 2         10 7        13 4
+--R           (784a b  x  + 56056a b  x  + 192192a b  x  + 56056a  b x + 784a  b )
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R              2 15 4          5 12 3          8 9 2         11 6       14 3
+--R         5096a b  x  + 112112a b  x  + 168168a b x  + 20384a  b x + 56a  b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1787
+
+--S 1788 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 3+-+2      3+-+    2
+--R     - 28b  \|x  - 8a b\|x  - a
+--R  /
+--R           11 2        3 8         6 5 3+-+2
+--R       (56b  x  + 3136a b x + 1568a b )\|x
+--R     + 
+--R              10 2        4 7        7 4 3+-+        2 9 2        5 6       8 3
+--R       (448a b  x  + 3920a b x + 448a b )\|x  + 1568a b x  + 3136a b x + 56a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1788
+
+--S 1789 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      2 14 4         5 11 3          8 8 2         11 5
+--R               - 2661a b  x  - 64428a b  x  - 114543a b x  - 20202a  b x
+--R             + 
+--R                     14 2
+--R               - 231a  b
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                    16 5         3 13 4          6 10 3         9 7 2
+--R               - 28b  x  - 10934a b  x  - 101101a b  x  - 83512a b x
+--R             + 
+--R                      12 4       15
+--R               - 6461a  b x - 22a  b
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R                   15 5         4 12 4          7 9 3         10 6 2
+--R           - 400a b  x  - 31031a b  x  - 122122a b x  - 47047a  b x
+--R         + 
+--R                  13 3     16
+--R           - 1484a  b x - a
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R              17 5         3 14 4          6 11 3          9 8 2         12 5
+--R           28b  x  + 13595a b  x  + 165529a b  x  + 198055a b x  + 26663a  b x
+--R         + 
+--R               15 2
+--R           253a  b
+--R      *
+--R         3+-+2
+--R         \|x
+--R     + 
+--R                 16 5         4 13 4          7 10 3          10 7 2
+--R           428a b  x  + 41965a b  x  + 223223a b  x  + 130559a  b x
+--R         + 
+--R                13 4       16
+--R           7945a  b x + 23a  b
+--R      *
+--R         3+-+
+--R         \|x
+--R     + 
+--R          2 15 5         5 12 4          8 9 3         11 6 2        14 3     17
+--R     3061a b  x  + 95459a b  x  + 236665a b x  + 67249a  b x  + 1715a  b x + a
+--R  /
+--R                   2 23 6           5 20 5            8 17 4            11 14 3
+--R             12936a b  x  + 1474704a b  x  + 17907120a b  x  + 39504192a  b  x
+--R           + 
+--R                      14 11 2           17 8          20 5
+--R             17907120a  b  x  + 1474704a  b x + 12936a  b
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                25 7         3 22 6           6 19 5            9 16 4
+--R             56b  x  + 86240a b  x  + 4178328a b  x  + 27855520a b  x
+--R           + 
+--R                      12 13 3           15 10 2          18 7         21 4
+--R             36212176a  b  x  + 9550464a  b  x  + 409640a  b x + 1232a  b
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R                24 7          4 21 6           7 18 5            10 15 4
+--R         1232a b  x  + 409640a b  x  + 9550464a b  x  + 36212176a  b  x
+--R       + 
+--R                  13 12 3           16 9 2         19 6       22 3
+--R         27855520a  b  x  + 4178328a  b x  + 86240a  b x + 56a  b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1789
+
+--S 1790 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                    36 12         4 33 11            7 30 10             10 27 9
+--R               37a b  x   + 66045a b  x   + 10295472a b  x   + 348330136a  b  x
+--R             + 
+--R                          13 24 8               16 21 7               19 18 6
+--R               3562467300a  b  x  + 12875774670a  b  x  + 17672631900a  b  x
+--R             + 
+--R                          22 15 5              25 12 4             28 9 3
+--R               9364199760a  b  x  + 1852482996a  b  x  + 124403620a  b x
+--R             + 
+--R                       31 6 2        34 3     37
+--R               2324784a  b x  + 7770a  b x + a
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                   2 35 12          5 32 11            8 29 10
+--R               666a b  x   + 435897a b  x   + 38608020a b  x
+--R             + 
+--R                         11 26 9              14 23 8               17 20 7
+--R               854992152a  b  x  + 6107086800a  b  x  + 15905368710a  b  x
+--R             + 
+--R                           20 17 6              23 14 5             26 11 4
+--R               15905368710a  b  x  + 6107086800a  b  x  + 854992152a  b  x
+--R             + 
+--R                        29 8 3          32 5 2       35 2
+--R               38608020a  b x  + 435897a  b x  + 666a  b x
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R            37 13        3 34 12           6 31 11             9 28 10
+--R           b  x   + 7770a b  x   + 2324784a b  x   + 124403620a b  x
+--R         + 
+--R                      12 25 9              15 22 8               18 19 7
+--R           1852482996a  b  x  + 9364199760a  b  x  + 17672631900a  b  x
+--R         + 
+--R                       21 16 6              24 13 5             27 10 4
+--R           12875774670a  b  x  + 3562467300a  b  x  + 348330136a  b  x
+--R         + 
+--R                    30 7 3         33 4 2      36
+--R           10295472a  b x  + 66045a  b x  + 37a  b x
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R                 2 36 12          5 33 11            8 30 10
+--R           - 703a b  x   - 501942a b  x   - 48903492a b  x
+--R         + 
+--R                        11 27 9              14 24 8               17 21 7
+--R           - 1203322288a  b  x  - 9669554100a  b  x  - 28781143380a  b  x
+--R         + 
+--R                         20 18 6               23 15 5              26 12 4
+--R           - 33578000610a  b  x  - 15471286560a  b  x  - 2707475148a  b  x
+--R         + 
+--R                       29 9 3           32 6 2        35 3     38
+--R           - 163011640a  b x  - 2760681a  b x  - 8436a  b x - a
+--R      *
+--R         3+-+2
+--R         \|x
+--R     + 
+--R              38 13        3 35 12           6 32 11             9 29 10
+--R           - b  x   - 8436a b  x   - 2760681a b  x   - 163011640a b  x
+--R         + 
+--R                        12 26 9               15 23 8               18 20 7
+--R           - 2707475148a  b  x  - 15471286560a  b  x  - 33578000610a  b  x
+--R         + 
+--R                         21 17 6              24 14 5              27 11 4
+--R           - 28781143380a  b  x  - 9669554100a  b  x  - 1203322288a  b  x
+--R         + 
+--R                      30 8 3          33 5 2       36 2
+--R           - 48903492a  b x  - 501942a  b x  - 703a  b x
+--R      *
+--R         3+-+
+--R         \|x
+--R     + 
+--R              37 13         4 34 12            7 31 11             10 28 10
+--R       - 38a b  x   - 73815a b  x   - 12620256a b  x   - 472733756a  b  x
+--R     + 
+--R                    13 25 9               16 22 8               19 19 7
+--R       - 5414950296a  b  x  - 22239974430a  b  x  - 35345263800a  b  x
+--R     + 
+--R                     22 16 6              25 13 5             28 10 4
+--R       - 22239974430a  b  x  - 5414950296a  b  x  - 472733756a  b  x
+--R     + 
+--R                  31 7 3         34 4 2      37
+--R       - 12620256a  b x  - 73815a  b x  - 38a  b x
+--R  /
+--R                  45 15          4 42 14            7 39 13
+--R             46a b  x   + 163185a b  x   + 53524680a b  x
+--R           + 
+--R                        10 36 12                13 33 11                16 30 10
+--R             4076350421a  b  x   + 101766230790a  b  x   + 991493848554a  b  x
+--R           + 
+--R                           19 27 9                 22 24 8
+--R             4154246671960a  b  x  + 7890371113950a  b  x
+--R           + 
+--R                           25 21 7                 28 18 6
+--R             6943526580276a  b  x  + 2818953098830a  b  x
+--R           + 
+--R                          31 15 5               34 12 4              37 9 3
+--R             511738760544a  b  x  + 38910617655a  b  x  + 1101716330a  b x
+--R           + 
+--R                     40 6 2         43 3     46
+--R             9366819a  b x  + 15180a  b x + a
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                  2 44 15           5 41 14             8 38 13
+--R             1035a b  x   + 1370754a b  x   + 260932815a b  x
+--R           + 
+--R                         11 35 12                14 32 11
+--R             13340783196a  b  x   + 239877544005a  b  x
+--R           + 
+--R                           17 29 10                 20 26 9
+--R             1749695026860a  b  x   + 5608233007146a  b  x
+--R           + 
+--R                           23 23 8                 26 20 7
+--R             8233430727600a  b  x  + 5608233007146a  b  x
+--R           + 
+--R                           29 17 6                32 14 5               35 11 4
+--R             1749695026860a  b  x  + 239877544005a  b  x  + 13340783196a  b  x
+--R           + 
+--R                       38 8 3           41 5 2        44 2
+--R             260932815a  b x  + 1370754a  b x  + 1035a  b x
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R          46 16         3 43 15           6 40 14              9 37 13
+--R         b  x   + 15180a b  x   + 9366819a b  x   + 1101716330a b  x
+--R       + 
+--R                     12 34 12                15 31 11                 18 28 10
+--R         38910617655a  b  x   + 511738760544a  b  x   + 2818953098830a  b  x
+--R       + 
+--R                       21 25 9                 24 22 8                 27 19 7
+--R         6943526580276a  b  x  + 7890371113950a  b  x  + 4154246671960a  b  x
+--R       + 
+--R                      30 16 6                33 13 5              36 10 4
+--R         991493848554a  b  x  + 101766230790a  b  x  + 4076350421a  b  x
+--R       + 
+--R                  39 7 3          42 4 2      45
+--R         53524680a  b x  + 163185a  b x  + 46a  b x
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1790
+
+)clear all
+
+--S 1791 of 2282
+t0:=1/(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(11/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R             2 8 2       5 5       8 2 3+-+2
+--R         (45a b x  + 252a b x + 45a b )\|x
+--R       + 
+--R           10 3       3 7 2       6 4       9  3+-+        9 3       4 6 2
+--R         (b  x  + 120a b x  + 210a b x + 10a b)\|x  + 10a b x  + 210a b x
+--R       + 
+--R             7 3     10
+--R         120a b x + a
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1791
+
+--S 1792 of 2282
+r0:=1/120*(-a-b*x^(1/3))/(b^3*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(9/2))-_
+   1/15*x^(1/3)/(b^2*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(9/2))-_
+   3/10*(a+b*x^(1/3))*x^(2/3)/(b*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(11/2))
+--R 
+--R
+--R   (2)
+--R             11 3        3 8 2        6 5        9 2 3+-+2
+--R       (- 45b  x  - 4149a b x  - 5166a b x - 171a b )\|x
+--R     + 
+--R                10 3        4 7 2        7 4       10  3+-+        2 9 3
+--R       (- 415a b  x  - 6546a b x  - 2586a b x - 19a  b)\|x  - 1711a b x
+--R     + 
+--R              5 6 2       8 3     11
+--R       - 7014a b x  - 849a b x - a
+--R  /
+--R                    20 5          4 17 4           7 14 3           10 11 2
+--R             2160a b  x  + 367200a b  x  + 3818880a b  x  + 5250960a  b  x
+--R           + 
+--R                     13 8          16 5
+--R             1028160a  b x + 18360a  b
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                   2 19 5           5 16 4           8 13 3           11 10 2
+--R             18360a b  x  + 1028160a b  x  + 5250960a b  x  + 3818880a  b  x
+--R           + 
+--R                    14 7         17 4
+--R             367200a  b x + 2160a  b
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R             21 6         3 18 5           6 15 4           9 12 3
+--R         120b  x  + 97920a b  x  + 2227680a b  x  + 5834400a b  x
+--R       + 
+--R                 12 9 2         15 6        18 3
+--R         2227680a  b x  + 97920a  b x + 120a  b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1792
+
+--S 1793 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 3+-+2       3+-+    2
+--R     - 45b  \|x  - 10a b\|x  - a
+--R  /
+--R             2 11 2         5 8         8 5 3+-+2
+--R       (5400a b  x  + 30240a b x + 5400a b )\|x
+--R     + 
+--R            13 3         3 10 2         6 7         9 4 3+-+          12 3
+--R       (120b  x  + 14400a b  x  + 25200a b x + 1200a b )\|x  + 1200a b  x
+--R     + 
+--R             4 9 2         7 6        10 3
+--R       25200a b x  + 14400a b x + 120a  b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1793
+
+--S 1794 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    20 6         3 17 5          6 14 4           9 11 3
+--R               - 45b  x  - 38268a b  x  - 924120a b  x  - 2657304a b  x
+--R             + 
+--R                         12 8 2         15 5        18 2
+--R               - 1197378a  b x  - 75888a  b x - 378a  b
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                       19 6          4 16 5           7 13 4           10 10 3
+--R               - 820a b  x  - 146013a b  x  - 1626288a b  x  - 2499068a  b  x
+--R             + 
+--R                        13 7 2         16 4       19
+--R               - 603024a  b x  - 18105a  b x - 28a  b
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R                  2 18 6          5 15 5           8 12 4           11 9 3
+--R           - 7066a b  x  - 416976a b  x  - 2305914a b  x  - 1918280a  b x
+--R         + 
+--R                    14 6 2        17 3     20
+--R           - 241944a  b x  - 3156a  b x - a
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R                 20 6          4 17 5           7 14 4           10 11 3
+--R           865a b  x  + 184281a b  x  + 2550408a b  x  + 5156372a  b  x
+--R         + 
+--R                   13 8 2         16 5        19 2
+--R           1800402a  b x  + 93993a  b x + 406a  b
+--R      *
+--R         3+-+2
+--R         \|x
+--R     + 
+--R                2 19 6          5 16 5           8 13 4           11 10 3
+--R           7886a b  x  + 562989a b  x  + 3932202a b  x  + 4417348a  b  x
+--R         + 
+--R                  14 7 2         17 4       20
+--R           844968a  b x  + 21261a  b x + 29a  b
+--R      *
+--R         3+-+
+--R         \|x
+--R     + 
+--R          21 7         3 18 6           6 15 5           9 12 4           12 9 3
+--R       45b  x  + 45334a b  x  + 1341096a b  x  + 4963218a b  x  + 3115658a  b x
+--R     + 
+--R              15 6 2        18 3     21
+--R       317832a  b x  + 3534a  b x + a
+--R  /
+--R                   2 29 8            5 26 7             8 23 6
+--R             45360a b  x  + 11793600a b  x  + 372972600a b  x
+--R           + 
+--R                        11 20 5              14 17 4              17 14 3
+--R             2576901600a  b  x  + 4813992000a  b  x  + 2576901600a  b  x
+--R           + 
+--R                       20 11 2            23 8          26 5
+--R             372972600a  b  x  + 11793600a  b x + 45360a  b
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                 31 9          3 28 8            6 25 7             9 22 6
+--R             120b  x  + 393120a b  x  + 45208800a b  x  + 828828000a b  x
+--R           + 
+--R                        12 19 5              15 16 4              18 13 3
+--R             3650610600a  b  x  + 4493059200a  b  x  + 1574773200a  b  x
+--R           + 
+--R                       21 10 2           24 7         27 4
+--R             142084800a  b  x  + 2457000a  b x + 3360a  b
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R                30 9           4 27 8             7 24 7              10 21 6
+--R         3360a b  x  + 2457000a b  x  + 142084800a b  x  + 1574773200a  b  x
+--R       + 
+--R                    13 18 5              16 15 4             19 12 3
+--R         4493059200a  b  x  + 3650610600a  b  x  + 828828000a  b  x
+--R       + 
+--R                  22 9 2          25 6        28 3
+--R         45208800a  b x  + 393120a  b x + 120a  b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1794
+
+--S 1795 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                    2 45 15           5 42 14             8 39 13
+--R               1081a b  x   + 1533939a b  x   + 314457495a b  x
+--R             + 
+--R                           11 36 12                14 33 11
+--R               17417133617a  b  x   + 341643774795a  b  x
+--R             + 
+--R                             17 30 10                 20 27 9
+--R               2741188875414a  b  x   + 9762479679106a  b  x
+--R             + 
+--R                              23 24 8                  26 21 7
+--R               16123801841550a  b  x  + 12551759587422a  b  x
+--R             + 
+--R                             29 18 6                32 15 5
+--R               4568648125690a  b  x  + 751616304549a  b  x
+--R             + 
+--R                           35 12 4              38 9 3            41 6 2
+--R               52251400851a  b  x  + 1362649145a  b x  + 10737573a  b x
+--R             + 
+--R                     44 3     47
+--R               16215a  b x + a
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                47 16         3 44 15            6 41 14              9 38 13
+--R               b  x   + 16215a b  x   + 10737573a b  x   + 1362649145a b  x
+--R             + 
+--R                           12 35 12                15 32 11
+--R               52251400851a  b  x   + 751616304549a  b  x
+--R             + 
+--R                             18 29 10                  21 26 9
+--R               4568648125690a  b  x   + 12551759587422a  b  x
+--R             + 
+--R                              24 23 8                 27 20 7
+--R               16123801841550a  b  x  + 9762479679106a  b  x
+--R             + 
+--R                             30 17 6                33 14 5
+--R               2741188875414a  b  x  + 341643774795a  b  x
+--R             + 
+--R                           36 11 4             39 8 3           42 5 2
+--R               17417133617a  b  x  + 314457495a  b x  + 1533939a  b x
+--R             + 
+--R                    45 2
+--R               1081a  b x
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R                46 16          4 43 15            7 40 14              10 37 13
+--R           47a b  x   + 178365a b  x   + 62891499a b  x   + 5178066751a  b  x
+--R         + 
+--R                        13 34 12                 16 31 11
+--R           140676848445a  b  x   + 1503232609098a  b  x
+--R         + 
+--R                         19 28 10                  22 25 9
+--R           6973199770790a  b  x   + 14833897694226a  b  x
+--R         + 
+--R                          25 22 8                 28 19 7
+--R           14833897694226a  b  x  + 6973199770790a  b  x
+--R         + 
+--R                         31 16 6                34 13 5              37 10 4
+--R           1503232609098a  b  x  + 140676848445a  b  x  + 5178066751a  b  x
+--R         + 
+--R                    40 7 3          43 4 2      46
+--R           62891499a  b x  + 178365a  b x  + 47a  b x
+--R      *
+--R          +-----------------------+
+--R          | 2 3+-+2      3+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R              48 16         3 45 15            6 42 14              9 39 13
+--R           - b  x   - 17296a b  x   - 12271512a b  x   - 1677106640a b  x
+--R         + 
+--R                         12 36 12                 15 33 11
+--R           - 69668534468a  b  x   - 1093260079344a  b  x
+--R         + 
+--R                           18 30 10                  21 27 9
+--R           - 7309837001104a  b  x   - 22314239266528a  b  x
+--R         + 
+--R                            24 24 8                  27 21 7
+--R           - 32247603683100a  b  x  - 22314239266528a  b  x
+--R         + 
+--R                           30 18 6                 33 15 5               36 12 4
+--R           - 7309837001104a  b  x  - 1093260079344a  b  x  - 69668534468a  b  x
+--R         + 
+--R                        39 9 3            42 6 2         45 3     48
+--R           - 1677106640a  b x  - 12271512a  b x  - 17296a  b x - a
+--R      *
+--R         3+-+2
+--R         \|x
+--R     + 
+--R                  47 16          4 44 15            7 41 14
+--R           - 48a b  x   - 194580a b  x   - 73629072a b  x
+--R         + 
+--R                        10 38 13                13 35 12
+--R           - 6540715896a  b  x   - 192928249296a  b  x
+--R         + 
+--R                           16 32 11                  19 29 10
+--R           - 2254848913647a  b  x   - 11541847896480a  b  x
+--R         + 
+--R                            22 26 9                  25 23 8
+--R           - 27385657281648a  b  x  - 30957699535776a  b  x
+--R         + 
+--R                            28 20 7                 31 17 6
+--R           - 16735679449896a  b  x  - 4244421484512a  b  x
+--R         + 
+--R                          34 14 5               37 11 4             40 8 3
+--R           - 482320623240a  b  x  - 22595200368a  b  x  - 377348994a  b x
+--R         + 
+--R                     43 5 2        46 2
+--R           - 1712304a  b x  - 1128a  b x
+--R      *
+--R         3+-+
+--R         \|x
+--R     + 
+--R              2 46 16           5 43 15             8 40 14
+--R       - 1128a b  x   - 1712304a b  x   - 377348994a b  x
+--R     + 
+--R                     11 37 13                14 34 12                 17 31 11
+--R       - 22595200368a  b  x   - 482320623240a  b  x   - 4244421484512a  b  x
+--R     + 
+--R                        20 28 10                  23 25 9
+--R       - 16735679449896a  b  x   - 30957699535776a  b  x
+--R     + 
+--R                        26 22 8                  29 19 7                 32 16 6
+--R       - 27385657281648a  b  x  - 11541847896480a  b  x  - 2254848913647a  b  x
+--R     + 
+--R                      35 13 5              38 10 4            41 7 3
+--R       - 192928249296a  b  x  - 6540715896a  b  x  - 73629072a  b x
+--R     + 
+--R                44 4 2      47
+--R       - 194580a  b x  - 48a  b x
+--R  /
+--R                  57 19          4 54 18             7 51 17
+--R             58a b  x   + 424270a b  x   + 300674088a b  x
+--R           + 
+--R                         10 48 16                 13 45 15
+--R             52179482355a  b  x   + 3155581562280a  b  x
+--R           + 
+--R                            16 42 14                   19 39 13
+--R             79960182801345a  b  x   + 947309492837400a  b  x
+--R           + 
+--R                              22 36 12                     25 33 11
+--R             5621728217559090a  b  x   + 17451799771031262a  b  x
+--R           + 
+--R                               28 30 10                     31 27 9
+--R             29065024282889672a  b  x   + 26252279997448736a  b  x
+--R           + 
+--R                               34 24 8                    37 21 7
+--R             12832205713993575a  b  x  + 3342649210440540a  b  x
+--R           + 
+--R                             40 18 6                  43 15 5
+--R             449972009097765a  b  x  + 29752626158640a  b  x
+--R           + 
+--R                          46 12 4               49 9 3            52 6 2
+--R             891794789340a  b  x  + 10648873950a  b x  + 40475358a  b x
+--R           + 
+--R                   55 3     58
+--R             30856a  b x + a
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                  2 56 19           5 53 18              8 50 17
+--R             1653a b  x   + 4582116a b  x   + 1916797311a b  x
+--R           + 
+--R                          11 47 16                  14 44 15
+--R             227692286640a  b  x   + 10142940735900a  b  x
+--R           + 
+--R                             17 41 14                    20 38 13
+--R             197548686920970a  b  x   + 1847253511032930a  b  x
+--R           + 
+--R                              23 35 12                     26 32 11
+--R             8799226775309880a  b  x   + 22150361247847371a  b  x
+--R           + 
+--R                               29 29 10                     32 26 9
+--R             30067266499541040a  b  x   + 22150361247847371a  b  x
+--R           + 
+--R                              35 23 8                    38 20 7
+--R             8799226775309880a  b  x  + 1847253511032930a  b  x
+--R           + 
+--R                             41 17 6                  44 14 5
+--R             197548686920970a  b  x  + 10142940735900a  b  x
+--R           + 
+--R                          47 11 4              50 8 3           53 5 2
+--R             227692286640a  b  x  + 1916797311a  b x  + 4582116a  b x
+--R           + 
+--R                  56 2
+--R             1653a  b x
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R          58 20         3 55 19            6 52 18               9 49 17
+--R         b  x   + 30856a b  x   + 40475358a b  x   + 10648873950a b  x
+--R       + 
+--R                      12 46 16                  15 43 15
+--R         891794789340a  b  x   + 29752626158640a  b  x
+--R       + 
+--R                         18 40 14                    21 37 13
+--R         449972009097765a  b  x   + 3342649210440540a  b  x
+--R       + 
+--R                           24 34 12                     27 31 11
+--R         12832205713993575a  b  x   + 26252279997448736a  b  x
+--R       + 
+--R                           30 28 10                     33 25 9
+--R         29065024282889672a  b  x   + 17451799771031262a  b  x
+--R       + 
+--R                          36 22 8                   39 19 7
+--R         5621728217559090a  b  x  + 947309492837400a  b  x
+--R       + 
+--R                        42 16 6                 45 13 5               48 10 4
+--R         79960182801345a  b  x  + 3155581562280a  b  x  + 52179482355a  b  x
+--R       + 
+--R                   51 7 3          54 4 2      57
+--R         300674088a  b x  + 424270a  b x  + 58a  b x
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1795
+
+)clear all
+
+--S 1796 of 2282
+t0:=(a^2+b^2/x^(2/5)+2*a*b/x^(1/5))^(5/2)
+--R 
+--R
+--R   (1)
+--R         4 5+-+4    3  5+-+3     2 2 5+-+2      3 5+-+   4
+--R       (a  \|x  + 4a b \|x   + 6a b  \|x  + 4a b  \|x + b )
+--R    *
+--R        +-----------------------+
+--R        | 2 5+-+2      5+-+    2
+--R        |a  \|x  + 2a b\|x  + b
+--R        |-----------------------
+--R        |         5+-+2
+--R       \|         \|x
+--R  /
+--R     5+-+4
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 1796
+
+--S 1797 of 2282
+r0:=25*a*b^5*x^(1/5)*sqrt(a^2+b^2/x^(2/5)+2*a*b/x^(1/5))/(a*b+b^2/x^(1/5))+_
+   25*a^2*b^4*x^(2/5)*sqrt(a^2+b^2/x^(2/5)+2*a*b/x^(1/5))/(a*b+b^2/x^(1/5))+_
+   50/3*a^3*b^3*x^(3/5)*sqrt(a^2+b^2/x^(2/5)+2*a*b/x^(1/5))/_
+   (a*b+b^2/x^(1/5))+25/4*a^4*b^2*x^(4/5)*sqrt(a^2+b^2/x^(2/5)+_
+   2*a*b/x^(1/5))/(a*b+b^2/x^(1/5))+a^5*x*sqrt(a^2+b^2/x^(2/5)+_
+   2*a*b/x^(1/5))/(a+b/x^(1/5))+b^6*log(x)*sqrt(a^2+b^2/x^(2/5)+_
+   2*a*b/x^(1/5))/(a*b+b^2/x^(1/5))
+--R 
+--R
+--R   (2)
+--R             3 2 5+-+4      2 3 5+-+3        4 5+-+2      5            5  5+-+
+--R         200a b  \|x  + 300a b  \|x  + 300a b  \|x  + (12b log(x) + 12a x)\|x
+--R       + 
+--R            4
+--R         75a b x
+--R    *
+--R        +-----------------------+
+--R        | 2 5+-+2      5+-+    2
+--R        |a  \|x  + 2a b\|x  + b
+--R        |-----------------------
+--R        |         5+-+2
+--R       \|         \|x
+--R  /
+--R        5+-+
+--R     12a\|x  + 12b
+--R                                                    Type: Expression(Integer)
+--E 1797
+
+--S 1798 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          5    5+-+       4  5+-+4       3 2 5+-+3      2 3 5+-+2        4 5+-+
+--R       60b log(\|x ) + 75a b \|x   + 200a b  \|x  + 300a b  \|x  + 300a b  \|x
+--R     + 
+--R          5
+--R       12a x
+--R  /
+--R     12
+--R                                         Type: Union(Expression(Integer),...)
+--E 1798
+
+--S 1799 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3 2 5+-+4      2 3 5+-+3        4 5+-+2
+--R           - 200a b  \|x  - 300a b  \|x  - 300a b  \|x
+--R         + 
+--R                 5            5  5+-+      4
+--R           (- 12b log(x) - 12a x)\|x  - 75a b x
+--R      *
+--R          +-----------------------+
+--R          | 2 5+-+2      5+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         5+-+2
+--R         \|         \|x
+--R     + 
+--R             5 5+-+     6     5+-+        4 2 5+-+4      3 3 5+-+3      2 4 5+-+2
+--R       (60a b  \|x + 60b )log(\|x ) + 275a b  \|x  + 500a b  \|x  + 600a b  \|x
+--R     + 
+--R           6          5 5+-+      5
+--R       (12a x + 300a b )\|x  + 87a b x
+--R  /
+--R        5+-+
+--R     12a\|x  + 12b
+--R                                                    Type: Expression(Integer)
+--E 1799
+
+--S 1800 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R              3 4 5+-+4    7       2 5 5+-+3      6          6 5+-+2
+--R           35a b  \|x  + (a x + 21a b )\|x   + (7a b x + 7a b )\|x
+--R         + 
+--R               5 2     7 5+-+      4 3
+--R           (21a b x + b )\|x  + 35a b x
+--R      *
+--R          +-----------------------+
+--R          | 2 5+-+2      5+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         5+-+2
+--R         \|         \|x
+--R     + 
+--R            4 4 5+-+4      8       3 5 5+-+3        7         2 6 5+-+2
+--R       - 70a b  \|x  + (- a x - 56a b )\|x   + (- 8a b x - 28a b )\|x
+--R     + 
+--R             6 2        7 5+-+      5 3     8
+--R       (- 28a b x - 8a b )\|x  - 56a b x - b
+--R  /
+--R                                          +-----------------------+
+--R                                          | 2 5+-+2      5+-+    2
+--R       2  5+-+3          5+-+2    2 5+-+  |a  \|x  + 2a b\|x  + b
+--R     (a x \|x   + 2a b x \|x   + b x\|x ) |-----------------------
+--R                                          |         5+-+2
+--R                                         \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1800
+
+)clear all
+
+--S 1801 of 2282
+t0:=(a^2+b^2/x^2+2*a*b/x)^(1/2)
+--R 
+--R
+--R         +------------------+
+--R         | 2 2             2
+--R         |a x  + 2a b x + b
+--R   (1)   |------------------
+--R         |         2
+--R        \|        x
+--R                                                    Type: Expression(Integer)
+--E 1801
+
+--S 1802 of 2282
+r0:=a*x*sqrt(a^2+b^2/x^2+2*a*b/x)/(a+b/x)+b*log(x)*_
+   sqrt(a^2+b^2/x^2+2*a*b/x)/(a+b/x)
+--R 
+--R
+--R                            +------------------+
+--R                            | 2 2             2
+--R                         2  |a x  + 2a b x + b
+--R        (b x log(x) + a x ) |------------------
+--R                            |         2
+--R                           \|        x
+--R   (2)  ----------------------------------------
+--R                         a x + b
+--R                                                    Type: Expression(Integer)
+--E 1802
+
+--S 1803 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  b log(x) + a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1803
+
+--S 1804 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +------------------+
+--R                             | 2 2             2
+--R                          2  |a x  + 2a b x + b               2           2 2
+--R       (- b x log(x) - a x ) |------------------  + (a b x + b )log(x) + a x
+--R                             |         2
+--R                            \|        x
+--R     + 
+--R       a b x
+--R  /
+--R     a x + b
+--R                                                    Type: Expression(Integer)
+--E 1804
+
+--S 1805 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +------------------+
+--R                     | 2 2             2
+--R            2        |a x  + 2a b x + b      2 2             2
+--R        (a x  + b x) |------------------  - a x  - 2a b x - b
+--R                     |         2
+--R                    \|        x
+--R   (5)  ------------------------------------------------------
+--R                           +------------------+
+--R                           | 2 2             2
+--R                         2 |a x  + 2a b x + b
+--R                        x  |------------------
+--R                           |         2
+--R                          \|        x
+--R                                                    Type: Expression(Integer)
+--E 1805
+
+)clear all
+
+--S 1806 of 2282
+t0:=1/(a^2+2*a*b*x+b^2*x^2)^(1/2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         +------------------+
+--R         | 2 2             2
+--R        \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 1806
+
+--S 1807 of 2282
+r0:=(a+b*x)*log(a+b*x)/(b*sqrt(a^2+2*a*b*x+b^2*x^2))
+--R 
+--R
+--R         (b x + a)log(b x + a)
+--R   (2)  ----------------------
+--R          +------------------+
+--R          | 2 2             2
+--R        b\|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 1807
+
+--S 1808 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(b x + a)
+--R   (3)  ------------
+--R              b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1808
+
+--S 1809 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                     +------------------+
+--R                     | 2 2             2
+--R        log(b x + a)\|b x  + 2a b x + a   + (- b x - a)log(b x + a)
+--R   (4)  -----------------------------------------------------------
+--R                             +------------------+
+--R                             | 2 2             2
+--R                           b\|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 1809
+
+--S 1810 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R         +------------------+
+--R         | 2 2             2
+--R        \|b x  + 2a b x + a   - b x - a
+--R   (5)  -------------------------------
+--R                   +------------------+
+--R                   | 2 2             2
+--R         (b x + a)\|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 1810
+
+)clear all
+
+--S 1811 of 2282
+t0:=1/(a^2+2*a*b*x^(1/5)+b^2*x^(2/5))^(5/2)
+--R 
+--R
+--R   (1)
+--R                                         1
+--R   -----------------------------------------------------------------------------
+--R                                                       +-----------------------+
+--R     4 5+-+4      3 5+-+3    2 2 5+-+2    3 5+-+    4  | 2 5+-+2      5+-+    2
+--R   (b  \|x  + 4a b  \|x  + 6a b  \|x  + 4a b\|x  + a )\|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1811
+
+--S 1812 of 2282
+r0:=-5/2*(a+b*x^(1/5))*x^(2/5)/(b^3*(a^2+2*a*b*x^(1/5)+b^2*x^(2/5))^(3/2))-_
+   5/3*x^(3/5)/(b^2*(a^2+2*a*b*x^(1/5)+b^2*x^(2/5))^(3/2))-_
+   5/4*(a+b*x^(1/5))*x^(4/5)/(b*(a^2+2*a*b*x^(1/5)+b^2*x^(2/5))^(5/2))-_
+   5*x^(1/5)/(b^4*sqrt(a^2+2*a*b*x^(1/5)+b^2*x^(2/5)))+_
+   5*(a+b*x^(1/5))*log(a+b*x^(1/5))/(b^5*sqrt(a^2+2*a*b*x^(1/5)+b^2*x^(2/5)))
+--R 
+--R
+--R   (2)
+--R                   4 5+-+4      2 3 5+-+3      3 2 5+-+2      4 5+-+      5
+--R             300a b  \|x  + 600a b  \|x  + 600a b  \|x  + 300a b\|x  + 60b x
+--R           + 
+--R                5
+--R             60a
+--R      *
+--R              5+-+
+--R         log(b\|x  + a)
+--R     + 
+--R               4 5+-+4      2 3 5+-+3      3 2 5+-+2     4 5+-+       5
+--R       - 385a b  \|x  - 470a b  \|x  - 270a b  \|x  - 60a b\|x  - 125b x
+--R  /
+--R           9 5+-+4       8 5+-+3     2 7 5+-+2     3 6 5+-+     4 5
+--R       (12b  \|x  + 48a b  \|x  + 72a b  \|x  + 48a b  \|x + 12a b )
+--R    *
+--R        +-----------------------+
+--R        | 2 5+-+2      5+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1812
+
+--S 1813 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             4 5+-+4        3 5+-+3      2 2 5+-+2      3 5+-+      4
+--R         (60b  \|x  + 240a b  \|x  + 360a b  \|x  + 240a b\|x  + 60a )
+--R      *
+--R              5+-+
+--R         log(b\|x  + a)
+--R     + 
+--R             3 5+-+3      2 2 5+-+2      3 5+-+       4
+--R       240a b  \|x  + 540a b  \|x  + 440a b\|x  + 125a
+--R  /
+--R        9 5+-+4       8 5+-+3     2 7 5+-+2     3 6 5+-+     4 5
+--R     12b  \|x  + 48a b  \|x  + 72a b  \|x  + 48a b  \|x + 12a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1813
+
+--S 1814 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 4 5+-+4        3 5+-+3      2 2 5+-+2      3 5+-+      4
+--R             (60b  \|x  + 240a b  \|x  + 360a b  \|x  + 240a b\|x  + 60a )
+--R          *
+--R                  5+-+
+--R             log(b\|x  + a)
+--R         + 
+--R                 3 5+-+3      2 2 5+-+2      3 5+-+       4
+--R           240a b  \|x  + 540a b  \|x  + 440a b\|x  + 125a
+--R      *
+--R          +-----------------------+
+--R          | 2 5+-+2      5+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R                   4 5+-+4      2 3 5+-+3      3 2 5+-+2      4 5+-+      5
+--R           - 300a b  \|x  - 600a b  \|x  - 600a b  \|x  - 300a b\|x  - 60b x
+--R         + 
+--R                5
+--R           - 60a
+--R      *
+--R              5+-+
+--R         log(b\|x  + a)
+--R     + 
+--R             4 5+-+4      2 3 5+-+3      3 2 5+-+2     4 5+-+       5
+--R       385a b  \|x  + 470a b  \|x  + 270a b  \|x  + 60a b\|x  + 125b x
+--R  /
+--R           9 5+-+4       8 5+-+3     2 7 5+-+2     3 6 5+-+     4 5
+--R       (12b  \|x  + 48a b  \|x  + 72a b  \|x  + 48a b  \|x + 12a b )
+--R    *
+--R        +-----------------------+
+--R        | 2 5+-+2      5+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1814
+
+--S 1815 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R             6      5  5+-+4        5     6 5+-+3      2 4  5+-+2      3 3 5+-+
+--R           (b x + 6a b)\|x   + (6a b x + a )\|x   + 15a b x \|x   + 20a b x\|x
+--R         + 
+--R              4 2
+--R           15a b x
+--R      *
+--R          +-----------------------+
+--R          | 2 5+-+2      5+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R              6      6  5+-+4         2 5     7 5+-+3      3 4  5+-+2
+--R       (- 7a b x - 7a b)\|x   + (- 21a b x - a )\|x   - 35a b x \|x
+--R     + 
+--R            4 3 5+-+    7 2      5 2
+--R       - 35a b x\|x  - b x  - 21a b x
+--R  /
+--R           11 2       5 6       10  5+-+4         10 2       6 5     11 5+-+3
+--R         (b  x  + 462a b x + 11a  b)\|x   + (11a b  x  + 462a b x + a  )\|x
+--R       + 
+--R             2 9 2       7 4  5+-+2        3 8 2       8 3  5+-+       4 7 2
+--R         (55a b x  + 330a b x)\|x   + (165a b x  + 165a b x)\|x  + 330a b x
+--R       + 
+--R            9 2
+--R         55a b x
+--R    *
+--R        +-----------------------+
+--R        | 2 5+-+2      5+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1815
+
+)clear all
+
+--S 1816 of 2282
+t0:=(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))^(7/2)
+--R 
+--R
+--R   (1)
+--R            4 2 3+-+2    2 4 3+-+   6     6 6+-+3
+--R         (3a b  \|x  + 3a b  \|x + a x + b )\|x
+--R       + 
+--R             3 3 3+-+2      5 3+-+    5    6+-+2       2 4 3+-+2     4 2  6+-+
+--R         (12a b  \|x  + 6a b  \|x + 6a b x)\|x   + (12a b  \|x  + 12a b x)\|x
+--R       + 
+--R           3 3
+--R         8a b x
+--R    *
+--R        +----------------------------+
+--R        |  2 3+-+   2 6+-+       3+-+
+--R        |(a  \|x + b )\|x  + 2a b\|x
+--R        |----------------------------
+--R        |          3+-+6+-+
+--R       \|          \|x \|x
+--R  /
+--R       6+-+3
+--R     x \|x
+--R                                                    Type: Expression(Integer)
+--E 1816
+
+--S 1817 of 2282
+r0:=-6*b^8*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/((a*b+b^2/x^(1/6))*x^(1/6))+_
+   126*a^2*b^6*x^(1/6)*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/_
+   (a*b+b^2/x^(1/6))+105*a^3*b^5*x^(1/3)*sqrt(a^2+b^2/x^(1/3)+_
+   2*a*b/x^(1/6))/(a*b+b^2/x^(1/6))+63/2*a^5*b^3*x^(2/3)*_
+   sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/(a*b+b^2/x^(1/6))+_
+   42/5*a^6*b^2*x^(5/6)*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/_
+   (a*b+b^2/x^(1/6))+a^7*x*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/_
+   (a+b/x^(1/6))+7*a*b^7*log(x)*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/_
+   (a*b+b^2/x^(1/6))+70*a^4*b^4*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))*_
+   sqrt(x)/(a*b+b^2/x^(1/6))
+--R 
+--R
+--R   (2)
+--R              2 5 6+-+2
+--R         1260a b  \|x
+--R       + 
+--R              5 2 3+-+2       3 4 3+-+      4 3 +-+        6            7  6+-+
+--R         (315a b  \|x  + 1050a b  \|x + 700a b \|x  + 70a b log(x) + 10a x)\|x
+--R       + 
+--R            6         7
+--R         84a b x - 60b
+--R    *
+--R        +----------------------------+
+--R        |  2 3+-+   2 6+-+       3+-+
+--R        |(a  \|x + b )\|x  + 2a b\|x
+--R        |----------------------------
+--R        |          3+-+6+-+
+--R       \|          \|x \|x
+--R  /
+--R        6+-+
+--R     10a\|x  + 10b
+--R                                                    Type: Expression(Integer)
+--E 1817
+
+--S 1818 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             6 6+-+    6+-+       5 2 6+-+5      4 3 6+-+4       3 4 6+-+3
+--R       420a b  \|x log(\|x  + 315a b  \|x  + 700a b  \|x  + 1050a b  \|x
+--R     + 
+--R            2 5 6+-+2     7 6+-+      6         7
+--R       1260a b  \|x  + 10a x\|x  + 84a b x - 60b
+--R  /
+--R       6+-+
+--R     10\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1818
+
+--S 1819 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  2 5 6+-+3
+--R           - 1260a b  \|x
+--R         + 
+--R                       5 2 3+-+2       3 4 3+-+      4 3 +-+        6
+--R                 - 315a b  \|x  - 1050a b  \|x - 700a b \|x  - 70a b log(x)
+--R               + 
+--R                      7
+--R                 - 10a x
+--R          *
+--R             6+-+2
+--R             \|x
+--R         + 
+--R                 6         7 6+-+
+--R           (- 84a b x + 60b )\|x
+--R      *
+--R          +----------------------------+
+--R          |  2 3+-+   2 6+-+       3+-+
+--R          |(a  \|x + b )\|x  + 2a b\|x
+--R          |----------------------------
+--R          |          3+-+6+-+
+--R         \|          \|x \|x
+--R     + 
+--R            2 6 6+-+2        7 6+-+    6+-+         5 3 6+-+5       4 4 6+-+4
+--R       (420a b  \|x  + 420a b  \|x)log(\|x ) + 1015a b  \|x  + 1750a b  \|x
+--R     + 
+--R            3 5 6+-+3      8         2 6 6+-+2       7           7 6+-+
+--R       2310a b  \|x  + (10a x + 1260a b )\|x   + (94a b x - 60a b )\|x
+--R     + 
+--R           6 2       8
+--R       399a b x - 60b
+--R  /
+--R         6+-+2      6+-+
+--R     10a \|x   + 10b\|x
+--R                                                    Type: Expression(Integer)
+--E 1819
+
+--S 1820 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R               6 3     9 6+-+5       5 4  6+-+4       4 5  6+-+3
+--R           (84a b x + b )\|x   + 126a b x \|x   + 126a b x \|x
+--R         + 
+--R             9 2      3 6  6+-+2      8   2      2 7  6+-+      7 2 2       8
+--R           (a x  + 84a b x)\|x   + (9a b x  + 36a b x)\|x  + 36a b x  + 9a b x
+--R      *
+--R          +-----------------------+
+--R          | 2 6+-+2      6+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         6+-+2
+--R         \|         \|x
+--R     + 
+--R              7 3         9 6+-+5          6 4     10 6+-+4       5 5  6+-+3
+--R       (- 120a b x - 10a b )\|x   + (- 210a b x - b  )\|x   - 252a b x \|x
+--R     + 
+--R           10 2       4 6  6+-+2         9   2       3 7  6+-+      8 2 2
+--R       (- a  x  - 210a b x)\|x   + (- 10a b x  - 120a b x)\|x  - 45a b x
+--R     + 
+--R            2 8
+--R       - 45a b x
+--R  /
+--R                                      +-----------------------+
+--R                                      | 2 6+-+2      6+-+    2
+--R       2 2 6+-+2        2 6+-+   2 2  |a  \|x  + 2a b\|x  + b
+--R     (a x  \|x  + 2a b x  \|x + b x ) |-----------------------
+--R                                      |         6+-+2
+--R                                     \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1820
+
+)clear all
+
+--S 1821 of 2282
+t0:=(a^2+b^2/x^(1/2)+2*a*b/x^(1/4))^(5/2)
+--R 
+--R
+--R   (1)
+--R           2 2 +-+    4     4 4+-+2        3 +-+     3    4+-+     2 2
+--R       ((2a b \|x  + a x + b )\|x   + (4a b \|x  + 4a b x)\|x  + 4a b x)
+--R    *
+--R        +----------------------------+
+--R        |  2 +-+    2 4+-+        +-+
+--R        |(a \|x  + b )\|x  + 2a b\|x
+--R        |----------------------------
+--R        |           +-+4+-+
+--R       \|          \|x \|x
+--R  /
+--R       4+-+2
+--R     x \|x
+--R                                                    Type: Expression(Integer)
+--E 1821
+
+--S 1822 of 2282
+r0:=-4*b^6*sqrt(a^2+2*a*b/x^(1/4)+b^2/sqrt(x))/((a*b+b^2/x^(1/4))*x^(1/4))+_
+   40*a^2*b^4*x^(1/4)*sqrt(a^2+2*a*b/x^(1/4)+b^2/sqrt(x))/(a*b+b^2/x^(1/4))+_
+   20/3*a^4*b^2*x^(3/4)*sqrt(a^2+2*a*b/x^(1/4)+b^2/sqrt(x))/_
+   (a*b+b^2/x^(1/4))+a^5*x*sqrt(a^2+2*a*b/x^(1/4)+b^2/sqrt(x))/_
+   (a+b/x^(1/4))+5*a*b^5*log(x)*sqrt(a^2+2*a*b/x^(1/4)+b^2/sqrt(x))/_
+   (a*b+b^2/x^(1/4))+20*a^3*b^3*sqrt(x)*sqrt(a^2+2*a*b/x^(1/4)+_
+   b^2/sqrt(x))/(a*b+b^2/x^(1/4))
+--R 
+--R
+--R   (2)
+--R            2 3 4+-+2      3 2 +-+        4           5  4+-+      4         5
+--R       (120a b  \|x  + (60a b \|x  + 15a b log(x) + 3a x)\|x  + 20a b x - 12b )
+--R    *
+--R        +----------------------------+
+--R        |  2 +-+    2 4+-+        +-+
+--R        |(a \|x  + b )\|x  + 2a b\|x
+--R        |----------------------------
+--R        |           +-+4+-+
+--R       \|          \|x \|x
+--R  /
+--R       4+-+
+--R     3a\|x  + 3b
+--R                                                    Type: Expression(Integer)
+--E 1822
+
+--S 1823 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        4 4+-+    4+-+      3 2 4+-+3      2 3 4+-+2    5 4+-+      4         5
+--R   60a b  \|x log(\|x  + 60a b  \|x  + 120a b  \|x  + 3a x\|x  + 20a b x - 12b
+--R   ----------------------------------------------------------------------------
+--R                                        4+-+
+--R                                       3\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1823
+
+--S 1824 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 2 3 4+-+3        3 2 +-+        4           5  4+-+2
+--R           - 120a b  \|x  + (- 60a b \|x  - 15a b log(x) - 3a x)\|x
+--R         + 
+--R                 4         5 4+-+
+--R           (- 20a b x + 12b )\|x
+--R      *
+--R          +----------------------------+
+--R          |  2 +-+    2 4+-+        +-+
+--R          |(a \|x  + b )\|x  + 2a b\|x
+--R          |----------------------------
+--R          |           +-+4+-+
+--R         \|          \|x \|x
+--R     + 
+--R           2 4 4+-+2       5 4+-+    4+-+        3 3 4+-+3
+--R       (60a b  \|x  + 60a b  \|x)log(\|x ) + 180a b  \|x
+--R     + 
+--R          6        2 4 4+-+2       5           5 4+-+      4 2       6
+--R       (3a x + 120a b )\|x   + (23a b x - 12a b )\|x  + 80a b x - 12b
+--R  /
+--R        4+-+2     4+-+
+--R     3a \|x   + 3b\|x
+--R                                                    Type: Expression(Integer)
+--E 1824
+
+--S 1825 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R               4 3     7 4+-+3     7 2      3 4  4+-+2      6   2      2 5  4+-+
+--R           (35a b x + b )\|x   + (a x  + 35a b x)\|x   + (7a b x  + 21a b x)\|x
+--R         + 
+--R              5 2 2       6
+--R           21a b x  + 7a b x
+--R      *
+--R          +-----------------------+
+--R          | 2 4+-+2      4+-+    2
+--R          |a  \|x  + 2a b\|x  + b
+--R          |-----------------------
+--R          |         4+-+2
+--R         \|         \|x
+--R     + 
+--R             5 3        7 4+-+3       8 2      4 4     8 4+-+2
+--R       (- 56a b x - 8a b )\|x   + (- a x  - 70a b x - b )\|x
+--R     + 
+--R            7   2      3 5  4+-+      6 2 2      2 6
+--R       (- 8a b x  - 56a b x)\|x  - 28a b x  - 28a b x
+--R  /
+--R                                      +-----------------------+
+--R                                      | 2 4+-+2      4+-+    2
+--R       2 2 4+-+2        2 4+-+   2 2  |a  \|x  + 2a b\|x  + b
+--R     (a x  \|x  + 2a b x  \|x + b x ) |-----------------------
+--R                                      |         4+-+2
+--R                                     \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1825
+
+)clear all
+
+--S 1826 of 2282
+t0:=(a^2+b^2/x+2*a*b/x^(1/2))^(3/2)
+--R 
+--R
+--R                                  +-----------------------+
+--R                                  |  2     2  +-+
+--R           2     2  +-+           |(a x + b )\|x  + 2a b x
+--R        ((a x + b )\|x  + 2a b x) |-----------------------
+--R                                  |           +-+
+--R                                 \|         x\|x
+--R   (1)  ---------------------------------------------------
+--R                                 +-+
+--R                               x\|x
+--R                                                    Type: Expression(Integer)
+--E 1826
+
+--S 1827 of 2282
+r0:=a^3*x*sqrt(a^2+b^2/x+2*a*b/sqrt(x))/(a+b/sqrt(x))+3*a*b^3*log(x)*_
+   sqrt(a^2+b^2/x+2*a*b/sqrt(x))/(a*b+b^2/sqrt(x))-2*b^4*sqrt(a^2+b^2/x+_
+   2*a*b/sqrt(x))/((a*b+b^2/sqrt(x))*sqrt(x))+6*a^2*b^2*sqrt(x)*_
+   sqrt(a^2+b^2/x+2*a*b/sqrt(x))/(a*b+b^2/sqrt(x))
+--R 
+--R
+--R                                                 +-----------------------+
+--R                                                 |  2     2  +-+
+--R              2          3   +-+     2        3  |(a x + b )\|x  + 2a b x
+--R        ((3a b log(x) + a x)\|x  + 6a b x - 2b ) |-----------------------
+--R                                                 |           +-+
+--R                                                \|         x\|x
+--R   (2)  ------------------------------------------------------------------
+--R                                       +-+
+--R                                     a\|x  + b
+--R                                                    Type: Expression(Integer)
+--E 1827
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 1828 of 2282
+a0:=integrate(t0,x)
+--E 1828
+
+--S 1829 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (3)
+--R                                                  +-----------------------+
+--R                                                  |  2     2  +-+
+--R               2          3   +-+     2        3  |(a x + b )\|x  + 2a b x
+--R       ((- 3a b log(x) - a x)\|x  - 6a b x + 2b ) |-----------------------
+--R                                                  |           +-+
+--R                                                 \|         x\|x
+--R     + 
+--R            +-+
+--R       a a0\|x  + a0 b
+--R  /
+--R       +-+
+--R     a\|x  + b
+--R                                                    Type: Expression(Integer)
+--E 1829
+
+--S 1830 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             5   2      3 3        5  +-+    6 3      4 2 2      2 4     6
+--R        (- 6a b x  - 20a b x - 6a b )\|x  - a x  - 15a b x  - 15a b x - b
+--R   (4)  ------------------------------------------------------------------
+--R                                           +-----------------------+
+--R                                           |  2     2  +-+
+--R                      2 +-+    2 3    2 2  |(a x + b )\|x  + 2a b x
+--R               (2a b x \|x  + a x  + b x ) |-----------------------
+--R                                           |           +-+
+--R                                          \|         x\|x
+--R                                                    Type: Expression(Integer)
+--E 1830
+
+)clear all
+
+--S 1831 of 2282
+t0:=1/(a^2+2*a*b*x^(1/2)+b^2*x)^(1/2)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         |     +-+    2     2
+--R        \|2a b\|x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 1831
+
+--S 1832 of 2282
+r0:=-2*a*log(a+b*sqrt(x))*(a+b*sqrt(x))/(b^2*sqrt(a^2+b^2*x+2*a*b*sqrt(x)))+_
+   2*sqrt(a^2+b^2*x+2*a*b*sqrt(x))/b^2
+--R 
+--R
+--R                +-+     2       +-+             +-+     2      2
+--R        (- 2a b\|x  - 2a )log(b\|x  + a) + 4a b\|x  + 2b x + 2a
+--R   (2)  --------------------------------------------------------
+--R                           +-------------------+
+--R                         2 |     +-+    2     2
+--R                        b \|2a b\|x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 1832
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 1833 of 2282
+a0:=integrate(t0,x)
+--E 1833
+
+--S 1834 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (3)
+--R             +-------------------+
+--R           2 |     +-+    2     2          +-+     2       +-+             +-+
+--R       a0 b \|2a b\|x  + b x + a   + (2a b\|x  + 2a )log(b\|x  + a) - 4a b\|x
+--R     + 
+--R           2      2
+--R       - 2b x - 2a
+--R  /
+--R        +-------------------+
+--R      2 |     +-+    2     2
+--R     b \|2a b\|x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 1834
+
+--S 1835 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     1
+--R   (4)  - ----------------------
+--R           +-------------------+
+--R           |     +-+    2     2
+--R          \|2a b\|x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 1835
+
+)clear all
+
+--S 1836 of 2282
+t0:=1/(a^2+2*a*b*x^(1/4)+b^2*x^(1/2))^(3/2)
+--R 
+--R
+--R                                1
+--R   (1)  -------------------------------------------------
+--R                                 +----------------------+
+--R             4+-+    2 +-+    2  |    4+-+    2 +-+    2
+--R        (2a b\|x  + b \|x  + a )\|2a b\|x  + b \|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1836
+
+--S 1837 of 2282
+r0:=-2*(a+b*x^(1/4))*x^(3/4)/(b*(a^2+2*a*b*x^(1/4)+b^2*sqrt(x))^(3/2))-_
+   12*a*(a+b*x^(1/4))*log(a+b*x^(1/4))/(b^4*sqrt(a^2+2*a*b*x^(1/4)+_
+   b^2*sqrt(x)))-6*sqrt(x)/(b^2*sqrt(a^2+2*a*b*x^(1/4)+b^2*sqrt(x)))+_
+   12*sqrt(a^2+2*a*b*x^(1/4)+b^2*sqrt(x))/b^4
+--R 
+--R
+--R   (2)
+--R               2 2 4+-+2          3 +-+      3  4+-+      2 2 +-+      4
+--R         (- 24a b  \|x  + (- 12a b \|x  - 36a b)\|x  - 12a b \|x  - 12a )
+--R      *
+--R              4+-+
+--R         log(b\|x  + a)
+--R     + 
+--R             3 4+-+3     2 2 4+-+2        3 +-+      3  4+-+      2 2 +-+     4
+--R       - 2a b  \|x  + 48a b  \|x  + (36a b \|x  + 48a b)\|x  + 18a b \|x  + 4b x
+--R     + 
+--R          4
+--R       12a
+--R  /
+--R                                 +----------------------+
+--R          5 4+-+   6 +-+    2 4  |    4+-+    2 +-+    2
+--R     (2a b  \|x + b \|x  + a b )\|2a b\|x  + b \|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1837
+
+--S 1838 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 4+-+2     2 4+-+      3      4+-+          3 4+-+3      2 4+-+2
+--R       (- 12a b  \|x  - 24a b\|x  - 12a )log(b\|x  + a) + 4b  \|x  + 8a b  \|x
+--R     + 
+--R           2 4+-+      3
+--R       - 8a b\|x  - 10a
+--R  /
+--R      6 4+-+2      5 4+-+   2 4
+--R     b  \|x  + 2a b  \|x + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1838
+
+--S 1839 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    2 3 4+-+3          4 +-+      3 2 4+-+2
+--R               - 24a b  \|x  + (- 12a b \|x  - 60a b )\|x
+--R             + 
+--R                     2 3 +-+      4  4+-+      3 2 +-+      5
+--R               (- 24a b \|x  - 48a b)\|x  - 12a b \|x  - 12a
+--R          *
+--R                  4+-+
+--R             log(b\|x  + a)
+--R         + 
+--R              5 +-+      2 3 4+-+3        4 +-+     3 2 4+-+2
+--R           (4b \|x  + 20a b )\|x   + (8a b \|x  - 8a b )\|x
+--R         + 
+--R                2 3 +-+      4  4+-+      3 2 +-+       4       5
+--R           (- 8a b \|x  - 28a b)\|x  - 10a b \|x  + 8a b x - 10a
+--R      *
+--R          +----------------------+
+--R          |    4+-+    2 +-+    2
+--R         \|2a b\|x  + b \|x  + a
+--R     + 
+--R                 5 +-+      3 3 4+-+3       2 4 +-+       4 2 4+-+2
+--R           (12a b \|x  + 84a b )\|x   + (36a b \|x  + 108a b )\|x
+--R         + 
+--R               3 3 +-+      5  4+-+      4 2 +-+      2 4       6
+--R           (36a b \|x  + 60a b)\|x  + 12a b \|x  + 24a b x + 12a
+--R      *
+--R              4+-+
+--R         log(b\|x  + a)
+--R     + 
+--R               5 +-+       3 3 4+-+3         2 4 +-+     6        4 2 4+-+2
+--R       (- 36a b \|x  - 142a b )\|x   + (- 90a b \|x  - 4b x - 156a b )\|x
+--R     + 
+--R             3 3 +-+       5       5  4+-+      4 2 +-+      2 4       6
+--R       (- 72a b \|x  - 6a b x - 72a b)\|x  - 18a b \|x  - 48a b x - 12a
+--R  /
+--R             7 4+-+3    8 +-+     2 6 4+-+2        7 +-+     3 5 4+-+    2 6 +-+
+--R         2a b  \|x  + (b \|x  + 5a b )\|x   + (2a b \|x  + 4a b )\|x  + a b \|x
+--R       + 
+--R          4 4
+--R         a b
+--R    *
+--R        +----------------------+
+--R        |    4+-+    2 +-+    2
+--R       \|2a b\|x  + b \|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1839
+
+--S 1840 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                7       5 3 4+-+3       2 6       6 2 4+-+2
+--R           (8a b x + 56a b )\|x   + (28a b x + 28a b )\|x
+--R         + 
+--R               3 5      7  4+-+    8 2      4 4     8
+--R           (56a b x + 8a b)\|x  + b x  + 70a b x + a
+--R      *
+--R          +-----------------------+
+--R          | 2 4+-+2      4+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R             2 7       6 3 4+-+3         3 6       7 2 4+-+2
+--R       (- 36a b x - 84a b )\|x   + (- 84a b x - 36a b )\|x
+--R     + 
+--R           9 2       4 5      8  4+-+       8 2       5 4     9
+--R       (- b x  - 126a b x - 9a b)\|x  - 9a b x  - 126a b x - a
+--R  /
+--R           11 2       4 7        8 3 4+-+3
+--R         (b  x  + 330a b x + 165a b )\|x
+--R       + 
+--R               10 2       5 6       9 2 4+-+2
+--R         (11a b  x  + 462a b x + 55a b )\|x
+--R       + 
+--R             2 9 2       6 5       10  4+-+       3 8 2       7 4     11
+--R         (55a b x  + 462a b x + 11a  b)\|x  + 165a b x  + 330a b x + a
+--R    *
+--R        +-----------------------+
+--R        | 2 4+-+2      4+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1840
+
+)clear all
+
+--S 1841 of 2282
+t0:=1/(a^2+2*a*b*x^(1/6)+b^2*x^(1/3))^(5/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          2 2 6+-+2       3 3+-+    3  6+-+    4 3+-+2    2 2 3+-+   4
+--R       (4a b  \|x  + (4a b  \|x + 4a b)\|x  + b  \|x  + 2a b  \|x + a )
+--R    *
+--R        +----------------------+
+--R        |    6+-+    2 3+-+   2
+--R       \|2a b\|x  + b  \|x + a
+--R                                                    Type: Expression(Integer)
+--E 1841
+
+--S 1842 of 2282
+r0:=-5/2*x^(2/3)/(b^2*(a^2+2*a*b*x^(1/6)+b^2*x^(1/3))^(3/2))-_
+   3/2*(a+b*x^(1/6))*x^(5/6)/(b*(a^2+2*a*b*x^(1/6)+b^2*x^(1/3))^(5/2))-_
+   15*x^(1/3)/(b^4*sqrt(a^2+2*a*b*x^(1/6)+b^2*x^(1/3)))-_
+   30*a*(a+b*x^(1/6))*log(a+b*x^(1/6))/(b^6*sqrt(a^2+2*a*b*x^(1/6)+_
+   b^2*x^(1/3)))+30*sqrt(a^2+2*a*b*x^(1/6)+b^2*x^(1/3))/b^6-_
+   5*(a+b*x^(1/6))*sqrt(x)/(b^3*(a^2+2*a*b*x^(1/6)+b^2*x^(1/3))^(3/2))
+--R 
+--R
+--R   (2)
+--R                 3 3 6+-+3         2 4 3+-+      4 2 6+-+2
+--R           - 240a b  \|x  + (- 240a b  \|x - 480a b )\|x
+--R         + 
+--R                   5 3+-+2      3 3 3+-+      5  6+-+      2 4 3+-+2
+--R           (- 60a b  \|x  - 360a b  \|x - 300a b)\|x  - 60a b  \|x
+--R         + 
+--R                 4 2 3+-+     6
+--R           - 120a b  \|x - 60a
+--R      *
+--R              6+-+
+--R         log(b\|x  + a)
+--R     + 
+--R             5 6+-+5      3 3 6+-+3       2 4 3+-+       5 +-+       4 2 6+-+2
+--R       - 3a b  \|x  + 480a b  \|x  + (600a b  \|x - 20a b \|x  + 720a b )\|x
+--R     + 
+--R              5 3+-+2        6 +-+       3 3 3+-+      2 4 +-+       5  6+-+
+--R       (230a b  \|x  + (- 10b \|x  + 600a b )\|x  - 30a b \|x  + 360a b)\|x
+--R     + 
+--R           2 4 3+-+2          5 +-+       4 2 3+-+      3 3 +-+      6       6
+--R       115a b  \|x  + (- 10a b \|x  + 150a b )\|x  - 10a b \|x  + 22b x + 60a
+--R  /
+--R          2 8 6+-+2       9 3+-+    3 7 6+-+     10 3+-+2    2 8 3+-+    4 6
+--R       (8a b  \|x  + (8a b  \|x + 8a b )\|x  + 2b   \|x  + 4a b  \|x + 2a b )
+--R    *
+--R        +----------------------+
+--R        |    6+-+    2 3+-+   2
+--R       \|2a b\|x  + b  \|x + a
+--R                                                    Type: Expression(Integer)
+--E 1842
+
+--S 1843 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 4 6+-+4      2 3 6+-+3      3 2 6+-+2      4 6+-+      5
+--R         (- 60a b  \|x  - 240a b  \|x  - 360a b  \|x  - 240a b\|x  - 60a )
+--R      *
+--R              6+-+
+--R         log(b\|x  + a)
+--R     + 
+--R          5 6+-+5       4 6+-+4     2 3 6+-+3      3 2 6+-+2      4 6+-+      5
+--R       12b  \|x  + 48a b  \|x  - 48a b  \|x  - 252a b  \|x  - 248a b\|x  - 77a
+--R  /
+--R       10 6+-+4      9 6+-+3     2 8 6+-+2    3 7 6+-+    4 6
+--R     2b   \|x  + 8a b  \|x  + 12a b  \|x  + 8a b  \|x + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1843
+
+--S 1844 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      2 7 3+-+       4 5 6+-+5
+--R               (- 240a b  \|x - 1200a b )\|x
+--R             + 
+--R                       8 3+-+2       3 6 3+-+       5 4 6+-+4
+--R               (- 60a b  \|x  - 1080a b  \|x - 2460a b )\|x
+--R             + 
+--R                      2 7 3+-+2       4 5 3+-+       6 3 6+-+3
+--R               (- 240a b  \|x  - 1920a b  \|x - 2640a b )\|x
+--R             + 
+--R                      3 6 3+-+2       5 4 3+-+       7 2 6+-+2
+--R               (- 360a b  \|x  - 1680a b  \|x - 1560a b )\|x
+--R             + 
+--R                      4 5 3+-+2      6 3 3+-+      8  6+-+      5 4 3+-+2
+--R               (- 240a b  \|x  - 720a b  \|x - 480a b)\|x  - 60a b  \|x
+--R             + 
+--R                     7 2 3+-+      3 6       9
+--R               - 120a b  \|x - 240a b x - 60a
+--R          *
+--R                  6+-+
+--R             log(b\|x  + a)
+--R         + 
+--R               9 3+-+2      2 7 3+-+     4 5 6+-+5
+--R           (12b  \|x  + 216a b  \|x + 12a b )\|x
+--R         + 
+--R                 8 3+-+2     3 6 3+-+       5 4 6+-+4
+--R           (48a b  \|x  - 96a b  \|x - 1152a b )\|x
+--R         + 
+--R                 2 7 3+-+2       4 5 3+-+       6 3 6+-+3
+--R           (- 48a b  \|x  - 1104a b  \|x - 2048a b )\|x
+--R         + 
+--R                  3 6 3+-+2       5 4 3+-+       7 2 6+-+2
+--R           (- 252a b  \|x  - 1496a b  \|x - 1552a b )\|x
+--R         + 
+--R                  4 5 3+-+2      6 3 3+-+     2 7        8  6+-+      5 4 3+-+2
+--R           (- 248a b  \|x  - 804a b  \|x + 48a b x - 556a b)\|x  - 77a b  \|x
+--R         + 
+--R                 8        7 2 3+-+       3 6       9
+--R           (48a b x - 154a b )\|x  + 240a b x - 77a
+--R      *
+--R          +----------------------+
+--R          |    6+-+    2 3+-+   2
+--R         \|2a b\|x  + b  \|x + a
+--R     + 
+--R                 9 3+-+2       3 7 3+-+       5 5 6+-+5
+--R           (60a b  \|x  + 1320a b  \|x + 3660a b )\|x
+--R         + 
+--R                2 8 3+-+2       4 6 3+-+       6 4 6+-+4
+--R           (300a b  \|x  + 3000a b  \|x + 5100a b )\|x
+--R         + 
+--R                3 7 3+-+2       5 5 3+-+       7 3 6+-+3
+--R           (600a b  \|x  + 3600a b  \|x + 4200a b )\|x
+--R         + 
+--R                4 6 3+-+2       6 4 3+-+       8 2 6+-+2
+--R           (600a b  \|x  + 2400a b  \|x + 2040a b )\|x
+--R         + 
+--R                5 5 3+-+2      7 3 3+-+      3 7        9  6+-+      6 4 3+-+2
+--R           (300a b  \|x  + 840a b  \|x + 240a b x + 540a b)\|x  + 60a b  \|x
+--R         + 
+--R                2 8        8 2 3+-+        4 6       10
+--R           (240a b x + 120a b )\|x  + 1440a b x + 60a
+--R      *
+--R              6+-+
+--R         log(b\|x  + a)
+--R     + 
+--R                  9 3+-+2      10 +-+        3 7 3+-+       2 8 +-+        5 5
+--R         (- 230a b  \|x  + (10b  \|x  - 3000a b )\|x  + 110a b \|x  - 6117a b )
+--R      *
+--R         6+-+5
+--R         \|x
+--R     + 
+--R                  2 8 3+-+2        9 +-+        4 6 3+-+       3 7 +-+      10
+--R           - 1035a b  \|x  + (50a b \|x  - 6150a b )\|x  + 250a b \|x  - 22b  x
+--R         + 
+--R                  6 4
+--R           - 7740a b
+--R      *
+--R         6+-+4
+--R         \|x
+--R     + 
+--R                  3 7 3+-+2       2 8 +-+        5 5 3+-+       4 6 +-+
+--R           - 1840a b  \|x  + (100a b \|x  - 6600a b )\|x  + 300a b \|x
+--R         + 
+--R                  9         7 3
+--R           - 85a b x - 5760a b
+--R      *
+--R         6+-+3
+--R         \|x
+--R     + 
+--R                  4 6 3+-+2       3 7 +-+        6 4 3+-+       5 5 +-+
+--R           - 1610a b  \|x  + (100a b \|x  - 3900a b )\|x  + 200a b \|x
+--R         + 
+--R                 2 8         8 2
+--R           - 120a b x - 2520a b
+--R      *
+--R         6+-+2
+--R         \|x
+--R     + 
+--R                 5 5 3+-+2      4 6 +-+        7 3 3+-+      6 4 +-+       3 7
+--R           - 690a b  \|x  + (50a b \|x  - 1200a b )\|x  + 70a b \|x  - 550a b x
+--R         + 
+--R                 9
+--R           - 600a b
+--R      *
+--R         6+-+
+--R         \|x
+--R     + 
+--R             6 4 3+-+2      5 5 +-+       2 8        8 2 3+-+
+--R       - 115a b  \|x  + (10a b \|x  - 600a b x - 150a b )\|x
+--R     + 
+--R             9       7 3  +-+        4 6       10
+--R       (20a b x + 10a b )\|x  - 2650a b x - 60a
+--R  /
+--R              13 3+-+     3 11 6+-+5      14 3+-+2     2 12 3+-+     4 10 6+-+4
+--R         (8a b   \|x + 40a b  )\|x   + (2b   \|x  + 36a b   \|x + 82a b  )\|x
+--R       + 
+--R              13 3+-+2     3 11 3+-+     5 9 6+-+3
+--R         (8a b   \|x  + 64a b   \|x + 88a b )\|x
+--R       + 
+--R             2 12 3+-+2     4 10 3+-+     6 8 6+-+2
+--R         (12a b   \|x  + 56a b   \|x + 52a b )\|x
+--R       + 
+--R            3 11 3+-+2     5 9 3+-+     7 7 6+-+     4 10 3+-+2    6 8 3+-+
+--R         (8a b   \|x  + 24a b  \|x + 16a b )\|x  + 2a b   \|x  + 4a b  \|x
+--R       + 
+--R           2 12      8 6
+--R         8a b  x + 2a b
+--R    *
+--R        +----------------------+
+--R        |    6+-+    2 3+-+   2
+--R       \|2a b\|x  + b  \|x + a
+--R                                                    Type: Expression(Integer)
+--E 1844
+
+--S 1845 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R               2 12 2        8 6     14 6+-+5        3 11 2        9 5  6+-+4
+--R           (91a b  x  + 3003a b x + a  )\|x   + (364a b  x  + 2002a b x)\|x
+--R         + 
+--R                 4 10 2        10 4  6+-+3         5 9 2       11 3  6+-+2
+--R           (1001a b  x  + 1001a  b x)\|x   + (2002a b x  + 364a  b x)\|x
+--R         + 
+--R           14 3        6 8 2      12 2  6+-+        13 3        7 7 2      13
+--R         (b  x  + 3003a b x  + 91a  b x)\|x  + 14a b  x  + 3432a b x  + 14a  b x
+--R      *
+--R          +-----------------------+
+--R          | 2 6+-+2      6+-+    2
+--R         \|b  \|x  + 2a b\|x  + a
+--R     + 
+--R              3 12 2        9 6     15 6+-+5           4 11 2        10 5  6+-+4
+--R       (- 455a b  x  - 5005a b x - a  )\|x   + (- 1365a b  x  - 3003a  b x)\|x
+--R     + 
+--R               5 10 2        11 4  6+-+3
+--R       (- 3003a b  x  - 1365a  b x)\|x
+--R     + 
+--R           15 3        6 9 2       12 3  6+-+2
+--R       (- b  x  - 5005a b x  - 455a  b x)\|x
+--R     + 
+--R               14 3        7 8 2       13 2  6+-+       2 13 3        8 7 2
+--R       (- 15a b  x  - 6435a b x  - 105a  b x)\|x  - 105a b  x  - 6435a b x
+--R     + 
+--R            14
+--R       - 15a  b x
+--R  /
+--R               18 3         7 12 2         13 6     19 6+-+5
+--R         (19a b  x  + 50388a b  x  + 27132a  b x + a  )\|x
+--R       + 
+--R              2 17 3         8 11 2         14 5  6+-+4
+--R         (171a b  x  + 75582a b  x  + 11628a  b x)\|x
+--R       + 
+--R              3 16 3         9 10 2        15 4  6+-+3
+--R         (969a b  x  + 92378a b  x  + 3876a  b x)\|x
+--R       + 
+--R               4 15 3         10 9 2       16 3  6+-+2
+--R         (3876a b  x  + 92378a  b x  + 969a  b x)\|x
+--R       + 
+--R                5 14 3         11 8 2       17 2  6+-+    19 4         6 13 3
+--R         (11628a b  x  + 75582a  b x  + 171a  b x)\|x  + b  x  + 27132a b  x
+--R       + 
+--R               12 7 2      18
+--R         50388a  b x  + 19a  b x
+--R    *
+--R        +-----------------------+
+--R        | 2 6+-+2      6+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1845
+
+)clear all
+
+--S 1846 of 2282
+t0:=(a^2+b^2/x^(2/(1+2*p))+2*a*b/x^(1/(1+2*p)))^p
+--R 
+--R
+--R                1              2           1   p
+--R             ------         ------      ------
+--R           2 2p + 1         2p + 1    2 2p + 1
+--R         (a x       + 2a b)x       + b x
+--R   (1)  (-------------------------------------)
+--R                         1      2
+--R                      ------ ------
+--R                      2p + 1 2p + 1
+--R                     x      x
+--R                                                    Type: Expression(Integer)
+--E 1846
+
+--S 1847 of 2282
+r0:=x*(a+b*x^(1/(-1-2*p)))*(a^2+2*a*b*x^(1/(-1-2*p))+b^2/x^(2/(1+2*p)))^p/a
+--R 
+--R
+--R                                          1            2        p
+--R                   1                 - ------       ------
+--R              - ------                 2p + 1    2  2p + 1    2
+--R                2p + 1        (2a b x         + a )x       + b
+--R        (b x x         + a x)(---------------------------------)
+--R                                               2
+--R                                            ------
+--R                                            2p + 1
+--R                                           x
+--R   (2)  ---------------------------------------------------------
+--R                                    a
+--R                                                    Type: Expression(Integer)
+--E 1847
+
+--S 1848 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       1                2             1   p
+--R                    ------           ------        ------
+--R           x    2   2p + 1           2p + 1    2   2p + 1
+--R         ++   (a %BM       + 2a b)%BM       + b %BM
+--R   (3)   |   (-------------------------------------------) d%BM
+--R        ++                       1        2
+--R                              ------   ------
+--R                              2p + 1   2p + 1
+--R                           %BM      %BM
+--R                                         Type: Union(Expression(Integer),...)
+--E 1848
+
+--S 1849 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       1                2             1   p
+--R                    ------           ------        ------
+--R           x    2   2p + 1           2p + 1    2   2p + 1
+--R         ++   (a %BM       + 2a b)%BM       + b %BM
+--R       a |   (-------------------------------------------) d%BM
+--R        ++                       1        2
+--R                              ------   ------
+--R                              2p + 1   2p + 1
+--R                           %BM      %BM
+--R     + 
+--R                                           1            2        p
+--R                    1                 - ------       ------
+--R               - ------                 2p + 1    2  2p + 1    2
+--R                 2p + 1        (2a b x         + a )x       + b
+--R       (- b x x         - a x)(---------------------------------)
+--R                                                2
+--R                                             ------
+--R                                             2p + 1
+--R                                            x
+--R  /
+--R     a
+--R                                                    Type: Expression(Integer)
+--E 1849
+
+--S 1850 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1850
+
+)clear all
+
+--S 1851 of 2282
+t0:=1/(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2*(1+n)/n)
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                              n + 1
+--R                              -----
+--R          2 2n         n    2   2n
+--R        (b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1851
+
+--S 1852 of 2282
+r0:=x*(a+b*x^n)/(a*(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2*(1+n)/n))
+--R 
+--R
+--R                      n
+--R                 b x x  + a x
+--R   (2)  -----------------------------
+--R                                n + 1
+--R                                -----
+--R            2 2n         n    2   2n
+--R        a (b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1852
+
+--S 1853 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x
+--R         ++                 1
+--R   (3)   |   ------------------------------- d%BM
+--R        ++                             n + 1
+--R                                       -----
+--R               2   2n           n    2   2n
+--R             (b %BM   + 2a b %BM  + a )
+--R                                         Type: Union(Expression(Integer),...)
+--E 1853
+
+--S 1854 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               n + 1
+--R                               -----   x
+--R           2 2n         n    2   2n  ++                 1
+--R       a (b x   + 2a b x  + a )      |   ------------------------------- d%BM
+--R                                    ++                             n + 1
+--R                                                                   -----
+--R                                           2   2n           n    2   2n
+--R                                         (b %BM   + 2a b %BM  + a )
+--R     + 
+--R              n
+--R       - b x x  - a x
+--R  /
+--R                             n + 1
+--R                             -----
+--R         2 2n         n    2   2n
+--R     a (b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1854
+
+--S 1855 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1855
+
+)clear all
+
+--S 1856 of 2282
+t0:=(a^2+b^2/x^(1/(1+p))+2*a*b/x^(1/2/(1+p)))^p
+--R 
+--R
+--R                1             1           1   p
+--R             ------         -----      ------
+--R           2 2p + 2         p + 1    2 2p + 2
+--R         (a x       + 2a b)x      + b x
+--R   (1)  (------------------------------------)
+--R                         1     1
+--R                      ------ -----
+--R                      2p + 2 p + 1
+--R                     x      x
+--R                                                    Type: Expression(Integer)
+--E 1856
+
+--S 1857 of 2282
+r0:=2*(1+p)*x*(a+b/x^(1/2/(1+p)))*(a^2+b^2/x^(1/(1+p))+_
+   2*a*b/x^(1/2/(1+p)))^p/(a*(1+2*p))-x*(a^2+b^2/x^(1/(1+p))+_
+   2*a*b/x^(1/2/(1+p)))^(1+p)/(a^2*(1+2*p))
+--R 
+--R
+--R   (2)
+--R                          1             1           1   p + 1
+--R               1       ------         -----      ------
+--R            ------   2 2p + 2         p + 1    2 2p + 2
+--R            2p + 2 (a x       + 2a b)x      + b x
+--R       - x x      (------------------------------------)
+--R                                   1     1
+--R                                ------ -----
+--R                                2p + 2 p + 1
+--R                               x      x
+--R     + 
+--R                            1
+--R                         ------
+--R             2      2    2p + 2
+--R         ((2a p + 2a )x x       + (2a b p + 2a b)x)
+--R      *
+--R                 1             1           1   p
+--R              ------         -----      ------
+--R            2 2p + 2         p + 1    2 2p + 2
+--R          (a x       + 2a b)x      + b x
+--R         (------------------------------------)
+--R                          1     1
+--R                       ------ -----
+--R                       2p + 2 p + 1
+--R                      x      x
+--R  /
+--R                    1
+--R                 ------
+--R        2     2  2p + 2
+--R     (2a p + a )x
+--R                                                    Type: Expression(Integer)
+--E 1857
+
+--S 1858 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       1               1             1   p
+--R                    ------           -----        ------
+--R           x    2   2p + 2           p + 1    2   2p + 2
+--R         ++   (a %BM       + 2a b)%BM      + b %BM
+--R   (3)   |   (------------------------------------------) d%BM
+--R        ++                       1       1
+--R                              ------   -----
+--R                              2p + 2   p + 1
+--R                           %BM      %BM
+--R                                         Type: Union(Expression(Integer),...)
+--E 1858
+
+--S 1859 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                        1               1             1   p
+--R                      1              ------           -----        ------
+--R                   ------   x    2   2p + 2           p + 1    2   2p + 2
+--R          2     2  2p + 2 ++   (a %BM       + 2a b)%BM      + b %BM
+--R       (2a p + a )x       |   (------------------------------------------) d%BM
+--R                         ++                       1       1
+--R                                               ------   -----
+--R                                               2p + 2   p + 1
+--R                                            %BM      %BM
+--R     + 
+--R                        1             1           1   p + 1
+--R             1       ------         -----      ------
+--R          ------   2 2p + 2         p + 1    2 2p + 2
+--R          2p + 2 (a x       + 2a b)x      + b x
+--R       x x      (------------------------------------)
+--R                                 1     1
+--R                              ------ -----
+--R                              2p + 2 p + 1
+--R                             x      x
+--R     + 
+--R                              1
+--R                           ------
+--R               2      2    2p + 2
+--R         ((- 2a p - 2a )x x       + (- 2a b p - 2a b)x)
+--R      *
+--R                 1             1           1   p
+--R              ------         -----      ------
+--R            2 2p + 2         p + 1    2 2p + 2
+--R          (a x       + 2a b)x      + b x
+--R         (------------------------------------)
+--R                          1     1
+--R                       ------ -----
+--R                       2p + 2 p + 1
+--R                      x      x
+--R  /
+--R                    1
+--R                 ------
+--R        2     2  2p + 2
+--R     (2a p + a )x
+--R                                                    Type: Expression(Integer)
+--E 1859
+
+--S 1860 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1860
+
+)clear all
+
+--S 1861 of 2282
+t0:=1/(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2*(1+2*n)/n)
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R                              2n + 1
+--R                              ------
+--R          2 2n         n    2   2n
+--R        (b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1861
+
+--S 1862 of 2282
+r0:=x*(a+b*x^n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2*(-2+(-1)/n))/(a*(1+n))+_
+   n*x/(a^2*(1+n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2/n))
+--R 
+--R
+--R   (2)
+--R                                         - 2n - 1                       1
+--R                                         --------                      --
+--R           n    2    2 2n         n    2    2n     2 2n         n    2 2n
+--R   (a b x x  + a x)(b x   + 2a b x  + a )        (b x   + 2a b x  + a )   + n x
+--R   ----------------------------------------------------------------------------
+--R                                                         1
+--R                                                        --
+--R                          2     2   2 2n         n    2 2n
+--R                        (a n + a )(b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1862
+
+--S 1863 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x
+--R         ++                  1
+--R   (3)   |   -------------------------------- d%BM
+--R        ++                             2n + 1
+--R                                       ------
+--R               2   2n           n    2   2n
+--R             (b %BM   + 2a b %BM  + a )
+--R                                         Type: Union(Expression(Integer),...)
+--E 1863
+
+--S 1864 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                          1
+--R                                         --
+--R           2     2   2 2n         n    2 2n
+--R         (a n + a )(b x   + 2a b x  + a )
+--R      *
+--R            x
+--R          ++                  1
+--R          |   -------------------------------- d%BM
+--R         ++                             2n + 1
+--R                                        ------
+--R                2   2n           n    2   2n
+--R              (b %BM   + 2a b %BM  + a )
+--R     + 
+--R                                               - 2n - 1                       1
+--R                                               --------                      --
+--R                 n    2    2 2n         n    2    2n     2 2n         n    2 2n
+--R       (- a b x x  - a x)(b x   + 2a b x  + a )        (b x   + 2a b x  + a )
+--R     + 
+--R       - n x
+--R  /
+--R                                      1
+--R                                     --
+--R       2     2   2 2n         n    2 2n
+--R     (a n + a )(b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1864
+
+--S 1865 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      2   n log(x) 2          n log(x)    2
+--R     b (%e        )  + 2a b %e         + a  - 1
+--R  /
+--R         2   n log(x) 2          n log(x)    2
+--R       (b (%e        )  + 2a b %e         + a )
+--R    *
+--R              2   n log(x) 2          n log(x)    2
+--R         log(b (%e        )  + 2a b %e         + a )
+--R         -------------------------------------------
+--R                              2n
+--R       %e
+--R                                                    Type: Expression(Integer)
+--E 1865
+
+)clear all
+
+--S 1866 of 2282
+t0:=x^(-1+2*n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^p
+--R 
+--R
+--R         2n - 1  2 2n         n    2 p
+--R   (1)  x      (b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1866
+
+--S 1867 of 2282
+r0:=-a*(a+b*x^n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^p/(b^2*n*(1+2*p))+_
+   1/2*(a^2+2*a*b*x^n+b^2*x^(2*n))^(1+p)/(b^2*n*(1+p))
+--R 
+--R
+--R   (2)
+--R                 2 2n         n    2 p + 1
+--R       (2p + 1)(b x   + 2a b x  + a )
+--R     + 
+--R                          n     2      2   2 2n         n    2 p
+--R       ((- 2a b p - 2a b)x  - 2a p - 2a )(b x   + 2a b x  + a )
+--R  /
+--R       2   2     2        2
+--R     4b n p  + 6b n p + 2b n
+--R                                                    Type: Expression(Integer)
+--E 1867
+
+--S 1868 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2     2    n log(x) 2            n log(x)    2
+--R       ((2b p + b )(%e        )  + 2a b p %e         - a )
+--R    *
+--R                2   n log(x) 2          n log(x)    2
+--R         p log(b (%e        )  + 2a b %e         + a )
+--R       %e
+--R  /
+--R       2   2     2        2
+--R     4b n p  + 6b n p + 2b n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1868
+
+--S 1869 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2     2    n log(x) 2            n log(x)    2
+--R         ((2b p + b )(%e        )  + 2a b p %e         - a )
+--R      *
+--R                  2   n log(x) 2          n log(x)    2
+--R           p log(b (%e        )  + 2a b %e         + a )
+--R         %e
+--R     + 
+--R                   2 2n         n    2 p + 1
+--R       (- 2p - 1)(b x   + 2a b x  + a )
+--R     + 
+--R                        n     2      2   2 2n         n    2 p
+--R       ((2a b p + 2a b)x  + 2a p + 2a )(b x   + 2a b x  + a )
+--R  /
+--R       2   2     2        2
+--R     4b n p  + 6b n p + 2b n
+--R                                                    Type: Expression(Integer)
+--E 1869
+
+--S 1870 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1870
+
+)clear all
+
+--S 1871 of 2282
+t0:=x^(-1+2*n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2)
+--R 
+--R
+--R   (1)
+--R        4 2n - 1  2n 2        3 n     2 2  2n - 1 2n
+--R       b x      (x  )  + (4a b x  + 2a b )x      x
+--R     + 
+--R          2 2  n 2     3   n    4  2n - 1
+--R       (4a b (x )  + 4a b x  + a )x
+--R  *
+--R      +--------------------+
+--R      | 2 2n         n    2
+--R     \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1871
+
+--S 1872 of 2282
+r0:=-1/6*a*(a+b*x^n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2)/(b^2*n)+_
+   1/7*(a^2+2*a*b*x^n+b^2*x^(2*n))^(7/2)/(b^2*n)
+--R 
+--R
+--R   (2)
+--R           6  2n 3         5 n      2 4   2n 2
+--R         6b (x  )  + (29a b x  + 11a b )(x  )
+--R       + 
+--R             2 4  n 2      3 3 n     4 2  2n      3 3  n 3      4 2  n 2
+--R         (44a b (x )  + 30a b x  + 4a b )x   + 20a b (x )  + 16a b (x )
+--R       + 
+--R          5   n    6
+--R         a b x  - a
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R  /
+--R        2
+--R     42b n
+--R                                                    Type: Expression(Integer)
+--E 1872
+
+--S 1873 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         5   n log(x) 7        4   n log(x) 6      2 3   n log(x) 5
+--R       6b (%e        )  + 35a b (%e        )  + 84a b (%e        )
+--R     + 
+--R           3 2   n log(x) 4      4     n log(x) 3      5   n log(x) 2
+--R       105a b (%e        )  + 70a b (%e        )  + 21a (%e        )
+--R  /
+--R     42n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1873
+
+--S 1874 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               6  2n 3           5 n      2 4   2n 2
+--R           - 6b (x  )  + (- 29a b x  - 11a b )(x  )
+--R         + 
+--R                 2 4  n 2      3 3 n     4 2  2n      3 3  n 3      4 2  n 2
+--R           (- 44a b (x )  - 30a b x  - 4a b )x   - 20a b (x )  - 16a b (x )
+--R         + 
+--R              5   n    6
+--R           - a b x  + a
+--R      *
+--R          +--------------------+
+--R          | 2 2n         n    2
+--R         \|b x   + 2a b x  + a
+--R     + 
+--R         7   n log(x) 7        6   n log(x) 6      2 5   n log(x) 5
+--R       6b (%e        )  + 35a b (%e        )  + 84a b (%e        )
+--R     + 
+--R           3 4   n log(x) 4      4 3   n log(x) 3      5 2   n log(x) 2
+--R       105a b (%e        )  + 70a b (%e        )  + 21a b (%e        )
+--R  /
+--R        2
+--R     42b n
+--R                                                    Type: Expression(Integer)
+--E 1874
+
+--S 1875 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R            5   n log(x) 7       4   n log(x) 6      2 3   n log(x) 5
+--R           b (%e        )  + 5a b (%e        )  + 10a b (%e        )
+--R         + 
+--R              3 2   n log(x) 4     4     n log(x) 3    5   n log(x) 2
+--R           10a b (%e        )  + 5a b (%e        )  + a (%e        )
+--R      *
+--R          +--------------------------------------+
+--R          | 2   n log(x) 2          n log(x)    2
+--R         \|b (%e        )  + 2a b %e         + a
+--R     + 
+--R          6   n log(x) 8       5   n log(x) 7      2 4   n log(x) 6
+--R       - b (%e        )  - 6a b (%e        )  - 15a b (%e        )
+--R     + 
+--R            3 3   n log(x) 5      4 2   n log(x) 4     5     n log(x) 3
+--R       - 20a b (%e        )  - 15a b (%e        )  - 6a b (%e        )
+--R     + 
+--R          6   n log(x) 2
+--R       - a (%e        )
+--R  /
+--R       +--------------------------------------+
+--R       | 2   n log(x) 2          n log(x)    2
+--R     x\|b (%e        )  + 2a b %e         + a
+--R                                                    Type: Expression(Integer)
+--E 1875
+
+)clear all
+
+--S 1876 of 2282
+t0:=x^(-1+2*n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(3/2)
+--R 
+--R
+--R                                               +--------------------+
+--R          2 2n - 1 2n          n    2  2n - 1  | 2 2n         n    2
+--R   (1)  (b x      x   + (2a b x  + a )x      )\|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1876
+
+--S 1877 of 2282
+r0:=-1/4*a*(a+b*x^n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(3/2)/(b^2*n)+_
+   1/5*(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2)/(b^2*n)
+--R 
+--R
+--R   (2)
+--R          4  2n 2         3 n     2 2  2n     2 2  n 2    3   n    4
+--R       (4b (x  )  + (11a b x  + 3a b )x   + 6a b (x )  + a b x  - a )
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R  /
+--R        2
+--R     20b n
+--R                                                    Type: Expression(Integer)
+--E 1877
+
+--S 1878 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3   n log(x) 5        2   n log(x) 4      2     n log(x) 3
+--R       4b (%e        )  + 15a b (%e        )  + 20a b (%e        )
+--R     + 
+--R          3   n log(x) 2
+--R       10a (%e        )
+--R  /
+--R     20n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1878
+
+--S 1879 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              4  2n 2           3 n     2 2  2n     2 2  n 2    3   n    4
+--R         (- 4b (x  )  + (- 11a b x  - 3a b )x   - 6a b (x )  - a b x  + a )
+--R      *
+--R          +--------------------+
+--R          | 2 2n         n    2
+--R         \|b x   + 2a b x  + a
+--R     + 
+--R         5   n log(x) 5        4   n log(x) 4      2 3   n log(x) 3
+--R       4b (%e        )  + 15a b (%e        )  + 20a b (%e        )
+--R     + 
+--R          3 2   n log(x) 2
+--R       10a b (%e        )
+--R  /
+--R        2
+--R     20b n
+--R                                                    Type: Expression(Integer)
+--E 1879
+
+--S 1880 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R            3   n log(x) 5       2   n log(x) 4     2     n log(x) 3
+--R           b (%e        )  + 3a b (%e        )  + 3a b (%e        )
+--R         + 
+--R            3   n log(x) 2
+--R           a (%e        )
+--R      *
+--R          +--------------------------------------+
+--R          | 2   n log(x) 2          n log(x)    2
+--R         \|b (%e        )  + 2a b %e         + a
+--R     + 
+--R          4   n log(x) 6       3   n log(x) 5     2 2   n log(x) 4
+--R       - b (%e        )  - 4a b (%e        )  - 6a b (%e        )
+--R     + 
+--R           3     n log(x) 3    4   n log(x) 2
+--R       - 4a b (%e        )  - a (%e        )
+--R  /
+--R       +--------------------------------------+
+--R       | 2   n log(x) 2          n log(x)    2
+--R     x\|b (%e        )  + 2a b %e         + a
+--R                                                    Type: Expression(Integer)
+--E 1880
+
+)clear all
+
+--S 1881 of 2282
+t0:=x^(-1+2*n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2)
+--R 
+--R
+--R                +--------------------+
+--R         2n - 1 | 2 2n         n    2
+--R   (1)  x      \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1881
+
+--S 1882 of 2282
+r0:=1/3*x^(2*n)*sqrt(a^2+2*a*b*x^n+b^2*x^(2*n))/n+1/6*a*x^(2*n)*_
+   sqrt(a^2+2*a*b*x^n+b^2*x^(2*n))/(n*(a+b*x^n))
+--R 
+--R
+--R                        +--------------------+
+--R             n       2n | 2 2n         n    2
+--R        (2b x  + 3a)x  \|b x   + 2a b x  + a
+--R   (2)  --------------------------------------
+--R                          n
+--R                    6b n x  + 6a n
+--R                                                    Type: Expression(Integer)
+--E 1882
+
+--S 1883 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R              n log(x) 3         n log(x) 2
+--R        2b (%e        )  + 3a (%e        )
+--R   (3)  -----------------------------------
+--R                         6n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1883
+
+--S 1884 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +--------------------+
+--R              n       2n | 2 2n         n    2       2 n           n log(x) 3
+--R       (- 2b x  - 3a)x  \|b x   + 2a b x  + a   + (2b x  + 2a b)(%e        )
+--R     + 
+--R              n     2    n log(x) 2
+--R       (3a b x  + 3a )(%e        )
+--R  /
+--R           n
+--R     6b n x  + 6a n
+--R                                                    Type: Expression(Integer)
+--E 1884
+
+--S 1885 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R               n log(x) 3        n log(x) 2
+--R         (b (%e        )  + a (%e        ) )
+--R      *
+--R          +--------------------------------------+
+--R          | 2   n log(x) 2          n log(x)    2
+--R         \|b (%e        )  + 2a b %e         + a
+--R     + 
+--R          2   n log(x) 4           n log(x) 3    2   n log(x) 2
+--R       - b (%e        )  - 2a b (%e        )  - a (%e        )
+--R  /
+--R       +--------------------------------------+
+--R       | 2   n log(x) 2          n log(x)    2
+--R     x\|b (%e        )  + 2a b %e         + a
+--R                                                    Type: Expression(Integer)
+--E 1885
+
+)clear all
+
+--S 1886 of 2282
+t0:=x^(-1+2*n)/(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2)
+--R 
+--R
+--R                 2n - 1
+--R                x
+--R   (1)  -----------------------
+--R         +--------------------+
+--R         | 2 2n         n    2
+--R        \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1886
+
+--S 1887 of 2282
+r0:=-a*(a+b*x^n)*log(a+b*x^n)/(b^2*n*sqrt(a^2+2*a*b*x^n+b^2*x^(2*n)))+_
+   sqrt(a^2+2*a*b*x^n+b^2*x^(2*n))/(b^2*n)
+--R 
+--R
+--R                n    2        n         2 2n         n    2
+--R        (- a b x  - a )log(b x  + a) + b x   + 2a b x  + a
+--R   (2)  ---------------------------------------------------
+--R                         +--------------------+
+--R                      2  | 2 2n         n    2
+--R                     b n\|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1887
+
+--S 1888 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    n log(x)            n log(x)
+--R        - a log(b %e         + a) + b %e
+--R   (3)  ----------------------------------------
+--R                            2
+--R                           b n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1888
+
+--S 1889 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           +--------------------+
+--R           | 2 2n         n    2         n log(x)
+--R       - a\|b x   + 2a b x  + a  log(b %e         + a)
+--R     + 
+--R                    +--------------------+
+--R           n log(x) | 2 2n         n    2          n    2        n         2 2n
+--R       b %e        \|b x   + 2a b x  + a   + (a b x  + a )log(b x  + a) - b x
+--R     + 
+--R               n    2
+--R       - 2a b x  - a
+--R  /
+--R         +--------------------+
+--R      2  | 2 2n         n    2
+--R     b n\|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1889
+
+--S 1890 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                     +--------------------------------------+
+--R          n log(x) 2 | 2   n log(x) 2          n log(x)    2         n log(x) 3
+--R       (%e        ) \|b (%e        )  + 2a b %e         + a   - b (%e        )
+--R     + 
+--R              n log(x) 2
+--R       - a (%e        )
+--R  /
+--R                            +--------------------------------------+
+--R            n log(x)        | 2   n log(x) 2          n log(x)    2
+--R     (b x %e         + a x)\|b (%e        )  + 2a b %e         + a
+--R                                                    Type: Expression(Integer)
+--E 1890
+
+)clear all
+
+--S 1891 of 2282
+t0:=x^(-1+2*n)/(a^2+2*a*b*x^n+b^2*x^(2*n))^(3/2)
+--R 
+--R
+--R                            2n - 1
+--R                           x
+--R   (1)  ---------------------------------------------
+--R                               +--------------------+
+--R          2 2n         n    2  | 2 2n         n    2
+--R        (b x   + 2a b x  + a )\|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1891
+
+--S 1892 of 2282
+r0:=1/2*x^(2*n)*(a+b*x^n)/(a*n*(a^2+2*a*b*x^n+b^2*x^(2*n))^(3/2))
+--R 
+--R
+--R                                 n      2n
+--R                             (b x  + a)x
+--R   (2)  ------------------------------------------------------
+--R                                        +--------------------+
+--R             2   2n     2     n     3   | 2 2n         n    2
+--R        (2a b n x   + 4a b n x  + 2a n)\|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1892
+
+--S 1893 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             n log(x)
+--R                      - 2b %e         - a
+--R   (3)  -----------------------------------------------
+--R          4     n log(x) 2       3    n log(x)     2 2
+--R        2b n (%e        )  + 4a b n %e         + 2a b n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1893
+
+--S 1894 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3 2n     2 2 n     3    n log(x)    2 2 2n     3   n    4
+--R         ((- 2a b x   - 4a b x  - 2a b)%e         - a b x   - 2a b x  - a )
+--R      *
+--R          +--------------------+
+--R          | 2 2n         n    2
+--R         \|b x   + 2a b x  + a
+--R     + 
+--R           5 n      4  2n   n log(x) 2          4 n     2 3  2n  n log(x)
+--R       (- b x  - a b )x  (%e        )  + (- 2a b x  - 2a b )x  %e
+--R     + 
+--R           2 3 n    3 2  2n
+--R       (- a b x  - a b )x
+--R  /
+--R              6   2n     2 5   n     3 4     n log(x) 2
+--R         (2a b n x   + 4a b n x  + 2a b n)(%e        )
+--R       + 
+--R            2 5   2n     3 4   n     4 3    n log(x)     3 4   2n     4 3   n
+--R         (4a b n x   + 8a b n x  + 4a b n)%e         + 2a b n x   + 4a b n x
+--R       + 
+--R           5 2
+--R         2a b n
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1894
+
+--S 1895 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                     +--------------------------------------+
+--R          n log(x) 2 | 2   n log(x) 2          n log(x)    2         n log(x) 3
+--R       (%e        ) \|b (%e        )  + 2a b %e         + a   - b (%e        )
+--R     + 
+--R              n log(x) 2
+--R       - a (%e        )
+--R  /
+--R         3     n log(x) 3       2     n log(x) 2     2      n log(x)    3
+--R       (b x (%e        )  + 3a b x (%e        )  + 3a b x %e         + a x)
+--R    *
+--R        +--------------------------------------+
+--R        | 2   n log(x) 2          n log(x)    2
+--R       \|b (%e        )  + 2a b %e         + a
+--R                                                    Type: Expression(Integer)
+--E 1895
+
+)clear all
+
+--S 1896 of 2282
+t0:=x^(-1+2*n)/(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2)
+--R 
+--R
+--R   (1)
+--R      2n - 1
+--R     x
+--R  /
+--R         4  2n 2        3 n     2 2  2n     2 2  n 2     3   n    4
+--R       (b (x  )  + (4a b x  + 2a b )x   + 4a b (x )  + 4a b x  + a )
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1896
+
+--S 1897 of 2282
+r0:=1/4*a*(a+b*x^n)/(b^2*n*(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2))+(-1/3)/_
+   (b^2*n*(a^2+2*a*b*x^n+b^2*x^(2*n))^(3/2))
+--R 
+--R
+--R   (2)
+--R         2 2n         n    2
+--R     - 4b x   - 5a b x  - a
+--R  /
+--R            6    2n 2         5   n      2 4   2n      2 4    n 2      3 3   n
+--R         12b n (x  )  + (48a b n x  + 24a b n)x   + 48a b n (x )  + 48a b n x
+--R       + 
+--R            4 2
+--R         12a b n
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1897
+
+--S 1898 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            n log(x)
+--R     - 4b %e         - a
+--R  /
+--R          6     n log(x) 4        5     n log(x) 3      2 4     n log(x) 2
+--R       12b n (%e        )  + 48a b n (%e        )  + 72a b n (%e        )
+--R     + 
+--R          3 3    n log(x)      4 2
+--R       48a b n %e         + 12a b n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1898
+
+--S 1899 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   5  2n 2           4 n     2 3  2n      2 3  n 2      3 2 n
+--R               - 4b (x  )  + (- 16a b x  - 8a b )x   - 16a b (x )  - 16a b x
+--R             + 
+--R                   4
+--R               - 4a b
+--R          *
+--R               n log(x)
+--R             %e
+--R         + 
+--R                4  2n 2        2 3 n     3 2  2n     3 2  n 2     4   n    5
+--R           - a b (x  )  + (- 4a b x  - 2a b )x   - 4a b (x )  - 4a b x  - a
+--R      *
+--R          +--------------------+
+--R          | 2 2n         n    2
+--R         \|b x   + 2a b x  + a
+--R     + 
+--R          6 2n       5 n    2 4    n log(x) 4
+--R       (4b x   + 5a b x  + a b )(%e        )
+--R     + 
+--R             5 2n      2 4 n     3 3    n log(x) 3
+--R       (16a b x   + 20a b x  + 4a b )(%e        )
+--R     + 
+--R           2 4 2n      3 3 n     4 2    n log(x) 2
+--R       (24a b x   + 30a b x  + 6a b )(%e        )
+--R     + 
+--R           3 3 2n      4 2 n     5    n log(x)     4 2 2n     5   n    6
+--R       (16a b x   + 20a b x  + 4a b)%e         + 4a b x   + 5a b x  + a
+--R  /
+--R                10    2n 2         9   n      2 8   2n      2 8    n 2
+--R             12b  n (x  )  + (48a b n x  + 24a b n)x   + 48a b n (x )
+--R           + 
+--R                3 7   n      4 6
+--R             48a b n x  + 12a b n
+--R        *
+--R              n log(x) 4
+--R           (%e        )
+--R       + 
+--R                  9    2n 2        2 8   n      3 7   2n       3 7    n 2
+--R             48a b n (x  )  + (192a b n x  + 96a b n)x   + 192a b n (x )
+--R           + 
+--R                 4 6   n      5 5
+--R             192a b n x  + 48a b n
+--R        *
+--R              n log(x) 3
+--R           (%e        )
+--R       + 
+--R                2 8    2n 2        3 7   n       4 6   2n       4 6    n 2
+--R             72a b n (x  )  + (288a b n x  + 144a b n)x   + 288a b n (x )
+--R           + 
+--R                 5 5   n      6 4
+--R             288a b n x  + 72a b n
+--R        *
+--R              n log(x) 2
+--R           (%e        )
+--R       + 
+--R                3 7    2n 2        4 6   n      5 5   2n       5 5    n 2
+--R             48a b n (x  )  + (192a b n x  + 96a b n)x   + 192a b n (x )
+--R           + 
+--R                 6 4   n      7 3
+--R             192a b n x  + 48a b n
+--R        *
+--R             n log(x)
+--R           %e
+--R       + 
+--R            4 6    2n 2       5 5   n      6 4   2n      6 4    n 2      7 3   n
+--R         12a b n (x  )  + (48a b n x  + 24a b n)x   + 48a b n (x )  + 48a b n x
+--R       + 
+--R            8 2
+--R         12a b n
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1899
+
+--S 1900 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                     +--------------------------------------+
+--R          n log(x) 2 | 2   n log(x) 2          n log(x)    2         n log(x) 3
+--R       (%e        ) \|b (%e        )  + 2a b %e         + a   - b (%e        )
+--R     + 
+--R              n log(x) 2
+--R       - a (%e        )
+--R  /
+--R          5     n log(x) 5       4     n log(x) 4      2 3     n log(x) 3
+--R         b x (%e        )  + 5a b x (%e        )  + 10a b x (%e        )
+--R       + 
+--R            3 2     n log(x) 2     4      n log(x)    5
+--R         10a b x (%e        )  + 5a b x %e         + a x
+--R    *
+--R        +--------------------------------------+
+--R        | 2   n log(x) 2          n log(x)    2
+--R       \|b (%e        )  + 2a b %e         + a
+--R                                                    Type: Expression(Integer)
+--E 1900
+
+)clear all
+
+--S 1901 of 2282
+t0:=x^(-1+2*n)/(a^2+2*a*b*x^n+b^2*x^(2*n))^(7/2)
+--R 
+--R
+--R   (1)
+--R      2n - 1
+--R     x
+--R  /
+--R          6  2n 3        5 n     2 4   2n 2
+--R         b (x  )  + (6a b x  + 3a b )(x  )
+--R       + 
+--R             2 4  n 2      3 3 n     4 2  2n     3 3  n 3      4 2  n 2
+--R         (12a b (x )  + 12a b x  + 3a b )x   + 8a b (x )  + 12a b (x )
+--R       + 
+--R           5   n    6
+--R         6a b x  + a
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1901
+
+--S 1902 of 2282
+r0:=1/6*a*(a+b*x^n)/(b^2*n*(a^2+2*a*b*x^n+b^2*x^(2*n))^(7/2))+_
+   (-1/5)/(b^2*n*(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2))
+--R 
+--R
+--R   (2)
+--R         2 2n         n    2
+--R     - 6b x   - 7a b x  - a
+--R  /
+--R            8    2n 3          7   n      2 6    2n 2
+--R         30b n (x  )  + (180a b n x  + 90a b n)(x  )
+--R       + 
+--R              2 6    n 2       3 5   n      4 4   2n       3 5    n 3
+--R         (360a b n (x )  + 360a b n x  + 90a b n)x   + 240a b n (x )
+--R       + 
+--R             4 4    n 2       5 3   n      6 2
+--R         360a b n (x )  + 180a b n x  + 30a b n
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1902
+
+--S 1903 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            n log(x)
+--R     - 6b %e         - a
+--R  /
+--R          8     n log(x) 6         7     n log(x) 5       2 6     n log(x) 4
+--R       30b n (%e        )  + 180a b n (%e        )  + 450a b n (%e        )
+--R     + 
+--R           3 5     n log(x) 3       4 4     n log(x) 2       5 3    n log(x)
+--R       600a b n (%e        )  + 450a b n (%e        )  + 180a b n %e
+--R     + 
+--R          6 2
+--R       30a b n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1903
+
+--S 1904 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   7  2n 3           6 n      2 5   2n 2
+--R               - 6b (x  )  + (- 36a b x  - 18a b )(x  )
+--R             + 
+--R                     2 5  n 2      3 4 n      4 3  2n      3 4  n 3
+--R               (- 72a b (x )  - 72a b x  - 18a b )x   - 48a b (x )
+--R             + 
+--R                    4 3  n 2      5 2 n     6
+--R               - 72a b (x )  - 36a b x  - 6a b
+--R          *
+--R               n log(x)
+--R             %e
+--R         + 
+--R                6  2n 3        2 5 n     3 4   2n 2
+--R           - a b (x  )  + (- 6a b x  - 3a b )(x  )
+--R         + 
+--R                 3 4  n 2      4 3 n     5 2  2n     4 3  n 3      5 2  n 2
+--R           (- 12a b (x )  - 12a b x  - 3a b )x   - 8a b (x )  - 12a b (x )
+--R         + 
+--R               6   n    7
+--R           - 6a b x  - a
+--R      *
+--R          +--------------------+
+--R          | 2 2n         n    2
+--R         \|b x   + 2a b x  + a
+--R     + 
+--R          8 2n       7 n    2 6    n log(x) 6
+--R       (6b x   + 7a b x  + a b )(%e        )
+--R     + 
+--R             7 2n      2 6 n     3 5    n log(x) 5
+--R       (36a b x   + 42a b x  + 6a b )(%e        )
+--R     + 
+--R           2 6 2n       3 5 n      4 4    n log(x) 4
+--R       (90a b x   + 105a b x  + 15a b )(%e        )
+--R     + 
+--R            3 5 2n       4 4 n      5 3    n log(x) 3
+--R       (120a b x   + 140a b x  + 20a b )(%e        )
+--R     + 
+--R           4 4 2n       5 3 n      6 2    n log(x) 2
+--R       (90a b x   + 105a b x  + 15a b )(%e        )
+--R     + 
+--R           5 3 2n      6 2 n     7    n log(x)     6 2 2n     7   n    8
+--R       (36a b x   + 42a b x  + 6a b)%e         + 6a b x   + 7a b x  + a
+--R  /
+--R                14    2n 3          13   n      2 12    2n 2
+--R             30b  n (x  )  + (180a b  n x  + 90a b  n)(x  )
+--R           + 
+--R                  2 12    n 2       3 11   n      4 10   2n       3 11    n 3
+--R             (360a b  n (x )  + 360a b  n x  + 90a b  n)x   + 240a b  n (x )
+--R           + 
+--R                 4 10    n 2       5 9   n      6 8
+--R             360a b  n (x )  + 180a b n x  + 30a b n
+--R        *
+--R              n log(x) 6
+--R           (%e        )
+--R       + 
+--R                   13    2n 3         2 12   n       3 11    2n 2
+--R             180a b  n (x  )  + (1080a b  n x  + 540a b  n)(x  )
+--R           + 
+--R                   3 11    n 2        4 10   n       5 9   2n        4 10    n 3
+--R             (2160a b  n (x )  + 2160a b  n x  + 540a b n)x   + 1440a b  n (x )
+--R           + 
+--R                  5 9    n 2        6 8   n       7 7
+--R             2160a b n (x )  + 1080a b n x  + 180a b n
+--R        *
+--R              n log(x) 5
+--R           (%e        )
+--R       + 
+--R                 2 12    2n 3         3 11   n        4 10    2n 2
+--R             450a b  n (x  )  + (2700a b  n x  + 1350a b  n)(x  )
+--R           + 
+--R                   4 10    n 2        5 9   n        6 8   2n        5 9    n 3
+--R             (5400a b  n (x )  + 5400a b n x  + 1350a b n)x   + 3600a b n (x )
+--R           + 
+--R                  6 8    n 2        7 7   n       8 6
+--R             5400a b n (x )  + 2700a b n x  + 450a b n
+--R        *
+--R              n log(x) 4
+--R           (%e        )
+--R       + 
+--R                 3 11    2n 3         4 10   n        5 9    2n 2
+--R             600a b  n (x  )  + (3600a b  n x  + 1800a b n)(x  )
+--R           + 
+--R                   5 9    n 2        6 8   n        7 7   2n        6 8    n 3
+--R             (7200a b n (x )  + 7200a b n x  + 1800a b n)x   + 4800a b n (x )
+--R           + 
+--R                  7 7    n 2        8 6   n       9 5
+--R             7200a b n (x )  + 3600a b n x  + 600a b n
+--R        *
+--R              n log(x) 3
+--R           (%e        )
+--R       + 
+--R                 4 10    2n 3         5 9   n        6 8    2n 2
+--R             450a b  n (x  )  + (2700a b n x  + 1350a b n)(x  )
+--R           + 
+--R                   6 8    n 2        7 7   n        8 6   2n        7 7    n 3
+--R             (5400a b n (x )  + 5400a b n x  + 1350a b n)x   + 3600a b n (x )
+--R           + 
+--R                  8 6    n 2        9 5   n       10 4
+--R             5400a b n (x )  + 2700a b n x  + 450a  b n
+--R        *
+--R              n log(x) 2
+--R           (%e        )
+--R       + 
+--R                 5 9    2n 3         6 8   n       7 7    2n 2
+--R             180a b n (x  )  + (1080a b n x  + 540a b n)(x  )
+--R           + 
+--R                   7 7    n 2        8 6   n       9 5   2n        8 6    n 3
+--R             (2160a b n (x )  + 2160a b n x  + 540a b n)x   + 1440a b n (x )
+--R           + 
+--R                  9 5    n 2        10 4   n       11 3
+--R             2160a b n (x )  + 1080a  b n x  + 180a  b n
+--R        *
+--R             n log(x)
+--R           %e
+--R       + 
+--R            6 8    2n 3        7 7   n      8 6    2n 2
+--R         30a b n (x  )  + (180a b n x  + 90a b n)(x  )
+--R       + 
+--R              8 6    n 2       9 5   n      10 4   2n       9 5    n 3
+--R         (360a b n (x )  + 360a b n x  + 90a  b n)x   + 240a b n (x )
+--R       + 
+--R             10 4    n 2       11 3   n      12 2
+--R         360a  b n (x )  + 180a  b n x  + 30a  b n
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1904
+
+--S 1905 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                     +--------------------------------------+
+--R          n log(x) 2 | 2   n log(x) 2          n log(x)    2         n log(x) 3
+--R       (%e        ) \|b (%e        )  + 2a b %e         + a   - b (%e        )
+--R     + 
+--R              n log(x) 2
+--R       - a (%e        )
+--R  /
+--R          7     n log(x) 7       6     n log(x) 6      2 5     n log(x) 5
+--R         b x (%e        )  + 7a b x (%e        )  + 21a b x (%e        )
+--R       + 
+--R            3 4     n log(x) 4      4 3     n log(x) 3      5 2     n log(x) 2
+--R         35a b x (%e        )  + 35a b x (%e        )  + 21a b x (%e        )
+--R       + 
+--R           6      n log(x)    7
+--R         7a b x %e         + a x
+--R    *
+--R        +--------------------------------------+
+--R        | 2   n log(x) 2          n log(x)    2
+--R       \|b (%e        )  + 2a b %e         + a
+--R                                                    Type: Expression(Integer)
+--E 1905
+
+)clear all
+
+--S 1906 of 2282
+t0:=x^(-1+4*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              4n - 1
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1906
+
+--S 1907 of 2282
+r0:=-b*x^n/(c^2*n)+1/2*x^(2*n)/(c*n)+1/2*(b^2-a*c)*log(a+b*x^n+c*x^(2*n))/_
+   (c^3*n)+b*(b^2-3*a*c)*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/_
+   (c^3*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    +-----------+
+--R                 2  |          2        2n      n
+--R       (- a c + b )\|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R                                    n                            +-----------+
+--R                     3          2c x  + b        2 2n         n  |          2
+--R       (- 6a b c + 2b )atanh(--------------) + (c x   - 2b c x )\|- 4a c + b
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R  /
+--R          +-----------+
+--R       3  |          2
+--R     2c n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1907
+
+--S 1908 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      +-----------+
+--R                   2  |          2          n log(x) 2       n log(x)
+--R         (- a c + b )\|- 4a c + b  log(c (%e        )  + b %e         + a)
+--R       + 
+--R                      3
+--R           (3a b c - b )
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    n log(x) 2
+--R                  2c \|- 4a c + b  (%e        )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    n log(x)
+--R                  (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R             /
+--R                     n log(x) 2       n log(x)
+--R                c (%e        )  + b %e         + a
+--R       + 
+--R            +-----------+                     +-----------+
+--R          2 |          2    n log(x) 2        |          2   n log(x)
+--R         c \|- 4a c + b  (%e        )  - 2b c\|- 4a c + b  %e
+--R    /
+--R            +-----------+
+--R         3  |          2
+--R       2c n\|- 4a c + b
+--R     ,
+--R
+--R                      +---------+
+--R                   2  |        2          n log(x) 2       n log(x)
+--R         (- a c + b )\|4a c - b  log(c (%e        )  + b %e         + a)
+--R       + 
+--R                               +---------+               +---------+
+--R                               |        2   n log(x)     |        2
+--R                     3      2c\|4a c - b  %e         + b\|4a c - b
+--R         (6a b c - 2b )atan(----------------------------------------)
+--R                                                    2
+--R                                            4a c - b
+--R       + 
+--R            +---------+                     +---------+
+--R          2 |        2    n log(x) 2        |        2   n log(x)
+--R         c \|4a c - b  (%e        )  - 2b c\|4a c - b  %e
+--R    /
+--R            +---------+
+--R         3  |        2
+--R       2c n\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1908
+
+--S 1909 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    +-----------+
+--R                 2  |          2          n log(x) 2       n log(x)
+--R       (- a c + b )\|- 4a c + b  log(c (%e        )  + b %e         + a)
+--R     + 
+--R                    3
+--R         (3a b c - b )
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    n log(x) 2
+--R                2c \|- 4a c + b  (%e        )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    n log(x)
+--R                (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R           /
+--R                   n log(x) 2       n log(x)
+--R              c (%e        )  + b %e         + a
+--R     + 
+--R                  +-----------+
+--R               2  |          2        2n      n
+--R       (a c - b )\|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R          +-----------+                     +-----------+
+--R        2 |          2    n log(x) 2        |          2   n log(x)
+--R       c \|- 4a c + b  (%e        )  - 2b c\|- 4a c + b  %e
+--R     + 
+--R                                  n                              +-----------+
+--R                   3          2c x  + b          2 2n         n  |          2
+--R       (6a b c - 2b )atanh(--------------) + (- c x   + 2b c x )\|- 4a c + b
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R          +-----------+
+--R       3  |          2
+--R     2c n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1909
+
+--S 1910 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1910
+
+--S 1911 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      +-----------+ +---------+
+--R                   2  |          2  |        2
+--R         (- a c + b )\|- 4a c + b  \|4a c - b
+--R      *
+--R                  n log(x) 2       n log(x)
+--R         log(c (%e        )  + b %e         + a)
+--R     + 
+--R                        +-----------+
+--R                     3  |          2
+--R         (6a b c - 2b )\|- 4a c + b
+--R      *
+--R                 +---------+               +---------+
+--R                 |        2   n log(x)     |        2
+--R              2c\|4a c - b  %e         + b\|4a c - b
+--R         atan(----------------------------------------)
+--R                                      2
+--R                              4a c - b
+--R     + 
+--R                  +-----------+ +---------+
+--R               2  |          2  |        2        2n      n
+--R       (a c - b )\|- 4a c + b  \|4a c - b  log(c x   + b x  + a)
+--R     + 
+--R          +-----------+ +---------+
+--R        2 |          2  |        2    n log(x) 2
+--R       c \|- 4a c + b  \|4a c - b  (%e        )
+--R     + 
+--R              +-----------+ +---------+
+--R              |          2  |        2   n log(x)
+--R       - 2b c\|- 4a c + b  \|4a c - b  %e
+--R     + 
+--R                      +---------+             n
+--R                   3  |        2          2c x  + b
+--R       (6a b c - 2b )\|4a c - b  atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                           +-----------+ +---------+
+--R           2 2n         n  |          2  |        2
+--R       (- c x   + 2b c x )\|- 4a c + b  \|4a c - b
+--R  /
+--R          +-----------+ +---------+
+--R       3  |          2  |        2
+--R     2c n\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1911
+
+--S 1912 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1912
+
+)clear all
+
+--S 1913 of 2282
+t0:=x^(-1+3*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              3n - 1
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1913
+
+--S 1914 of 2282
+r0:=x^n/(c*n)-1/2*b*log(a+b*x^n+c*x^(2*n))/(c^2*n)-(b^2-2*a*c)*_
+   atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/(c^2*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R           +-----------+
+--R           |          2        2n      n
+--R       - b\|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R                                n                +-----------+
+--R                 2          2c x  + b          n |          2
+--R       (4a c - 2b )atanh(--------------) + 2c x \|- 4a c + b
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R  /
+--R          +-----------+
+--R       2  |          2
+--R     2c n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1914
+
+--S 1915 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R             +-----------+
+--R             |          2          n log(x) 2       n log(x)
+--R         - b\|- 4a c + b  log(c (%e        )  + b %e         + a)
+--R       + 
+--R                    2
+--R           (2a c - b )
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    n log(x) 2
+--R                  2c \|- 4a c + b  (%e        )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    n log(x)
+--R                  (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R             /
+--R                     n log(x) 2       n log(x)
+--R                c (%e        )  + b %e         + a
+--R       + 
+--R            +-----------+
+--R            |          2   n log(x)
+--R         2c\|- 4a c + b  %e
+--R    /
+--R            +-----------+
+--R         2  |          2
+--R       2c n\|- 4a c + b
+--R     ,
+--R
+--R             +---------+
+--R             |        2          n log(x) 2       n log(x)
+--R         - b\|4a c - b  log(c (%e        )  + b %e         + a)
+--R       + 
+--R                               +---------+               +---------+
+--R                               |        2   n log(x)     |        2
+--R                     2      2c\|4a c - b  %e         + b\|4a c - b
+--R         (- 4a c + 2b )atan(----------------------------------------)
+--R                                                    2
+--R                                            4a c - b
+--R       + 
+--R            +---------+
+--R            |        2   n log(x)
+--R         2c\|4a c - b  %e
+--R    /
+--R            +---------+
+--R         2  |        2
+--R       2c n\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1915
+
+--S 1916 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           +-----------+
+--R           |          2          n log(x) 2       n log(x)
+--R       - b\|- 4a c + b  log(c (%e        )  + b %e         + a)
+--R     + 
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    n log(x) 2
+--R                2c \|- 4a c + b  (%e        )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    n log(x)
+--R                (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R           /
+--R                   n log(x) 2       n log(x)
+--R              c (%e        )  + b %e         + a
+--R     + 
+--R         +-----------+                           +-----------+
+--R         |          2        2n      n           |          2   n log(x)
+--R       b\|- 4a c + b  log(c x   + b x  + a) + 2c\|- 4a c + b  %e
+--R     + 
+--R                                  n                +-----------+
+--R                   2          2c x  + b          n |          2
+--R       (- 4a c + 2b )atanh(--------------) - 2c x \|- 4a c + b
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R          +-----------+
+--R       2  |          2
+--R     2c n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1916
+
+--S 1917 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1917
+
+--S 1918 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +-----------+ +---------+
+--R           |          2  |        2          n log(x) 2       n log(x)
+--R       - b\|- 4a c + b  \|4a c - b  log(c (%e        )  + b %e         + a)
+--R     + 
+--R                        +-----------+
+--R                     2  |          2
+--R         (- 4a c + 2b )\|- 4a c + b
+--R      *
+--R                 +---------+               +---------+
+--R                 |        2   n log(x)     |        2
+--R              2c\|4a c - b  %e         + b\|4a c - b
+--R         atan(----------------------------------------)
+--R                                      2
+--R                              4a c - b
+--R     + 
+--R         +-----------+ +---------+
+--R         |          2  |        2        2n      n
+--R       b\|- 4a c + b  \|4a c - b  log(c x   + b x  + a)
+--R     + 
+--R          +-----------+ +---------+
+--R          |          2  |        2   n log(x)
+--R       2c\|- 4a c + b  \|4a c - b  %e
+--R     + 
+--R                      +---------+             n
+--R                   2  |        2          2c x  + b
+--R       (- 4a c + 2b )\|4a c - b  atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R               +-----------+ +---------+
+--R             n |          2  |        2
+--R       - 2c x \|- 4a c + b  \|4a c - b
+--R  /
+--R          +-----------+ +---------+
+--R       2  |          2  |        2
+--R     2c n\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1918
+
+--S 1919 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1919
+
+)clear all
+
+--S 1920 of 2282
+t0:=x^(-1+2*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              2n - 1
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1920
+
+--S 1921 of 2282
+r0:=1/2*log(a+b*x^n+c*x^(2*n))/(c*n)+b*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/_
+   (c*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R         +-----------+                                        n
+--R         |          2        2n      n                    2c x  + b
+--R        \|- 4a c + b  log(c x   + b x  + a) + 2b atanh(--------------)
+--R                                                        +-----------+
+--R                                                        |          2
+--R                                                       \|- 4a c + b
+--R   (2)  --------------------------------------------------------------
+--R                                   +-----------+
+--R                                   |          2
+--R                              2c n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1921
+
+--S 1922 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R          +-----------+
+--R          |          2          n log(x) 2       n log(x)
+--R         \|- 4a c + b  log(c (%e        )  + b %e         + a)
+--R       + 
+--R           b
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    n log(x) 2
+--R                  2c \|- 4a c + b  (%e        )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    n log(x)
+--R                  (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R             /
+--R                     n log(x) 2       n log(x)
+--R                c (%e        )  + b %e         + a
+--R    /
+--R            +-----------+
+--R            |          2
+--R       2c n\|- 4a c + b
+--R     ,
+--R
+--R          +---------+
+--R          |        2          n log(x) 2       n log(x)
+--R         \|4a c - b  log(c (%e        )  + b %e         + a)
+--R       + 
+--R                      +---------+               +---------+
+--R                      |        2   n log(x)     |        2
+--R                   2c\|4a c - b  %e         + b\|4a c - b
+--R         - 2b atan(----------------------------------------)
+--R                                           2
+--R                                   4a c - b
+--R    /
+--R            +---------+
+--R            |        2
+--R       2c n\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1922
+
+--S 1923 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R        +-----------+
+--R        |          2          n log(x) 2       n log(x)
+--R       \|- 4a c + b  log(c (%e        )  + b %e         + a)
+--R     + 
+--R         b
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    n log(x) 2
+--R                2c \|- 4a c + b  (%e        )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    n log(x)
+--R                (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R           /
+--R                   n log(x) 2       n log(x)
+--R              c (%e        )  + b %e         + a
+--R     + 
+--R          +-----------+                                        n
+--R          |          2        2n      n                    2c x  + b
+--R       - \|- 4a c + b  log(c x   + b x  + a) - 2b atanh(--------------)
+--R                                                         +-----------+
+--R                                                         |          2
+--R                                                        \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     2c n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1923
+
+--S 1924 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1924
+
+--S 1925 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        +-----------+ +---------+
+--R        |          2  |        2          n log(x) 2       n log(x)
+--R       \|- 4a c + b  \|4a c - b  log(c (%e        )  + b %e         + a)
+--R     + 
+--R                                 +---------+               +---------+
+--R            +-----------+        |        2   n log(x)     |        2
+--R            |          2      2c\|4a c - b  %e         + b\|4a c - b
+--R       - 2b\|- 4a c + b  atan(----------------------------------------)
+--R                                                      2
+--R                                              4a c - b
+--R     + 
+--R          +-----------+ +---------+
+--R          |          2  |        2        2n      n
+--R       - \|- 4a c + b  \|4a c - b  log(c x   + b x  + a)
+--R     + 
+--R            +---------+             n
+--R            |        2          2c x  + b
+--R       - 2b\|4a c - b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R  /
+--R          +-----------+ +---------+
+--R          |          2  |        2
+--R     2c n\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1925
+
+--S 1926 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1926
+
+)clear all
+
+--S 1927 of 2282
+t0:=x^(-1+n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              n - 1
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1927
+
+--S 1928 of 2282
+r0:=-2*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/(n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                        n
+--R                    2c x  + b
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  - ----------------------
+--R                +-----------+
+--R                |          2
+--R              n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1928
+
+--S 1929 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                  +-----------+
+--R                2 |          2    n log(x) 2
+--R              2c \|- 4a c + b  (%e        )
+--R            + 
+--R                    +-----------+
+--R                    |          2        2     2    n log(x)
+--R              (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R            + 
+--R                            +-----------+
+--R                         2  |          2              3
+--R              (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R         /
+--R                 n log(x) 2       n log(x)
+--R            c (%e        )  + b %e         + a
+--R    /
+--R         +-----------+
+--R         |          2
+--R       n\|- 4a c + b
+--R     ,
+--R             +---------+               +---------+
+--R             |        2   n log(x)     |        2
+--R          2c\|4a c - b  %e         + b\|4a c - b
+--R    2atan(----------------------------------------)
+--R                                  2
+--R                          4a c - b
+--R    -----------------------------------------------]
+--R                       +---------+
+--R                       |        2
+--R                     n\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1929
+
+--S 1930 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                  +-----------+
+--R                2 |          2    n log(x) 2
+--R              2c \|- 4a c + b  (%e        )
+--R            + 
+--R                    +-----------+
+--R                    |          2        2     2    n log(x)
+--R              (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R            + 
+--R                            +-----------+
+--R                         2  |          2              3
+--R              (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R         /
+--R                 n log(x) 2       n log(x)
+--R            c (%e        )  + b %e         + a
+--R     + 
+--R                     n
+--R                 2c x  + b
+--R       2atanh(--------------)
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R  /
+--R       +-----------+
+--R       |          2
+--R     n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1930
+
+--S 1931 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1931
+
+--S 1932 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                              +---------+               +---------+
+--R         +-----------+        |        2   n log(x)     |        2
+--R         |          2      2c\|4a c - b  %e         + b\|4a c - b
+--R       2\|- 4a c + b  atan(----------------------------------------)
+--R                                                   2
+--R                                           4a c - b
+--R     + 
+--R         +---------+             n
+--R         |        2          2c x  + b
+--R       2\|4a c - b  atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R       +-----------+ +---------+
+--R       |          2  |        2
+--R     n\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1932
+
+--S 1933 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1933
+
+)clear all
+
+--S 1934 of 2282
+t0:=x^(-1-n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - n - 1
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1934
+
+--S 1935 of 2282
+r0:=(-1)/(a*n*x^n)-b*log(x)/a^2+1/2*b*log(a+b*x^n+c*x^(2*n))/(a^2*n)-_
+   (b^2-2*a*c)*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/(a^2*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R            +-----------+
+--R          n |          2        2n      n
+--R       b x \|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R                                n                                 +-----------+
+--R               2  n         2c x  + b                     n       |          2
+--R     (4a c - 2b )x atanh(--------------) + (- 2b n log(x)x  - 2a)\|- 4a c + b
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R  /
+--R             +-----------+
+--R       2   n |          2
+--R     2a n x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1935
+
+--S 1936 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           +-----------+
+--R           |          2   n log(x)         n log(x) 2       n log(x)
+--R         b\|- 4a c + b  %e        log(c (%e        )  + b %e         + a)
+--R       + 
+--R                    2   n log(x)
+--R           (2a c - b )%e
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    n log(x) 2
+--R                  2c \|- 4a c + b  (%e        )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    n log(x)
+--R                  (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R             /
+--R                     n log(x) 2       n log(x)
+--R                c (%e        )  + b %e         + a
+--R       + 
+--R                       +-----------+                +-----------+
+--R                       |          2   n log(x)      |          2
+--R         - 2b n log(x)\|- 4a c + b  %e         - 2a\|- 4a c + b
+--R    /
+--R            +-----------+
+--R         2  |          2   n log(x)
+--R       2a n\|- 4a c + b  %e
+--R     ,
+--R
+--R           +---------+
+--R           |        2   n log(x)         n log(x) 2       n log(x)
+--R         b\|4a c - b  %e        log(c (%e        )  + b %e         + a)
+--R       + 
+--R                                         +---------+               +---------+
+--R                                         |        2   n log(x)     |        2
+--R                     2   n log(x)     2c\|4a c - b  %e         + b\|4a c - b
+--R         (- 4a c + 2b )%e        atan(----------------------------------------)
+--R                                                              2
+--R                                                      4a c - b
+--R       + 
+--R                       +---------+                +---------+
+--R                       |        2   n log(x)      |        2
+--R         - 2b n log(x)\|4a c - b  %e         - 2a\|4a c - b
+--R    /
+--R            +---------+
+--R         2  |        2   n log(x)
+--R       2a n\|4a c - b  %e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1936
+
+--S 1937 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            +-----------+
+--R          n |          2   n log(x)         n log(x) 2       n log(x)
+--R       b x \|- 4a c + b  %e        log(c (%e        )  + b %e         + a)
+--R     + 
+--R                  2  n  n log(x)
+--R         (2a c - b )x %e
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    n log(x) 2
+--R                2c \|- 4a c + b  (%e        )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    n log(x)
+--R                (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R           /
+--R                   n log(x) 2       n log(x)
+--R              c (%e        )  + b %e         + a
+--R     + 
+--R              +-----------+
+--R            n |          2   n log(x)       2n      n
+--R       - b x \|- 4a c + b  %e        log(c x   + b x  + a)
+--R     + 
+--R                                     n             +-----------+
+--R                    2  n         2c x  + b         |          2    n log(x)
+--R       ((- 4a c + 2b )x atanh(--------------) + 2a\|- 4a c + b  )%e
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R     + 
+--R               +-----------+
+--R             n |          2
+--R       - 2a x \|- 4a c + b
+--R  /
+--R             +-----------+
+--R       2   n |          2   n log(x)
+--R     2a n x \|- 4a c + b  %e
+--R                                                    Type: Expression(Integer)
+--E 1937
+
+--S 1938 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1938
+
+--S 1939 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              +-----------+ +---------+
+--R            n |          2  |        2   n log(x)
+--R         b x \|- 4a c + b  \|4a c - b  %e
+--R      *
+--R                  n log(x) 2       n log(x)
+--R         log(c (%e        )  + b %e         + a)
+--R     + 
+--R                          +-----------+
+--R                     2  n |          2   n log(x)
+--R         (- 4a c + 2b )x \|- 4a c + b  %e
+--R      *
+--R                 +---------+               +---------+
+--R                 |        2   n log(x)     |        2
+--R              2c\|4a c - b  %e         + b\|4a c - b
+--R         atan(----------------------------------------)
+--R                                      2
+--R                              4a c - b
+--R     + 
+--R              +-----------+ +---------+
+--R            n |          2  |        2   n log(x)       2n      n
+--R       - b x \|- 4a c + b  \|4a c - b  %e        log(c x   + b x  + a)
+--R     + 
+--R                            +---------+             n
+--R                       2  n |        2          2c x  + b
+--R           (- 4a c + 2b )x \|4a c - b  atanh(--------------)
+--R                                              +-----------+
+--R                                              |          2
+--R                                             \|- 4a c + b
+--R         + 
+--R              +-----------+ +---------+
+--R              |          2  |        2
+--R           2a\|- 4a c + b  \|4a c - b
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R               +-----------+ +---------+
+--R             n |          2  |        2
+--R       - 2a x \|- 4a c + b  \|4a c - b
+--R  /
+--R             +-----------+ +---------+
+--R       2   n |          2  |        2   n log(x)
+--R     2a n x \|- 4a c + b  \|4a c - b  %e
+--R                                                    Type: Expression(Integer)
+--E 1939
+
+--S 1940 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1940
+
+)clear all
+
+--S 1941 of 2282
+t0:=x^(-1-2*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - 2n - 1
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1941
+
+--S 1942 of 2282
+r0:=(-1/2)/(a*n*x^(2*n))+b/(a^2*n*x^n)+(b^2-a*c)*log(x)/a^3-1/2*(b^2-a*c)*_
+   log(a+b*x^n+c*x^(2*n))/(a^3*n)+b*(b^2-3*a*c)*atanh((b+2*c*x^n)/_
+   sqrt(b^2-4*a*c))/(a^3*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                       +-----------+
+--R               2  n 2n |          2        2n      n
+--R       (a c - b )x x  \|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R                                         n
+--R                     3  n 2n         2c x  + b
+--R       (- 6a b c + 2b )x x  atanh(--------------)
+--R                                   +-----------+
+--R                                   |          2
+--R                                  \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R                     2          n         2n    2 n  |          2
+--R       (((- 2a c + 2b )n log(x)x  + 2a b)x   - a x )\|- 4a c + b
+--R  /
+--R                +-----------+
+--R       3   n 2n |          2
+--R     2a n x x  \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1942
+
+--S 1943 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      +-----------+
+--R                   2  |          2    n log(x) 2
+--R           (a c - b )\|- 4a c + b  (%e        )
+--R        *
+--R                    n log(x) 2       n log(x)
+--R           log(c (%e        )  + b %e         + a)
+--R       + 
+--R                      3    n log(x) 2
+--R           (3a b c - b )(%e        )
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    n log(x) 2
+--R                  2c \|- 4a c + b  (%e        )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    n log(x)
+--R                  (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R             /
+--R                     n log(x) 2       n log(x)
+--R                c (%e        )  + b %e         + a
+--R       + 
+--R                                +-----------+
+--R                     2          |          2    n log(x) 2
+--R         (- 2a c + 2b )n log(x)\|- 4a c + b  (%e        )
+--R       + 
+--R              +-----------+                +-----------+
+--R              |          2   n log(x)    2 |          2
+--R         2a b\|- 4a c + b  %e         - a \|- 4a c + b
+--R    /
+--R            +-----------+
+--R         3  |          2    n log(x) 2
+--R       2a n\|- 4a c + b  (%e        )
+--R     ,
+--R
+--R                      +---------+
+--R                   2  |        2    n log(x) 2
+--R           (a c - b )\|4a c - b  (%e        )
+--R        *
+--R                    n log(x) 2       n log(x)
+--R           log(c (%e        )  + b %e         + a)
+--R       + 
+--R                       3    n log(x) 2
+--R           (6a b c - 2b )(%e        )
+--R        *
+--R                   +---------+               +---------+
+--R                   |        2   n log(x)     |        2
+--R                2c\|4a c - b  %e         + b\|4a c - b
+--R           atan(----------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R       + 
+--R                                +---------+
+--R                     2          |        2    n log(x) 2
+--R         (- 2a c + 2b )n log(x)\|4a c - b  (%e        )
+--R       + 
+--R              +---------+                +---------+
+--R              |        2   n log(x)    2 |        2
+--R         2a b\|4a c - b  %e         - a \|4a c - b
+--R    /
+--R            +---------+
+--R         3  |        2    n log(x) 2
+--R       2a n\|4a c - b  (%e        )
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1943
+
+--S 1944 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         +-----------+
+--R                 2  n 2n |          2    n log(x) 2
+--R         (a c - b )x x  \|- 4a c + b  (%e        )
+--R      *
+--R                  n log(x) 2       n log(x)
+--R         log(c (%e        )  + b %e         + a)
+--R     + 
+--R                    3  n 2n   n log(x) 2
+--R         (3a b c - b )x x  (%e        )
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    n log(x) 2
+--R                2c \|- 4a c + b  (%e        )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    n log(x)
+--R                (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R           /
+--R                   n log(x) 2       n log(x)
+--R              c (%e        )  + b %e         + a
+--R     + 
+--R                         +-----------+
+--R                 2  n 2n |          2    n log(x) 2       2n      n
+--R       (- a c + b )x x  \|- 4a c + b  (%e        ) log(c x   + b x  + a)
+--R     + 
+--R                                           n
+--R                       3  n 2n         2c x  + b
+--R           (6a b c - 2b )x x  atanh(--------------)
+--R                                     +-----------+
+--R                                     |          2
+--R                                    \|- 4a c + b
+--R         + 
+--R                               +-----------+
+--R                    2n    2 n  |          2
+--R           (- 2a b x   + a x )\|- 4a c + b
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R                  +-----------+                     +-----------+
+--R             n 2n |          2   n log(x)    2 n 2n |          2
+--R       2a b x x  \|- 4a c + b  %e         - a x x  \|- 4a c + b
+--R  /
+--R                +-----------+
+--R       3   n 2n |          2    n log(x) 2
+--R     2a n x x  \|- 4a c + b  (%e        )
+--R                                                    Type: Expression(Integer)
+--E 1944
+
+--S 1945 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1945
+
+--S 1946 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         +-----------+ +---------+
+--R                 2  n 2n |          2  |        2    n log(x) 2
+--R         (a c - b )x x  \|- 4a c + b  \|4a c - b  (%e        )
+--R      *
+--R                  n log(x) 2       n log(x)
+--R         log(c (%e        )  + b %e         + a)
+--R     + 
+--R                             +-----------+
+--R                     3  n 2n |          2    n log(x) 2
+--R         (6a b c - 2b )x x  \|- 4a c + b  (%e        )
+--R      *
+--R                 +---------+               +---------+
+--R                 |        2   n log(x)     |        2
+--R              2c\|4a c - b  %e         + b\|4a c - b
+--R         atan(----------------------------------------)
+--R                                      2
+--R                              4a c - b
+--R     + 
+--R                           +-----------+ +---------+
+--R                   2  n 2n |          2  |        2    n log(x) 2
+--R         (- a c + b )x x  \|- 4a c + b  \|4a c - b  (%e        )
+--R      *
+--R                2n      n
+--R         log(c x   + b x  + a)
+--R     + 
+--R                               +---------+             n
+--R                       3  n 2n |        2          2c x  + b
+--R           (6a b c - 2b )x x  \|4a c - b  atanh(--------------)
+--R                                                 +-----------+
+--R                                                 |          2
+--R                                                \|- 4a c + b
+--R         + 
+--R                               +-----------+ +---------+
+--R                    2n    2 n  |          2  |        2
+--R           (- 2a b x   + a x )\|- 4a c + b  \|4a c - b
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R                  +-----------+ +---------+
+--R             n 2n |          2  |        2   n log(x)
+--R       2a b x x  \|- 4a c + b  \|4a c - b  %e
+--R     + 
+--R                 +-----------+ +---------+
+--R          2 n 2n |          2  |        2
+--R       - a x x  \|- 4a c + b  \|4a c - b
+--R  /
+--R                +-----------+ +---------+
+--R       3   n 2n |          2  |        2    n log(x) 2
+--R     2a n x x  \|- 4a c + b  \|4a c - b  (%e        )
+--R                                                    Type: Expression(Integer)
+--E 1946
+
+--S 1947 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1947
+
+)clear all
+
+--S 1948 of 2282
+t0:=x^(-1-3*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - 3n - 1
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1948
+
+--S 1949 of 2282
+r0:=(-1/3)/(a*n*x^(3*n))+1/2*b/(a^2*n*x^(2*n))+(-b^2+a*c)/(a^3*n*x^n)-_
+   b*(b^2-2*a*c)*log(x)/a^4+1/2*b*(b^2-2*a*c)*log(a+b*x^n+c*x^(2*n))/_
+   (a^4*n)-(b^4-4*a*b^2*c+2*a^2*c^2)*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/_
+   (a^4*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                +-----------+
+--R                     3  n 2n 3n |          2        2n      n
+--R       (- 6a b c + 3b )x x  x  \|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R                                                      n
+--R             2 2        2      4  n 2n 3n         2c x  + b
+--R       (- 12a c  + 24a b c - 6b )x x  x  atanh(--------------)
+--R                                                +-----------+
+--R                                                |          2
+--R                                               \|- 4a c + b
+--R     + 
+--R                            3          n     2        2  2n     2   n  3n
+--R             (((12a b c - 6b )n log(x)x  + 6a c - 6a b )x   + 3a b x )x
+--R           + 
+--R                 3 n 2n
+--R             - 2a x x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                   +-----------+
+--R       4   n 2n 3n |          2
+--R     6a n x x  x  \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1949
+
+--S 1950 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            +-----------+
+--R                         3  |          2    n log(x) 3
+--R           (- 6a b c + 3b )\|- 4a c + b  (%e        )
+--R        *
+--R                    n log(x) 2       n log(x)
+--R           log(c (%e        )  + b %e         + a)
+--R       + 
+--R              2 2        2      4    n log(x) 3
+--R           (6a c  - 12a b c + 3b )(%e        )
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    n log(x) 2
+--R                  2c \|- 4a c + b  (%e        )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    n log(x)
+--R                  (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R             /
+--R                     n log(x) 2       n log(x)
+--R                c (%e        )  + b %e         + a
+--R       + 
+--R                                 +-----------+
+--R                      3          |          2    n log(x) 3
+--R         (12a b c - 6b )n log(x)\|- 4a c + b  (%e        )
+--R       + 
+--R                        +-----------+
+--R            2        2  |          2    n log(x) 2
+--R         (6a c - 6a b )\|- 4a c + b  (%e        )
+--R       + 
+--R              +-----------+                 +-----------+
+--R           2  |          2   n log(x)     3 |          2
+--R         3a b\|- 4a c + b  %e         - 2a \|- 4a c + b
+--R    /
+--R            +-----------+
+--R         4  |          2    n log(x) 3
+--R       6a n\|- 4a c + b  (%e        )
+--R     ,
+--R
+--R                            +---------+
+--R                         3  |        2    n log(x) 3
+--R           (- 6a b c + 3b )\|4a c - b  (%e        )
+--R        *
+--R                    n log(x) 2       n log(x)
+--R           log(c (%e        )  + b %e         + a)
+--R       + 
+--R               2 2        2      4    n log(x) 3
+--R           (12a c  - 24a b c + 6b )(%e        )
+--R        *
+--R                   +---------+               +---------+
+--R                   |        2   n log(x)     |        2
+--R                2c\|4a c - b  %e         + b\|4a c - b
+--R           atan(----------------------------------------)
+--R                                        2
+--R                                4a c - b
+--R       + 
+--R                                 +---------+
+--R                      3          |        2    n log(x) 3
+--R         (12a b c - 6b )n log(x)\|4a c - b  (%e        )
+--R       + 
+--R                        +---------+                     +---------+
+--R            2        2  |        2    n log(x) 2     2  |        2   n log(x)
+--R         (6a c - 6a b )\|4a c - b  (%e        )  + 3a b\|4a c - b  %e
+--R       + 
+--R               +---------+
+--R             3 |        2
+--R         - 2a \|4a c - b
+--R    /
+--R            +---------+
+--R         4  |        2    n log(x) 3
+--R       6a n\|4a c - b  (%e        )
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1950
+
+--S 1951 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                  +-----------+
+--R                       3  n 2n 3n |          2    n log(x) 3
+--R         (- 6a b c + 3b )x x  x  \|- 4a c + b  (%e        )
+--R      *
+--R                  n log(x) 2       n log(x)
+--R         log(c (%e        )  + b %e         + a)
+--R     + 
+--R            2 2        2      4  n 2n 3n   n log(x) 3
+--R         (6a c  - 12a b c + 3b )x x  x  (%e        )
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    n log(x) 2
+--R                2c \|- 4a c + b  (%e        )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    n log(x)
+--R                (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R           /
+--R                   n log(x) 2       n log(x)
+--R              c (%e        )  + b %e         + a
+--R     + 
+--R                              +-----------+
+--R                   3  n 2n 3n |          2    n log(x) 3       2n      n
+--R       (6a b c - 3b )x x  x  \|- 4a c + b  (%e        ) log(c x   + b x  + a)
+--R     + 
+--R                                                        n
+--R               2 2        2      4  n 2n 3n         2c x  + b
+--R           (12a c  - 24a b c + 6b )x x  x  atanh(--------------)
+--R                                                  +-----------+
+--R                                                  |          2
+--R                                                 \|- 4a c + b
+--R         + 
+--R                                                           +-----------+
+--R                  2        2  2n     2   n  3n     3 n 2n  |          2
+--R           (((- 6a c + 6a b )x   - 3a b x )x   + 2a x x  )\|- 4a c + b
+--R      *
+--R            n log(x) 3
+--R         (%e        )
+--R     + 
+--R                              +-----------+
+--R          2        2  n 2n 3n |          2    n log(x) 2
+--R       (6a c - 6a b )x x  x  \|- 4a c + b  (%e        )
+--R     + 
+--R                     +-----------+                         +-----------+
+--R         2   n 2n 3n |          2   n log(x)     3 n 2n 3n |          2
+--R       3a b x x  x  \|- 4a c + b  %e         - 2a x x  x  \|- 4a c + b
+--R  /
+--R                   +-----------+
+--R       4   n 2n 3n |          2    n log(x) 3
+--R     6a n x x  x  \|- 4a c + b  (%e        )
+--R                                                    Type: Expression(Integer)
+--E 1951
+
+--S 1952 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1952
+
+--S 1953 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +-----------+ +---------+
+--R                       3  n 2n 3n |          2  |        2    n log(x) 3
+--R         (- 6a b c + 3b )x x  x  \|- 4a c + b  \|4a c - b  (%e        )
+--R      *
+--R                  n log(x) 2       n log(x)
+--R         log(c (%e        )  + b %e         + a)
+--R     + 
+--R                                          +-----------+
+--R             2 2        2      4  n 2n 3n |          2    n log(x) 3
+--R         (12a c  - 24a b c + 6b )x x  x  \|- 4a c + b  (%e        )
+--R      *
+--R                 +---------+               +---------+
+--R                 |        2   n log(x)     |        2
+--R              2c\|4a c - b  %e         + b\|4a c - b
+--R         atan(----------------------------------------)
+--R                                      2
+--R                              4a c - b
+--R     + 
+--R                                +-----------+ +---------+
+--R                     3  n 2n 3n |          2  |        2    n log(x) 3
+--R         (6a b c - 3b )x x  x  \|- 4a c + b  \|4a c - b  (%e        )
+--R      *
+--R                2n      n
+--R         log(c x   + b x  + a)
+--R     + 
+--R                                            +---------+             n
+--R               2 2        2      4  n 2n 3n |        2          2c x  + b
+--R           (12a c  - 24a b c + 6b )x x  x  \|4a c - b  atanh(--------------)
+--R                                                              +-----------+
+--R                                                              |          2
+--R                                                             \|- 4a c + b
+--R         + 
+--R                                                             +-----------+
+--R                    2        2  2n     2   n  3n     3 n 2n  |          2
+--R             (((- 6a c + 6a b )x   - 3a b x )x   + 2a x x  )\|- 4a c + b
+--R          *
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R      *
+--R            n log(x) 3
+--R         (%e        )
+--R     + 
+--R                              +-----------+ +---------+
+--R          2        2  n 2n 3n |          2  |        2    n log(x) 2
+--R       (6a c - 6a b )x x  x  \|- 4a c + b  \|4a c - b  (%e        )
+--R     + 
+--R                     +-----------+ +---------+
+--R         2   n 2n 3n |          2  |        2   n log(x)
+--R       3a b x x  x  \|- 4a c + b  \|4a c - b  %e
+--R     + 
+--R                     +-----------+ +---------+
+--R           3 n 2n 3n |          2  |        2
+--R       - 2a x x  x  \|- 4a c + b  \|4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R       4   n 2n 3n |          2  |        2    n log(x) 3
+--R     6a n x x  x  \|- 4a c + b  \|4a c - b  (%e        )
+--R                                                    Type: Expression(Integer)
+--E 1953
+
+--S 1954 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1954
+
+)clear all
+
+--S 1955 of 2282
+t0:=x^(-1+1/4*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              n - 4
+--R              -----
+--R                4
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1955
+
+--S 1956 of 2282
+r0:=2*2^(3/4)*c^(3/4)*atan(2^(1/4)*c^(1/4)*x^(1/4*n)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))/(n*(-b-sqrt(b^2-4*a*c))^(3/4)*sqrt(b^2-4*a*c))+_
+   2*2^(3/4)*c^(3/4)*atanh(2^(1/4)*c^(1/4)*x^(1/4*n)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))/(n*(-b-sqrt(b^2-4*a*c))^(3/4)*sqrt(b^2-4*a*c))-_
+   2*2^(3/4)*c^(3/4)*atan(2^(1/4)*c^(1/4)*x^(1/4*n)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))/(n*sqrt(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))-_
+   2*2^(3/4)*c^(3/4)*atanh(2^(1/4)*c^(1/4)*x^(1/4*n)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))/(n*sqrt(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                                            n
+--R                     +------------------+3                  -
+--R                     | +-----------+                   4+-+ 4 4+-+
+--R        4+-+3 4+-+3 4| |          2                    \|2 x  \|c
+--R       2\|2   \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                                 +--------------------+
+--R                                                 |   +-----------+
+--R                                                4|   |          2
+--R                                                \|- \|- 4a c + b   - b
+--R     + 
+--R                                                               n
+--R                       +--------------------+3                 -
+--R                       |   +-----------+                  4+-+ 4 4+-+
+--R          4+-+3 4+-+3 4|   |          2                   \|2 x  \|c
+--R       - 2\|2   \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                                     +------------------+
+--R                                                     | +-----------+
+--R                                                    4| |          2
+--R                                                    \|\|- 4a c + b   - b
+--R     + 
+--R                                                           n
+--R                     +------------------+3                 -
+--R                     | +-----------+                  4+-+ 4 4+-+
+--R        4+-+3 4+-+3 4| |          2                   \|2 x  \|c
+--R       2\|2   \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                                +--------------------+
+--R                                                |   +-----------+
+--R                                               4|   |          2
+--R                                               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                              n
+--R                       +--------------------+3                -
+--R                       |   +-----------+                 4+-+ 4 4+-+
+--R          4+-+3 4+-+3 4|   |          2                  \|2 x  \|c
+--R       - 2\|2   \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                                    +------------------+
+--R                                                    | +-----------+
+--R                                                   4| |          2
+--R                                                   \|\|- 4a c + b   - b
+--R  /
+--R                     +--------------------+3  +------------------+3
+--R       +-----------+ |   +-----------+        | +-----------+
+--R       |          2 4|   |          2        4| |          2
+--R     n\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1956
+
+--S 1957 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           5 2      4 2      3 4  4
+--R                       (32a c  - 16a b c + 2a b )n
+--R                    *
+--R                        +--------------------------------------+
+--R                        |            2 2       2     4
+--R                        |         - a c  + 2a b c - b
+--R                        |--------------------------------------
+--R                        |    9 3      8 2 2      7 4     6 6  8
+--R                       \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                   + 
+--R                                3
+--R                     6a b c - 2b
+--R                /
+--R                       5 2     4 2     3 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         log
+--R                          5   2     4 3     3 5  5
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |            2 2       2     4
+--R                       |         - a c  + 2a b c - b
+--R                       |--------------------------------------
+--R                       |    9 3      8 2 2      7 4     6 6  8
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (4a c  - 5a b c + b )n
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                    5 2      4 2      3 4  4
+--R                                (32a c  - 16a b c + 2a b )n
+--R                             *
+--R                                 +--------------------------------------+
+--R                                 |            2 2       2     4
+--R                                 |         - a c  + 2a b c - b
+--R                                 |--------------------------------------
+--R                                 |    9 3      8 2 2      7 4     6 6  8
+--R                                \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                            + 
+--R                                         3
+--R                              6a b c - 2b
+--R                         /
+--R                                5 2     4 2     3 4  4
+--R                            (16a c  - 8a b c + a b )n
+--R              + 
+--R                                  (n - 4)log(x)
+--R                                  -------------
+--R                     2     2            4
+--R                (4a c  - 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                5 2      4 2      3 4  4
+--R                          (- 32a c  + 16a b c - 2a b )n
+--R                       *
+--R                           +--------------------------------------+
+--R                           |            2 2       2     4
+--R                           |         - a c  + 2a b c - b
+--R                           |--------------------------------------
+--R                           |    9 3      8 2 2      7 4     6 6  8
+--R                          \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                      + 
+--R                                   3
+--R                        6a b c - 2b
+--R                   /
+--R                          5 2     4 2     3 4  4
+--R                      (16a c  - 8a b c + a b )n
+--R         *
+--R            log
+--R                             5   2     4 3     3 5  5
+--R                         (16a b c  - 8a b c + a b )n
+--R                      *
+--R                          +--------------------------------------+
+--R                          |            2 2       2     4
+--R                          |         - a c  + 2a b c - b
+--R                          |--------------------------------------
+--R                          |    9 3      8 2 2      7 4     6 6  8
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                            2 2       2     4
+--R                       (- 4a c  + 5a b c - b )n
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         5 2      4 2      3 4  4
+--R                                   (- 32a c  + 16a b c - 2a b )n
+--R                                *
+--R                                    +--------------------------------------+
+--R                                    |            2 2       2     4
+--R                                    |         - a c  + 2a b c - b
+--R                                    |--------------------------------------
+--R                                    |    9 3      8 2 2      7 4     6 6  8
+--R                                   \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                               + 
+--R                                            3
+--R                                 6a b c - 2b
+--R                            /
+--R                                   5 2     4 2     3 4  4
+--R                               (16a c  - 8a b c + a b )n
+--R                 + 
+--R                                     (n - 4)log(x)
+--R                                     -------------
+--R                        2     2            4
+--R                   (4a c  - 4b c)x %e
+--R              /
+--R                 x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 2      4 2      3 4  4
+--R                       (- 32a c  + 16a b c - 2a b )n
+--R                    *
+--R                        +--------------------------------------+
+--R                        |            2 2       2     4
+--R                        |         - a c  + 2a b c - b
+--R                        |--------------------------------------
+--R                        |    9 3      8 2 2      7 4     6 6  8
+--R                       \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                   + 
+--R                                3
+--R                     6a b c - 2b
+--R                /
+--R                       5 2     4 2     3 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         log
+--R                            5   2     4 3     3 5  5
+--R                      (- 16a b c  + 8a b c - a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |            2 2       2     4
+--R                       |         - a c  + 2a b c - b
+--R                       |--------------------------------------
+--R                       |    9 3      8 2 2      7 4     6 6  8
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (4a c  - 5a b c + b )n
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      5 2      4 2      3 4  4
+--R                                (- 32a c  + 16a b c - 2a b )n
+--R                             *
+--R                                 +--------------------------------------+
+--R                                 |            2 2       2     4
+--R                                 |         - a c  + 2a b c - b
+--R                                 |--------------------------------------
+--R                                 |    9 3      8 2 2      7 4     6 6  8
+--R                                \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                            + 
+--R                                         3
+--R                              6a b c - 2b
+--R                         /
+--R                                5 2     4 2     3 4  4
+--R                            (16a c  - 8a b c + a b )n
+--R              + 
+--R                                  (n - 4)log(x)
+--R                                  -------------
+--R                     2     2            4
+--R                (4a c  - 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                              5 2      4 2      3 4  4
+--R                          (32a c  - 16a b c + 2a b )n
+--R                       *
+--R                           +--------------------------------------+
+--R                           |            2 2       2     4
+--R                           |         - a c  + 2a b c - b
+--R                           |--------------------------------------
+--R                           |    9 3      8 2 2      7 4     6 6  8
+--R                          \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                      + 
+--R                                   3
+--R                        6a b c - 2b
+--R                   /
+--R                          5 2     4 2     3 4  4
+--R                      (16a c  - 8a b c + a b )n
+--R         *
+--R            log
+--R                               5   2     4 3     3 5  5
+--R                         (- 16a b c  + 8a b c - a b )n
+--R                      *
+--R                          +--------------------------------------+
+--R                          |            2 2       2     4
+--R                          |         - a c  + 2a b c - b
+--R                          |--------------------------------------
+--R                          |    9 3      8 2 2      7 4     6 6  8
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                            2 2       2     4
+--R                       (- 4a c  + 5a b c - b )n
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                       5 2      4 2      3 4  4
+--R                                   (32a c  - 16a b c + 2a b )n
+--R                                *
+--R                                    +--------------------------------------+
+--R                                    |            2 2       2     4
+--R                                    |         - a c  + 2a b c - b
+--R                                    |--------------------------------------
+--R                                    |    9 3      8 2 2      7 4     6 6  8
+--R                                   \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                               + 
+--R                                            3
+--R                                 6a b c - 2b
+--R                            /
+--R                                   5 2     4 2     3 4  4
+--R                               (16a c  - 8a b c + a b )n
+--R                 + 
+--R                                     (n - 4)log(x)
+--R                                     -------------
+--R                        2     2            4
+--R                   (4a c  - 4b c)x %e
+--R              /
+--R                 x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                              5 2      4 2      3 4  4
+--R                          (32a c  - 16a b c + 2a b )n
+--R                       *
+--R                           +--------------------------------------+
+--R                           |            2 2       2     4
+--R                           |         - a c  + 2a b c - b
+--R                           |--------------------------------------
+--R                           |    9 3      8 2 2      7 4     6 6  8
+--R                          \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                      + 
+--R                                   3
+--R                        6a b c - 2b
+--R                   /
+--R                          5 2     4 2     3 4  4
+--R                      (16a c  - 8a b c + a b )n
+--R         *
+--R            atan
+--R                           5   2     4 3     3 5  5
+--R                       (16a b c  - 8a b c + a b )n
+--R                    *
+--R                        +--------------------------------------+
+--R                        |            2 2       2     4
+--R                        |         - a c  + 2a b c - b
+--R                        |--------------------------------------
+--R                        |    9 3      8 2 2      7 4     6 6  8
+--R                       \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                   + 
+--R                        2 2       2     4
+--R                     (4a c  - 5a b c + b )n
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                     5 2      4 2      3 4  4
+--R                                 (32a c  - 16a b c + 2a b )n
+--R                              *
+--R                                  +--------------------------------------+
+--R                                  |            2 2       2     4
+--R                                  |         - a c  + 2a b c - b
+--R                                  |--------------------------------------
+--R                                  |    9 3      8 2 2      7 4     6 6  8
+--R                                 \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                             + 
+--R                                          3
+--R                               6a b c - 2b
+--R                          /
+--R                                 5 2     4 2     3 4  4
+--R                             (16a c  - 8a b c + a b )n
+--R              /
+--R                                   (n - 4)log(x)
+--R                                   -------------
+--R                      2     2            4
+--R                 (4a c  - 4b c)x %e
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 2      4 2      3 4  4
+--R                       (- 32a c  + 16a b c - 2a b )n
+--R                    *
+--R                        +--------------------------------------+
+--R                        |            2 2       2     4
+--R                        |         - a c  + 2a b c - b
+--R                        |--------------------------------------
+--R                        |    9 3      8 2 2      7 4     6 6  8
+--R                       \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                   + 
+--R                                3
+--R                     6a b c - 2b
+--R                /
+--R                       5 2     4 2     3 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         atan
+--R                        5   2     4 3     3 5  5
+--R                    (16a b c  - 8a b c + a b )n
+--R                 *
+--R                     +--------------------------------------+
+--R                     |            2 2       2     4
+--R                     |         - a c  + 2a b c - b
+--R                     |--------------------------------------
+--R                     |    9 3      8 2 2      7 4     6 6  8
+--R                    \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                + 
+--R                       2 2       2     4
+--R                  (- 4a c  + 5a b c - b )n
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 2      4 2      3 4  4
+--R                              (- 32a c  + 16a b c - 2a b )n
+--R                           *
+--R                               +--------------------------------------+
+--R                               |            2 2       2     4
+--R                               |         - a c  + 2a b c - b
+--R                               |--------------------------------------
+--R                               |    9 3      8 2 2      7 4     6 6  8
+--R                              \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                          + 
+--R                                       3
+--R                            6a b c - 2b
+--R                       /
+--R                              5 2     4 2     3 4  4
+--R                          (16a c  - 8a b c + a b )n
+--R           /
+--R                                (n - 4)log(x)
+--R                                -------------
+--R                   2     2            4
+--R              (4a c  - 4b c)x %e
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1957
+
+--S 1958 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +--------------------+3  +------------------+3
+--R           +-----------+ |   +-----------+        | +-----------+
+--R           |          2 4|   |          2        4| |          2
+--R         n\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           5 2      4 2      3 4  4
+--R                       (32a c  - 16a b c + 2a b )n
+--R                    *
+--R                        +--------------------------------------+
+--R                        |            2 2       2     4
+--R                        |         - a c  + 2a b c - b
+--R                        |--------------------------------------
+--R                        |    9 3      8 2 2      7 4     6 6  8
+--R                       \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                   + 
+--R                                3
+--R                     6a b c - 2b
+--R                /
+--R                       5 2     4 2     3 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         log
+--R                          5   2     4 3     3 5  5
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |            2 2       2     4
+--R                       |         - a c  + 2a b c - b
+--R                       |--------------------------------------
+--R                       |    9 3      8 2 2      7 4     6 6  8
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (4a c  - 5a b c + b )n
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                    5 2      4 2      3 4  4
+--R                                (32a c  - 16a b c + 2a b )n
+--R                             *
+--R                                 +--------------------------------------+
+--R                                 |            2 2       2     4
+--R                                 |         - a c  + 2a b c - b
+--R                                 |--------------------------------------
+--R                                 |    9 3      8 2 2      7 4     6 6  8
+--R                                \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                            + 
+--R                                         3
+--R                              6a b c - 2b
+--R                         /
+--R                                5 2     4 2     3 4  4
+--R                            (16a c  - 8a b c + a b )n
+--R              + 
+--R                                  (n - 4)log(x)
+--R                                  -------------
+--R                     2     2            4
+--R                (4a c  - 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                            +--------------------+3  +------------------+3
+--R              +-----------+ |   +-----------+        | +-----------+
+--R              |          2 4|   |          2        4| |          2
+--R            n\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                5 2      4 2      3 4  4
+--R                          (- 32a c  + 16a b c - 2a b )n
+--R                       *
+--R                           +--------------------------------------+
+--R                           |            2 2       2     4
+--R                           |         - a c  + 2a b c - b
+--R                           |--------------------------------------
+--R                           |    9 3      8 2 2      7 4     6 6  8
+--R                          \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                      + 
+--R                                   3
+--R                        6a b c - 2b
+--R                   /
+--R                          5 2     4 2     3 4  4
+--R                      (16a c  - 8a b c + a b )n
+--R         *
+--R            log
+--R                             5   2     4 3     3 5  5
+--R                         (16a b c  - 8a b c + a b )n
+--R                      *
+--R                          +--------------------------------------+
+--R                          |            2 2       2     4
+--R                          |         - a c  + 2a b c - b
+--R                          |--------------------------------------
+--R                          |    9 3      8 2 2      7 4     6 6  8
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                            2 2       2     4
+--R                       (- 4a c  + 5a b c - b )n
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         5 2      4 2      3 4  4
+--R                                   (- 32a c  + 16a b c - 2a b )n
+--R                                *
+--R                                    +--------------------------------------+
+--R                                    |            2 2       2     4
+--R                                    |         - a c  + 2a b c - b
+--R                                    |--------------------------------------
+--R                                    |    9 3      8 2 2      7 4     6 6  8
+--R                                   \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                               + 
+--R                                            3
+--R                                 6a b c - 2b
+--R                            /
+--R                                   5 2     4 2     3 4  4
+--R                               (16a c  - 8a b c + a b )n
+--R                 + 
+--R                                     (n - 4)log(x)
+--R                                     -------------
+--R                        2     2            4
+--R                   (4a c  - 4b c)x %e
+--R              /
+--R                 x
+--R     + 
+--R                         +--------------------+3  +------------------+3
+--R           +-----------+ |   +-----------+        | +-----------+
+--R           |          2 4|   |          2        4| |          2
+--R         n\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 2      4 2      3 4  4
+--R                       (- 32a c  + 16a b c - 2a b )n
+--R                    *
+--R                        +--------------------------------------+
+--R                        |            2 2       2     4
+--R                        |         - a c  + 2a b c - b
+--R                        |--------------------------------------
+--R                        |    9 3      8 2 2      7 4     6 6  8
+--R                       \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                   + 
+--R                                3
+--R                     6a b c - 2b
+--R                /
+--R                       5 2     4 2     3 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         log
+--R                            5   2     4 3     3 5  5
+--R                      (- 16a b c  + 8a b c - a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |            2 2       2     4
+--R                       |         - a c  + 2a b c - b
+--R                       |--------------------------------------
+--R                       |    9 3      8 2 2      7 4     6 6  8
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (4a c  - 5a b c + b )n
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      5 2      4 2      3 4  4
+--R                                (- 32a c  + 16a b c - 2a b )n
+--R                             *
+--R                                 +--------------------------------------+
+--R                                 |            2 2       2     4
+--R                                 |         - a c  + 2a b c - b
+--R                                 |--------------------------------------
+--R                                 |    9 3      8 2 2      7 4     6 6  8
+--R                                \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                            + 
+--R                                         3
+--R                              6a b c - 2b
+--R                         /
+--R                                5 2     4 2     3 4  4
+--R                            (16a c  - 8a b c + a b )n
+--R              + 
+--R                                  (n - 4)log(x)
+--R                                  -------------
+--R                     2     2            4
+--R                (4a c  - 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                            +--------------------+3  +------------------+3
+--R              +-----------+ |   +-----------+        | +-----------+
+--R              |          2 4|   |          2        4| |          2
+--R            n\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                              5 2      4 2      3 4  4
+--R                          (32a c  - 16a b c + 2a b )n
+--R                       *
+--R                           +--------------------------------------+
+--R                           |            2 2       2     4
+--R                           |         - a c  + 2a b c - b
+--R                           |--------------------------------------
+--R                           |    9 3      8 2 2      7 4     6 6  8
+--R                          \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                      + 
+--R                                   3
+--R                        6a b c - 2b
+--R                   /
+--R                          5 2     4 2     3 4  4
+--R                      (16a c  - 8a b c + a b )n
+--R         *
+--R            log
+--R                               5   2     4 3     3 5  5
+--R                         (- 16a b c  + 8a b c - a b )n
+--R                      *
+--R                          +--------------------------------------+
+--R                          |            2 2       2     4
+--R                          |         - a c  + 2a b c - b
+--R                          |--------------------------------------
+--R                          |    9 3      8 2 2      7 4     6 6  8
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                            2 2       2     4
+--R                       (- 4a c  + 5a b c - b )n
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                       5 2      4 2      3 4  4
+--R                                   (32a c  - 16a b c + 2a b )n
+--R                                *
+--R                                    +--------------------------------------+
+--R                                    |            2 2       2     4
+--R                                    |         - a c  + 2a b c - b
+--R                                    |--------------------------------------
+--R                                    |    9 3      8 2 2      7 4     6 6  8
+--R                                   \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                               + 
+--R                                            3
+--R                                 6a b c - 2b
+--R                            /
+--R                                   5 2     4 2     3 4  4
+--R                               (16a c  - 8a b c + a b )n
+--R                 + 
+--R                                     (n - 4)log(x)
+--R                                     -------------
+--R                        2     2            4
+--R                   (4a c  - 4b c)x %e
+--R              /
+--R                 x
+--R     + 
+--R       -
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R               |          2 4|   |          2        4| |          2
+--R            2n\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                              5 2      4 2      3 4  4
+--R                          (32a c  - 16a b c + 2a b )n
+--R                       *
+--R                           +--------------------------------------+
+--R                           |            2 2       2     4
+--R                           |         - a c  + 2a b c - b
+--R                           |--------------------------------------
+--R                           |    9 3      8 2 2      7 4     6 6  8
+--R                          \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                      + 
+--R                                   3
+--R                        6a b c - 2b
+--R                   /
+--R                          5 2     4 2     3 4  4
+--R                      (16a c  - 8a b c + a b )n
+--R         *
+--R            atan
+--R                           5   2     4 3     3 5  5
+--R                       (16a b c  - 8a b c + a b )n
+--R                    *
+--R                        +--------------------------------------+
+--R                        |            2 2       2     4
+--R                        |         - a c  + 2a b c - b
+--R                        |--------------------------------------
+--R                        |    9 3      8 2 2      7 4     6 6  8
+--R                       \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                   + 
+--R                        2 2       2     4
+--R                     (4a c  - 5a b c + b )n
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                     5 2      4 2      3 4  4
+--R                                 (32a c  - 16a b c + 2a b )n
+--R                              *
+--R                                  +--------------------------------------+
+--R                                  |            2 2       2     4
+--R                                  |         - a c  + 2a b c - b
+--R                                  |--------------------------------------
+--R                                  |    9 3      8 2 2      7 4     6 6  8
+--R                                 \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                             + 
+--R                                          3
+--R                               6a b c - 2b
+--R                          /
+--R                                 5 2     4 2     3 4  4
+--R                             (16a c  - 8a b c + a b )n
+--R              /
+--R                                   (n - 4)log(x)
+--R                                   -------------
+--R                      2     2            4
+--R                 (4a c  - 4b c)x %e
+--R     + 
+--R                          +--------------------+3  +------------------+3
+--R            +-----------+ |   +-----------+        | +-----------+
+--R            |          2 4|   |          2        4| |          2
+--R         2n\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 2      4 2      3 4  4
+--R                       (- 32a c  + 16a b c - 2a b )n
+--R                    *
+--R                        +--------------------------------------+
+--R                        |            2 2       2     4
+--R                        |         - a c  + 2a b c - b
+--R                        |--------------------------------------
+--R                        |    9 3      8 2 2      7 4     6 6  8
+--R                       \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                   + 
+--R                                3
+--R                     6a b c - 2b
+--R                /
+--R                       5 2     4 2     3 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         atan
+--R                        5   2     4 3     3 5  5
+--R                    (16a b c  - 8a b c + a b )n
+--R                 *
+--R                     +--------------------------------------+
+--R                     |            2 2       2     4
+--R                     |         - a c  + 2a b c - b
+--R                     |--------------------------------------
+--R                     |    9 3      8 2 2      7 4     6 6  8
+--R                    \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                + 
+--R                       2 2       2     4
+--R                  (- 4a c  + 5a b c - b )n
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 2      4 2      3 4  4
+--R                              (- 32a c  + 16a b c - 2a b )n
+--R                           *
+--R                               +--------------------------------------+
+--R                               |            2 2       2     4
+--R                               |         - a c  + 2a b c - b
+--R                               |--------------------------------------
+--R                               |    9 3      8 2 2      7 4     6 6  8
+--R                              \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                          + 
+--R                                       3
+--R                            6a b c - 2b
+--R                       /
+--R                              5 2     4 2     3 4  4
+--R                          (16a c  - 8a b c + a b )n
+--R           /
+--R                                (n - 4)log(x)
+--R                                -------------
+--R                   2     2            4
+--R              (4a c  - 4b c)x %e
+--R     + 
+--R                                                              n
+--R                       +------------------+3                  -
+--R                       | +-----------+                   4+-+ 4 4+-+
+--R          4+-+3 4+-+3 4| |          2                    \|2 x  \|c
+--R       - 4\|2   \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                                   +--------------------+
+--R                                                   |   +-----------+
+--R                                                  4|   |          2
+--R                                                  \|- \|- 4a c + b   - b
+--R     + 
+--R                                                             n
+--R                     +--------------------+3                 -
+--R                     |   +-----------+                  4+-+ 4 4+-+
+--R        4+-+3 4+-+3 4|   |          2                   \|2 x  \|c
+--R       4\|2   \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                                   +------------------+
+--R                                                   | +-----------+
+--R                                                  4| |          2
+--R                                                  \|\|- 4a c + b   - b
+--R     + 
+--R                                                             n
+--R                       +------------------+3                 -
+--R                       | +-----------+                  4+-+ 4 4+-+
+--R          4+-+3 4+-+3 4| |          2                   \|2 x  \|c
+--R       - 4\|2   \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                                  +--------------------+
+--R                                                  |   +-----------+
+--R                                                 4|   |          2
+--R                                                 \|- \|- 4a c + b   - b
+--R     + 
+--R                                                            n
+--R                     +--------------------+3                -
+--R                     |   +-----------+                 4+-+ 4 4+-+
+--R        4+-+3 4+-+3 4|   |          2                  \|2 x  \|c
+--R       4\|2   \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                                  +------------------+
+--R                                                  | +-----------+
+--R                                                 4| |          2
+--R                                                 \|\|- 4a c + b   - b
+--R  /
+--R                      +--------------------+3  +------------------+3
+--R        +-----------+ |   +-----------+        | +-----------+
+--R        |          2 4|   |          2        4| |          2
+--R     2n\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1958
+
+--S 1959 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1959
+
+)clear all
+
+--S 1960 of 2282
+t0:=x^(-1+1/3*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              n - 3
+--R              -----
+--R                3
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1960
+
+--S 1961 of 2282
+r0:=2^(2/3)*c^(2/3)*log(2^(1/3)*c^(1/3)*x^(1/3*n)+(b-sqrt(b^2-_
+   4*a*c))^(1/3))/(n*(b-sqrt(b^2-4*a*c))^(2/3)*sqrt(b^2-4*a*c))-_
+   c^(2/3)*log(2^(2/3)*c^(2/3)*x^(2/3*n)-2^(1/3)*c^(1/3)*x^(1/3*n)*_
+   (b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))/(2^(1/3)*_
+   n*(b-sqrt(b^2-4*a*c))^(2/3)*sqrt(b^2-4*a*c))-2^(2/3)*c^(2/3)*_
+   atan((-4*c^(1/3)*x^(1/3*n)+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*sqrt(3)/(n*_
+   (b-sqrt(b^2-4*a*c))^(2/3)*sqrt(b^2-4*a*c))-2^(2/3)*c^(2/3)*_
+   log(2^(1/3)*c^(1/3)*x^(1/3*n)+(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (n*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(2/3))+c^(2/3)*log(2^(2/3)*_
+   c^(2/3)*x^(2/3*n)-2^(1/3)*c^(1/3)*x^(1/3*n)*(b+sqrt(b^2-_
+   4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))/(2^(1/3)*n*sqrt(b^2-4*a*c)*_
+   (b+sqrt(b^2-4*a*c))^(2/3))+2^(2/3)*c^(2/3)*atan((-4*c^(1/3)*_
+   x^(1/3*n)+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*_
+   (b+sqrt(b^2-4*a*c))^(1/3)))*sqrt(3)/(n*sqrt(b^2-4*a*c)*_
+   (b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                +--------------------+2
+--R                |   +-----------+
+--R         3+-+2 3|   |          2
+--R         \|c   \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2        n      +------------------+
+--R               | +-----------+              -      | +-----------+
+--R              3| |          2          3+-+ 3 3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - \|2 x  \|c \|\|- 4a c + b   + b
+--R            + 
+--R                    2n
+--R                    --
+--R              3+-+2  3 3+-+2
+--R              \|2  x   \|c
+--R     + 
+--R                 +--------------------+2     +------------------+        n
+--R                 |   +-----------+           | +-----------+             -
+--R          3+-+2 3|   |          2           3| |          2         3+-+ 3 3+-+
+--R       - 2\|c   \|- \|- 4a c + b   + b  log(\|\|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R       -
+--R                   +------------------+2
+--R                   | +-----------+
+--R            3+-+2 3| |          2
+--R            \|c   \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +--------------------+2        n      +--------------------+
+--R                  |   +-----------+              -      |   +-----------+
+--R                 3|   |          2          3+-+ 3 3+-+3|   |          2
+--R                 \|- \|- 4a c + b   + b   - \|2 x  \|c \|- \|- 4a c + b   + b
+--R               + 
+--R                       2n
+--R                       --
+--R                 3+-+2  3 3+-+2
+--R                 \|2  x   \|c
+--R     + 
+--R               +------------------+2     +--------------------+        n
+--R               | +-----------+           |   +-----------+             -
+--R        3+-+2 3| |          2           3|   |          2         3+-+ 3 3+-+
+--R       2\|c   \|\|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R                     +--------------------+2
+--R                     |   +-----------+
+--R           +-+3+-+2 3|   |          2
+--R         2\|3 \|c   \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+    n
+--R                     | +-----------+         -
+--R              3+-+2 3| |          2          3 3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x  \|c
+--R         atan(------------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                        +------------------+2
+--R                        | +-----------+
+--R              +-+3+-+2 3| |          2
+--R            2\|3 \|c   \|\|- 4a c + b   + b
+--R         *
+--R                        +--------------------+    n
+--R                        |   +-----------+         -
+--R                 3+-+2 3|   |          2          3 3+-+
+--R                 \|2   \|- \|- 4a c + b   + b - 4x  \|c
+--R            atan(--------------------------------------)
+--R                              +--------------------+
+--R                              |   +-----------+
+--R                    3+-+2 +-+3|   |          2
+--R                    \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                         +--------------------+2  +------------------+2
+--R           +-----------+ |   +-----------+        | +-----------+
+--R      3+-+ |          2 3|   |          2        3| |          2
+--R     n\|2 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1961
+
+--S 1962 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +--------------------------------------------------------------+
+--R             |                  +--------------------------------------+
+--R             |                  |             2 2       2     4
+--R             |     3     2 2  3 |         - 4a c  + 4a b c - b
+--R             |(- 4a c + a b )n  |--------------------------------------  - b
+--R             |                  |    7 3      6 2 2      5 4     4 6  6
+--R             |                 \|(64a c  - 48a b c  + 12a b c - a b )n
+--R             |--------------------------------------------------------------
+--R            3|                          3      2 2  3
+--R            \|                       (8a c - 2a b )n
+--R         *
+--R            log
+--R                             5   3      4 3 2      3 5     2 7  5
+--R                         (64a b c  - 48a b c  + 12a b c - a b )n
+--R                      *
+--R                          +--------------------------------------+
+--R                          |             2 2       2     4
+--R                          |         - 4a c  + 4a b c - b
+--R                          |--------------------------------------
+--R                          |    7 3      6 2 2      5 4     4 6  6
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                           3 3      2 2 2       4     6  2
+--R                       (16a c  - 20a b c  + 8a b c - b )n
+--R                  *
+--R                       ROOT
+--R                                     3     2 2  3
+--R                                (- 4a c + a b )n
+--R                             *
+--R                                 +--------------------------------------+
+--R                                 |             2 2       2     4
+--R                                 |         - 4a c  + 4a b c - b
+--R                                 |--------------------------------------
+--R                                 |    7 3      6 2 2      5 4     4 6  6
+--R                                \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                            + 
+--R                              - b
+--R                         /
+--R                               3      2 2  3
+--R                            (8a c - 2a b )n
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                               4   3     3 3 2    2 5   4
+--R                         (- 16a b c  + 8a b c  - a b c)n x
+--R                      *
+--R                          +--------------------------------------+
+--R                          |             2 2       2     4
+--R                          |         - 4a c  + 4a b c - b
+--R                          |--------------------------------------
+--R                          |    7 3      6 2 2      5 4     4 6  6
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                            2 3       2 2    4
+--R                       (- 8a c  + 6a b c  - b c)n x
+--R                  *
+--R                       (n - 3)log(x)
+--R                       -------------
+--R                             3
+--R                     %e
+--R                  *
+--R                     ROOT
+--R                                   3     2 2  3
+--R                              (- 4a c + a b )n
+--R                           *
+--R                               +--------------------------------------+
+--R                               |             2 2       2     4
+--R                               |         - 4a c  + 4a b c - b
+--R                               |--------------------------------------
+--R                               |    7 3      6 2 2      5 4     4 6  6
+--R                              \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                          + 
+--R                            - b
+--R                       /
+--R                             3      2 2  3
+--R                          (8a c - 2a b )n
+--R                    ,
+--R                        3
+--R                 + 
+--R                                       (n - 3)log(x) 2
+--R                                       -------------
+--R                        3     2 2  2         3
+--R                   (4a c  - 2b c )x (%e             )
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R            +--------------------------------------------------------------+
+--R            |                  +--------------------------------------+
+--R            |                  |             2 2       2     4
+--R            |     3     2 2  3 |         - 4a c  + 4a b c - b
+--R            |(- 4a c + a b )n  |--------------------------------------  - b
+--R            |                  |    7 3      6 2 2      5 4     4 6  6
+--R            |                 \|(64a c  - 48a b c  + 12a b c - a b )n
+--R         2  |--------------------------------------------------------------
+--R           3|                          3      2 2  3
+--R           \|                       (8a c - 2a b )n
+--R      *
+--R         log
+--R                          4   2     3 3     2 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |             2 2       2     4
+--R                       |         - 4a c  + 4a b c - b
+--R                       |--------------------------------------
+--R                       |    7 3      6 2 2      5 4     4 6  6
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (8a c  - 6a b c + b )n
+--R               *
+--R                  ROOT
+--R                                3     2 2  3
+--R                           (- 4a c + a b )n
+--R                        *
+--R                            +--------------------------------------+
+--R                            |             2 2       2     4
+--R                            |         - 4a c  + 4a b c - b
+--R                            |--------------------------------------
+--R                            |    7 3      6 2 2      5 4     4 6  6
+--R                           \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                       + 
+--R                         - b
+--R                    /
+--R                          3      2 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                  (n - 3)log(x)
+--R                                  -------------
+--R                     2     2            3
+--R                (4a c  - 2b c)x %e
+--R           /
+--R              x
+--R     + 
+--R            +------------------------------------------------------------+
+--R            |                +--------------------------------------+
+--R            |                |             2 2       2     4
+--R            |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R            |(4a c - a b )n  |--------------------------------------  - b
+--R            |                |    7 3      6 2 2      5 4     4 6  6
+--R            |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R         2  |------------------------------------------------------------
+--R           3|                         3      2 2  3
+--R           \|                      (8a c - 2a b )n
+--R      *
+--R         log
+--R                            4   2     3 3     2 5  4
+--R                      (- 16a b c  + 8a b c - a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |             2 2       2     4
+--R                       |         - 4a c  + 4a b c - b
+--R                       |--------------------------------------
+--R                       |    7 3      6 2 2      5 4     4 6  6
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (8a c  - 6a b c + b )n
+--R               *
+--R                 +------------------------------------------------------------+
+--R                 |                +--------------------------------------+
+--R                 |                |             2 2       2     4
+--R                 |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R                 |(4a c - a b )n  |--------------------------------------  - b
+--R                 |                |    7 3      6 2 2      5 4     4 6  6
+--R                 |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                 |------------------------------------------------------------
+--R                3|                         3      2 2  3
+--R                \|                      (8a c - 2a b )n
+--R              + 
+--R                                  (n - 3)log(x)
+--R                                  -------------
+--R                     2     2            3
+--R                (4a c  - 2b c)x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R             +------------------------------------------------------------+
+--R             |                +--------------------------------------+
+--R             |                |             2 2       2     4
+--R             |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R             |(4a c - a b )n  |--------------------------------------  - b
+--R             |                |    7 3      6 2 2      5 4     4 6  6
+--R             |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R             |------------------------------------------------------------
+--R            3|                         3      2 2  3
+--R            \|                      (8a c - 2a b )n
+--R         *
+--R            log
+--R                               5   3      4 3 2      3 5     2 7  5
+--R                         (- 64a b c  + 48a b c  - 12a b c + a b )n
+--R                      *
+--R                          +--------------------------------------+
+--R                          |             2 2       2     4
+--R                          |         - 4a c  + 4a b c - b
+--R                          |--------------------------------------
+--R                          |    7 3      6 2 2      5 4     4 6  6
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                           3 3      2 2 2       4     6  2
+--R                       (16a c  - 20a b c  + 8a b c - b )n
+--R                  *
+--R                       ROOT
+--R                                   3     2 2  3
+--R                                (4a c - a b )n
+--R                             *
+--R                                 +--------------------------------------+
+--R                                 |             2 2       2     4
+--R                                 |         - 4a c  + 4a b c - b
+--R                                 |--------------------------------------
+--R                                 |    7 3      6 2 2      5 4     4 6  6
+--R                                \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                            + 
+--R                              - b
+--R                         /
+--R                               3      2 2  3
+--R                            (8a c - 2a b )n
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                             4   3     3 3 2    2 5   4
+--R                         (16a b c  - 8a b c  + a b c)n x
+--R                      *
+--R                          +--------------------------------------+
+--R                          |             2 2       2     4
+--R                          |         - 4a c  + 4a b c - b
+--R                          |--------------------------------------
+--R                          |    7 3      6 2 2      5 4     4 6  6
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                            2 3       2 2    4
+--R                       (- 8a c  + 6a b c  - b c)n x
+--R                  *
+--R                       (n - 3)log(x)
+--R                       -------------
+--R                             3
+--R                     %e
+--R                  *
+--R                     ROOT
+--R                                 3     2 2  3
+--R                              (4a c - a b )n
+--R                           *
+--R                               +--------------------------------------+
+--R                               |             2 2       2     4
+--R                               |         - 4a c  + 4a b c - b
+--R                               |--------------------------------------
+--R                               |    7 3      6 2 2      5 4     4 6  6
+--R                              \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                          + 
+--R                            - b
+--R                       /
+--R                             3      2 2  3
+--R                          (8a c - 2a b )n
+--R                    ,
+--R                        3
+--R                 + 
+--R                                       (n - 3)log(x) 2
+--R                                       -------------
+--R                        3     2 2  2         3
+--R                   (4a c  - 2b c )x (%e             )
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                +--------------------------------------------------------------+
+--R                |                  +--------------------------------------+
+--R                |                  |             2 2       2     4
+--R                |     3     2 2  3 |         - 4a c  + 4a b c - b
+--R                |(- 4a c + a b )n  |--------------------------------------  - b
+--R                |                  |    7 3      6 2 2      5 4     4 6  6
+--R           +-+  |                 \|(64a c  - 48a b c  + 12a b c - a b )n
+--R         2\|3   |--------------------------------------------------------------
+--R               3|                          3      2 2  3
+--R               \|                       (8a c - 2a b )n
+--R      *
+--R         atan
+--R                        4   2     3 3     2 5  4 +-+
+--R                    (16a b c  - 8a b c + a b )n \|3
+--R                 *
+--R                     +--------------------------------------+
+--R                     |             2 2       2     4
+--R                     |         - 4a c  + 4a b c - b
+--R                     |--------------------------------------
+--R                     |    7 3      6 2 2      5 4     4 6  6
+--R                    \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                + 
+--R                     2 2       2     4   +-+
+--R                  (8a c  - 6a b c + b )n\|3
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |                  +--------------------------------------+
+--R               |                  |             2 2       2     4
+--R               |     3     2 2  3 |         - 4a c  + 4a b c - b
+--R               |(- 4a c + a b )n  |--------------------------------------  - b
+--R               |                  |    7 3      6 2 2      5 4     4 6  6
+--R               |                 \|(64a c  - 48a b c  + 12a b c - a b )n
+--R               |--------------------------------------------------------------
+--R              3|                          3      2 2  3
+--R              \|                       (8a c - 2a b )n
+--R           /
+--R                          4   2     3 3     2 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |             2 2       2     4
+--R                       |         - 4a c  + 4a b c - b
+--R                       |--------------------------------------
+--R                       |    7 3      6 2 2      5 4     4 6  6
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (8a c  - 6a b c + b )n
+--R               *
+--R                  ROOT
+--R                                3     2 2  3
+--R                           (- 4a c + a b )n
+--R                        *
+--R                            +--------------------------------------+
+--R                            |             2 2       2     4
+--R                            |         - 4a c  + 4a b c - b
+--R                            |--------------------------------------
+--R                            |    7 3      6 2 2      5 4     4 6  6
+--R                           \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                       + 
+--R                         - b
+--R                    /
+--R                          3      2 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                    (n - 3)log(x)
+--R                                    -------------
+--R                       2     2            3
+--R                (- 8a c  + 4b c)x %e
+--R     + 
+--R                +------------------------------------------------------------+
+--R                |                +--------------------------------------+
+--R                |                |             2 2       2     4
+--R                |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R                |(4a c - a b )n  |--------------------------------------  - b
+--R                |                |    7 3      6 2 2      5 4     4 6  6
+--R           +-+  |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R         2\|3   |------------------------------------------------------------
+--R               3|                         3      2 2  3
+--R               \|                      (8a c - 2a b )n
+--R      *
+--R         atan
+--R                        4   2     3 3     2 5  4 +-+
+--R                    (16a b c  - 8a b c + a b )n \|3
+--R                 *
+--R                     +--------------------------------------+
+--R                     |             2 2       2     4
+--R                     |         - 4a c  + 4a b c - b
+--R                     |--------------------------------------
+--R                     |    7 3      6 2 2      5 4     4 6  6
+--R                    \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                + 
+--R                       2 2       2     4   +-+
+--R                  (- 8a c  + 6a b c - b )n\|3
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |                +--------------------------------------+
+--R                 |                |             2 2       2     4
+--R                 |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R                 |(4a c - a b )n  |--------------------------------------  - b
+--R                 |                |    7 3      6 2 2      5 4     4 6  6
+--R                 |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                 |------------------------------------------------------------
+--R                3|                         3      2 2  3
+--R                \|                      (8a c - 2a b )n
+--R           /
+--R                          4   2     3 3     2 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |             2 2       2     4
+--R                       |         - 4a c  + 4a b c - b
+--R                       |--------------------------------------
+--R                       |    7 3      6 2 2      5 4     4 6  6
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                         2 2       2     4
+--R                    (- 8a c  + 6a b c - b )n
+--R               *
+--R                 +------------------------------------------------------------+
+--R                 |                +--------------------------------------+
+--R                 |                |             2 2       2     4
+--R                 |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R                 |(4a c - a b )n  |--------------------------------------  - b
+--R                 |                |    7 3      6 2 2      5 4     4 6  6
+--R                 |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                 |------------------------------------------------------------
+--R                3|                         3      2 2  3
+--R                \|                      (8a c - 2a b )n
+--R              + 
+--R                                  (n - 3)log(x)
+--R                                  -------------
+--R                     2     2            3
+--R                (8a c  - 4b c)x %e
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1962
+
+--S 1963 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                    +--------------------+2
+--R                    |   +-----------+
+--R             3+-+2 3|   |          2
+--R            2\|c   \|- \|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +------------------+2        n      +------------------+
+--R                  | +-----------+              -      | +-----------+
+--R                 3| |          2          3+-+ 3 3+-+3| |          2
+--R                 \|\|- 4a c + b   + b   - \|2 x  \|c \|\|- 4a c + b   + b
+--R               + 
+--R                       2n
+--R                       --
+--R                 3+-+2  3 3+-+2
+--R                 \|2  x   \|c
+--R     + 
+--R               +--------------------+2     +------------------+        n
+--R               |   +-----------+           | +-----------+             -
+--R        3+-+2 3|   |          2           3| |          2         3+-+ 3 3+-+
+--R       4\|c   \|- \|- 4a c + b   + b  log(\|\|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R                 +------------------+2
+--R                 | +-----------+
+--R          3+-+2 3| |          2
+--R         2\|c   \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2        n      +--------------------+
+--R               |   +-----------+              -      |   +-----------+
+--R              3|   |          2          3+-+ 3 3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - \|2 x  \|c \|- \|- 4a c + b   + b
+--R            + 
+--R                    2n
+--R                    --
+--R              3+-+2  3 3+-+2
+--R              \|2  x   \|c
+--R     + 
+--R                 +------------------+2     +--------------------+        n
+--R                 | +-----------+           |   +-----------+             -
+--R          3+-+2 3| |          2           3|   |          2         3+-+ 3 3+-+
+--R       - 4\|c   \|\|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R       -
+--R                  +-----------+
+--R             3+-+ |          2
+--R            n\|2 \|- 4a c + b
+--R         *
+--R             +--------------------------------------------------------------+
+--R             |                  +--------------------------------------+
+--R             |                  |             2 2       2     4
+--R             |     3     2 2  3 |         - 4a c  + 4a b c - b
+--R             |(- 4a c + a b )n  |--------------------------------------  - b
+--R             |                  |    7 3      6 2 2      5 4     4 6  6
+--R             |                 \|(64a c  - 48a b c  + 12a b c - a b )n
+--R             |--------------------------------------------------------------
+--R            3|                          3      2 2  3
+--R            \|                       (8a c - 2a b )n
+--R         *
+--R             +--------------------+2  +------------------+2
+--R             |   +-----------+        | +-----------+
+--R            3|   |          2        3| |          2
+--R            \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                             5   3      4 3 2      3 5     2 7  5
+--R                         (64a b c  - 48a b c  + 12a b c - a b )n
+--R                      *
+--R                          +--------------------------------------+
+--R                          |             2 2       2     4
+--R                          |         - 4a c  + 4a b c - b
+--R                          |--------------------------------------
+--R                          |    7 3      6 2 2      5 4     4 6  6
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                           3 3      2 2 2       4     6  2
+--R                       (16a c  - 20a b c  + 8a b c - b )n
+--R                  *
+--R                       ROOT
+--R                                     3     2 2  3
+--R                                (- 4a c + a b )n
+--R                             *
+--R                                 +--------------------------------------+
+--R                                 |             2 2       2     4
+--R                                 |         - 4a c  + 4a b c - b
+--R                                 |--------------------------------------
+--R                                 |    7 3      6 2 2      5 4     4 6  6
+--R                                \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                            + 
+--R                              - b
+--R                         /
+--R                               3      2 2  3
+--R                            (8a c - 2a b )n
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                               4   3     3 3 2    2 5   4
+--R                         (- 16a b c  + 8a b c  - a b c)n x
+--R                      *
+--R                          +--------------------------------------+
+--R                          |             2 2       2     4
+--R                          |         - 4a c  + 4a b c - b
+--R                          |--------------------------------------
+--R                          |    7 3      6 2 2      5 4     4 6  6
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                            2 3       2 2    4
+--R                       (- 8a c  + 6a b c  - b c)n x
+--R                  *
+--R                       (n - 3)log(x)
+--R                       -------------
+--R                             3
+--R                     %e
+--R                  *
+--R                     ROOT
+--R                                   3     2 2  3
+--R                              (- 4a c + a b )n
+--R                           *
+--R                               +--------------------------------------+
+--R                               |             2 2       2     4
+--R                               |         - 4a c  + 4a b c - b
+--R                               |--------------------------------------
+--R                               |    7 3      6 2 2      5 4     4 6  6
+--R                              \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                          + 
+--R                            - b
+--R                       /
+--R                             3      2 2  3
+--R                          (8a c - 2a b )n
+--R                    ,
+--R                        3
+--R                 + 
+--R                                       (n - 3)log(x) 2
+--R                                       -------------
+--R                        3     2 2  2         3
+--R                   (4a c  - 2b c )x (%e             )
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                +-----------+
+--R           3+-+ |          2
+--R         2n\|2 \|- 4a c + b
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |                  +--------------------------------------+
+--R          |                  |             2 2       2     4
+--R          |     3     2 2  3 |         - 4a c  + 4a b c - b
+--R          |(- 4a c + a b )n  |--------------------------------------  - b
+--R          |                  |    7 3      6 2 2      5 4     4 6  6
+--R          |                 \|(64a c  - 48a b c  + 12a b c - a b )n
+--R          |--------------------------------------------------------------
+--R         3|                          3      2 2  3
+--R         \|                       (8a c - 2a b )n
+--R      *
+--R          +--------------------+2  +------------------+2
+--R          |   +-----------+        | +-----------+
+--R         3|   |          2        3| |          2
+--R         \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          4   2     3 3     2 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |             2 2       2     4
+--R                       |         - 4a c  + 4a b c - b
+--R                       |--------------------------------------
+--R                       |    7 3      6 2 2      5 4     4 6  6
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (8a c  - 6a b c + b )n
+--R               *
+--R                  ROOT
+--R                                3     2 2  3
+--R                           (- 4a c + a b )n
+--R                        *
+--R                            +--------------------------------------+
+--R                            |             2 2       2     4
+--R                            |         - 4a c  + 4a b c - b
+--R                            |--------------------------------------
+--R                            |    7 3      6 2 2      5 4     4 6  6
+--R                           \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                       + 
+--R                         - b
+--R                    /
+--R                          3      2 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                  (n - 3)log(x)
+--R                                  -------------
+--R                     2     2            3
+--R                (4a c  - 2b c)x %e
+--R           /
+--R              x
+--R     + 
+--R                              +--------------------+2  +------------------+2
+--R                +-----------+ |   +-----------+        | +-----------+
+--R           3+-+ |          2 3|   |          2        3| |          2
+--R         2n\|2 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R          +------------------------------------------------------------+
+--R          |                +--------------------------------------+
+--R          |                |             2 2       2     4
+--R          |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R          |(4a c - a b )n  |--------------------------------------  - b
+--R          |                |    7 3      6 2 2      5 4     4 6  6
+--R          |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R          |------------------------------------------------------------
+--R         3|                         3      2 2  3
+--R         \|                      (8a c - 2a b )n
+--R      *
+--R         log
+--R                            4   2     3 3     2 5  4
+--R                      (- 16a b c  + 8a b c - a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |             2 2       2     4
+--R                       |         - 4a c  + 4a b c - b
+--R                       |--------------------------------------
+--R                       |    7 3      6 2 2      5 4     4 6  6
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (8a c  - 6a b c + b )n
+--R               *
+--R                 +------------------------------------------------------------+
+--R                 |                +--------------------------------------+
+--R                 |                |             2 2       2     4
+--R                 |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R                 |(4a c - a b )n  |--------------------------------------  - b
+--R                 |                |    7 3      6 2 2      5 4     4 6  6
+--R                 |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                 |------------------------------------------------------------
+--R                3|                         3      2 2  3
+--R                \|                      (8a c - 2a b )n
+--R              + 
+--R                                  (n - 3)log(x)
+--R                                  -------------
+--R                     2     2            3
+--R                (4a c  - 2b c)x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                                +--------------------+2  +------------------+2
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             3+-+ |          2 3|   |          2        3| |          2
+--R            n\|2 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R         *
+--R             +------------------------------------------------------------+
+--R             |                +--------------------------------------+
+--R             |                |             2 2       2     4
+--R             |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R             |(4a c - a b )n  |--------------------------------------  - b
+--R             |                |    7 3      6 2 2      5 4     4 6  6
+--R             |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R             |------------------------------------------------------------
+--R            3|                         3      2 2  3
+--R            \|                      (8a c - 2a b )n
+--R         *
+--R            log
+--R                               5   3      4 3 2      3 5     2 7  5
+--R                         (- 64a b c  + 48a b c  - 12a b c + a b )n
+--R                      *
+--R                          +--------------------------------------+
+--R                          |             2 2       2     4
+--R                          |         - 4a c  + 4a b c - b
+--R                          |--------------------------------------
+--R                          |    7 3      6 2 2      5 4     4 6  6
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                           3 3      2 2 2       4     6  2
+--R                       (16a c  - 20a b c  + 8a b c - b )n
+--R                  *
+--R                       ROOT
+--R                                   3     2 2  3
+--R                                (4a c - a b )n
+--R                             *
+--R                                 +--------------------------------------+
+--R                                 |             2 2       2     4
+--R                                 |         - 4a c  + 4a b c - b
+--R                                 |--------------------------------------
+--R                                 |    7 3      6 2 2      5 4     4 6  6
+--R                                \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                            + 
+--R                              - b
+--R                         /
+--R                               3      2 2  3
+--R                            (8a c - 2a b )n
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                             4   3     3 3 2    2 5   4
+--R                         (16a b c  - 8a b c  + a b c)n x
+--R                      *
+--R                          +--------------------------------------+
+--R                          |             2 2       2     4
+--R                          |         - 4a c  + 4a b c - b
+--R                          |--------------------------------------
+--R                          |    7 3      6 2 2      5 4     4 6  6
+--R                         \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                     + 
+--R                            2 3       2 2    4
+--R                       (- 8a c  + 6a b c  - b c)n x
+--R                  *
+--R                       (n - 3)log(x)
+--R                       -------------
+--R                             3
+--R                     %e
+--R                  *
+--R                     ROOT
+--R                                 3     2 2  3
+--R                              (4a c - a b )n
+--R                           *
+--R                               +--------------------------------------+
+--R                               |             2 2       2     4
+--R                               |         - 4a c  + 4a b c - b
+--R                               |--------------------------------------
+--R                               |    7 3      6 2 2      5 4     4 6  6
+--R                              \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                          + 
+--R                            - b
+--R                       /
+--R                             3      2 2  3
+--R                          (8a c - 2a b )n
+--R                    ,
+--R                        3
+--R                 + 
+--R                                       (n - 3)log(x) 2
+--R                                       -------------
+--R                        3     2 2  2         3
+--R                   (4a c  - 2b c )x (%e             )
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R                    +-----------+
+--R           3+-+ +-+ |          2
+--R         2n\|2 \|3 \|- 4a c + b
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |                  +--------------------------------------+
+--R          |                  |             2 2       2     4
+--R          |     3     2 2  3 |         - 4a c  + 4a b c - b
+--R          |(- 4a c + a b )n  |--------------------------------------  - b
+--R          |                  |    7 3      6 2 2      5 4     4 6  6
+--R          |                 \|(64a c  - 48a b c  + 12a b c - a b )n
+--R          |--------------------------------------------------------------
+--R         3|                          3      2 2  3
+--R         \|                       (8a c - 2a b )n
+--R      *
+--R          +--------------------+2  +------------------+2
+--R          |   +-----------+        | +-----------+
+--R         3|   |          2        3| |          2
+--R         \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                        4   2     3 3     2 5  4 +-+
+--R                    (16a b c  - 8a b c + a b )n \|3
+--R                 *
+--R                     +--------------------------------------+
+--R                     |             2 2       2     4
+--R                     |         - 4a c  + 4a b c - b
+--R                     |--------------------------------------
+--R                     |    7 3      6 2 2      5 4     4 6  6
+--R                    \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                + 
+--R                     2 2       2     4   +-+
+--R                  (8a c  - 6a b c + b )n\|3
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |                  +--------------------------------------+
+--R               |                  |             2 2       2     4
+--R               |     3     2 2  3 |         - 4a c  + 4a b c - b
+--R               |(- 4a c + a b )n  |--------------------------------------  - b
+--R               |                  |    7 3      6 2 2      5 4     4 6  6
+--R               |                 \|(64a c  - 48a b c  + 12a b c - a b )n
+--R               |--------------------------------------------------------------
+--R              3|                          3      2 2  3
+--R              \|                       (8a c - 2a b )n
+--R           /
+--R                          4   2     3 3     2 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |             2 2       2     4
+--R                       |         - 4a c  + 4a b c - b
+--R                       |--------------------------------------
+--R                       |    7 3      6 2 2      5 4     4 6  6
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (8a c  - 6a b c + b )n
+--R               *
+--R                  ROOT
+--R                                3     2 2  3
+--R                           (- 4a c + a b )n
+--R                        *
+--R                            +--------------------------------------+
+--R                            |             2 2       2     4
+--R                            |         - 4a c  + 4a b c - b
+--R                            |--------------------------------------
+--R                            |    7 3      6 2 2      5 4     4 6  6
+--R                           \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                       + 
+--R                         - b
+--R                    /
+--R                          3      2 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                    (n - 3)log(x)
+--R                                    -------------
+--R                       2     2            3
+--R                (- 8a c  + 4b c)x %e
+--R     + 
+--R                                  +--------------------+2  +------------------+2
+--R                    +-----------+ |   +-----------+        | +-----------+
+--R           3+-+ +-+ |          2 3|   |          2        3| |          2
+--R         2n\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R      *
+--R          +------------------------------------------------------------+
+--R          |                +--------------------------------------+
+--R          |                |             2 2       2     4
+--R          |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R          |(4a c - a b )n  |--------------------------------------  - b
+--R          |                |    7 3      6 2 2      5 4     4 6  6
+--R          |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R          |------------------------------------------------------------
+--R         3|                         3      2 2  3
+--R         \|                      (8a c - 2a b )n
+--R      *
+--R         atan
+--R                        4   2     3 3     2 5  4 +-+
+--R                    (16a b c  - 8a b c + a b )n \|3
+--R                 *
+--R                     +--------------------------------------+
+--R                     |             2 2       2     4
+--R                     |         - 4a c  + 4a b c - b
+--R                     |--------------------------------------
+--R                     |    7 3      6 2 2      5 4     4 6  6
+--R                    \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                + 
+--R                       2 2       2     4   +-+
+--R                  (- 8a c  + 6a b c - b )n\|3
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |                +--------------------------------------+
+--R                 |                |             2 2       2     4
+--R                 |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R                 |(4a c - a b )n  |--------------------------------------  - b
+--R                 |                |    7 3      6 2 2      5 4     4 6  6
+--R                 |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                 |------------------------------------------------------------
+--R                3|                         3      2 2  3
+--R                \|                      (8a c - 2a b )n
+--R           /
+--R                          4   2     3 3     2 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +--------------------------------------+
+--R                       |             2 2       2     4
+--R                       |         - 4a c  + 4a b c - b
+--R                       |--------------------------------------
+--R                       |    7 3      6 2 2      5 4     4 6  6
+--R                      \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                  + 
+--R                         2 2       2     4
+--R                    (- 8a c  + 6a b c - b )n
+--R               *
+--R                 +------------------------------------------------------------+
+--R                 |                +--------------------------------------+
+--R                 |                |             2 2       2     4
+--R                 |   3     2 2  3 |         - 4a c  + 4a b c - b
+--R                 |(4a c - a b )n  |--------------------------------------  - b
+--R                 |                |    7 3      6 2 2      5 4     4 6  6
+--R                 |               \|(64a c  - 48a b c  + 12a b c - a b )n
+--R                 |------------------------------------------------------------
+--R                3|                         3      2 2  3
+--R                \|                      (8a c - 2a b )n
+--R              + 
+--R                                  (n - 3)log(x)
+--R                                  -------------
+--R                     2     2            3
+--R                (8a c  - 4b c)x %e
+--R     + 
+--R       -
+--R                        +--------------------+2
+--R                        |   +-----------+
+--R              +-+3+-+2 3|   |          2
+--R            4\|3 \|c   \|- \|- 4a c + b   + b
+--R         *
+--R                        +------------------+    n
+--R                        | +-----------+         -
+--R                 3+-+2 3| |          2          3 3+-+
+--R                 \|2   \|\|- 4a c + b   + b - 4x  \|c
+--R            atan(------------------------------------)
+--R                              +------------------+
+--R                              | +-----------+
+--R                    3+-+2 +-+3| |          2
+--R                    \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                     +------------------+2
+--R                     | +-----------+
+--R           +-+3+-+2 3| |          2
+--R         4\|3 \|c   \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+    n
+--R                     |   +-----------+         -
+--R              3+-+2 3|   |          2          3 3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x  \|c
+--R         atan(--------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                          +--------------------+2  +------------------+2
+--R            +-----------+ |   +-----------+        | +-----------+
+--R       3+-+ |          2 3|   |          2        3| |          2
+--R     2n\|2 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1963
+
+--S 1964 of 2282
+--d0:=normalize(D(m0,x))
+--E 1964
+
+)clear all
+
+--S 1965 of 2282
+t0:=x^(-1+1/2*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              n - 2
+--R              -----
+--R                2
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1965
+
+--S 1966 of 2282
+r0:=2*atan(x^(1/2*n)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*_
+   sqrt(c)/(n*sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-2*atan(x^(1/2*n)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/_
+   (n*sqrt(b^2-4*a*c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                      n
+--R                 +------------------+                 -
+--R                 | +-----------+                  +-+ 2 +-+
+--R         +-+ +-+ | |          2                  \|2 x \|c
+--R       2\|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                           |   |          2
+--R                                          \|- \|- 4a c + b   + b
+--R     + 
+--R                                                         n
+--R                   +--------------------+                -
+--R                   |   +-----------+                 +-+ 2 +-+
+--R           +-+ +-+ |   |          2                 \|2 x \|c
+--R       - 2\|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                               +------------------+
+--R                                               | +-----------+
+--R                                               | |          2
+--R                                              \|\|- 4a c + b   + b
+--R  /
+--R                     +--------------------+ +------------------+
+--R       +-----------+ |   +-----------+      | +-----------+
+--R       |          2  |   |          2       | |          2
+--R     n\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1966
+
+--S 1967 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-----------------------------------------+
+--R          |                 +-----------------+
+--R          |   2        2  2 |         1
+--R          |(8a c - 2a b )n  |- ---------------  + 2b
+--R          |                 |     3     2 2  4
+--R          |                \|  (4a c - a b )n
+--R          |-----------------------------------------
+--R          |                2       2  2
+--R         \|             (4a c - a b )n
+--R      *
+--R         log
+--R                                     +-----------------+
+--R                      2         3  3 |         1                    2
+--R                  ((4a b c - a b )n  |- ---------------  + (4a c - b )n)
+--R                                     |     3     2 2  4
+--R                                    \|  (4a c - a b )n
+--R               *
+--R                   +-----------------------------------------+
+--R                   |                 +-----------------+
+--R                   |   2        2  2 |         1
+--R                   |(8a c - 2a b )n  |- ---------------  + 2b
+--R                   |                 |     3     2 2  4
+--R                   |                \|  (4a c - a b )n
+--R                   |-----------------------------------------
+--R                   |                2       2  2
+--R                  \|             (4a c - a b )n
+--R              + 
+--R                       (n - 2)log(x)
+--R                       -------------
+--R                             2
+--R                4c x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R             +-------------------------------------------+
+--R             |                   +-----------------+
+--R             |     2        2  2 |         1
+--R             |(- 8a c + 2a b )n  |- ---------------  + 2b
+--R             |                   |     3     2 2  4
+--R             |                  \|  (4a c - a b )n
+--R             |-------------------------------------------
+--R             |                 2       2  2
+--R            \|              (4a c - a b )n
+--R         *
+--R            log
+--R                                        +-----------------+
+--R                         2         3  3 |         1                      2
+--R                     ((4a b c - a b )n  |- ---------------  + (- 4a c + b )n)
+--R                                        |     3     2 2  4
+--R                                       \|  (4a c - a b )n
+--R                  *
+--R                      +-------------------------------------------+
+--R                      |                   +-----------------+
+--R                      |     2        2  2 |         1
+--R                      |(- 8a c + 2a b )n  |- ---------------  + 2b
+--R                      |                   |     3     2 2  4
+--R                      |                  \|  (4a c - a b )n
+--R                      |-------------------------------------------
+--R                      |                 2       2  2
+--R                     \|              (4a c - a b )n
+--R                 + 
+--R                          (n - 2)log(x)
+--R                          -------------
+--R                                2
+--R                   4c x %e
+--R              /
+--R                 x
+--R     + 
+--R          +-------------------------------------------+
+--R          |                   +-----------------+
+--R          |     2        2  2 |         1
+--R          |(- 8a c + 2a b )n  |- ---------------  + 2b
+--R          |                   |     3     2 2  4
+--R          |                  \|  (4a c - a b )n
+--R          |-------------------------------------------
+--R          |                 2       2  2
+--R         \|              (4a c - a b )n
+--R      *
+--R         log
+--R                                       +-----------------+
+--R                        2         3  3 |         1                    2
+--R                  ((- 4a b c + a b )n  |- ---------------  + (4a c - b )n)
+--R                                       |     3     2 2  4
+--R                                      \|  (4a c - a b )n
+--R               *
+--R                   +-------------------------------------------+
+--R                   |                   +-----------------+
+--R                   |     2        2  2 |         1
+--R                   |(- 8a c + 2a b )n  |- ---------------  + 2b
+--R                   |                   |     3     2 2  4
+--R                   |                  \|  (4a c - a b )n
+--R                   |-------------------------------------------
+--R                   |                 2       2  2
+--R                  \|              (4a c - a b )n
+--R              + 
+--R                       (n - 2)log(x)
+--R                       -------------
+--R                             2
+--R                4c x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R             +-----------------------------------------+
+--R             |                 +-----------------+
+--R             |   2        2  2 |         1
+--R             |(8a c - 2a b )n  |- ---------------  + 2b
+--R             |                 |     3     2 2  4
+--R             |                \|  (4a c - a b )n
+--R             |-----------------------------------------
+--R             |                2       2  2
+--R            \|             (4a c - a b )n
+--R         *
+--R            log
+--R                                          +-----------------+
+--R                           2         3  3 |         1                      2
+--R                     ((- 4a b c + a b )n  |- ---------------  + (- 4a c + b )n)
+--R                                          |     3     2 2  4
+--R                                         \|  (4a c - a b )n
+--R                  *
+--R                      +-----------------------------------------+
+--R                      |                 +-----------------+
+--R                      |   2        2  2 |         1
+--R                      |(8a c - 2a b )n  |- ---------------  + 2b
+--R                      |                 |     3     2 2  4
+--R                      |                \|  (4a c - a b )n
+--R                      |-----------------------------------------
+--R                      |                2       2  2
+--R                     \|             (4a c - a b )n
+--R                 + 
+--R                          (n - 2)log(x)
+--R                          -------------
+--R                                2
+--R                   4c x %e
+--R              /
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1967
+
+--S 1968 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +--------------------+ +------------------+
+--R           +-----------+ |   +-----------+      | +-----------+
+--R           |          2  |   |          2       | |          2
+--R         n\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------------------------+
+--R          |                 +-----------------+
+--R          |   2        2  2 |         1
+--R          |(8a c - 2a b )n  |- ---------------  + 2b
+--R          |                 |     3     2 2  4
+--R          |                \|  (4a c - a b )n
+--R          |-----------------------------------------
+--R          |                2       2  2
+--R         \|             (4a c - a b )n
+--R      *
+--R         log
+--R                                     +-----------------+
+--R                      2         3  3 |         1                    2
+--R                  ((4a b c - a b )n  |- ---------------  + (4a c - b )n)
+--R                                     |     3     2 2  4
+--R                                    \|  (4a c - a b )n
+--R               *
+--R                   +-----------------------------------------+
+--R                   |                 +-----------------+
+--R                   |   2        2  2 |         1
+--R                   |(8a c - 2a b )n  |- ---------------  + 2b
+--R                   |                 |     3     2 2  4
+--R                   |                \|  (4a c - a b )n
+--R                   |-----------------------------------------
+--R                   |                2       2  2
+--R                  \|             (4a c - a b )n
+--R              + 
+--R                       (n - 2)log(x)
+--R                       -------------
+--R                             2
+--R                4c x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                            +-------------------------------------------+
+--R                            |                   +-----------------+
+--R                            |     2        2  2 |         1
+--R                            |(- 8a c + 2a b )n  |- ---------------  + 2b
+--R              +-----------+ |                   |     3     2 2  4
+--R              |          2  |                  \|  (4a c - a b )n
+--R            n\|- 4a c + b   |-------------------------------------------
+--R                            |                 2       2  2
+--R                           \|              (4a c - a b )n
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                        +-----------------+
+--R                         2         3  3 |         1                      2
+--R                     ((4a b c - a b )n  |- ---------------  + (- 4a c + b )n)
+--R                                        |     3     2 2  4
+--R                                       \|  (4a c - a b )n
+--R                  *
+--R                      +-------------------------------------------+
+--R                      |                   +-----------------+
+--R                      |     2        2  2 |         1
+--R                      |(- 8a c + 2a b )n  |- ---------------  + 2b
+--R                      |                   |     3     2 2  4
+--R                      |                  \|  (4a c - a b )n
+--R                      |-------------------------------------------
+--R                      |                 2       2  2
+--R                     \|              (4a c - a b )n
+--R                 + 
+--R                          (n - 2)log(x)
+--R                          -------------
+--R                                2
+--R                   4c x %e
+--R              /
+--R                 x
+--R     + 
+--R                         +-------------------------------------------+
+--R                         |                   +-----------------+
+--R                         |     2        2  2 |         1
+--R                         |(- 8a c + 2a b )n  |- ---------------  + 2b
+--R           +-----------+ |                   |     3     2 2  4
+--R           |          2  |                  \|  (4a c - a b )n
+--R         n\|- 4a c + b   |-------------------------------------------
+--R                         |                 2       2  2
+--R                        \|              (4a c - a b )n
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                       +-----------------+
+--R                        2         3  3 |         1                    2
+--R                  ((- 4a b c + a b )n  |- ---------------  + (4a c - b )n)
+--R                                       |     3     2 2  4
+--R                                      \|  (4a c - a b )n
+--R               *
+--R                   +-------------------------------------------+
+--R                   |                   +-----------------+
+--R                   |     2        2  2 |         1
+--R                   |(- 8a c + 2a b )n  |- ---------------  + 2b
+--R                   |                   |     3     2 2  4
+--R                   |                  \|  (4a c - a b )n
+--R                   |-------------------------------------------
+--R                   |                 2       2  2
+--R                  \|              (4a c - a b )n
+--R              + 
+--R                       (n - 2)log(x)
+--R                       -------------
+--R                             2
+--R                4c x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R              |          2  |   |          2       | |          2
+--R            n\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +-----------------------------------------+
+--R             |                 +-----------------+
+--R             |   2        2  2 |         1
+--R             |(8a c - 2a b )n  |- ---------------  + 2b
+--R             |                 |     3     2 2  4
+--R             |                \|  (4a c - a b )n
+--R             |-----------------------------------------
+--R             |                2       2  2
+--R            \|             (4a c - a b )n
+--R         *
+--R            log
+--R                                          +-----------------+
+--R                           2         3  3 |         1                      2
+--R                     ((- 4a b c + a b )n  |- ---------------  + (- 4a c + b )n)
+--R                                          |     3     2 2  4
+--R                                         \|  (4a c - a b )n
+--R                  *
+--R                      +-----------------------------------------+
+--R                      |                 +-----------------+
+--R                      |   2        2  2 |         1
+--R                      |(8a c - 2a b )n  |- ---------------  + 2b
+--R                      |                 |     3     2 2  4
+--R                      |                \|  (4a c - a b )n
+--R                      |-----------------------------------------
+--R                      |                2       2  2
+--R                     \|             (4a c - a b )n
+--R                 + 
+--R                          (n - 2)log(x)
+--R                          -------------
+--R                                2
+--R                   4c x %e
+--R              /
+--R                 x
+--R     + 
+--R                                                        n
+--R                   +------------------+                 -
+--R                   | +-----------+                  +-+ 2 +-+
+--R           +-+ +-+ | |          2                  \|2 x \|c
+--R       - 4\|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                             +--------------------+
+--R                                             |   +-----------+
+--R                                             |   |          2
+--R                                            \|- \|- 4a c + b   + b
+--R     + 
+--R                                                       n
+--R                 +--------------------+                -
+--R                 |   +-----------+                 +-+ 2 +-+
+--R         +-+ +-+ |   |          2                 \|2 x \|c
+--R       4\|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                             | |          2
+--R                                            \|\|- 4a c + b   + b
+--R  /
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R     2n\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1968
+
+--S 1969 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1969
+
+)clear all
+
+--S 1970 of 2282
+t0:=x^(-1-1/2*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - n - 2
+--R             -------
+--R                2
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1970
+
+--S 1971 of 2282
+r0:=-4*c^(3/2)*atan(x^(1/2*n)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(2)/(n*(b-sqrt(b^2-4*a*c))^(3/2)*sqrt(b^2-4*a*c))+4*c^(3/2)*_
+   atan(x^(1/2*n)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)/_
+   (n*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(3/2))+4*c/(n*x^(1/2*n)*_
+   (b^2-4*a*c-b*sqrt(b^2-4*a*c)))+4*c/(n*x^(1/2*n)*(b^2-4*a*c+_
+   b*sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                n                                   n      +------------------+
+--R                - +-----------+                     -      | +-----------+
+--R            +-+ 2 |          2               2  +-+ 2  +-+ | |          2
+--R         (b\|2 x \|- 4a c + b   + (- 4a c + b )\|2 x )\|c \|\|- 4a c + b   + b
+--R      *
+--R                          n
+--R                          -
+--R                      +-+ 2 +-+
+--R                     \|2 x \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                  n                                   n
+--R                  - +-----------+                     -
+--R              +-+ 2 |          2               2  +-+ 2  +-+
+--R         (- b\|2 x \|- 4a c + b   + (- 4a c + b )\|2 x )\|c
+--R      *
+--R                                                n
+--R          +--------------------+                -
+--R          |   +-----------+                 +-+ 2 +-+
+--R          |   |          2                 \|2 x \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                      +--------------------+ +------------------+
+--R                      |   +-----------+      | +-----------+
+--R                   2  |   |          2       | |          2
+--R       (- 8a c + 2b )\|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                     n +--------------------+ +------------------+
+--R                     - |   +-----------+      | +-----------+
+--R        2       2    2 |   |          2       | |          2
+--R     (4a c - a b )n x \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1971
+
+--S 1972 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                +------------------------------------------------------+
+--R                |                 +--------------------+
+--R                |                 |   2 2       2     4
+--R                |   4      3 2  2 |- a c  + 2a b c - b                3
+--R                |(8a c - 2a b )n  |--------------------  - 6a b c + 2b
+--R                |                 |      7     6 2  4
+--R                |                \|   (4a c - a b )n
+--R            a n |------------------------------------------------------
+--R                |                       4     3 2  2
+--R               \|                    (4a c - a b )n
+--R         *
+--R            log
+--R                                         +--------------------+
+--R                                         |   2 2       2     4
+--R                          4       3 3  3 |- a c  + 2a b c - b
+--R                       (4a b c - a b )n  |--------------------
+--R                                         |      7     6 2  4
+--R                                        \|   (4a c - a b )n
+--R                     + 
+--R                            2 2       2     4
+--R                       (- 4a c  + 5a b c - b )n
+--R                  *
+--R                      +------------------------------------------------------+
+--R                      |                 +--------------------+
+--R                      |                 |   2 2       2     4
+--R                      |   4      3 2  2 |- a c  + 2a b c - b                3
+--R                      |(8a c - 2a b )n  |--------------------  - 6a b c + 2b
+--R                      |                 |      7     6 2  4
+--R                      |                \|   (4a c - a b )n
+--R                      |------------------------------------------------------
+--R                      |                       4     3 2  2
+--R                     \|                    (4a c - a b )n
+--R                 + 
+--R                                     (- n - 2)log(x)
+--R                                     ---------------
+--R                        2     2             2
+--R                   (4a c  - 4b c)x %e
+--R              /
+--R                 x
+--R     + 
+--R             +--------------------------------------------------------+
+--R             |                   +--------------------+
+--R             |                   |   2 2       2     4
+--R             |     4      3 2  2 |- a c  + 2a b c - b                3
+--R             |(- 8a c + 2a b )n  |--------------------  - 6a b c + 2b
+--R             |                   |      7     6 2  4
+--R             |                  \|   (4a c - a b )n
+--R         a n |--------------------------------------------------------
+--R             |                        4     3 2  2
+--R            \|                     (4a c - a b )n
+--R      *
+--R         log
+--R                                      +--------------------+
+--R                                      |   2 2       2     4
+--R                       4       3 3  3 |- a c  + 2a b c - b
+--R                    (4a b c - a b )n  |--------------------
+--R                                      |      7     6 2  4
+--R                                     \|   (4a c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (4a c  - 5a b c + b )n
+--R               *
+--R                   +--------------------------------------------------------+
+--R                   |                   +--------------------+
+--R                   |                   |   2 2       2     4
+--R                   |     4      3 2  2 |- a c  + 2a b c - b                3
+--R                   |(- 8a c + 2a b )n  |--------------------  - 6a b c + 2b
+--R                   |                   |      7     6 2  4
+--R                   |                  \|   (4a c - a b )n
+--R                   |--------------------------------------------------------
+--R                   |                        4     3 2  2
+--R                  \|                     (4a c - a b )n
+--R              + 
+--R                                  (- n - 2)log(x)
+--R                                  ---------------
+--R                     2     2             2
+--R                (4a c  - 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                +--------------------------------------------------------+
+--R                |                   +--------------------+
+--R                |                   |   2 2       2     4
+--R                |     4      3 2  2 |- a c  + 2a b c - b                3
+--R                |(- 8a c + 2a b )n  |--------------------  - 6a b c + 2b
+--R                |                   |      7     6 2  4
+--R                |                  \|   (4a c - a b )n
+--R            a n |--------------------------------------------------------
+--R                |                        4     3 2  2
+--R               \|                     (4a c - a b )n
+--R         *
+--R            log
+--R                                           +--------------------+
+--R                                           |   2 2       2     4
+--R                            4       3 3  3 |- a c  + 2a b c - b
+--R                       (- 4a b c + a b )n  |--------------------
+--R                                           |      7     6 2  4
+--R                                          \|   (4a c - a b )n
+--R                     + 
+--R                            2 2       2     4
+--R                       (- 4a c  + 5a b c - b )n
+--R                  *
+--R                    +--------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |     4      3 2  2 |- a c  + 2a b c - b                3
+--R                    |(- 8a c + 2a b )n  |--------------------  - 6a b c + 2b
+--R                    |                   |      7     6 2  4
+--R                    |                  \|   (4a c - a b )n
+--R                    |--------------------------------------------------------
+--R                    |                        4     3 2  2
+--R                   \|                     (4a c - a b )n
+--R                 + 
+--R                                     (- n - 2)log(x)
+--R                                     ---------------
+--R                        2     2             2
+--R                   (4a c  - 4b c)x %e
+--R              /
+--R                 x
+--R     + 
+--R             +------------------------------------------------------+
+--R             |                 +--------------------+
+--R             |                 |   2 2       2     4
+--R             |   4      3 2  2 |- a c  + 2a b c - b                3
+--R             |(8a c - 2a b )n  |--------------------  - 6a b c + 2b
+--R             |                 |      7     6 2  4
+--R             |                \|   (4a c - a b )n
+--R         a n |------------------------------------------------------
+--R             |                       4     3 2  2
+--R            \|                    (4a c - a b )n
+--R      *
+--R         log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                         4       3 3  3 |- a c  + 2a b c - b
+--R                    (- 4a b c + a b )n  |--------------------
+--R                                        |      7     6 2  4
+--R                                       \|   (4a c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (4a c  - 5a b c + b )n
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                 +--------------------+
+--R                   |                 |   2 2       2     4
+--R                   |   4      3 2  2 |- a c  + 2a b c - b                3
+--R                   |(8a c - 2a b )n  |--------------------  - 6a b c + 2b
+--R                   |                 |      7     6 2  4
+--R                   |                \|   (4a c - a b )n
+--R                   |------------------------------------------------------
+--R                   |                       4     3 2  2
+--R                  \|                    (4a c - a b )n
+--R              + 
+--R                                  (- n - 2)log(x)
+--R                                  ---------------
+--R                     2     2             2
+--R                (4a c  - 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R              (- n - 2)log(x)
+--R              ---------------
+--R                     2
+--R       - 4x %e
+--R  /
+--R     2a n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1972
+
+--S 1973 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           n +--------------------+ +------------------+
+--R                           - |   +-----------+      | +-----------+
+--R              2       2    2 |   |          2       | |          2
+--R         (- 4a c + a b )n x \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +------------------------------------------------------+
+--R          |                 +--------------------+
+--R          |                 |   2 2       2     4
+--R          |   4      3 2  2 |- a c  + 2a b c - b                3
+--R          |(8a c - 2a b )n  |--------------------  - 6a b c + 2b
+--R          |                 |      7     6 2  4
+--R          |                \|   (4a c - a b )n
+--R          |------------------------------------------------------
+--R          |                       4     3 2  2
+--R         \|                    (4a c - a b )n
+--R      *
+--R         log
+--R                                      +--------------------+
+--R                                      |   2 2       2     4
+--R                       4       3 3  3 |- a c  + 2a b c - b
+--R                    (4a b c - a b )n  |--------------------
+--R                                      |      7     6 2  4
+--R                                     \|   (4a c - a b )n
+--R                  + 
+--R                         2 2       2     4
+--R                    (- 4a c  + 5a b c - b )n
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                 +--------------------+
+--R                   |                 |   2 2       2     4
+--R                   |   4      3 2  2 |- a c  + 2a b c - b                3
+--R                   |(8a c - 2a b )n  |--------------------  - 6a b c + 2b
+--R                   |                 |      7     6 2  4
+--R                   |                \|   (4a c - a b )n
+--R                   |------------------------------------------------------
+--R                   |                       4     3 2  2
+--R                  \|                    (4a c - a b )n
+--R              + 
+--R                                  (- n - 2)log(x)
+--R                                  ---------------
+--R                     2     2             2
+--R                (4a c  - 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R                         n
+--R                         -
+--R            2       2    2
+--R         (4a c - a b )n x
+--R      *
+--R          +--------------------------------------------------------+
+--R          |                   +--------------------+
+--R          |                   |   2 2       2     4
+--R          |     4      3 2  2 |- a c  + 2a b c - b                3
+--R          |(- 8a c + 2a b )n  |--------------------  - 6a b c + 2b
+--R          |                   |      7     6 2  4
+--R          |                  \|   (4a c - a b )n
+--R          |--------------------------------------------------------
+--R          |                        4     3 2  2
+--R         \|                     (4a c - a b )n
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                      +--------------------+
+--R                                      |   2 2       2     4
+--R                       4       3 3  3 |- a c  + 2a b c - b
+--R                    (4a b c - a b )n  |--------------------
+--R                                      |      7     6 2  4
+--R                                     \|   (4a c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (4a c  - 5a b c + b )n
+--R               *
+--R                   +--------------------------------------------------------+
+--R                   |                   +--------------------+
+--R                   |                   |   2 2       2     4
+--R                   |     4      3 2  2 |- a c  + 2a b c - b                3
+--R                   |(- 8a c + 2a b )n  |--------------------  - 6a b c + 2b
+--R                   |                   |      7     6 2  4
+--R                   |                  \|   (4a c - a b )n
+--R                   |--------------------------------------------------------
+--R                   |                        4     3 2  2
+--R                  \|                     (4a c - a b )n
+--R              + 
+--R                                  (- n - 2)log(x)
+--R                                  ---------------
+--R                     2     2             2
+--R                (4a c  - 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R                           n
+--R                           -
+--R              2       2    2
+--R         (- 4a c + a b )n x
+--R      *
+--R          +--------------------------------------------------------+
+--R          |                   +--------------------+
+--R          |                   |   2 2       2     4
+--R          |     4      3 2  2 |- a c  + 2a b c - b                3
+--R          |(- 8a c + 2a b )n  |--------------------  - 6a b c + 2b
+--R          |                   |      7     6 2  4
+--R          |                  \|   (4a c - a b )n
+--R          |--------------------------------------------------------
+--R          |                        4     3 2  2
+--R         \|                     (4a c - a b )n
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                         4       3 3  3 |- a c  + 2a b c - b
+--R                    (- 4a b c + a b )n  |--------------------
+--R                                        |      7     6 2  4
+--R                                       \|   (4a c - a b )n
+--R                  + 
+--R                         2 2       2     4
+--R                    (- 4a c  + 5a b c - b )n
+--R               *
+--R                   +--------------------------------------------------------+
+--R                   |                   +--------------------+
+--R                   |                   |   2 2       2     4
+--R                   |     4      3 2  2 |- a c  + 2a b c - b                3
+--R                   |(- 8a c + 2a b )n  |--------------------  - 6a b c + 2b
+--R                   |                   |      7     6 2  4
+--R                   |                  \|   (4a c - a b )n
+--R                   |--------------------------------------------------------
+--R                   |                        4     3 2  2
+--R                  \|                     (4a c - a b )n
+--R              + 
+--R                                  (- n - 2)log(x)
+--R                                  ---------------
+--R                     2     2             2
+--R                (4a c  - 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R                         n +--------------------+ +------------------+
+--R                         - |   +-----------+      | +-----------+
+--R            2       2    2 |   |          2       | |          2
+--R         (4a c - a b )n x \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +------------------------------------------------------+
+--R          |                 +--------------------+
+--R          |                 |   2 2       2     4
+--R          |   4      3 2  2 |- a c  + 2a b c - b                3
+--R          |(8a c - 2a b )n  |--------------------  - 6a b c + 2b
+--R          |                 |      7     6 2  4
+--R          |                \|   (4a c - a b )n
+--R          |------------------------------------------------------
+--R          |                       4     3 2  2
+--R         \|                    (4a c - a b )n
+--R      *
+--R         log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                         4       3 3  3 |- a c  + 2a b c - b
+--R                    (- 4a b c + a b )n  |--------------------
+--R                                        |      7     6 2  4
+--R                                       \|   (4a c - a b )n
+--R                  + 
+--R                       2 2       2     4
+--R                    (4a c  - 5a b c + b )n
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |                 +--------------------+
+--R                   |                 |   2 2       2     4
+--R                   |   4      3 2  2 |- a c  + 2a b c - b                3
+--R                   |(8a c - 2a b )n  |--------------------  - 6a b c + 2b
+--R                   |                 |      7     6 2  4
+--R                   |                \|   (4a c - a b )n
+--R                   |------------------------------------------------------
+--R                   |                       4     3 2  2
+--R                  \|                    (4a c - a b )n
+--R              + 
+--R                                  (- n - 2)log(x)
+--R                                  ---------------
+--R                     2     2             2
+--R                (4a c  - 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R                   n                                  n
+--R                   - +-----------+                    -
+--R               +-+ 2 |          2              2  +-+ 2  +-+
+--R         (- 2b\|2 x \|- 4a c + b   + (8a c - 2b )\|2 x )\|c
+--R      *
+--R                                               n
+--R          +------------------+                 -
+--R          | +-----------+                  +-+ 2 +-+
+--R          | |          2                  \|2 x \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                 n                                  n
+--R                 - +-----------+                    -
+--R             +-+ 2 |          2              2  +-+ 2  +-+
+--R         (2b\|2 x \|- 4a c + b   + (8a c - 2b )\|2 x )\|c
+--R      *
+--R                                                n
+--R          +--------------------+                -
+--R          |   +-----------+                 +-+ 2 +-+
+--R          |   |          2                 \|2 x \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                            n  (- n - 2)log(x)
+--R                            -  ---------------
+--R                       2    2         2                    2
+--R         ((- 16a c + 4b )x x %e                + 16a c - 4b )
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                      n +--------------------+ +------------------+
+--R                      - |   +-----------+      | +-----------+
+--R        2        2    2 |   |          2       | |          2
+--R     (8a c - 2a b )n x \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1973
+
+--S 1974 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                             n log(x) 5
+--R             +-----------+                   --------
+--R           2 |          2        3    2 2        2
+--R       (b c \|- 4a c + b   - 4a c  + b c )(%e        )
+--R     + 
+--R                                                           n log(x) 3
+--R                         +-----------+                     --------
+--R               2     2   |          2          2     3         2
+--R       ((- 4a c  + 2b c)\|- 4a c + b   - 8a b c  + 2b c)(%e        )
+--R     + 
+--R                                                              n log(x)
+--R                        +-----------+                         --------
+--R                     3  |          2      2 2       2     4       2
+--R       ((- 3a b c + b )\|- 4a c + b   + 4a c  - 5a b c + b )%e
+--R  /
+--R                             n log(x) 6
+--R                             --------
+--R          2 3       2 2          2
+--R       (8a c  - 2a b c )x (%e        )
+--R     + 
+--R                                                                 n log(x) 4
+--R                         +-----------+                           --------
+--R           2 2      2    |          2        2   2       3           2
+--R       ((4a c  - a b c)x\|- 4a c + b   + (12a b c  - 3a b c)x)(%e        )
+--R     + 
+--R                                                                     n log(x) 2
+--R                         +-----------+                               --------
+--R           2         3   |          2       3 2     2 2       4          2
+--R       ((4a b c - a b )x\|- 4a c + b   + (8a c  + 2a b c - a b )x)(%e        )
+--R     + 
+--R                      +-----------+
+--R          3     2 2   |          2       3       2 3
+--R       (4a c - a b )x\|- 4a c + b   + (4a b c - a b )x
+--R                                                    Type: Expression(Integer)
+--E 1974
+
+)clear all
+
+--S 1975 of 2282
+t0:=x^(-1-1/3*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - n - 3
+--R             -------
+--R                3
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1975
+
+--S 1976 of 2282
+r0:=2*2^(1/3)*c^(4/3)*log(2^(1/3)*c^(1/3)*x^(1/3*n)+(b-_
+   sqrt(b^2-4*a*c))^(1/3))/(n*(b-sqrt(b^2-4*a*c))^(4/3)*_
+   sqrt(b^2-4*a*c))-2^(1/3)*c^(4/3)*log(2^(2/3)*c^(2/3)*x^(2/3*n)-_
+   2^(1/3)*c^(1/3)*x^(1/3*n)*(b-sqrt(b^2-4*a*c))^(1/3)+_
+   (b-sqrt(b^2-4*a*c))^(2/3))/(n*(b-sqrt(b^2-4*a*c))^(4/3)*_
+   sqrt(b^2-4*a*c))+2*2^(1/3)*c^(4/3)*atan((-4*c^(1/3)*x^(1/3*n)+_
+   2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3)))*sqrt(3)/(n*(b-sqrt(b^2-4*a*c))^(4/3)*_
+   sqrt(b^2-4*a*c))-2*2^(1/3)*c^(4/3)*log(2^(1/3)*c^(1/3)*x^(1/3*n)+_
+   (b+sqrt(b^2-4*a*c))^(1/3))/(n*sqrt(b^2-4*a*c)*(b+sqrt(b^2-_
+   4*a*c))^(4/3))+2^(1/3)*c^(4/3)*log(2^(2/3)*c^(2/3)*x^(2/3*n)-_
+   2^(1/3)*c^(1/3)*x^(1/3*n)*(b+sqrt(b^2-4*a*c))^(1/3)+(b+_
+   sqrt(b^2-4*a*c))^(2/3))/(n*sqrt(b^2-4*a*c)*(b+sqrt(b^2-_
+   4*a*c))^(4/3))-2*2^(1/3)*c^(4/3)*atan((-4*c^(1/3)*x^(1/3*n)+_
+   2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+_
+   sqrt(b^2-4*a*c))^(1/3)))*sqrt(3)/(n*sqrt(b^2-4*a*c)*(b+_
+   sqrt(b^2-4*a*c))^(4/3))+6*c/(n*x^(1/3*n)*(b^2-4*a*c-b*_
+   sqrt(b^2-4*a*c)))+6*c/(n*x^(1/3*n)*(b^2-4*a*c+b*sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                  n      +--------------------+
+--R                  -      |   +-----------+
+--R             3+-+ 3 3+-+3|   |          2
+--R         2a c\|2 x  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2        n      +------------------+
+--R               | +-----------+              -      | +-----------+
+--R              3| |          2          3+-+ 3 3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - \|2 x  \|c \|\|- 4a c + b   + b
+--R            + 
+--R                    2n
+--R                    --
+--R              3+-+2  3 3+-+2
+--R              \|2  x   \|c
+--R     + 
+--R       -
+--R                     n      +--------------------+
+--R                     -      |   +-----------+
+--R                3+-+ 3 3+-+3|   |          2
+--R            4a c\|2 x  \|c \|- \|- 4a c + b   + b
+--R         *
+--R                 +------------------+        n
+--R                 | +-----------+             -
+--R                3| |          2         3+-+ 3 3+-+
+--R            log(\|\|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R                  n                                 n      +------------------+
+--R                  - +-----------+                   -      | +-----------+
+--R             3+-+ 3 |          2             2 3+-+ 3 3+-+3| |          2
+--R         (- b\|2 x \|- 4a c + b   + (2a c - b )\|2 x )\|c \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2        n      +--------------------+
+--R               |   +-----------+              -      |   +-----------+
+--R              3|   |          2          3+-+ 3 3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - \|2 x  \|c \|- \|- 4a c + b   + b
+--R            + 
+--R                    2n
+--R                    --
+--R              3+-+2  3 3+-+2
+--R              \|2  x   \|c
+--R     + 
+--R                 n                                    n
+--R                 - +-----------+                      -
+--R            3+-+ 3 |          2                2 3+-+ 3 3+-+
+--R         (2b\|2 x \|- 4a c + b   + (- 4a c + 2b )\|2 x )\|c
+--R      *
+--R          +------------------+     +--------------------+        n
+--R          | +-----------+          |   +-----------+             -
+--R         3| |          2          3|   |          2         3+-+ 3 3+-+
+--R         \|\|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R       -
+--R                         n      +--------------------+
+--R                         -      |   +-----------+
+--R                3+-+ +-+ 3 3+-+3|   |          2
+--R            4a c\|2 \|3 x  \|c \|- \|- 4a c + b   + b
+--R         *
+--R                        +------------------+    n
+--R                        | +-----------+         -
+--R                 3+-+2 3| |          2          3 3+-+
+--R                 \|2   \|\|- 4a c + b   + b - 4x  \|c
+--R            atan(------------------------------------)
+--R                              +------------------+
+--R                              | +-----------+
+--R                    3+-+2 +-+3| |          2
+--R                    \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                     n                                        n
+--R                     - +-----------+                          -
+--R            3+-+ +-+ 3 |          2                2 3+-+ +-+ 3 3+-+
+--R         (2b\|2 \|3 x \|- 4a c + b   + (- 4a c + 2b )\|2 \|3 x )\|c
+--R      *
+--R                                          +--------------------+    n
+--R          +------------------+            |   +-----------+         -
+--R          | +-----------+          3+-+2 3|   |          2          3 3+-+
+--R         3| |          2           \|2   \|- \|- 4a c + b   + b - 4x  \|c
+--R         \|\|- 4a c + b   + b atan(--------------------------------------)
+--R                                                +--------------------+
+--R                                                |   +-----------+
+--R                                      3+-+2 +-+3|   |          2
+--R                                      \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R               +-----------+                |   +-----------+
+--R               |          2              2 3|   |          2
+--R         (- 6b\|- 4a c + b   + 24a c - 6b )\|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                n                                    n  +--------------------+
+--R                - +-----------+                      -  |   +-----------+
+--R                3 |          2         2        2    3 3|   |          2
+--R       (2a b n x \|- 4a c + b   + (- 8a c + 2a b )n x )\|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R       3| |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1976
+
+--S 1977 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            a n
+--R         *
+--R            ROOT
+--R                                   +-------------------------------------------+
+--R                                   |    4 4      3 2 3      2 4 2       6     8
+--R                      5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                   (4a c - a b )n  |-------------------------------------------
+--R                                   |      11 3      10 2 2      9 4     8 6  6
+--R                                  \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                 + 
+--R                             3
+--R                   2a b c - b
+--R              /
+--R                    5      4 2  3
+--R                 (8a c - 2a b )n
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                             7   3      6 3 2      5 5     4 7  5
+--R                         (64a b c  - 48a b c  + 12a b c - a b )n
+--R                      *
+--R                          +-------------------------------------------+
+--R                          |    4 4      3 2 3      2 4 2       6     8
+--R                          |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-------------------------------------------
+--R                          |      11 3      10 2 2      9 4     8 6  6
+--R                         \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                     + 
+--R                           4 4      3 2 3      2 4 2        6     8  2
+--R                       (16a c  - 44a b c  + 34a b c  - 10a b c + b )n
+--R                  *
+--R                       ROOT
+--R                                   5     4 2  3
+--R                                (4a c - a b )n
+--R                             *
+--R                                 +-------------------------------------------+
+--R                                 |    4 4      3 2 3      2 4 2       6     8
+--R                                 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                                 |-------------------------------------------
+--R                                 |      11 3      10 2 2      9 4     8 6  6
+--R                                \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                            + 
+--R                                        3
+--R                              2a b c - b
+--R                         /
+--R                               5      4 2  3
+--R                            (8a c - 2a b )n
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                               6   3     5 3 2    4 5   4
+--R                         (- 16a b c  + 8a b c  - a b c)n x
+--R                      *
+--R                          +-------------------------------------------+
+--R                          |    4 4      3 2 3      2 4 2       6     8
+--R                          |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-------------------------------------------
+--R                          |      11 3      10 2 2      9 4     8 6  6
+--R                         \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                     + 
+--R                            3 4      2 2 3       4 2    6
+--R                       (- 8a c  + 18a b c  - 8a b c  + b c)n x
+--R                  *
+--R                       (- n - 3)log(x)
+--R                       ---------------
+--R                              3
+--R                     %e
+--R                  *
+--R                     ROOT
+--R                                 5     4 2  3
+--R                              (4a c - a b )n
+--R                           *
+--R                               +-------------------------------------------+
+--R                               |    4 4      3 2 3      2 4 2       6     8
+--R                               |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                               |-------------------------------------------
+--R                               |      11 3      10 2 2      9 4     8 6  6
+--R                              \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                          + 
+--R                                      3
+--R                            2a b c - b
+--R                       /
+--R                             5      4 2  3
+--R                          (8a c - 2a b )n
+--R                    ,
+--R                        3
+--R                 + 
+--R                                                 (- n - 3)log(x) 2
+--R                                                 ---------------
+--R                      2 4       2 3     4 2  2          3
+--R                   (4a c  - 8a b c  + 2b c )x (%e               )
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R         2a n
+--R      *
+--R         ROOT
+--R                                +-------------------------------------------+
+--R                                |    4 4      3 2 3      2 4 2       6     8
+--R                   5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                (4a c - a b )n  |-------------------------------------------
+--R                                |      11 3      10 2 2      9 4     8 6  6
+--R                               \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                 5      4 2  3
+--R              (8a c - 2a b )n
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                          6   2     5 3     4 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                       3 3      2 2 2       4     6
+--R                    (8a c  - 18a b c  + 8a b c - b )n
+--R               *
+--R                  ROOT
+--R                              5     4 2  3
+--R                           (4a c - a b )n
+--R                        *
+--R                            +-------------------------------------------+
+--R                            |    4 4      3 2 3      2 4 2       6     8
+--R                            |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-------------------------------------------
+--R                            |      11 3      10 2 2      9 4     8 6  6
+--R                           \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                          5      4 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                            (- n - 3)log(x)
+--R                                            ---------------
+--R                   2 3       2 2     4             3
+--R                (4a c  - 8a b c  + 2b c)x %e
+--R           /
+--R              x
+--R     + 
+--R         2a n
+--R      *
+--R         ROOT
+--R                                  +-------------------------------------------+
+--R                                  |    4 4      3 2 3      2 4 2       6     8
+--R                     5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                (- 4a c + a b )n  |-------------------------------------------
+--R                                  |      11 3      10 2 2      9 4     8 6  6
+--R                                 \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                 5      4 2  3
+--R              (8a c - 2a b )n
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                            6   2     5 3     4 5  4
+--R                      (- 16a b c  + 8a b c - a b )n
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                       3 3      2 2 2       4     6
+--R                    (8a c  - 18a b c  + 8a b c - b )n
+--R               *
+--R                  ROOT
+--R                                5     4 2  3
+--R                           (- 4a c + a b )n
+--R                        *
+--R                            +-------------------------------------------+
+--R                            |    4 4      3 2 3      2 4 2       6     8
+--R                            |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-------------------------------------------
+--R                            |      11 3      10 2 2      9 4     8 6  6
+--R                           \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                          5      4 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                            (- n - 3)log(x)
+--R                                            ---------------
+--R                   2 3       2 2     4             3
+--R                (4a c  - 8a b c  + 2b c)x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            a n
+--R         *
+--R            ROOT
+--R                          5     4 2  3
+--R                     (- 4a c + a b )n
+--R                  *
+--R                      +-------------------------------------------+
+--R                      |    4 4      3 2 3      2 4 2       6     8
+--R                      |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                      |-------------------------------------------
+--R                      |      11 3      10 2 2      9 4     8 6  6
+--R                     \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                 + 
+--R                             3
+--R                   2a b c - b
+--R              /
+--R                    5      4 2  3
+--R                 (8a c - 2a b )n
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                               7   3      6 3 2      5 5     4 7  5
+--R                         (- 64a b c  + 48a b c  - 12a b c + a b )n
+--R                      *
+--R                          +-------------------------------------------+
+--R                          |    4 4      3 2 3      2 4 2       6     8
+--R                          |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-------------------------------------------
+--R                          |      11 3      10 2 2      9 4     8 6  6
+--R                         \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                     + 
+--R                           4 4      3 2 3      2 4 2        6     8  2
+--R                       (16a c  - 44a b c  + 34a b c  - 10a b c + b )n
+--R                  *
+--R                       ROOT
+--R                                     5     4 2  3
+--R                                (- 4a c + a b )n
+--R                             *
+--R                                 +-------------------------------------------+
+--R                                 |    4 4      3 2 3      2 4 2       6     8
+--R                                 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                                 |-------------------------------------------
+--R                                 |      11 3      10 2 2      9 4     8 6  6
+--R                                \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                            + 
+--R                                        3
+--R                              2a b c - b
+--R                         /
+--R                               5      4 2  3
+--R                            (8a c - 2a b )n
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                             6   3     5 3 2    4 5   4
+--R                         (16a b c  - 8a b c  + a b c)n x
+--R                      *
+--R                          +-------------------------------------------+
+--R                          |    4 4      3 2 3      2 4 2       6     8
+--R                          |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-------------------------------------------
+--R                          |      11 3      10 2 2      9 4     8 6  6
+--R                         \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                     + 
+--R                            3 4      2 2 3       4 2    6
+--R                       (- 8a c  + 18a b c  - 8a b c  + b c)n x
+--R                  *
+--R                       (- n - 3)log(x)
+--R                       ---------------
+--R                              3
+--R                     %e
+--R                  *
+--R                     ROOT
+--R                                   5     4 2  3
+--R                              (- 4a c + a b )n
+--R                           *
+--R                               +-------------------------------------------+
+--R                               |    4 4      3 2 3      2 4 2       6     8
+--R                               |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                               |-------------------------------------------
+--R                               |      11 3      10 2 2      9 4     8 6  6
+--R                              \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                          + 
+--R                                      3
+--R                            2a b c - b
+--R                       /
+--R                             5      4 2  3
+--R                          (8a c - 2a b )n
+--R                    ,
+--R                        3
+--R                 + 
+--R                                                 (- n - 3)log(x) 2
+--R                                                 ---------------
+--R                      2 4       2 3     4 2  2          3
+--R                   (4a c  - 8a b c  + 2b c )x (%e               )
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R              +-+
+--R         2a n\|3
+--R      *
+--R         ROOT
+--R                                +-------------------------------------------+
+--R                                |    4 4      3 2 3      2 4 2       6     8
+--R                   5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                (4a c - a b )n  |-------------------------------------------
+--R                                |      11 3      10 2 2      9 4     8 6  6
+--R                               \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                 5      4 2  3
+--R              (8a c - 2a b )n
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                        6   2     5 3     4 5  4 +-+
+--R                    (16a b c  - 8a b c + a b )n \|3
+--R                 *
+--R                     +-------------------------------------------+
+--R                     |    4 4      3 2 3      2 4 2       6     8
+--R                     |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |-------------------------------------------
+--R                     |      11 3      10 2 2      9 4     8 6  6
+--R                    \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                + 
+--R                     3 3      2 2 2       4     6   +-+
+--R                  (8a c  - 18a b c  + 8a b c - b )n\|3
+--R             *
+--R                ROOT
+--R                            5     4 2  3
+--R                         (4a c - a b )n
+--R                      *
+--R                          +-------------------------------------------+
+--R                          |    4 4      3 2 3      2 4 2       6     8
+--R                          |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-------------------------------------------
+--R                          |      11 3      10 2 2      9 4     8 6  6
+--R                         \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                     + 
+--R                                 3
+--R                       2a b c - b
+--R                  /
+--R                        5      4 2  3
+--R                     (8a c - 2a b )n
+--R               ,
+--R                   3
+--R           /
+--R                          6   2     5 3     4 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                       3 3      2 2 2       4     6
+--R                    (8a c  - 18a b c  + 8a b c - b )n
+--R               *
+--R                  ROOT
+--R                              5     4 2  3
+--R                           (4a c - a b )n
+--R                        *
+--R                            +-------------------------------------------+
+--R                            |    4 4      3 2 3      2 4 2       6     8
+--R                            |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-------------------------------------------
+--R                            |      11 3      10 2 2      9 4     8 6  6
+--R                           \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                          5      4 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                               (- n - 3)log(x)
+--R                                               ---------------
+--R                     2 3        2 2     4             3
+--R                (- 8a c  + 16a b c  - 4b c)x %e
+--R     + 
+--R              +-+
+--R         2a n\|3
+--R      *
+--R         ROOT
+--R                                  +-------------------------------------------+
+--R                                  |    4 4      3 2 3      2 4 2       6     8
+--R                     5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                (- 4a c + a b )n  |-------------------------------------------
+--R                                  |      11 3      10 2 2      9 4     8 6  6
+--R                                 \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                 5      4 2  3
+--R              (8a c - 2a b )n
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                        6   2     5 3     4 5  4 +-+
+--R                    (16a b c  - 8a b c + a b )n \|3
+--R                 *
+--R                     +-------------------------------------------+
+--R                     |    4 4      3 2 3      2 4 2       6     8
+--R                     |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |-------------------------------------------
+--R                     |      11 3      10 2 2      9 4     8 6  6
+--R                    \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                + 
+--R                       3 3      2 2 2       4     6   +-+
+--R                  (- 8a c  + 18a b c  - 8a b c + b )n\|3
+--R             *
+--R                ROOT
+--R                              5     4 2  3
+--R                         (- 4a c + a b )n
+--R                      *
+--R                          +-------------------------------------------+
+--R                          |    4 4      3 2 3      2 4 2       6     8
+--R                          |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-------------------------------------------
+--R                          |      11 3      10 2 2      9 4     8 6  6
+--R                         \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                     + 
+--R                                 3
+--R                       2a b c - b
+--R                  /
+--R                        5      4 2  3
+--R                     (8a c - 2a b )n
+--R               ,
+--R                   3
+--R           /
+--R                          6   2     5 3     4 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                         3 3      2 2 2       4     6
+--R                    (- 8a c  + 18a b c  - 8a b c + b )n
+--R               *
+--R                  ROOT
+--R                                5     4 2  3
+--R                           (- 4a c + a b )n
+--R                        *
+--R                            +-------------------------------------------+
+--R                            |    4 4      3 2 3      2 4 2       6     8
+--R                            |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-------------------------------------------
+--R                            |      11 3      10 2 2      9 4     8 6  6
+--R                           \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                          5      4 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                             (- n - 3)log(x)
+--R                                             ---------------
+--R                   2 3        2 2     4             3
+--R                (8a c  - 16a b c  + 4b c)x %e
+--R     + 
+--R              (- n - 3)log(x)
+--R              ---------------
+--R                     3
+--R       - 6x %e
+--R  /
+--R     2a n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1977
+
+--S 1978 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   n                                 n  +--------------------+
+--R                   - +-----------+                   -  |   +-----------+
+--R                   3 |          2       2       2    3 3|   |          2
+--R         (- a b n x \|- 4a c + b   + (4a c - a b )n x )\|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                +-------------------------------------------+
+--R                                |    4 4      3 2 3      2 4 2       6     8
+--R                   5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                (4a c - a b )n  |-------------------------------------------
+--R                                |      11 3      10 2 2      9 4     8 6  6
+--R                               \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                 5      4 2  3
+--R              (8a c - 2a b )n
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                          7   3      6 3 2      5 5     4 7  5
+--R                      (64a b c  - 48a b c  + 12a b c - a b )n
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                        4 4      3 2 3      2 4 2        6     8  2
+--R                    (16a c  - 44a b c  + 34a b c  - 10a b c + b )n
+--R               *
+--R                    ROOT
+--R                                5     4 2  3
+--R                             (4a c - a b )n
+--R                          *
+--R                              +-------------------------------------------+
+--R                              |    4 4      3 2 3      2 4 2       6     8
+--R                              |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                              |-------------------------------------------
+--R                              |      11 3      10 2 2      9 4     8 6  6
+--R                             \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                         + 
+--R                                     3
+--R                           2a b c - b
+--R                      /
+--R                            5      4 2  3
+--R                         (8a c - 2a b )n
+--R                   ,
+--R                       3
+--R                 **
+--R                    2
+--R              + 
+--R                            6   3     5 3 2    4 5   4
+--R                      (- 16a b c  + 8a b c  - a b c)n x
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                         3 4      2 2 3       4 2    6
+--R                    (- 8a c  + 18a b c  - 8a b c  + b c)n x
+--R               *
+--R                    (- n - 3)log(x)
+--R                    ---------------
+--R                           3
+--R                  %e
+--R               *
+--R                  ROOT
+--R                              5     4 2  3
+--R                           (4a c - a b )n
+--R                        *
+--R                            +-------------------------------------------+
+--R                            |    4 4      3 2 3      2 4 2       6     8
+--R                            |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-------------------------------------------
+--R                            |      11 3      10 2 2      9 4     8 6  6
+--R                           \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                          5      4 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                              (- n - 3)log(x) 2
+--R                                              ---------------
+--R                   2 4       2 3     4 2  2          3
+--R                (4a c  - 8a b c  + 2b c )x (%e               )
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                  n                                    n  +--------------------+
+--R                  - +-----------+                      -  |   +-----------+
+--R                  3 |          2         2        2    3 3|   |          2
+--R         (2a b n x \|- 4a c + b   + (- 8a c + 2a b )n x )\|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                +-------------------------------------------+
+--R                                |    4 4      3 2 3      2 4 2       6     8
+--R                   5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                (4a c - a b )n  |-------------------------------------------
+--R                                |      11 3      10 2 2      9 4     8 6  6
+--R                               \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                 5      4 2  3
+--R              (8a c - 2a b )n
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                          6   2     5 3     4 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                       3 3      2 2 2       4     6
+--R                    (8a c  - 18a b c  + 8a b c - b )n
+--R               *
+--R                  ROOT
+--R                              5     4 2  3
+--R                           (4a c - a b )n
+--R                        *
+--R                            +-------------------------------------------+
+--R                            |    4 4      3 2 3      2 4 2       6     8
+--R                            |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-------------------------------------------
+--R                            |      11 3      10 2 2      9 4     8 6  6
+--R                           \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                          5      4 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                            (- n - 3)log(x)
+--R                                            ---------------
+--R                   2 3       2 2     4             3
+--R                (4a c  - 8a b c  + 2b c)x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                     n      +--------------------+
+--R                     -      |   +-----------+
+--R                3+-+ 3 3+-+3|   |          2
+--R            2a c\|2 x  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +------------------+2        n      +------------------+
+--R                  | +-----------+              -      | +-----------+
+--R                 3| |          2          3+-+ 3 3+-+3| |          2
+--R                 \|\|- 4a c + b   + b   - \|2 x  \|c \|\|- 4a c + b   + b
+--R               + 
+--R                       2n
+--R                       --
+--R                 3+-+2  3 3+-+2
+--R                 \|2  x   \|c
+--R     + 
+--R                  n      +--------------------+
+--R                  -      |   +-----------+
+--R             3+-+ 3 3+-+3|   |          2
+--R         4a c\|2 x  \|c \|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+        n
+--R              | +-----------+             -
+--R             3| |          2         3+-+ 3 3+-+
+--R         log(\|\|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R                n                                   n      +------------------+
+--R                - +-----------+                     -      | +-----------+
+--R           3+-+ 3 |          2               2 3+-+ 3 3+-+3| |          2
+--R         (b\|2 x \|- 4a c + b   + (- 2a c + b )\|2 x )\|c \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2        n      +--------------------+
+--R               |   +-----------+              -      |   +-----------+
+--R              3|   |          2          3+-+ 3 3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - \|2 x  \|c \|- \|- 4a c + b   + b
+--R            + 
+--R                    2n
+--R                    --
+--R              3+-+2  3 3+-+2
+--R              \|2  x   \|c
+--R     + 
+--R                   n                                  n
+--R                   - +-----------+                    -
+--R              3+-+ 3 |          2              2 3+-+ 3 3+-+
+--R         (- 2b\|2 x \|- 4a c + b   + (4a c - 2b )\|2 x )\|c
+--R      *
+--R          +------------------+     +--------------------+        n
+--R          | +-----------+          |   +-----------+             -
+--R         3| |          2          3|   |          2         3+-+ 3 3+-+
+--R         \|\|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R                      n      +--------------------+
+--R                      -      |   +-----------+
+--R             3+-+ +-+ 3 3+-+3|   |          2
+--R         4a c\|2 \|3 x  \|c \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+    n
+--R                     | +-----------+         -
+--R              3+-+2 3| |          2          3 3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x  \|c
+--R         atan(------------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                  n                                    n
+--R                  - +-----------+                      -
+--R                  3 |          2         2        2    3
+--R         (2a b n x \|- 4a c + b   + (- 8a c + 2a b )n x )
+--R      *
+--R         ROOT
+--R                                  +-------------------------------------------+
+--R                                  |    4 4      3 2 3      2 4 2       6     8
+--R                     5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                (- 4a c + a b )n  |-------------------------------------------
+--R                                  |      11 3      10 2 2      9 4     8 6  6
+--R                                 \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                 5      4 2  3
+--R              (8a c - 2a b )n
+--R        ,
+--R            3
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         3|   |          2      3| |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            6   2     5 3     4 5  4
+--R                      (- 16a b c  + 8a b c - a b )n
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                       3 3      2 2 2       4     6
+--R                    (8a c  - 18a b c  + 8a b c - b )n
+--R               *
+--R                  ROOT
+--R                                5     4 2  3
+--R                           (- 4a c + a b )n
+--R                        *
+--R                            +-------------------------------------------+
+--R                            |    4 4      3 2 3      2 4 2       6     8
+--R                            |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-------------------------------------------
+--R                            |      11 3      10 2 2      9 4     8 6  6
+--R                           \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                          5      4 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                            (- n - 3)log(x)
+--R                                            ---------------
+--R                   2 3       2 2     4             3
+--R                (4a c  - 8a b c  + 2b c)x %e
+--R           /
+--R              x
+--R     + 
+--R                   n                                 n
+--R                   - +-----------+                   -
+--R                   3 |          2       2       2    3
+--R         (- a b n x \|- 4a c + b   + (4a c - a b )n x )
+--R      *
+--R         ROOT
+--R                                  +-------------------------------------------+
+--R                                  |    4 4      3 2 3      2 4 2       6     8
+--R                     5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                (- 4a c + a b )n  |-------------------------------------------
+--R                                  |      11 3      10 2 2      9 4     8 6  6
+--R                                 \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                 5      4 2  3
+--R              (8a c - 2a b )n
+--R        ,
+--R            3
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         3|   |          2      3| |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            7   3      6 3 2      5 5     4 7  5
+--R                      (- 64a b c  + 48a b c  - 12a b c + a b )n
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                        4 4      3 2 3      2 4 2        6     8  2
+--R                    (16a c  - 44a b c  + 34a b c  - 10a b c + b )n
+--R               *
+--R                    ROOT
+--R                                  5     4 2  3
+--R                             (- 4a c + a b )n
+--R                          *
+--R                              +-------------------------------------------+
+--R                              |    4 4      3 2 3      2 4 2       6     8
+--R                              |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                              |-------------------------------------------
+--R                              |      11 3      10 2 2      9 4     8 6  6
+--R                             \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                         + 
+--R                                     3
+--R                           2a b c - b
+--R                      /
+--R                            5      4 2  3
+--R                         (8a c - 2a b )n
+--R                   ,
+--R                       3
+--R                 **
+--R                    2
+--R              + 
+--R                          6   3     5 3 2    4 5   4
+--R                      (16a b c  - 8a b c  + a b c)n x
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                         3 4      2 2 3       4 2    6
+--R                    (- 8a c  + 18a b c  - 8a b c  + b c)n x
+--R               *
+--R                    (- n - 3)log(x)
+--R                    ---------------
+--R                           3
+--R                  %e
+--R               *
+--R                  ROOT
+--R                                5     4 2  3
+--R                           (- 4a c + a b )n
+--R                        *
+--R                            +-------------------------------------------+
+--R                            |    4 4      3 2 3      2 4 2       6     8
+--R                            |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-------------------------------------------
+--R                            |      11 3      10 2 2      9 4     8 6  6
+--R                           \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                          5      4 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                              (- n - 3)log(x) 2
+--R                                              ---------------
+--R                   2 4       2 3     4 2  2          3
+--R                (4a c  - 8a b c  + 2b c )x (%e               )
+--R           /
+--R               2
+--R              x
+--R     + 
+--R                       n                                      n
+--R                       - +-----------+                        -
+--R              3+-+ +-+ 3 |          2              2 3+-+ +-+ 3 3+-+
+--R         (- 2b\|2 \|3 x \|- 4a c + b   + (4a c - 2b )\|2 \|3 x )\|c
+--R      *
+--R                                          +--------------------+    n
+--R          +------------------+            |   +-----------+         -
+--R          | +-----------+          3+-+2 3|   |          2          3 3+-+
+--R         3| |          2           \|2   \|- \|- 4a c + b   + b - 4x  \|c
+--R         \|\|- 4a c + b   + b atan(--------------------------------------)
+--R                                                +--------------------+
+--R                                                |   +-----------+
+--R                                      3+-+2 +-+3|   |          2
+--R                                      \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                     n                                       n
+--R                     - +-----------+                         -
+--R                 +-+ 3 |          2         2        2   +-+ 3
+--R         (2a b n\|3 x \|- 4a c + b   + (- 8a c + 2a b )n\|3 x )
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         3|   |          2      3| |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                +-------------------------------------------+
+--R                                |    4 4      3 2 3      2 4 2       6     8
+--R                   5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                (4a c - a b )n  |-------------------------------------------
+--R                                |      11 3      10 2 2      9 4     8 6  6
+--R                               \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                 5      4 2  3
+--R              (8a c - 2a b )n
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                        6   2     5 3     4 5  4 +-+
+--R                    (16a b c  - 8a b c + a b )n \|3
+--R                 *
+--R                     +-------------------------------------------+
+--R                     |    4 4      3 2 3      2 4 2       6     8
+--R                     |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |-------------------------------------------
+--R                     |      11 3      10 2 2      9 4     8 6  6
+--R                    \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                + 
+--R                     3 3      2 2 2       4     6   +-+
+--R                  (8a c  - 18a b c  + 8a b c - b )n\|3
+--R             *
+--R                ROOT
+--R                            5     4 2  3
+--R                         (4a c - a b )n
+--R                      *
+--R                          +-------------------------------------------+
+--R                          |    4 4      3 2 3      2 4 2       6     8
+--R                          |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-------------------------------------------
+--R                          |      11 3      10 2 2      9 4     8 6  6
+--R                         \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                     + 
+--R                                 3
+--R                       2a b c - b
+--R                  /
+--R                        5      4 2  3
+--R                     (8a c - 2a b )n
+--R               ,
+--R                   3
+--R           /
+--R                          6   2     5 3     4 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                       3 3      2 2 2       4     6
+--R                    (8a c  - 18a b c  + 8a b c - b )n
+--R               *
+--R                  ROOT
+--R                              5     4 2  3
+--R                           (4a c - a b )n
+--R                        *
+--R                            +-------------------------------------------+
+--R                            |    4 4      3 2 3      2 4 2       6     8
+--R                            |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-------------------------------------------
+--R                            |      11 3      10 2 2      9 4     8 6  6
+--R                           \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                          5      4 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                               (- n - 3)log(x)
+--R                                               ---------------
+--R                     2 3        2 2     4             3
+--R                (- 8a c  + 16a b c  - 4b c)x %e
+--R     + 
+--R                     n                                       n
+--R                     - +-----------+                         -
+--R                 +-+ 3 |          2         2        2   +-+ 3
+--R         (2a b n\|3 x \|- 4a c + b   + (- 8a c + 2a b )n\|3 x )
+--R      *
+--R         ROOT
+--R                                  +-------------------------------------------+
+--R                                  |    4 4      3 2 3      2 4 2       6     8
+--R                     5     4 2  3 |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                (- 4a c + a b )n  |-------------------------------------------
+--R                                  |      11 3      10 2 2      9 4     8 6  6
+--R                                 \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R              + 
+--R                          3
+--R                2a b c - b
+--R           /
+--R                 5      4 2  3
+--R              (8a c - 2a b )n
+--R        ,
+--R            3
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         3|   |          2      3| |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                        6   2     5 3     4 5  4 +-+
+--R                    (16a b c  - 8a b c + a b )n \|3
+--R                 *
+--R                     +-------------------------------------------+
+--R                     |    4 4      3 2 3      2 4 2       6     8
+--R                     |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                     |-------------------------------------------
+--R                     |      11 3      10 2 2      9 4     8 6  6
+--R                    \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                + 
+--R                       3 3      2 2 2       4     6   +-+
+--R                  (- 8a c  + 18a b c  - 8a b c + b )n\|3
+--R             *
+--R                ROOT
+--R                              5     4 2  3
+--R                         (- 4a c + a b )n
+--R                      *
+--R                          +-------------------------------------------+
+--R                          |    4 4      3 2 3      2 4 2       6     8
+--R                          |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                          |-------------------------------------------
+--R                          |      11 3      10 2 2      9 4     8 6  6
+--R                         \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                     + 
+--R                                 3
+--R                       2a b c - b
+--R                  /
+--R                        5      4 2  3
+--R                     (8a c - 2a b )n
+--R               ,
+--R                   3
+--R           /
+--R                          6   2     5 3     4 5  4
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +-------------------------------------------+
+--R                       |    4 4      3 2 3      2 4 2       6     8
+--R                       |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                       |-------------------------------------------
+--R                       |      11 3      10 2 2      9 4     8 6  6
+--R                      \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                  + 
+--R                         3 3      2 2 2       4     6
+--R                    (- 8a c  + 18a b c  - 8a b c + b )n
+--R               *
+--R                  ROOT
+--R                                5     4 2  3
+--R                           (- 4a c + a b )n
+--R                        *
+--R                            +-------------------------------------------+
+--R                            |    4 4      3 2 3      2 4 2       6     8
+--R                            |- 4a c  + 16a b c  - 20a b c  + 8a b c - b
+--R                            |-------------------------------------------
+--R                            |      11 3      10 2 2      9 4     8 6  6
+--R                           \|  (64a  c  - 48a  b c  + 12a b c - a b )n
+--R                       + 
+--R                                   3
+--R                         2a b c - b
+--R                    /
+--R                          5      4 2  3
+--R                       (8a c - 2a b )n
+--R                 ,
+--R                     3
+--R              + 
+--R                                             (- n - 3)log(x)
+--R                                             ---------------
+--R                   2 3        2 2     4             3
+--R                (8a c  - 16a b c  + 4b c)x %e
+--R     + 
+--R                    n                                 n   (- n - 3)log(x)
+--R                    - +-----------+                   -   ---------------
+--R                    3 |          2               2    3          3
+--R           (- 6b x x \|- 4a c + b   + (24a c - 6b )x x )%e
+--R         + 
+--R              +-----------+
+--R              |          2              2
+--R           6b\|- 4a c + b   - 24a c + 6b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         3|   |          2      3| |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                n                                    n  +--------------------+
+--R                - +-----------+                      -  |   +-----------+
+--R                3 |          2         2        2    3 3|   |          2
+--R       (2a b n x \|- 4a c + b   + (- 8a c + 2a b )n x )\|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R       3| |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1978
+
+--S 1979 of 2282
+--d0:=normalize(D(m0,x))
+--E 1979
+
+)clear all
+
+--S 1980 of 2282
+t0:=x^(-1-1/4*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - n - 4
+--R             -------
+--R                4
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1980
+
+--S 1981 of 2282
+r0:=-4*2^(1/4)*c^(5/4)*atan(2^(1/4)*c^(1/4)*x^(1/4*n)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))/(n*(-b-sqrt(b^2-4*a*c))^(5/4)*_
+   sqrt(b^2-4*a*c))+4*2^(1/4)*c^(5/4)*atanh(2^(1/4)*c^(1/4)*x^(1/4*n)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))/(n*(-b-sqrt(b^2-4*a*c))^(5/4)*_
+   sqrt(b^2-4*a*c))+4*2^(1/4)*c^(5/4)*atan(2^(1/4)*c^(1/4)*x^(1/4*n)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))/(n*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(5/4))-4*2^(1/4)*c^(5/4)*atanh(2^(1/4)*_
+   c^(1/4)*x^(1/4*n)/(-b+sqrt(b^2-4*a*c))^(1/4))/(n*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(5/4))+8*c/(n*x^(1/4*n)*(b^2-4*a*c-_
+   b*sqrt(b^2-4*a*c)))+8*c/(n*x^(1/4*n)*(b^2-4*a*c+b*sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                n                                 n      +------------------+
+--R                - +-----------+                   -      | +-----------+
+--R           4+-+ 4 |          2             2 4+-+ 4 4+-+4| |          2
+--R         (b\|2 x \|- 4a c + b   + (4a c - b )\|2 x )\|c \|\|- 4a c + b   - b
+--R      *
+--R                           n
+--R                           -
+--R                      4+-+ 4 4+-+
+--R                      \|2 x  \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                  n                                 n
+--R                  - +-----------+                   -
+--R             4+-+ 4 |          2             2 4+-+ 4 4+-+
+--R         (- b\|2 x \|- 4a c + b   + (4a c - b )\|2 x )\|c
+--R      *
+--R                                                 n
+--R          +--------------------+                 -
+--R          |   +-----------+                 4+-+ 4 4+-+
+--R         4|   |          2                  \|2 x  \|c
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                  n                                   n
+--R                  - +-----------+                     -
+--R             4+-+ 4 |          2               2 4+-+ 4 4+-+
+--R         (- b\|2 x \|- 4a c + b   + (- 4a c + b )\|2 x )\|c
+--R      *
+--R                                               n
+--R          +------------------+                 -
+--R          | +-----------+                 4+-+ 4 4+-+
+--R         4| |          2                  \|2 x  \|c
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                n                                   n
+--R                - +-----------+                     -
+--R           4+-+ 4 |          2               2 4+-+ 4 4+-+
+--R         (b\|2 x \|- 4a c + b   + (- 4a c + b )\|2 x )\|c
+--R      *
+--R                                                n
+--R          +--------------------+                -
+--R          |   +-----------+                4+-+ 4 4+-+
+--R         4|   |          2                 \|2 x  \|c
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                       +--------------------+ +------------------+
+--R                       |   +-----------+      | +-----------+
+--R                    2 4|   |          2      4| |          2
+--R       (- 16a c + 4b )\|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                     n  +--------------------+ +------------------+
+--R                     -  |   +-----------+      | +-----------+
+--R        2       2    4 4|   |          2      4| |          2
+--R     (4a c - a b )n x  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1981
+
+--S 1982 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            a n
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                              7 2      6 2      5 4  4
+--R                          (32a c  - 16a b c + 2a b )n
+--R                       *
+--R                           +------------------------------------------+
+--R                           |    4 4     3 2 3      2 4 2       6     8
+--R                           | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |------------------------------------------
+--R                           |    13 3      12 2 2      11 4     10 6  8
+--R                          \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                      + 
+--R                             2   2        3      5
+--R                        - 10a b c  + 10a b c - 2b
+--R                   /
+--R                          7 2     6 2     5 4  4
+--R                      (16a c  - 8a b c + a b )n
+--R         *
+--R            log
+--R                             7   2     6 3     5 5  5
+--R                         (16a b c  - 8a b c + a b )n
+--R                      *
+--R                          +------------------------------------------+
+--R                          |    4 4     3 2 3      2 4 2       6     8
+--R                          | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |------------------------------------------
+--R                          |    13 3      12 2 2      11 4     10 6  8
+--R                         \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                     + 
+--R                            3 3      2 2 2       4     6
+--R                       (- 4a c  + 13a b c  - 7a b c + b )n
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                       7 2      6 2      5 4  4
+--R                                   (32a c  - 16a b c + 2a b )n
+--R                                *
+--R                                  +------------------------------------------+
+--R                                  |    4 4     3 2 3      2 4 2       6     8
+--R                                  | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                  |------------------------------------------
+--R                                  |    13 3      12 2 2      11 4     10 6  8
+--R                                 \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                               + 
+--R                                      2   2        3      5
+--R                                 - 10a b c  + 10a b c - 2b
+--R                            /
+--R                                   7 2     6 2     5 4  4
+--R                               (16a c  - 8a b c + a b )n
+--R                 + 
+--R                                                (- n - 4)log(x)
+--R                                                ---------------
+--R                      2 3        2 2     4             4
+--R                   (4a c  - 12a b c  + 4b c)x %e
+--R              /
+--R                 x
+--R     + 
+--R         a n
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2      6 2      5 4  4
+--R                       (- 32a c  + 16a b c - 2a b )n
+--R                    *
+--R                        +------------------------------------------+
+--R                        |    4 4     3 2 3      2 4 2       6     8
+--R                        | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |------------------------------------------
+--R                        |    13 3      12 2 2      11 4     10 6  8
+--R                       \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                   + 
+--R                          2   2        3      5
+--R                     - 10a b c  + 10a b c - 2b
+--R                /
+--R                       7 2     6 2     5 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         log
+--R                          7   2     6 3     5 5  5
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +------------------------------------------+
+--R                       |    4 4     3 2 3      2 4 2       6     8
+--R                       | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                       |------------------------------------------
+--R                       |    13 3      12 2 2      11 4     10 6  8
+--R                      \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                  + 
+--R                       3 3      2 2 2       4     6
+--R                    (4a c  - 13a b c  + 7a b c - b )n
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      7 2      6 2      5 4  4
+--R                                (- 32a c  + 16a b c - 2a b )n
+--R                             *
+--R                                 +------------------------------------------+
+--R                                 |    4 4     3 2 3      2 4 2       6     8
+--R                                 | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                 |------------------------------------------
+--R                                 |    13 3      12 2 2      11 4     10 6  8
+--R                                \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                            + 
+--R                                   2   2        3      5
+--R                              - 10a b c  + 10a b c - 2b
+--R                         /
+--R                                7 2     6 2     5 4  4
+--R                            (16a c  - 8a b c + a b )n
+--R              + 
+--R                                             (- n - 4)log(x)
+--R                                             ---------------
+--R                   2 3        2 2     4             4
+--R                (4a c  - 12a b c  + 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            a n
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                7 2      6 2      5 4  4
+--R                          (- 32a c  + 16a b c - 2a b )n
+--R                       *
+--R                           +------------------------------------------+
+--R                           |    4 4     3 2 3      2 4 2       6     8
+--R                           | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |------------------------------------------
+--R                           |    13 3      12 2 2      11 4     10 6  8
+--R                          \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                      + 
+--R                             2   2        3      5
+--R                        - 10a b c  + 10a b c - 2b
+--R                   /
+--R                          7 2     6 2     5 4  4
+--R                      (16a c  - 8a b c + a b )n
+--R         *
+--R            log
+--R                               7   2     6 3     5 5  5
+--R                         (- 16a b c  + 8a b c - a b )n
+--R                      *
+--R                          +------------------------------------------+
+--R                          |    4 4     3 2 3      2 4 2       6     8
+--R                          | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |------------------------------------------
+--R                          |    13 3      12 2 2      11 4     10 6  8
+--R                         \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                     + 
+--R                            3 3      2 2 2       4     6
+--R                       (- 4a c  + 13a b c  - 7a b c + b )n
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         7 2      6 2      5 4  4
+--R                                   (- 32a c  + 16a b c - 2a b )n
+--R                                *
+--R                                  +------------------------------------------+
+--R                                  |    4 4     3 2 3      2 4 2       6     8
+--R                                  | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                  |------------------------------------------
+--R                                  |    13 3      12 2 2      11 4     10 6  8
+--R                                 \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                               + 
+--R                                      2   2        3      5
+--R                                 - 10a b c  + 10a b c - 2b
+--R                            /
+--R                                   7 2     6 2     5 4  4
+--R                               (16a c  - 8a b c + a b )n
+--R                 + 
+--R                                                (- n - 4)log(x)
+--R                                                ---------------
+--R                      2 3        2 2     4             4
+--R                   (4a c  - 12a b c  + 4b c)x %e
+--R              /
+--R                 x
+--R     + 
+--R         a n
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           7 2      6 2      5 4  4
+--R                       (32a c  - 16a b c + 2a b )n
+--R                    *
+--R                        +------------------------------------------+
+--R                        |    4 4     3 2 3      2 4 2       6     8
+--R                        | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |------------------------------------------
+--R                        |    13 3      12 2 2      11 4     10 6  8
+--R                       \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                   + 
+--R                          2   2        3      5
+--R                     - 10a b c  + 10a b c - 2b
+--R                /
+--R                       7 2     6 2     5 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         log
+--R                            7   2     6 3     5 5  5
+--R                      (- 16a b c  + 8a b c - a b )n
+--R                   *
+--R                       +------------------------------------------+
+--R                       |    4 4     3 2 3      2 4 2       6     8
+--R                       | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                       |------------------------------------------
+--R                       |    13 3      12 2 2      11 4     10 6  8
+--R                      \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                  + 
+--R                       3 3      2 2 2       4     6
+--R                    (4a c  - 13a b c  + 7a b c - b )n
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                    7 2      6 2      5 4  4
+--R                                (32a c  - 16a b c + 2a b )n
+--R                             *
+--R                                 +------------------------------------------+
+--R                                 |    4 4     3 2 3      2 4 2       6     8
+--R                                 | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                 |------------------------------------------
+--R                                 |    13 3      12 2 2      11 4     10 6  8
+--R                                \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                            + 
+--R                                   2   2        3      5
+--R                              - 10a b c  + 10a b c - 2b
+--R                         /
+--R                                7 2     6 2     5 4  4
+--R                            (16a c  - 8a b c + a b )n
+--R              + 
+--R                                             (- n - 4)log(x)
+--R                                             ---------------
+--R                   2 3        2 2     4             4
+--R                (4a c  - 12a b c  + 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R         2a n
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           7 2      6 2      5 4  4
+--R                       (32a c  - 16a b c + 2a b )n
+--R                    *
+--R                        +------------------------------------------+
+--R                        |    4 4     3 2 3      2 4 2       6     8
+--R                        | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |------------------------------------------
+--R                        |    13 3      12 2 2      11 4     10 6  8
+--R                       \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                   + 
+--R                          2   2        3      5
+--R                     - 10a b c  + 10a b c - 2b
+--R                /
+--R                       7 2     6 2     5 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         atan
+--R                        7   2     6 3     5 5  5
+--R                    (16a b c  - 8a b c + a b )n
+--R                 *
+--R                     +------------------------------------------+
+--R                     |    4 4     3 2 3      2 4 2       6     8
+--R                     | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |------------------------------------------
+--R                     |    13 3      12 2 2      11 4     10 6  8
+--R                    \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                + 
+--R                       3 3      2 2 2       4     6
+--R                  (- 4a c  + 13a b c  - 7a b c + b )n
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                  7 2      6 2      5 4  4
+--R                              (32a c  - 16a b c + 2a b )n
+--R                           *
+--R                               +------------------------------------------+
+--R                               |    4 4     3 2 3      2 4 2       6     8
+--R                               | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                               |------------------------------------------
+--R                               |    13 3      12 2 2      11 4     10 6  8
+--R                              \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                          + 
+--R                                 2   2        3      5
+--R                            - 10a b c  + 10a b c - 2b
+--R                       /
+--R                              7 2     6 2     5 4  4
+--R                          (16a c  - 8a b c + a b )n
+--R           /
+--R                                           (- n - 4)log(x)
+--R                                           ---------------
+--R                 2 3        2 2     4             4
+--R              (4a c  - 12a b c  + 4b c)x %e
+--R     + 
+--R       -
+--R            2a n
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                7 2      6 2      5 4  4
+--R                          (- 32a c  + 16a b c - 2a b )n
+--R                       *
+--R                           +------------------------------------------+
+--R                           |    4 4     3 2 3      2 4 2       6     8
+--R                           | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                           |------------------------------------------
+--R                           |    13 3      12 2 2      11 4     10 6  8
+--R                          \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                      + 
+--R                             2   2        3      5
+--R                        - 10a b c  + 10a b c - 2b
+--R                   /
+--R                          7 2     6 2     5 4  4
+--R                      (16a c  - 8a b c + a b )n
+--R         *
+--R            atan
+--R                           7   2     6 3     5 5  5
+--R                       (16a b c  - 8a b c + a b )n
+--R                    *
+--R                        +------------------------------------------+
+--R                        |    4 4     3 2 3      2 4 2       6     8
+--R                        | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |------------------------------------------
+--R                        |    13 3      12 2 2      11 4     10 6  8
+--R                       \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                   + 
+--R                        3 3      2 2 2       4     6
+--R                     (4a c  - 13a b c  + 7a b c - b )n
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       7 2      6 2      5 4  4
+--R                                 (- 32a c  + 16a b c - 2a b )n
+--R                              *
+--R                                  +------------------------------------------+
+--R                                  |    4 4     3 2 3      2 4 2       6     8
+--R                                  | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                  |------------------------------------------
+--R                                  |    13 3      12 2 2      11 4     10 6  8
+--R                                 \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                             + 
+--R                                    2   2        3      5
+--R                               - 10a b c  + 10a b c - 2b
+--R                          /
+--R                                 7 2     6 2     5 4  4
+--R                             (16a c  - 8a b c + a b )n
+--R              /
+--R                                              (- n - 4)log(x)
+--R                                              ---------------
+--R                    2 3        2 2     4             4
+--R                 (4a c  - 12a b c  + 4b c)x %e
+--R     + 
+--R              (- n - 4)log(x)
+--R              ---------------
+--R                     4
+--R       - 8x %e
+--R  /
+--R     2a n
+--R                                         Type: Union(Expression(Integer),...)
+--E 1982
+
+--S 1983 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           n  +--------------------+ +------------------+
+--R                           -  |   +-----------+      | +-----------+
+--R              2       2    4 4|   |          2      4| |          2
+--R         (- 4a c + a b )n x  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           7 2      6 2      5 4  4
+--R                       (32a c  - 16a b c + 2a b )n
+--R                    *
+--R                        +------------------------------------------+
+--R                        |    4 4     3 2 3      2 4 2       6     8
+--R                        | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |------------------------------------------
+--R                        |    13 3      12 2 2      11 4     10 6  8
+--R                       \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                   + 
+--R                          2   2        3      5
+--R                     - 10a b c  + 10a b c - 2b
+--R                /
+--R                       7 2     6 2     5 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         log
+--R                          7   2     6 3     5 5  5
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +------------------------------------------+
+--R                       |    4 4     3 2 3      2 4 2       6     8
+--R                       | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                       |------------------------------------------
+--R                       |    13 3      12 2 2      11 4     10 6  8
+--R                      \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                  + 
+--R                         3 3      2 2 2       4     6
+--R                    (- 4a c  + 13a b c  - 7a b c + b )n
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                    7 2      6 2      5 4  4
+--R                                (32a c  - 16a b c + 2a b )n
+--R                             *
+--R                                 +------------------------------------------+
+--R                                 |    4 4     3 2 3      2 4 2       6     8
+--R                                 | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                 |------------------------------------------
+--R                                 |    13 3      12 2 2      11 4     10 6  8
+--R                                \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                            + 
+--R                                   2   2        3      5
+--R                              - 10a b c  + 10a b c - 2b
+--R                         /
+--R                                7 2     6 2     5 4  4
+--R                            (16a c  - 8a b c + a b )n
+--R              + 
+--R                                             (- n - 4)log(x)
+--R                                             ---------------
+--R                   2 3        2 2     4             4
+--R                (4a c  - 12a b c  + 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R                         n  +--------------------+ +------------------+
+--R                         -  |   +-----------+      | +-----------+
+--R            2       2    4 4|   |          2      4| |          2
+--R         (4a c - a b )n x  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2      6 2      5 4  4
+--R                       (- 32a c  + 16a b c - 2a b )n
+--R                    *
+--R                        +------------------------------------------+
+--R                        |    4 4     3 2 3      2 4 2       6     8
+--R                        | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |------------------------------------------
+--R                        |    13 3      12 2 2      11 4     10 6  8
+--R                       \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                   + 
+--R                          2   2        3      5
+--R                     - 10a b c  + 10a b c - 2b
+--R                /
+--R                       7 2     6 2     5 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         log
+--R                          7   2     6 3     5 5  5
+--R                      (16a b c  - 8a b c + a b )n
+--R                   *
+--R                       +------------------------------------------+
+--R                       |    4 4     3 2 3      2 4 2       6     8
+--R                       | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                       |------------------------------------------
+--R                       |    13 3      12 2 2      11 4     10 6  8
+--R                      \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                  + 
+--R                       3 3      2 2 2       4     6
+--R                    (4a c  - 13a b c  + 7a b c - b )n
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      7 2      6 2      5 4  4
+--R                                (- 32a c  + 16a b c - 2a b )n
+--R                             *
+--R                                 +------------------------------------------+
+--R                                 |    4 4     3 2 3      2 4 2       6     8
+--R                                 | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                 |------------------------------------------
+--R                                 |    13 3      12 2 2      11 4     10 6  8
+--R                                \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                            + 
+--R                                   2   2        3      5
+--R                              - 10a b c  + 10a b c - 2b
+--R                         /
+--R                                7 2     6 2     5 4  4
+--R                            (16a c  - 8a b c + a b )n
+--R              + 
+--R                                             (- n - 4)log(x)
+--R                                             ---------------
+--R                   2 3        2 2     4             4
+--R                (4a c  - 12a b c  + 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R                           n  +--------------------+ +------------------+
+--R                           -  |   +-----------+      | +-----------+
+--R              2       2    4 4|   |          2      4| |          2
+--R         (- 4a c + a b )n x  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2      6 2      5 4  4
+--R                       (- 32a c  + 16a b c - 2a b )n
+--R                    *
+--R                        +------------------------------------------+
+--R                        |    4 4     3 2 3      2 4 2       6     8
+--R                        | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |------------------------------------------
+--R                        |    13 3      12 2 2      11 4     10 6  8
+--R                       \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                   + 
+--R                          2   2        3      5
+--R                     - 10a b c  + 10a b c - 2b
+--R                /
+--R                       7 2     6 2     5 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         log
+--R                            7   2     6 3     5 5  5
+--R                      (- 16a b c  + 8a b c - a b )n
+--R                   *
+--R                       +------------------------------------------+
+--R                       |    4 4     3 2 3      2 4 2       6     8
+--R                       | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                       |------------------------------------------
+--R                       |    13 3      12 2 2      11 4     10 6  8
+--R                      \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                  + 
+--R                         3 3      2 2 2       4     6
+--R                    (- 4a c  + 13a b c  - 7a b c + b )n
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      7 2      6 2      5 4  4
+--R                                (- 32a c  + 16a b c - 2a b )n
+--R                             *
+--R                                 +------------------------------------------+
+--R                                 |    4 4     3 2 3      2 4 2       6     8
+--R                                 | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                 |------------------------------------------
+--R                                 |    13 3      12 2 2      11 4     10 6  8
+--R                                \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                            + 
+--R                                   2   2        3      5
+--R                              - 10a b c  + 10a b c - 2b
+--R                         /
+--R                                7 2     6 2     5 4  4
+--R                            (16a c  - 8a b c + a b )n
+--R              + 
+--R                                             (- n - 4)log(x)
+--R                                             ---------------
+--R                   2 3        2 2     4             4
+--R                (4a c  - 12a b c  + 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R                         n  +--------------------+ +------------------+
+--R                         -  |   +-----------+      | +-----------+
+--R            2       2    4 4|   |          2      4| |          2
+--R         (4a c - a b )n x  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           7 2      6 2      5 4  4
+--R                       (32a c  - 16a b c + 2a b )n
+--R                    *
+--R                        +------------------------------------------+
+--R                        |    4 4     3 2 3      2 4 2       6     8
+--R                        | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |------------------------------------------
+--R                        |    13 3      12 2 2      11 4     10 6  8
+--R                       \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                   + 
+--R                          2   2        3      5
+--R                     - 10a b c  + 10a b c - 2b
+--R                /
+--R                       7 2     6 2     5 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         log
+--R                            7   2     6 3     5 5  5
+--R                      (- 16a b c  + 8a b c - a b )n
+--R                   *
+--R                       +------------------------------------------+
+--R                       |    4 4     3 2 3      2 4 2       6     8
+--R                       | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                       |------------------------------------------
+--R                       |    13 3      12 2 2      11 4     10 6  8
+--R                      \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                  + 
+--R                       3 3      2 2 2       4     6
+--R                    (4a c  - 13a b c  + 7a b c - b )n
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                    7 2      6 2      5 4  4
+--R                                (32a c  - 16a b c + 2a b )n
+--R                             *
+--R                                 +------------------------------------------+
+--R                                 |    4 4     3 2 3      2 4 2       6     8
+--R                                 | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                                 |------------------------------------------
+--R                                 |    13 3      12 2 2      11 4     10 6  8
+--R                                \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                            + 
+--R                                   2   2        3      5
+--R                              - 10a b c  + 10a b c - 2b
+--R                         /
+--R                                7 2     6 2     5 4  4
+--R                            (16a c  - 8a b c + a b )n
+--R              + 
+--R                                             (- n - 4)log(x)
+--R                                             ---------------
+--R                   2 3        2 2     4             4
+--R                (4a c  - 12a b c  + 4b c)x %e
+--R           /
+--R              x
+--R     + 
+--R                          n  +--------------------+ +------------------+
+--R                          -  |   +-----------+      | +-----------+
+--R            2        2    4 4|   |          2      4| |          2
+--R         (8a c - 2a b )n x  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           7 2      6 2      5 4  4
+--R                       (32a c  - 16a b c + 2a b )n
+--R                    *
+--R                        +------------------------------------------+
+--R                        |    4 4     3 2 3      2 4 2       6     8
+--R                        | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |------------------------------------------
+--R                        |    13 3      12 2 2      11 4     10 6  8
+--R                       \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                   + 
+--R                          2   2        3      5
+--R                     - 10a b c  + 10a b c - 2b
+--R                /
+--R                       7 2     6 2     5 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         atan
+--R                        7   2     6 3     5 5  5
+--R                    (16a b c  - 8a b c + a b )n
+--R                 *
+--R                     +------------------------------------------+
+--R                     |    4 4     3 2 3      2 4 2       6     8
+--R                     | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |------------------------------------------
+--R                     |    13 3      12 2 2      11 4     10 6  8
+--R                    \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                + 
+--R                       3 3      2 2 2       4     6
+--R                  (- 4a c  + 13a b c  - 7a b c + b )n
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                  7 2      6 2      5 4  4
+--R                              (32a c  - 16a b c + 2a b )n
+--R                           *
+--R                               +------------------------------------------+
+--R                               |    4 4     3 2 3      2 4 2       6     8
+--R                               | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                               |------------------------------------------
+--R                               |    13 3      12 2 2      11 4     10 6  8
+--R                              \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                          + 
+--R                                 2   2        3      5
+--R                            - 10a b c  + 10a b c - 2b
+--R                       /
+--R                              7 2     6 2     5 4  4
+--R                          (16a c  - 8a b c + a b )n
+--R           /
+--R                                           (- n - 4)log(x)
+--R                                           ---------------
+--R                 2 3        2 2     4             4
+--R              (4a c  - 12a b c  + 4b c)x %e
+--R     + 
+--R                            n  +--------------------+ +------------------+
+--R                            -  |   +-----------+      | +-----------+
+--R              2        2    4 4|   |          2      4| |          2
+--R         (- 8a c + 2a b )n x  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2      6 2      5 4  4
+--R                       (- 32a c  + 16a b c - 2a b )n
+--R                    *
+--R                        +------------------------------------------+
+--R                        |    4 4     3 2 3      2 4 2       6     8
+--R                        | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |------------------------------------------
+--R                        |    13 3      12 2 2      11 4     10 6  8
+--R                       \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                   + 
+--R                          2   2        3      5
+--R                     - 10a b c  + 10a b c - 2b
+--R                /
+--R                       7 2     6 2     5 4  4
+--R                   (16a c  - 8a b c + a b )n
+--R      *
+--R         atan
+--R                        7   2     6 3     5 5  5
+--R                    (16a b c  - 8a b c + a b )n
+--R                 *
+--R                     +------------------------------------------+
+--R                     |    4 4     3 2 3      2 4 2       6     8
+--R                     | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |------------------------------------------
+--R                     |    13 3      12 2 2      11 4     10 6  8
+--R                    \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                + 
+--R                     3 3      2 2 2       4     6
+--R                  (4a c  - 13a b c  + 7a b c - b )n
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    7 2      6 2      5 4  4
+--R                              (- 32a c  + 16a b c - 2a b )n
+--R                           *
+--R                               +------------------------------------------+
+--R                               |    4 4     3 2 3      2 4 2       6     8
+--R                               | - a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                               |------------------------------------------
+--R                               |    13 3      12 2 2      11 4     10 6  8
+--R                              \|(64a  c  - 48a  b c  + 12a  b c - a  b )n
+--R                          + 
+--R                                 2   2        3      5
+--R                            - 10a b c  + 10a b c - 2b
+--R                       /
+--R                              7 2     6 2     5 4  4
+--R                          (16a c  - 8a b c + a b )n
+--R           /
+--R                                           (- n - 4)log(x)
+--R                                           ---------------
+--R                 2 3        2 2     4             4
+--R              (4a c  - 12a b c  + 4b c)x %e
+--R     + 
+--R                   n                                    n
+--R                   - +-----------+                      -
+--R              4+-+ 4 |          2                2 4+-+ 4 4+-+
+--R         (- 2b\|2 x \|- 4a c + b   + (- 8a c + 2b )\|2 x )\|c
+--R      *
+--R                                                n
+--R          +------------------+                  -
+--R          | +-----------+                  4+-+ 4 4+-+
+--R         4| |          2                   \|2 x  \|c
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                 n                                    n
+--R                 - +-----------+                      -
+--R            4+-+ 4 |          2                2 4+-+ 4 4+-+
+--R         (2b\|2 x \|- 4a c + b   + (- 8a c + 2b )\|2 x )\|c
+--R      *
+--R                                                 n
+--R          +--------------------+                 -
+--R          |   +-----------+                 4+-+ 4 4+-+
+--R         4|   |          2                  \|2 x  \|c
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                 n                                  n      +------------------+
+--R                 - +-----------+                    -      | +-----------+
+--R            4+-+ 4 |          2              2 4+-+ 4 4+-+4| |          2
+--R         (2b\|2 x \|- 4a c + b   + (8a c - 2b )\|2 x )\|c \|\|- 4a c + b   - b
+--R      *
+--R                          n
+--R                          -
+--R                     4+-+ 4 4+-+
+--R                     \|2 x  \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                   n                                  n
+--R                   - +-----------+                    -
+--R              4+-+ 4 |          2              2 4+-+ 4 4+-+
+--R         (- 2b\|2 x \|- 4a c + b   + (8a c - 2b )\|2 x )\|c
+--R      *
+--R                                                n
+--R          +--------------------+                -
+--R          |   +-----------+                4+-+ 4 4+-+
+--R         4|   |          2                 \|2 x  \|c
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                            n  (- n - 4)log(x)
+--R                            -  ---------------
+--R                       2    4         4                    2
+--R         ((- 32a c + 8b )x x %e                + 32a c - 8b )
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                      n  +--------------------+ +------------------+
+--R                      -  |   +-----------+      | +-----------+
+--R        2        2    4 4|   |          2      4| |          2
+--R     (8a c - 2a b )n x  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1983
+
+--S 1984 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1984
+
+)clear all
+
+--S 1985 of 2282
+t0:=x^3/(c+a/x^2+b/x)
+--R 
+--R
+--R               5
+--R              x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1985
+
+--S 1986 of 2282
+r0:=-b*(b^2-2*a*c)*x/c^4+1/2*(b^2-a*c)*x^2/c^3-1/3*b*x^3/c^2+1/4*x^4/c+_
+   1/2*(b^4-3*a*b^2*c+a^2*c^2)*log(a+b*x+c*x^2)/c^5+b*(b^4-_
+   5*a*b^2*c+5*a^2*c^2)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^5*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R           2   2        3       5          2c x + b
+--R       (60a b c  - 60a b c + 12b )atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R              2 2        2      4        2                4 4       3 3
+--R           (6a c  - 18a b c + 6b )log(c x  + b x + a) + 3c x  - 4b c x
+--R         + 
+--R                  3     2 2  2           2      3
+--R           (- 6a c  + 6b c )x  + (24a b c  - 12b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R          +-----------+
+--R        5 |          2
+--R     12c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1986
+
+--S 1987 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               2   2        3      5
+--R           (30a b c  - 30a b c + 6b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                2 2        2      4        2                4 4       3 3
+--R             (6a c  - 18a b c + 6b )log(c x  + b x + a) + 3c x  - 4b c x
+--R           + 
+--R                    3     2 2  2           2      3
+--R             (- 6a c  + 6b c )x  + (24a b c  - 12b c)x
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R            +-----------+
+--R          5 |          2
+--R       12c \|- 4a c + b
+--R     ,
+--R
+--R                                                      +---------+
+--R                                                      |        2
+--R               2   2        3       5      (2c x + b)\|4a c - b
+--R         (- 60a b c  + 60a b c - 12b )atan(----------------------)
+--R                                                          2
+--R                                                  4a c - b
+--R       + 
+--R                2 2        2      4        2                4 4       3 3
+--R             (6a c  - 18a b c + 6b )log(c x  + b x + a) + 3c x  - 4b c x
+--R           + 
+--R                    3     2 2  2           2      3
+--R             (- 6a c  + 6b c )x  + (24a b c  - 12b c)x
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R            +---------+
+--R          5 |        2
+--R       12c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1987
+
+--S 1988 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2   2       3     5
+--R         (5a b c  - 5a b c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R             2   2        3      5          2c x + b
+--R       (- 10a b c  + 10a b c - 2b )atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       5 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1988
+
+--S 1989 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1989
+
+--S 1990 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                 +---------+
+--R            2   2       3     5  |        2          2c x + b
+--R       (- 5a b c  + 5a b c - b )\|4a c - b  atanh(--------------)
+--R                                                   +-----------+
+--R                                                   |          2
+--R                                                  \|- 4a c + b
+--R     + 
+--R                                                              +---------+
+--R                                 +-----------+                |        2
+--R            2   2       3     5  |          2      (2c x + b)\|4a c - b
+--R       (- 5a b c  + 5a b c - b )\|- 4a c + b  atan(----------------------)
+--R                                                                  2
+--R                                                          4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      5 |          2  |        2
+--R     c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1990
+
+--S 1991 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1991
+
+)clear all
+
+--S 1992 of 2282
+t0:=x^2/(c+a/x^2+b/x)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1992
+
+--S 1993 of 2282
+r0:=(b^2-a*c)*x/c^3-1/2*b*x^2/c^2+1/3*x^3/c-1/2*b*(b^2-2*a*c)*_
+   log(a+b*x+c*x^2)/c^4-(b^4-4*a*b^2*c+2*a^2*c^2)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(c^4*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R             2 2        2      4          2c x + b
+--R       (- 12a c  + 24a b c - 6b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                         3        2                3 3       2 2
+--R             (6a b c - 3b )log(c x  + b x + a) + 2c x  - 3b c x
+--R           + 
+--R                    2     2
+--R             (- 6a c  + 6b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       4 |          2
+--R     6c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1993
+
+--S 1994 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              2 2        2      4
+--R           (6a c  - 12a b c + 3b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                         3        2                3 3       2 2
+--R             (6a b c - 3b )log(c x  + b x + a) + 2c x  - 3b c x
+--R           + 
+--R                    2     2
+--R             (- 6a c  + 6b c)x
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R           +-----------+
+--R         4 |          2
+--R       6c \|- 4a c + b
+--R     ,
+--R
+--R                                                 +---------+
+--R                                                 |        2
+--R             2 2        2      4      (2c x + b)\|4a c - b
+--R         (12a c  - 24a b c + 6b )atan(----------------------)
+--R                                                     2
+--R                                             4a c - b
+--R       + 
+--R                         3        2                3 3       2 2
+--R             (6a b c - 3b )log(c x  + b x + a) + 2c x  - 3b c x
+--R           + 
+--R                    2     2
+--R             (- 6a c  + 6b c)x
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R           +---------+
+--R         4 |        2
+--R       6c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1994
+
+--S 1995 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (2a c  - 4a b c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R          2 2       2      4          2c x + b
+--R       (4a c  - 8a b c + 2b )atanh(--------------)
+--R                                    +-----------+
+--R                                    |          2
+--R                                   \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       4 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1995
+
+--S 1996 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1996
+
+--S 1997 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             +---------+
+--R          2 2       2     4  |        2          2c x + b
+--R       (2a c  - 4a b c + b )\|4a c - b  atanh(--------------)
+--R                                               +-----------+
+--R                                               |          2
+--R                                              \|- 4a c + b
+--R     + 
+--R                                                          +---------+
+--R                             +-----------+                |        2
+--R          2 2       2     4  |          2      (2c x + b)\|4a c - b
+--R       (2a c  - 4a b c + b )\|- 4a c + b  atan(----------------------)
+--R                                                              2
+--R                                                      4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      4 |          2  |        2
+--R     c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1997
+
+--S 1998 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1998
+
+)clear all
+
+--S 1999 of 2282
+t0:=x/(c+a/x^2+b/x)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1999
+
+--S 2000 of 2282
+r0:=-b*x/c^2+1/2*x^2/c+1/2*(b^2-a*c)*log(a+b*x+c*x^2)/c^3+b*(b^2-3*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                     3          2c x + b
+--R       (- 6a b c + 2b )atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                                         +-----------+
+--R                  2        2               2 2           |          2
+--R       ((- a c + b )log(c x  + b x + a) + c x  - 2b c x)\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2000
+
+--S 2001 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3
+--R           (3a b c - b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                                           +-----------+
+--R                    2        2               2 2           |          2
+--R         ((- a c + b )log(c x  + b x + a) + c x  - 2b c x)\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         3 |          2
+--R       2c \|- 4a c + b
+--R     ,
+--R
+--R                                       +---------+
+--R                                       |        2
+--R                     3      (2c x + b)\|4a c - b
+--R         (6a b c - 2b )atan(----------------------)
+--R                                           2
+--R                                   4a c - b
+--R       + 
+--R                                                           +---------+
+--R                    2        2               2 2           |        2
+--R         ((- a c + b )log(c x  + b x + a) + c x  - 2b c x)\|4a c - b
+--R    /
+--R           +---------+
+--R         3 |        2
+--R       2c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2001
+
+--S 2002 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (3a b c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                   3          2c x + b
+--R       (6a b c - 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2002
+
+--S 2003 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2003
+
+--S 2004 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+
+--R                  3  |        2          2c x + b
+--R       (3a b c - b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                     +-----------+                |        2
+--R                  3  |          2      (2c x + b)\|4a c - b
+--R       (3a b c - b )\|- 4a c + b  atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      3 |          2  |        2
+--R     c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2004
+
+--S 2005 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2005
+
+)clear all
+
+--S 2006 of 2282
+t0:=1/(c+a/x^2+b/x)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2006
+
+--S 2007 of 2282
+r0:=x/c-1/2*b*log(a+b*x+c*x^2)/c^2-(b^2-2*a*c)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                 2          2c x + b
+--R       (4a c - 2b )atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                        +-----------+
+--R                   2                    |          2
+--R       (- b log(c x  + b x + a) + 2c x)\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2007
+
+--S 2008 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2
+--R           (2a c - b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                          +-----------+
+--R                     2                    |          2
+--R         (- b log(c x  + b x + a) + 2c x)\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         2 |          2
+--R       2c \|- 4a c + b
+--R     ,
+--R
+--R                                       +---------+
+--R                                       |        2
+--R                     2      (2c x + b)\|4a c - b
+--R         (- 4a c + 2b )atan(----------------------)
+--R                                           2
+--R                                   4a c - b
+--R       + 
+--R                                          +---------+
+--R                     2                    |        2
+--R         (- b log(c x  + b x + a) + 2c x)\|4a c - b
+--R    /
+--R           +---------+
+--R         2 |        2
+--R       2c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2008
+
+--S 2009 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                   2          2c x + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2009
+
+--S 2010 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2010
+
+--S 2011 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+
+--R                  2  |        2          2c x + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                     +-----------+                |        2
+--R                  2  |          2      (2c x + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      2 |          2  |        2
+--R     c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2011
+
+--S 2012 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2012
+
+)clear all
+
+--S 2013 of 2282
+t0:=1/((c+a/x^2+b/x)*x)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2013
+
+--S 2014 of 2282
+r0:=1/2*log(a+b*x+c*x^2)/c+b*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                                                       +-----------+
+--R                    2c x + b              2            |          2
+--R        2b atanh(--------------) + log(c x  + b x + a)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  ------------------------------------------------------------
+--R                                 +-----------+
+--R                                 |          2
+--R                              2c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2014
+
+--S 2015 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                             +-----------+
+--R                2            |          2
+--R         log(c x  + b x + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       2c\|- 4a c + b
+--R     ,
+--R                         +---------+
+--R                         |        2                         +---------+
+--R              (2c x + b)\|4a c - b             2            |        2
+--R    - 2b atan(----------------------) + log(c x  + b x + a)\|4a c - b
+--R                             2
+--R                     4a c - b
+--R    -------------------------------------------------------------------]
+--R                                  +---------+
+--R                                  |        2
+--R                               2c\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2015
+
+--S 2016 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                     2c x + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     2c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2016
+
+--S 2017 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2017
+
+--S 2018 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+
+--R           |        2          2c x + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                        +---------+
+--R           +-----------+                |        2
+--R           |          2      (2c x + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R       +-----------+ +---------+
+--R       |          2  |        2
+--R     c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2018
+
+--S 2019 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2019
+
+)clear all
+
+--S 2020 of 2282
+t0:=1/((c+a/x^2+b/x)*x^2)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2020
+
+--S 2021 of 2282
+r0:=2*atanh((b+2*a/x)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                   b x + 2a
+--R        2atanh(---------------)
+--R                 +-----------+
+--R                 |          2
+--R               x\|- 4a c + b
+--R   (2)  -----------------------
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2021
+
+--S 2022 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                           +-----------+
+--R                 2 2                    2  |          2         2     2
+--R              (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               2
+--R            c x  + b x + a
+--R    /
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R     ,
+--R                     +---------+
+--R                     |        2
+--R          (2c x + b)\|4a c - b
+--R    2atan(----------------------)
+--R                         2
+--R                 4a c - b
+--R    -----------------------------]
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2022
+
+--S 2023 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                           +-----------+
+--R                 2 2                    2  |          2         2     2
+--R              (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               2
+--R            c x  + b x + a
+--R     + 
+--R                    b x + 2a
+--R       - 2atanh(---------------)
+--R                  +-----------+
+--R                  |          2
+--R                x\|- 4a c + b
+--R  /
+--R      +-----------+
+--R      |          2
+--R     \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2023
+
+--S 2024 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2024
+
+--S 2025 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+
+--R           |        2           b x + 2a
+--R       - 2\|4a c - b  atanh(---------------)
+--R                              +-----------+
+--R                              |          2
+--R                            x\|- 4a c + b
+--R     + 
+--R                                      +---------+
+--R         +-----------+                |        2
+--R         |          2      (2c x + b)\|4a c - b
+--R       2\|- 4a c + b  atan(----------------------)
+--R                                          2
+--R                                  4a c - b
+--R  /
+--R      +-----------+ +---------+
+--R      |          2  |        2
+--R     \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2025
+
+--S 2026 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2026
+
+)clear all
+
+--S 2027 of 2282
+t0:=1/((c+a/x^2+b/x)*x^3)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           3      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2027
+
+--S 2028 of 2282
+r0:=log(x)/a-1/2*log(a+b*x+c*x^2)/a+b*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                                                +-----------+
+--R               2c x + b                 2                       |          2
+--R   2b atanh(--------------) + (- log(c x  + b x + a) + 2log(x))\|- 4a c + b
+--R             +-----------+
+--R             |          2
+--R            \|- 4a c + b
+--R   --------------------------------------------------------------------------
+--R                                   +-----------+
+--R                                   |          2
+--R                                2a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2028
+
+--S 2029 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                           +-----------+
+--R                   2                       |          2
+--R         (- log(c x  + b x + a) + 2log(x))\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       2a\|- 4a c + b
+--R     ,
+--R
+--R                              +---------+
+--R                              |        2
+--R                   (2c x + b)\|4a c - b
+--R         - 2b atan(----------------------)
+--R                                  2
+--R                          4a c - b
+--R       + 
+--R                                           +---------+
+--R                   2                       |        2
+--R         (- log(c x  + b x + a) + 2log(x))\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       2a\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2029
+
+--S 2030 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                     2c x + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     2a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2030
+
+--S 2031 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2031
+
+--S 2032 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+
+--R           |        2          2c x + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                        +---------+
+--R           +-----------+                |        2
+--R           |          2      (2c x + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R       +-----------+ +---------+
+--R       |          2  |        2
+--R     a\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2032
+
+--S 2033 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2033
+
+)clear all
+
+--S 2034 of 2282
+t0:=1/((c+a/x^2+b/x)*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           4      3      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2034
+
+--S 2035 of 2282
+r0:=(-1)/(a*x)-b*log(x)/a^2+1/2*b*log(a+b*x+c*x^2)/a^2-(b^2-2*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                 2            2c x + b
+--R       (4a c - 2b )x atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                                    +-----------+
+--R                   2                                |          2
+--R       (b x log(c x  + b x + a) - 2b x log(x) - 2a)\|- 4a c + b
+--R  /
+--R          +-----------+
+--R       2  |          2
+--R     2a x\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2035
+
+--S 2036 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2
+--R           (2a c - b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                                      +-----------+
+--R                     2                                |          2
+--R         (b x log(c x  + b x + a) - 2b x log(x) - 2a)\|- 4a c + b
+--R    /
+--R            +-----------+
+--R         2  |          2
+--R       2a x\|- 4a c + b
+--R     ,
+--R
+--R                                         +---------+
+--R                                         |        2
+--R                     2        (2c x + b)\|4a c - b
+--R         (- 4a c + 2b )x atan(----------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R                                                      +---------+
+--R                     2                                |        2
+--R         (b x log(c x  + b x + a) - 2b x log(x) - 2a)\|4a c - b
+--R    /
+--R            +---------+
+--R         2  |        2
+--R       2a x\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2036
+
+--S 2037 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                   2          2c x + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2037
+
+--S 2038 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2038
+
+--S 2039 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+
+--R                  2  |        2          2c x + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                     +-----------+                |        2
+--R                  2  |          2      (2c x + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      2 |          2  |        2
+--R     a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2039
+
+--S 2040 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2040
+
+)clear all
+
+--S 2041 of 2282
+t0:=1/((c+a/x^2+b/x)*x^5)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           5      4      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2041
+
+--S 2042 of 2282
+r0:=(-1/2)/(a*x^2)+b/(a^2*x)+(b^2-a*c)*log(x)/a^3-1/2*(b^2-a*c)*_
+   log(a+b*x+c*x^2)/a^3+b*(b^2-3*a*c)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(a^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                     3  2         2c x + b
+--R       (- 6a b c + 2b )x atanh(--------------)
+--R                                +-----------+
+--R                                |          2
+--R                               \|- 4a c + b
+--R     + 
+--R                     2  2       2                          2  2
+--R             (a c - b )x log(c x  + b x + a) + (- 2a c + 2b )x log(x) + 2a b x
+--R           + 
+--R                2
+--R             - a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       3 2 |          2
+--R     2a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2042
+
+--S 2043 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3  2
+--R           (3a b c - b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                     2  2       2                          2  2
+--R             (a c - b )x log(c x  + b x + a) + (- 2a c + 2b )x log(x) + 2a b x
+--R           + 
+--R                2
+--R             - a
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             +-----------+
+--R         3 2 |          2
+--R       2a x \|- 4a c + b
+--R     ,
+--R
+--R                                         +---------+
+--R                                         |        2
+--R                     3  2     (2c x + b)\|4a c - b
+--R         (6a b c - 2b )x atan(----------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R                     2  2       2                          2  2
+--R             (a c - b )x log(c x  + b x + a) + (- 2a c + 2b )x log(x) + 2a b x
+--R           + 
+--R                2
+--R             - a
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R             +---------+
+--R         3 2 |        2
+--R       2a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2043
+
+--S 2044 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (3a b c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                   3          2c x + b
+--R       (6a b c - 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     2a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2044
+
+--S 2045 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2045
+
+--S 2046 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+
+--R                  3  |        2          2c x + b
+--R       (3a b c - b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                     +-----------+                |        2
+--R                  3  |          2      (2c x + b)\|4a c - b
+--R       (3a b c - b )\|- 4a c + b  atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      3 |          2  |        2
+--R     a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2046
+
+--S 2047 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2047
+
+)clear all
+
+--S 2048 of 2282
+t0:=1/((c+a/x^2+b/x)*x^6)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           6      5      4
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2048
+
+--S 2049 of 2282
+r0:=(-1/3)/(a*x^3)+1/2*b/(a^2*x^2)+(-b^2+a*c)/(a^3*x)-b*(b^2-2*a*c)*_
+   log(x)/a^4+1/2*b*(b^2-2*a*c)*log(a+b*x+c*x^2)/a^4-(b^4-4*a*b^2*c+_
+   2*a^2*c^2)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^4*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R             2 2        2      4  3         2c x + b
+--R       (- 12a c  + 24a b c - 6b )x atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R     + 
+--R                         3  3       2                           3  3
+--R           (- 6a b c + 3b )x log(c x  + b x + a) + (12a b c - 6b )x log(x)
+--R         + 
+--R              2        2  2     2        3
+--R           (6a c - 6a b )x  + 3a b x - 2a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       4 3 |          2
+--R     6a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2049
+
+--S 2050 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              2 2        2      4  3
+--R           (6a c  - 12a b c + 3b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                           3  3       2                           3  3
+--R             (- 6a b c + 3b )x log(c x  + b x + a) + (12a b c - 6b )x log(x)
+--R           + 
+--R                2        2  2     2        3
+--R             (6a c - 6a b )x  + 3a b x - 2a
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             +-----------+
+--R         4 3 |          2
+--R       6a x \|- 4a c + b
+--R     ,
+--R
+--R                                                   +---------+
+--R                                                   |        2
+--R             2 2        2      4  3     (2c x + b)\|4a c - b
+--R         (12a c  - 24a b c + 6b )x atan(----------------------)
+--R                                                       2
+--R                                               4a c - b
+--R       + 
+--R                           3  3       2                           3  3
+--R             (- 6a b c + 3b )x log(c x  + b x + a) + (12a b c - 6b )x log(x)
+--R           + 
+--R                2        2  2     2        3
+--R             (6a c - 6a b )x  + 3a b x - 2a
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R             +---------+
+--R         4 3 |        2
+--R       6a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2050
+
+--S 2051 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (2a c  - 4a b c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R          2 2       2      4          2c x + b
+--R       (4a c  - 8a b c + 2b )atanh(--------------)
+--R                                    +-----------+
+--R                                    |          2
+--R                                   \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       4 |          2
+--R     2a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2051
+
+--S 2052 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2052
+
+--S 2053 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             +---------+
+--R          2 2       2     4  |        2          2c x + b
+--R       (2a c  - 4a b c + b )\|4a c - b  atanh(--------------)
+--R                                               +-----------+
+--R                                               |          2
+--R                                              \|- 4a c + b
+--R     + 
+--R                                                          +---------+
+--R                             +-----------+                |        2
+--R          2 2       2     4  |          2      (2c x + b)\|4a c - b
+--R       (2a c  - 4a b c + b )\|- 4a c + b  atan(----------------------)
+--R                                                              2
+--R                                                      4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      4 |          2  |        2
+--R     a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2053
+
+--S 2054 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2054
+
+)clear all
+
+--S 2055 of 2282
+t0:=x/(c+a/x^2+b/x)^2
+--R 
+--R
+--R                              5
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2055
+
+--S 2056 of 2282
+r0:=-b*(3*b^2-11*a*c)*x/(c^3*(b^2-4*a*c))+1/2*(3*b^2-8*a*c)*x^2/(c^2*_
+   (b^2-4*a*c))-b*x^3/(c*(b^2-4*a*c))+x^4*(2*a+b*x)/((b^2-4*a*c)*_
+   (a+b*x+c*x^2))+b*(3*b^4-20*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(c^4*(b^2-4*a*c)^(3/2))+1/2*(3*b^2-2*a*c)*_
+   log(a+b*x+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R                 2   3        3 2     5   2         2 2 2        4      6
+--R           (- 60a b c  + 40a b c  - 6b c)x  + (- 60a b c  + 40a b c - 6b )x
+--R         + 
+--R                3   2      2 3        5
+--R           - 60a b c  + 40a b c - 6a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                    2 3        2 2     4   2        2   2        3      5
+--R               (- 8a c  + 14a b c  - 3b c)x  + (- 8a b c  + 14a b c - 3b )x
+--R             + 
+--R                   3 2      2 2        4
+--R               - 8a c  + 14a b c - 3a b
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                4    2 3  4             3     3 2  3
+--R           (4a c  - b c )x  + (- 12a b c  + 3b c )x
+--R         + 
+--R              2 3        2 2     4   2         2   2       3
+--R           (8a c  - 25a b c  + 6b c)x  + (- 22a b c  + 6a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                +-----------+
+--R           6     2 5  2          5     3 4       2 5       2 4  |          2
+--R     ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2056
+
+--S 2057 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   3        3 2     5   2       2 2 2        4      6
+--R             (30a b c  - 20a b c  + 3b c)x  + (30a b c  - 20a b c + 3b )x
+--R           + 
+--R                3   2      2 3        5
+--R             30a b c  - 20a b c + 3a b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                      2 3        2 2     4   2        2   2        3      5
+--R                 (- 8a c  + 14a b c  - 3b c)x  + (- 8a b c  + 14a b c - 3b )x
+--R               + 
+--R                     3 2      2 2        4
+--R                 - 8a c  + 14a b c - 3a b
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                  4    2 3  4             3     3 2  3
+--R             (4a c  - b c )x  + (- 12a b c  + 3b c )x
+--R           + 
+--R                2 3        2 2     4   2         2   2        3      5       3 2
+--R             (4a c  - 17a b c  + 4b c)x  + (- 26a b c  + 14a b c - 2b )x - 4a c
+--R           + 
+--R               2 2        4
+--R             8a b c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                                  +-----------+
+--R             6     2 5  2          5     3 4       2 5       2 4  |          2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|- 4a c + b
+--R     ,
+--R
+--R                 2   3        3 2     5   2       2 2 2        4      6
+--R             (60a b c  - 40a b c  + 6b c)x  + (60a b c  - 40a b c + 6b )x
+--R           + 
+--R                3   2      2 3        5
+--R             60a b c  - 40a b c + 6a b
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                      2 3        2 2     4   2        2   2        3      5
+--R                 (- 8a c  + 14a b c  - 3b c)x  + (- 8a b c  + 14a b c - 3b )x
+--R               + 
+--R                     3 2      2 2        4
+--R                 - 8a c  + 14a b c - 3a b
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                  4    2 3  4             3     3 2  3
+--R             (4a c  - b c )x  + (- 12a b c  + 3b c )x
+--R           + 
+--R                2 3        2 2     4   2         2   2        3      5       3 2
+--R             (4a c  - 17a b c  + 4b c)x  + (- 26a b c  + 14a b c - 2b )x - 4a c
+--R           + 
+--R               2 2        4
+--R             8a b c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                  +---------+
+--R             6     2 5  2          5     3 4       2 5       2 4  |        2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2057
+
+--S 2058 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2   2        3      5
+--R         (30a b c  - 20a b c + 3b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R           2   2        3      5          2c x + b
+--R       (60a b c  - 40a b c + 6b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                                +-----------+
+--R            2 2       2      4  |          2
+--R       (- 4a c  + 8a b c - 2b )\|- 4a c + b
+--R  /
+--R                     +-----------+
+--R          5     2 4  |          2
+--R     (8a c  - 2b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2058
+
+--S 2059 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2059
+
+--S 2060 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------+
+--R           2   2        3      5  |        2          2c x + b
+--R       (30a b c  - 20a b c + 3b )\|4a c - b  atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R                                  +-----------+                |        2
+--R           2   2        3      5  |          2      (2c x + b)\|4a c - b
+--R       (30a b c  - 20a b c + 3b )\|- 4a c + b  atan(----------------------)
+--R                                                                   2
+--R                                                           4a c - b
+--R     + 
+--R                               +-----------+ +---------+
+--R            2 2       2     4  |          2  |        2
+--R       (- 2a c  + 4a b c - b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R          5    2 4  |          2  |        2
+--R     (4a c  - b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2060
+
+--S 2061 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2061
+
+)clear all
+
+--S 2062 of 2282
+t0:=1/(c+a/x^2+b/x)^2
+--R 
+--R
+--R                              4
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2062
+
+--S 2063 of 2282
+r0:=2*(b^2-3*a*c)*x/(c^2*(b^2-4*a*c))-(b^2-2*a*c+a*b/x)*x/(c*(b^2-4*a*c)*_
+   (c+a/x^2+b/x))+2*(b^4-6*a*b^2*c+6*a^2*c^2)*atanh((b+2*a/x)/_
+   sqrt(b^2-4*a*c))/(c^3*(b^2-4*a*c)^(3/2))-b*log(c+a/x^2+b/x)/c^3-_
+   2*b*log(x)/c^3
+--R 
+--R
+--R   (2)
+--R                 2 3        2 2     4   2         2   2        3      5
+--R           (- 12a c  + 12a b c  - 2b c)x  + (- 12a b c  + 12a b c - 2b )x
+--R         + 
+--R                3 2      2 2        4
+--R           - 12a c  + 12a b c - 2a b
+--R      *
+--R                   b x + 2a
+--R         atanh(---------------)
+--R                 +-----------+
+--R                 |          2
+--R               x\|- 4a c + b
+--R     + 
+--R                     2     3   2          2      4       2          3
+--R           ((- 8a b c  + 2b c)x  + (- 8a b c + 2b )x - 8a b c + 2a b )log(x)
+--R         + 
+--R                       2    3   2          2     4       2         3
+--R             ((- 4a b c  + b c)x  + (- 4a b c + b )x - 4a b c + a b )
+--R          *
+--R                    2
+--R                 c x  + b x + a
+--R             log(--------------)
+--R                        2
+--R                       x
+--R         + 
+--R                3    2 2  3          2     3   2      2 2       2
+--R           (4a c  - b c )x  + (7a b c  - 2b c)x  + (6a c  - 2a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                             +-----------+
+--R           5    2 4  2          4    3 3       2 4      2 3  |          2
+--R     ((4a c  - b c )x  + (4a b c  - b c )x + 4a c  - a b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2063
+
+--S 2064 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3       2 2    4   2      2   2       3     5       3 2
+--R             (6a c  - 6a b c  + b c)x  + (6a b c  - 6a b c + b )x + 6a c
+--R           + 
+--R                 2 2       4
+--R             - 6a b c + a b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                         2    3   2          2     4       2         3
+--R               ((- 4a b c  + b c)x  + (- 4a b c + b )x - 4a b c + a b )
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                  3    2 2  3          2    3   2      2 2       2     4
+--R             (4a c  - b c )x  + (4a b c  - b c)x  + (6a c  - 5a b c + b )x
+--R           + 
+--R                 2         3
+--R             - 3a b c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                               +-----------+
+--R             5    2 4  2          4    3 3       2 4      2 3  |          2
+--R       ((4a c  - b c )x  + (4a b c  - b c )x + 4a c  - a b c )\|- 4a c + b
+--R     ,
+--R
+--R                   2 3        2 2     4   2         2   2        3      5
+--R             (- 12a c  + 12a b c  - 2b c)x  + (- 12a b c  + 12a b c - 2b )x
+--R           + 
+--R                  3 2      2 2        4
+--R             - 12a c  + 12a b c - 2a b
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                         2    3   2          2     4       2         3
+--R               ((- 4a b c  + b c)x  + (- 4a b c + b )x - 4a b c + a b )
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                  3    2 2  3          2    3   2      2 2       2     4
+--R             (4a c  - b c )x  + (4a b c  - b c)x  + (6a c  - 5a b c + b )x
+--R           + 
+--R                 2         3
+--R             - 3a b c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                               +---------+
+--R             5    2 4  2          4    3 3       2 4      2 3  |        2
+--R       ((4a c  - b c )x  + (4a b c  - b c )x + 4a c  - a b c )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2064
+
+--S 2065 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (6a c  - 6a b c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R           2 2        2      4           b x + 2a
+--R       (12a c  - 12a b c + 2b )atanh(---------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                     x\|- 4a c + b
+--R     + 
+--R                        3        2                          3
+--R           (- 4a b c + b )log(c x  + b x + a) + (8a b c - 2b )log(x)
+--R         + 
+--R                               2
+--R                      3     c x  + b x + a              3
+--R           (4a b c - b )log(--------------) - 3a b c + b
+--R                                   2
+--R                                  x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R          4    2 3  |          2
+--R     (4a c  - b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2065
+
+--S 2066 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2066
+
+--S 2067 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                +---------+
+--R           2 2        2      4  |        2           b x + 2a
+--R       (12a c  - 12a b c + 2b )\|4a c - b  atanh(---------------)
+--R                                                   +-----------+
+--R                                                   |          2
+--R                                                 x\|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R                                  +-----------+                |        2
+--R             2 2        2      4  |          2      (2c x + b)\|4a c - b
+--R       (- 12a c  + 12a b c - 2b )\|- 4a c + b  atan(----------------------)
+--R                                                                   2
+--R                                                           4a c - b
+--R     + 
+--R                        3        2                          3
+--R           (- 4a b c + b )log(c x  + b x + a) + (8a b c - 2b )log(x)
+--R         + 
+--R                               2
+--R                      3     c x  + b x + a              3
+--R           (4a b c - b )log(--------------) - 3a b c + b
+--R                                   2
+--R                                  x
+--R      *
+--R          +-----------+ +---------+
+--R          |          2  |        2
+--R         \|- 4a c + b  \|4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R          4    2 3  |          2  |        2
+--R     (4a c  - b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2067
+
+--S 2068 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2068
+
+)clear all
+
+--S 2069 of 2282
+t0:=1/((c+a/x^2+b/x)^2*x)
+--R 
+--R
+--R                              3
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2069
+
+--S 2070 of 2282
+r0:=-b*x/(c*(b^2-4*a*c))+x^2*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))+_
+   b*(b^2-6*a*c)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^2*(b^2-_
+   4*a*c)^(3/2))+1/2*log(a+b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R                  2     3   2         2      4        2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x + 12a b c - 2a b )
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 2    2   2              3       2       2        2
+--R           ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )log(c x  + b x + a)
+--R         + 
+--R                  2     2   2
+--R           (- 4a c  + 2b c)x  + 2a b c x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                +-----------+
+--R           4     2 3  2          3     3 2       2 3       2 2  |          2
+--R     ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2070
+
+--S 2071 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2    3   2        2     4       2         3
+--R           ((6a b c  - b c)x  + (6a b c - b )x + 6a b c - a b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                   2    2   2              3       2       2        2
+--R             ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )log(c x  + b x + a)
+--R           + 
+--R                         3       2        2
+--R             (6a b c - 2b )x + 4a c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                                  +-----------+
+--R             4     2 3  2          3     3 2       2 3       2 2  |          2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|- 4a c + b
+--R     ,
+--R
+--R                      2     3   2           2      4        2          3
+--R           ((- 12a b c  + 2b c)x  + (- 12a b c + 2b )x - 12a b c + 2a b )
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                   2    2   2              3       2       2        2
+--R             ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )log(c x  + b x + a)
+--R           + 
+--R                         3       2        2
+--R             (6a b c - 2b )x + 4a c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                  +---------+
+--R             4     2 3  2          3     3 2       2 3       2 2  |        2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2071
+
+--S 2072 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (6a b c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                                                             +-----------+
+--R                      3          2c x + b                 2  |          2
+--R       (- 12a b c + 2b )atanh(--------------) + (4a c - 2b )\|- 4a c + b
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                     +-----------+
+--R          3     2 2  |          2
+--R     (8a c  - 2b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2072
+
+--S 2073 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2073
+
+--S 2074 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+
+--R                    3  |        2          2c x + b
+--R       (- 6a b c + b )\|4a c - b  atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                                                    +---------+
+--R                       +-----------+                |        2
+--R                    3  |          2      (2c x + b)\|4a c - b
+--R       (- 6a b c + b )\|- 4a c + b  atan(----------------------)
+--R                                                        2
+--R                                                4a c - b
+--R     + 
+--R                   +-----------+ +---------+
+--R                2  |          2  |        2
+--R       (2a c - b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R          3    2 2  |          2  |        2
+--R     (4a c  - b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2074
+
+--S 2075 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2075
+
+)clear all
+
+--S 2076 of 2282
+t0:=1/((c+a/x^2+b/x)^2*x^2)
+--R 
+--R
+--R                              2
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2076
+
+--S 2077 of 2282
+r0:=(b+2*a/x)/((b^2-4*a*c)*(c+a/x^2+b/x))-4*a*atanh((b+2*a/x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R              2              2           b x + 2a
+--R       (4a c x  + 4a b x + 4a )atanh(---------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                     x\|- 4a c + b
+--R     + 
+--R                       +-----------+
+--R             2         |          2
+--R       (- b x  - 2a x)\|- 4a c + b
+--R  /
+--R                                                      +-----------+
+--R           2    2   2              3       2       2  |          2
+--R     ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2077
+
+--S 2078 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 2                2
+--R           (2a c x  + 2a b c x + 2a c)
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                +-----------+
+--R                     2          |          2
+--R         ((- 2a c + b )x + a b)\|- 4a c + b
+--R    /
+--R                                                             +-----------+
+--R             3    2 2  2          2    3        2 2      2   |          2
+--R       ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|- 4a c + b
+--R     ,
+--R
+--R                                                    +---------+
+--R                                                    |        2
+--R              2 2                2       (2c x + b)\|4a c - b
+--R         (4a c x  + 4a b c x + 4a c)atan(----------------------)
+--R                                                        2
+--R                                                4a c - b
+--R       + 
+--R                                +---------+
+--R                     2          |        2
+--R         ((- 2a c + b )x + a b)\|4a c - b
+--R    /
+--R                                                             +---------+
+--R             3    2 2  2          2    3        2 2      2   |        2
+--R       ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2078
+
+--S 2079 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         2a c
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                                         +-----------+
+--R                        b x + 2a         |          2
+--R       - 4a c atanh(---------------) + b\|- 4a c + b
+--R                      +-----------+
+--R                      |          2
+--R                    x\|- 4a c + b
+--R  /
+--R                   +-----------+
+--R          2    2   |          2
+--R     (4a c  - b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2079
+
+--S 2080 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2080
+
+--S 2081 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              +---------+
+--R              |        2           b x + 2a
+--R       - 4a c\|4a c - b  atanh(---------------)
+--R                                 +-----------+
+--R                                 |          2
+--R                               x\|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R            +-----------+                |        2
+--R            |          2      (2c x + b)\|4a c - b
+--R       4a c\|- 4a c + b  atan(----------------------)
+--R                                             2
+--R                                     4a c - b
+--R     + 
+--R         +-----------+ +---------+
+--R         |          2  |        2
+--R       b\|- 4a c + b  \|4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R          2    2   |          2  |        2
+--R     (4a c  - b c)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2081
+
+--S 2082 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2082
+
+)clear all
+
+--S 2083 of 2282
+t0:=1/((c+a/x^2+b/x)^2*x^3)
+--R 
+--R
+--R                              x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2083
+
+--S 2084 of 2282
+r0:=(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))-2*b*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                                               +-----------+
+--R          2     2                  2c x + b                    |          2
+--R   (2b c x  + 2b x + 2a b)atanh(--------------) + (- b x - 2a)\|- 4a c + b
+--R                                 +-----------+
+--R                                 |          2
+--R                                \|- 4a c + b
+--R   -------------------------------------------------------------------------
+--R                                                          +-----------+
+--R               2    2   2              3       2       2  |          2
+--R         ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2084
+
+--S 2085 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2    2
+--R           (b c x  + b x + a b)
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                      +-----------+
+--R                      |          2
+--R         (- b x - 2a)\|- 4a c + b
+--R    /
+--R                                                        +-----------+
+--R             2    2   2              3       2       2  |          2
+--R       ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R     ,
+--R
+--R                                                  +---------+
+--R                                                  |        2
+--R                  2     2              (2c x + b)\|4a c - b
+--R         (- 2b c x  - 2b x - 2a b)atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R       + 
+--R                      +---------+
+--R                      |        2
+--R         (- b x - 2a)\|4a c - b
+--R    /
+--R                                                        +---------+
+--R             2    2   2              3       2       2  |        2
+--R       ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2085
+
+--S 2086 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                     2c x + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R              2  |          2
+--R     (4a c - b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2086
+
+--S 2087 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2087
+
+--S 2088 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            +---------+
+--R            |        2          2c x + b
+--R       - 2b\|4a c - b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R            +-----------+                |        2
+--R            |          2      (2c x + b)\|4a c - b
+--R       - 2b\|- 4a c + b  atan(----------------------)
+--R                                             2
+--R                                     4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2088
+
+--S 2089 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2089
+
+)clear all
+
+--S 2090 of 2282
+t0:=1/((c+a/x^2+b/x)^2*x^4)
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2090
+
+--S 2091 of 2282
+r0:=(-b-2*c*x)/((b^2-4*a*c)*(a+b*x+c*x^2))+4*c*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                                               +-----------+
+--R        2 2                          2c x + b                  |          2
+--R   (- 4c x  - 4b c x - 4a c)atanh(--------------) + (2c x + b)\|- 4a c + b
+--R                                   +-----------+
+--R                                   |          2
+--R                                  \|- 4a c + b
+--R   -------------------------------------------------------------------------
+--R                                                          +-----------+
+--R               2    2   2              3       2       2  |          2
+--R         ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2091
+
+--S 2092 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              2 2
+--R           (2c x  + 2b c x + 2a c)
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                    +-----------+
+--R                    |          2
+--R         (2c x + b)\|- 4a c + b
+--R    /
+--R                                                        +-----------+
+--R             2    2   2              3       2       2  |          2
+--R       ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R     ,
+--R                                           +---------+
+--R                                           |        2                +---------+
+--R       2 2                      (2c x + b)\|4a c - b                 |        2
+--R    (4c x  + 4b c x + 4a c)atan(----------------------) + (2c x + b)\|4a c - b
+--R                                               2
+--R                                       4a c - b
+--R    ----------------------------------------------------------------------------
+--R                                                             +---------+
+--R                  2    2   2              3       2       2  |        2
+--R            ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2092
+
+--S 2093 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         2c
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                   2c x + b
+--R       4c atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R              2  |          2
+--R     (4a c - b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2093
+
+--S 2094 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2094
+
+--S 2095 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +---------+
+--R          |        2          2c x + b
+--R       4c\|4a c - b  atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                       +---------+
+--R          +-----------+                |        2
+--R          |          2      (2c x + b)\|4a c - b
+--R       4c\|- 4a c + b  atan(----------------------)
+--R                                           2
+--R                                   4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2095
+
+--S 2096 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2096
+
+)clear all
+
+--S 2097 of 2282
+t0:=1/((c+a/x^2+b/x)^2*x^5)
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R         2 5         4            2  3         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2097
+
+--S 2098 of 2282
+r0:=(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*(a+b*x+c*x^2))+b*(b^2-6*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^(3/2))+_
+   log(x)/a^2-1/2*log(a+b*x+c*x^2)/a^2
+--R 
+--R
+--R   (2)
+--R                  2     3   2         2      4        2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x + 12a b c - 2a b )
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    2   2                3       2       2
+--R             ((- 4a c  + b c)x  + (- 4a b c + b )x - 4a c + a b )
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                 2     2   2               3       2        2
+--R           ((8a c  - 2b c)x  + (8a b c - 2b )x + 8a c - 2a b )log(x) - 2a b c x
+--R         + 
+--R             2        2
+--R           4a c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                             +-----------+
+--R         3 2     2 2   2      3        2 3       4      3 2  |          2
+--R     ((8a c  - 2a b c)x  + (8a b c - 2a b )x + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2098
+
+--S 2099 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2    3   2        2     4       2         3
+--R           ((6a b c  - b c)x  + (6a b c - b )x + 6a b c - a b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                       2    2   2                3       2       2
+--R               ((- 4a c  + b c)x  + (- 4a b c + b )x - 4a c + a b )
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                   2     2   2               3       2        2
+--R             ((8a c  - 2b c)x  + (8a b c - 2b )x + 8a c - 2a b )log(x)
+--R           + 
+--R                            2        2
+--R             - 2a b c x + 4a c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                               +-----------+
+--R           3 2     2 2   2      3        2 3       4      3 2  |          2
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x + 8a c - 2a b )\|- 4a c + b
+--R     ,
+--R
+--R                      2     3   2           2      4        2          3
+--R           ((- 12a b c  + 2b c)x  + (- 12a b c + 2b )x - 12a b c + 2a b )
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2    2   2                3       2       2
+--R               ((- 4a c  + b c)x  + (- 4a b c + b )x - 4a c + a b )
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                   2     2   2               3       2        2
+--R             ((8a c  - 2b c)x  + (8a b c - 2b )x + 8a c - 2a b )log(x)
+--R           + 
+--R                            2        2
+--R             - 2a b c x + 4a c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                               +---------+
+--R           3 2     2 2   2      3        2 3       4      3 2  |        2
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x + 8a c - 2a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2099
+
+--S 2100 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (6a b c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                      3          2c x + b
+--R       (- 12a b c + 2b )atanh(--------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R        3      2 2  |          2
+--R     (8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2100
+
+--S 2101 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2101
+
+--S 2102 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+
+--R                    3  |        2          2c x + b
+--R       (- 6a b c + b )\|4a c - b  atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                                                    +---------+
+--R                       +-----------+                |        2
+--R                    3  |          2      (2c x + b)\|4a c - b
+--R       (- 6a b c + b )\|- 4a c + b  atan(----------------------)
+--R                                                        2
+--R                                                4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R        3     2 2  |          2  |        2
+--R     (4a c - a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2102
+
+--S 2103 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2103
+
+)clear all
+
+--S 2104 of 2282
+t0:=1/((c+a/x^2+b/x)^2*x^6)
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R         2 6         5            2  4         3    2 2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2104
+
+--S 2105 of 2282
+r0:=-2*(b^2-3*a*c)/(a^2*(b^2-4*a*c)*x)+(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*_
+   x*(a+b*x+c*x^2))-2*(b^4-6*a*b^2*c+6*a^2*c^2)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(3/2))-2*b*log(x)/a^3+_
+   b*log(a+b*x+c*x^2)/a^3
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   3       2   2        3      5  2
+--R           (12a c  - 12a b c  + 2b c)x  + (12a b c  - 12a b c + 2b )x
+--R         + 
+--R               3 2      2 2        4
+--R           (12a c  - 12a b c + 2a b )x
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    3   3        2     4  2      2         3
+--R             ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x)
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                       2     3   3          2      4  2        2          3
+--R             ((- 8a b c  + 2b c)x  + (- 8a b c + 2b )x  + (- 8a b c + 2a b )x)
+--R          *
+--R             log(x)
+--R         + 
+--R                2 2       2   2        2          3       3     2 2
+--R           (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                              +-----------+
+--R         4 2    3 2   3      4       3 3  2      5     4 2    |          2
+--R     ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2105
+
+--S 2106 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3       2 2    4   3      2   2       3     5  2
+--R             (6a c  - 6a b c  + b c)x  + (6a b c  - 6a b c + b )x
+--R           + 
+--R                3 2     2 2       4
+--R             (6a c  - 6a b c + a b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                       2    3   3        2     4  2      2         3
+--R               ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x)
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                         2     3   3          2      4  2        2          3
+--R               ((- 8a b c  + 2b c)x  + (- 8a b c + 2b )x  + (- 8a b c + 2a b )x)
+--R            *
+--R               log(x)
+--R           + 
+--R                  2 2       2   2        2          3       3     2 2
+--R             (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x - 4a c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                                +-----------+
+--R           4 2    3 2   3      4       3 3  2      5     4 2    |          2
+--R       ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)\|- 4a c + b
+--R     ,
+--R
+--R                   2 3        2 2     4   3         2   2        3      5  2
+--R             (- 12a c  + 12a b c  - 2b c)x  + (- 12a b c  + 12a b c - 2b )x
+--R           + 
+--R                   3 2      2 2        4
+--R             (- 12a c  + 12a b c - 2a b )x
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2    3   3        2     4  2      2         3
+--R               ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x)
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                         2     3   3          2      4  2        2          3
+--R               ((- 8a b c  + 2b c)x  + (- 8a b c + 2b )x  + (- 8a b c + 2a b )x)
+--R            *
+--R               log(x)
+--R           + 
+--R                  2 2       2   2        2          3       3     2 2
+--R             (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x - 4a c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                +---------+
+--R           4 2    3 2   3      4       3 3  2      5     4 2    |        2
+--R       ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2106
+
+--S 2107 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (6a c  - 6a b c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R             2 2        2      4          2c x + b
+--R       (- 12a c  + 12a b c - 2b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R                   +-----------+
+--R        4     3 2  |          2
+--R     (4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2107
+
+--S 2108 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2108
+
+--S 2109 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------+
+--R             2 2        2      4  |        2          2c x + b
+--R       (- 12a c  + 12a b c - 2b )\|4a c - b  atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R                                  +-----------+                |        2
+--R             2 2        2      4  |          2      (2c x + b)\|4a c - b
+--R       (- 12a c  + 12a b c - 2b )\|- 4a c + b  atan(----------------------)
+--R                                                                   2
+--R                                                           4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R        4     3 2  |          2  |        2
+--R     (4a c - a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2109
+
+--S 2110 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2110
+
+)clear all
+
+--S 2111 of 2282
+t0:=1/((c+a/x^2+b/x)^2*x^7)
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R         2 7         6            2  5         4    2 3
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2111
+
+--S 2112 of 2282
+r0:=1/2*(-3*b^2+8*a*c)/(a^2*(b^2-4*a*c)*x^2)+b*(3*b^2-11*a*c)/_
+   (a^3*(b^2-4*a*c)*x)+(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^2*_
+   (a+b*x+c*x^2))+b*(3*b^4-20*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(3/2))+(3*b^2-2*a*c)*_
+   log(x)/a^4-1/2*(3*b^2-2*a*c)*log(a+b*x+c*x^2)/a^4
+--R 
+--R
+--R   (2)
+--R                 2   3        3 2     5   4         2 2 2        4      6  3
+--R           (- 60a b c  + 40a b c  - 6b c)x  + (- 60a b c  + 40a b c - 6b )x
+--R         + 
+--R                 3   2      2 3        5  2
+--R           (- 60a b c  + 40a b c - 6a b )x
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                  2 3        2 2     4   4      2   2        3      5  3
+--R               (8a c  - 14a b c  + 3b c)x  + (8a b c  - 14a b c + 3b )x
+--R             + 
+--R                  3 2      2 2        4  2
+--R               (8a c  - 14a b c + 3a b )x
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                     2 3        2 2     4   4         2   2        3      5  3
+--R               (- 16a c  + 28a b c  - 6b c)x  + (- 16a b c  + 28a b c - 6b )x
+--R             + 
+--R                     3 2      2 2        4  2
+--R               (- 16a c  + 28a b c - 6a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R               2   2       3   3        3 2      2 2        4  2
+--R           (22a b c  - 6a b c)x  + (- 8a c  + 25a b c - 6a b )x
+--R         + 
+--R               3        2 3       4     3 2
+--R           (12a b c - 3a b )x - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                  +-----------+
+--R         5 2     4 2   4      5        4 3  3      6      5 2  2  |          2
+--R     ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2112
+
+--S 2113 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   3        3 2     5   4       2 2 2        4      6  3
+--R             (30a b c  - 20a b c  + 3b c)x  + (30a b c  - 20a b c + 3b )x
+--R           + 
+--R                 3   2      2 3        5  2
+--R             (30a b c  - 20a b c + 3a b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                    2 3        2 2     4   4      2   2        3      5  3
+--R                 (8a c  - 14a b c  + 3b c)x  + (8a b c  - 14a b c + 3b )x
+--R               + 
+--R                    3 2      2 2        4  2
+--R                 (8a c  - 14a b c + 3a b )x
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                       2 3        2 2     4   4         2   2        3      5  3
+--R                 (- 16a c  + 28a b c  - 6b c)x  + (- 16a b c  + 28a b c - 6b )x
+--R               + 
+--R                       3 2      2 2        4  2
+--R                 (- 16a c  + 28a b c - 6a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                 2   2       3   3        3 2      2 2        4  2
+--R             (22a b c  - 6a b c)x  + (- 8a c  + 25a b c - 6a b )x
+--R           + 
+--R                 3        2 3       4     3 2
+--R             (12a b c - 3a b )x - 4a c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             5 2     4 2   4      5        4 3  3      6      5 2  2
+--R         ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                 2   3        3 2     5   4       2 2 2        4      6  3
+--R             (60a b c  - 40a b c  + 6b c)x  + (60a b c  - 40a b c + 6b )x
+--R           + 
+--R                 3   2      2 3        5  2
+--R             (60a b c  - 40a b c + 6a b )x
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                    2 3        2 2     4   4      2   2        3      5  3
+--R                 (8a c  - 14a b c  + 3b c)x  + (8a b c  - 14a b c + 3b )x
+--R               + 
+--R                    3 2      2 2        4  2
+--R                 (8a c  - 14a b c + 3a b )x
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                       2 3        2 2     4   4         2   2        3      5  3
+--R                 (- 16a c  + 28a b c  - 6b c)x  + (- 16a b c  + 28a b c - 6b )x
+--R               + 
+--R                       3 2      2 2        4  2
+--R                 (- 16a c  + 28a b c - 6a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                 2   2       3   3        3 2      2 2        4  2
+--R             (22a b c  - 6a b c)x  + (- 8a c  + 25a b c - 6a b )x
+--R           + 
+--R                 3        2 3       4     3 2
+--R             (12a b c - 3a b )x - 4a c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                    +---------+
+--R           5 2     4 2   4      5        4 3  3      6      5 2  2  |        2
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2113
+
+--S 2114 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2   2        3      5
+--R         (30a b c  - 20a b c + 3b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R           2   2        3      5          2c x + b
+--R       (60a b c  - 40a b c + 6b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R        5      4 2  |          2
+--R     (8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2114
+
+--S 2115 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2115
+
+--S 2116 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------+
+--R           2   2        3      5  |        2          2c x + b
+--R       (30a b c  - 20a b c + 3b )\|4a c - b  atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R                                  +-----------+                |        2
+--R           2   2        3      5  |          2      (2c x + b)\|4a c - b
+--R       (30a b c  - 20a b c + 3b )\|- 4a c + b  atan(----------------------)
+--R                                                                   2
+--R                                                           4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R        5     4 2  |          2  |        2
+--R     (4a c - a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2116
+
+--S 2117 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2117
+
+)clear all
+
+--S 2118 of 2282
+t0:=1/(c+a/x^2+b/x)^3
+--R 
+--R
+--R   (1)
+--R      6
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2118
+
+--S 2119 of 2282
+r0:=3*(b^4-7*a*b^2*c+10*a^2*c^2)*x/(c^3*(b^2-4*a*c)^2)-_
+   1/2*(b^2-2*a*c+a*b/x)*x/(c*(b^2-4*a*c)*(c+a/x^2+b/x)^2)-_
+   1/2*(3*b^4-20*a*b^2*c+20*a^2*c^2+3*a*b*(b^2-6*a*c)/x)*x/_
+   (c^2*(b^2-4*a*c)^2*(c+a/x^2+b/x))+3*(b^6-10*a*b^4*c+30*a^2*_
+   b^2*c^2-20*a^3*c^3)*atanh((b+2*a/x)/sqrt(b^2-4*a*c))/(c^4*_
+   (b^2-4*a*c)^(5/2))-3/2*b*log(c+a/x^2+b/x)/c^4-3*b*log(x)/c^4
+--R 
+--R
+--R   (2)
+--R                  3 5       2 2 4        4 3     6 2  4
+--R           (- 120a c  + 180a b c  - 60a b c  + 6b c )x
+--R         + 
+--R                  3   4       2 3 3         5 2      7   3
+--R           (- 240a b c  + 360a b c  - 120a b c  + 12b c)x
+--R         + 
+--R                  4 4       3 2 3      2 4 2        6      8  2
+--R           (- 240a c  + 240a b c  + 60a b c  - 48a b c + 6b )x
+--R         + 
+--R                  4   3       3 3 2       2 5         7         5 3       4 2 2
+--R           (- 240a b c  + 360a b c  - 120a b c + 12a b )x - 120a c  + 180a b c
+--R         + 
+--R                3 4      2 6
+--R           - 60a b c + 6a b
+--R      *
+--R                   b x + 2a
+--R         atanh(---------------)
+--R                 +-----------+
+--R                 |          2
+--R               x\|- 4a c + b
+--R     + 
+--R                     2   4        3 3     5 2  4
+--R               (- 96a b c  + 48a b c  - 6b c )x
+--R             + 
+--R                      2 2 3        4 2      6   3
+--R               (- 192a b c  + 96a b c  - 12b c)x
+--R             + 
+--R                      3   3        5      7  2
+--R               (- 192a b c  + 36a b c - 6b )x
+--R             + 
+--R                      3 2 2      2 4         6        4   2      3 3      2 5
+--R               (- 192a b c  + 96a b c - 12a b )x - 96a b c  + 48a b c - 6a b
+--R          *
+--R             log(x)
+--R         + 
+--R                     2   4        3 3     5 2  4
+--R               (- 48a b c  + 24a b c  - 3b c )x
+--R             + 
+--R                     2 2 3        4 2     6   3         3   3        5      7  2
+--R               (- 96a b c  + 48a b c  - 6b c)x  + (- 96a b c  + 18a b c - 3b )x
+--R             + 
+--R                     3 2 2      2 4        6        4   2      3 3      2 5
+--R               (- 96a b c  + 48a b c - 6a b )x - 48a b c  + 24a b c - 3a b
+--R          *
+--R                    2
+--R                 c x  + b x + a
+--R             log(--------------)
+--R                        2
+--R                       x
+--R         + 
+--R               2 5        2 4     4 3  5        2   4        3 3     5 2  4
+--R           (32a c  - 16a b c  + 2b c )x  + (122a b c  - 68a b c  + 9b c )x
+--R         + 
+--R                3 4      2 2 3        4 2     6   3
+--R           (100a c  + 14a b c  - 36a b c  + 6b c)x
+--R         + 
+--R                3   3      2 3 2        5   2       4 3      3 2 2     2 4
+--R           (138a b c  - 87a b c  + 12a b c)x  + (60a c  - 42a b c  + 6a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 8        2 7     4 6  4       2   7        3 6     5 5  3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R       + 
+--R             3 7        4 5     6 4  2       3   6      2 3 5       5 4
+--R         (64a c  - 12a b c  + 2b c )x  + (64a b c  - 32a b c  + 4a b c )x
+--R       + 
+--R            4 6      3 2 5     2 4 4
+--R         32a c  - 16a b c  + 2a b c
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2119
+
+--S 2120 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3 5      2 2 4        4 3     6 2  4
+--R             (60a c  - 90a b c  + 30a b c  - 3b c )x
+--R           + 
+--R                  3   4       2 3 3        5 2     7   3
+--R             (120a b c  - 180a b c  + 60a b c  - 6b c)x
+--R           + 
+--R                  4 4       3 2 3      2 4 2        6      8  2
+--R             (120a c  - 120a b c  - 30a b c  + 24a b c - 3b )x
+--R           + 
+--R                  4   3       3 3 2      2 5        7        5 3      4 2 2
+--R             (120a b c  - 180a b c  + 60a b c - 6a b )x + 60a c  - 90a b c
+--R           + 
+--R                3 4      2 6
+--R             30a b c - 3a b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                       2   4        3 3     5 2  4
+--R                 (- 48a b c  + 24a b c  - 3b c )x
+--R               + 
+--R                       2 2 3        4 2     6   3
+--R                 (- 96a b c  + 48a b c  - 6b c)x
+--R               + 
+--R                       3   3        5      7  2
+--R                 (- 96a b c  + 18a b c - 3b )x
+--R               + 
+--R                       3 2 2      2 4        6        4   2      3 3      2 5
+--R                 (- 96a b c  + 48a b c - 6a b )x - 48a b c  + 24a b c - 3a b
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                 2 5        2 4     4 3  5       2   4        3 3     5 2  4
+--R             (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R           + 
+--R                  3 4       2 2 3        4 2     6   3
+--R             (100a c  - 102a b c  + 36a b c  - 4b c)x
+--R           + 
+--R                 3   3      2 3 2        5      7  2
+--R             (22a b c  - 73a b c  + 38a b c - 5b )x
+--R           + 
+--R               4 3       3 2 2      2 4         6        4   2      3 3      2 5
+--R           (60a c  - 158a b c  + 78a b c - 10a b )x - 58a b c  + 36a b c - 5a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 8        2 7     4 6  4       2   7        3 6     5 5  3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R         + 
+--R               3 7        4 5     6 4  2       3   6      2 3 5       5 4
+--R           (64a c  - 12a b c  + 2b c )x  + (64a b c  - 32a b c  + 4a b c )x
+--R         + 
+--R              4 6      3 2 5     2 4 4
+--R           32a c  - 16a b c  + 2a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    3 5       2 2 4        4 3     6 2  4
+--R             (- 120a c  + 180a b c  - 60a b c  + 6b c )x
+--R           + 
+--R                    3   4       2 3 3         5 2      7   3
+--R             (- 240a b c  + 360a b c  - 120a b c  + 12b c)x
+--R           + 
+--R                    4 4       3 2 3      2 4 2        6      8  2
+--R             (- 240a c  + 240a b c  + 60a b c  - 48a b c + 6b )x
+--R           + 
+--R                    4   3       3 3 2       2 5         7         5 3
+--R             (- 240a b c  + 360a b c  - 120a b c + 12a b )x - 120a c
+--R           + 
+--R                 4 2 2      3 4      2 6
+--R             180a b c  - 60a b c + 6a b
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2   4        3 3     5 2  4
+--R                 (- 48a b c  + 24a b c  - 3b c )x
+--R               + 
+--R                       2 2 3        4 2     6   3
+--R                 (- 96a b c  + 48a b c  - 6b c)x
+--R               + 
+--R                       3   3        5      7  2
+--R                 (- 96a b c  + 18a b c - 3b )x
+--R               + 
+--R                       3 2 2      2 4        6        4   2      3 3      2 5
+--R                 (- 96a b c  + 48a b c - 6a b )x - 48a b c  + 24a b c - 3a b
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                 2 5        2 4     4 3  5       2   4        3 3     5 2  4
+--R             (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R           + 
+--R                  3 4       2 2 3        4 2     6   3
+--R             (100a c  - 102a b c  + 36a b c  - 4b c)x
+--R           + 
+--R                 3   3      2 3 2        5      7  2
+--R             (22a b c  - 73a b c  + 38a b c - 5b )x
+--R           + 
+--R               4 3       3 2 2      2 4         6        4   2      3 3      2 5
+--R           (60a c  - 158a b c  + 78a b c - 10a b )x - 58a b c  + 36a b c - 5a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 8        2 7     4 6  4       2   7        3 6     5 5  3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R         + 
+--R               3 7        4 5     6 4  2       3   6      2 3 5       5 4
+--R           (64a c  - 12a b c  + 2b c )x  + (64a b c  - 32a b c  + 4a b c )x
+--R         + 
+--R              4 6      3 2 5     2 4 4
+--R           32a c  - 16a b c  + 2a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2120
+
+--S 2121 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             3 3      2 2 2        4      6
+--R         (60a c  - 90a b c  + 30a b c - 3b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R            3 3       2 2 2        4      6           b x + 2a
+--R       (120a c  - 180a b c  + 60a b c - 6b )atanh(---------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                  x\|- 4a c + b
+--R     + 
+--R                 2   2        3      5        2
+--R           (- 48a b c  + 24a b c - 3b )log(c x  + b x + a)
+--R         + 
+--R               2   2        3      5
+--R           (96a b c  - 48a b c + 6b )log(x)
+--R         + 
+--R                                            2
+--R               2   2        3      5     c x  + b x + a       2   2        3
+--R           (48a b c  - 24a b c + 3b )log(--------------) - 58a b c  + 36a b c
+--R                                                2
+--R                                               x
+--R         + 
+--R               5
+--R           - 5b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                 +-----------+
+--R         2 6        2 5     4 4  |          2
+--R     (32a c  - 16a b c  + 2b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2121
+
+--S 2122 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2122
+
+--S 2123 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                             +---------+
+--R            3 3       2 2 2        4      6  |        2           b x + 2a
+--R       (120a c  - 180a b c  + 60a b c - 6b )\|4a c - b  atanh(---------------)
+--R                                                                +-----------+
+--R                                                                |          2
+--R                                                              x\|- 4a c + b
+--R     + 
+--R                                                 +-----------+
+--R                3 3       2 2 2        4      6  |          2
+--R         (- 120a c  + 180a b c  - 60a b c + 6b )\|- 4a c + b
+--R      *
+--R                         +---------+
+--R                         |        2
+--R              (2c x + b)\|4a c - b
+--R         atan(----------------------)
+--R                             2
+--R                     4a c - b
+--R     + 
+--R                 2   2        3      5        2
+--R           (- 48a b c  + 24a b c - 3b )log(c x  + b x + a)
+--R         + 
+--R               2   2        3      5
+--R           (96a b c  - 48a b c + 6b )log(x)
+--R         + 
+--R                                            2
+--R               2   2        3      5     c x  + b x + a       2   2        3
+--R           (48a b c  - 24a b c + 3b )log(--------------) - 58a b c  + 36a b c
+--R                                                2
+--R                                               x
+--R         + 
+--R               5
+--R           - 5b
+--R      *
+--R          +-----------+ +---------+
+--R          |          2  |        2
+--R         \|- 4a c + b  \|4a c - b
+--R  /
+--R                                 +-----------+ +---------+
+--R         2 6        2 5     4 4  |          2  |        2
+--R     (32a c  - 16a b c  + 2b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2123
+
+--S 2124 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2124
+
+)clear all
+
+--S 2125 of 2282
+t0:=1/((c+a/x^2+b/x)^3*x)
+--R 
+--R
+--R   (1)
+--R      5
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2125
+
+--S 2126 of 2282
+r0:=-b*(b^2-7*a*c)*x/(c^2*(b^2-4*a*c)^2)+1/2*(b^2-16*a*c)*x^2/_
+   (c*(b^2-4*a*c)^2)+1/2*x^4*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2)^2)+_
+   1/2*x^3*(6*a*b-(b^2-16*a*c)*x)/((b^2-4*a*c)^2*(a+b*x+c*x^2))+_
+   b*(b^4-10*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (c^3*(b^2-4*a*c)^(5/2))+1/2*log(a+b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  4        2 2 3        4 2     6   3
+--R           (60a b c  - 20a b c  + 2b c )x  + (120a b c  - 40a b c  + 4b c)x
+--R         + 
+--R                3   3      2 3 2        5      7  2
+--R           (120a b c  + 20a b c  - 16a b c + 2b )x
+--R         + 
+--R                3 2 2      2 4        6        4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )x + 60a b c  - 20a b c + 2a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2 4       2 3    4 2  4       2   3        3 2     5   3
+--R               (16a c  - 8a b c  + b c )x  + (32a b c  - 16a b c  + 2b c)x
+--R             + 
+--R                   3 3       4     6  2       3   2      2 3        5        4 2
+--R               (32a c  - 6a b c + b )x  + (32a b c  - 16a b c + 2a b )x + 16a c
+--R             + 
+--R                   3 2     2 4
+--R               - 8a b c + a b
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                 2 4        2 3     4 2  4      2   3        3 2     5   3
+--R           (- 24a c  + 21a b c  - 3b c )x  + (2a b c  + 12a b c  - 2b c)x
+--R         + 
+--R                 3 3      2 2 2       4   2       3   2     2 3
+--R           (- 16a c  + 29a b c  - 4a b c)x  + (14a b c  - 2a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 7        2 6     4 5  4       2   6        3 5     5 4  3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R       + 
+--R             3 6        4 4     6 3  2       3   5      2 3 4       5 3
+--R         (64a c  - 12a b c  + 2b c )x  + (64a b c  - 32a b c  + 4a b c )x
+--R       + 
+--R            4 5      3 2 4     2 4 3
+--R         32a c  - 16a b c  + 2a b c
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2126
+
+--S 2127 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   4        3 3    5 2  4       2 2 3        4 2     6   3
+--R             (30a b c  - 10a b c  + b c )x  + (60a b c  - 20a b c  + 2b c)x
+--R           + 
+--R                 3   3      2 3 2       5     7  2
+--R             (60a b c  + 10a b c  - 8a b c + b )x
+--R           + 
+--R                 3 2 2      2 4        6        4   2      3 3     2 5
+--R             (60a b c  - 20a b c + 2a b )x + 30a b c  - 10a b c + a b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                     2 4       2 3    4 2  4       2   3        3 2     5   3
+--R                 (16a c  - 8a b c  + b c )x  + (32a b c  - 16a b c  + 2b c)x
+--R               + 
+--R                     3 3       4     6  2       3   2      2 3        5
+--R                 (32a c  - 6a b c + b )x  + (32a b c  - 16a b c + 2a b )x
+--R               + 
+--R                    4 2     3 2     2 4
+--R                 16a c  - 8a b c + a b
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                 2   3        3 2     5   3
+--R             (50a b c  - 30a b c  + 4b c)x
+--R           + 
+--R                 3 3      2 2 2        4      6  2
+--R             (32a c  + 11a b c  - 19a b c + 3b )x
+--R           + 
+--R                 3   2      2 3        5        4 2      3 2      2 4
+--R             (62a b c  - 44a b c + 6a b )x + 24a c  - 21a b c + 3a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 7        2 6     4 5  4       2   6        3 5     5 4  3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R         + 
+--R               3 6        4 4     6 3  2       3   5      2 3 4       5 3
+--R           (64a c  - 12a b c  + 2b c )x  + (64a b c  - 32a b c  + 4a b c )x
+--R         + 
+--R              4 5      3 2 4     2 4 3
+--R           32a c  - 16a b c  + 2a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2   4        3 3     5 2  4
+--R             (- 60a b c  + 20a b c  - 2b c )x
+--R           + 
+--R                    2 2 3        4 2     6   3
+--R             (- 120a b c  + 40a b c  - 4b c)x
+--R           + 
+--R                    3   3      2 3 2        5      7  2
+--R             (- 120a b c  - 20a b c  + 16a b c - 2b )x
+--R           + 
+--R                    3 2 2      2 4        6        4   2      3 3      2 5
+--R             (- 120a b c  + 40a b c - 4a b )x - 60a b c  + 20a b c - 2a b
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                     2 4       2 3    4 2  4       2   3        3 2     5   3
+--R                 (16a c  - 8a b c  + b c )x  + (32a b c  - 16a b c  + 2b c)x
+--R               + 
+--R                     3 3       4     6  2       3   2      2 3        5
+--R                 (32a c  - 6a b c + b )x  + (32a b c  - 16a b c + 2a b )x
+--R               + 
+--R                    4 2     3 2     2 4
+--R                 16a c  - 8a b c + a b
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                 2   3        3 2     5   3
+--R             (50a b c  - 30a b c  + 4b c)x
+--R           + 
+--R                 3 3      2 2 2        4      6  2
+--R             (32a c  + 11a b c  - 19a b c + 3b )x
+--R           + 
+--R                 3   2      2 3        5        4 2      3 2      2 4
+--R             (62a b c  - 44a b c + 6a b )x + 24a c  - 21a b c + 3a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 7        2 6     4 5  4       2   6        3 5     5 4  3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R         + 
+--R               3 6        4 4     6 3  2       3   5      2 3 4       5 3
+--R           (64a c  - 12a b c  + 2b c )x  + (64a b c  - 32a b c  + 4a b c )x
+--R         + 
+--R              4 5      3 2 4     2 4 3
+--R           32a c  - 16a b c  + 2a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2127
+
+--S 2128 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2   2        3     5
+--R         (30a b c  - 10a b c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R             2   2        3      5          2c x + b
+--R       (- 60a b c  + 20a b c - 2b )atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R     + 
+--R                                +-----------+
+--R           2 2        2      4  |          2
+--R       (24a c  - 21a b c + 3b )\|- 4a c + b
+--R  /
+--R                                 +-----------+
+--R         2 5        2 4     4 3  |          2
+--R     (32a c  - 16a b c  + 2b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2128
+
+--S 2129 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2129
+
+--S 2130 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                    +---------+
+--R             2   2        3      5  |        2          2c x + b
+--R       (- 60a b c  + 20a b c - 2b )\|4a c - b  atanh(--------------)
+--R                                                      +-----------+
+--R                                                      |          2
+--R                                                     \|- 4a c + b
+--R     + 
+--R                                                                 +---------+
+--R                                    +-----------+                |        2
+--R             2   2        3      5  |          2      (2c x + b)\|4a c - b
+--R       (- 60a b c  + 20a b c - 2b )\|- 4a c + b  atan(----------------------)
+--R                                                                     2
+--R                                                             4a c - b
+--R     + 
+--R                                +-----------+ +---------+
+--R           2 2        2      4  |          2  |        2
+--R       (24a c  - 21a b c + 3b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                                 +-----------+ +---------+
+--R         2 5        2 4     4 3  |          2  |        2
+--R     (32a c  - 16a b c  + 2b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2130
+
+--S 2131 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2131
+
+)clear all
+
+--S 2132 of 2282
+t0:=1/((c+a/x^2+b/x)^3*x^2)
+--R 
+--R
+--R   (1)
+--R      4
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2132
+
+--S 2133 of 2282
+r0:=1/2*(b+2*a/x)/((b^2-4*a*c)*(c+a/x^2+b/x)^2)-_
+   3*a*(b+2*a/x)/((b^2-4*a*c)^2*(c+a/x^2+b/x))+_
+   12*a^2*atanh((b+2*a/x)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R             2 2 4      2     3       3       2 2  2      3         4
+--R         (24a c x  + 48a b c x  + (48a c + 24a b )x  + 48a b x + 24a )
+--R      *
+--R                   b x + 2a
+--R         atanh(---------------)
+--R                 +-----------+
+--R                 |          2
+--R               x\|- 4a c + b
+--R     + 
+--R                                                                   +-----------+
+--R                    3  4         2        2  3      2   2      3   |          2
+--R     ((- 10a b c + b )x  + (- 20a c - 4a b )x  - 18a b x  - 12a x)\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2133
+
+--S 2134 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               2 4 4      2   3 3       3 3      2 2 2  2      3   2       4 2
+--R           (12a c x  + 24a b c x  + (24a c  + 12a b c )x  + 24a b c x + 12a c )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                   2 3        2 2     4   3      2   2       3     5  2
+--R             (- 20a c  + 16a b c  - 2b c)x  + (2a b c  + 8a b c - b )x
+--R           + 
+--R                   3 2      2 2        4        3       2 3
+--R             (- 12a c  + 20a b c - 2a b )x + 10a b c - a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 6        2 5     4 4  4       2   5        3 4     5 3  3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R         + 
+--R               3 5        4 3     6 2  2       3   4      2 3 3       5 2
+--R           (64a c  - 12a b c  + 2b c )x  + (64a b c  - 32a b c  + 4a b c )x
+--R         + 
+--R              4 4      3 2 3     2 4 2
+--R           32a c  - 16a b c  + 2a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R               2 4 4      2   3 3       3 3      2 2 2  2      3   2       4 2
+--R           (24a c x  + 48a b c x  + (48a c  + 24a b c )x  + 48a b c x + 24a c )
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                   2 3        2 2     4   3      2   2       3     5  2
+--R             (- 20a c  + 16a b c  - 2b c)x  + (2a b c  + 8a b c - b )x
+--R           + 
+--R                   3 2      2 2        4        3       2 3
+--R             (- 12a c  + 20a b c - 2a b )x + 10a b c - a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 6        2 5     4 4  4       2   5        3 4     5 3  3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R         + 
+--R               3 5        4 3     6 2  2       3   4      2 3 3       5 2
+--R           (64a c  - 12a b c  + 2b c )x  + (64a b c  - 32a b c  + 4a b c )x
+--R         + 
+--R              4 4      3 2 3     2 4 2
+--R           32a c  - 16a b c  + 2a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2134
+
+--S 2135 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2
+--R         12a c
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                                                       +-----------+
+--R            2 2          b x + 2a                   3  |          2
+--R       - 24a c atanh(---------------) + (10a b c - b )\|- 4a c + b
+--R                       +-----------+
+--R                       |          2
+--R                     x\|- 4a c + b
+--R  /
+--R                                 +-----------+
+--R         2 4        2 3     4 2  |          2
+--R     (32a c  - 16a b c  + 2b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2135
+
+--S 2136 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2136
+
+--S 2137 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                +---------+
+--R            2 2 |        2           b x + 2a
+--R       - 24a c \|4a c - b  atanh(---------------)
+--R                                   +-----------+
+--R                                   |          2
+--R                                 x\|- 4a c + b
+--R     + 
+--R                                           +---------+
+--R              +-----------+                |        2
+--R          2 2 |          2      (2c x + b)\|4a c - b
+--R       24a c \|- 4a c + b  atan(----------------------)
+--R                                               2
+--R                                       4a c - b
+--R     + 
+--R                      +-----------+ +---------+
+--R                   3  |          2  |        2
+--R       (10a b c - b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                                 +-----------+ +---------+
+--R         2 4        2 3     4 2  |          2  |        2
+--R     (32a c  - 16a b c  + 2b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2137
+
+--S 2138 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2138
+
+)clear all
+
+--S 2139 of 2282
+t0:=1/((c+a/x^2+b/x)^3*x^3)
+--R 
+--R
+--R   (1)
+--R      3
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2139
+
+--S 2140 of 2282
+r0:=-1/2*x^3*(b+2*c*x)/((b^2-4*a*c)*(a+b*x+c*x^2)^2)+3/2*b*x*(2*a+b*x)/_
+   ((b^2-4*a*c)^2*(a+b*x+c*x^2))+6*a*b*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                 2 4        2   3       2           3  2      2 2       3
+--R         (12a b c x  + 24a b c x  + (24a b c + 12a b )x  + 24a b x + 12a b)
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                                +-----------+
+--R             2    2   4                3  3       2 2     2     |          2
+--R       ((8a c  + b c)x  + (10a b c + 2b )x  + 9a b x  + 6a b x)\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2140
+
+--S 2141 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3 4        2 2 3       2   2       3   2      2 2        3
+--R           (6a b c x  + 12a b c x  + (12a b c  + 6a b c)x  + 12a b c x + 6a b c)
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                     2 3         2 2      2     4  2         2          3
+--R             - 6a b c x  + (- 16a c  - a b c - b )x  + (- 10a b c - 2a b )x
+--R           + 
+--R                 3     2 2
+--R             - 8a c - a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 5        2 4     4 3  4       2   4        3 3     5 2  3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R         + 
+--R               3 4        4 2     6   2       3   3      2 3 2       5
+--R           (64a c  - 12a b c  + 2b c)x  + (64a b c  - 32a b c  + 4a b c)x
+--R         + 
+--R              4 3      3 2 2     2 4
+--R           32a c  - 16a b c  + 2a b c
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                      3 4        2 2 3         2   2        3   2      2 2
+--R             - 12a b c x  - 24a b c x  + (- 24a b c  - 12a b c)x  - 24a b c x
+--R           + 
+--R                  3
+--R             - 12a b c
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                     2 3         2 2      2     4  2         2          3
+--R             - 6a b c x  + (- 16a c  - a b c - b )x  + (- 10a b c - 2a b )x
+--R           + 
+--R                 3     2 2
+--R             - 8a c - a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 5        2 4     4 3  4       2   4        3 3     5 2  3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R         + 
+--R               3 4        4 2     6   2       3   3      2 3 2       5
+--R           (64a c  - 12a b c  + 2b c)x  + (64a b c  - 32a b c  + 4a b c)x
+--R         + 
+--R              4 3      3 2 2     2 4
+--R           32a c  - 16a b c  + 2a b c
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2141
+
+--S 2142 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         6a b c
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                                                       +-----------+
+--R                          2c x + b                  2  |          2
+--R       - 12a b c atanh(--------------) + (- 8a c - b )\|- 4a c + b
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R  /
+--R                                +-----------+
+--R         2 3        2 2     4   |          2
+--R     (32a c  - 16a b c  + 2b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2142
+
+--S 2143 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2143
+
+--S 2144 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 +---------+
+--R                 |        2          2c x + b
+--R       - 12a b c\|4a c - b  atanh(--------------)
+--R                                   +-----------+
+--R                                   |          2
+--R                                  \|- 4a c + b
+--R     + 
+--R                                              +---------+
+--R                 +-----------+                |        2
+--R                 |          2      (2c x + b)\|4a c - b
+--R       - 12a b c\|- 4a c + b  atan(----------------------)
+--R                                                  2
+--R                                          4a c - b
+--R     + 
+--R                     +-----------+ +---------+
+--R                  2  |          2  |        2
+--R       (- 8a c - b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                                +-----------+ +---------+
+--R         2 3        2 2     4   |          2  |        2
+--R     (32a c  - 16a b c  + 2b c)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2144
+
+--S 2145 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2145
+
+)clear all
+
+--S 2146 of 2282
+t0:=1/((c+a/x^2+b/x)^3*x^4)
+--R 
+--R
+--R   (1)
+--R      2
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2146
+
+--S 2147 of 2282
+r0:=1/2*x^3*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*(a+b*x+c*x^2)^2)-_
+   1/2*(b^2+2*a*c)*x*(2*a+b*x)/(a*(b^2-4*a*c)^2*(a+b*x+c*x^2))-_
+   2*(b^2+2*a*c)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                  3     2 2  4             2     3   3
+--R           (- 8a c  - 4b c )x  + (- 16a b c  - 8b c)x
+--R         + 
+--R                 2 2        2      4  2         2          3       3      2 2
+--R           (- 16a c  - 16a b c - 4b )x  + (- 16a b c - 8a b )x - 8a c - 4a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2 4        2      2   3                 3  2
+--R             - 6b c x  + (4a c  - 10b c)x  + (- 6a b c - 3b )x
+--R           + 
+--R                  2        2
+--R             (- 4a c - 2a b )x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2147
+
+--S 2148 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3     2 2  4          2     3   3      2 2       2      4  2
+--R             (4a c  + 2b c )x  + (8a b c  + 4b c)x  + (8a c  + 8a b c + 2b )x
+--R           + 
+--R                2          3       3      2 2
+--R             (8a b c + 4a b )x + 4a c + 2a b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                 2     2   3               3  2        2         2       2
+--R           ((4a c  + 2b c)x  + (6a b c + 3b )x  + (- 4a c + 10a b )x + 6a b)
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  4       2   3        3 2     5   3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R         + 
+--R               3 3        4      6  2       3   2      2 3        5        4 2
+--R           (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                3 2      2 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                  3     2 2  4           2     3   3
+--R             (8a c  + 4b c )x  + (16a b c  + 8b c)x
+--R           + 
+--R                 2 2        2      4  2       2          3       3      2 2
+--R             (16a c  + 16a b c + 4b )x  + (16a b c + 8a b )x + 8a c + 4a b
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                 2     2   3               3  2        2         2       2
+--R           ((4a c  + 2b c)x  + (6a b c + 3b )x  + (- 4a c + 10a b )x + 6a b)
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               2 4        2 3     4 2  4       2   3        3 2     5   3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R         + 
+--R               3 3        4      6  2       3   2      2 3        5        4 2
+--R           (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                3 2      2 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2148
+
+--S 2149 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                                              +-----------+
+--R                 2          2c x + b          |          2
+--R       (4a c + 2b )atanh(--------------) + 3b\|- 4a c + b
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R  /
+--R                            +-----------+
+--R         2 2       2     4  |          2
+--R     (16a c  - 8a b c + b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2149
+
+--S 2150 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2150
+
+--S 2151 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    +---------+
+--R                 2  |        2          2c x + b
+--R       (4a c + 2b )\|4a c - b  atanh(--------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R     + 
+--R                                                 +---------+
+--R                    +-----------+                |        2
+--R                 2  |          2      (2c x + b)\|4a c - b
+--R       (4a c + 2b )\|- 4a c + b  atan(----------------------)
+--R                                                     2
+--R                                             4a c - b
+--R     + 
+--R          +-----------+ +---------+
+--R          |          2  |        2
+--R       3b\|- 4a c + b  \|4a c - b
+--R  /
+--R                            +-----------+ +---------+
+--R         2 2       2     4  |          2  |        2
+--R     (16a c  - 8a b c + b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2151
+
+--S 2152 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2152
+
+)clear all
+
+--S 2153 of 2282
+t0:=1/((c+a/x^2+b/x)^3*x^5)
+--R 
+--R
+--R   (1)
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2153
+
+--S 2154 of 2282
+r0:=1/2*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2)^2)-3/2*b*(b+2*c*x)/_
+   ((b^2-4*a*c)^2*(a+b*x+c*x^2))+6*b*c*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R               3 4      2 2 3           2      3   2        2         2
+--R         (12b c x  + 24b c x  + (24a b c  + 12b c)x  + 24a b c x + 12a b c)
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                                +-----------+
+--R              2 3     2   2                  3       2       2  |          2
+--R       (- 6b c x  - 9b c x  + (- 10a b c - 2b )x - 8a c - a b )\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2154
+
+--S 2155 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                3 4      2 2 3           2     3   2        2        2
+--R           (6b c x  + 12b c x  + (12a b c  + 6b c)x  + 12a b c x + 6a b c)
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                                                  +-----------+
+--R                2 3     2   2                  3       2       2  |          2
+--R         (- 6b c x  - 9b c x  + (- 10a b c - 2b )x - 8a c - a b )\|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  4       2   3        3 2     5   3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R         + 
+--R               3 3        4      6  2       3   2      2 3        5        4 2
+--R           (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                3 2      2 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                      3 4      2 2 3             2      3   2        2
+--R               - 12b c x  - 24b c x  + (- 24a b c  - 12b c)x  - 24a b c x
+--R             + 
+--R                    2
+--R               - 12a b c
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                                                                  +---------+
+--R                2 3     2   2                  3       2       2  |        2
+--R         (- 6b c x  - 9b c x  + (- 10a b c - 2b )x - 8a c - a b )\|4a c - b
+--R    /
+--R               2 4        2 3     4 2  4       2   3        3 2     5   3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R         + 
+--R               3 3        4      6  2       3   2      2 3        5        4 2
+--R           (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                3 2      2 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2155
+
+--S 2156 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         3b c
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                       2c x + b
+--R       - 6b c atanh(--------------)
+--R                     +-----------+
+--R                     |          2
+--R                    \|- 4a c + b
+--R  /
+--R                            +-----------+
+--R         2 2       2     4  |          2
+--R     (16a c  - 8a b c + b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2156
+
+--S 2157 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2157
+
+--S 2158 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              +---------+
+--R              |        2          2c x + b
+--R       - 6b c\|4a c - b  atanh(--------------)
+--R                                +-----------+
+--R                                |          2
+--R                               \|- 4a c + b
+--R     + 
+--R                                           +---------+
+--R              +-----------+                |        2
+--R              |          2      (2c x + b)\|4a c - b
+--R       - 6b c\|- 4a c + b  atan(----------------------)
+--R                                               2
+--R                                       4a c - b
+--R  /
+--R                            +-----------+ +---------+
+--R         2 2       2     4  |          2  |        2
+--R     (16a c  - 8a b c + b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2158
+
+--S 2159 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2159
+
+)clear all
+
+--S 2160 of 2282
+t0:=1/((c+a/x^2+b/x)^3*x^6)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2160
+
+--S 2161 of 2282
+r0:=1/2*(-b-2*c*x)/((b^2-4*a*c)*(a+b*x+c*x^2)^2)+3*c*(b+2*c*x)/_
+   ((b^2-4*a*c)^2*(a+b*x+c*x^2))-12*c^2*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R               4 4        3 3           3      2 2  2          2       2 2
+--R         (- 24c x  - 48b c x  + (- 48a c  - 24b c )x  - 48a b c x - 24a c )
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                             +-----------+
+--R           3 3        2 2         2     2                 3  |          2
+--R       (12c x  + 18b c x  + (20a c  + 4b c)x + 10a b c - b )\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2161
+
+--S 2162 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               4 4        3 3         3      2 2  2          2       2 2
+--R           (12c x  + 24b c x  + (24a c  + 12b c )x  + 24a b c x + 12a c )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                                               +-----------+
+--R             3 3        2 2         2     2                 3  |          2
+--R         (12c x  + 18b c x  + (20a c  + 4b c)x + 10a b c - b )\|- 4a c + b
+--R    /
+--R               2 4        2 3     4 2  4       2   3        3 2     5   3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R         + 
+--R               3 3        4      6  2       3   2      2 3        5        4 2
+--R           (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                3 2      2 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R               4 4        3 3         3      2 2  2          2       2 2
+--R           (24c x  + 48b c x  + (48a c  + 24b c )x  + 48a b c x + 24a c )
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                                                               +---------+
+--R             3 3        2 2         2     2                 3  |        2
+--R         (12c x  + 18b c x  + (20a c  + 4b c)x + 10a b c - b )\|4a c - b
+--R    /
+--R               2 4        2 3     4 2  4       2   3        3 2     5   3
+--R           (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R         + 
+--R               3 3        4      6  2       3   2      2 3        5        4 2
+--R           (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                3 2      2 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2162
+
+--S 2163 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           2
+--R         6c
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R          2         2c x + b
+--R       12c atanh(--------------)
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R  /
+--R                            +-----------+
+--R         2 2       2     4  |          2
+--R     (16a c  - 8a b c + b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2163
+
+--S 2164 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2164
+
+--S 2165 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            +---------+
+--R          2 |        2          2c x + b
+--R       12c \|4a c - b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R            +-----------+                |        2
+--R          2 |          2      (2c x + b)\|4a c - b
+--R       12c \|- 4a c + b  atan(----------------------)
+--R                                             2
+--R                                     4a c - b
+--R  /
+--R                            +-----------+ +---------+
+--R         2 2       2     4  |          2  |        2
+--R     (16a c  - 8a b c + b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2165
+
+--S 2166 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2166
+
+)clear all
+
+--S 2167 of 2282
+t0:=1/((c+a/x^2+b/x)^3*x^7)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 7       2 6        2     2   5              3  4      2        2  3
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2167
+
+--S 2168 of 2282
+r0:=1/2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*(a+b*x+c*x^2)^2)+_
+   1/2*(2*b^4-15*a*b^2*c+16*a^2*c^2+2*b*c*(b^2-7*a*c)*x)/_
+   (a^2*(b^2-4*a*c)^2*(a+b*x+c*x^2))+b*(b^4-10*a*b^2*c+30*a^2*c^2)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(5/2))+_
+   log(x)/a^3-1/2*log(a+b*x+c*x^2)/a^3
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  4        2 2 3        4 2     6   3
+--R           (60a b c  - 20a b c  + 2b c )x  + (120a b c  - 40a b c  + 4b c)x
+--R         + 
+--R                3   3      2 3 2        5      7  2
+--R           (120a b c  + 20a b c  - 16a b c + 2b )x
+--R         + 
+--R                3 2 2      2 4        6        4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )x + 60a b c  - 20a b c + 2a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2 4       2 3    4 2  4         2   3        3 2     5   3
+--R               (- 16a c  + 8a b c  - b c )x  + (- 32a b c  + 16a b c  - 2b c)x
+--R             + 
+--R                     3 3       4     6  2         3   2      2 3        5
+--R               (- 32a c  + 6a b c - b )x  + (- 32a b c  + 16a b c - 2a b )x
+--R             + 
+--R                    4 2     3 2     2 4
+--R               - 16a c  + 8a b c - a b
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                   2 4        2 3     4 2  4       2   3        3 2     5   3
+--R               (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R             + 
+--R                   3 3        4      6  2       3   2      2 3        5
+--R               (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x
+--R             + 
+--R                  4 2      3 2      2 4
+--R               32a c  - 16a b c + 2a b
+--R          *
+--R             log(x)
+--R         + 
+--R                 2   3       3 2  3       3 3      2 2 2       4   2
+--R           (- 14a b c  + 2a b c )x  + (16a c  - 29a b c  + 4a b c)x
+--R         + 
+--R                3   2      2 3        5        4 2      3 2      2 4
+--R           (- 2a b c  - 12a b c + 2a b )x + 24a c  - 21a b c + 3a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             5 4      4 2 3     3 4 2  4       5   3      4 3 2     3 5   3
+--R         (32a c  - 16a b c  + 2a b c )x  + (64a b c  - 32a b c  + 4a b c)x
+--R       + 
+--R             6 3      4 4      3 6  2       6   2      5 3      4 5        7 2
+--R         (64a c  - 12a b c + 2a b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              6 2      5 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2168
+
+--S 2169 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   4        3 3    5 2  4       2 2 3        4 2     6   3
+--R             (30a b c  - 10a b c  + b c )x  + (60a b c  - 20a b c  + 2b c)x
+--R           + 
+--R                 3   3      2 3 2       5     7  2
+--R             (60a b c  + 10a b c  - 8a b c + b )x
+--R           + 
+--R                 3 2 2      2 4        6        4   2      3 3     2 5
+--R             (60a b c  - 20a b c + 2a b )x + 30a b c  - 10a b c + a b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                       2 4       2 3    4 2  4
+--R                 (- 16a c  + 8a b c  - b c )x
+--R               + 
+--R                       2   3        3 2     5   3         3 3       4     6  2
+--R                 (- 32a b c  + 16a b c  - 2b c)x  + (- 32a c  + 6a b c - b )x
+--R               + 
+--R                       3   2      2 3        5        4 2     3 2     2 4
+--R                 (- 32a b c  + 16a b c - 2a b )x - 16a c  + 8a b c - a b
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                     2 4        2 3     4 2  4       2   3        3 2     5   3
+--R                 (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R               + 
+--R                     3 3        4      6  2       3   2      2 3        5
+--R                 (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x
+--R               + 
+--R                    4 2      3 2      2 4
+--R                 32a c  - 16a b c + 2a b
+--R            *
+--R               log(x)
+--R           + 
+--R                   2   3       3 2  3       3 3      2 2 2       4   2
+--R             (- 14a b c  + 2a b c )x  + (16a c  - 29a b c  + 4a b c)x
+--R           + 
+--R                  3   2      2 3        5        4 2      3 2      2 4
+--R             (- 2a b c  - 12a b c + 2a b )x + 24a c  - 21a b c + 3a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               5 4      4 2 3     3 4 2  4       5   3      4 3 2     3 5   3
+--R           (32a c  - 16a b c  + 2a b c )x  + (64a b c  - 32a b c  + 4a b c)x
+--R         + 
+--R               6 3      4 4      3 6  2       6   2      5 3      4 5        7 2
+--R           (64a c  - 12a b c + 2a b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                6 2      5 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2   4        3 3     5 2  4
+--R             (- 60a b c  + 20a b c  - 2b c )x
+--R           + 
+--R                    2 2 3        4 2     6   3
+--R             (- 120a b c  + 40a b c  - 4b c)x
+--R           + 
+--R                    3   3      2 3 2        5      7  2
+--R             (- 120a b c  - 20a b c  + 16a b c - 2b )x
+--R           + 
+--R                    3 2 2      2 4        6        4   2      3 3      2 5
+--R             (- 120a b c  + 40a b c - 4a b )x - 60a b c  + 20a b c - 2a b
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2 4       2 3    4 2  4
+--R                 (- 16a c  + 8a b c  - b c )x
+--R               + 
+--R                       2   3        3 2     5   3         3 3       4     6  2
+--R                 (- 32a b c  + 16a b c  - 2b c)x  + (- 32a c  + 6a b c - b )x
+--R               + 
+--R                       3   2      2 3        5        4 2     3 2     2 4
+--R                 (- 32a b c  + 16a b c - 2a b )x - 16a c  + 8a b c - a b
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                     2 4        2 3     4 2  4       2   3        3 2     5   3
+--R                 (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R               + 
+--R                     3 3        4      6  2       3   2      2 3        5
+--R                 (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x
+--R               + 
+--R                    4 2      3 2      2 4
+--R                 32a c  - 16a b c + 2a b
+--R            *
+--R               log(x)
+--R           + 
+--R                   2   3       3 2  3       3 3      2 2 2       4   2
+--R             (- 14a b c  + 2a b c )x  + (16a c  - 29a b c  + 4a b c)x
+--R           + 
+--R                  3   2      2 3        5        4 2      3 2      2 4
+--R             (- 2a b c  - 12a b c + 2a b )x + 24a c  - 21a b c + 3a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               5 4      4 2 3     3 4 2  4       5   3      4 3 2     3 5   3
+--R           (32a c  - 16a b c  + 2a b c )x  + (64a b c  - 32a b c  + 4a b c)x
+--R         + 
+--R               6 3      4 4      3 6  2       6   2      5 3      4 5        7 2
+--R           (64a c  - 12a b c + 2a b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R         + 
+--R                6 2      5 4
+--R           - 16a b c + 2a b
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2169
+
+--S 2170 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2   2        3     5
+--R         (30a b c  - 10a b c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R             2   2        3      5          2c x + b
+--R       (- 60a b c  + 20a b c - 2b )atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R  /
+--R                                +-----------+
+--R         5 2      4 2      3 4  |          2
+--R     (32a c  - 16a b c + 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2170
+
+--S 2171 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2171
+
+--S 2172 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                   +---------+
+--R             2   2        3     5  |        2          2c x + b
+--R       (- 30a b c  + 10a b c - b )\|4a c - b  atanh(--------------)
+--R                                                     +-----------+
+--R                                                     |          2
+--R                                                    \|- 4a c + b
+--R     + 
+--R                                                                +---------+
+--R                                   +-----------+                |        2
+--R             2   2        3     5  |          2      (2c x + b)\|4a c - b
+--R       (- 30a b c  + 10a b c - b )\|- 4a c + b  atan(----------------------)
+--R                                                                    2
+--R                                                            4a c - b
+--R  /
+--R                              +-----------+ +---------+
+--R         5 2     4 2     3 4  |          2  |        2
+--R     (16a c  - 8a b c + a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2172
+
+--S 2173 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2173
+
+)clear all
+
+--S 2174 of 2282
+t0:=1/((c+a/x^2+b/x)^3*x^8)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 8       2 7        2     2   6              3  5      2        2  4
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   3    3 2
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2174
+
+--S 2175 of 2282
+r0:=-3*(b^4-7*a*b^2*c+10*a^2*c^2)/(a^3*(b^2-4*a*c)^2*x)+_
+   1/2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x*(a+b*x+c*x^2)^2)+_
+   1/2*(3*b^4-20*a*b^2*c+20*a^2*c^2+3*b*c*(b^2-6*a*c)*x)/(a^2*_
+   (b^2-4*a*c)^2*x*(a+b*x+c*x^2))-3*(b^6-10*a*b^4*c+30*a^2*b^2*c^2-_
+   20*a^3*c^3)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(5/2))-_
+   3*b*log(x)/a^4+3/2*b*log(a+b*x+c*x^2)/a^4
+--R 
+--R
+--R   (2)
+--R                3 5       2 2 4        4 3     6 2  5
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )x
+--R         + 
+--R                3   4       2 3 3         5 2      7   4
+--R           (240a b c  - 360a b c  + 120a b c  - 12b c)x
+--R         + 
+--R                4 4       3 2 3      2 4 2        6      8  3
+--R           (240a c  - 240a b c  - 60a b c  + 48a b c - 6b )x
+--R         + 
+--R                4   3       3 3 2       2 5         7  2
+--R           (240a b c  - 360a b c  + 120a b c - 12a b )x
+--R         + 
+--R                5 3       4 2 2      3 4      2 6
+--R           (120a c  - 180a b c  + 60a b c - 6a b )x
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2   4        3 3     5 2  5       2 2 3        4 2     6   4
+--R               (48a b c  - 24a b c  + 3b c )x  + (96a b c  - 48a b c  + 6b c)x
+--R             + 
+--R                   3   3        5      7  3       3 2 2      2 4        6  2
+--R               (96a b c  - 18a b c + 3b )x  + (96a b c  - 48a b c + 6a b )x
+--R             + 
+--R                   4   2      3 3      2 5
+--R               (48a b c  - 24a b c + 3a b )x
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                     2   4        3 3     5 2  5
+--R               (- 96a b c  + 48a b c  - 6b c )x
+--R             + 
+--R                      2 2 3        4 2      6   4
+--R               (- 192a b c  + 96a b c  - 12b c)x
+--R             + 
+--R                      3   3        5      7  3
+--R               (- 192a b c  + 36a b c - 6b )x
+--R             + 
+--R                      3 2 2      2 4         6  2
+--R               (- 192a b c  + 96a b c - 12a b )x
+--R             + 
+--R                     4   2      3 3      2 5
+--R               (- 96a b c  + 48a b c - 6a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R                 3 4      2 2 3       4 2  4
+--R           (- 60a c  + 42a b c  - 6a b c )x
+--R         + 
+--R                  3   3      2 3 2        5   3
+--R           (- 138a b c  + 87a b c  - 12a b c)x
+--R         + 
+--R                  4 3      3 2 2      2 4        6  2
+--R           (- 100a c  - 14a b c  + 36a b c - 6a b )x
+--R         + 
+--R                  4   2      3 3      2 5        5 2      4 2      3 4
+--R           (- 122a b c  + 68a b c - 9a b )x - 32a c  + 16a b c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             6 4      5 2 3     4 4 2  5       6   3      5 3 2     4 5   4
+--R         (32a c  - 16a b c  + 2a b c )x  + (64a b c  - 32a b c  + 4a b c)x
+--R       + 
+--R             7 3      5 4      4 6  3       7   2      6 3      5 5  2
+--R         (64a c  - 12a b c + 2a b )x  + (64a b c  - 32a b c + 4a b )x
+--R       + 
+--R             8 2      7 2      6 4
+--R         (32a c  - 16a b c + 2a b )x
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2175
+
+--S 2176 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3 5      2 2 4        4 3     6 2  5
+--R             (60a c  - 90a b c  + 30a b c  - 3b c )x
+--R           + 
+--R                  3   4       2 3 3        5 2     7   4
+--R             (120a b c  - 180a b c  + 60a b c  - 6b c)x
+--R           + 
+--R                  4 4       3 2 3      2 4 2        6      8  3
+--R             (120a c  - 120a b c  - 30a b c  + 24a b c - 3b )x
+--R           + 
+--R                  4   3       3 3 2      2 5        7  2
+--R             (120a b c  - 180a b c  + 60a b c - 6a b )x
+--R           + 
+--R                 5 3      4 2 2      3 4      2 6
+--R             (60a c  - 90a b c  + 30a b c - 3a b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                     2   4        3 3     5 2  5
+--R                 (48a b c  - 24a b c  + 3b c )x
+--R               + 
+--R                     2 2 3        4 2     6   4       3   3        5      7  3
+--R                 (96a b c  - 48a b c  + 6b c)x  + (96a b c  - 18a b c + 3b )x
+--R               + 
+--R                     3 2 2      2 4        6  2       4   2      3 3      2 5
+--R                 (96a b c  - 48a b c + 6a b )x  + (48a b c  - 24a b c + 3a b )x
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                       2   4        3 3     5 2  5
+--R                 (- 96a b c  + 48a b c  - 6b c )x
+--R               + 
+--R                        2 2 3        4 2      6   4
+--R                 (- 192a b c  + 96a b c  - 12b c)x
+--R               + 
+--R                        3   3        5      7  3
+--R                 (- 192a b c  + 36a b c - 6b )x
+--R               + 
+--R                        3 2 2      2 4         6  2
+--R                 (- 192a b c  + 96a b c - 12a b )x
+--R               + 
+--R                       4   2      3 3      2 5
+--R                 (- 96a b c  + 48a b c - 6a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                   3 4      2 2 3       4 2  4
+--R             (- 60a c  + 42a b c  - 6a b c )x
+--R           + 
+--R                    3   3      2 3 2        5   3
+--R             (- 138a b c  + 87a b c  - 12a b c)x
+--R           + 
+--R                    4 3      3 2 2      2 4        6  2
+--R             (- 100a c  - 14a b c  + 36a b c - 6a b )x
+--R           + 
+--R                    4   2      3 3      2 5        5 2      4 2      3 4
+--R             (- 122a b c  + 68a b c - 9a b )x - 32a c  + 16a b c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R               6 4      5 2 3     4 4 2  5       6   3      5 3 2     4 5   4
+--R           (32a c  - 16a b c  + 2a b c )x  + (64a b c  - 32a b c  + 4a b c)x
+--R         + 
+--R               7 3      5 4      4 6  3       7   2      6 3      5 5  2
+--R           (64a c  - 12a b c + 2a b )x  + (64a b c  - 32a b c + 4a b )x
+--R         + 
+--R               8 2      7 2      6 4
+--R           (32a c  - 16a b c + 2a b )x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    3 5       2 2 4        4 3     6 2  5
+--R             (- 120a c  + 180a b c  - 60a b c  + 6b c )x
+--R           + 
+--R                    3   4       2 3 3         5 2      7   4
+--R             (- 240a b c  + 360a b c  - 120a b c  + 12b c)x
+--R           + 
+--R                    4 4       3 2 3      2 4 2        6      8  3
+--R             (- 240a c  + 240a b c  + 60a b c  - 48a b c + 6b )x
+--R           + 
+--R                    4   3       3 3 2       2 5         7  2
+--R             (- 240a b c  + 360a b c  - 120a b c + 12a b )x
+--R           + 
+--R                    5 3       4 2 2      3 4      2 6
+--R             (- 120a c  + 180a b c  - 60a b c + 6a b )x
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                     2   4        3 3     5 2  5
+--R                 (48a b c  - 24a b c  + 3b c )x
+--R               + 
+--R                     2 2 3        4 2     6   4       3   3        5      7  3
+--R                 (96a b c  - 48a b c  + 6b c)x  + (96a b c  - 18a b c + 3b )x
+--R               + 
+--R                     3 2 2      2 4        6  2       4   2      3 3      2 5
+--R                 (96a b c  - 48a b c + 6a b )x  + (48a b c  - 24a b c + 3a b )x
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                       2   4        3 3     5 2  5
+--R                 (- 96a b c  + 48a b c  - 6b c )x
+--R               + 
+--R                        2 2 3        4 2      6   4
+--R                 (- 192a b c  + 96a b c  - 12b c)x
+--R               + 
+--R                        3   3        5      7  3
+--R                 (- 192a b c  + 36a b c - 6b )x
+--R               + 
+--R                        3 2 2      2 4         6  2
+--R                 (- 192a b c  + 96a b c - 12a b )x
+--R               + 
+--R                       4   2      3 3      2 5
+--R                 (- 96a b c  + 48a b c - 6a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                   3 4      2 2 3       4 2  4
+--R             (- 60a c  + 42a b c  - 6a b c )x
+--R           + 
+--R                    3   3      2 3 2        5   3
+--R             (- 138a b c  + 87a b c  - 12a b c)x
+--R           + 
+--R                    4 3      3 2 2      2 4        6  2
+--R             (- 100a c  - 14a b c  + 36a b c - 6a b )x
+--R           + 
+--R                    4   2      3 3      2 5        5 2      4 2      3 4
+--R             (- 122a b c  + 68a b c - 9a b )x - 32a c  + 16a b c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R               6 4      5 2 3     4 4 2  5       6   3      5 3 2     4 5   4
+--R           (32a c  - 16a b c  + 2a b c )x  + (64a b c  - 32a b c  + 4a b c)x
+--R         + 
+--R               7 3      5 4      4 6  3       7   2      6 3      5 5  2
+--R           (64a c  - 12a b c + 2a b )x  + (64a b c  - 32a b c + 4a b )x
+--R         + 
+--R               8 2      7 2      6 4
+--R           (32a c  - 16a b c + 2a b )x
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2176
+
+--S 2177 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             3 3      2 2 2        4      6
+--R         (60a c  - 90a b c  + 30a b c - 3b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R              3 3       2 2 2        4      6          2c x + b
+--R       (- 120a c  + 180a b c  - 60a b c + 6b )atanh(--------------)
+--R                                                     +-----------+
+--R                                                     |          2
+--R                                                    \|- 4a c + b
+--R  /
+--R                                +-----------+
+--R         6 2      5 2      4 4  |          2
+--R     (32a c  - 16a b c + 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2177
+
+--S 2178 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2178
+
+--S 2179 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                             +---------+
+--R             3 3      2 2 2        4      6  |        2          2c x + b
+--R       (- 60a c  + 90a b c  - 30a b c + 3b )\|4a c - b  atanh(--------------)
+--R                                                               +-----------+
+--R                                                               |          2
+--R                                                              \|- 4a c + b
+--R     + 
+--R                                               +-----------+
+--R               3 3      2 2 2        4      6  |          2
+--R         (- 60a c  + 90a b c  - 30a b c + 3b )\|- 4a c + b
+--R      *
+--R                         +---------+
+--R                         |        2
+--R              (2c x + b)\|4a c - b
+--R         atan(----------------------)
+--R                             2
+--R                     4a c - b
+--R  /
+--R                              +-----------+ +---------+
+--R         6 2     5 2     4 4  |          2  |        2
+--R     (16a c  - 8a b c + a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2179
+
+--S 2180 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2180
+
+)clear all
+
+--S 2181 of 2282
+t0:=x^2/(15+2/x^2+13/x)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2181
+
+--S 2182 of 2282
+r0:=139/3375*x-13/450*x^2+1/45*x^3-16/567*log(2+3*x)+1/4375*log(1+5*x)
+--R 
+--R
+--R                                                  3         2
+--R        162log(5x + 1) - 20000log(3x + 2) + 15750x  - 20475x  + 29190x
+--R   (2)  --------------------------------------------------------------
+--R                                    708750
+--R                                                    Type: Expression(Integer)
+--E 2182
+
+--S 2183 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                  3         2
+--R        162log(5x + 1) - 20000log(3x + 2) + 15750x  - 20475x  + 29190x
+--R   (3)  --------------------------------------------------------------
+--R                                    708750
+--R                                         Type: Union(Expression(Integer),...)
+--E 2183
+
+--S 2184 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2184
+
+--S 2185 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2185
+
+)clear all
+
+--S 2186 of 2282
+t0:=x/(15+2/x^2+13/x)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2186
+
+--S 2187 of 2282
+r0:=-13/225*x+1/30*x^2+8/189*log(2+3*x)-1/875*log(1+5*x)
+--R 
+--R
+--R                                                 2
+--R        - 54log(5x + 1) + 2000log(3x + 2) + 1575x  - 2730x
+--R   (2)  --------------------------------------------------
+--R                               47250
+--R                                                    Type: Expression(Integer)
+--E 2187
+
+--S 2188 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                 2
+--R        - 54log(5x + 1) + 2000log(3x + 2) + 1575x  - 2730x
+--R   (3)  --------------------------------------------------
+--R                               47250
+--R                                         Type: Union(Expression(Integer),...)
+--E 2188
+
+--S 2189 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2189
+
+--S 2190 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2190
+
+)clear all
+
+--S 2191 of 2282
+t0:=1/(15+2/x^2+13/x)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2191
+
+--S 2192 of 2282
+r0:=1/15*x-4/63*log(2+3*x)+1/175*log(1+5*x)
+--R 
+--R
+--R        9log(5x + 1) - 100log(3x + 2) + 105x
+--R   (2)  ------------------------------------
+--R                        1575
+--R                                                    Type: Expression(Integer)
+--E 2192
+
+--S 2193 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R        9log(5x + 1) - 100log(3x + 2) + 105x
+--R   (3)  ------------------------------------
+--R                        1575
+--R                                         Type: Union(Expression(Integer),...)
+--E 2193
+
+--S 2194 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2194
+
+--S 2195 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2195
+
+)clear all
+
+--S 2196 of 2282
+t0:=1/((15+2/x^2+13/x)*x)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2196
+
+--S 2197 of 2282
+r0:=2/21*log(2+3*x)-1/35*log(1+5*x)
+--R 
+--R
+--R        - 3log(5x + 1) + 10log(3x + 2)
+--R   (2)  ------------------------------
+--R                      105
+--R                                                    Type: Expression(Integer)
+--E 2197
+
+--S 2198 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 3log(5x + 1) + 10log(3x + 2)
+--R   (3)  ------------------------------
+--R                      105
+--R                                         Type: Union(Expression(Integer),...)
+--E 2198
+
+--S 2199 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2199
+
+--S 2200 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2200
+
+)clear all
+
+--S 2201 of 2282
+t0:=1/((15+2/x^2+13/x)*x^2)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2201
+
+--S 2202 of 2282
+r0:=1/7*log(5+1/x)-1/7*log(3+2/x)
+--R 
+--R
+--R            5x + 1        3x + 2
+--R        log(------) - log(------)
+--R               x             x
+--R   (2)  -------------------------
+--R                    7
+--R                                                    Type: Expression(Integer)
+--E 2202
+
+--S 2203 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(5x + 1) - log(3x + 2)
+--R   (3)  -------------------------
+--R                    7
+--R                                         Type: Union(Expression(Integer),...)
+--E 2203
+
+--S 2204 of 2282
+m0:=a0-r0
+--R 
+--R
+--R                                        5x + 1        3x + 2
+--R        log(5x + 1) - log(3x + 2) - log(------) + log(------)
+--R                                           x             x
+--R   (4)  -----------------------------------------------------
+--R                                  7
+--R                                                    Type: Expression(Integer)
+--E 2204
+
+--S 2205 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2205
+
+)clear all
+
+--S 2206 of 2282
+t0:=1/((15+2/x^2+13/x)*x^3)
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           3      2
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2206
+
+--S 2207 of 2282
+r0:=1/2*log(x)+3/14*log(2+3*x)-5/7*log(1+5*x)
+--R 
+--R
+--R        - 10log(5x + 1) + 3log(3x + 2) + 7log(x)
+--R   (2)  ----------------------------------------
+--R                           14
+--R                                                    Type: Expression(Integer)
+--E 2207
+
+--S 2208 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 10log(5x + 1) + 3log(3x + 2) + 7log(x)
+--R   (3)  ----------------------------------------
+--R                           14
+--R                                         Type: Union(Expression(Integer),...)
+--E 2208
+
+--S 2209 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2209
+
+--S 2210 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2210
+
+)clear all
+
+--S 2211 of 2282
+t0:=1/((15+2/x^2+13/x)*x^4)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           4      3     2
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2211
+
+--S 2212 of 2282
+r0:=(-1/2)/x-13/4*log(x)-9/28*log(2+3*x)+25/7*log(1+5*x)
+--R 
+--R
+--R        100x log(5x + 1) - 9x log(3x + 2) - 91x log(x) - 14
+--R   (2)  ---------------------------------------------------
+--R                                28x
+--R                                                    Type: Expression(Integer)
+--E 2212
+
+--S 2213 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R        100x log(5x + 1) - 9x log(3x + 2) - 91x log(x) - 14
+--R   (3)  ---------------------------------------------------
+--R                                28x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2213
+
+--S 2214 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2214
+
+--S 2215 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2215
+
+)clear all
+
+--S 2216 of 2282
+t0:=1/((15+2/x^2+13/x)*x^5)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           5      4     3
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2216
+
+--S 2217 of 2282
+r0:=(-1/4)/x^2+13/4/x+139/8*log(x)+27/56*log(2+3*x)-125/7*log(1+5*x)
+--R 
+--R
+--R               2                 2                  2
+--R        - 1000x log(5x + 1) + 27x log(3x + 2) + 973x log(x) + 182x - 14
+--R   (2)  ---------------------------------------------------------------
+--R                                         2
+--R                                      56x
+--R                                                    Type: Expression(Integer)
+--E 2217
+
+--S 2218 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2                 2                  2
+--R        - 1000x log(5x + 1) + 27x log(3x + 2) + 973x log(x) + 182x - 14
+--R   (3)  ---------------------------------------------------------------
+--R                                         2
+--R                                      56x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2218
+
+--S 2219 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2219
+
+--S 2220 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2220
+
+)clear all
+
+--S 2221 of 2282
+t0:=1/((15+2/x^2+13/x)*x^6)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           6      5     4
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 2221
+
+--S 2222 of 2282
+r0:=(-1/6)/x^3+13/8/x^2+(-139/8)/x-1417/16*log(x)-81/112*log(2+3*x)+_
+   625/7*log(1+5*x)
+--R 
+--R
+--R   (2)
+--R         3                  3                    3              2
+--R   30000x log(5x + 1) - 243x log(3x + 2) - 29757x log(x) - 5838x  + 546x - 56
+--R   --------------------------------------------------------------------------
+--R                                          3
+--R                                      336x
+--R                                                    Type: Expression(Integer)
+--E 2222
+
+--S 2223 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3                  3                    3              2
+--R   30000x log(5x + 1) - 243x log(3x + 2) - 29757x log(x) - 5838x  + 546x - 56
+--R   --------------------------------------------------------------------------
+--R                                          3
+--R                                      336x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2223
+
+--S 2224 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2224
+
+--S 2225 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2225
+
+)clear all
+
+--S 2226 of 2282
+t0:=x^m/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2226
+
+--S 2227 of 2282
+--r0:=2*c*x^(1+m)*hypergeometric(1,(1+m)/n,(1+m+n)/n,_
+--   -2*c*x^n/(b-sqrt(b^2-4*a*c)))/((1+m)*(b-sqrt(b^2-4*a*c))*_
+--   sqrt(b^2-4*a*c))-2*c*x^(1+m)*hypergeometric(1,(1+m)/n,(1+m+n)/n,_
+--   -2*c*x^n/(b+sqrt(b^2-4*a*c)))/((1+m)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))
+--E 2227
+
+--S 2228 of 2282
+--a0:=integrate(t0,x)
+--E 2228
+
+--S 2229 of 2282
+--m0:=a0-r0
+--E 2229
+
+--S 2230 of 2282
+--d0:=normalize(D(m0,x))
+--E 2230
+
+)clear all
+
+--S 2231 of 2282
+t0:=x^2/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2231
+
+--S 2232 of 2282
+--r0:=-2/3*c*x^3*hypergeometric(1,3/n,(3+n)/n,-2*c*x^n/(b-sqrt(b^2-_
+--   4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-4*a*c))-2/3*c*x^3*_
+--   hypergeometric(1,3/n,(3+n)/n,-2*c*x^n/(b+sqrt(b^2-4*a*c)))/_
+--   (b^2-4*a*c+b*sqrt(b^2-4*a*c))
+--E 2232
+
+--S 2233 of 2282
+--a0:=integrate(t0,x)
+--E 2233
+
+--S 2234 of 2282
+--m0:=a0-r0
+--E 2234
+
+--S 2235 of 2282
+--d0:=normalize(D(m0,x))
+--E 2235
+
+)clear all
+
+--S 2236 of 2282
+t0:=x/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R                x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2236
+
+--S 2237 of 2282
+--r0:=-c*x^2*hypergeometric(1,2/n,(2+n)/n,-2*c*x^n/(b-sqrt(b^2-4*a*c)))/_
+--   (b^2-4*a*c-b*sqrt(b^2-4*a*c))-c*x^2*hypergeometric(1,2/n,(2+n)/n,_
+--   -2*c*x^n/(b+sqrt(b^2-4*a*c)))/(b^2-4*a*c+b*sqrt(b^2-4*a*c))
+--E 2237
+
+--S 2238 of 2282
+--a0:=integrate(t0,x)
+--E 2238
+
+--S 2239 of 2282
+--m0:=a0-r0
+--E 2239
+
+--S 2240 of 2282
+--d0:=normalize(D(m0,x))
+--E 2240
+
+)clear all
+
+--S 2241 of 2282
+t0:=1/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2241
+
+--S 2242 of 2282
+--r0:=x*AppellF1(1/n,1,1,1+1/n,-2*c*x^n/(b+sqrt(b^2-4*a*c)),_
+--   -2*c*x^n/(b-sqrt(b^2-4*a*c)))*(1+2*c*x^n/(b-sqrt(b^2-4*a*c)))*_
+--   (1+2*c*x^n/(b+sqrt(b^2-4*a*c)))/(a+b*x^n+c*x^(2*n))
+--E 2242
+
+--S 2243 of 2282
+--a0:=integrate(t0,x)
+--E 2243
+
+--S 2244 of 2282
+--m0:=a0-r0
+--E 2244
+
+--S 2245 of 2282
+--d0:=normalize(D(m0,x))
+--E 2245
+
+)clear all
+
+--S 2246 of 2282
+t0:=1/(x*(a+b*x^n+c*x^(2*n)))
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R             2n        n
+--R        c x x   + b x x  + a x
+--R                                                    Type: Expression(Integer)
+--E 2246
+
+--S 2247 of 2282
+r0:=log(x)/a-1/2*log(a+b*x^n+c*x^(2*n))/(a*n)+_
+   b*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/(a*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +-----------+                                        n
+--R          |          2        2n      n                    2c x  + b
+--R       - \|- 4a c + b  log(c x   + b x  + a) + 2b atanh(--------------)
+--R                                                         +-----------+
+--R                                                         |          2
+--R                                                        \|- 4a c + b
+--R     + 
+--R                 +-----------+
+--R                 |          2
+--R       2n log(x)\|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     2a n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2247
+
+--S 2248 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R            +-----------+
+--R            |          2          n log(x) 2       n log(x)
+--R         - \|- 4a c + b  log(c (%e        )  + b %e         + a)
+--R       + 
+--R           b
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    n log(x) 2
+--R                  2c \|- 4a c + b  (%e        )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    n log(x)
+--R                  (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R             /
+--R                     n log(x) 2       n log(x)
+--R                c (%e        )  + b %e         + a
+--R       + 
+--R                   +-----------+
+--R                   |          2
+--R         2n log(x)\|- 4a c + b
+--R    /
+--R            +-----------+
+--R            |          2
+--R       2a n\|- 4a c + b
+--R     ,
+--R
+--R            +---------+
+--R            |        2          n log(x) 2       n log(x)
+--R         - \|4a c - b  log(c (%e        )  + b %e         + a)
+--R       + 
+--R                      +---------+               +---------+
+--R                      |        2   n log(x)     |        2
+--R                   2c\|4a c - b  %e         + b\|4a c - b
+--R         - 2b atan(----------------------------------------)
+--R                                           2
+--R                                   4a c - b
+--R       + 
+--R                   +---------+
+--R                   |        2
+--R         2n log(x)\|4a c - b
+--R    /
+--R            +---------+
+--R            |        2
+--R       2a n\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2248
+
+--S 2249 of 2282
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-----------+
+--R          |          2          n log(x) 2       n log(x)
+--R       - \|- 4a c + b  log(c (%e        )  + b %e         + a)
+--R     + 
+--R         b
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    n log(x) 2
+--R                2c \|- 4a c + b  (%e        )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    n log(x)
+--R                (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R           /
+--R                   n log(x) 2       n log(x)
+--R              c (%e        )  + b %e         + a
+--R     + 
+--R        +-----------+                                        n
+--R        |          2        2n      n                    2c x  + b
+--R       \|- 4a c + b  log(c x   + b x  + a) - 2b atanh(--------------)
+--R                                                       +-----------+
+--R                                                       |          2
+--R                                                      \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     2a n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 2249
+
+--S 2250 of 2282
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2250
+
+--S 2251 of 2282
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +-----------+ +---------+
+--R          |          2  |        2          n log(x) 2       n log(x)
+--R       - \|- 4a c + b  \|4a c - b  log(c (%e        )  + b %e         + a)
+--R     + 
+--R                                 +---------+               +---------+
+--R            +-----------+        |        2   n log(x)     |        2
+--R            |          2      2c\|4a c - b  %e         + b\|4a c - b
+--R       - 2b\|- 4a c + b  atan(----------------------------------------)
+--R                                                      2
+--R                                              4a c - b
+--R     + 
+--R        +-----------+ +---------+
+--R        |          2  |        2        2n      n
+--R       \|- 4a c + b  \|4a c - b  log(c x   + b x  + a)
+--R     + 
+--R            +---------+             n
+--R            |        2          2c x  + b
+--R       - 2b\|4a c - b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R  /
+--R          +-----------+ +---------+
+--R          |          2  |        2
+--R     2a n\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 2251
+
+--S 2252 of 2282
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2252
+
+)clear all
+
+--S 2253 of 2282
+t0:=1/(x^2*(a+b*x^n+c*x^(2*n)))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R           2 2n      2 n      2
+--R        c x x   + b x x  + a x
+--R                                                    Type: Expression(Integer)
+--E 2253
+
+--S 2254 of 2282
+--r0:=2*c*hypergeometric(1,(-1)/n,(-1+n)/n,-2*c*x^n/(b-sqrt(b^2-4*a*c)))/_
+--   (x*(b^2-4*a*c-b*sqrt(b^2-4*a*c)))+2*c*hypergeometric(1,(-1)/n,_
+--   (-1+n)/n,-2*c*x^n/(b+sqrt(b^2-4*a*c)))/(x*(b^2-4*a*c+b*sqrt(b^2-4*a*c)))
+--E 2254
+
+--S 2255 of 2282
+--a0:=integrate(t0,x)
+--E 2255
+
+--S 2256 of 2282
+--m0:=a0-r0
+--E 2256
+
+--S 2257 of 2282
+--d0:=normalize(D(m0,x))
+--E 2257
+
+)clear all
+
+--S 2258 of 2282
+t0:=1/(x^3*(a+b*x^n+c*x^(2*n)))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R           3 2n      3 n      3
+--R        c x x   + b x x  + a x
+--R                                                    Type: Expression(Integer)
+--E 2258
+
+--S 2259 of 2282
+--r0:=c*hypergeometric(1,(-2)/n,(-2+n)/n,-2*c*x^n/(b-sqrt(b^2-4*a*c)))/_
+--   (x^2*(b^2-4*a*c-b*sqrt(b^2-4*a*c)))+c*hypergeometric(1,(-2)/n,_
+--   (-2+n)/n,-2*c*x^n/(b+sqrt(b^2-4*a*c)))/(x^2*(b^2-4*a*c+b*sqrt(b^2-4*a*c)))
+--E 2259
+
+--S 2260 of 2282
+--a0:=integrate(t0,x)
+--E 2260
+
+--S 2261 of 2282
+--m0:=a0-r0
+--E 2261
+
+--S 2262 of 2282
+--d0:=normalize(D(m0,x))
+--E 2262
+
+)clear all
+
+--S 2263 of 2282
+t0:=(c^(1/3)-2*d^(1/3)*x^(1/3))/(c*d^(1/3)*x^(2/3)-c^(2/3)*d^(2/3)*x+c^(1/3)*d*x^(4/3))
+--R 
+--R
+--R                      3+-+3+-+   3+-+
+--R                   - 2\|d \|x  + \|c
+--R   (1)  ---------------------------------------
+--R         3+-+3+-+2      3+-+3+-+     3+-+2 3+-+2
+--R        c\|d \|x   + d x\|c \|x  - x \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 2263
+
+--S 2264 of 2282
+r0:=-3*log(c^(2/3)-c^(1/3)*d^(1/3)*x^(1/3)+d^(2/3)*x^(2/3))/(c^(1/3)*d^(2/3))
+--R 
+--R
+--R               3+-+2 3+-+2  3+-+3+-+3+-+   3+-+2
+--R          3log(\|d   \|x  - \|c \|d \|x  + \|c  )
+--R   (2)  - ---------------------------------------
+--R                         3+-+3+-+2
+--R                         \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 2264
+
+--S 2265 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3+-+     3+-+3+-+2   3+-+2 3+-+2 3+-+  3+-+
+--R          3\|d log(d\|c \|x   - \|c   \|d   \| + c\|d )
+--R   (3)  - ---------------------------------------------
+--R                               3+-+
+--R                              d\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2265
+
+--S 2266 of 2282
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3+-+2 3+-+2  3+-+3+-+3+-+   3+-+2
+--R       3log(\|d   \|x  - \|c \|d \|x  + \|c  )
+--R     + 
+--R               3+-+3+-+2   3+-+2 3+-+2 3+-+  3+-+
+--R       - 3log(d\|c \|x   - \|c   \|d   \| + c\|d )
+--R  /
+--R     3+-+3+-+2
+--R     \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 2266
+
+--S 2267 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2267
+
+)clear all
+
+--S 2268 of 2282
+t0:=(1/4*b^2/c+c*x+b*sqrt(x))^2
+--R 
+--R
+--R              3      3   +-+      4 2      2 2     4
+--R        (32b c x + 8b c)\|x  + 16c x  + 24b c x + b
+--R   (1)  --------------------------------------------
+--R                               2
+--R                            16c
+--R                                                    Type: Expression(Integer)
+--E 2268
+
+--S 2269 of 2282
+r0:=-1/160*b*(b+2*c*sqrt(x))^5/c^4+1/192*(b+2*c*sqrt(x))^6/c^4
+--R 
+--R
+--R               5 2       3 3   +-+       6 3       2 4 2      4 2     6
+--R        (768b c x  + 320b c x)\|x  + 320c x  + 720b c x  + 60b c x - b
+--R   (2)  ---------------------------------------------------------------
+--R                                         4
+--R                                     960c
+--R                                                    Type: Expression(Integer)
+--E 2269
+
+--S 2270 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3 2      3     +-+      4 3       2 2 2      4
+--R        (192b c x  + 80b c x)\|x  + 80c x  + 180b c x  + 15b x
+--R   (3)  ------------------------------------------------------
+--R                                     2
+--R                                 240c
+--R                                         Type: Union(Expression(Integer),...)
+--E 2270
+
+--S 2271 of 2282
+m0:=a0-r0
+--R 
+--R
+--R           6
+--R          b
+--R   (4)  -----
+--R            4
+--R        960c
+--R                                                    Type: Expression(Integer)
+--E 2271
+
+--S 2272 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2272
+
+)clear all
+
+--S 2273 of 2282
+t0:=(2+3*x)^6*(1+(2+3*x)^7+(2+3*x)^14)
+--R 
+--R
+--R   (1)
+--R                20               19                18                 17
+--R     3486784401x   + 46490458680x   + 294439571640x   + 1177758286560x
+--R   + 
+--R                   16                 15                  14                  13
+--R     3336981811920x   + 7118894532096x   + 11864824220160x   + 15819767221203x
+--R   + 
+--R                    12                  11                  10                 9
+--R     17138093246586x   + 15233903651304x   + 11171623917168x   + 6770824454160x
+--R   + 
+--R                   8                 7                6                5
+--R     3385569848544x  + 1389081063168x  + 463107083481x  + 123532587108x
+--R   + 
+--R                 4              3             2
+--R     25748932860x  + 4042307808x  + 449706096x  + 31617600x + 1056832
+--R                                                    Type: Polynomial(Integer)
+--E 2273
+
+--S 2274 of 2282
+r0:=1/21*(2+3*x)^7+1/42*(2+3*x)^14+1/63*(2+3*x)^21
+--R 
+--R
+--R   (2)
+--R     1162261467  21              20               19               18
+--R     ---------- x   + 2324522934x   + 15496819560x   + 65431015920x
+--R          7
+--R   + 
+--R                  17                16                15   15819767221203  14
+--R     196293047760x   + 444930908256x   + 790988281344x   + -------------- x
+--R                                                                 14
+--R   + 
+--R                   13                 12                 11                10
+--R     1318314865122x   + 1269491970942x   + 1015602174288x   + 677082445416x
+--R   + 
+--R                  9                8               7               6
+--R     376174427616x  + 173635132896x  + 66158154783x  + 20588764518x
+--R   + 
+--R              5              4             3            2              2122112
+--R   5149786572x  + 1010576952x  + 149902032x  + 15808800x  + 1056832x + -------
+--R                                                                          63
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2274
+
+--S 2275 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1162261467  21              20               19               18
+--R     ---------- x   + 2324522934x   + 15496819560x   + 65431015920x
+--R          7
+--R   + 
+--R                  17                16                15   15819767221203  14
+--R     196293047760x   + 444930908256x   + 790988281344x   + -------------- x
+--R                                                                 14
+--R   + 
+--R                   13                 12                 11                10
+--R     1318314865122x   + 1269491970942x   + 1015602174288x   + 677082445416x
+--R   + 
+--R                  9                8               7               6
+--R     376174427616x  + 173635132896x  + 66158154783x  + 20588764518x
+--R   + 
+--R                5              4             3            2
+--R     5149786572x  + 1010576952x  + 149902032x  + 15808800x  + 1056832x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2275
+
+--S 2276 of 2282
+m0:=a0-r0
+--R 
+--R
+--R          2122112
+--R   (4)  - -------
+--R             63
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2276
+
+--S 2277 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2277
+
+)clear all
+
+--S 2278 of 2282
+t0:=(2+3*x)^6*(1+(2+3*x)^7+(2+3*x)^14)^2
+--R 
+--R
+--R   (1)
+--R                       34                      33                       32
+--R     16677181699666569x   + 378016118525775564x   + 4158177303783531204x
+--R   + 
+--R                          31                         30
+--R     29569260826905110784x   + 152774514272343072384x
+--R   + 
+--R                           29                          28
+--R     611098057089372289536x   + 1969093739510199599616x
+--R   + 
+--R                            27                           26
+--R     5250916653945060568950x   + 11814562711582707057228x
+--R   + 
+--R                             25                           24
+--R     22753974480193166244840x   + 37923300052713558858960x
+--R   + 
+--R                             23                           22
+--R     55161197358098322404160x   + 70483846759795477607040x
+--R   + 
+--R                             21                           20
+--R     79520450781314886393600x   + 79520847116576754110643x
+--R   + 
+--R                             19                           18
+--R     70685813958589477281960x   + 55960416183860517516840x
+--R   + 
+--R                             17                           16
+--R     39502388988265540321440x   + 24872768546728823564400x
+--R   + 
+--R                             15                          14
+--R     13964412385079287976448x   + 6982756365625215229440x
+--R   + 
+--R                            13                          12
+--R     3103796605675782721446x   + 1222900430946085012212x
+--R   + 
+--R                           11                         10
+--R     425448833766864577488x   + 130036362517827878112x
+--R   + 
+--R                          9                       8                       7
+--R     34689917186099544096x  + 8009483060433484224x  + 1583178214811622912x
+--R   + 
+--R                        6                     5                    4
+--R     264090004030265049x  + 36466108367328612x  + 4057390785756924x
+--R   + 
+--R                     3                  2
+--R     349626718314720x  + 21898634455152x  + 887139656256x + 17451466816
+--R                                                    Type: Polynomial(Integer)
+--E 2278
+
+--S 2279 of 2282
+r0:=1/21*(2+3*x)^7+1/21*(2+3*x)^14+1/21*(2+3*x)^21+1/42*(2+3*x)^28+_
+   1/105*(2+3*x)^35
+--R 
+--R
+--R   (2)
+--R     16677181699666569  35                     34                      33
+--R     ----------------- x   + 11118121133111046x   + 126005372841925188x
+--R             35
+--R   + 
+--R                        32                       31   101849676181562048256  30
+--R     924039400840784712x   + 4928210137817518464x   + --------------------- x
+--R                                                                5
+--R   + 
+--R                          29   2625458326972530284475  28
+--R     67899784121041365504x   + ---------------------- x
+--R                                         14
+--R   + 
+--R                           27                         26
+--R     437576396725285446564x   + 875152864622814086340x
+--R   + 
+--R     7584660010542711771792  25                          24
+--R     ---------------------- x   + 2298383223254096766840x
+--R                5
+--R   + 
+--R                            23                          22
+--R     3064515076512846852480x   + 3614565944605222108800x
+--R   + 
+--R     26506949038858918036881  21                          20
+--R     ----------------------- x   + 3534290697929473864098x
+--R                7
+--R   + 
+--R                            19                          18
+--R     2945285062308448290360x   + 2194577166014752240080x
+--R   + 
+--R                            17                         16
+--R     1463104032160519033200x   + 872775774067455498528x
+--R   + 
+--R                           15                         14
+--R     465517091041681015296x   + 221699757548270194389x
+--R   + 
+--R                          13                        12                        11
+--R     94069263918929616324x   + 35454069480572048124x   + 11821487501620716192x
+--R   + 
+--R     17344958593049772048  10                      9                      8
+--R     -------------------- x   + 889942562270387136x  + 197897276851452864x
+--R               5
+--R   + 
+--R                       7                    6   4057390785756924  5
+--R     37727143432895007x  + 6077684727888102x  + ---------------- x
+--R                                                        5
+--R   + 
+--R                    4                 3                2
+--R     87406679578680x  + 7299544818384x  + 443569828128x  + 17451466816x
+--R   + 
+--R     35041395328
+--R     -----------
+--R         105
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2279
+
+--S 2280 of 2282
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     16677181699666569  35                     34                      33
+--R     ----------------- x   + 11118121133111046x   + 126005372841925188x
+--R             35
+--R   + 
+--R                        32                       31   101849676181562048256  30
+--R     924039400840784712x   + 4928210137817518464x   + --------------------- x
+--R                                                                5
+--R   + 
+--R                          29   2625458326972530284475  28
+--R     67899784121041365504x   + ---------------------- x
+--R                                         14
+--R   + 
+--R                           27                         26
+--R     437576396725285446564x   + 875152864622814086340x
+--R   + 
+--R     7584660010542711771792  25                          24
+--R     ---------------------- x   + 2298383223254096766840x
+--R                5
+--R   + 
+--R                            23                          22
+--R     3064515076512846852480x   + 3614565944605222108800x
+--R   + 
+--R     26506949038858918036881  21                          20
+--R     ----------------------- x   + 3534290697929473864098x
+--R                7
+--R   + 
+--R                            19                          18
+--R     2945285062308448290360x   + 2194577166014752240080x
+--R   + 
+--R                            17                         16
+--R     1463104032160519033200x   + 872775774067455498528x
+--R   + 
+--R                           15                         14
+--R     465517091041681015296x   + 221699757548270194389x
+--R   + 
+--R                          13                        12                        11
+--R     94069263918929616324x   + 35454069480572048124x   + 11821487501620716192x
+--R   + 
+--R     17344958593049772048  10                      9                      8
+--R     -------------------- x   + 889942562270387136x  + 197897276851452864x
+--R               5
+--R   + 
+--R                       7                    6   4057390785756924  5
+--R     37727143432895007x  + 6077684727888102x  + ---------------- x
+--R                                                        5
+--R   + 
+--R                    4                 3                2
+--R     87406679578680x  + 7299544818384x  + 443569828128x  + 17451466816x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2280
+
+--S 2281 of 2282
+m0:=a0-r0
+--R 
+--R
+--R          35041395328
+--R   (4)  - -----------
+--R              105
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2281
+
+--S 2282 of 2282
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2282
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich17.input.pamphlet b/src/input/rich17.input.pamphlet
new file mode 100644
index 0000000..f05644d
--- /dev/null
+++ b/src/input/rich17.input.pamphlet
@@ -0,0 +1,84751 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich17.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (d+e x^n)^q (a+b x^n+c x^(2n))^p|
+There are:
+\begin{itemize}
+\item 255 integrals in this file.
+\item 255 supplied "optimal results".
+\item 307 matching answers.
+\item 0 cases where Axiom answer differs from Rubi
+\item 91 cases where Axiom supplied 2 results.
+\item 12 cases that Axiom failed to integrate.
+\item 31 that contain expressions Axiom does not recognize.
+\end{itemize}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich17.output
+)spool rich17.output
+)set message test on
+)set message auto off
+)clear all
+ 
+--S 1 of 649
+t0:=x^4*(d+e*x^3)/(a+b*x^3+c*x^6)
+--R 
+--R
+--R             7      4
+--R          e x  + d x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1
+
+--S 2 of 649
+r0:=1/2*e*x^2/c-1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*_
+   (c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3))+1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*_
+   c^(1/3)*x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*_
+   (c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3))-atan((-4*c^(1/3)*x+2^(2/3)*(b-_
+   sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*_
+   (c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3))-1/3*log(2^(1/3)*c^(1/3)*x+_
+   (b+sqrt(b^2-4*a*c))^(1/3))*(c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/_
+   sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*(b+sqrt(b^2-4*a*c))^(1/3))+_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-_
+   4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*(c*d-b*e+(b*c*d-b^2*e+_
+   2*a*c*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))-atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*_
+   (c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*_
+   sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3))
+--R 
+--R
+--R   (2)
+--R                            +-----------+
+--R                        +-+ |          2              2            +-+
+--R         ((- b e + c d)\|3 \|- 4a c + b   + ((2a c - b )e + b c d)\|3 )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+
+--R         3|   |          2
+--R         \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                            +-----------+
+--R                        +-+ |          2                 2             +-+
+--R         ((2b e - 2c d)\|3 \|- 4a c + b   + ((- 4a c + 2b )e - 2b c d)\|3 )
+--R      *
+--R          +--------------------+     +------------------+
+--R          |   +-----------+          | +-----------+
+--R         3|   |          2          3| |          2          3+-+3+-+
+--R         \|- \|- 4a c + b   + b log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                            +-----------+
+--R                        +-+ |          2                2            +-+
+--R         ((- b e + c d)\|3 \|- 4a c + b   + ((- 2a c + b )e - b c d)\|3 )
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                            +-----------+
+--R                        +-+ |          2               2             +-+
+--R         ((2b e - 2c d)\|3 \|- 4a c + b   + ((4a c - 2b )e + 2b c d)\|3 )
+--R      *
+--R          +------------------+     +--------------------+
+--R          | +-----------+          |   +-----------+
+--R         3| |          2          3|   |          2          3+-+3+-+
+--R         \|\|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                        +-----------+
+--R                        |          2                 2
+--R         ((6b e - 6c d)\|- 4a c + b   + (- 12a c + 6b )e - 6b c d)
+--R      *
+--R                                            +------------------+
+--R          +--------------------+            | +-----------+
+--R          |   +-----------+          3+-+2 3| |          2          3+-+
+--R         3|   |          2           \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         \|- \|- 4a c + b   + b atan(-----------------------------------)
+--R                                                  +------------------+
+--R                                                  | +-----------+
+--R                                        3+-+2 +-+3| |          2
+--R                                        \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                        +-----------+
+--R                        |          2               2
+--R         ((6b e - 6c d)\|- 4a c + b   + (12a c - 6b )e + 6b c d)
+--R      *
+--R                                          +--------------------+
+--R          +------------------+            |   +-----------+
+--R          | +-----------+          3+-+2 3|   |          2          3+-+
+--R         3| |          2           \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         \|\|- 4a c + b   + b atan(-------------------------------------)
+--R                                                +--------------------+
+--R                                                |   +-----------+
+--R                                      3+-+2 +-+3|   |          2
+--R                                      \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                             +--------------------+
+--R                         +-----------+       |   +-----------+
+--R             2 3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R         3e x  \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R        3+-+2 +-+ |          2 3+-+2 3|   |          2      3| |          2
+--R     6c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                            6      2 5
+--R                     (108a c  - 27b c )
+--R                  *
+--R                     ROOT
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                          + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                           *
+--R                                 5
+--R                              d e
+--R                          + 
+--R                                     4 6       3 2 5       2 4 4         6 3
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     8 2
+--R                                - 15b c
+--R                           *
+--R                               2 4
+--R                              d e
+--R                          + 
+--R                                   3   6       2 3 5         5 4      7 3  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                          + 
+--R                                3 7       2 2 6        4 5      6 4  4 2
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                2   7        3 6     5 5  5
+--R                            (36a b c  - 30a b c  + 6b c )d e
+--R                          + 
+--R                                 2 8       2 7    4 6  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                3 13         2 2 12          4 11       6 10
+--R                          46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                       2 2       2     4  3            2     3     2
+--R                   (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (3a c  - 3b c )d e + b c d
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                   4 9         3 2 8         2 4 7          6 6
+--R                             15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                           + 
+--R                                 8 5
+--R                             243b c
+--R                        *
+--R                            2
+--R                           e
+--R                       + 
+--R                                3   9         2 3 8          5 7       7 6
+--R                         (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                       + 
+--R                                  3 10         2 2 9          4 8       6 7  2
+--R                         (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                                     4 2 4       3 4 3       2 6 2         8
+--R                               - 540a b c  + 855a b c  - 468a b c  + 108a b c
+--R                             + 
+--R                                   10
+--R                               - 9b
+--R                        *
+--R                            5
+--R                           e
+--R                       + 
+--R                                  4   5        3 3 4        2 5 3         7 2
+--R                             1368a b c  - 2934a b c  + 1908a b c  - 495a b c
+--R                           + 
+--R                                9
+--R                             45b c
+--R                        *
+--R                              4
+--R                           d e
+--R                       + 
+--R                                   4 6        3 2 5        2 4 4         6 3
+--R                             - 864a c  + 3528a b c  - 2952a b c  + 891a b c
+--R                           + 
+--R                                  8 2
+--R                             - 90b c
+--R                        *
+--R                            2 3
+--R                           d e
+--R                       + 
+--R                                 3   6        2 3 5         5 4      7 3  3 2
+--R                         (- 1728a b c  + 2124a b c  - 783a b c  + 90b c )d e
+--R                       + 
+--R                              3 7       2 2 6         4 5      6 4  4
+--R                         (288a c  - 684a b c  + 333a b c  - 45b c )d e
+--R                       + 
+--R                             2   7        3 6     5 5  5
+--R                         (72a b c  - 54a b c  + 9b c )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                     6      2 5
+--R                              (108a c  - 27b c )
+--R                           *
+--R                              ROOT
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                            4   5       3 3 4       2 5 3
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                                7 2     9
+--R                                         - 54a b c  + 6b c
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                              4 6       3 2 5       2 4 4
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                               6 3      8 2
+--R                                         120a b c  - 15b c
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                               3   6       2 3 5         5 4
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            7 3
+--R                                         20b c
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                           3 7       2 2 6        4 5      6 4
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                         2   7        3 6     5 5  5
+--R                                     (36a b c  - 30a b c  + 6b c )d e
+--R                                   + 
+--R                                          2 8       2 7    4 6  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                                2 2       2     4  3            2     3     2
+--R                            (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (3a c  - 3b c )d e + b c d
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               4   7       3 3 6      2 5 5  3
+--R                         (1296a b c  - 648a b c  + 81a b c )e
+--R                       + 
+--R                                 4 8       2 4 6        6 5    2
+--R                         (- 2592a c  + 486a b c  - 81a b c )d e
+--R                       + 
+--R                               3   8        2 3 7         5 6  2
+--R                         (3888a b c  - 1944a b c  + 243a b c )d e
+--R                       + 
+--R                                 3 9        2 2 8         4 7  3
+--R                         (- 2592a c  + 1296a b c  - 162a b c )d
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                         5   3      4 3 2      3 5      2 7  6
+--R                     (60a b c  - 75a b c  + 27a b c - 3a b )e
+--R                   + 
+--R                           5 4       4 2 3     3 4 2      2 6        8    5
+--R                     (- 72a c  + 102a b c  + 3a b c  - 18a b c + 3a b )d e
+--R                   + 
+--R                         4   4       3 3 3      2 5 2        7   2 4
+--R                     (24a b c  - 174a b c  + 90a b c  - 12a b c)d e
+--R                   + 
+--R                           4 5       3 2 4       2 4 3        6 2  3 3
+--R                     (- 48a c  + 252a b c  - 132a b c  + 18a b c )d e
+--R                   + 
+--R                            3   5      2 3 4        5 3  4 2
+--R                     (- 132a b c  + 81a b c  - 12a b c )d e
+--R                   + 
+--R                         3 6      2 2 5       4 4  5
+--R                     (24a c  - 18a b c  + 3a b c )d e
+--R                *
+--R                   ROOT
+--R                                   6      2 5
+--R                            (108a c  - 27b c )
+--R                         *
+--R                            ROOT
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  *
+--R                                      6
+--R                                     e
+--R                                 + 
+--R                                          4   5       3 3 4       2 5 3
+--R                                       60a b c  - 180a b c  + 162a b c
+--R                                     + 
+--R                                              7 2     9
+--R                                       - 54a b c  + 6b c
+--R                                  *
+--R                                        5
+--R                                     d e
+--R                                 + 
+--R                                            4 6       3 2 5       2 4 4
+--R                                       - 36a c  + 234a b c  - 300a b c
+--R                                     + 
+--R                                             6 3      8 2
+--R                                       120a b c  - 15b c
+--R                                  *
+--R                                      2 4
+--R                                     d e
+--R                                 + 
+--R                                             3   6       2 3 5         5 4
+--R                                       - 128a b c  + 282a b c  - 140a b c
+--R                                     + 
+--R                                          7 3
+--R                                       20b c
+--R                                  *
+--R                                      3 3
+--R                                     d e
+--R                                 + 
+--R                                       3 7       2 2 6        4 5      6 4  4 2
+--R                                   (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                 + 
+--R                                       2   7        3 6     5 5  5
+--R                                   (36a b c  - 30a b c  + 6b c )d e
+--R                                 + 
+--R                                        2 8       2 7    4 6  6
+--R                                   (- 4a c  + 4a b c  - b c )d
+--R                              /
+--R                                         3 13         2 2 12          4 11
+--R                                   46656a c   - 34992a b c   + 8748a b c
+--R                                 + 
+--R                                         6 10
+--R                                   - 729b c
+--R                        + 
+--R                              2 2       2     4  3            2     3     2
+--R                          (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                        + 
+--R                               3     2 2  2       3 3
+--R                          (3a c  - 3b c )d e + b c d
+--R                     /
+--R                              6      2 5
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                         5   2      4 3      3 5  7
+--R                     (10a b c  - 10a b c + 2a b )e
+--R                   + 
+--R                           5 3     4 2 2      3 4      2 6    6
+--R                     (- 12a c  + 4a b c  + 14a b c - 4a b )d e
+--R                   + 
+--R                         4   3      3 3 2     2 5        7  2 5
+--R                     (26a b c  - 52a b c  + 6a b c + 2a b )d e
+--R                   + 
+--R                           4 4      3 2 3      2 4 2        6   3 4
+--R                     (- 20a c  + 50a b c  + 20a b c  - 10a b c)d e
+--R                   + 
+--R                           3   4      2 3 3        5 2  4 3
+--R                     (- 10a b c  - 60a b c  + 20a b c )d e
+--R                   + 
+--R                          3 5      2 2 4        4 3  5 2
+--R                     (- 4a c  + 60a b c  - 20a b c )d e
+--R                   + 
+--R                           2   5        3 4  6       2 6       2 5  7
+--R                     (- 26a b c  + 10a b c )d e + (4a c  - 2a b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R         2c
+--R      *
+--R         ROOT
+--R                           6      2 5
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                  ROOT
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                       + 
+--R                               4   5       3 3 4       2 5 3        7 2     9
+--R                           (60a b c  - 180a b c  + 162a b c  - 54a b c  + 6b c)d
+--R                        *
+--R                            5
+--R                           e
+--R                       + 
+--R                                    4 6       3 2 5       2 4 4         6 3
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    8 2
+--R                               - 15b c
+--R                        *
+--R                            2 4
+--R                           d e
+--R                       + 
+--R                                3   6       2 3 5         5 4      7 3  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                       + 
+--R                             3 7       2 2 6        4 5      6 4  4 2
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                             2   7        3 6     5 5  5
+--R                         (36a b c  - 30a b c  + 6b c )d e
+--R                       + 
+--R                              2 8       2 7    4 6  6
+--R                         (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R              + 
+--R                    2 2       2     4  3            2     3     2
+--R                (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R              + 
+--R                     3     2 2  2       3 3
+--R                (3a c  - 3b c )d e + b c d
+--R           /
+--R                    6      2 5
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                                4 9         3 2 8         2 4 7          6 6
+--R                          15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                        + 
+--R                              8 5
+--R                          243b c
+--R                     *
+--R                         2
+--R                        e
+--R                    + 
+--R                             3   9         2 3 8          5 7       7 6
+--R                      (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                    + 
+--R                               3 10         2 2 9          4 8       6 7  2
+--R                      (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                 *
+--R                    ROOT
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                         + 
+--R                                    4   5       3 3 4       2 5 3        7 2
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                   9
+--R                                 6b c
+--R                          *
+--R                                5
+--R                             d e
+--R                         + 
+--R                                    4 6       3 2 5       2 4 4         6 3
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    8 2
+--R                               - 15b c
+--R                          *
+--R                              2 4
+--R                             d e
+--R                         + 
+--R                                  3   6       2 3 5         5 4      7 3  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                         + 
+--R                               3 7       2 2 6        4 5      6 4  4 2
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                               2   7        3 6     5 5  5
+--R                           (36a b c  - 30a b c  + 6b c )d e
+--R                         + 
+--R                                2 8       2 7    4 6  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                + 
+--R                       4 2 4       3 4 3       2 6 2         8      10  5
+--R                  (540a b c  - 855a b c  + 468a b c  - 108a b c + 9b  )e
+--R                + 
+--R                            4   5        3 3 4        2 5 3         7 2      9
+--R                    (- 1368a b c  + 2934a b c  - 1908a b c  + 495a b c  - 45b c)
+--R                 *
+--R                       4
+--R                    d e
+--R                + 
+--R                       4 6        3 2 5        2 4 4         6 3      8 2  2 3
+--R                  (864a c  - 3528a b c  + 2952a b c  - 891a b c  + 90b c )d e
+--R                + 
+--R                        3   6        2 3 5         5 4      7 3  3 2
+--R                  (1728a b c  - 2124a b c  + 783a b c  - 90b c )d e
+--R                + 
+--R                         3 7       2 2 6         4 5      6 4  4
+--R                  (- 288a c  + 684a b c  - 333a b c  + 45b c )d e
+--R                + 
+--R                        2   7        3 6     5 5  5
+--R                  (- 72a b c  + 54a b c  - 9b c )d
+--R             *
+--R                  ROOT
+--R                                    6      2 5
+--R                           (- 108a c  + 27b c )
+--R                        *
+--R                           ROOT
+--R                                           4 2 4      3 4 3      2 6 2        8
+--R                                      - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                    + 
+--R                                         10
+--R                                      - b
+--R                                 *
+--R                                     6
+--R                                    e
+--R                                + 
+--R                                         4   5       3 3 4       2 5 3
+--R                                      60a b c  - 180a b c  + 162a b c
+--R                                    + 
+--R                                             7 2     9
+--R                                      - 54a b c  + 6b c
+--R                                 *
+--R                                       5
+--R                                    d e
+--R                                + 
+--R                                           4 6       3 2 5       2 4 4
+--R                                      - 36a c  + 234a b c  - 300a b c
+--R                                    + 
+--R                                            6 3      8 2
+--R                                      120a b c  - 15b c
+--R                                 *
+--R                                     2 4
+--R                                    d e
+--R                                + 
+--R                                              3   6       2 3 5         5 4
+--R                                        - 128a b c  + 282a b c  - 140a b c
+--R                                      + 
+--R                                           7 3
+--R                                        20b c
+--R                                 *
+--R                                     3 3
+--R                                    d e
+--R                                + 
+--R                                      3 7       2 2 6        4 5      6 4  4 2
+--R                                  (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                + 
+--R                                      2   7        3 6     5 5  5
+--R                                  (36a b c  - 30a b c  + 6b c )d e
+--R                                + 
+--R                                       2 8       2 7    4 6  6
+--R                                  (- 4a c  + 4a b c  - b c )d
+--R                             /
+--R                                        3 13         2 2 12          4 11
+--R                                  46656a c   - 34992a b c   + 8748a b c
+--R                                + 
+--R                                        6 10
+--R                                  - 729b c
+--R                       + 
+--R                             2 2       2     4  3            2     3     2
+--R                         (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                       + 
+--R                              3     2 2  2       3 3
+--R                         (3a c  - 3b c )d e + b c d
+--R                    /
+--R                             6      2 5
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                      5   2      4 3      3 5  7
+--R                  (10a b c  - 10a b c + 2a b )e
+--R                + 
+--R                        5 3     4 2 2      3 4      2 6    6
+--R                  (- 12a c  + 4a b c  + 14a b c - 4a b )d e
+--R                + 
+--R                      4   3      3 3 2     2 5        7  2 5
+--R                  (26a b c  - 52a b c  + 6a b c + 2a b )d e
+--R                + 
+--R                        4 4      3 2 3      2 4 2        6   3 4
+--R                  (- 20a c  + 50a b c  + 20a b c  - 10a b c)d e
+--R                + 
+--R                        3   4      2 3 3        5 2  4 3
+--R                  (- 10a b c  - 60a b c  + 20a b c )d e
+--R                + 
+--R                       3 5      2 2 4        4 3  5 2
+--R                  (- 4a c  + 60a b c  - 20a b c )d e
+--R                + 
+--R                        2   5        3 4  6       2 6       2 5  7
+--R                  (- 26a b c  + 10a b c )d e + (4a c  - 2a b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                              6      2 5
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                     ROOT
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                          + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                           *
+--R                                 5
+--R                              d e
+--R                          + 
+--R                                     4 6       3 2 5       2 4 4         6 3
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     8 2
+--R                                - 15b c
+--R                           *
+--R                               2 4
+--R                              d e
+--R                          + 
+--R                                   3   6       2 3 5         5 4      7 3  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                          + 
+--R                                3 7       2 2 6        4 5      6 4  4 2
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                2   7        3 6     5 5  5
+--R                            (36a b c  - 30a b c  + 6b c )d e
+--R                          + 
+--R                                 2 8       2 7    4 6  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                3 13         2 2 12          4 11       6 10
+--R                          46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                       2 2       2     4  3            2     3     2
+--R                   (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (3a c  - 3b c )d e + b c d
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                     4 9         3 2 8         2 4 7
+--R                             - 15552a c  + 27216a b c  - 14580a b c
+--R                           + 
+--R                                    6 6       8 5
+--R                             3159a b c  - 243b c
+--R                        *
+--R                            2
+--R                           e
+--R                       + 
+--R                                  3   9         2 3 8          5 7       7 6
+--R                         (- 31104a b c  + 23328a b c  - 5832a b c  + 486b c )d e
+--R                       + 
+--R                                3 10         2 2 9          4 8       6 7  2
+--R                         (15552a c   - 11664a b c  + 2916a b c  - 243b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                                     4 2 4       3 4 3       2 6 2         8
+--R                               - 540a b c  + 855a b c  - 468a b c  + 108a b c
+--R                             + 
+--R                                   10
+--R                               - 9b
+--R                        *
+--R                            5
+--R                           e
+--R                       + 
+--R                                  4   5        3 3 4        2 5 3         7 2
+--R                             1368a b c  - 2934a b c  + 1908a b c  - 495a b c
+--R                           + 
+--R                                9
+--R                             45b c
+--R                        *
+--R                              4
+--R                           d e
+--R                       + 
+--R                                   4 6        3 2 5        2 4 4         6 3
+--R                             - 864a c  + 3528a b c  - 2952a b c  + 891a b c
+--R                           + 
+--R                                  8 2
+--R                             - 90b c
+--R                        *
+--R                            2 3
+--R                           d e
+--R                       + 
+--R                                 3   6        2 3 5         5 4      7 3  3 2
+--R                         (- 1728a b c  + 2124a b c  - 783a b c  + 90b c )d e
+--R                       + 
+--R                              3 7       2 2 6         4 5      6 4  4
+--R                         (288a c  - 684a b c  + 333a b c  - 45b c )d e
+--R                       + 
+--R                             2   7        3 6     5 5  5
+--R                         (72a b c  - 54a b c  + 9b c )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                       6      2 5
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                              ROOT
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                            4   5       3 3 4       2 5 3
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                                7 2     9
+--R                                         - 54a b c  + 6b c
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                              4 6       3 2 5       2 4 4
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                               6 3      8 2
+--R                                         120a b c  - 15b c
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                               3   6       2 3 5         5 4
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            7 3
+--R                                         20b c
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                           3 7       2 2 6        4 5      6 4
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                         2   7        3 6     5 5  5
+--R                                     (36a b c  - 30a b c  + 6b c )d e
+--R                                   + 
+--R                                          2 8       2 7    4 6  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                                2 2       2     4  3            2     3     2
+--R                            (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (3a c  - 3b c )d e + b c d
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 4   7       3 3 6      2 5 5  3
+--R                         (- 1296a b c  + 648a b c  - 81a b c )e
+--R                       + 
+--R                               4 8       2 4 6        6 5    2
+--R                         (2592a c  - 486a b c  + 81a b c )d e
+--R                       + 
+--R                                 3   8        2 3 7         5 6  2
+--R                         (- 3888a b c  + 1944a b c  - 243a b c )d e
+--R                       + 
+--R                               3 9        2 2 8         4 7  3
+--R                         (2592a c  - 1296a b c  + 162a b c )d
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                         5   3      4 3 2      3 5      2 7  6
+--R                     (60a b c  - 75a b c  + 27a b c - 3a b )e
+--R                   + 
+--R                           5 4       4 2 3     3 4 2      2 6        8    5
+--R                     (- 72a c  + 102a b c  + 3a b c  - 18a b c + 3a b )d e
+--R                   + 
+--R                         4   4       3 3 3      2 5 2        7   2 4
+--R                     (24a b c  - 174a b c  + 90a b c  - 12a b c)d e
+--R                   + 
+--R                           4 5       3 2 4       2 4 3        6 2  3 3
+--R                     (- 48a c  + 252a b c  - 132a b c  + 18a b c )d e
+--R                   + 
+--R                            3   5      2 3 4        5 3  4 2
+--R                     (- 132a b c  + 81a b c  - 12a b c )d e
+--R                   + 
+--R                         3 6      2 2 5       4 4  5
+--R                     (24a c  - 18a b c  + 3a b c )d e
+--R                *
+--R                   ROOT
+--R                                     6      2 5
+--R                            (- 108a c  + 27b c )
+--R                         *
+--R                            ROOT
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  *
+--R                                      6
+--R                                     e
+--R                                 + 
+--R                                          4   5       3 3 4       2 5 3
+--R                                       60a b c  - 180a b c  + 162a b c
+--R                                     + 
+--R                                              7 2     9
+--R                                       - 54a b c  + 6b c
+--R                                  *
+--R                                        5
+--R                                     d e
+--R                                 + 
+--R                                            4 6       3 2 5       2 4 4
+--R                                       - 36a c  + 234a b c  - 300a b c
+--R                                     + 
+--R                                             6 3      8 2
+--R                                       120a b c  - 15b c
+--R                                  *
+--R                                      2 4
+--R                                     d e
+--R                                 + 
+--R                                             3   6       2 3 5         5 4
+--R                                       - 128a b c  + 282a b c  - 140a b c
+--R                                     + 
+--R                                          7 3
+--R                                       20b c
+--R                                  *
+--R                                      3 3
+--R                                     d e
+--R                                 + 
+--R                                       3 7       2 2 6        4 5      6 4  4 2
+--R                                   (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                 + 
+--R                                       2   7        3 6     5 5  5
+--R                                   (36a b c  - 30a b c  + 6b c )d e
+--R                                 + 
+--R                                        2 8       2 7    4 6  6
+--R                                   (- 4a c  + 4a b c  - b c )d
+--R                              /
+--R                                         3 13         2 2 12          4 11
+--R                                   46656a c   - 34992a b c   + 8748a b c
+--R                                 + 
+--R                                         6 10
+--R                                   - 729b c
+--R                        + 
+--R                              2 2       2     4  3            2     3     2
+--R                          (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                        + 
+--R                               3     2 2  2       3 3
+--R                          (3a c  - 3b c )d e + b c d
+--R                     /
+--R                              6      2 5
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                         5   2      4 3      3 5  7
+--R                     (10a b c  - 10a b c + 2a b )e
+--R                   + 
+--R                           5 3     4 2 2      3 4      2 6    6
+--R                     (- 12a c  + 4a b c  + 14a b c - 4a b )d e
+--R                   + 
+--R                         4   3      3 3 2     2 5        7  2 5
+--R                     (26a b c  - 52a b c  + 6a b c + 2a b )d e
+--R                   + 
+--R                           4 4      3 2 3      2 4 2        6   3 4
+--R                     (- 20a c  + 50a b c  + 20a b c  - 10a b c)d e
+--R                   + 
+--R                           3   4      2 3 3        5 2  4 3
+--R                     (- 10a b c  - 60a b c  + 20a b c )d e
+--R                   + 
+--R                          3 5      2 2 4        4 3  5 2
+--R                     (- 4a c  + 60a b c  - 20a b c )d e
+--R                   + 
+--R                           2   5        3 4  6       2 6       2 5  7
+--R                     (- 26a b c  + 10a b c )d e + (4a c  - 2a b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R         2c
+--R      *
+--R         ROOT
+--R                         6      2 5
+--R                  (108a c  - 27b c )
+--R               *
+--R                  ROOT
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                       + 
+--R                               4   5       3 3 4       2 5 3        7 2     9
+--R                           (60a b c  - 180a b c  + 162a b c  - 54a b c  + 6b c)d
+--R                        *
+--R                            5
+--R                           e
+--R                       + 
+--R                                    4 6       3 2 5       2 4 4         6 3
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    8 2
+--R                               - 15b c
+--R                        *
+--R                            2 4
+--R                           d e
+--R                       + 
+--R                                3   6       2 3 5         5 4      7 3  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                       + 
+--R                             3 7       2 2 6        4 5      6 4  4 2
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                             2   7        3 6     5 5  5
+--R                         (36a b c  - 30a b c  + 6b c )d e
+--R                       + 
+--R                              2 8       2 7    4 6  6
+--R                         (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R              + 
+--R                    2 2       2     4  3            2     3     2
+--R                (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R              + 
+--R                     3     2 2  2       3 3
+--R                (3a c  - 3b c )d e + b c d
+--R           /
+--R                    6      2 5
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                                  4 9         3 2 8         2 4 7          6 6
+--R                          - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                        + 
+--R                                8 5
+--R                          - 243b c
+--R                     *
+--R                         2
+--R                        e
+--R                    + 
+--R                               3   9         2 3 8          5 7       7 6
+--R                      (- 31104a b c  + 23328a b c  - 5832a b c  + 486b c )d e
+--R                    + 
+--R                             3 10         2 2 9          4 8       6 7  2
+--R                      (15552a c   - 11664a b c  + 2916a b c  - 243b c )d
+--R                 *
+--R                    ROOT
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                         + 
+--R                                    4   5       3 3 4       2 5 3        7 2
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                   9
+--R                                 6b c
+--R                          *
+--R                                5
+--R                             d e
+--R                         + 
+--R                                    4 6       3 2 5       2 4 4         6 3
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    8 2
+--R                               - 15b c
+--R                          *
+--R                              2 4
+--R                             d e
+--R                         + 
+--R                                  3   6       2 3 5         5 4      7 3  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                         + 
+--R                               3 7       2 2 6        4 5      6 4  4 2
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                               2   7        3 6     5 5  5
+--R                           (36a b c  - 30a b c  + 6b c )d e
+--R                         + 
+--R                                2 8       2 7    4 6  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                + 
+--R                       4 2 4       3 4 3       2 6 2         8      10  5
+--R                  (540a b c  - 855a b c  + 468a b c  - 108a b c + 9b  )e
+--R                + 
+--R                            4   5        3 3 4        2 5 3         7 2      9
+--R                    (- 1368a b c  + 2934a b c  - 1908a b c  + 495a b c  - 45b c)
+--R                 *
+--R                       4
+--R                    d e
+--R                + 
+--R                       4 6        3 2 5        2 4 4         6 3      8 2  2 3
+--R                  (864a c  - 3528a b c  + 2952a b c  - 891a b c  + 90b c )d e
+--R                + 
+--R                        3   6        2 3 5         5 4      7 3  3 2
+--R                  (1728a b c  - 2124a b c  + 783a b c  - 90b c )d e
+--R                + 
+--R                         3 7       2 2 6         4 5      6 4  4
+--R                  (- 288a c  + 684a b c  - 333a b c  + 45b c )d e
+--R                + 
+--R                        2   7        3 6     5 5  5
+--R                  (- 72a b c  + 54a b c  - 9b c )d
+--R             *
+--R                  ROOT
+--R                                  6      2 5
+--R                           (108a c  - 27b c )
+--R                        *
+--R                           ROOT
+--R                                           4 2 4      3 4 3      2 6 2        8
+--R                                      - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                    + 
+--R                                         10
+--R                                      - b
+--R                                 *
+--R                                     6
+--R                                    e
+--R                                + 
+--R                                         4   5       3 3 4       2 5 3
+--R                                      60a b c  - 180a b c  + 162a b c
+--R                                    + 
+--R                                             7 2     9
+--R                                      - 54a b c  + 6b c
+--R                                 *
+--R                                       5
+--R                                    d e
+--R                                + 
+--R                                           4 6       3 2 5       2 4 4
+--R                                      - 36a c  + 234a b c  - 300a b c
+--R                                    + 
+--R                                            6 3      8 2
+--R                                      120a b c  - 15b c
+--R                                 *
+--R                                     2 4
+--R                                    d e
+--R                                + 
+--R                                              3   6       2 3 5         5 4
+--R                                        - 128a b c  + 282a b c  - 140a b c
+--R                                      + 
+--R                                           7 3
+--R                                        20b c
+--R                                 *
+--R                                     3 3
+--R                                    d e
+--R                                + 
+--R                                      3 7       2 2 6        4 5      6 4  4 2
+--R                                  (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                + 
+--R                                      2   7        3 6     5 5  5
+--R                                  (36a b c  - 30a b c  + 6b c )d e
+--R                                + 
+--R                                       2 8       2 7    4 6  6
+--R                                  (- 4a c  + 4a b c  - b c )d
+--R                             /
+--R                                        3 13         2 2 12          4 11
+--R                                  46656a c   - 34992a b c   + 8748a b c
+--R                                + 
+--R                                        6 10
+--R                                  - 729b c
+--R                       + 
+--R                             2 2       2     4  3            2     3     2
+--R                         (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                       + 
+--R                              3     2 2  2       3 3
+--R                         (3a c  - 3b c )d e + b c d
+--R                    /
+--R                             6      2 5
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                      5   2      4 3      3 5  7
+--R                  (10a b c  - 10a b c + 2a b )e
+--R                + 
+--R                        5 3     4 2 2      3 4      2 6    6
+--R                  (- 12a c  + 4a b c  + 14a b c - 4a b )d e
+--R                + 
+--R                      4   3      3 3 2     2 5        7  2 5
+--R                  (26a b c  - 52a b c  + 6a b c + 2a b )d e
+--R                + 
+--R                        4 4      3 2 3      2 4 2        6   3 4
+--R                  (- 20a c  + 50a b c  + 20a b c  - 10a b c)d e
+--R                + 
+--R                        3   4      2 3 3        5 2  4 3
+--R                  (- 10a b c  - 60a b c  + 20a b c )d e
+--R                + 
+--R                       3 5      2 2 4        4 3  5 2
+--R                  (- 4a c  + 60a b c  - 20a b c )d e
+--R                + 
+--R                        2   5        3 4  6       2 6       2 5  7
+--R                  (- 26a b c  + 10a b c )d e + (4a c  - 2a b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R               +-+
+--R            2c\|3
+--R         *
+--R            ROOT
+--R                              6      2 5
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                     ROOT
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                          + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                           *
+--R                                 5
+--R                              d e
+--R                          + 
+--R                                     4 6       3 2 5       2 4 4         6 3
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     8 2
+--R                                - 15b c
+--R                           *
+--R                               2 4
+--R                              d e
+--R                          + 
+--R                                   3   6       2 3 5         5 4      7 3  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                          + 
+--R                                3 7       2 2 6        4 5      6 4  4 2
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                2   7        3 6     5 5  5
+--R                            (36a b c  - 30a b c  + 6b c )d e
+--R                          + 
+--R                                 2 8       2 7    4 6  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                3 13         2 2 12          4 11       6 10
+--R                          46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                       2 2       2     4  3            2     3     2
+--R                   (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (3a c  - 3b c )d e + b c d
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                                   4 9         3 2 8         2 4 7          6 6
+--R                             15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                           + 
+--R                                 8 5
+--R                             243b c
+--R                        *
+--R                            2
+--R                           e
+--R                       + 
+--R                                3   9         2 3 8          5 7       7 6
+--R                         (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                       + 
+--R                                  3 10         2 2 9          4 8       6 7  2
+--R                         (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                              4 2 4       3 4 3       2 6 2         8      10  5
+--R                         (540a b c  - 855a b c  + 468a b c  - 108a b c + 9b  )e
+--R                       + 
+--R                                    4   5        3 3 4        2 5 3         7 2
+--R                             - 1368a b c  + 2934a b c  - 1908a b c  + 495a b c
+--R                           + 
+--R                                  9
+--R                             - 45b c
+--R                        *
+--R                              4
+--R                           d e
+--R                       + 
+--R                                 4 6        3 2 5        2 4 4         6 3
+--R                             864a c  - 3528a b c  + 2952a b c  - 891a b c
+--R                           + 
+--R                                8 2
+--R                             90b c
+--R                        *
+--R                            2 3
+--R                           d e
+--R                       + 
+--R                               3   6        2 3 5         5 4      7 3  3 2
+--R                         (1728a b c  - 2124a b c  + 783a b c  - 90b c )d e
+--R                       + 
+--R                                3 7       2 2 6         4 5      6 4  4
+--R                         (- 288a c  + 684a b c  - 333a b c  + 45b c )d e
+--R                       + 
+--R                               2   7        3 6     5 5  5
+--R                         (- 72a b c  + 54a b c  - 9b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                       6      2 5
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                              ROOT
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                            4   5       3 3 4       2 5 3
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                                7 2     9
+--R                                         - 54a b c  + 6b c
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                              4 6       3 2 5       2 4 4
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                               6 3      8 2
+--R                                         120a b c  - 15b c
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                               3   6       2 3 5         5 4
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            7 3
+--R                                         20b c
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                           3 7       2 2 6        4 5      6 4
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                         2   7        3 6     5 5  5
+--R                                     (36a b c  - 30a b c  + 6b c )d e
+--R                                   + 
+--R                                          2 8       2 7    4 6  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                                2 2       2     4  3            2     3     2
+--R                            (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (3a c  - 3b c )d e + b c d
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                     4 9         3 2 8         2 4 7
+--R                               15552a c  - 27216a b c  + 14580a b c
+--R                             + 
+--R                                        6 6       8 5
+--R                               - 3159a b c  + 243b c
+--R                          *
+--R                              2
+--R                             e
+--R                         + 
+--R                                  3   9         2 3 8          5 7       7 6
+--R                           (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                         + 
+--R                                  3 10         2 2 9          4 8       6 7  2
+--R                         (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                      *
+--R                         ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  e
+--R                              + 
+--R                                       4   5       3 3 4       2 5 3        7 2
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                      9
+--R                                    6b c
+--R                               *
+--R                                     5
+--R                                  d e
+--R                              + 
+--R                                         4 6       3 2 5       2 4 4         6 3
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         8 2
+--R                                    - 15b c
+--R                               *
+--R                                   2 4
+--R                                  d e
+--R                              + 
+--R                                         3   6       2 3 5         5 4      7 3
+--R                                  (- 128a b c  + 282a b c  - 140a b c  + 20b c )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                    3 7       2 2 6        4 5      6 4  4 2
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                    2   7        3 6     5 5  5
+--R                                (36a b c  - 30a b c  + 6b c )d e
+--R                              + 
+--R                                     2 8       2 7    4 6  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                     + 
+--R                            4 2 4       3 4 3       2 6 2         8      10  5
+--R                       (540a b c  - 855a b c  + 468a b c  - 108a b c + 9b  )e
+--R                     + 
+--R                                  4   5        3 3 4        2 5 3         7 2
+--R                           - 1368a b c  + 2934a b c  - 1908a b c  + 495a b c
+--R                         + 
+--R                                9
+--R                           - 45b c
+--R                      *
+--R                            4
+--R                         d e
+--R                     + 
+--R                                 4 6        3 2 5        2 4 4         6 3
+--R                             864a c  - 3528a b c  + 2952a b c  - 891a b c
+--R                           + 
+--R                                8 2
+--R                             90b c
+--R                      *
+--R                          2 3
+--R                         d e
+--R                     + 
+--R                             3   6        2 3 5         5 4      7 3  3 2
+--R                       (1728a b c  - 2124a b c  + 783a b c  - 90b c )d e
+--R                     + 
+--R                              3 7       2 2 6         4 5      6 4  4
+--R                       (- 288a c  + 684a b c  - 333a b c  + 45b c )d e
+--R                     + 
+--R                             2   7        3 6     5 5  5
+--R                       (- 72a b c  + 54a b c  - 9b c )d
+--R                  *
+--R                       ROOT
+--R                                         6      2 5
+--R                                (- 108a c  + 27b c )
+--R                             *
+--R                                ROOT
+--R                                                4 2 4      3 4 3      2 6 2
+--R                                           - 25a b c  + 50a b c  - 35a b c
+--R                                         + 
+--R                                                8     10
+--R                                           10a b c - b
+--R                                      *
+--R                                          6
+--R                                         e
+--R                                     + 
+--R                                              4   5       3 3 4       2 5 3
+--R                                           60a b c  - 180a b c  + 162a b c
+--R                                         + 
+--R                                                  7 2     9
+--R                                           - 54a b c  + 6b c
+--R                                      *
+--R                                            5
+--R                                         d e
+--R                                     + 
+--R                                                4 6       3 2 5       2 4 4
+--R                                           - 36a c  + 234a b c  - 300a b c
+--R                                         + 
+--R                                                 6 3      8 2
+--R                                           120a b c  - 15b c
+--R                                      *
+--R                                          2 4
+--R                                         d e
+--R                                     + 
+--R                                                 3   6       2 3 5         5 4
+--R                                           - 128a b c  + 282a b c  - 140a b c
+--R                                         + 
+--R                                              7 3
+--R                                           20b c
+--R                                      *
+--R                                          3 3
+--R                                         d e
+--R                                     + 
+--R                                                3 7       2 2 6        4 5
+--R                                             24a c  - 141a b c  + 90a b c
+--R                                           + 
+--R                                                  6 4
+--R                                             - 15b c
+--R                                      *
+--R                                          4 2
+--R                                         d e
+--R                                     + 
+--R                                           2   7        3 6     5 5  5
+--R                                       (36a b c  - 30a b c  + 6b c )d e
+--R                                     + 
+--R                                            2 8       2 7    4 6  6
+--R                                       (- 4a c  + 4a b c  - b c )d
+--R                                  /
+--R                                             3 13         2 2 12          4 11
+--R                                       46656a c   - 34992a b c   + 8748a b c
+--R                                     + 
+--R                                             6 10
+--R                                       - 729b c
+--R                            + 
+--R                                  2 2       2     4  3            2     3     2
+--R                              (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                            + 
+--R                                   3     2 2  2       3 3
+--R                              (3a c  - 3b c )d e + b c d
+--R                         /
+--R                                  6      2 5
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                             5   2      4 3      3 5  7
+--R                       (- 20a b c  + 20a b c - 4a b )e
+--R                     + 
+--R                           5 3     4 2 2      3 4      2 6    6
+--R                       (24a c  - 8a b c  - 28a b c + 8a b )d e
+--R                     + 
+--R                             4   3       3 3 2      2 5        7  2 5
+--R                       (- 52a b c  + 104a b c  - 12a b c - 4a b )d e
+--R                     + 
+--R                           4 4       3 2 3      2 4 2        6   3 4
+--R                       (40a c  - 100a b c  - 40a b c  + 20a b c)d e
+--R                     + 
+--R                           3   4       2 3 3        5 2  4 3
+--R                       (20a b c  + 120a b c  - 40a b c )d e
+--R                     + 
+--R                          3 5       2 2 4        4 3  5 2
+--R                       (8a c  - 120a b c  + 40a b c )d e
+--R                     + 
+--R                           2   5        3 4  6         2 6       2 5  7
+--R                       (52a b c  - 20a b c )d e + (- 8a c  + 4a b c )d
+--R                  *
+--R                     x
+--R     + 
+--R       -
+--R               +-+
+--R            2c\|3
+--R         *
+--R            ROOT
+--R                            6      2 5
+--R                     (108a c  - 27b c )
+--R                  *
+--R                     ROOT
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                          + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                           *
+--R                                 5
+--R                              d e
+--R                          + 
+--R                                     4 6       3 2 5       2 4 4         6 3
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     8 2
+--R                                - 15b c
+--R                           *
+--R                               2 4
+--R                              d e
+--R                          + 
+--R                                   3   6       2 3 5         5 4      7 3  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                          + 
+--R                                3 7       2 2 6        4 5      6 4  4 2
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                2   7        3 6     5 5  5
+--R                            (36a b c  - 30a b c  + 6b c )d e
+--R                          + 
+--R                                 2 8       2 7    4 6  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                3 13         2 2 12          4 11       6 10
+--R                          46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                       2 2       2     4  3            2     3     2
+--R                   (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (3a c  - 3b c )d e + b c d
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                                   4 9         3 2 8         2 4 7          6 6
+--R                             15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                           + 
+--R                                 8 5
+--R                             243b c
+--R                        *
+--R                            2
+--R                           e
+--R                       + 
+--R                                3   9         2 3 8          5 7       7 6
+--R                         (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                       + 
+--R                                  3 10         2 2 9          4 8       6 7  2
+--R                         (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                                     4 2 4       3 4 3       2 6 2         8
+--R                               - 540a b c  + 855a b c  - 468a b c  + 108a b c
+--R                             + 
+--R                                   10
+--R                               - 9b
+--R                        *
+--R                            5
+--R                           e
+--R                       + 
+--R                                  4   5        3 3 4        2 5 3         7 2
+--R                             1368a b c  - 2934a b c  + 1908a b c  - 495a b c
+--R                           + 
+--R                                9
+--R                             45b c
+--R                        *
+--R                              4
+--R                           d e
+--R                       + 
+--R                                   4 6        3 2 5        2 4 4         6 3
+--R                             - 864a c  + 3528a b c  - 2952a b c  + 891a b c
+--R                           + 
+--R                                  8 2
+--R                             - 90b c
+--R                        *
+--R                            2 3
+--R                           d e
+--R                       + 
+--R                                 3   6        2 3 5         5 4      7 3  3 2
+--R                         (- 1728a b c  + 2124a b c  - 783a b c  + 90b c )d e
+--R                       + 
+--R                              3 7       2 2 6         4 5      6 4  4
+--R                         (288a c  - 684a b c  + 333a b c  - 45b c )d e
+--R                       + 
+--R                             2   7        3 6     5 5  5
+--R                         (72a b c  - 54a b c  + 9b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                     6      2 5
+--R                              (108a c  - 27b c )
+--R                           *
+--R                              ROOT
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                            4   5       3 3 4       2 5 3
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                                7 2     9
+--R                                         - 54a b c  + 6b c
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                              4 6       3 2 5       2 4 4
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                               6 3      8 2
+--R                                         120a b c  - 15b c
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                               3   6       2 3 5         5 4
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            7 3
+--R                                         20b c
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                           3 7       2 2 6        4 5      6 4
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                         2   7        3 6     5 5  5
+--R                                     (36a b c  - 30a b c  + 6b c )d e
+--R                                   + 
+--R                                          2 8       2 7    4 6  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                                2 2       2     4  3            2     3     2
+--R                            (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (3a c  - 3b c )d e + b c d
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                     4 9         3 2 8         2 4 7
+--R                               15552a c  - 27216a b c  + 14580a b c
+--R                             + 
+--R                                        6 6       8 5
+--R                               - 3159a b c  + 243b c
+--R                          *
+--R                              2
+--R                             e
+--R                         + 
+--R                                  3   9         2 3 8          5 7       7 6
+--R                           (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                         + 
+--R                                  3 10         2 2 9          4 8       6 7  2
+--R                         (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                      *
+--R                         ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  e
+--R                              + 
+--R                                       4   5       3 3 4       2 5 3        7 2
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                      9
+--R                                    6b c
+--R                               *
+--R                                     5
+--R                                  d e
+--R                              + 
+--R                                         4 6       3 2 5       2 4 4         6 3
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         8 2
+--R                                    - 15b c
+--R                               *
+--R                                   2 4
+--R                                  d e
+--R                              + 
+--R                                         3   6       2 3 5         5 4      7 3
+--R                                  (- 128a b c  + 282a b c  - 140a b c  + 20b c )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                    3 7       2 2 6        4 5      6 4  4 2
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                    2   7        3 6     5 5  5
+--R                                (36a b c  - 30a b c  + 6b c )d e
+--R                              + 
+--R                                     2 8       2 7    4 6  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                     + 
+--R                              4 2 4       3 4 3       2 6 2         8      10  5
+--R                       (- 540a b c  + 855a b c  - 468a b c  + 108a b c - 9b  )e
+--R                     + 
+--R                                4   5        3 3 4        2 5 3         7 2
+--R                           1368a b c  - 2934a b c  + 1908a b c  - 495a b c
+--R                         + 
+--R                              9
+--R                           45b c
+--R                      *
+--R                            4
+--R                         d e
+--R                     + 
+--R                                 4 6        3 2 5        2 4 4         6 3
+--R                           - 864a c  + 3528a b c  - 2952a b c  + 891a b c
+--R                         + 
+--R                                8 2
+--R                           - 90b c
+--R                      *
+--R                          2 3
+--R                         d e
+--R                     + 
+--R                               3   6        2 3 5         5 4      7 3  3 2
+--R                       (- 1728a b c  + 2124a b c  - 783a b c  + 90b c )d e
+--R                     + 
+--R                            3 7       2 2 6         4 5      6 4  4
+--R                       (288a c  - 684a b c  + 333a b c  - 45b c )d e
+--R                     + 
+--R                           2   7        3 6     5 5  5
+--R                       (72a b c  - 54a b c  + 9b c )d
+--R                  *
+--R                       ROOT
+--R                                       6      2 5
+--R                                (108a c  - 27b c )
+--R                             *
+--R                                ROOT
+--R                                                4 2 4      3 4 3      2 6 2
+--R                                           - 25a b c  + 50a b c  - 35a b c
+--R                                         + 
+--R                                                8     10
+--R                                           10a b c - b
+--R                                      *
+--R                                          6
+--R                                         e
+--R                                     + 
+--R                                              4   5       3 3 4       2 5 3
+--R                                           60a b c  - 180a b c  + 162a b c
+--R                                         + 
+--R                                                  7 2     9
+--R                                           - 54a b c  + 6b c
+--R                                      *
+--R                                            5
+--R                                         d e
+--R                                     + 
+--R                                                4 6       3 2 5       2 4 4
+--R                                           - 36a c  + 234a b c  - 300a b c
+--R                                         + 
+--R                                                 6 3      8 2
+--R                                           120a b c  - 15b c
+--R                                      *
+--R                                          2 4
+--R                                         d e
+--R                                     + 
+--R                                                 3   6       2 3 5         5 4
+--R                                           - 128a b c  + 282a b c  - 140a b c
+--R                                         + 
+--R                                              7 3
+--R                                           20b c
+--R                                      *
+--R                                          3 3
+--R                                         d e
+--R                                     + 
+--R                                                3 7       2 2 6        4 5
+--R                                             24a c  - 141a b c  + 90a b c
+--R                                           + 
+--R                                                  6 4
+--R                                             - 15b c
+--R                                      *
+--R                                          4 2
+--R                                         d e
+--R                                     + 
+--R                                           2   7        3 6     5 5  5
+--R                                       (36a b c  - 30a b c  + 6b c )d e
+--R                                     + 
+--R                                            2 8       2 7    4 6  6
+--R                                       (- 4a c  + 4a b c  - b c )d
+--R                                  /
+--R                                             3 13         2 2 12          4 11
+--R                                       46656a c   - 34992a b c   + 8748a b c
+--R                                     + 
+--R                                             6 10
+--R                                       - 729b c
+--R                            + 
+--R                                  2 2       2     4  3            2     3     2
+--R                              (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                            + 
+--R                                   3     2 2  2       3 3
+--R                              (3a c  - 3b c )d e + b c d
+--R                         /
+--R                                  6      2 5
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                           5   2      4 3      3 5  7
+--R                       (20a b c  - 20a b c + 4a b )e
+--R                     + 
+--R                             5 3     4 2 2      3 4      2 6    6
+--R                       (- 24a c  + 8a b c  + 28a b c - 8a b )d e
+--R                     + 
+--R                           4   3       3 3 2      2 5        7  2 5
+--R                       (52a b c  - 104a b c  + 12a b c + 4a b )d e
+--R                     + 
+--R                             4 4       3 2 3      2 4 2        6   3 4
+--R                       (- 40a c  + 100a b c  + 40a b c  - 20a b c)d e
+--R                     + 
+--R                             3   4       2 3 3        5 2  4 3
+--R                       (- 20a b c  - 120a b c  + 40a b c )d e
+--R                     + 
+--R                            3 5       2 2 4        4 3  5 2
+--R                       (- 8a c  + 120a b c  - 40a b c )d e
+--R                     + 
+--R                             2   5        3 4  6       2 6       2 5  7
+--R                       (- 52a b c  + 20a b c )d e + (8a c  - 4a b c )d
+--R                  *
+--R                     x
+--R     + 
+--R          2
+--R       e x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +-----------+
+--R                      +-+ |          2                2            +-+
+--R         ((b e - c d)\|3 \|- 4a c + b   + ((- 2a c + b )e - b c d)\|3 )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+
+--R         3|   |          2
+--R         \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                              +-----------+
+--R                          +-+ |          2               2             +-+
+--R         ((- 2b e + 2c d)\|3 \|- 4a c + b   + ((4a c - 2b )e + 2b c d)\|3 )
+--R      *
+--R          +--------------------+     +------------------+
+--R          |   +-----------+          | +-----------+
+--R         3|   |          2          3| |          2          3+-+3+-+
+--R         \|- \|- 4a c + b   + b log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                                             +--------------------+
+--R                         +-----------+       |   +-----------+
+--R               3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R            3c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            6      2 5
+--R                     (108a c  - 27b c )
+--R                  *
+--R                     ROOT
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                          + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                           *
+--R                                 5
+--R                              d e
+--R                          + 
+--R                                     4 6       3 2 5       2 4 4         6 3
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     8 2
+--R                                - 15b c
+--R                           *
+--R                               2 4
+--R                              d e
+--R                          + 
+--R                                   3   6       2 3 5         5 4      7 3  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                          + 
+--R                                3 7       2 2 6        4 5      6 4  4 2
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                2   7        3 6     5 5  5
+--R                            (36a b c  - 30a b c  + 6b c )d e
+--R                          + 
+--R                                 2 8       2 7    4 6  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                3 13         2 2 12          4 11       6 10
+--R                          46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                       2 2       2     4  3            2     3     2
+--R                   (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (3a c  - 3b c )d e + b c d
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                   4 9         3 2 8         2 4 7          6 6
+--R                             15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                           + 
+--R                                 8 5
+--R                             243b c
+--R                        *
+--R                            2
+--R                           e
+--R                       + 
+--R                                3   9         2 3 8          5 7       7 6
+--R                         (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                       + 
+--R                                  3 10         2 2 9          4 8       6 7  2
+--R                         (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                                     4 2 4       3 4 3       2 6 2         8
+--R                               - 540a b c  + 855a b c  - 468a b c  + 108a b c
+--R                             + 
+--R                                   10
+--R                               - 9b
+--R                        *
+--R                            5
+--R                           e
+--R                       + 
+--R                                  4   5        3 3 4        2 5 3         7 2
+--R                             1368a b c  - 2934a b c  + 1908a b c  - 495a b c
+--R                           + 
+--R                                9
+--R                             45b c
+--R                        *
+--R                              4
+--R                           d e
+--R                       + 
+--R                                   4 6        3 2 5        2 4 4         6 3
+--R                             - 864a c  + 3528a b c  - 2952a b c  + 891a b c
+--R                           + 
+--R                                  8 2
+--R                             - 90b c
+--R                        *
+--R                            2 3
+--R                           d e
+--R                       + 
+--R                                 3   6        2 3 5         5 4      7 3  3 2
+--R                         (- 1728a b c  + 2124a b c  - 783a b c  + 90b c )d e
+--R                       + 
+--R                              3 7       2 2 6         4 5      6 4  4
+--R                         (288a c  - 684a b c  + 333a b c  - 45b c )d e
+--R                       + 
+--R                             2   7        3 6     5 5  5
+--R                         (72a b c  - 54a b c  + 9b c )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                     6      2 5
+--R                              (108a c  - 27b c )
+--R                           *
+--R                              ROOT
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                            4   5       3 3 4       2 5 3
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                                7 2     9
+--R                                         - 54a b c  + 6b c
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                              4 6       3 2 5       2 4 4
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                               6 3      8 2
+--R                                         120a b c  - 15b c
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                               3   6       2 3 5         5 4
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            7 3
+--R                                         20b c
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                           3 7       2 2 6        4 5      6 4
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                         2   7        3 6     5 5  5
+--R                                     (36a b c  - 30a b c  + 6b c )d e
+--R                                   + 
+--R                                          2 8       2 7    4 6  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                                2 2       2     4  3            2     3     2
+--R                            (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (3a c  - 3b c )d e + b c d
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               4   7       3 3 6      2 5 5  3
+--R                         (1296a b c  - 648a b c  + 81a b c )e
+--R                       + 
+--R                                 4 8       2 4 6        6 5    2
+--R                         (- 2592a c  + 486a b c  - 81a b c )d e
+--R                       + 
+--R                               3   8        2 3 7         5 6  2
+--R                         (3888a b c  - 1944a b c  + 243a b c )d e
+--R                       + 
+--R                                 3 9        2 2 8         4 7  3
+--R                         (- 2592a c  + 1296a b c  - 162a b c )d
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                         5   3      4 3 2      3 5      2 7  6
+--R                     (60a b c  - 75a b c  + 27a b c - 3a b )e
+--R                   + 
+--R                           5 4       4 2 3     3 4 2      2 6        8    5
+--R                     (- 72a c  + 102a b c  + 3a b c  - 18a b c + 3a b )d e
+--R                   + 
+--R                         4   4       3 3 3      2 5 2        7   2 4
+--R                     (24a b c  - 174a b c  + 90a b c  - 12a b c)d e
+--R                   + 
+--R                           4 5       3 2 4       2 4 3        6 2  3 3
+--R                     (- 48a c  + 252a b c  - 132a b c  + 18a b c )d e
+--R                   + 
+--R                            3   5      2 3 4        5 3  4 2
+--R                     (- 132a b c  + 81a b c  - 12a b c )d e
+--R                   + 
+--R                         3 6      2 2 5       4 4  5
+--R                     (24a c  - 18a b c  + 3a b c )d e
+--R                *
+--R                   ROOT
+--R                                   6      2 5
+--R                            (108a c  - 27b c )
+--R                         *
+--R                            ROOT
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  *
+--R                                      6
+--R                                     e
+--R                                 + 
+--R                                          4   5       3 3 4       2 5 3
+--R                                       60a b c  - 180a b c  + 162a b c
+--R                                     + 
+--R                                              7 2     9
+--R                                       - 54a b c  + 6b c
+--R                                  *
+--R                                        5
+--R                                     d e
+--R                                 + 
+--R                                            4 6       3 2 5       2 4 4
+--R                                       - 36a c  + 234a b c  - 300a b c
+--R                                     + 
+--R                                             6 3      8 2
+--R                                       120a b c  - 15b c
+--R                                  *
+--R                                      2 4
+--R                                     d e
+--R                                 + 
+--R                                             3   6       2 3 5         5 4
+--R                                       - 128a b c  + 282a b c  - 140a b c
+--R                                     + 
+--R                                          7 3
+--R                                       20b c
+--R                                  *
+--R                                      3 3
+--R                                     d e
+--R                                 + 
+--R                                       3 7       2 2 6        4 5      6 4  4 2
+--R                                   (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                 + 
+--R                                       2   7        3 6     5 5  5
+--R                                   (36a b c  - 30a b c  + 6b c )d e
+--R                                 + 
+--R                                        2 8       2 7    4 6  6
+--R                                   (- 4a c  + 4a b c  - b c )d
+--R                              /
+--R                                         3 13         2 2 12          4 11
+--R                                   46656a c   - 34992a b c   + 8748a b c
+--R                                 + 
+--R                                         6 10
+--R                                   - 729b c
+--R                        + 
+--R                              2 2       2     4  3            2     3     2
+--R                          (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                        + 
+--R                               3     2 2  2       3 3
+--R                          (3a c  - 3b c )d e + b c d
+--R                     /
+--R                              6      2 5
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                         5   2      4 3      3 5  7
+--R                     (10a b c  - 10a b c + 2a b )e
+--R                   + 
+--R                           5 3     4 2 2      3 4      2 6    6
+--R                     (- 12a c  + 4a b c  + 14a b c - 4a b )d e
+--R                   + 
+--R                         4   3      3 3 2     2 5        7  2 5
+--R                     (26a b c  - 52a b c  + 6a b c + 2a b )d e
+--R                   + 
+--R                           4 4      3 2 3      2 4 2        6   3 4
+--R                     (- 20a c  + 50a b c  + 20a b c  - 10a b c)d e
+--R                   + 
+--R                           3   4      2 3 3        5 2  4 3
+--R                     (- 10a b c  - 60a b c  + 20a b c )d e
+--R                   + 
+--R                          3 5      2 2 4        4 3  5 2
+--R                     (- 4a c  + 60a b c  - 20a b c )d e
+--R                   + 
+--R                           2   5        3 4  6       2 6       2 5  7
+--R                     (- 26a b c  + 10a b c )d e + (4a c  - 2a b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                                          +--------------------+
+--R                      +-----------+       |   +-----------+
+--R            3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R         6c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           6      2 5
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                  ROOT
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                       + 
+--R                               4   5       3 3 4       2 5 3        7 2     9
+--R                           (60a b c  - 180a b c  + 162a b c  - 54a b c  + 6b c)d
+--R                        *
+--R                            5
+--R                           e
+--R                       + 
+--R                                    4 6       3 2 5       2 4 4         6 3
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    8 2
+--R                               - 15b c
+--R                        *
+--R                            2 4
+--R                           d e
+--R                       + 
+--R                                3   6       2 3 5         5 4      7 3  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                       + 
+--R                             3 7       2 2 6        4 5      6 4  4 2
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                             2   7        3 6     5 5  5
+--R                         (36a b c  - 30a b c  + 6b c )d e
+--R                       + 
+--R                              2 8       2 7    4 6  6
+--R                         (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R              + 
+--R                    2 2       2     4  3            2     3     2
+--R                (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R              + 
+--R                     3     2 2  2       3 3
+--R                (3a c  - 3b c )d e + b c d
+--R           /
+--R                    6      2 5
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                4 9         3 2 8         2 4 7          6 6
+--R                          15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                        + 
+--R                              8 5
+--R                          243b c
+--R                     *
+--R                         2
+--R                        e
+--R                    + 
+--R                             3   9         2 3 8          5 7       7 6
+--R                      (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                    + 
+--R                               3 10         2 2 9          4 8       6 7  2
+--R                      (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                 *
+--R                    ROOT
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                         + 
+--R                                    4   5       3 3 4       2 5 3        7 2
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                   9
+--R                                 6b c
+--R                          *
+--R                                5
+--R                             d e
+--R                         + 
+--R                                    4 6       3 2 5       2 4 4         6 3
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    8 2
+--R                               - 15b c
+--R                          *
+--R                              2 4
+--R                             d e
+--R                         + 
+--R                                  3   6       2 3 5         5 4      7 3  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                         + 
+--R                               3 7       2 2 6        4 5      6 4  4 2
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                               2   7        3 6     5 5  5
+--R                           (36a b c  - 30a b c  + 6b c )d e
+--R                         + 
+--R                                2 8       2 7    4 6  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                + 
+--R                       4 2 4       3 4 3       2 6 2         8      10  5
+--R                  (540a b c  - 855a b c  + 468a b c  - 108a b c + 9b  )e
+--R                + 
+--R                            4   5        3 3 4        2 5 3         7 2      9
+--R                    (- 1368a b c  + 2934a b c  - 1908a b c  + 495a b c  - 45b c)
+--R                 *
+--R                       4
+--R                    d e
+--R                + 
+--R                       4 6        3 2 5        2 4 4         6 3      8 2  2 3
+--R                  (864a c  - 3528a b c  + 2952a b c  - 891a b c  + 90b c )d e
+--R                + 
+--R                        3   6        2 3 5         5 4      7 3  3 2
+--R                  (1728a b c  - 2124a b c  + 783a b c  - 90b c )d e
+--R                + 
+--R                         3 7       2 2 6         4 5      6 4  4
+--R                  (- 288a c  + 684a b c  - 333a b c  + 45b c )d e
+--R                + 
+--R                        2   7        3 6     5 5  5
+--R                  (- 72a b c  + 54a b c  - 9b c )d
+--R             *
+--R                  ROOT
+--R                                    6      2 5
+--R                           (- 108a c  + 27b c )
+--R                        *
+--R                           ROOT
+--R                                           4 2 4      3 4 3      2 6 2        8
+--R                                      - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                    + 
+--R                                         10
+--R                                      - b
+--R                                 *
+--R                                     6
+--R                                    e
+--R                                + 
+--R                                         4   5       3 3 4       2 5 3
+--R                                      60a b c  - 180a b c  + 162a b c
+--R                                    + 
+--R                                             7 2     9
+--R                                      - 54a b c  + 6b c
+--R                                 *
+--R                                       5
+--R                                    d e
+--R                                + 
+--R                                           4 6       3 2 5       2 4 4
+--R                                      - 36a c  + 234a b c  - 300a b c
+--R                                    + 
+--R                                            6 3      8 2
+--R                                      120a b c  - 15b c
+--R                                 *
+--R                                     2 4
+--R                                    d e
+--R                                + 
+--R                                              3   6       2 3 5         5 4
+--R                                        - 128a b c  + 282a b c  - 140a b c
+--R                                      + 
+--R                                           7 3
+--R                                        20b c
+--R                                 *
+--R                                     3 3
+--R                                    d e
+--R                                + 
+--R                                      3 7       2 2 6        4 5      6 4  4 2
+--R                                  (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                + 
+--R                                      2   7        3 6     5 5  5
+--R                                  (36a b c  - 30a b c  + 6b c )d e
+--R                                + 
+--R                                       2 8       2 7    4 6  6
+--R                                  (- 4a c  + 4a b c  - b c )d
+--R                             /
+--R                                        3 13         2 2 12          4 11
+--R                                  46656a c   - 34992a b c   + 8748a b c
+--R                                + 
+--R                                        6 10
+--R                                  - 729b c
+--R                       + 
+--R                             2 2       2     4  3            2     3     2
+--R                         (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                       + 
+--R                              3     2 2  2       3 3
+--R                         (3a c  - 3b c )d e + b c d
+--R                    /
+--R                             6      2 5
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                      5   2      4 3      3 5  7
+--R                  (10a b c  - 10a b c + 2a b )e
+--R                + 
+--R                        5 3     4 2 2      3 4      2 6    6
+--R                  (- 12a c  + 4a b c  + 14a b c - 4a b )d e
+--R                + 
+--R                      4   3      3 3 2     2 5        7  2 5
+--R                  (26a b c  - 52a b c  + 6a b c + 2a b )d e
+--R                + 
+--R                        4 4      3 2 3      2 4 2        6   3 4
+--R                  (- 20a c  + 50a b c  + 20a b c  - 10a b c)d e
+--R                + 
+--R                        3   4      2 3 3        5 2  4 3
+--R                  (- 10a b c  - 60a b c  + 20a b c )d e
+--R                + 
+--R                       3 5      2 2 4        4 3  5 2
+--R                  (- 4a c  + 60a b c  - 20a b c )d e
+--R                + 
+--R                        2   5        3 4  6       2 6       2 5  7
+--R                  (- 26a b c  + 10a b c )d e + (4a c  - 2a b c )d
+--R             *
+--R                x
+--R     + 
+--R                          +-----------+
+--R                      +-+ |          2              2            +-+
+--R         ((b e - c d)\|3 \|- 4a c + b   + ((2a c - b )e + b c d)\|3 )
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                              +-----------+
+--R                          +-+ |          2                 2             +-+
+--R         ((- 2b e + 2c d)\|3 \|- 4a c + b   + ((- 4a c + 2b )e - 2b c d)\|3 )
+--R      *
+--R          +------------------+     +--------------------+
+--R          | +-----------+          |   +-----------+
+--R         3| |          2          3|   |          2          3+-+3+-+
+--R         \|\|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                                             +--------------------+
+--R                         +-----------+       |   +-----------+
+--R               3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R            3c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                              6      2 5
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                     ROOT
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                          + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                           *
+--R                                 5
+--R                              d e
+--R                          + 
+--R                                     4 6       3 2 5       2 4 4         6 3
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     8 2
+--R                                - 15b c
+--R                           *
+--R                               2 4
+--R                              d e
+--R                          + 
+--R                                   3   6       2 3 5         5 4      7 3  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                          + 
+--R                                3 7       2 2 6        4 5      6 4  4 2
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                2   7        3 6     5 5  5
+--R                            (36a b c  - 30a b c  + 6b c )d e
+--R                          + 
+--R                                 2 8       2 7    4 6  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                3 13         2 2 12          4 11       6 10
+--R                          46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                       2 2       2     4  3            2     3     2
+--R                   (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (3a c  - 3b c )d e + b c d
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                     4 9         3 2 8         2 4 7
+--R                             - 15552a c  + 27216a b c  - 14580a b c
+--R                           + 
+--R                                    6 6       8 5
+--R                             3159a b c  - 243b c
+--R                        *
+--R                            2
+--R                           e
+--R                       + 
+--R                                  3   9         2 3 8          5 7       7 6
+--R                         (- 31104a b c  + 23328a b c  - 5832a b c  + 486b c )d e
+--R                       + 
+--R                                3 10         2 2 9          4 8       6 7  2
+--R                         (15552a c   - 11664a b c  + 2916a b c  - 243b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                                     4 2 4       3 4 3       2 6 2         8
+--R                               - 540a b c  + 855a b c  - 468a b c  + 108a b c
+--R                             + 
+--R                                   10
+--R                               - 9b
+--R                        *
+--R                            5
+--R                           e
+--R                       + 
+--R                                  4   5        3 3 4        2 5 3         7 2
+--R                             1368a b c  - 2934a b c  + 1908a b c  - 495a b c
+--R                           + 
+--R                                9
+--R                             45b c
+--R                        *
+--R                              4
+--R                           d e
+--R                       + 
+--R                                   4 6        3 2 5        2 4 4         6 3
+--R                             - 864a c  + 3528a b c  - 2952a b c  + 891a b c
+--R                           + 
+--R                                  8 2
+--R                             - 90b c
+--R                        *
+--R                            2 3
+--R                           d e
+--R                       + 
+--R                                 3   6        2 3 5         5 4      7 3  3 2
+--R                         (- 1728a b c  + 2124a b c  - 783a b c  + 90b c )d e
+--R                       + 
+--R                              3 7       2 2 6         4 5      6 4  4
+--R                         (288a c  - 684a b c  + 333a b c  - 45b c )d e
+--R                       + 
+--R                             2   7        3 6     5 5  5
+--R                         (72a b c  - 54a b c  + 9b c )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                       6      2 5
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                              ROOT
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                            4   5       3 3 4       2 5 3
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                                7 2     9
+--R                                         - 54a b c  + 6b c
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                              4 6       3 2 5       2 4 4
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                               6 3      8 2
+--R                                         120a b c  - 15b c
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                               3   6       2 3 5         5 4
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            7 3
+--R                                         20b c
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                           3 7       2 2 6        4 5      6 4
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                         2   7        3 6     5 5  5
+--R                                     (36a b c  - 30a b c  + 6b c )d e
+--R                                   + 
+--R                                          2 8       2 7    4 6  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                                2 2       2     4  3            2     3     2
+--R                            (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (3a c  - 3b c )d e + b c d
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 4   7       3 3 6      2 5 5  3
+--R                         (- 1296a b c  + 648a b c  - 81a b c )e
+--R                       + 
+--R                               4 8       2 4 6        6 5    2
+--R                         (2592a c  - 486a b c  + 81a b c )d e
+--R                       + 
+--R                                 3   8        2 3 7         5 6  2
+--R                         (- 3888a b c  + 1944a b c  - 243a b c )d e
+--R                       + 
+--R                               3 9        2 2 8         4 7  3
+--R                         (2592a c  - 1296a b c  + 162a b c )d
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                         5   3      4 3 2      3 5      2 7  6
+--R                     (60a b c  - 75a b c  + 27a b c - 3a b )e
+--R                   + 
+--R                           5 4       4 2 3     3 4 2      2 6        8    5
+--R                     (- 72a c  + 102a b c  + 3a b c  - 18a b c + 3a b )d e
+--R                   + 
+--R                         4   4       3 3 3      2 5 2        7   2 4
+--R                     (24a b c  - 174a b c  + 90a b c  - 12a b c)d e
+--R                   + 
+--R                           4 5       3 2 4       2 4 3        6 2  3 3
+--R                     (- 48a c  + 252a b c  - 132a b c  + 18a b c )d e
+--R                   + 
+--R                            3   5      2 3 4        5 3  4 2
+--R                     (- 132a b c  + 81a b c  - 12a b c )d e
+--R                   + 
+--R                         3 6      2 2 5       4 4  5
+--R                     (24a c  - 18a b c  + 3a b c )d e
+--R                *
+--R                   ROOT
+--R                                     6      2 5
+--R                            (- 108a c  + 27b c )
+--R                         *
+--R                            ROOT
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  *
+--R                                      6
+--R                                     e
+--R                                 + 
+--R                                          4   5       3 3 4       2 5 3
+--R                                       60a b c  - 180a b c  + 162a b c
+--R                                     + 
+--R                                              7 2     9
+--R                                       - 54a b c  + 6b c
+--R                                  *
+--R                                        5
+--R                                     d e
+--R                                 + 
+--R                                            4 6       3 2 5       2 4 4
+--R                                       - 36a c  + 234a b c  - 300a b c
+--R                                     + 
+--R                                             6 3      8 2
+--R                                       120a b c  - 15b c
+--R                                  *
+--R                                      2 4
+--R                                     d e
+--R                                 + 
+--R                                             3   6       2 3 5         5 4
+--R                                       - 128a b c  + 282a b c  - 140a b c
+--R                                     + 
+--R                                          7 3
+--R                                       20b c
+--R                                  *
+--R                                      3 3
+--R                                     d e
+--R                                 + 
+--R                                       3 7       2 2 6        4 5      6 4  4 2
+--R                                   (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                 + 
+--R                                       2   7        3 6     5 5  5
+--R                                   (36a b c  - 30a b c  + 6b c )d e
+--R                                 + 
+--R                                        2 8       2 7    4 6  6
+--R                                   (- 4a c  + 4a b c  - b c )d
+--R                              /
+--R                                         3 13         2 2 12          4 11
+--R                                   46656a c   - 34992a b c   + 8748a b c
+--R                                 + 
+--R                                         6 10
+--R                                   - 729b c
+--R                        + 
+--R                              2 2       2     4  3            2     3     2
+--R                          (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                        + 
+--R                               3     2 2  2       3 3
+--R                          (3a c  - 3b c )d e + b c d
+--R                     /
+--R                              6      2 5
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                         5   2      4 3      3 5  7
+--R                     (10a b c  - 10a b c + 2a b )e
+--R                   + 
+--R                           5 3     4 2 2      3 4      2 6    6
+--R                     (- 12a c  + 4a b c  + 14a b c - 4a b )d e
+--R                   + 
+--R                         4   3      3 3 2     2 5        7  2 5
+--R                     (26a b c  - 52a b c  + 6a b c + 2a b )d e
+--R                   + 
+--R                           4 4      3 2 3      2 4 2        6   3 4
+--R                     (- 20a c  + 50a b c  + 20a b c  - 10a b c)d e
+--R                   + 
+--R                           3   4      2 3 3        5 2  4 3
+--R                     (- 10a b c  - 60a b c  + 20a b c )d e
+--R                   + 
+--R                          3 5      2 2 4        4 3  5 2
+--R                     (- 4a c  + 60a b c  - 20a b c )d e
+--R                   + 
+--R                           2   5        3 4  6       2 6       2 5  7
+--R                     (- 26a b c  + 10a b c )d e + (4a c  - 2a b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                                          +--------------------+
+--R                      +-----------+       |   +-----------+
+--R            3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R         6c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         6      2 5
+--R                  (108a c  - 27b c )
+--R               *
+--R                  ROOT
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                       + 
+--R                               4   5       3 3 4       2 5 3        7 2     9
+--R                           (60a b c  - 180a b c  + 162a b c  - 54a b c  + 6b c)d
+--R                        *
+--R                            5
+--R                           e
+--R                       + 
+--R                                    4 6       3 2 5       2 4 4         6 3
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    8 2
+--R                               - 15b c
+--R                        *
+--R                            2 4
+--R                           d e
+--R                       + 
+--R                                3   6       2 3 5         5 4      7 3  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                       + 
+--R                             3 7       2 2 6        4 5      6 4  4 2
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                             2   7        3 6     5 5  5
+--R                         (36a b c  - 30a b c  + 6b c )d e
+--R                       + 
+--R                              2 8       2 7    4 6  6
+--R                         (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             3 13         2 2 12          4 11       6 10
+--R                       46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R              + 
+--R                    2 2       2     4  3            2     3     2
+--R                (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R              + 
+--R                     3     2 2  2       3 3
+--R                (3a c  - 3b c )d e + b c d
+--R           /
+--R                    6      2 5
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                  4 9         3 2 8         2 4 7          6 6
+--R                          - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                        + 
+--R                                8 5
+--R                          - 243b c
+--R                     *
+--R                         2
+--R                        e
+--R                    + 
+--R                               3   9         2 3 8          5 7       7 6
+--R                      (- 31104a b c  + 23328a b c  - 5832a b c  + 486b c )d e
+--R                    + 
+--R                             3 10         2 2 9          4 8       6 7  2
+--R                      (15552a c   - 11664a b c  + 2916a b c  - 243b c )d
+--R                 *
+--R                    ROOT
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                         + 
+--R                                    4   5       3 3 4       2 5 3        7 2
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                   9
+--R                                 6b c
+--R                          *
+--R                                5
+--R                             d e
+--R                         + 
+--R                                    4 6       3 2 5       2 4 4         6 3
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    8 2
+--R                               - 15b c
+--R                          *
+--R                              2 4
+--R                             d e
+--R                         + 
+--R                                  3   6       2 3 5         5 4      7 3  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                         + 
+--R                               3 7       2 2 6        4 5      6 4  4 2
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                               2   7        3 6     5 5  5
+--R                           (36a b c  - 30a b c  + 6b c )d e
+--R                         + 
+--R                                2 8       2 7    4 6  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               3 13         2 2 12          4 11       6 10
+--R                         46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                + 
+--R                       4 2 4       3 4 3       2 6 2         8      10  5
+--R                  (540a b c  - 855a b c  + 468a b c  - 108a b c + 9b  )e
+--R                + 
+--R                            4   5        3 3 4        2 5 3         7 2      9
+--R                    (- 1368a b c  + 2934a b c  - 1908a b c  + 495a b c  - 45b c)
+--R                 *
+--R                       4
+--R                    d e
+--R                + 
+--R                       4 6        3 2 5        2 4 4         6 3      8 2  2 3
+--R                  (864a c  - 3528a b c  + 2952a b c  - 891a b c  + 90b c )d e
+--R                + 
+--R                        3   6        2 3 5         5 4      7 3  3 2
+--R                  (1728a b c  - 2124a b c  + 783a b c  - 90b c )d e
+--R                + 
+--R                         3 7       2 2 6         4 5      6 4  4
+--R                  (- 288a c  + 684a b c  - 333a b c  + 45b c )d e
+--R                + 
+--R                        2   7        3 6     5 5  5
+--R                  (- 72a b c  + 54a b c  - 9b c )d
+--R             *
+--R                  ROOT
+--R                                  6      2 5
+--R                           (108a c  - 27b c )
+--R                        *
+--R                           ROOT
+--R                                           4 2 4      3 4 3      2 6 2        8
+--R                                      - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                    + 
+--R                                         10
+--R                                      - b
+--R                                 *
+--R                                     6
+--R                                    e
+--R                                + 
+--R                                         4   5       3 3 4       2 5 3
+--R                                      60a b c  - 180a b c  + 162a b c
+--R                                    + 
+--R                                             7 2     9
+--R                                      - 54a b c  + 6b c
+--R                                 *
+--R                                       5
+--R                                    d e
+--R                                + 
+--R                                           4 6       3 2 5       2 4 4
+--R                                      - 36a c  + 234a b c  - 300a b c
+--R                                    + 
+--R                                            6 3      8 2
+--R                                      120a b c  - 15b c
+--R                                 *
+--R                                     2 4
+--R                                    d e
+--R                                + 
+--R                                              3   6       2 3 5         5 4
+--R                                        - 128a b c  + 282a b c  - 140a b c
+--R                                      + 
+--R                                           7 3
+--R                                        20b c
+--R                                 *
+--R                                     3 3
+--R                                    d e
+--R                                + 
+--R                                      3 7       2 2 6        4 5      6 4  4 2
+--R                                  (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                + 
+--R                                      2   7        3 6     5 5  5
+--R                                  (36a b c  - 30a b c  + 6b c )d e
+--R                                + 
+--R                                       2 8       2 7    4 6  6
+--R                                  (- 4a c  + 4a b c  - b c )d
+--R                             /
+--R                                        3 13         2 2 12          4 11
+--R                                  46656a c   - 34992a b c   + 8748a b c
+--R                                + 
+--R                                        6 10
+--R                                  - 729b c
+--R                       + 
+--R                             2 2       2     4  3            2     3     2
+--R                         (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                       + 
+--R                              3     2 2  2       3 3
+--R                         (3a c  - 3b c )d e + b c d
+--R                    /
+--R                             6      2 5
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                      5   2      4 3      3 5  7
+--R                  (10a b c  - 10a b c + 2a b )e
+--R                + 
+--R                        5 3     4 2 2      3 4      2 6    6
+--R                  (- 12a c  + 4a b c  + 14a b c - 4a b )d e
+--R                + 
+--R                      4   3      3 3 2     2 5        7  2 5
+--R                  (26a b c  - 52a b c  + 6a b c + 2a b )d e
+--R                + 
+--R                        4 4      3 2 3      2 4 2        6   3 4
+--R                  (- 20a c  + 50a b c  + 20a b c  - 10a b c)d e
+--R                + 
+--R                        3   4      2 3 3        5 2  4 3
+--R                  (- 10a b c  - 60a b c  + 20a b c )d e
+--R                + 
+--R                       3 5      2 2 4        4 3  5 2
+--R                  (- 4a c  + 60a b c  - 20a b c )d e
+--R                + 
+--R                        2   5        3 4  6       2 6       2 5  7
+--R                  (- 26a b c  + 10a b c )d e + (4a c  - 2a b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                          +--------------------+
+--R                      +-----------+       |   +-----------+
+--R                3+-+2 |          2 3+-+2 3|   |          2
+--R            18c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                              6      2 5
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                     ROOT
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                          + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                           *
+--R                                 5
+--R                              d e
+--R                          + 
+--R                                     4 6       3 2 5       2 4 4         6 3
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     8 2
+--R                                - 15b c
+--R                           *
+--R                               2 4
+--R                              d e
+--R                          + 
+--R                                   3   6       2 3 5         5 4      7 3  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                          + 
+--R                                3 7       2 2 6        4 5      6 4  4 2
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                2   7        3 6     5 5  5
+--R                            (36a b c  - 30a b c  + 6b c )d e
+--R                          + 
+--R                                 2 8       2 7    4 6  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                3 13         2 2 12          4 11       6 10
+--R                          46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                       2 2       2     4  3            2     3     2
+--R                   (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (3a c  - 3b c )d e + b c d
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            atan
+--R                                   4 9         3 2 8         2 4 7          6 6
+--R                             15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                           + 
+--R                                 8 5
+--R                             243b c
+--R                        *
+--R                            2
+--R                           e
+--R                       + 
+--R                                3   9         2 3 8          5 7       7 6
+--R                         (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                       + 
+--R                                  3 10         2 2 9          4 8       6 7  2
+--R                         (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                              4 2 4       3 4 3       2 6 2         8      10  5
+--R                         (540a b c  - 855a b c  + 468a b c  - 108a b c + 9b  )e
+--R                       + 
+--R                                    4   5        3 3 4        2 5 3         7 2
+--R                             - 1368a b c  + 2934a b c  - 1908a b c  + 495a b c
+--R                           + 
+--R                                  9
+--R                             - 45b c
+--R                        *
+--R                              4
+--R                           d e
+--R                       + 
+--R                                 4 6        3 2 5        2 4 4         6 3
+--R                             864a c  - 3528a b c  + 2952a b c  - 891a b c
+--R                           + 
+--R                                8 2
+--R                             90b c
+--R                        *
+--R                            2 3
+--R                           d e
+--R                       + 
+--R                               3   6        2 3 5         5 4      7 3  3 2
+--R                         (1728a b c  - 2124a b c  + 783a b c  - 90b c )d e
+--R                       + 
+--R                                3 7       2 2 6         4 5      6 4  4
+--R                         (- 288a c  + 684a b c  - 333a b c  + 45b c )d e
+--R                       + 
+--R                               2   7        3 6     5 5  5
+--R                         (- 72a b c  + 54a b c  - 9b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                       6      2 5
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                              ROOT
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                            4   5       3 3 4       2 5 3
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                                7 2     9
+--R                                         - 54a b c  + 6b c
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                              4 6       3 2 5       2 4 4
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                               6 3      8 2
+--R                                         120a b c  - 15b c
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                               3   6       2 3 5         5 4
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            7 3
+--R                                         20b c
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                           3 7       2 2 6        4 5      6 4
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                         2   7        3 6     5 5  5
+--R                                     (36a b c  - 30a b c  + 6b c )d e
+--R                                   + 
+--R                                          2 8       2 7    4 6  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                                2 2       2     4  3            2     3     2
+--R                            (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (3a c  - 3b c )d e + b c d
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                     4 9         3 2 8         2 4 7
+--R                               15552a c  - 27216a b c  + 14580a b c
+--R                             + 
+--R                                        6 6       8 5
+--R                               - 3159a b c  + 243b c
+--R                          *
+--R                              2
+--R                             e
+--R                         + 
+--R                                  3   9         2 3 8          5 7       7 6
+--R                           (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                         + 
+--R                                  3 10         2 2 9          4 8       6 7  2
+--R                         (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                      *
+--R                         ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  e
+--R                              + 
+--R                                       4   5       3 3 4       2 5 3        7 2
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                      9
+--R                                    6b c
+--R                               *
+--R                                     5
+--R                                  d e
+--R                              + 
+--R                                         4 6       3 2 5       2 4 4         6 3
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         8 2
+--R                                    - 15b c
+--R                               *
+--R                                   2 4
+--R                                  d e
+--R                              + 
+--R                                         3   6       2 3 5         5 4      7 3
+--R                                  (- 128a b c  + 282a b c  - 140a b c  + 20b c )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                    3 7       2 2 6        4 5      6 4  4 2
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                    2   7        3 6     5 5  5
+--R                                (36a b c  - 30a b c  + 6b c )d e
+--R                              + 
+--R                                     2 8       2 7    4 6  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                     + 
+--R                            4 2 4       3 4 3       2 6 2         8      10  5
+--R                       (540a b c  - 855a b c  + 468a b c  - 108a b c + 9b  )e
+--R                     + 
+--R                                  4   5        3 3 4        2 5 3         7 2
+--R                           - 1368a b c  + 2934a b c  - 1908a b c  + 495a b c
+--R                         + 
+--R                                9
+--R                           - 45b c
+--R                      *
+--R                            4
+--R                         d e
+--R                     + 
+--R                                 4 6        3 2 5        2 4 4         6 3
+--R                             864a c  - 3528a b c  + 2952a b c  - 891a b c
+--R                           + 
+--R                                8 2
+--R                             90b c
+--R                      *
+--R                          2 3
+--R                         d e
+--R                     + 
+--R                             3   6        2 3 5         5 4      7 3  3 2
+--R                       (1728a b c  - 2124a b c  + 783a b c  - 90b c )d e
+--R                     + 
+--R                              3 7       2 2 6         4 5      6 4  4
+--R                       (- 288a c  + 684a b c  - 333a b c  + 45b c )d e
+--R                     + 
+--R                             2   7        3 6     5 5  5
+--R                       (- 72a b c  + 54a b c  - 9b c )d
+--R                  *
+--R                       ROOT
+--R                                         6      2 5
+--R                                (- 108a c  + 27b c )
+--R                             *
+--R                                ROOT
+--R                                                4 2 4      3 4 3      2 6 2
+--R                                           - 25a b c  + 50a b c  - 35a b c
+--R                                         + 
+--R                                                8     10
+--R                                           10a b c - b
+--R                                      *
+--R                                          6
+--R                                         e
+--R                                     + 
+--R                                              4   5       3 3 4       2 5 3
+--R                                           60a b c  - 180a b c  + 162a b c
+--R                                         + 
+--R                                                  7 2     9
+--R                                           - 54a b c  + 6b c
+--R                                      *
+--R                                            5
+--R                                         d e
+--R                                     + 
+--R                                                4 6       3 2 5       2 4 4
+--R                                           - 36a c  + 234a b c  - 300a b c
+--R                                         + 
+--R                                                 6 3      8 2
+--R                                           120a b c  - 15b c
+--R                                      *
+--R                                          2 4
+--R                                         d e
+--R                                     + 
+--R                                                 3   6       2 3 5         5 4
+--R                                           - 128a b c  + 282a b c  - 140a b c
+--R                                         + 
+--R                                              7 3
+--R                                           20b c
+--R                                      *
+--R                                          3 3
+--R                                         d e
+--R                                     + 
+--R                                                3 7       2 2 6        4 5
+--R                                             24a c  - 141a b c  + 90a b c
+--R                                           + 
+--R                                                  6 4
+--R                                             - 15b c
+--R                                      *
+--R                                          4 2
+--R                                         d e
+--R                                     + 
+--R                                           2   7        3 6     5 5  5
+--R                                       (36a b c  - 30a b c  + 6b c )d e
+--R                                     + 
+--R                                            2 8       2 7    4 6  6
+--R                                       (- 4a c  + 4a b c  - b c )d
+--R                                  /
+--R                                             3 13         2 2 12          4 11
+--R                                       46656a c   - 34992a b c   + 8748a b c
+--R                                     + 
+--R                                             6 10
+--R                                       - 729b c
+--R                            + 
+--R                                  2 2       2     4  3            2     3     2
+--R                              (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                            + 
+--R                                   3     2 2  2       3 3
+--R                              (3a c  - 3b c )d e + b c d
+--R                         /
+--R                                  6      2 5
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                             5   2      4 3      3 5  7
+--R                       (- 20a b c  + 20a b c - 4a b )e
+--R                     + 
+--R                           5 3     4 2 2      3 4      2 6    6
+--R                       (24a c  - 8a b c  - 28a b c + 8a b )d e
+--R                     + 
+--R                             4   3       3 3 2      2 5        7  2 5
+--R                       (- 52a b c  + 104a b c  - 12a b c - 4a b )d e
+--R                     + 
+--R                           4 4       3 2 3      2 4 2        6   3 4
+--R                       (40a c  - 100a b c  - 40a b c  + 20a b c)d e
+--R                     + 
+--R                           3   4       2 3 3        5 2  4 3
+--R                       (20a b c  + 120a b c  - 40a b c )d e
+--R                     + 
+--R                          3 5       2 2 4        4 3  5 2
+--R                       (8a c  - 120a b c  + 40a b c )d e
+--R                     + 
+--R                           2   5        3 4  6         2 6       2 5  7
+--R                       (52a b c  - 20a b c )d e + (- 8a c  + 4a b c )d
+--R                  *
+--R                     x
+--R     + 
+--R       -
+--R                                          +--------------------+
+--R                      +-----------+       |   +-----------+
+--R                3+-+2 |          2 3+-+2 3|   |          2
+--R            18c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            6      2 5
+--R                     (108a c  - 27b c )
+--R                  *
+--R                     ROOT
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )e
+--R                          + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                           *
+--R                                 5
+--R                              d e
+--R                          + 
+--R                                     4 6       3 2 5       2 4 4         6 3
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     8 2
+--R                                - 15b c
+--R                           *
+--R                               2 4
+--R                              d e
+--R                          + 
+--R                                   3   6       2 3 5         5 4      7 3  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                          + 
+--R                                3 7       2 2 6        4 5      6 4  4 2
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                2   7        3 6     5 5  5
+--R                            (36a b c  - 30a b c  + 6b c )d e
+--R                          + 
+--R                                 2 8       2 7    4 6  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                3 13         2 2 12          4 11       6 10
+--R                          46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                 + 
+--R                       2 2       2     4  3            2     3     2
+--R                   (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                 + 
+--R                        3     2 2  2       3 3
+--R                   (3a c  - 3b c )d e + b c d
+--R              /
+--R                       6      2 5
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            atan
+--R                                   4 9         3 2 8         2 4 7          6 6
+--R                             15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                           + 
+--R                                 8 5
+--R                             243b c
+--R                        *
+--R                            2
+--R                           e
+--R                       + 
+--R                                3   9         2 3 8          5 7       7 6
+--R                         (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                       + 
+--R                                  3 10         2 2 9          4 8       6 7  2
+--R                         (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                             *
+--R                                 6
+--R                                e
+--R                            + 
+--R                                     4   5       3 3 4       2 5 3        7 2
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                    9
+--R                                  6b c
+--R                             *
+--R                                   5
+--R                                d e
+--R                            + 
+--R                                       4 6       3 2 5       2 4 4         6 3
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       8 2
+--R                                  - 15b c
+--R                             *
+--R                                 2 4
+--R                                d e
+--R                            + 
+--R                                     3   6       2 3 5         5 4      7 3  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c  + 20b c )d e
+--R                            + 
+--R                                  3 7       2 2 6        4 5      6 4  4 2
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                  2   7        3 6     5 5  5
+--R                              (36a b c  - 30a b c  + 6b c )d e
+--R                            + 
+--R                                   2 8       2 7    4 6  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  3 13         2 2 12          4 11       6 10
+--R                            46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                   + 
+--R                                     4 2 4       3 4 3       2 6 2         8
+--R                               - 540a b c  + 855a b c  - 468a b c  + 108a b c
+--R                             + 
+--R                                   10
+--R                               - 9b
+--R                        *
+--R                            5
+--R                           e
+--R                       + 
+--R                                  4   5        3 3 4        2 5 3         7 2
+--R                             1368a b c  - 2934a b c  + 1908a b c  - 495a b c
+--R                           + 
+--R                                9
+--R                             45b c
+--R                        *
+--R                              4
+--R                           d e
+--R                       + 
+--R                                   4 6        3 2 5        2 4 4         6 3
+--R                             - 864a c  + 3528a b c  - 2952a b c  + 891a b c
+--R                           + 
+--R                                  8 2
+--R                             - 90b c
+--R                        *
+--R                            2 3
+--R                           d e
+--R                       + 
+--R                                 3   6        2 3 5         5 4      7 3  3 2
+--R                         (- 1728a b c  + 2124a b c  - 783a b c  + 90b c )d e
+--R                       + 
+--R                              3 7       2 2 6         4 5      6 4  4
+--R                         (288a c  - 684a b c  + 333a b c  - 45b c )d e
+--R                       + 
+--R                             2   7        3 6     5 5  5
+--R                         (72a b c  - 54a b c  + 9b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                     6      2 5
+--R                              (108a c  - 27b c )
+--R                           *
+--R                              ROOT
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                            4   5       3 3 4       2 5 3
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                                7 2     9
+--R                                         - 54a b c  + 6b c
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                              4 6       3 2 5       2 4 4
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                               6 3      8 2
+--R                                         120a b c  - 15b c
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                               3   6       2 3 5         5 4
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            7 3
+--R                                         20b c
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                           3 7       2 2 6        4 5      6 4
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                         2   7        3 6     5 5  5
+--R                                     (36a b c  - 30a b c  + 6b c )d e
+--R                                   + 
+--R                                          2 8       2 7    4 6  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           3 13         2 2 12          4 11
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 10
+--R                                     - 729b c
+--R                          + 
+--R                                2 2       2     4  3            2     3     2
+--R                            (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                          + 
+--R                                 3     2 2  2       3 3
+--R                            (3a c  - 3b c )d e + b c d
+--R                       /
+--R                                6      2 5
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                     4 9         3 2 8         2 4 7
+--R                               15552a c  - 27216a b c  + 14580a b c
+--R                             + 
+--R                                        6 6       8 5
+--R                               - 3159a b c  + 243b c
+--R                          *
+--R                              2
+--R                             e
+--R                         + 
+--R                                  3   9         2 3 8          5 7       7 6
+--R                           (31104a b c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                         + 
+--R                                  3 10         2 2 9          4 8       6 7  2
+--R                         (- 15552a c   + 11664a b c  - 2916a b c  + 243b c )d
+--R                      *
+--R                         ROOT
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  e
+--R                              + 
+--R                                       4   5       3 3 4       2 5 3        7 2
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                      9
+--R                                    6b c
+--R                               *
+--R                                     5
+--R                                  d e
+--R                              + 
+--R                                         4 6       3 2 5       2 4 4         6 3
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         8 2
+--R                                    - 15b c
+--R                               *
+--R                                   2 4
+--R                                  d e
+--R                              + 
+--R                                         3   6       2 3 5         5 4      7 3
+--R                                  (- 128a b c  + 282a b c  - 140a b c  + 20b c )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                    3 7       2 2 6        4 5      6 4  4 2
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                    2   7        3 6     5 5  5
+--R                                (36a b c  - 30a b c  + 6b c )d e
+--R                              + 
+--R                                     2 8       2 7    4 6  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    3 13         2 2 12          4 11       6 10
+--R                              46656a c   - 34992a b c   + 8748a b c   - 729b c
+--R                     + 
+--R                              4 2 4       3 4 3       2 6 2         8      10  5
+--R                       (- 540a b c  + 855a b c  - 468a b c  + 108a b c - 9b  )e
+--R                     + 
+--R                                4   5        3 3 4        2 5 3         7 2
+--R                           1368a b c  - 2934a b c  + 1908a b c  - 495a b c
+--R                         + 
+--R                              9
+--R                           45b c
+--R                      *
+--R                            4
+--R                         d e
+--R                     + 
+--R                                 4 6        3 2 5        2 4 4         6 3
+--R                           - 864a c  + 3528a b c  - 2952a b c  + 891a b c
+--R                         + 
+--R                                8 2
+--R                           - 90b c
+--R                      *
+--R                          2 3
+--R                         d e
+--R                     + 
+--R                               3   6        2 3 5         5 4      7 3  3 2
+--R                       (- 1728a b c  + 2124a b c  - 783a b c  + 90b c )d e
+--R                     + 
+--R                            3 7       2 2 6         4 5      6 4  4
+--R                       (288a c  - 684a b c  + 333a b c  - 45b c )d e
+--R                     + 
+--R                           2   7        3 6     5 5  5
+--R                       (72a b c  - 54a b c  + 9b c )d
+--R                  *
+--R                       ROOT
+--R                                       6      2 5
+--R                                (108a c  - 27b c )
+--R                             *
+--R                                ROOT
+--R                                                4 2 4      3 4 3      2 6 2
+--R                                           - 25a b c  + 50a b c  - 35a b c
+--R                                         + 
+--R                                                8     10
+--R                                           10a b c - b
+--R                                      *
+--R                                          6
+--R                                         e
+--R                                     + 
+--R                                              4   5       3 3 4       2 5 3
+--R                                           60a b c  - 180a b c  + 162a b c
+--R                                         + 
+--R                                                  7 2     9
+--R                                           - 54a b c  + 6b c
+--R                                      *
+--R                                            5
+--R                                         d e
+--R                                     + 
+--R                                                4 6       3 2 5       2 4 4
+--R                                           - 36a c  + 234a b c  - 300a b c
+--R                                         + 
+--R                                                 6 3      8 2
+--R                                           120a b c  - 15b c
+--R                                      *
+--R                                          2 4
+--R                                         d e
+--R                                     + 
+--R                                                 3   6       2 3 5         5 4
+--R                                           - 128a b c  + 282a b c  - 140a b c
+--R                                         + 
+--R                                              7 3
+--R                                           20b c
+--R                                      *
+--R                                          3 3
+--R                                         d e
+--R                                     + 
+--R                                                3 7       2 2 6        4 5
+--R                                             24a c  - 141a b c  + 90a b c
+--R                                           + 
+--R                                                  6 4
+--R                                             - 15b c
+--R                                      *
+--R                                          4 2
+--R                                         d e
+--R                                     + 
+--R                                           2   7        3 6     5 5  5
+--R                                       (36a b c  - 30a b c  + 6b c )d e
+--R                                     + 
+--R                                            2 8       2 7    4 6  6
+--R                                       (- 4a c  + 4a b c  - b c )d
+--R                                  /
+--R                                             3 13         2 2 12          4 11
+--R                                       46656a c   - 34992a b c   + 8748a b c
+--R                                     + 
+--R                                             6 10
+--R                                       - 729b c
+--R                            + 
+--R                                  2 2       2     4  3            2     3     2
+--R                              (- a c  + 3a b c - b )e  + (- 6a b c  + 3b c)d e
+--R                            + 
+--R                                   3     2 2  2       3 3
+--R                              (3a c  - 3b c )d e + b c d
+--R                         /
+--R                                  6      2 5
+--R                            216a c  - 54b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                           5   2      4 3      3 5  7
+--R                       (20a b c  - 20a b c + 4a b )e
+--R                     + 
+--R                             5 3     4 2 2      3 4      2 6    6
+--R                       (- 24a c  + 8a b c  + 28a b c - 8a b )d e
+--R                     + 
+--R                           4   3       3 3 2      2 5        7  2 5
+--R                       (52a b c  - 104a b c  + 12a b c + 4a b )d e
+--R                     + 
+--R                             4 4       3 2 3      2 4 2        6   3 4
+--R                       (- 40a c  + 100a b c  + 40a b c  - 20a b c)d e
+--R                     + 
+--R                             3   4       2 3 3        5 2  4 3
+--R                       (- 20a b c  - 120a b c  + 40a b c )d e
+--R                     + 
+--R                            3 5       2 2 4        4 3  5 2
+--R                       (- 8a c  + 120a b c  - 40a b c )d e
+--R                     + 
+--R                             2   5        3 4  6       2 6       2 5  7
+--R                       (- 52a b c  + 20a b c )d e + (8a c  - 4a b c )d
+--R                  *
+--R                     x
+--R     + 
+--R                          +-----------+
+--R                          |          2               2
+--R         ((- 6b e + 6c d)\|- 4a c + b   + (12a c - 6b )e + 6b c d)
+--R      *
+--R                                            +------------------+
+--R          +--------------------+            | +-----------+
+--R          |   +-----------+          3+-+2 3| |          2          3+-+
+--R         3|   |          2           \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         \|- \|- 4a c + b   + b atan(-----------------------------------)
+--R                                                  +------------------+
+--R                                                  | +-----------+
+--R                                        3+-+2 +-+3| |          2
+--R                                        \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                          |          2                 2
+--R         ((- 6b e + 6c d)\|- 4a c + b   + (- 12a c + 6b )e - 6b c d)
+--R      *
+--R                                          +--------------------+
+--R          +------------------+            |   +-----------+
+--R          | +-----------+          3+-+2 3|   |          2          3+-+
+--R         3| |          2           \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         \|\|- 4a c + b   + b atan(-------------------------------------)
+--R                                                +--------------------+
+--R                                                |   +-----------+
+--R                                      3+-+2 +-+3|   |          2
+--R                                      \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R        3+-+2 +-+ |          2 3+-+2 3|   |          2      3| |          2
+--R     6c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 649 
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 649
+t0:=x^3*(d+e*x^3)/(a+b*x^3+c*x^6)
+--R 
+--R
+--R             6      3
+--R          e x  + d x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 6
+
+--S 7 of 649
+r0:=e*x/c+1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(c*d-b*e+_
+   (-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b-_
+   sqrt(b^2-4*a*c))^(2/3))-1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*_
+   x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(c*d-b*e+_
+   (-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*_
+   (b-sqrt(b^2-4*a*c))^(2/3))-atan((-4*c^(1/3)*x+2^(2/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b-sqrt(b^2-_
+   4*a*c))^(1/3)))*(c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*c^(4/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(2/3))+1/3*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/_
+   sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b+sqrt(b^2-4*a*c))^(2/3))-_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-_
+   4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*(c*d-b*e+(b*c*d-b^2*e+_
+   2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b+sqrt(b^2-_
+   4*a*c))^(2/3))-atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*_
+   (c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*_
+   sqrt(3)*(b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R                      +-+ |          2                2            +-+
+--R         ((b e - c d)\|3 \|- 4a c + b   + ((- 2a c + b )e - b c d)\|3 )
+--R      *
+--R          +--------------------+2
+--R          |   +-----------+
+--R         3|   |          2
+--R         \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                              +-----------+
+--R                          +-+ |          2               2             +-+
+--R         ((- 2b e + 2c d)\|3 \|- 4a c + b   + ((4a c - 2b )e + 2b c d)\|3 )
+--R      *
+--R          +--------------------+2     +------------------+
+--R          |   +-----------+           | +-----------+
+--R         3|   |          2           3| |          2          3+-+3+-+
+--R         \|- \|- 4a c + b   + b  log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                          +-----------+
+--R                      +-+ |          2              2            +-+
+--R         ((b e - c d)\|3 \|- 4a c + b   + ((2a c - b )e + b c d)\|3 )
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                              +-----------+
+--R                          +-+ |          2                 2             +-+
+--R         ((- 2b e + 2c d)\|3 \|- 4a c + b   + ((- 4a c + 2b )e - 2b c d)\|3 )
+--R      *
+--R          +------------------+2     +--------------------+
+--R          | +-----------+           |   +-----------+
+--R         3| |          2           3|   |          2          3+-+3+-+
+--R         \|\|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                        +-----------+
+--R                        |          2                 2
+--R         ((6b e - 6c d)\|- 4a c + b   + (- 12a c + 6b )e - 6b c d)
+--R      *
+--R                                             +------------------+
+--R          +--------------------+2            | +-----------+
+--R          |   +-----------+           3+-+2 3| |          2          3+-+
+--R         3|   |          2            \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         \|- \|- 4a c + b   + b  atan(-----------------------------------)
+--R                                                   +------------------+
+--R                                                   | +-----------+
+--R                                         3+-+2 +-+3| |          2
+--R                                         \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                        +-----------+
+--R                        |          2               2
+--R         ((6b e - 6c d)\|- 4a c + b   + (12a c - 6b )e + 6b c d)
+--R      *
+--R                                           +--------------------+
+--R          +------------------+2            |   +-----------+
+--R          | +-----------+           3+-+2 3|   |          2          3+-+
+--R         3| |          2            \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         \|\|- 4a c + b   + b  atan(-------------------------------------)
+--R                                                 +--------------------+
+--R                                                 |   +-----------+
+--R                                       3+-+2 +-+3|   |          2
+--R                                       \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                        +--------------------+2
+--R                      +-----------+     |   +-----------+
+--R             3+-+ +-+ |          2 3+-+3|   |          2
+--R         6e x\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+2  +------------------+2
+--R                +-----------+     |   +-----------+        | +-----------+
+--R       3+-+ +-+ |          2 3+-+3|   |          2        3| |          2
+--R     6c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2c
+--R      *
+--R         ROOT
+--R                         5      2 4
+--R                  (108a c  - 27b c )
+--R               *
+--R                  ROOT
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                       + 
+--R                               3   4      2 3 3        5 2     7     5
+--R                         (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                       + 
+--R                             3 5       2 2 4        4 3      6 2  2 4
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                              2   5        3 4      5 3  3 3
+--R                         (112a b c  - 98a b c  + 20b c )d e
+--R                       + 
+--R                               2 6        2 5      4 4  4 2
+--R                         (- 36a c  + 54a b c  - 15b c )d e
+--R                       + 
+--R                                   6     3 5  5     2 6 6
+--R                         (- 12a b c  + 6b c )d e - b c d
+--R                    /
+--R                             3 11         2 2 10          4 9       6 8
+--R                       46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                             3  3        2     2     2       2 2     3 3
+--R                (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                            2   6         3 5      5 4
+--R                      (1296a b c  - 648a b c  + 81b c )e
+--R                    + 
+--R                              2 7          2 6       4 5
+--R                      (- 2592a c  + 1296a b c  - 162b c )d
+--R                 *
+--R                    ROOT
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     5
+--R                           (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                         + 
+--R                               3 5       2 2 4        4 3      6 2  2 4
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                                2   5        3 4      5 3  3 3
+--R                           (112a b c  - 98a b c  + 20b c )d e
+--R                         + 
+--R                                 2 6        2 5      4 4  4 2
+--R                           (- 36a c  + 54a b c  - 15b c )d e
+--R                         + 
+--R                                     6     3 5  5     2 6 6
+--R                           (- 12a b c  + 6b c )d e - b c d
+--R                      /
+--R                               3 11         2 2 10          4 9       6 8
+--R                         46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                        3 3      2 2 2        4      6  4
+--R                  (- 24a c  + 54a b c  - 24a b c + 3b )e
+--R                + 
+--R                         2   3        3 2     5     3
+--R                  (- 108a b c  + 63a b c  - 9b c)d e
+--R                + 
+--R                      2 4        2 3     4 2  2 2           4     3 3  3
+--R                  (72a c  - 54a b c  + 9b c )d e  + (12a b c  - 3b c )d e
+--R             *
+--R                ROOT
+--R                                5      2 4
+--R                         (108a c  - 27b c )
+--R                      *
+--R                         ROOT
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                              + 
+--R                                      3   4      2 3 3        5 2     7     5
+--R                                (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                              + 
+--R                                    3 5       2 2 4        4 3      6 2  2 4
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                     2   5        3 4      5 3  3 3
+--R                                (112a b c  - 98a b c  + 20b c )d e
+--R                              + 
+--R                                      2 6        2 5      4 4  4 2
+--R                                (- 36a c  + 54a b c  - 15b c )d e
+--R                              + 
+--R                                          6     3 5  5     2 6 6
+--R                                (- 12a b c  + 6b c )d e - b c d
+--R                           /
+--R                                    3 11         2 2 10          4 9       6 8
+--R                              46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R                     3 2     2 2        4  5       2   2       3      5    4
+--R                  (4a c  - 8a b c + 2a b )e  + (14a b c  + 2a b c - 2b )d e
+--R                + 
+--R                       2 3        2 2     4   2 3           3      3 2  3 2
+--R                  (- 8a c  - 20a b c  + 8b c)d e  + (28a b c  - 12b c )d e
+--R                + 
+--R                          4     2 3  4        4 5
+--R                  (- 12a c  + 8b c )d e - 2b c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                              5      2 4
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                     ROOT
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                          + 
+--R                                  3   4      2 3 3        5 2     7     5
+--R                            (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                          + 
+--R                                3 5       2 2 4        4 3      6 2  2 4
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                 2   5        3 4      5 3  3 3
+--R                            (112a b c  - 98a b c  + 20b c )d e
+--R                          + 
+--R                                  2 6        2 5      4 4  4 2
+--R                            (- 36a c  + 54a b c  - 15b c )d e
+--R                          + 
+--R                                      6     3 5  5     2 6 6
+--R                            (- 12a b c  + 6b c )d e - b c d
+--R                       /
+--R                                3 11         2 2 10          4 9       6 8
+--R                          46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                 + 
+--R                                3  3        2     2     2       2 2     3 3
+--R                   (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R              /
+--R                       5      2 4
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                3   7         2 3 6          5 5       7 4  2
+--R                         (15552a b c  - 11664a b c  + 2916a b c  - 243b c )e
+--R                       + 
+--R                                  3 8         2 2 7          4 6       6 5
+--R                         (- 31104a c  + 23328a b c  - 5832a b c  + 486b c )d e
+--R                    *
+--R                       ROOT
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     5
+--R                              (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                            + 
+--R                                  3 5       2 2 4        4 3      6 2  2 4
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                   2   5        3 4      5 3  3 3
+--R                              (112a b c  - 98a b c  + 20b c )d e
+--R                            + 
+--R                                    2 6        2 5      4 4  4 2
+--R                              (- 36a c  + 54a b c  - 15b c )d e
+--R                            + 
+--R                                        6     3 5  5     2 6 6
+--R                              (- 12a b c  + 6b c )d e - b c d
+--R                         /
+--R                                  3 11         2 2 10          4 9       6 8
+--R                            46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                          4 4       3 2 3       2 4 2        6      8  5
+--R                     (144a c  - 396a b c  + 306a b c  - 90a b c + 9b )e
+--R                   + 
+--R                          3   4        2 3 3         5 2      7     4
+--R                     (792a b c  - 1026a b c  + 387a b c  - 45b c)d e
+--R                   + 
+--R                            3 5        2 2 4         4 3      6 2  2 3
+--R                     (- 576a c  + 1512a b c  - 738a b c  + 99b c )d e
+--R                   + 
+--R                             2   5         3 4       5 3  3 2
+--R                     (- 1152a b c  + 756a b c  - 117b c )d e
+--R                   + 
+--R                          2 6         2 5      4 4  4            6      3 5  5
+--R                     (432a c  - 396a b c  + 72b c )d e + (72a b c  - 18b c )d
+--R                *
+--R                     ROOT
+--R                                       5      2 4
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                              ROOT
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                             3   4      2 3 3        5 2     7
+--R                                       (- 36a b c  + 84a b c  - 42a b c  + 6b c)
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                           3 5       2 2 4        4 3      6 2
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                          2   5        3 4      5 3  3 3
+--R                                     (112a b c  - 98a b c  + 20b c )d e
+--R                                   + 
+--R                                           2 6        2 5      4 4  4 2
+--R                                     (- 36a c  + 54a b c  - 15b c )d e
+--R                                   + 
+--R                                               6     3 5  5     2 6 6
+--R                                     (- 12a b c  + 6b c )d e - b c d
+--R                                /
+--R                                           3 11         2 2 10          4 9
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 8
+--R                                     - 729b c
+--R                          + 
+--R                                         3  3        2     2     2       2 2
+--R                            (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e
+--R                          + 
+--R                               3 3
+--R                            - c d
+--R                       /
+--R                                5      2 4
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               3   6       2 3 5        5 4  3
+--R                         (1296a b c  - 648a b c  + 81a b c )e
+--R                       + 
+--R                                 3 7         4 5      6 4    2
+--R                         (- 2592a c  + 486a b c  - 81b c )d e
+--R                       + 
+--R                               2   7          3 6       5 5  2
+--R                         (3888a b c  - 1944a b c  + 243b c )d e
+--R                       + 
+--R                                 2 8          2 7       4 6  3
+--R                         (- 2592a c  + 1296a b c  - 162b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     5
+--R                              (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                            + 
+--R                                  3 5       2 2 4        4 3      6 2  2 4
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                   2   5        3 4      5 3  3 3
+--R                              (112a b c  - 98a b c  + 20b c )d e
+--R                            + 
+--R                                    2 6        2 5      4 4  4 2
+--R                              (- 36a c  + 54a b c  - 15b c )d e
+--R                            + 
+--R                                        6     3 5  5     2 6 6
+--R                              (- 12a b c  + 6b c )d e - b c d
+--R                         /
+--R                                  3 11         2 2 10          4 9       6 8
+--R                            46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                             4 3      3 2 2      2 4        6  6
+--R                         (24a c  - 54a b c  + 24a b c - 3a b )e
+--R                       + 
+--R                             3   3     2 3 2        5      7    5
+--R                         (84a b c  - 9a b c  - 15a b c + 3b )d e
+--R                       + 
+--R                               3 4       2 2 3        4 2      6   2 4
+--R                         (- 48a c  - 108a b c  + 78a b c  - 12b c)d e
+--R                       + 
+--R                              2   4         3 3      5 2  3 3
+--R                         (168a b c  - 114a b c  + 18b c )d e
+--R                       + 
+--R                               2 5        2 4      4 3  4 2
+--R                         (- 72a c  + 66a b c  - 12b c )d e
+--R                       + 
+--R                                   5     3 4  5
+--R                         (- 12a b c  + 3b c )d e
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                     5      2 4
+--R                            (- 108a c  + 27b c )
+--R                         *
+--R                            ROOT
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                  *
+--R                                      6
+--R                                     e
+--R                                 + 
+--R                                         3   4      2 3 3        5 2     7     5
+--R                                   (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                                 + 
+--R                                       3 5       2 2 4        4 3      6 2  2 4
+--R                                   (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                 + 
+--R                                        2   5        3 4      5 3  3 3
+--R                                   (112a b c  - 98a b c  + 20b c )d e
+--R                                 + 
+--R                                         2 6        2 5      4 4  4 2
+--R                                   (- 36a c  + 54a b c  - 15b c )d e
+--R                                 + 
+--R                                             6     3 5  5     2 6 6
+--R                                   (- 12a b c  + 6b c )d e - b c d
+--R                              /
+--R                                         3 11         2 2 10          4 9
+--R                                   46656a c   - 34992a b c   + 8748a b c
+--R                                 + 
+--R                                         6 8
+--R                                   - 729b c
+--R                        + 
+--R                                     3  3        2     2     2       2 2     3 3
+--R                        (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                     /
+--R                              5      2 4
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                        4 2     3 2      2 4  7
+--R                     (4a c  - 8a b c + 2a b )e
+--R                   + 
+--R                         3   2      2 3        5    6
+--R                     (10a b c  + 10a b c - 4a b )d e
+--R                   + 
+--R                          3 3      2 2 2       4      6  2 5
+--R                     (- 4a c  - 42a b c  + 8a b c + 2b )d e
+--R                   + 
+--R                         2   3        3 2      5   3 4
+--R                     (50a b c  + 10a b c  - 10b c)d e
+--R                   + 
+--R                           2 4        2 3      4 2  4 3
+--R                     (- 20a c  - 40a b c  + 20b c )d e
+--R                   + 
+--R                             4      3 3  5 2           5      2 4  6        5 7
+--R                     (38a b c  - 20b c )d e  + (- 12a c  + 10b c )d e - 2b c d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R         2c
+--R      *
+--R         ROOT
+--R                           5      2 4
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                  ROOT
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                       + 
+--R                               3   4      2 3 3        5 2     7     5
+--R                         (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                       + 
+--R                             3 5       2 2 4        4 3      6 2  2 4
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                              2   5        3 4      5 3  3 3
+--R                         (112a b c  - 98a b c  + 20b c )d e
+--R                       + 
+--R                               2 6        2 5      4 4  4 2
+--R                         (- 36a c  + 54a b c  - 15b c )d e
+--R                       + 
+--R                                   6     3 5  5     2 6 6
+--R                         (- 12a b c  + 6b c )d e - b c d
+--R                    /
+--R                             3 11         2 2 10          4 9       6 8
+--R                       46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                             3  3        2     2     2       2 2     3 3
+--R                (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                              2   6         3 5      5 4
+--R                      (- 1296a b c  + 648a b c  - 81b c )e
+--R                    + 
+--R                            2 7          2 6       4 5
+--R                      (2592a c  - 1296a b c  + 162b c )d
+--R                 *
+--R                    ROOT
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     5
+--R                           (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                         + 
+--R                               3 5       2 2 4        4 3      6 2  2 4
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                                2   5        3 4      5 3  3 3
+--R                           (112a b c  - 98a b c  + 20b c )d e
+--R                         + 
+--R                                 2 6        2 5      4 4  4 2
+--R                           (- 36a c  + 54a b c  - 15b c )d e
+--R                         + 
+--R                                     6     3 5  5     2 6 6
+--R                           (- 12a b c  + 6b c )d e - b c d
+--R                      /
+--R                               3 11         2 2 10          4 9       6 8
+--R                         46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                        3 3      2 2 2        4      6  4
+--R                  (- 24a c  + 54a b c  - 24a b c + 3b )e
+--R                + 
+--R                         2   3        3 2     5     3
+--R                  (- 108a b c  + 63a b c  - 9b c)d e
+--R                + 
+--R                      2 4        2 3     4 2  2 2           4     3 3  3
+--R                  (72a c  - 54a b c  + 9b c )d e  + (12a b c  - 3b c )d e
+--R             *
+--R                ROOT
+--R                                  5      2 4
+--R                         (- 108a c  + 27b c )
+--R                      *
+--R                         ROOT
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                              + 
+--R                                      3   4      2 3 3        5 2     7     5
+--R                                (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                              + 
+--R                                    3 5       2 2 4        4 3      6 2  2 4
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                     2   5        3 4      5 3  3 3
+--R                                (112a b c  - 98a b c  + 20b c )d e
+--R                              + 
+--R                                      2 6        2 5      4 4  4 2
+--R                                (- 36a c  + 54a b c  - 15b c )d e
+--R                              + 
+--R                                          6     3 5  5     2 6 6
+--R                                (- 12a b c  + 6b c )d e - b c d
+--R                           /
+--R                                    3 11         2 2 10          4 9       6 8
+--R                              46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R                     3 2     2 2        4  5       2   2       3      5    4
+--R                  (4a c  - 8a b c + 2a b )e  + (14a b c  + 2a b c - 2b )d e
+--R                + 
+--R                       2 3        2 2     4   2 3           3      3 2  3 2
+--R                  (- 8a c  - 20a b c  + 8b c)d e  + (28a b c  - 12b c )d e
+--R                + 
+--R                          4     2 3  4        4 5
+--R                  (- 12a c  + 8b c )d e - 2b c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                            5      2 4
+--R                     (108a c  - 27b c )
+--R                  *
+--R                     ROOT
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                          + 
+--R                                  3   4      2 3 3        5 2     7     5
+--R                            (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                          + 
+--R                                3 5       2 2 4        4 3      6 2  2 4
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                 2   5        3 4      5 3  3 3
+--R                            (112a b c  - 98a b c  + 20b c )d e
+--R                          + 
+--R                                  2 6        2 5      4 4  4 2
+--R                            (- 36a c  + 54a b c  - 15b c )d e
+--R                          + 
+--R                                      6     3 5  5     2 6 6
+--R                            (- 12a b c  + 6b c )d e - b c d
+--R                       /
+--R                                3 11         2 2 10          4 9       6 8
+--R                          46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                 + 
+--R                                3  3        2     2     2       2 2     3 3
+--R                   (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R              /
+--R                       5      2 4
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                  3   7         2 3 6          5 5       7 4  2
+--R                         (- 15552a b c  + 11664a b c  - 2916a b c  + 243b c )e
+--R                       + 
+--R                                3 8         2 2 7          4 6       6 5
+--R                         (31104a c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                    *
+--R                       ROOT
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     5
+--R                              (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                            + 
+--R                                  3 5       2 2 4        4 3      6 2  2 4
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                   2   5        3 4      5 3  3 3
+--R                              (112a b c  - 98a b c  + 20b c )d e
+--R                            + 
+--R                                    2 6        2 5      4 4  4 2
+--R                              (- 36a c  + 54a b c  - 15b c )d e
+--R                            + 
+--R                                        6     3 5  5     2 6 6
+--R                              (- 12a b c  + 6b c )d e - b c d
+--R                         /
+--R                                  3 11         2 2 10          4 9       6 8
+--R                            46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                          4 4       3 2 3       2 4 2        6      8  5
+--R                     (144a c  - 396a b c  + 306a b c  - 90a b c + 9b )e
+--R                   + 
+--R                          3   4        2 3 3         5 2      7     4
+--R                     (792a b c  - 1026a b c  + 387a b c  - 45b c)d e
+--R                   + 
+--R                            3 5        2 2 4         4 3      6 2  2 3
+--R                     (- 576a c  + 1512a b c  - 738a b c  + 99b c )d e
+--R                   + 
+--R                             2   5         3 4       5 3  3 2
+--R                     (- 1152a b c  + 756a b c  - 117b c )d e
+--R                   + 
+--R                          2 6         2 5      4 4  4            6      3 5  5
+--R                     (432a c  - 396a b c  + 72b c )d e + (72a b c  - 18b c )d
+--R                *
+--R                     ROOT
+--R                                     5      2 4
+--R                              (108a c  - 27b c )
+--R                           *
+--R                              ROOT
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                             3   4      2 3 3        5 2     7
+--R                                       (- 36a b c  + 84a b c  - 42a b c  + 6b c)
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                           3 5       2 2 4        4 3      6 2
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                          2   5        3 4      5 3  3 3
+--R                                     (112a b c  - 98a b c  + 20b c )d e
+--R                                   + 
+--R                                           2 6        2 5      4 4  4 2
+--R                                     (- 36a c  + 54a b c  - 15b c )d e
+--R                                   + 
+--R                                               6     3 5  5     2 6 6
+--R                                     (- 12a b c  + 6b c )d e - b c d
+--R                                /
+--R                                           3 11         2 2 10          4 9
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 8
+--R                                     - 729b c
+--R                          + 
+--R                                         3  3        2     2     2       2 2
+--R                            (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e
+--R                          + 
+--R                               3 3
+--R                            - c d
+--R                       /
+--R                                5      2 4
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 3   6       2 3 5        5 4  3
+--R                         (- 1296a b c  + 648a b c  - 81a b c )e
+--R                       + 
+--R                               3 7         4 5      6 4    2
+--R                         (2592a c  - 486a b c  + 81b c )d e
+--R                       + 
+--R                                 2   7          3 6       5 5  2
+--R                         (- 3888a b c  + 1944a b c  - 243b c )d e
+--R                       + 
+--R                               2 8          2 7       4 6  3
+--R                         (2592a c  - 1296a b c  + 162b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     5
+--R                              (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                            + 
+--R                                  3 5       2 2 4        4 3      6 2  2 4
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                   2   5        3 4      5 3  3 3
+--R                              (112a b c  - 98a b c  + 20b c )d e
+--R                            + 
+--R                                    2 6        2 5      4 4  4 2
+--R                              (- 36a c  + 54a b c  - 15b c )d e
+--R                            + 
+--R                                        6     3 5  5     2 6 6
+--R                              (- 12a b c  + 6b c )d e - b c d
+--R                         /
+--R                                  3 11         2 2 10          4 9       6 8
+--R                            46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                             4 3      3 2 2      2 4        6  6
+--R                         (24a c  - 54a b c  + 24a b c - 3a b )e
+--R                       + 
+--R                             3   3     2 3 2        5      7    5
+--R                         (84a b c  - 9a b c  - 15a b c + 3b )d e
+--R                       + 
+--R                               3 4       2 2 3        4 2      6   2 4
+--R                         (- 48a c  - 108a b c  + 78a b c  - 12b c)d e
+--R                       + 
+--R                              2   4         3 3      5 2  3 3
+--R                         (168a b c  - 114a b c  + 18b c )d e
+--R                       + 
+--R                               2 5        2 4      4 3  4 2
+--R                         (- 72a c  + 66a b c  - 12b c )d e
+--R                       + 
+--R                                   5     3 4  5
+--R                         (- 12a b c  + 3b c )d e
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                   5      2 4
+--R                            (108a c  - 27b c )
+--R                         *
+--R                            ROOT
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                  *
+--R                                      6
+--R                                     e
+--R                                 + 
+--R                                         3   4      2 3 3        5 2     7     5
+--R                                   (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                                 + 
+--R                                       3 5       2 2 4        4 3      6 2  2 4
+--R                                   (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                 + 
+--R                                        2   5        3 4      5 3  3 3
+--R                                   (112a b c  - 98a b c  + 20b c )d e
+--R                                 + 
+--R                                         2 6        2 5      4 4  4 2
+--R                                   (- 36a c  + 54a b c  - 15b c )d e
+--R                                 + 
+--R                                             6     3 5  5     2 6 6
+--R                                   (- 12a b c  + 6b c )d e - b c d
+--R                              /
+--R                                         3 11         2 2 10          4 9
+--R                                   46656a c   - 34992a b c   + 8748a b c
+--R                                 + 
+--R                                         6 8
+--R                                   - 729b c
+--R                        + 
+--R                                     3  3        2     2     2       2 2     3 3
+--R                        (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                     /
+--R                              5      2 4
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                        4 2     3 2      2 4  7
+--R                     (4a c  - 8a b c + 2a b )e
+--R                   + 
+--R                         3   2      2 3        5    6
+--R                     (10a b c  + 10a b c - 4a b )d e
+--R                   + 
+--R                          3 3      2 2 2       4      6  2 5
+--R                     (- 4a c  - 42a b c  + 8a b c + 2b )d e
+--R                   + 
+--R                         2   3        3 2      5   3 4
+--R                     (50a b c  + 10a b c  - 10b c)d e
+--R                   + 
+--R                           2 4        2 3      4 2  4 3
+--R                     (- 20a c  - 40a b c  + 20b c )d e
+--R                   + 
+--R                             4      3 3  5 2           5      2 4  6        5 7
+--R                     (38a b c  - 20b c )d e  + (- 12a c  + 10b c )d e - 2b c d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R            +-+
+--R         2c\|3
+--R      *
+--R         ROOT
+--R                         5      2 4
+--R                  (108a c  - 27b c )
+--R               *
+--R                  ROOT
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                       + 
+--R                               3   4      2 3 3        5 2     7     5
+--R                         (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                       + 
+--R                             3 5       2 2 4        4 3      6 2  2 4
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                              2   5        3 4      5 3  3 3
+--R                         (112a b c  - 98a b c  + 20b c )d e
+--R                       + 
+--R                               2 6        2 5      4 4  4 2
+--R                         (- 36a c  + 54a b c  - 15b c )d e
+--R                       + 
+--R                                   6     3 5  5     2 6 6
+--R                         (- 12a b c  + 6b c )d e - b c d
+--R                    /
+--R                             3 11         2 2 10          4 9       6 8
+--R                       46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                             3  3        2     2     2       2 2     3 3
+--R                (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                            2   6         3 5      5 4
+--R                      (1296a b c  - 648a b c  + 81b c )e
+--R                    + 
+--R                              2 7          2 6       4 5
+--R                      (- 2592a c  + 1296a b c  - 162b c )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     5
+--R                           (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                         + 
+--R                               3 5       2 2 4        4 3      6 2  2 4
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                                2   5        3 4      5 3  3 3
+--R                           (112a b c  - 98a b c  + 20b c )d e
+--R                         + 
+--R                                 2 6        2 5      4 4  4 2
+--R                           (- 36a c  + 54a b c  - 15b c )d e
+--R                         + 
+--R                                     6     3 5  5     2 6 6
+--R                           (- 12a b c  + 6b c )d e - b c d
+--R                      /
+--R                               3 11         2 2 10          4 9       6 8
+--R                         46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                            3 3      2 2 2        4      6  4
+--R                      (- 24a c  + 54a b c  - 24a b c + 3b )e
+--R                    + 
+--R                             2   3        3 2     5     3
+--R                      (- 108a b c  + 63a b c  - 9b c)d e
+--R                    + 
+--R                          2 4        2 3     4 2  2 2           4     3 3  3
+--R                      (72a c  - 54a b c  + 9b c )d e  + (12a b c  - 3b c )d e
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                                5      2 4
+--R                         (108a c  - 27b c )
+--R                      *
+--R                         ROOT
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                              + 
+--R                                      3   4      2 3 3        5 2     7     5
+--R                                (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                              + 
+--R                                    3 5       2 2 4        4 3      6 2  2 4
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                     2   5        3 4      5 3  3 3
+--R                                (112a b c  - 98a b c  + 20b c )d e
+--R                              + 
+--R                                      2 6        2 5      4 4  4 2
+--R                                (- 36a c  + 54a b c  - 15b c )d e
+--R                              + 
+--R                                          6     3 5  5     2 6 6
+--R                                (- 12a b c  + 6b c )d e - b c d
+--R                           /
+--R                                    3 11         2 2 10          4 9       6 8
+--R                              46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                              2   6         3 5      5 4
+--R                        (1296a b c  - 648a b c  + 81b c )e
+--R                      + 
+--R                                2 7          2 6       4 5
+--R                        (- 2592a c  + 1296a b c  - 162b c )d
+--R                   *
+--R                      ROOT
+--R                                  4 4      3 2 3      2 4 2       6     8  6
+--R                             (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                           + 
+--R                                   3   4      2 3 3        5 2     7     5
+--R                             (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                           + 
+--R                                 3 5       2 2 4        4 3      6 2  2 4
+--R                             (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                           + 
+--R                                  2   5        3 4      5 3  3 3
+--R                             (112a b c  - 98a b c  + 20b c )d e
+--R                           + 
+--R                                   2 6        2 5      4 4  4 2
+--R                             (- 36a c  + 54a b c  - 15b c )d e
+--R                           + 
+--R                                       6     3 5  5     2 6 6
+--R                             (- 12a b c  + 6b c )d e - b c d
+--R                        /
+--R                                 3 11         2 2 10          4 9       6 8
+--R                           46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                  + 
+--R                          3 3      2 2 2        4      6  4
+--R                    (- 24a c  + 54a b c  - 24a b c + 3b )e
+--R                  + 
+--R                           2   3        3 2     5     3
+--R                    (- 108a b c  + 63a b c  - 9b c)d e
+--R                  + 
+--R                        2 4        2 3     4 2  2 2           4     3 3  3
+--R                    (72a c  - 54a b c  + 9b c )d e  + (12a b c  - 3b c )d e
+--R               *
+--R                  ROOT
+--R                                  5      2 4
+--R                           (108a c  - 27b c )
+--R                        *
+--R                           ROOT
+--R                                            4 4      3 2 3      2 4 2       6
+--R                                        - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                      + 
+--R                                           8
+--R                                        - b
+--R                                 *
+--R                                     6
+--R                                    e
+--R                                + 
+--R                                        3   4      2 3 3        5 2     7     5
+--R                                  (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                                + 
+--R                                      3 5       2 2 4        4 3      6 2  2 4
+--R                                  (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                + 
+--R                                       2   5        3 4      5 3  3 3
+--R                                  (112a b c  - 98a b c  + 20b c )d e
+--R                                + 
+--R                                        2 6        2 5      4 4  4 2
+--R                                  (- 36a c  + 54a b c  - 15b c )d e
+--R                                + 
+--R                                            6     3 5  5     2 6 6
+--R                                  (- 12a b c  + 6b c )d e - b c d
+--R                             /
+--R                                      3 11         2 2 10          4 9       6 8
+--R                                46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                    /
+--R                             5      2 4
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                         3 2      2 2        4  5
+--R                    (- 8a c  + 16a b c - 4a b )e
+--R                  + 
+--R                          2   2       3      5    4
+--R                    (- 28a b c  - 4a b c + 4b )d e
+--R                  + 
+--R                        2 3        2 2      4   2 3             3      3 2  3 2
+--R                    (16a c  + 40a b c  - 16b c)d e  + (- 56a b c  + 24b c )d e
+--R                  + 
+--R                          4      2 3  4        4 5
+--R                    (24a c  - 16b c )d e + 4b c d
+--R               *
+--R                  x
+--R     + 
+--R            +-+
+--R         2c\|3
+--R      *
+--R         ROOT
+--R                           5      2 4
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                  ROOT
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                       + 
+--R                               3   4      2 3 3        5 2     7     5
+--R                         (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                       + 
+--R                             3 5       2 2 4        4 3      6 2  2 4
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                              2   5        3 4      5 3  3 3
+--R                         (112a b c  - 98a b c  + 20b c )d e
+--R                       + 
+--R                               2 6        2 5      4 4  4 2
+--R                         (- 36a c  + 54a b c  - 15b c )d e
+--R                       + 
+--R                                   6     3 5  5     2 6 6
+--R                         (- 12a b c  + 6b c )d e - b c d
+--R                    /
+--R                             3 11         2 2 10          4 9       6 8
+--R                       46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                             3  3        2     2     2       2 2     3 3
+--R                (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                            2   6         3 5      5 4
+--R                      (1296a b c  - 648a b c  + 81b c )e
+--R                    + 
+--R                              2 7          2 6       4 5
+--R                      (- 2592a c  + 1296a b c  - 162b c )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     5
+--R                           (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                         + 
+--R                               3 5       2 2 4        4 3      6 2  2 4
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                                2   5        3 4      5 3  3 3
+--R                           (112a b c  - 98a b c  + 20b c )d e
+--R                         + 
+--R                                 2 6        2 5      4 4  4 2
+--R                           (- 36a c  + 54a b c  - 15b c )d e
+--R                         + 
+--R                                     6     3 5  5     2 6 6
+--R                           (- 12a b c  + 6b c )d e - b c d
+--R                      /
+--R                               3 11         2 2 10          4 9       6 8
+--R                         46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                          3 3      2 2 2        4      6  4
+--R                      (24a c  - 54a b c  + 24a b c - 3b )e
+--R                    + 
+--R                           2   3        3 2     5     3
+--R                      (108a b c  - 63a b c  + 9b c)d e
+--R                    + 
+--R                          2 4        2 3     4 2  2 2             4     3 3  3
+--R                    (- 72a c  + 54a b c  - 9b c )d e  + (- 12a b c  + 3b c )d e
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                                  5      2 4
+--R                         (- 108a c  + 27b c )
+--R                      *
+--R                         ROOT
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                              + 
+--R                                      3   4      2 3 3        5 2     7     5
+--R                                (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                              + 
+--R                                    3 5       2 2 4        4 3      6 2  2 4
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                     2   5        3 4      5 3  3 3
+--R                                (112a b c  - 98a b c  + 20b c )d e
+--R                              + 
+--R                                      2 6        2 5      4 4  4 2
+--R                                (- 36a c  + 54a b c  - 15b c )d e
+--R                              + 
+--R                                          6     3 5  5     2 6 6
+--R                                (- 12a b c  + 6b c )d e - b c d
+--R                           /
+--R                                    3 11         2 2 10          4 9       6 8
+--R                              46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                              2   6         3 5      5 4
+--R                        (1296a b c  - 648a b c  + 81b c )e
+--R                      + 
+--R                                2 7          2 6       4 5
+--R                        (- 2592a c  + 1296a b c  - 162b c )d
+--R                   *
+--R                      ROOT
+--R                                  4 4      3 2 3      2 4 2       6     8  6
+--R                             (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                           + 
+--R                                   3   4      2 3 3        5 2     7     5
+--R                             (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                           + 
+--R                                 3 5       2 2 4        4 3      6 2  2 4
+--R                             (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                           + 
+--R                                  2   5        3 4      5 3  3 3
+--R                             (112a b c  - 98a b c  + 20b c )d e
+--R                           + 
+--R                                   2 6        2 5      4 4  4 2
+--R                             (- 36a c  + 54a b c  - 15b c )d e
+--R                           + 
+--R                                       6     3 5  5     2 6 6
+--R                             (- 12a b c  + 6b c )d e - b c d
+--R                        /
+--R                                 3 11         2 2 10          4 9       6 8
+--R                           46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                  + 
+--R                        3 3      2 2 2        4      6  4
+--R                    (24a c  - 54a b c  + 24a b c - 3b )e
+--R                  + 
+--R                         2   3        3 2     5     3
+--R                    (108a b c  - 63a b c  + 9b c)d e
+--R                  + 
+--R                          2 4        2 3     4 2  2 2             4     3 3  3
+--R                    (- 72a c  + 54a b c  - 9b c )d e  + (- 12a b c  + 3b c )d e
+--R               *
+--R                  ROOT
+--R                                    5      2 4
+--R                           (- 108a c  + 27b c )
+--R                        *
+--R                           ROOT
+--R                                            4 4      3 2 3      2 4 2       6
+--R                                        - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                      + 
+--R                                           8
+--R                                        - b
+--R                                 *
+--R                                     6
+--R                                    e
+--R                                + 
+--R                                        3   4      2 3 3        5 2     7     5
+--R                                  (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                                + 
+--R                                      3 5       2 2 4        4 3      6 2  2 4
+--R                                  (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                + 
+--R                                       2   5        3 4      5 3  3 3
+--R                                  (112a b c  - 98a b c  + 20b c )d e
+--R                                + 
+--R                                        2 6        2 5      4 4  4 2
+--R                                  (- 36a c  + 54a b c  - 15b c )d e
+--R                                + 
+--R                                            6     3 5  5     2 6 6
+--R                                  (- 12a b c  + 6b c )d e - b c d
+--R                             /
+--R                                      3 11         2 2 10          4 9       6 8
+--R                                46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                    /
+--R                             5      2 4
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                       3 2      2 2        4  5       2   2       3      5    4
+--R                    (8a c  - 16a b c + 4a b )e  + (28a b c  + 4a b c - 4b )d e
+--R                  + 
+--R                          2 3        2 2      4   2 3           3      3 2  3 2
+--R                    (- 16a c  - 40a b c  + 16b c)d e  + (56a b c  - 24b c )d e
+--R                  + 
+--R                            4      2 3  4        4 5
+--R                    (- 24a c  + 16b c )d e - 4b c d
+--R               *
+--R                  x
+--R     + 
+--R       2e x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            +-----------+
+--R                        +-+ |          2              2            +-+
+--R         ((- b e + c d)\|3 \|- 4a c + b   + ((2a c - b )e + b c d)\|3 )
+--R      *
+--R          +--------------------+2
+--R          |   +-----------+
+--R         3|   |          2
+--R         \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                            +-----------+
+--R                        +-+ |          2                 2             +-+
+--R         ((2b e - 2c d)\|3 \|- 4a c + b   + ((- 4a c + 2b )e - 2b c d)\|3 )
+--R      *
+--R          +--------------------+2     +------------------+
+--R          |   +-----------+           | +-----------+
+--R         3|   |          2           3| |          2          3+-+3+-+
+--R         \|- \|- 4a c + b   + b  log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                      +--------------------+2
+--R                    +-----------+     |   +-----------+
+--R           3+-+ +-+ |          2 3+-+3|   |          2
+--R         6c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         5      2 4
+--R                  (108a c  - 27b c )
+--R               *
+--R                  ROOT
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                       + 
+--R                               3   4      2 3 3        5 2     7     5
+--R                         (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                       + 
+--R                             3 5       2 2 4        4 3      6 2  2 4
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                              2   5        3 4      5 3  3 3
+--R                         (112a b c  - 98a b c  + 20b c )d e
+--R                       + 
+--R                               2 6        2 5      4 4  4 2
+--R                         (- 36a c  + 54a b c  - 15b c )d e
+--R                       + 
+--R                                   6     3 5  5     2 6 6
+--R                         (- 12a b c  + 6b c )d e - b c d
+--R                    /
+--R                             3 11         2 2 10          4 9       6 8
+--R                       46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                             3  3        2     2     2       2 2     3 3
+--R                (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            2   6         3 5      5 4
+--R                      (1296a b c  - 648a b c  + 81b c )e
+--R                    + 
+--R                              2 7          2 6       4 5
+--R                      (- 2592a c  + 1296a b c  - 162b c )d
+--R                 *
+--R                    ROOT
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     5
+--R                           (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                         + 
+--R                               3 5       2 2 4        4 3      6 2  2 4
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                                2   5        3 4      5 3  3 3
+--R                           (112a b c  - 98a b c  + 20b c )d e
+--R                         + 
+--R                                 2 6        2 5      4 4  4 2
+--R                           (- 36a c  + 54a b c  - 15b c )d e
+--R                         + 
+--R                                     6     3 5  5     2 6 6
+--R                           (- 12a b c  + 6b c )d e - b c d
+--R                      /
+--R                               3 11         2 2 10          4 9       6 8
+--R                         46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                        3 3      2 2 2        4      6  4
+--R                  (- 24a c  + 54a b c  - 24a b c + 3b )e
+--R                + 
+--R                         2   3        3 2     5     3
+--R                  (- 108a b c  + 63a b c  - 9b c)d e
+--R                + 
+--R                      2 4        2 3     4 2  2 2           4     3 3  3
+--R                  (72a c  - 54a b c  + 9b c )d e  + (12a b c  - 3b c )d e
+--R             *
+--R                ROOT
+--R                                5      2 4
+--R                         (108a c  - 27b c )
+--R                      *
+--R                         ROOT
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                              + 
+--R                                      3   4      2 3 3        5 2     7     5
+--R                                (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                              + 
+--R                                    3 5       2 2 4        4 3      6 2  2 4
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                     2   5        3 4      5 3  3 3
+--R                                (112a b c  - 98a b c  + 20b c )d e
+--R                              + 
+--R                                      2 6        2 5      4 4  4 2
+--R                                (- 36a c  + 54a b c  - 15b c )d e
+--R                              + 
+--R                                          6     3 5  5     2 6 6
+--R                                (- 12a b c  + 6b c )d e - b c d
+--R                           /
+--R                                    3 11         2 2 10          4 9       6 8
+--R                              46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R                     3 2     2 2        4  5       2   2       3      5    4
+--R                  (4a c  - 8a b c + 2a b )e  + (14a b c  + 2a b c - 2b )d e
+--R                + 
+--R                       2 3        2 2     4   2 3           3      3 2  3 2
+--R                  (- 8a c  - 20a b c  + 8b c)d e  + (28a b c  - 12b c )d e
+--R                + 
+--R                          4     2 3  4        4 5
+--R                  (- 12a c  + 8b c )d e - 2b c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                         +--------------------+2
+--R                       +-----------+     |   +-----------+
+--R              3+-+ +-+ |          2 3+-+3|   |          2
+--R            3c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                              5      2 4
+--R                     (- 108a c  + 27b c )
+--R                  *
+--R                     ROOT
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                          + 
+--R                                  3   4      2 3 3        5 2     7     5
+--R                            (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                          + 
+--R                                3 5       2 2 4        4 3      6 2  2 4
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                 2   5        3 4      5 3  3 3
+--R                            (112a b c  - 98a b c  + 20b c )d e
+--R                          + 
+--R                                  2 6        2 5      4 4  4 2
+--R                            (- 36a c  + 54a b c  - 15b c )d e
+--R                          + 
+--R                                      6     3 5  5     2 6 6
+--R                            (- 12a b c  + 6b c )d e - b c d
+--R                       /
+--R                                3 11         2 2 10          4 9       6 8
+--R                          46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                 + 
+--R                                3  3        2     2     2       2 2     3 3
+--R                   (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R              /
+--R                       5      2 4
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+2
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                3   7         2 3 6          5 5       7 4  2
+--R                         (15552a b c  - 11664a b c  + 2916a b c  - 243b c )e
+--R                       + 
+--R                                  3 8         2 2 7          4 6       6 5
+--R                         (- 31104a c  + 23328a b c  - 5832a b c  + 486b c )d e
+--R                    *
+--R                       ROOT
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     5
+--R                              (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                            + 
+--R                                  3 5       2 2 4        4 3      6 2  2 4
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                   2   5        3 4      5 3  3 3
+--R                              (112a b c  - 98a b c  + 20b c )d e
+--R                            + 
+--R                                    2 6        2 5      4 4  4 2
+--R                              (- 36a c  + 54a b c  - 15b c )d e
+--R                            + 
+--R                                        6     3 5  5     2 6 6
+--R                              (- 12a b c  + 6b c )d e - b c d
+--R                         /
+--R                                  3 11         2 2 10          4 9       6 8
+--R                            46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                          4 4       3 2 3       2 4 2        6      8  5
+--R                     (144a c  - 396a b c  + 306a b c  - 90a b c + 9b )e
+--R                   + 
+--R                          3   4        2 3 3         5 2      7     4
+--R                     (792a b c  - 1026a b c  + 387a b c  - 45b c)d e
+--R                   + 
+--R                            3 5        2 2 4         4 3      6 2  2 3
+--R                     (- 576a c  + 1512a b c  - 738a b c  + 99b c )d e
+--R                   + 
+--R                             2   5         3 4       5 3  3 2
+--R                     (- 1152a b c  + 756a b c  - 117b c )d e
+--R                   + 
+--R                          2 6         2 5      4 4  4            6      3 5  5
+--R                     (432a c  - 396a b c  + 72b c )d e + (72a b c  - 18b c )d
+--R                *
+--R                     ROOT
+--R                                       5      2 4
+--R                              (- 108a c  + 27b c )
+--R                           *
+--R                              ROOT
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                             3   4      2 3 3        5 2     7
+--R                                       (- 36a b c  + 84a b c  - 42a b c  + 6b c)
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                           3 5       2 2 4        4 3      6 2
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                          2   5        3 4      5 3  3 3
+--R                                     (112a b c  - 98a b c  + 20b c )d e
+--R                                   + 
+--R                                           2 6        2 5      4 4  4 2
+--R                                     (- 36a c  + 54a b c  - 15b c )d e
+--R                                   + 
+--R                                               6     3 5  5     2 6 6
+--R                                     (- 12a b c  + 6b c )d e - b c d
+--R                                /
+--R                                           3 11         2 2 10          4 9
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 8
+--R                                     - 729b c
+--R                          + 
+--R                                         3  3        2     2     2       2 2
+--R                            (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e
+--R                          + 
+--R                               3 3
+--R                            - c d
+--R                       /
+--R                                5      2 4
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               3   6       2 3 5        5 4  3
+--R                         (1296a b c  - 648a b c  + 81a b c )e
+--R                       + 
+--R                                 3 7         4 5      6 4    2
+--R                         (- 2592a c  + 486a b c  - 81b c )d e
+--R                       + 
+--R                               2   7          3 6       5 5  2
+--R                         (3888a b c  - 1944a b c  + 243b c )d e
+--R                       + 
+--R                                 2 8          2 7       4 6  3
+--R                         (- 2592a c  + 1296a b c  - 162b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     5
+--R                              (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                            + 
+--R                                  3 5       2 2 4        4 3      6 2  2 4
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                   2   5        3 4      5 3  3 3
+--R                              (112a b c  - 98a b c  + 20b c )d e
+--R                            + 
+--R                                    2 6        2 5      4 4  4 2
+--R                              (- 36a c  + 54a b c  - 15b c )d e
+--R                            + 
+--R                                        6     3 5  5     2 6 6
+--R                              (- 12a b c  + 6b c )d e - b c d
+--R                         /
+--R                                  3 11         2 2 10          4 9       6 8
+--R                            46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                             4 3      3 2 2      2 4        6  6
+--R                         (24a c  - 54a b c  + 24a b c - 3a b )e
+--R                       + 
+--R                             3   3     2 3 2        5      7    5
+--R                         (84a b c  - 9a b c  - 15a b c + 3b )d e
+--R                       + 
+--R                               3 4       2 2 3        4 2      6   2 4
+--R                         (- 48a c  - 108a b c  + 78a b c  - 12b c)d e
+--R                       + 
+--R                              2   4         3 3      5 2  3 3
+--R                         (168a b c  - 114a b c  + 18b c )d e
+--R                       + 
+--R                               2 5        2 4      4 3  4 2
+--R                         (- 72a c  + 66a b c  - 12b c )d e
+--R                       + 
+--R                                   5     3 4  5
+--R                         (- 12a b c  + 3b c )d e
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                     5      2 4
+--R                            (- 108a c  + 27b c )
+--R                         *
+--R                            ROOT
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                  *
+--R                                      6
+--R                                     e
+--R                                 + 
+--R                                         3   4      2 3 3        5 2     7     5
+--R                                   (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                                 + 
+--R                                       3 5       2 2 4        4 3      6 2  2 4
+--R                                   (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                 + 
+--R                                        2   5        3 4      5 3  3 3
+--R                                   (112a b c  - 98a b c  + 20b c )d e
+--R                                 + 
+--R                                         2 6        2 5      4 4  4 2
+--R                                   (- 36a c  + 54a b c  - 15b c )d e
+--R                                 + 
+--R                                             6     3 5  5     2 6 6
+--R                                   (- 12a b c  + 6b c )d e - b c d
+--R                              /
+--R                                         3 11         2 2 10          4 9
+--R                                   46656a c   - 34992a b c   + 8748a b c
+--R                                 + 
+--R                                         6 8
+--R                                   - 729b c
+--R                        + 
+--R                                     3  3        2     2     2       2 2     3 3
+--R                        (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                     /
+--R                              5      2 4
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                        4 2     3 2      2 4  7
+--R                     (4a c  - 8a b c + 2a b )e
+--R                   + 
+--R                         3   2      2 3        5    6
+--R                     (10a b c  + 10a b c - 4a b )d e
+--R                   + 
+--R                          3 3      2 2 2       4      6  2 5
+--R                     (- 4a c  - 42a b c  + 8a b c + 2b )d e
+--R                   + 
+--R                         2   3        3 2      5   3 4
+--R                     (50a b c  + 10a b c  - 10b c)d e
+--R                   + 
+--R                           2 4        2 3      4 2  4 3
+--R                     (- 20a c  - 40a b c  + 20b c )d e
+--R                   + 
+--R                             4      3 3  5 2           5      2 4  6        5 7
+--R                     (38a b c  - 20b c )d e  + (- 12a c  + 10b c )d e - 2b c d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                            +-----------+
+--R                        +-+ |          2                2            +-+
+--R         ((- b e + c d)\|3 \|- 4a c + b   + ((- 2a c + b )e - b c d)\|3 )
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                            +-----------+
+--R                        +-+ |          2               2             +-+
+--R         ((2b e - 2c d)\|3 \|- 4a c + b   + ((4a c - 2b )e + 2b c d)\|3 )
+--R      *
+--R          +------------------+2     +--------------------+
+--R          | +-----------+           |   +-----------+
+--R         3| |          2           3|   |          2          3+-+3+-+
+--R         \|\|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                      +--------------------+2
+--R                    +-----------+     |   +-----------+
+--R           3+-+ +-+ |          2 3+-+3|   |          2
+--R         6c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           5      2 4
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                  ROOT
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                       + 
+--R                               3   4      2 3 3        5 2     7     5
+--R                         (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                       + 
+--R                             3 5       2 2 4        4 3      6 2  2 4
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                              2   5        3 4      5 3  3 3
+--R                         (112a b c  - 98a b c  + 20b c )d e
+--R                       + 
+--R                               2 6        2 5      4 4  4 2
+--R                         (- 36a c  + 54a b c  - 15b c )d e
+--R                       + 
+--R                                   6     3 5  5     2 6 6
+--R                         (- 12a b c  + 6b c )d e - b c d
+--R                    /
+--R                             3 11         2 2 10          4 9       6 8
+--R                       46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                             3  3        2     2     2       2 2     3 3
+--R                (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              2   6         3 5      5 4
+--R                      (- 1296a b c  + 648a b c  - 81b c )e
+--R                    + 
+--R                            2 7          2 6       4 5
+--R                      (2592a c  - 1296a b c  + 162b c )d
+--R                 *
+--R                    ROOT
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     5
+--R                           (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                         + 
+--R                               3 5       2 2 4        4 3      6 2  2 4
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                                2   5        3 4      5 3  3 3
+--R                           (112a b c  - 98a b c  + 20b c )d e
+--R                         + 
+--R                                 2 6        2 5      4 4  4 2
+--R                           (- 36a c  + 54a b c  - 15b c )d e
+--R                         + 
+--R                                     6     3 5  5     2 6 6
+--R                           (- 12a b c  + 6b c )d e - b c d
+--R                      /
+--R                               3 11         2 2 10          4 9       6 8
+--R                         46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                        3 3      2 2 2        4      6  4
+--R                  (- 24a c  + 54a b c  - 24a b c + 3b )e
+--R                + 
+--R                         2   3        3 2     5     3
+--R                  (- 108a b c  + 63a b c  - 9b c)d e
+--R                + 
+--R                      2 4        2 3     4 2  2 2           4     3 3  3
+--R                  (72a c  - 54a b c  + 9b c )d e  + (12a b c  - 3b c )d e
+--R             *
+--R                ROOT
+--R                                  5      2 4
+--R                         (- 108a c  + 27b c )
+--R                      *
+--R                         ROOT
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                              + 
+--R                                      3   4      2 3 3        5 2     7     5
+--R                                (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                              + 
+--R                                    3 5       2 2 4        4 3      6 2  2 4
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                     2   5        3 4      5 3  3 3
+--R                                (112a b c  - 98a b c  + 20b c )d e
+--R                              + 
+--R                                      2 6        2 5      4 4  4 2
+--R                                (- 36a c  + 54a b c  - 15b c )d e
+--R                              + 
+--R                                          6     3 5  5     2 6 6
+--R                                (- 12a b c  + 6b c )d e - b c d
+--R                           /
+--R                                    3 11         2 2 10          4 9       6 8
+--R                              46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R            + 
+--R                     3 2     2 2        4  5       2   2       3      5    4
+--R                  (4a c  - 8a b c + 2a b )e  + (14a b c  + 2a b c - 2b )d e
+--R                + 
+--R                       2 3        2 2     4   2 3           3      3 2  3 2
+--R                  (- 8a c  - 20a b c  + 8b c)d e  + (28a b c  - 12b c )d e
+--R                + 
+--R                          4     2 3  4        4 5
+--R                  (- 12a c  + 8b c )d e - 2b c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                         +--------------------+2
+--R                       +-----------+     |   +-----------+
+--R              3+-+ +-+ |          2 3+-+3|   |          2
+--R            3c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            5      2 4
+--R                     (108a c  - 27b c )
+--R                  *
+--R                     ROOT
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                          + 
+--R                                  3   4      2 3 3        5 2     7     5
+--R                            (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                          + 
+--R                                3 5       2 2 4        4 3      6 2  2 4
+--R                            (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                          + 
+--R                                 2   5        3 4      5 3  3 3
+--R                            (112a b c  - 98a b c  + 20b c )d e
+--R                          + 
+--R                                  2 6        2 5      4 4  4 2
+--R                            (- 36a c  + 54a b c  - 15b c )d e
+--R                          + 
+--R                                      6     3 5  5     2 6 6
+--R                            (- 12a b c  + 6b c )d e - b c d
+--R                       /
+--R                                3 11         2 2 10          4 9       6 8
+--R                          46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                 + 
+--R                                3  3        2     2     2       2 2     3 3
+--R                   (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R              /
+--R                       5      2 4
+--R                 216a c  - 54b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+2
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                  3   7         2 3 6          5 5       7 4  2
+--R                         (- 15552a b c  + 11664a b c  - 2916a b c  + 243b c )e
+--R                       + 
+--R                                3 8         2 2 7          4 6       6 5
+--R                         (31104a c  - 23328a b c  + 5832a b c  - 486b c )d e
+--R                    *
+--R                       ROOT
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     5
+--R                              (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                            + 
+--R                                  3 5       2 2 4        4 3      6 2  2 4
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                   2   5        3 4      5 3  3 3
+--R                              (112a b c  - 98a b c  + 20b c )d e
+--R                            + 
+--R                                    2 6        2 5      4 4  4 2
+--R                              (- 36a c  + 54a b c  - 15b c )d e
+--R                            + 
+--R                                        6     3 5  5     2 6 6
+--R                              (- 12a b c  + 6b c )d e - b c d
+--R                         /
+--R                                  3 11         2 2 10          4 9       6 8
+--R                            46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                          4 4       3 2 3       2 4 2        6      8  5
+--R                     (144a c  - 396a b c  + 306a b c  - 90a b c + 9b )e
+--R                   + 
+--R                          3   4        2 3 3         5 2      7     4
+--R                     (792a b c  - 1026a b c  + 387a b c  - 45b c)d e
+--R                   + 
+--R                            3 5        2 2 4         4 3      6 2  2 3
+--R                     (- 576a c  + 1512a b c  - 738a b c  + 99b c )d e
+--R                   + 
+--R                             2   5         3 4       5 3  3 2
+--R                     (- 1152a b c  + 756a b c  - 117b c )d e
+--R                   + 
+--R                          2 6         2 5      4 4  4            6      3 5  5
+--R                     (432a c  - 396a b c  + 72b c )d e + (72a b c  - 18b c )d
+--R                *
+--R                     ROOT
+--R                                     5      2 4
+--R                              (108a c  - 27b c )
+--R                           *
+--R                              ROOT
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       e
+--R                                   + 
+--R                                             3   4      2 3 3        5 2     7
+--R                                       (- 36a b c  + 84a b c  - 42a b c  + 6b c)
+--R                                    *
+--R                                          5
+--R                                       d e
+--R                                   + 
+--R                                           3 5       2 2 4        4 3      6 2
+--R                                       (24a c  - 141a b c  + 90a b c  - 15b c )
+--R                                    *
+--R                                        2 4
+--R                                       d e
+--R                                   + 
+--R                                          2   5        3 4      5 3  3 3
+--R                                     (112a b c  - 98a b c  + 20b c )d e
+--R                                   + 
+--R                                           2 6        2 5      4 4  4 2
+--R                                     (- 36a c  + 54a b c  - 15b c )d e
+--R                                   + 
+--R                                               6     3 5  5     2 6 6
+--R                                     (- 12a b c  + 6b c )d e - b c d
+--R                                /
+--R                                           3 11         2 2 10          4 9
+--R                                     46656a c   - 34992a b c   + 8748a b c
+--R                                   + 
+--R                                           6 8
+--R                                     - 729b c
+--R                          + 
+--R                                         3  3        2     2     2       2 2
+--R                            (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e
+--R                          + 
+--R                               3 3
+--R                            - c d
+--R                       /
+--R                                5      2 4
+--R                          216a c  - 54b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 3   6       2 3 5        5 4  3
+--R                         (- 1296a b c  + 648a b c  - 81a b c )e
+--R                       + 
+--R                               3 7         4 5      6 4    2
+--R                         (2592a c  - 486a b c  + 81b c )d e
+--R                       + 
+--R                                 2   7          3 6       5 5  2
+--R                         (- 3888a b c  + 1944a b c  - 243b c )d e
+--R                       + 
+--R                               2 8          2 7       4 6  3
+--R                         (2592a c  - 1296a b c  + 162b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     5
+--R                              (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                            + 
+--R                                  3 5       2 2 4        4 3      6 2  2 4
+--R                              (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                            + 
+--R                                   2   5        3 4      5 3  3 3
+--R                              (112a b c  - 98a b c  + 20b c )d e
+--R                            + 
+--R                                    2 6        2 5      4 4  4 2
+--R                              (- 36a c  + 54a b c  - 15b c )d e
+--R                            + 
+--R                                        6     3 5  5     2 6 6
+--R                              (- 12a b c  + 6b c )d e - b c d
+--R                         /
+--R                                  3 11         2 2 10          4 9       6 8
+--R                            46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                   + 
+--R                             4 3      3 2 2      2 4        6  6
+--R                         (24a c  - 54a b c  + 24a b c - 3a b )e
+--R                       + 
+--R                             3   3     2 3 2        5      7    5
+--R                         (84a b c  - 9a b c  - 15a b c + 3b )d e
+--R                       + 
+--R                               3 4       2 2 3        4 2      6   2 4
+--R                         (- 48a c  - 108a b c  + 78a b c  - 12b c)d e
+--R                       + 
+--R                              2   4         3 3      5 2  3 3
+--R                         (168a b c  - 114a b c  + 18b c )d e
+--R                       + 
+--R                               2 5        2 4      4 3  4 2
+--R                         (- 72a c  + 66a b c  - 12b c )d e
+--R                       + 
+--R                                   5     3 4  5
+--R                         (- 12a b c  + 3b c )d e
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                   5      2 4
+--R                            (108a c  - 27b c )
+--R                         *
+--R                            ROOT
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                  *
+--R                                      6
+--R                                     e
+--R                                 + 
+--R                                         3   4      2 3 3        5 2     7     5
+--R                                   (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                                 + 
+--R                                       3 5       2 2 4        4 3      6 2  2 4
+--R                                   (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                 + 
+--R                                        2   5        3 4      5 3  3 3
+--R                                   (112a b c  - 98a b c  + 20b c )d e
+--R                                 + 
+--R                                         2 6        2 5      4 4  4 2
+--R                                   (- 36a c  + 54a b c  - 15b c )d e
+--R                                 + 
+--R                                             6     3 5  5     2 6 6
+--R                                   (- 12a b c  + 6b c )d e - b c d
+--R                              /
+--R                                         3 11         2 2 10          4 9
+--R                                   46656a c   - 34992a b c   + 8748a b c
+--R                                 + 
+--R                                         6 8
+--R                                   - 729b c
+--R                        + 
+--R                                     3  3        2     2     2       2 2     3 3
+--R                        (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                     /
+--R                              5      2 4
+--R                        216a c  - 54b c
+--R                  ,
+--R                      3
+--R               + 
+--R                        4 2     3 2      2 4  7
+--R                     (4a c  - 8a b c + 2a b )e
+--R                   + 
+--R                         3   2      2 3        5    6
+--R                     (10a b c  + 10a b c - 4a b )d e
+--R                   + 
+--R                          3 3      2 2 2       4      6  2 5
+--R                     (- 4a c  - 42a b c  + 8a b c + 2b )d e
+--R                   + 
+--R                         2   3        3 2      5   3 4
+--R                     (50a b c  + 10a b c  - 10b c)d e
+--R                   + 
+--R                           2 4        2 3      4 2  4 3
+--R                     (- 20a c  - 40a b c  + 20b c )d e
+--R                   + 
+--R                             4      3 3  5 2           5      2 4  6        5 7
+--R                     (38a b c  - 20b c )d e  + (- 12a c  + 10b c )d e - 2b c d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                                   +--------------------+2
+--R                 +-----------+     |   +-----------+
+--R            3+-+ |          2 3+-+3|   |          2
+--R         18c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         5      2 4
+--R                  (108a c  - 27b c )
+--R               *
+--R                  ROOT
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                       + 
+--R                               3   4      2 3 3        5 2     7     5
+--R                         (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                       + 
+--R                             3 5       2 2 4        4 3      6 2  2 4
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                              2   5        3 4      5 3  3 3
+--R                         (112a b c  - 98a b c  + 20b c )d e
+--R                       + 
+--R                               2 6        2 5      4 4  4 2
+--R                         (- 36a c  + 54a b c  - 15b c )d e
+--R                       + 
+--R                                   6     3 5  5     2 6 6
+--R                         (- 12a b c  + 6b c )d e - b c d
+--R                    /
+--R                             3 11         2 2 10          4 9       6 8
+--R                       46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                             3  3        2     2     2       2 2     3 3
+--R                (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                            2   6         3 5      5 4
+--R                      (1296a b c  - 648a b c  + 81b c )e
+--R                    + 
+--R                              2 7          2 6       4 5
+--R                      (- 2592a c  + 1296a b c  - 162b c )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     5
+--R                           (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                         + 
+--R                               3 5       2 2 4        4 3      6 2  2 4
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                                2   5        3 4      5 3  3 3
+--R                           (112a b c  - 98a b c  + 20b c )d e
+--R                         + 
+--R                                 2 6        2 5      4 4  4 2
+--R                           (- 36a c  + 54a b c  - 15b c )d e
+--R                         + 
+--R                                     6     3 5  5     2 6 6
+--R                           (- 12a b c  + 6b c )d e - b c d
+--R                      /
+--R                               3 11         2 2 10          4 9       6 8
+--R                         46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                            3 3      2 2 2        4      6  4
+--R                      (- 24a c  + 54a b c  - 24a b c + 3b )e
+--R                    + 
+--R                             2   3        3 2     5     3
+--R                      (- 108a b c  + 63a b c  - 9b c)d e
+--R                    + 
+--R                          2 4        2 3     4 2  2 2           4     3 3  3
+--R                      (72a c  - 54a b c  + 9b c )d e  + (12a b c  - 3b c )d e
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                                5      2 4
+--R                         (108a c  - 27b c )
+--R                      *
+--R                         ROOT
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                              + 
+--R                                      3   4      2 3 3        5 2     7     5
+--R                                (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                              + 
+--R                                    3 5       2 2 4        4 3      6 2  2 4
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                     2   5        3 4      5 3  3 3
+--R                                (112a b c  - 98a b c  + 20b c )d e
+--R                              + 
+--R                                      2 6        2 5      4 4  4 2
+--R                                (- 36a c  + 54a b c  - 15b c )d e
+--R                              + 
+--R                                          6     3 5  5     2 6 6
+--R                                (- 12a b c  + 6b c )d e - b c d
+--R                           /
+--R                                    3 11         2 2 10          4 9       6 8
+--R                              46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                              2   6         3 5      5 4
+--R                        (1296a b c  - 648a b c  + 81b c )e
+--R                      + 
+--R                                2 7          2 6       4 5
+--R                        (- 2592a c  + 1296a b c  - 162b c )d
+--R                   *
+--R                      ROOT
+--R                                  4 4      3 2 3      2 4 2       6     8  6
+--R                             (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                           + 
+--R                                   3   4      2 3 3        5 2     7     5
+--R                             (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                           + 
+--R                                 3 5       2 2 4        4 3      6 2  2 4
+--R                             (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                           + 
+--R                                  2   5        3 4      5 3  3 3
+--R                             (112a b c  - 98a b c  + 20b c )d e
+--R                           + 
+--R                                   2 6        2 5      4 4  4 2
+--R                             (- 36a c  + 54a b c  - 15b c )d e
+--R                           + 
+--R                                       6     3 5  5     2 6 6
+--R                             (- 12a b c  + 6b c )d e - b c d
+--R                        /
+--R                                 3 11         2 2 10          4 9       6 8
+--R                           46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                  + 
+--R                          3 3      2 2 2        4      6  4
+--R                    (- 24a c  + 54a b c  - 24a b c + 3b )e
+--R                  + 
+--R                           2   3        3 2     5     3
+--R                    (- 108a b c  + 63a b c  - 9b c)d e
+--R                  + 
+--R                        2 4        2 3     4 2  2 2           4     3 3  3
+--R                    (72a c  - 54a b c  + 9b c )d e  + (12a b c  - 3b c )d e
+--R               *
+--R                  ROOT
+--R                                  5      2 4
+--R                           (108a c  - 27b c )
+--R                        *
+--R                           ROOT
+--R                                            4 4      3 2 3      2 4 2       6
+--R                                        - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                      + 
+--R                                           8
+--R                                        - b
+--R                                 *
+--R                                     6
+--R                                    e
+--R                                + 
+--R                                        3   4      2 3 3        5 2     7     5
+--R                                  (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                                + 
+--R                                      3 5       2 2 4        4 3      6 2  2 4
+--R                                  (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                + 
+--R                                       2   5        3 4      5 3  3 3
+--R                                  (112a b c  - 98a b c  + 20b c )d e
+--R                                + 
+--R                                        2 6        2 5      4 4  4 2
+--R                                  (- 36a c  + 54a b c  - 15b c )d e
+--R                                + 
+--R                                            6     3 5  5     2 6 6
+--R                                  (- 12a b c  + 6b c )d e - b c d
+--R                             /
+--R                                      3 11         2 2 10          4 9       6 8
+--R                                46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                    /
+--R                             5      2 4
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                         3 2      2 2        4  5
+--R                    (- 8a c  + 16a b c - 4a b )e
+--R                  + 
+--R                          2   2       3      5    4
+--R                    (- 28a b c  - 4a b c + 4b )d e
+--R                  + 
+--R                        2 3        2 2      4   2 3             3      3 2  3 2
+--R                    (16a c  + 40a b c  - 16b c)d e  + (- 56a b c  + 24b c )d e
+--R                  + 
+--R                          4      2 3  4        4 5
+--R                    (24a c  - 16b c )d e + 4b c d
+--R               *
+--R                  x
+--R     + 
+--R                                   +--------------------+2
+--R                 +-----------+     |   +-----------+
+--R            3+-+ |          2 3+-+3|   |          2
+--R         18c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                           5      2 4
+--R                  (- 108a c  + 27b c )
+--R               *
+--R                  ROOT
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                       + 
+--R                               3   4      2 3 3        5 2     7     5
+--R                         (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                       + 
+--R                             3 5       2 2 4        4 3      6 2  2 4
+--R                         (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                       + 
+--R                              2   5        3 4      5 3  3 3
+--R                         (112a b c  - 98a b c  + 20b c )d e
+--R                       + 
+--R                               2 6        2 5      4 4  4 2
+--R                         (- 36a c  + 54a b c  - 15b c )d e
+--R                       + 
+--R                                   6     3 5  5     2 6 6
+--R                         (- 12a b c  + 6b c )d e - b c d
+--R                    /
+--R                             3 11         2 2 10          4 9       6 8
+--R                       46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R              + 
+--R                             3  3        2     2     2       2 2     3 3
+--R                (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R           /
+--R                    5      2 4
+--R              216a c  - 54b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                            2   6         3 5      5 4
+--R                      (1296a b c  - 648a b c  + 81b c )e
+--R                    + 
+--R                              2 7          2 6       4 5
+--R                      (- 2592a c  + 1296a b c  - 162b c )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     5
+--R                           (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                         + 
+--R                               3 5       2 2 4        4 3      6 2  2 4
+--R                           (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                         + 
+--R                                2   5        3 4      5 3  3 3
+--R                           (112a b c  - 98a b c  + 20b c )d e
+--R                         + 
+--R                                 2 6        2 5      4 4  4 2
+--R                           (- 36a c  + 54a b c  - 15b c )d e
+--R                         + 
+--R                                     6     3 5  5     2 6 6
+--R                           (- 12a b c  + 6b c )d e - b c d
+--R                      /
+--R                               3 11         2 2 10          4 9       6 8
+--R                         46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                + 
+--R                          3 3      2 2 2        4      6  4
+--R                      (24a c  - 54a b c  + 24a b c - 3b )e
+--R                    + 
+--R                           2   3        3 2     5     3
+--R                      (108a b c  - 63a b c  + 9b c)d e
+--R                    + 
+--R                          2 4        2 3     4 2  2 2             4     3 3  3
+--R                    (- 72a c  + 54a b c  - 9b c )d e  + (- 12a b c  + 3b c )d e
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                                  5      2 4
+--R                         (- 108a c  + 27b c )
+--R                      *
+--R                         ROOT
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                              + 
+--R                                      3   4      2 3 3        5 2     7     5
+--R                                (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                              + 
+--R                                    3 5       2 2 4        4 3      6 2  2 4
+--R                                (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                              + 
+--R                                     2   5        3 4      5 3  3 3
+--R                                (112a b c  - 98a b c  + 20b c )d e
+--R                              + 
+--R                                      2 6        2 5      4 4  4 2
+--R                                (- 36a c  + 54a b c  - 15b c )d e
+--R                              + 
+--R                                          6     3 5  5     2 6 6
+--R                                (- 12a b c  + 6b c )d e - b c d
+--R                           /
+--R                                    3 11         2 2 10          4 9       6 8
+--R                              46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                     + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                  /
+--R                           5      2 4
+--R                     216a c  - 54b c
+--R               ,
+--R                   3
+--R           /
+--R                              2   6         3 5      5 4
+--R                        (1296a b c  - 648a b c  + 81b c )e
+--R                      + 
+--R                                2 7          2 6       4 5
+--R                        (- 2592a c  + 1296a b c  - 162b c )d
+--R                   *
+--R                      ROOT
+--R                                  4 4      3 2 3      2 4 2       6     8  6
+--R                             (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )e
+--R                           + 
+--R                                   3   4      2 3 3        5 2     7     5
+--R                             (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                           + 
+--R                                 3 5       2 2 4        4 3      6 2  2 4
+--R                             (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                           + 
+--R                                  2   5        3 4      5 3  3 3
+--R                             (112a b c  - 98a b c  + 20b c )d e
+--R                           + 
+--R                                   2 6        2 5      4 4  4 2
+--R                             (- 36a c  + 54a b c  - 15b c )d e
+--R                           + 
+--R                                       6     3 5  5     2 6 6
+--R                             (- 12a b c  + 6b c )d e - b c d
+--R                        /
+--R                                 3 11         2 2 10          4 9       6 8
+--R                           46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                  + 
+--R                        3 3      2 2 2        4      6  4
+--R                    (24a c  - 54a b c  + 24a b c - 3b )e
+--R                  + 
+--R                         2   3        3 2     5     3
+--R                    (108a b c  - 63a b c  + 9b c)d e
+--R                  + 
+--R                          2 4        2 3     4 2  2 2             4     3 3  3
+--R                    (- 72a c  + 54a b c  - 9b c )d e  + (- 12a b c  + 3b c )d e
+--R               *
+--R                  ROOT
+--R                                    5      2 4
+--R                           (- 108a c  + 27b c )
+--R                        *
+--R                           ROOT
+--R                                            4 4      3 2 3      2 4 2       6
+--R                                        - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                      + 
+--R                                           8
+--R                                        - b
+--R                                 *
+--R                                     6
+--R                                    e
+--R                                + 
+--R                                        3   4      2 3 3        5 2     7     5
+--R                                  (- 36a b c  + 84a b c  - 42a b c  + 6b c)d e
+--R                                + 
+--R                                      3 5       2 2 4        4 3      6 2  2 4
+--R                                  (24a c  - 141a b c  + 90a b c  - 15b c )d e
+--R                                + 
+--R                                       2   5        3 4      5 3  3 3
+--R                                  (112a b c  - 98a b c  + 20b c )d e
+--R                                + 
+--R                                        2 6        2 5      4 4  4 2
+--R                                  (- 36a c  + 54a b c  - 15b c )d e
+--R                                + 
+--R                                            6     3 5  5     2 6 6
+--R                                  (- 12a b c  + 6b c )d e - b c d
+--R                             /
+--R                                      3 11         2 2 10          4 9       6 8
+--R                                46656a c   - 34992a b c   + 8748a b c  - 729b c
+--R                       + 
+--R                                    3  3        2     2     2       2 2     3 3
+--R                       (- 2a b c + b )e  + (3a c  - 3b c)d e  + 3b c d e - c d
+--R                    /
+--R                             5      2 4
+--R                       216a c  - 54b c
+--R                 ,
+--R                     3
+--R              + 
+--R                       3 2      2 2        4  5       2   2       3      5    4
+--R                    (8a c  - 16a b c + 4a b )e  + (28a b c  + 4a b c - 4b )d e
+--R                  + 
+--R                          2 3        2 2      4   2 3           3      3 2  3 2
+--R                    (- 16a c  - 40a b c  + 16b c)d e  + (56a b c  - 24b c )d e
+--R                  + 
+--R                            4      2 3  4        4 5
+--R                    (- 24a c  + 16b c )d e - 4b c d
+--R               *
+--R                  x
+--R     + 
+--R                          +-----------+
+--R                          |          2               2
+--R         ((- 6b e + 6c d)\|- 4a c + b   + (12a c - 6b )e + 6b c d)
+--R      *
+--R                                             +------------------+
+--R          +--------------------+2            | +-----------+
+--R          |   +-----------+           3+-+2 3| |          2          3+-+
+--R         3|   |          2            \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         \|- \|- 4a c + b   + b  atan(-----------------------------------)
+--R                                                   +------------------+
+--R                                                   | +-----------+
+--R                                         3+-+2 +-+3| |          2
+--R                                         \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                          |          2                 2
+--R         ((- 6b e + 6c d)\|- 4a c + b   + (- 12a c + 6b )e - 6b c d)
+--R      *
+--R                                           +--------------------+
+--R          +------------------+2            |   +-----------+
+--R          | +-----------+           3+-+2 3|   |          2          3+-+
+--R         3| |          2            \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         \|\|- 4a c + b   + b  atan(-------------------------------------)
+--R                                                 +--------------------+
+--R                                                 |   +-----------+
+--R                                       3+-+2 +-+3|   |          2
+--R                                       \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+2  +------------------+2
+--R                +-----------+     |   +-----------+        | +-----------+
+--R       3+-+ +-+ |          2 3+-+3|   |          2        3| |          2
+--R     6c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 649
+t0:=x^2*(d+e*x^3)/(a+b*x^3+c*x^6)
+--R 
+--R
+--R             5      2
+--R          e x  + d x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 11
+
+--S 12 of 649
+r0:=1/6*e*log(a+b*x^3+c*x^6)/c-1/3*(2*c*d-b*e)*atanh((b+2*c*x^3)/_
+   sqrt(b^2-4*a*c))/(c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                             3                                 +-----------+
+--R                         2c x  + b               6      3      |          2
+--R   (2b e - 4c d)atanh(--------------) + e log(c x  + b x  + a)\|- 4a c + b
+--R                       +-----------+
+--R                       |          2
+--R                      \|- 4a c + b
+--R   -------------------------------------------------------------------------
+--R                                   +-----------+
+--R                                   |          2
+--R                                6c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           (b e - 2c d)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 6         3           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   3             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   6      3
+--R                c x  + b x  + a
+--R       + 
+--R                                +-----------+
+--R                  6      3      |          2
+--R         e log(c x  + b x  + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       6c\|- 4a c + b
+--R     ,
+--R
+--R                                         +---------+
+--R                                  3      |        2
+--R                             (2c x  + b)\|4a c - b
+--R         (- 2b e + 4c d)atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R       + 
+--R                                +---------+
+--R                  6      3      |        2
+--R         e log(c x  + b x  + a)\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       6c\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 13
+
+--S 14 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (b e - 2c d)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 6         3           2  |          2           2     2   3
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 6      3
+--R              c x  + b x  + a
+--R     + 
+--R                                   3
+--R                               2c x  + b
+--R       (- 2b e + 4c d)atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     6c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+--S 16 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      +---------+             3
+--R                      |        2          2c x  + b
+--R       (- b e + 2c d)\|4a c - b  atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                                                    +---------+
+--R                      +-----------+          3      |        2
+--R                      |          2      (2c x  + b)\|4a c - b
+--R       (- b e + 2c d)\|- 4a c + b  atan(-----------------------)
+--R                                                       2
+--R                                               4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     3c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 17
+
+)clear all
+
+--S 18 of 649
+t0:=x*(d+e*x^3)/(a+b*x^3+c*x^6)
+--R 
+--R
+--R              4
+--R           e x  + d x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 18
+
+--S 19 of 649
+r0:=-1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(e+(2*c*d-b*e)/_
+   sqrt(b^2-4*a*c))/(2^(2/3)*c^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))+_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-_
+   4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(e+(2*c*d-b*e)/sqrt(b^2-_
+   4*a*c))/(2^(2/3)*c^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))-atan((-4*_
+   c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3)))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/(2^(2/3)*_
+   c^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3))-1/3*log(2^(1/3)*c^(1/3)*_
+   x+(b+sqrt(b^2-4*a*c))^(1/3))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(2/3)*_
+   c^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))+1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*_
+   c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))-atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(e+(-2*c*d+b*e)/_
+   sqrt(b^2-4*a*c))/(2^(2/3)*c^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3))
+--R 
+--R
+--R   (2)
+--R                                                  +--------------------+
+--R                +-----------+                     |   +-----------+
+--R            +-+ |          2                 +-+ 3|   |          2
+--R         (e\|3 \|- 4a c + b   + (b e - 2c d)\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                        +--------------------+
+--R                   +-----------+                        |   +-----------+
+--R               +-+ |          2                    +-+ 3|   |          2
+--R         (- 2e\|3 \|- 4a c + b   + (- 2b e + 4c d)\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                    +------------------+
+--R                +-----------+                       | +-----------+
+--R            +-+ |          2                   +-+ 3| |          2
+--R         (e\|3 \|- 4a c + b   + (- b e + 2c d)\|3 )\|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                      +------------------+
+--R                   +-----------+                      | +-----------+
+--R               +-+ |          2                  +-+ 3| |          2
+--R         (- 2e\|3 \|- 4a c + b   + (2b e - 4c d)\|3 )\|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                             +--------------------+
+--R               +-----------+                 |   +-----------+
+--R               |          2                 3|   |          2
+--R         (- 6e\|- 4a c + b   - 6b e + 12c d)\|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                             +------------------+
+--R               +-----------+                 | +-----------+
+--R               |          2                 3| |          2
+--R         (- 6e\|- 4a c + b   + 6b e - 12c d)\|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                                    +--------------------+ +------------------+
+--R                +-----------+       |   +-----------+      | +-----------+
+--R      3+-+2 +-+ |          2 3+-+2 3|   |          2      3| |          2
+--R     6\|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2
+--R      *
+--R         ROOT
+--R                       2 3        2 2
+--R                  (108a c  - 27a b c )
+--R               *
+--R                  ROOT
+--R                              4 2     3 2     2 4  6         3   2     2 3     5
+--R                         (- 4a c  + 4a b c - a b )e  + (- 12a b c  + 6a b c)d e
+--R                       + 
+--R                             3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                         (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                       + 
+--R                               2 4       2 3  4 2          4 5     2 4 6
+--R                         (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                    /
+--R                             5 7         4 2 6        3 4 5       2 6 4
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                     3           2    2 3
+--R                a b e  - 3a c d e  + c d
+--R           /
+--R                  2 3        2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                             5 5         4 2 4        3 4 3       2 6 2  2
+--R                      (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                    + 
+--R                               4 6         3 2 5        2 4 4         6 3  2
+--R                      (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                 *
+--R                    ROOT
+--R                                4 2     3 2     2 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                                 3   2     2 3     5       3 3      2 2 2  2 4
+--R                           (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                               2   3       3 2  3 3         2 4       2 3  4 2
+--R                           (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                         + 
+--R                                  4 5     2 4 6
+--R                           12a b c d e - b c d
+--R                      /
+--R                               5 7         4 2 6        3 4 5       2 6 4
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                        4   2      3 3      2 5  5
+--R                  (- 72a b c  + 54a b c - 9a b )e
+--R                + 
+--R                       4 3       3 2 2      2 4     4
+--R                  (288a c  - 324a b c  + 63a b c)d e
+--R                + 
+--R                       3   3       2 3 2       5   2 3
+--R                  (576a b c  - 108a b c  - 9a b c)d e
+--R                + 
+--R                         3 4      2 2 3        4 2  3 2
+--R                  (- 864a c  + 72a b c  + 36a b c )d e
+--R                + 
+--R                       2   4        3 3  4            2 4     4 3  5
+--R                  (360a b c  - 90a b c )d e + (- 36a b c  + 9b c )d
+--R             *
+--R                  ROOT
+--R                                2 3        2 2
+--R                           (108a c  - 27a b c )
+--R                        *
+--R                           ROOT
+--R                                       4 2     3 2     2 4  6
+--R                                  (- 4a c  + 4a b c - a b )e
+--R                                + 
+--R                                        3   2     2 3     5
+--R                                  (- 12a b c  + 6a b c)d e
+--R                                + 
+--R                                      3 3      2 2 2  2 4
+--R                                  (24a c  - 21a b c )d e
+--R                                + 
+--R                                      2   3       3 2  3 3
+--R                                  (32a b c  + 2a b c )d e
+--R                                + 
+--R                                      2 4       2 3  4 2          4 5     2 4 6
+--R                                (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                             /
+--R                                      5 7         4 2 6        3 4 5       2 6 4
+--R                                46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                       + 
+--R                              3           2    2 3
+--R                         a b e  - 3a c d e  + c d
+--R                    /
+--R                           2 3        2 2
+--R                       216a c  - 54a b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                     4      3 2  7        3        2 3    6
+--R                  (4a c - 2a b )e  + (- 2a b c + 4a b )d e
+--R                + 
+--R                       3 2      2 2        4  2 5       2   2        3   3 4
+--R                  (- 4a c  - 12a b c - 2a b )d e  + (30a b c  + 10a b c)d e
+--R                + 
+--R                        2 3        2 2  4 3           3     3 2  5 2
+--R                  (- 20a c  - 30a b c )d e  + (34a b c  + 2b c )d e
+--R                + 
+--R                          4     2 3  6        4 7
+--R                  (- 12a c  - 4b c )d e + 2b c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            ROOT
+--R                            2 3        2 2
+--R                     (- 108a c  + 27a b c )
+--R                  *
+--R                     ROOT
+--R                                 4 2     3 2     2 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                  3   2     2 3     5       3 3      2 2 2  2 4
+--R                            (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                2   3       3 2  3 3         2 4       2 3  4 2
+--R                            (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                          + 
+--R                                   4 5     2 4 6
+--R                            12a b c d e - b c d
+--R                       /
+--R                                5 7         4 2 6        3 4 5       2 6 4
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                        3           2    2 3
+--R                   a b e  - 3a c d e  + c d
+--R              /
+--R                     2 3        2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                5 5         4 2 4        3 4 3       2 6 2  2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                       + 
+--R                                  4 6         3 2 5        2 4 4         6 3  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                             4   2      3 3      2 5  5
+--R                         (72a b c  - 54a b c + 9a b )e
+--R                       + 
+--R                                4 3       3 2 2      2 4     4
+--R                         (- 288a c  + 324a b c  - 63a b c)d e
+--R                       + 
+--R                                3   3       2 3 2       5   2 3
+--R                         (- 576a b c  + 108a b c  + 9a b c)d e
+--R                       + 
+--R                              3 4      2 2 3        4 2  3 2
+--R                         (864a c  - 72a b c  - 36a b c )d e
+--R                       + 
+--R                                2   4        3 3  4          2 4     4 3  5
+--R                         (- 360a b c  + 90a b c )d e + (36a b c  - 9b c )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                     2 3        2 2
+--R                              (- 108a c  + 27a b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2     3 2     2 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                           3   2     2 3     5
+--R                                     (- 12a b c  + 6a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 4
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                         2   3       3 2  3 3
+--R                                     (32a b c  + 2a b c )d e
+--R                                   + 
+--R                                           2 4       2 3  4 2          4 5
+--R                                     (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                   + 
+--R                                        2 4 6
+--R                                     - b c d
+--R                                /
+--R                                           5 7         4 2 6        3 4 5
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           2 6 4
+--R                                     - 729a b c
+--R                          + 
+--R                                 3           2    2 3
+--R                            a b e  - 3a c d e  + c d
+--R                       /
+--R                              2 3        2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               5 4        4 2 3       3 4 2  3
+--R                         (2592a c  - 1296a b c  + 162a b c )e
+--R                       + 
+--R                                 4   4        3 3 3       2 5 2    2
+--R                         (- 3888a b c  + 1944a b c  - 243a b c )d e
+--R                       + 
+--R                               4 5       2 4 3        6 2  2
+--R                         (2592a c  - 486a b c  + 81a b c )d e
+--R                       + 
+--R                                 3   5       2 3 4        5 3  3
+--R                         (- 1296a b c  + 648a b c  - 81a b c )d
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                           4 2      3 2      2 4    5
+--R                     (- 24a c  + 18a b c - 3a b )d e
+--R                   + 
+--R                           3   2     2 3        5  2 4
+--R                     (- 12a b c  - 9a b c + 3a b )d e
+--R                   + 
+--R                         3 3      2 2 2        4   3 3
+--R                     (48a c  + 36a b c  - 12a b c)d e
+--R                   + 
+--R                            2   3        3 2  4 2
+--R                     (- 120a b c  + 30a b c )d e
+--R                   + 
+--R                         2 4       2 3     4 2  5              4     3 3  6
+--R                     (72a c  - 6a b c  - 3b c )d e + (- 12a b c  + 3b c )d
+--R                *
+--R                   ROOT
+--R                                   2 3        2 2
+--R                            (- 108a c  + 27a b c )
+--R                         *
+--R                            ROOT
+--R                                        4 2     3 2     2 4  6
+--R                                   (- 4a c  + 4a b c - a b )e
+--R                                 + 
+--R                                         3   2     2 3     5
+--R                                   (- 12a b c  + 6a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 4
+--R                                   (24a c  - 21a b c )d e
+--R                                 + 
+--R                                       2   3       3 2  3 3
+--R                                   (32a b c  + 2a b c )d e
+--R                                 + 
+--R                                       2 4       2 3  4 2          4 5     2 4 6
+--R                                 (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                              /
+--R                                         5 7         4 2 6        3 4 5
+--R                                   46656a c  - 34992a b c  + 8748a b c
+--R                                 + 
+--R                                         2 6 4
+--R                                   - 729a b c
+--R                        + 
+--R                               3           2    2 3
+--R                          a b e  - 3a c d e  + c d
+--R                     /
+--R                            2 3        2 2
+--R                        216a c  - 54a b c
+--R                  ,
+--R                      3
+--R               + 
+--R                        4      3 2  7        3        2 3    6
+--R                     (4a c - 2a b )e  + (- 2a b c + 4a b )d e
+--R                   + 
+--R                          3 2      2 2        4  2 5       2   2        3   3 4
+--R                     (- 4a c  - 12a b c - 2a b )d e  + (30a b c  + 10a b c)d e
+--R                   + 
+--R                           2 3        2 2  4 3           3     3 2  5 2
+--R                     (- 20a c  - 30a b c )d e  + (34a b c  + 2b c )d e
+--R                   + 
+--R                             4     2 3  6        4 7
+--R                     (- 12a c  - 4b c )d e + 2b c d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                         2 3        2 2
+--R                  (- 108a c  + 27a b c )
+--R               *
+--R                  ROOT
+--R                              4 2     3 2     2 4  6         3   2     2 3     5
+--R                         (- 4a c  + 4a b c - a b )e  + (- 12a b c  + 6a b c)d e
+--R                       + 
+--R                             3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                         (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                       + 
+--R                               2 4       2 3  4 2          4 5     2 4 6
+--R                         (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                    /
+--R                             5 7         4 2 6        3 4 5       2 6 4
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                     3           2    2 3
+--R                a b e  - 3a c d e  + c d
+--R           /
+--R                  2 3        2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                               5 5         4 2 4        3 4 3       2 6 2  2
+--R                      (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )e
+--R                    + 
+--R                             4 6         3 2 5        2 4 4         6 3  2
+--R                      (15552a c  - 11664a b c  + 2916a b c  - 243a b c )d
+--R                 *
+--R                    ROOT
+--R                                4 2     3 2     2 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                                 3   2     2 3     5       3 3      2 2 2  2 4
+--R                           (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                               2   3       3 2  3 3         2 4       2 3  4 2
+--R                           (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                         + 
+--R                                  4 5     2 4 6
+--R                           12a b c d e - b c d
+--R                      /
+--R                               5 7         4 2 6        3 4 5       2 6 4
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                        4   2      3 3      2 5  5
+--R                  (- 72a b c  + 54a b c - 9a b )e
+--R                + 
+--R                       4 3       3 2 2      2 4     4
+--R                  (288a c  - 324a b c  + 63a b c)d e
+--R                + 
+--R                       3   3       2 3 2       5   2 3
+--R                  (576a b c  - 108a b c  - 9a b c)d e
+--R                + 
+--R                         3 4      2 2 3        4 2  3 2
+--R                  (- 864a c  + 72a b c  + 36a b c )d e
+--R                + 
+--R                       2   4        3 3  4            2 4     4 3  5
+--R                  (360a b c  - 90a b c )d e + (- 36a b c  + 9b c )d
+--R             *
+--R                  ROOT
+--R                                  2 3        2 2
+--R                           (- 108a c  + 27a b c )
+--R                        *
+--R                           ROOT
+--R                                       4 2     3 2     2 4  6
+--R                                  (- 4a c  + 4a b c - a b )e
+--R                                + 
+--R                                        3   2     2 3     5
+--R                                  (- 12a b c  + 6a b c)d e
+--R                                + 
+--R                                      3 3      2 2 2  2 4
+--R                                  (24a c  - 21a b c )d e
+--R                                + 
+--R                                      2   3       3 2  3 3
+--R                                  (32a b c  + 2a b c )d e
+--R                                + 
+--R                                      2 4       2 3  4 2          4 5     2 4 6
+--R                                (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                             /
+--R                                      5 7         4 2 6        3 4 5       2 6 4
+--R                                46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                       + 
+--R                              3           2    2 3
+--R                         a b e  - 3a c d e  + c d
+--R                    /
+--R                           2 3        2 2
+--R                       216a c  - 54a b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                     4      3 2  7        3        2 3    6
+--R                  (4a c - 2a b )e  + (- 2a b c + 4a b )d e
+--R                + 
+--R                       3 2      2 2        4  2 5       2   2        3   3 4
+--R                  (- 4a c  - 12a b c - 2a b )d e  + (30a b c  + 10a b c)d e
+--R                + 
+--R                        2 3        2 2  4 3           3     3 2  5 2
+--R                  (- 20a c  - 30a b c )d e  + (34a b c  + 2b c )d e
+--R                + 
+--R                          4     2 3  6        4 7
+--R                  (- 12a c  - 4b c )d e + 2b c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            ROOT
+--R                          2 3        2 2
+--R                     (108a c  - 27a b c )
+--R                  *
+--R                     ROOT
+--R                                 4 2     3 2     2 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                  3   2     2 3     5       3 3      2 2 2  2 4
+--R                            (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                2   3       3 2  3 3         2 4       2 3  4 2
+--R                            (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                          + 
+--R                                   4 5     2 4 6
+--R                            12a b c d e - b c d
+--R                       /
+--R                                5 7         4 2 6        3 4 5       2 6 4
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                        3           2    2 3
+--R                   a b e  - 3a c d e  + c d
+--R              /
+--R                     2 3        2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                  5 5         4 2 4        3 4 3       2 6 2  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )e
+--R                       + 
+--R                                4 6         3 2 5        2 4 4         6 3  2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                             4   2      3 3      2 5  5
+--R                         (72a b c  - 54a b c + 9a b )e
+--R                       + 
+--R                                4 3       3 2 2      2 4     4
+--R                         (- 288a c  + 324a b c  - 63a b c)d e
+--R                       + 
+--R                                3   3       2 3 2       5   2 3
+--R                         (- 576a b c  + 108a b c  + 9a b c)d e
+--R                       + 
+--R                              3 4      2 2 3        4 2  3 2
+--R                         (864a c  - 72a b c  - 36a b c )d e
+--R                       + 
+--R                                2   4        3 3  4          2 4     4 3  5
+--R                         (- 360a b c  + 90a b c )d e + (36a b c  - 9b c )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                   2 3        2 2
+--R                              (108a c  - 27a b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2     3 2     2 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                           3   2     2 3     5
+--R                                     (- 12a b c  + 6a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 4
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                         2   3       3 2  3 3
+--R                                     (32a b c  + 2a b c )d e
+--R                                   + 
+--R                                           2 4       2 3  4 2          4 5
+--R                                     (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                   + 
+--R                                        2 4 6
+--R                                     - b c d
+--R                                /
+--R                                           5 7         4 2 6        3 4 5
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           2 6 4
+--R                                     - 729a b c
+--R                          + 
+--R                                 3           2    2 3
+--R                            a b e  - 3a c d e  + c d
+--R                       /
+--R                              2 3        2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 5 4        4 2 3       3 4 2  3
+--R                         (- 2592a c  + 1296a b c  - 162a b c )e
+--R                       + 
+--R                               4   4        3 3 3       2 5 2    2
+--R                         (3888a b c  - 1944a b c  + 243a b c )d e
+--R                       + 
+--R                                 4 5       2 4 3        6 2  2
+--R                         (- 2592a c  + 486a b c  - 81a b c )d e
+--R                       + 
+--R                               3   5       2 3 4        5 3  3
+--R                         (1296a b c  - 648a b c  + 81a b c )d
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                           4 2      3 2      2 4    5
+--R                     (- 24a c  + 18a b c - 3a b )d e
+--R                   + 
+--R                           3   2     2 3        5  2 4
+--R                     (- 12a b c  - 9a b c + 3a b )d e
+--R                   + 
+--R                         3 3      2 2 2        4   3 3
+--R                     (48a c  + 36a b c  - 12a b c)d e
+--R                   + 
+--R                            2   3        3 2  4 2
+--R                     (- 120a b c  + 30a b c )d e
+--R                   + 
+--R                         2 4       2 3     4 2  5              4     3 3  6
+--R                     (72a c  - 6a b c  - 3b c )d e + (- 12a b c  + 3b c )d
+--R                *
+--R                   ROOT
+--R                                 2 3        2 2
+--R                            (108a c  - 27a b c )
+--R                         *
+--R                            ROOT
+--R                                        4 2     3 2     2 4  6
+--R                                   (- 4a c  + 4a b c - a b )e
+--R                                 + 
+--R                                         3   2     2 3     5
+--R                                   (- 12a b c  + 6a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 4
+--R                                   (24a c  - 21a b c )d e
+--R                                 + 
+--R                                       2   3       3 2  3 3
+--R                                   (32a b c  + 2a b c )d e
+--R                                 + 
+--R                                       2 4       2 3  4 2          4 5     2 4 6
+--R                                 (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                              /
+--R                                         5 7         4 2 6        3 4 5
+--R                                   46656a c  - 34992a b c  + 8748a b c
+--R                                 + 
+--R                                         2 6 4
+--R                                   - 729a b c
+--R                        + 
+--R                               3           2    2 3
+--R                          a b e  - 3a c d e  + c d
+--R                     /
+--R                            2 3        2 2
+--R                        216a c  - 54a b c
+--R                  ,
+--R                      3
+--R               + 
+--R                        4      3 2  7        3        2 3    6
+--R                     (4a c - 2a b )e  + (- 2a b c + 4a b )d e
+--R                   + 
+--R                          3 2      2 2        4  2 5       2   2        3   3 4
+--R                     (- 4a c  - 12a b c - 2a b )d e  + (30a b c  + 10a b c)d e
+--R                   + 
+--R                           2 3        2 2  4 3           3     3 2  5 2
+--R                     (- 20a c  - 30a b c )d e  + (34a b c  + 2b c )d e
+--R                   + 
+--R                             4     2 3  6        4 7
+--R                     (- 12a c  - 4b c )d e + 2b c d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R       -
+--R              +-+
+--R            2\|3
+--R         *
+--R            ROOT
+--R                          2 3        2 2
+--R                     (108a c  - 27a b c )
+--R                  *
+--R                     ROOT
+--R                                 4 2     3 2     2 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                  3   2     2 3     5       3 3      2 2 2  2 4
+--R                            (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                2   3       3 2  3 3         2 4       2 3  4 2
+--R                            (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                          + 
+--R                                   4 5     2 4 6
+--R                            12a b c d e - b c d
+--R                       /
+--R                                5 7         4 2 6        3 4 5       2 6 4
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                        3           2    2 3
+--R                   a b e  - 3a c d e  + c d
+--R              /
+--R                     2 3        2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                                5 5         4 2 4        3 4 3       2 6 2  2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                       + 
+--R                                  4 6         3 2 5        2 4 4         6 3  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                               4   2      3 3      2 5  5
+--R                         (- 72a b c  + 54a b c - 9a b )e
+--R                       + 
+--R                              4 3       3 2 2      2 4     4
+--R                         (288a c  - 324a b c  + 63a b c)d e
+--R                       + 
+--R                              3   3       2 3 2       5   2 3
+--R                         (576a b c  - 108a b c  - 9a b c)d e
+--R                       + 
+--R                                3 4      2 2 3        4 2  3 2
+--R                         (- 864a c  + 72a b c  + 36a b c )d e
+--R                       + 
+--R                              2   4        3 3  4            2 4     4 3  5
+--R                         (360a b c  - 90a b c )d e + (- 36a b c  + 9b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                   2 3        2 2
+--R                              (108a c  - 27a b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2     3 2     2 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                           3   2     2 3     5
+--R                                     (- 12a b c  + 6a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 4
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                         2   3       3 2  3 3
+--R                                     (32a b c  + 2a b c )d e
+--R                                   + 
+--R                                           2 4       2 3  4 2          4 5
+--R                                     (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                   + 
+--R                                        2 4 6
+--R                                     - b c d
+--R                                /
+--R                                           5 7         4 2 6        3 4 5
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           2 6 4
+--R                                     - 729a b c
+--R                          + 
+--R                                 3           2    2 3
+--R                            a b e  - 3a c d e  + c d
+--R                       /
+--R                              2 3        2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                  5 5         4 2 4        3 4 3       2 6 2  2
+--R                           (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                         + 
+--R                                  4 6         3 2 5        2 4 4         6 3  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                      *
+--R                         ROOT
+--R                                     4 2     3 2     2 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                      3   2     2 3     5
+--R                                (- 12a b c  + 6a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 4
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                    2   3       3 2  3 3
+--R                                (32a b c  + 2a b c )d e
+--R                              + 
+--R                                      2 4       2 3  4 2          4 5     2 4 6
+--R                                (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                           /
+--R                                    5 7         4 2 6        3 4 5       2 6 4
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                             4   2      3 3      2 5  5
+--R                       (- 72a b c  + 54a b c - 9a b )e
+--R                     + 
+--R                            4 3       3 2 2      2 4     4
+--R                       (288a c  - 324a b c  + 63a b c)d e
+--R                     + 
+--R                            3   3       2 3 2       5   2 3
+--R                       (576a b c  - 108a b c  - 9a b c)d e
+--R                     + 
+--R                              3 4      2 2 3        4 2  3 2
+--R                       (- 864a c  + 72a b c  + 36a b c )d e
+--R                     + 
+--R                            2   4        3 3  4            2 4     4 3  5
+--R                       (360a b c  - 90a b c )d e + (- 36a b c  + 9b c )d
+--R                  *
+--R                       ROOT
+--R                                     2 3        2 2
+--R                                (108a c  - 27a b c )
+--R                             *
+--R                                ROOT
+--R                                            4 2     3 2     2 4  6
+--R                                       (- 4a c  + 4a b c - a b )e
+--R                                     + 
+--R                                             3   2     2 3     5
+--R                                       (- 12a b c  + 6a b c)d e
+--R                                     + 
+--R                                           3 3      2 2 2  2 4
+--R                                       (24a c  - 21a b c )d e
+--R                                     + 
+--R                                           2   3       3 2  3 3
+--R                                       (32a b c  + 2a b c )d e
+--R                                     + 
+--R                                             2 4       2 3  4 2          4 5
+--R                                       (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                     + 
+--R                                          2 4 6
+--R                                       - b c d
+--R                                  /
+--R                                             5 7         4 2 6        3 4 5
+--R                                       46656a c  - 34992a b c  + 8748a b c
+--R                                     + 
+--R                                             2 6 4
+--R                                       - 729a b c
+--R                            + 
+--R                                   3           2    2 3
+--R                              a b e  - 3a c d e  + c d
+--R                         /
+--R                                2 3        2 2
+--R                            216a c  - 54a b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                            4      3 2  7      3        2 3    6
+--R                       (- 8a c + 4a b )e  + (4a b c - 8a b )d e
+--R                     + 
+--R                          3 2      2 2        4  2 5
+--R                       (8a c  + 24a b c + 4a b )d e
+--R                     + 
+--R                             2   2        3   3 4       2 3        2 2  4 3
+--R                       (- 60a b c  - 20a b c)d e  + (40a c  + 60a b c )d e
+--R                     + 
+--R                                 3     3 2  5 2         4     2 3  6        4 7
+--R                       (- 68a b c  - 4b c )d e  + (24a c  + 8b c )d e - 4b c d
+--R                  *
+--R                     x
+--R     + 
+--R       -
+--R              +-+
+--R            2\|3
+--R         *
+--R            ROOT
+--R                            2 3        2 2
+--R                     (- 108a c  + 27a b c )
+--R                  *
+--R                     ROOT
+--R                                 4 2     3 2     2 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                  3   2     2 3     5       3 3      2 2 2  2 4
+--R                            (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                2   3       3 2  3 3         2 4       2 3  4 2
+--R                            (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                          + 
+--R                                   4 5     2 4 6
+--R                            12a b c d e - b c d
+--R                       /
+--R                                5 7         4 2 6        3 4 5       2 6 4
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                        3           2    2 3
+--R                   a b e  - 3a c d e  + c d
+--R              /
+--R                     2 3        2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                                5 5         4 2 4        3 4 3       2 6 2  2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                       + 
+--R                                  4 6         3 2 5        2 4 4         6 3  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                             4   2      3 3      2 5  5
+--R                         (72a b c  - 54a b c + 9a b )e
+--R                       + 
+--R                                4 3       3 2 2      2 4     4
+--R                         (- 288a c  + 324a b c  - 63a b c)d e
+--R                       + 
+--R                                3   3       2 3 2       5   2 3
+--R                         (- 576a b c  + 108a b c  + 9a b c)d e
+--R                       + 
+--R                              3 4      2 2 3        4 2  3 2
+--R                         (864a c  - 72a b c  - 36a b c )d e
+--R                       + 
+--R                                2   4        3 3  4          2 4     4 3  5
+--R                         (- 360a b c  + 90a b c )d e + (36a b c  - 9b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                     2 3        2 2
+--R                              (- 108a c  + 27a b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2     3 2     2 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                           3   2     2 3     5
+--R                                     (- 12a b c  + 6a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 4
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                         2   3       3 2  3 3
+--R                                     (32a b c  + 2a b c )d e
+--R                                   + 
+--R                                           2 4       2 3  4 2          4 5
+--R                                     (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                   + 
+--R                                        2 4 6
+--R                                     - b c d
+--R                                /
+--R                                           5 7         4 2 6        3 4 5
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           2 6 4
+--R                                     - 729a b c
+--R                          + 
+--R                                 3           2    2 3
+--R                            a b e  - 3a c d e  + c d
+--R                       /
+--R                              2 3        2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                  5 5         4 2 4        3 4 3       2 6 2  2
+--R                           (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                         + 
+--R                                  4 6         3 2 5        2 4 4         6 3  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                      *
+--R                         ROOT
+--R                                     4 2     3 2     2 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                      3   2     2 3     5
+--R                                (- 12a b c  + 6a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 4
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                    2   3       3 2  3 3
+--R                                (32a b c  + 2a b c )d e
+--R                              + 
+--R                                      2 4       2 3  4 2          4 5     2 4 6
+--R                                (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                           /
+--R                                    5 7         4 2 6        3 4 5       2 6 4
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                           4   2      3 3      2 5  5
+--R                       (72a b c  - 54a b c + 9a b )e
+--R                     + 
+--R                              4 3       3 2 2      2 4     4
+--R                       (- 288a c  + 324a b c  - 63a b c)d e
+--R                     + 
+--R                              3   3       2 3 2       5   2 3
+--R                       (- 576a b c  + 108a b c  + 9a b c)d e
+--R                     + 
+--R                            3 4      2 2 3        4 2  3 2
+--R                       (864a c  - 72a b c  - 36a b c )d e
+--R                     + 
+--R                              2   4        3 3  4          2 4     4 3  5
+--R                       (- 360a b c  + 90a b c )d e + (36a b c  - 9b c )d
+--R                  *
+--R                       ROOT
+--R                                       2 3        2 2
+--R                                (- 108a c  + 27a b c )
+--R                             *
+--R                                ROOT
+--R                                            4 2     3 2     2 4  6
+--R                                       (- 4a c  + 4a b c - a b )e
+--R                                     + 
+--R                                             3   2     2 3     5
+--R                                       (- 12a b c  + 6a b c)d e
+--R                                     + 
+--R                                           3 3      2 2 2  2 4
+--R                                       (24a c  - 21a b c )d e
+--R                                     + 
+--R                                           2   3       3 2  3 3
+--R                                       (32a b c  + 2a b c )d e
+--R                                     + 
+--R                                             2 4       2 3  4 2          4 5
+--R                                       (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                     + 
+--R                                          2 4 6
+--R                                       - b c d
+--R                                  /
+--R                                             5 7         4 2 6        3 4 5
+--R                                       46656a c  - 34992a b c  + 8748a b c
+--R                                     + 
+--R                                             2 6 4
+--R                                       - 729a b c
+--R                            + 
+--R                                   3           2    2 3
+--R                              a b e  - 3a c d e  + c d
+--R                         /
+--R                                2 3        2 2
+--R                            216a c  - 54a b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                          4      3 2  7        3        2 3    6
+--R                       (8a c - 4a b )e  + (- 4a b c + 8a b )d e
+--R                     + 
+--R                            3 2      2 2        4  2 5
+--R                       (- 8a c  - 24a b c - 4a b )d e
+--R                     + 
+--R                           2   2        3   3 4         2 3        2 2  4 3
+--R                       (60a b c  + 20a b c)d e  + (- 40a c  - 60a b c )d e
+--R                     + 
+--R                               3     3 2  5 2           4     2 3  6        4 7
+--R                       (68a b c  + 4b c )d e  + (- 24a c  - 8b c )d e + 4b c d
+--R                  *
+--R                     x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 20
+
+--S 21 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +--------------------+
+--R                  +-----------+                       |   +-----------+
+--R              +-+ |          2                   +-+ 3|   |          2
+--R         (- e\|3 \|- 4a c + b   + (- b e + 2c d)\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                    +--------------------+
+--R                 +-----------+                      |   +-----------+
+--R             +-+ |          2                  +-+ 3|   |          2
+--R         (2e\|3 \|- 4a c + b   + (2b e - 4c d)\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                        +--------------------+
+--R                    +-----------+       |   +-----------+
+--R          3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R         6\|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       2 3        2 2
+--R                  (108a c  - 27a b c )
+--R               *
+--R                  ROOT
+--R                              4 2     3 2     2 4  6         3   2     2 3     5
+--R                         (- 4a c  + 4a b c - a b )e  + (- 12a b c  + 6a b c)d e
+--R                       + 
+--R                             3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                         (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                       + 
+--R                               2 4       2 3  4 2          4 5     2 4 6
+--R                         (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                    /
+--R                             5 7         4 2 6        3 4 5       2 6 4
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                     3           2    2 3
+--R                a b e  - 3a c d e  + c d
+--R           /
+--R                  2 3        2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                             5 5         4 2 4        3 4 3       2 6 2  2
+--R                      (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                    + 
+--R                               4 6         3 2 5        2 4 4         6 3  2
+--R                      (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                 *
+--R                    ROOT
+--R                                4 2     3 2     2 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                                 3   2     2 3     5       3 3      2 2 2  2 4
+--R                           (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                               2   3       3 2  3 3         2 4       2 3  4 2
+--R                           (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                         + 
+--R                                  4 5     2 4 6
+--R                           12a b c d e - b c d
+--R                      /
+--R                               5 7         4 2 6        3 4 5       2 6 4
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                        4   2      3 3      2 5  5
+--R                  (- 72a b c  + 54a b c - 9a b )e
+--R                + 
+--R                       4 3       3 2 2      2 4     4
+--R                  (288a c  - 324a b c  + 63a b c)d e
+--R                + 
+--R                       3   3       2 3 2       5   2 3
+--R                  (576a b c  - 108a b c  - 9a b c)d e
+--R                + 
+--R                         3 4      2 2 3        4 2  3 2
+--R                  (- 864a c  + 72a b c  + 36a b c )d e
+--R                + 
+--R                       2   4        3 3  4            2 4     4 3  5
+--R                  (360a b c  - 90a b c )d e + (- 36a b c  + 9b c )d
+--R             *
+--R                  ROOT
+--R                                2 3        2 2
+--R                           (108a c  - 27a b c )
+--R                        *
+--R                           ROOT
+--R                                       4 2     3 2     2 4  6
+--R                                  (- 4a c  + 4a b c - a b )e
+--R                                + 
+--R                                        3   2     2 3     5
+--R                                  (- 12a b c  + 6a b c)d e
+--R                                + 
+--R                                      3 3      2 2 2  2 4
+--R                                  (24a c  - 21a b c )d e
+--R                                + 
+--R                                      2   3       3 2  3 3
+--R                                  (32a b c  + 2a b c )d e
+--R                                + 
+--R                                      2 4       2 3  4 2          4 5     2 4 6
+--R                                (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                             /
+--R                                      5 7         4 2 6        3 4 5       2 6 4
+--R                                46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                       + 
+--R                              3           2    2 3
+--R                         a b e  - 3a c d e  + c d
+--R                    /
+--R                           2 3        2 2
+--R                       216a c  - 54a b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                     4      3 2  7        3        2 3    6
+--R                  (4a c - 2a b )e  + (- 2a b c + 4a b )d e
+--R                + 
+--R                       3 2      2 2        4  2 5       2   2        3   3 4
+--R                  (- 4a c  - 12a b c - 2a b )d e  + (30a b c  + 10a b c)d e
+--R                + 
+--R                        2 3        2 2  4 3           3     3 2  5 2
+--R                  (- 20a c  - 30a b c )d e  + (34a b c  + 2b c )d e
+--R                + 
+--R                          4     2 3  6        4 7
+--R                  (- 12a c  - 4b c )d e + 2b c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                           +--------------------+
+--R                       +-----------+       |   +-----------+
+--R             3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R            3\|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            2 3        2 2
+--R                     (- 108a c  + 27a b c )
+--R                  *
+--R                     ROOT
+--R                                 4 2     3 2     2 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                  3   2     2 3     5       3 3      2 2 2  2 4
+--R                            (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                2   3       3 2  3 3         2 4       2 3  4 2
+--R                            (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                          + 
+--R                                   4 5     2 4 6
+--R                            12a b c d e - b c d
+--R                       /
+--R                                5 7         4 2 6        3 4 5       2 6 4
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                        3           2    2 3
+--R                   a b e  - 3a c d e  + c d
+--R              /
+--R                     2 3        2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                5 5         4 2 4        3 4 3       2 6 2  2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                       + 
+--R                                  4 6         3 2 5        2 4 4         6 3  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                             4   2      3 3      2 5  5
+--R                         (72a b c  - 54a b c + 9a b )e
+--R                       + 
+--R                                4 3       3 2 2      2 4     4
+--R                         (- 288a c  + 324a b c  - 63a b c)d e
+--R                       + 
+--R                                3   3       2 3 2       5   2 3
+--R                         (- 576a b c  + 108a b c  + 9a b c)d e
+--R                       + 
+--R                              3 4      2 2 3        4 2  3 2
+--R                         (864a c  - 72a b c  - 36a b c )d e
+--R                       + 
+--R                                2   4        3 3  4          2 4     4 3  5
+--R                         (- 360a b c  + 90a b c )d e + (36a b c  - 9b c )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                     2 3        2 2
+--R                              (- 108a c  + 27a b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2     3 2     2 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                           3   2     2 3     5
+--R                                     (- 12a b c  + 6a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 4
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                         2   3       3 2  3 3
+--R                                     (32a b c  + 2a b c )d e
+--R                                   + 
+--R                                           2 4       2 3  4 2          4 5
+--R                                     (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                   + 
+--R                                        2 4 6
+--R                                     - b c d
+--R                                /
+--R                                           5 7         4 2 6        3 4 5
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           2 6 4
+--R                                     - 729a b c
+--R                          + 
+--R                                 3           2    2 3
+--R                            a b e  - 3a c d e  + c d
+--R                       /
+--R                              2 3        2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               5 4        4 2 3       3 4 2  3
+--R                         (2592a c  - 1296a b c  + 162a b c )e
+--R                       + 
+--R                                 4   4        3 3 3       2 5 2    2
+--R                         (- 3888a b c  + 1944a b c  - 243a b c )d e
+--R                       + 
+--R                               4 5       2 4 3        6 2  2
+--R                         (2592a c  - 486a b c  + 81a b c )d e
+--R                       + 
+--R                                 3   5       2 3 4        5 3  3
+--R                         (- 1296a b c  + 648a b c  - 81a b c )d
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                           4 2      3 2      2 4    5
+--R                     (- 24a c  + 18a b c - 3a b )d e
+--R                   + 
+--R                           3   2     2 3        5  2 4
+--R                     (- 12a b c  - 9a b c + 3a b )d e
+--R                   + 
+--R                         3 3      2 2 2        4   3 3
+--R                     (48a c  + 36a b c  - 12a b c)d e
+--R                   + 
+--R                            2   3        3 2  4 2
+--R                     (- 120a b c  + 30a b c )d e
+--R                   + 
+--R                         2 4       2 3     4 2  5              4     3 3  6
+--R                     (72a c  - 6a b c  - 3b c )d e + (- 12a b c  + 3b c )d
+--R                *
+--R                   ROOT
+--R                                   2 3        2 2
+--R                            (- 108a c  + 27a b c )
+--R                         *
+--R                            ROOT
+--R                                        4 2     3 2     2 4  6
+--R                                   (- 4a c  + 4a b c - a b )e
+--R                                 + 
+--R                                         3   2     2 3     5
+--R                                   (- 12a b c  + 6a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 4
+--R                                   (24a c  - 21a b c )d e
+--R                                 + 
+--R                                       2   3       3 2  3 3
+--R                                   (32a b c  + 2a b c )d e
+--R                                 + 
+--R                                       2 4       2 3  4 2          4 5     2 4 6
+--R                                 (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                              /
+--R                                         5 7         4 2 6        3 4 5
+--R                                   46656a c  - 34992a b c  + 8748a b c
+--R                                 + 
+--R                                         2 6 4
+--R                                   - 729a b c
+--R                        + 
+--R                               3           2    2 3
+--R                          a b e  - 3a c d e  + c d
+--R                     /
+--R                            2 3        2 2
+--R                        216a c  - 54a b c
+--R                  ,
+--R                      3
+--R               + 
+--R                        4      3 2  7        3        2 3    6
+--R                     (4a c - 2a b )e  + (- 2a b c + 4a b )d e
+--R                   + 
+--R                          3 2      2 2        4  2 5       2   2        3   3 4
+--R                     (- 4a c  - 12a b c - 2a b )d e  + (30a b c  + 10a b c)d e
+--R                   + 
+--R                           2 3        2 2  4 3           3     3 2  5 2
+--R                     (- 20a c  - 30a b c )d e  + (34a b c  + 2b c )d e
+--R                   + 
+--R                             4     2 3  6        4 7
+--R                     (- 12a c  - 4b c )d e + 2b c d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                                                    +------------------+
+--R                  +-----------+                     | +-----------+
+--R              +-+ |          2                 +-+ 3| |          2
+--R         (- e\|3 \|- 4a c + b   + (b e - 2c d)\|3 )\|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                      +------------------+
+--R                 +-----------+                        | +-----------+
+--R             +-+ |          2                    +-+ 3| |          2
+--R         (2e\|3 \|- 4a c + b   + (- 2b e + 4c d)\|3 )\|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                        +--------------------+
+--R                    +-----------+       |   +-----------+
+--R          3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R         6\|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         2 3        2 2
+--R                  (- 108a c  + 27a b c )
+--R               *
+--R                  ROOT
+--R                              4 2     3 2     2 4  6         3   2     2 3     5
+--R                         (- 4a c  + 4a b c - a b )e  + (- 12a b c  + 6a b c)d e
+--R                       + 
+--R                             3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                         (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                       + 
+--R                               2 4       2 3  4 2          4 5     2 4 6
+--R                         (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                    /
+--R                             5 7         4 2 6        3 4 5       2 6 4
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                     3           2    2 3
+--R                a b e  - 3a c d e  + c d
+--R           /
+--R                  2 3        2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               5 5         4 2 4        3 4 3       2 6 2  2
+--R                      (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )e
+--R                    + 
+--R                             4 6         3 2 5        2 4 4         6 3  2
+--R                      (15552a c  - 11664a b c  + 2916a b c  - 243a b c )d
+--R                 *
+--R                    ROOT
+--R                                4 2     3 2     2 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                                 3   2     2 3     5       3 3      2 2 2  2 4
+--R                           (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                               2   3       3 2  3 3         2 4       2 3  4 2
+--R                           (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                         + 
+--R                                  4 5     2 4 6
+--R                           12a b c d e - b c d
+--R                      /
+--R                               5 7         4 2 6        3 4 5       2 6 4
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                        4   2      3 3      2 5  5
+--R                  (- 72a b c  + 54a b c - 9a b )e
+--R                + 
+--R                       4 3       3 2 2      2 4     4
+--R                  (288a c  - 324a b c  + 63a b c)d e
+--R                + 
+--R                       3   3       2 3 2       5   2 3
+--R                  (576a b c  - 108a b c  - 9a b c)d e
+--R                + 
+--R                         3 4      2 2 3        4 2  3 2
+--R                  (- 864a c  + 72a b c  + 36a b c )d e
+--R                + 
+--R                       2   4        3 3  4            2 4     4 3  5
+--R                  (360a b c  - 90a b c )d e + (- 36a b c  + 9b c )d
+--R             *
+--R                  ROOT
+--R                                  2 3        2 2
+--R                           (- 108a c  + 27a b c )
+--R                        *
+--R                           ROOT
+--R                                       4 2     3 2     2 4  6
+--R                                  (- 4a c  + 4a b c - a b )e
+--R                                + 
+--R                                        3   2     2 3     5
+--R                                  (- 12a b c  + 6a b c)d e
+--R                                + 
+--R                                      3 3      2 2 2  2 4
+--R                                  (24a c  - 21a b c )d e
+--R                                + 
+--R                                      2   3       3 2  3 3
+--R                                  (32a b c  + 2a b c )d e
+--R                                + 
+--R                                      2 4       2 3  4 2          4 5     2 4 6
+--R                                (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                             /
+--R                                      5 7         4 2 6        3 4 5       2 6 4
+--R                                46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                       + 
+--R                              3           2    2 3
+--R                         a b e  - 3a c d e  + c d
+--R                    /
+--R                           2 3        2 2
+--R                       216a c  - 54a b c
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                     4      3 2  7        3        2 3    6
+--R                  (4a c - 2a b )e  + (- 2a b c + 4a b )d e
+--R                + 
+--R                       3 2      2 2        4  2 5       2   2        3   3 4
+--R                  (- 4a c  - 12a b c - 2a b )d e  + (30a b c  + 10a b c)d e
+--R                + 
+--R                        2 3        2 2  4 3           3     3 2  5 2
+--R                  (- 20a c  - 30a b c )d e  + (34a b c  + 2b c )d e
+--R                + 
+--R                          4     2 3  6        4 7
+--R                  (- 12a c  - 4b c )d e + 2b c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                           +--------------------+
+--R                       +-----------+       |   +-----------+
+--R             3+-+2 +-+ |          2 3+-+2 3|   |          2
+--R            3\|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          2 3        2 2
+--R                     (108a c  - 27a b c )
+--R                  *
+--R                     ROOT
+--R                                 4 2     3 2     2 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                  3   2     2 3     5       3 3      2 2 2  2 4
+--R                            (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                2   3       3 2  3 3         2 4       2 3  4 2
+--R                            (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                          + 
+--R                                   4 5     2 4 6
+--R                            12a b c d e - b c d
+--R                       /
+--R                                5 7         4 2 6        3 4 5       2 6 4
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                        3           2    2 3
+--R                   a b e  - 3a c d e  + c d
+--R              /
+--R                     2 3        2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                  5 5         4 2 4        3 4 3       2 6 2  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )e
+--R                       + 
+--R                                4 6         3 2 5        2 4 4         6 3  2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                             4   2      3 3      2 5  5
+--R                         (72a b c  - 54a b c + 9a b )e
+--R                       + 
+--R                                4 3       3 2 2      2 4     4
+--R                         (- 288a c  + 324a b c  - 63a b c)d e
+--R                       + 
+--R                                3   3       2 3 2       5   2 3
+--R                         (- 576a b c  + 108a b c  + 9a b c)d e
+--R                       + 
+--R                              3 4      2 2 3        4 2  3 2
+--R                         (864a c  - 72a b c  - 36a b c )d e
+--R                       + 
+--R                                2   4        3 3  4          2 4     4 3  5
+--R                         (- 360a b c  + 90a b c )d e + (36a b c  - 9b c )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                   2 3        2 2
+--R                              (108a c  - 27a b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2     3 2     2 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                           3   2     2 3     5
+--R                                     (- 12a b c  + 6a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 4
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                         2   3       3 2  3 3
+--R                                     (32a b c  + 2a b c )d e
+--R                                   + 
+--R                                           2 4       2 3  4 2          4 5
+--R                                     (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                   + 
+--R                                        2 4 6
+--R                                     - b c d
+--R                                /
+--R                                           5 7         4 2 6        3 4 5
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           2 6 4
+--R                                     - 729a b c
+--R                          + 
+--R                                 3           2    2 3
+--R                            a b e  - 3a c d e  + c d
+--R                       /
+--R                              2 3        2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 5 4        4 2 3       3 4 2  3
+--R                         (- 2592a c  + 1296a b c  - 162a b c )e
+--R                       + 
+--R                               4   4        3 3 3       2 5 2    2
+--R                         (3888a b c  - 1944a b c  + 243a b c )d e
+--R                       + 
+--R                                 4 5       2 4 3        6 2  2
+--R                         (- 2592a c  + 486a b c  - 81a b c )d e
+--R                       + 
+--R                               3   5       2 3 4        5 3  3
+--R                         (1296a b c  - 648a b c  + 81a b c )d
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                           4 2      3 2      2 4    5
+--R                     (- 24a c  + 18a b c - 3a b )d e
+--R                   + 
+--R                           3   2     2 3        5  2 4
+--R                     (- 12a b c  - 9a b c + 3a b )d e
+--R                   + 
+--R                         3 3      2 2 2        4   3 3
+--R                     (48a c  + 36a b c  - 12a b c)d e
+--R                   + 
+--R                            2   3        3 2  4 2
+--R                     (- 120a b c  + 30a b c )d e
+--R                   + 
+--R                         2 4       2 3     4 2  5              4     3 3  6
+--R                     (72a c  - 6a b c  - 3b c )d e + (- 12a b c  + 3b c )d
+--R                *
+--R                   ROOT
+--R                                 2 3        2 2
+--R                            (108a c  - 27a b c )
+--R                         *
+--R                            ROOT
+--R                                        4 2     3 2     2 4  6
+--R                                   (- 4a c  + 4a b c - a b )e
+--R                                 + 
+--R                                         3   2     2 3     5
+--R                                   (- 12a b c  + 6a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 4
+--R                                   (24a c  - 21a b c )d e
+--R                                 + 
+--R                                       2   3       3 2  3 3
+--R                                   (32a b c  + 2a b c )d e
+--R                                 + 
+--R                                       2 4       2 3  4 2          4 5     2 4 6
+--R                                 (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                              /
+--R                                         5 7         4 2 6        3 4 5
+--R                                   46656a c  - 34992a b c  + 8748a b c
+--R                                 + 
+--R                                         2 6 4
+--R                                   - 729a b c
+--R                        + 
+--R                               3           2    2 3
+--R                          a b e  - 3a c d e  + c d
+--R                     /
+--R                            2 3        2 2
+--R                        216a c  - 54a b c
+--R                  ,
+--R                      3
+--R               + 
+--R                        4      3 2  7        3        2 3    6
+--R                     (4a c - 2a b )e  + (- 2a b c + 4a b )d e
+--R                   + 
+--R                          3 2      2 2        4  2 5       2   2        3   3 4
+--R                     (- 4a c  - 12a b c - 2a b )d e  + (30a b c  + 10a b c)d e
+--R                   + 
+--R                           2 3        2 2  4 3           3     3 2  5 2
+--R                     (- 20a c  - 30a b c )d e  + (34a b c  + 2b c )d e
+--R                   + 
+--R                             4     2 3  6        4 7
+--R                     (- 12a c  - 4b c )d e + 2b c d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R       -
+--R                                        +--------------------+
+--R                    +-----------+       |   +-----------+
+--R              3+-+2 |          2 3+-+2 3|   |          2
+--R            18\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          2 3        2 2
+--R                     (108a c  - 27a b c )
+--R                  *
+--R                     ROOT
+--R                                 4 2     3 2     2 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                  3   2     2 3     5       3 3      2 2 2  2 4
+--R                            (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                2   3       3 2  3 3         2 4       2 3  4 2
+--R                            (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                          + 
+--R                                   4 5     2 4 6
+--R                            12a b c d e - b c d
+--R                       /
+--R                                5 7         4 2 6        3 4 5       2 6 4
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                        3           2    2 3
+--R                   a b e  - 3a c d e  + c d
+--R              /
+--R                     2 3        2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            atan
+--R                                5 5         4 2 4        3 4 3       2 6 2  2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                       + 
+--R                                  4 6         3 2 5        2 4 4         6 3  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                               4   2      3 3      2 5  5
+--R                         (- 72a b c  + 54a b c - 9a b )e
+--R                       + 
+--R                              4 3       3 2 2      2 4     4
+--R                         (288a c  - 324a b c  + 63a b c)d e
+--R                       + 
+--R                              3   3       2 3 2       5   2 3
+--R                         (576a b c  - 108a b c  - 9a b c)d e
+--R                       + 
+--R                                3 4      2 2 3        4 2  3 2
+--R                         (- 864a c  + 72a b c  + 36a b c )d e
+--R                       + 
+--R                              2   4        3 3  4            2 4     4 3  5
+--R                         (360a b c  - 90a b c )d e + (- 36a b c  + 9b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                   2 3        2 2
+--R                              (108a c  - 27a b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2     3 2     2 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                           3   2     2 3     5
+--R                                     (- 12a b c  + 6a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 4
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                         2   3       3 2  3 3
+--R                                     (32a b c  + 2a b c )d e
+--R                                   + 
+--R                                           2 4       2 3  4 2          4 5
+--R                                     (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                   + 
+--R                                        2 4 6
+--R                                     - b c d
+--R                                /
+--R                                           5 7         4 2 6        3 4 5
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           2 6 4
+--R                                     - 729a b c
+--R                          + 
+--R                                 3           2    2 3
+--R                            a b e  - 3a c d e  + c d
+--R                       /
+--R                              2 3        2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                  5 5         4 2 4        3 4 3       2 6 2  2
+--R                           (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                         + 
+--R                                  4 6         3 2 5        2 4 4         6 3  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                      *
+--R                         ROOT
+--R                                     4 2     3 2     2 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                      3   2     2 3     5
+--R                                (- 12a b c  + 6a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 4
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                    2   3       3 2  3 3
+--R                                (32a b c  + 2a b c )d e
+--R                              + 
+--R                                      2 4       2 3  4 2          4 5     2 4 6
+--R                                (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                           /
+--R                                    5 7         4 2 6        3 4 5       2 6 4
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                             4   2      3 3      2 5  5
+--R                       (- 72a b c  + 54a b c - 9a b )e
+--R                     + 
+--R                            4 3       3 2 2      2 4     4
+--R                       (288a c  - 324a b c  + 63a b c)d e
+--R                     + 
+--R                            3   3       2 3 2       5   2 3
+--R                       (576a b c  - 108a b c  - 9a b c)d e
+--R                     + 
+--R                              3 4      2 2 3        4 2  3 2
+--R                       (- 864a c  + 72a b c  + 36a b c )d e
+--R                     + 
+--R                            2   4        3 3  4            2 4     4 3  5
+--R                       (360a b c  - 90a b c )d e + (- 36a b c  + 9b c )d
+--R                  *
+--R                       ROOT
+--R                                     2 3        2 2
+--R                                (108a c  - 27a b c )
+--R                             *
+--R                                ROOT
+--R                                            4 2     3 2     2 4  6
+--R                                       (- 4a c  + 4a b c - a b )e
+--R                                     + 
+--R                                             3   2     2 3     5
+--R                                       (- 12a b c  + 6a b c)d e
+--R                                     + 
+--R                                           3 3      2 2 2  2 4
+--R                                       (24a c  - 21a b c )d e
+--R                                     + 
+--R                                           2   3       3 2  3 3
+--R                                       (32a b c  + 2a b c )d e
+--R                                     + 
+--R                                             2 4       2 3  4 2          4 5
+--R                                       (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                     + 
+--R                                          2 4 6
+--R                                       - b c d
+--R                                  /
+--R                                             5 7         4 2 6        3 4 5
+--R                                       46656a c  - 34992a b c  + 8748a b c
+--R                                     + 
+--R                                             2 6 4
+--R                                       - 729a b c
+--R                            + 
+--R                                   3           2    2 3
+--R                              a b e  - 3a c d e  + c d
+--R                         /
+--R                                2 3        2 2
+--R                            216a c  - 54a b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                            4      3 2  7      3        2 3    6
+--R                       (- 8a c + 4a b )e  + (4a b c - 8a b )d e
+--R                     + 
+--R                          3 2      2 2        4  2 5
+--R                       (8a c  + 24a b c + 4a b )d e
+--R                     + 
+--R                             2   2        3   3 4       2 3        2 2  4 3
+--R                       (- 60a b c  - 20a b c)d e  + (40a c  + 60a b c )d e
+--R                     + 
+--R                                 3     3 2  5 2         4     2 3  6        4 7
+--R                       (- 68a b c  - 4b c )d e  + (24a c  + 8b c )d e - 4b c d
+--R                  *
+--R                     x
+--R     + 
+--R       -
+--R                                        +--------------------+
+--R                    +-----------+       |   +-----------+
+--R              3+-+2 |          2 3+-+2 3|   |          2
+--R            18\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            2 3        2 2
+--R                     (- 108a c  + 27a b c )
+--R                  *
+--R                     ROOT
+--R                                 4 2     3 2     2 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                  3   2     2 3     5       3 3      2 2 2  2 4
+--R                            (- 12a b c  + 6a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                2   3       3 2  3 3         2 4       2 3  4 2
+--R                            (32a b c  + 2a b c )d e  + (- 36a c  - 6a b c )d e
+--R                          + 
+--R                                   4 5     2 4 6
+--R                            12a b c d e - b c d
+--R                       /
+--R                                5 7         4 2 6        3 4 5       2 6 4
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                        3           2    2 3
+--R                   a b e  - 3a c d e  + c d
+--R              /
+--R                     2 3        2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            atan
+--R                                5 5         4 2 4        3 4 3       2 6 2  2
+--R                         (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                       + 
+--R                                  4 6         3 2 5        2 4 4         6 3  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                   4 2     3 2     2 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                    3   2     2 3     5
+--R                              (- 12a b c  + 6a b c)d e
+--R                            + 
+--R                                  3 3      2 2 2  2 4       2   3       3 2  3 3
+--R                              (24a c  - 21a b c )d e  + (32a b c  + 2a b c )d e
+--R                            + 
+--R                                    2 4       2 3  4 2          4 5     2 4 6
+--R                              (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                         /
+--R                                  5 7         4 2 6        3 4 5       2 6 4
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                             4   2      3 3      2 5  5
+--R                         (72a b c  - 54a b c + 9a b )e
+--R                       + 
+--R                                4 3       3 2 2      2 4     4
+--R                         (- 288a c  + 324a b c  - 63a b c)d e
+--R                       + 
+--R                                3   3       2 3 2       5   2 3
+--R                         (- 576a b c  + 108a b c  + 9a b c)d e
+--R                       + 
+--R                              3 4      2 2 3        4 2  3 2
+--R                         (864a c  - 72a b c  - 36a b c )d e
+--R                       + 
+--R                                2   4        3 3  4          2 4     4 3  5
+--R                         (- 360a b c  + 90a b c )d e + (36a b c  - 9b c )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                     2 3        2 2
+--R                              (- 108a c  + 27a b c )
+--R                           *
+--R                              ROOT
+--R                                          4 2     3 2     2 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                           3   2     2 3     5
+--R                                     (- 12a b c  + 6a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 4
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                         2   3       3 2  3 3
+--R                                     (32a b c  + 2a b c )d e
+--R                                   + 
+--R                                           2 4       2 3  4 2          4 5
+--R                                     (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                   + 
+--R                                        2 4 6
+--R                                     - b c d
+--R                                /
+--R                                           5 7         4 2 6        3 4 5
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           2 6 4
+--R                                     - 729a b c
+--R                          + 
+--R                                 3           2    2 3
+--R                            a b e  - 3a c d e  + c d
+--R                       /
+--R                              2 3        2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                  5 5         4 2 4        3 4 3       2 6 2  2
+--R                           (15552a c  - 11664a b c  + 2916a b c  - 243a b c )e
+--R                         + 
+--R                                  4 6         3 2 5        2 4 4         6 3  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c  + 243a b c )d
+--R                      *
+--R                         ROOT
+--R                                     4 2     3 2     2 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                      3   2     2 3     5
+--R                                (- 12a b c  + 6a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 4
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                    2   3       3 2  3 3
+--R                                (32a b c  + 2a b c )d e
+--R                              + 
+--R                                      2 4       2 3  4 2          4 5     2 4 6
+--R                                (- 36a c  - 6a b c )d e  + 12a b c d e - b c d
+--R                           /
+--R                                    5 7         4 2 6        3 4 5       2 6 4
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                           4   2      3 3      2 5  5
+--R                       (72a b c  - 54a b c + 9a b )e
+--R                     + 
+--R                              4 3       3 2 2      2 4     4
+--R                       (- 288a c  + 324a b c  - 63a b c)d e
+--R                     + 
+--R                              3   3       2 3 2       5   2 3
+--R                       (- 576a b c  + 108a b c  + 9a b c)d e
+--R                     + 
+--R                            3 4      2 2 3        4 2  3 2
+--R                       (864a c  - 72a b c  - 36a b c )d e
+--R                     + 
+--R                              2   4        3 3  4          2 4     4 3  5
+--R                       (- 360a b c  + 90a b c )d e + (36a b c  - 9b c )d
+--R                  *
+--R                       ROOT
+--R                                       2 3        2 2
+--R                                (- 108a c  + 27a b c )
+--R                             *
+--R                                ROOT
+--R                                            4 2     3 2     2 4  6
+--R                                       (- 4a c  + 4a b c - a b )e
+--R                                     + 
+--R                                             3   2     2 3     5
+--R                                       (- 12a b c  + 6a b c)d e
+--R                                     + 
+--R                                           3 3      2 2 2  2 4
+--R                                       (24a c  - 21a b c )d e
+--R                                     + 
+--R                                           2   3       3 2  3 3
+--R                                       (32a b c  + 2a b c )d e
+--R                                     + 
+--R                                             2 4       2 3  4 2          4 5
+--R                                       (- 36a c  - 6a b c )d e  + 12a b c d e
+--R                                     + 
+--R                                          2 4 6
+--R                                       - b c d
+--R                                  /
+--R                                             5 7         4 2 6        3 4 5
+--R                                       46656a c  - 34992a b c  + 8748a b c
+--R                                     + 
+--R                                             2 6 4
+--R                                       - 729a b c
+--R                            + 
+--R                                   3           2    2 3
+--R                              a b e  - 3a c d e  + c d
+--R                         /
+--R                                2 3        2 2
+--R                            216a c  - 54a b c
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                          4      3 2  7        3        2 3    6
+--R                       (8a c - 4a b )e  + (- 4a b c + 8a b )d e
+--R                     + 
+--R                            3 2      2 2        4  2 5
+--R                       (- 8a c  - 24a b c - 4a b )d e
+--R                     + 
+--R                           2   2        3   3 4         2 3        2 2  4 3
+--R                       (60a b c  + 20a b c)d e  + (- 40a c  - 60a b c )d e
+--R                     + 
+--R                               3     3 2  5 2           4     2 3  6        4 7
+--R                       (68a b c  + 4b c )d e  + (- 24a c  - 8b c )d e + 4b c d
+--R                  *
+--R                     x
+--R     + 
+--R                                           +--------------------+
+--R             +-----------+                 |   +-----------+
+--R             |          2                 3|   |          2
+--R         (6e\|- 4a c + b   + 6b e - 12c d)\|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                           +------------------+
+--R             +-----------+                 | +-----------+
+--R             |          2                 3| |          2
+--R         (6e\|- 4a c + b   - 6b e + 12c d)\|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                                    +--------------------+ +------------------+
+--R                +-----------+       |   +-----------+      | +-----------+
+--R      3+-+2 +-+ |          2 3+-+2 3|   |          2      3| |          2
+--R     6\|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 22
+
+)clear all
+
+--S 23 of 649
+t0:=(d+e*x^3)/(a+b*x^3+c*x^6)
+--R 
+--R
+--R               3
+--R            e x  + d
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 23
+
+--S 24 of 649
+r0:=1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(e+(2*c*d-b*e)/_
+   sqrt(b^2-4*a*c))/(2^(1/3)*c^(1/3)*(b-sqrt(b^2-4*a*c))^(2/3))-_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-_
+   4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(e+(2*c*d-b*e)/sqrt(b^2-_
+   4*a*c))/(2^(1/3)*c^(1/3)*(b-sqrt(b^2-4*a*c))^(2/3))-_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*c^(1/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(2/3))+1/3*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*c^(1/3)*(b+sqrt(b^2-4*a*c))^(2/3))-1/6*log(2^(2/3)*c^(2/3)*_
+   x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-_
+   4*a*c))^(2/3))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(1/3)*_
+   (b+sqrt(b^2-4*a*c))^(2/3))-atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(1/3)*sqrt(3)*_
+   (b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                                                      +--------------------+2
+--R                  +-----------+                       |   +-----------+
+--R              +-+ |          2                   +-+ 3|   |          2
+--R         (- e\|3 \|- 4a c + b   + (- b e + 2c d)\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                    +--------------------+2
+--R                 +-----------+                      |   +-----------+
+--R             +-+ |          2                  +-+ 3|   |          2
+--R         (2e\|3 \|- 4a c + b   + (2b e - 4c d)\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                    +------------------+2
+--R                  +-----------+                     | +-----------+
+--R              +-+ |          2                 +-+ 3| |          2
+--R         (- e\|3 \|- 4a c + b   + (b e - 2c d)\|3 )\|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                      +------------------+2
+--R                 +-----------+                        | +-----------+
+--R             +-+ |          2                    +-+ 3| |          2
+--R         (2e\|3 \|- 4a c + b   + (- 2b e + 4c d)\|3 )\|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                             +--------------------+2
+--R               +-----------+                 |   +-----------+
+--R               |          2                 3|   |          2
+--R         (- 6e\|- 4a c + b   - 6b e + 12c d)\|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                             +------------------+2
+--R               +-----------+                 | +-----------+
+--R               |          2                 3| |          2
+--R         (- 6e\|- 4a c + b   + 6b e - 12c d)\|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                                 +--------------------+2  +------------------+2
+--R               +-----------+     |   +-----------+        | +-----------+
+--R      3+-+ +-+ |          2 3+-+3|   |          2        3| |          2
+--R     6\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                          3 2      2 2
+--R                     (108a c  - 27a b c)
+--R                  *
+--R                     ROOT
+--R                               4 2 6      4       5         4 2     3 2   2 4
+--R                            - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                          + 
+--R                                3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                            (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                  2   3       3 2  5
+--R                            (- 12a b c  + 6a b c )d e
+--R                          + 
+--R                                 2 4       2 3    4 2  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                7 5         6 2 4        5 4 3       4 6 2
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                      2 3         2         3
+--R                   - a e  + 3a c d e - b c d
+--R              /
+--R                     3 2      2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                6 4         5 2 3        4 4 2       3 6
+--R                         (31104a c  - 23328a b c  + 5832a b c  - 486a b c)d e
+--R                       + 
+--R                                5   4         4 3 3        3 5 2       2 7   2
+--R                       (- 15552a b c  + 11664a b c  - 2916a b c  + 243a b c)d
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4       5         4 2     3 2   2 4
+--R                              - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                            + 
+--R                                  3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                              (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                            + 
+--R                                    2   3       3 2  5
+--R                              (- 12a b c  + 6a b c )d e
+--R                            + 
+--R                                   2 4       2 3    4 2  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  7 5         6 2 4        5 4 3       4 6 2
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                           5         4 3  5        5 2      4 2       3 4    4
+--R                     (- 72a b c + 18a b )e  + (432a c  - 36a b c - 18a b )d e
+--R                   + 
+--R                            4   2       3 3      2 5  2 3
+--R                     (- 576a b c  + 108a b c + 9a b )d e
+--R                   + 
+--R                            4 3       3 2 2       2 4   3 2
+--R                     (- 576a c  + 648a b c  - 126a b c)d e
+--R                   + 
+--R                          3   3       2 3 2        5   4
+--R                     (360a b c  - 270a b c  + 45a b c)d e
+--R                   + 
+--R                          3 4       2 2 3        4 2     6   5
+--R                     (144a c  - 180a b c  + 72a b c  - 9b c)d
+--R                *
+--R                     ROOT
+--R                                   3 2      2 2
+--R                              (108a c  - 27a b c)
+--R                           *
+--R                              ROOT
+--R                                        4 2 6      4       5
+--R                                     - a b e  + 12a b c d e
+--R                                   + 
+--R                                           4 2     3 2   2 4
+--R                                     (- 36a c  - 6a b c)d e
+--R                                   + 
+--R                                         3   2     2 3   3 3
+--R                                     (32a b c  + 2a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  4 2
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                           2   3       3 2  5
+--R                                     (- 12a b c  + 6a b c )d e
+--R                                   + 
+--R                                          2 4       2 3    4 2  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           7 5         6 2 4        5 4 3
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           4 6 2
+--R                                     - 729a b c
+--R                          + 
+--R                               2 3         2         3
+--R                            - a e  + 3a c d e - b c d
+--R                       /
+--R                              3 2      2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 6 3        5 2 2       4 4   3
+--R                         (- 2592a c  + 1296a b c  - 162a b c)e
+--R                       + 
+--R                               5   3        4 3 2       3 5     2
+--R                         (3888a b c  - 1944a b c  + 243a b c)d e
+--R                       + 
+--R                                 5 4       3 4 2      2 6   2
+--R                         (- 2592a c  + 486a b c  - 81a b c)d e
+--R                       + 
+--R                               4   4       3 3 3      2 5 2  3
+--R                         (1296a b c  - 648a b c  + 81a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4       5         4 2     3 2   2 4
+--R                              - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                            + 
+--R                                  3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                              (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                            + 
+--R                                    2   3       3 2  5
+--R                              (- 12a b c  + 6a b c )d e
+--R                            + 
+--R                                   2 4       2 3    4 2  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  7 5         6 2 4        5 4 3       4 6 2
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                               4        3 3    5       4 2     3 2      2 4  2 4
+--R                         (- 12a b c + 3a b )d e  + (72a c  - 6a b c - 3a b )d e
+--R                       + 
+--R                                3   2      2 3   3 3
+--R                         (- 120a b c  + 30a b c)d e
+--R                       + 
+--R                             3 3      2 2 2        4   4 2
+--R                         (48a c  + 36a b c  - 12a b c)d e
+--R                       + 
+--R                               2   3       3 2     5   5
+--R                         (- 12a b c  - 9a b c  + 3b c)d e
+--R                       + 
+--R                               2 4        2 3     4 2  6
+--R                         (- 24a c  + 18a b c  - 3b c )d
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                 3 2      2 2
+--R                            (108a c  - 27a b c)
+--R                         *
+--R                            ROOT
+--R                                      4 2 6      4       5
+--R                                   - a b e  + 12a b c d e
+--R                                 + 
+--R                                         4 2     3 2   2 4
+--R                                   (- 36a c  - 6a b c)d e
+--R                                 + 
+--R                                       3   2     2 3   3 3
+--R                                   (32a b c  + 2a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  4 2
+--R                                   (24a c  - 21a b c )d e
+--R                                 + 
+--R                                         2   3       3 2  5
+--R                                   (- 12a b c  + 6a b c )d e
+--R                                 + 
+--R                                        2 4       2 3    4 2  6
+--R                                   (- 4a c  + 4a b c  - b c )d
+--R                              /
+--R                                         7 5         6 2 4        5 4 3
+--R                                   46656a c  - 34992a b c  + 8748a b c
+--R                                 + 
+--R                                         4 6 2
+--R                                   - 729a b c
+--R                        + 
+--R                             2 3         2         3
+--R                          - a e  + 3a c d e - b c d
+--R                     /
+--R                            3 2      2 2
+--R                        216a c  - 54a b c
+--R                  ,
+--R                      3
+--R               + 
+--R                       4   7         4      3 2    6       3        2 3  2 5
+--R                     2a b e  + (- 12a c - 4a b )d e  + (34a b c + 2a b )d e
+--R                   + 
+--R                           3 2      2 2   3 4       2   2        3   4 3
+--R                     (- 20a c  - 30a b c)d e  + (30a b c  + 10a b c)d e
+--R                   + 
+--R                          2 3        2 2     4   5 2            3     3 2  6
+--R                     (- 4a c  - 12a b c  - 2b c)d e  + (- 2a b c  + 4b c )d e
+--R                   + 
+--R                          4     2 3  7
+--R                     (4a c  - 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                       3 2      2 2
+--R                  (108a c  - 27a b c)
+--R               *
+--R                  ROOT
+--R                            4 2 6      4       5         4 2     3 2   2 4
+--R                         - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                       + 
+--R                             3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                         (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                       + 
+--R                             2   3       3 2  5         2 4       2 3    4 2  6
+--R                       (- 12a b c  + 6a b c )d e + (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             7 5         6 2 4        5 4 3       4 6 2
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                   2 3         2         3
+--R                - a e  + 3a c d e - b c d
+--R           /
+--R                  3 2      2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                            5 3        4 2 2       3 4
+--R                      (2592a c  - 1296a b c  + 162a b c)e
+--R                    + 
+--R                              4   3       3 3 2      2 5
+--R                      (- 1296a b c  + 648a b c  - 81a b c)d
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4       5         4 2     3 2   2 4
+--R                           - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                         + 
+--R                               3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                           (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                                 2   3       3 2  5
+--R                           (- 12a b c  + 6a b c )d e
+--R                         + 
+--R                                2 4       2 3    4 2  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               7 5         6 2 4        5 4 3       4 6 2
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                      3        2 3    3         3 2      2 2   2 2
+--R                  (12a b c - 3a b )d e  + (- 72a c  + 18a b c)d e
+--R                + 
+--R                      2   2       3   3        2 3        2 2     4   4
+--R                  (36a b c  - 9a b c)d e + (24a c  - 18a b c  + 3b c)d
+--R             *
+--R                ROOT
+--R                              3 2      2 2
+--R                         (108a c  - 27a b c)
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4       5
+--R                                - a b e  + 12a b c d e
+--R                              + 
+--R                                      4 2     3 2   2 4
+--R                                (- 36a c  - 6a b c)d e
+--R                              + 
+--R                                    3   2     2 3   3 3
+--R                                (32a b c  + 2a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  4 2
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                      2   3       3 2  5
+--R                                (- 12a b c  + 6a b c )d e
+--R                              + 
+--R                                     2 4       2 3    4 2  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    7 5         6 2 4        5 4 3       4 6 2
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                          2 3         2         3
+--R                       - a e  + 3a c d e - b c d
+--R                  /
+--R                         3 2      2 2
+--R                     216a c  - 54a b c
+--R               ,
+--R                   3
+--R            + 
+--R                    3   5         3      2 2    4      2     2 3
+--R                  2a b e  + (- 12a c - 2a b )d e  + 20a b c d e
+--R                + 
+--R                     2 2       2   3 2          2     3   4         3     2 2  5
+--R                (- 8a c  - 8a b c)d e  + (2a b c  + 2b c)d e + (4a c  - 2b c )d
+--R             *
+--R                x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R                         3 2      2 2
+--R                  (- 108a c  + 27a b c)
+--R               *
+--R                  ROOT
+--R                            4 2 6      4       5         4 2     3 2   2 4
+--R                         - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                       + 
+--R                             3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                         (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                       + 
+--R                             2   3       3 2  5         2 4       2 3    4 2  6
+--R                       (- 12a b c  + 6a b c )d e + (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             7 5         6 2 4        5 4 3       4 6 2
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                   2 3         2         3
+--R                - a e  + 3a c d e - b c d
+--R           /
+--R                  3 2      2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                              5 3        4 2 2       3 4
+--R                      (- 2592a c  + 1296a b c  - 162a b c)e
+--R                    + 
+--R                            4   3       3 3 2      2 5
+--R                      (1296a b c  - 648a b c  + 81a b c)d
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4       5         4 2     3 2   2 4
+--R                           - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                         + 
+--R                               3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                           (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                                 2   3       3 2  5
+--R                           (- 12a b c  + 6a b c )d e
+--R                         + 
+--R                                2 4       2 3    4 2  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               7 5         6 2 4        5 4 3       4 6 2
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                      3        2 3    3         3 2      2 2   2 2
+--R                  (12a b c - 3a b )d e  + (- 72a c  + 18a b c)d e
+--R                + 
+--R                      2   2       3   3        2 3        2 2     4   4
+--R                  (36a b c  - 9a b c)d e + (24a c  - 18a b c  + 3b c)d
+--R             *
+--R                ROOT
+--R                                3 2      2 2
+--R                         (- 108a c  + 27a b c)
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4       5
+--R                                - a b e  + 12a b c d e
+--R                              + 
+--R                                      4 2     3 2   2 4
+--R                                (- 36a c  - 6a b c)d e
+--R                              + 
+--R                                    3   2     2 3   3 3
+--R                                (32a b c  + 2a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  4 2
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                      2   3       3 2  5
+--R                                (- 12a b c  + 6a b c )d e
+--R                              + 
+--R                                     2 4       2 3    4 2  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    7 5         6 2 4        5 4 3       4 6 2
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                          2 3         2         3
+--R                       - a e  + 3a c d e - b c d
+--R                  /
+--R                         3 2      2 2
+--R                     216a c  - 54a b c
+--R               ,
+--R                   3
+--R            + 
+--R                    3   5         3      2 2    4      2     2 3
+--R                  2a b e  + (- 12a c - 2a b )d e  + 20a b c d e
+--R                + 
+--R                     2 2       2   3 2          2     3   4         3     2 2  5
+--R                (- 8a c  - 8a b c)d e  + (2a b c  + 2b c)d e + (4a c  - 2b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            ROOT
+--R                            3 2      2 2
+--R                     (- 108a c  + 27a b c)
+--R                  *
+--R                     ROOT
+--R                               4 2 6      4       5         4 2     3 2   2 4
+--R                            - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                          + 
+--R                                3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                            (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                  2   3       3 2  5
+--R                            (- 12a b c  + 6a b c )d e
+--R                          + 
+--R                                 2 4       2 3    4 2  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                7 5         6 2 4        5 4 3       4 6 2
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                      2 3         2         3
+--R                   - a e  + 3a c d e - b c d
+--R              /
+--R                     3 2      2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                  6 4         5 2 3        4 4 2       3 6
+--R                         (- 31104a c  + 23328a b c  - 5832a b c  + 486a b c)d e
+--R                       + 
+--R                                5   4         4 3 3        3 5 2       2 7   2
+--R                         (15552a b c  - 11664a b c  + 2916a b c  - 243a b c)d
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4       5         4 2     3 2   2 4
+--R                              - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                            + 
+--R                                  3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                              (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                            + 
+--R                                    2   3       3 2  5
+--R                              (- 12a b c  + 6a b c )d e
+--R                            + 
+--R                                   2 4       2 3    4 2  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  7 5         6 2 4        5 4 3       4 6 2
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                           5         4 3  5        5 2      4 2       3 4    4
+--R                     (- 72a b c + 18a b )e  + (432a c  - 36a b c - 18a b )d e
+--R                   + 
+--R                            4   2       3 3      2 5  2 3
+--R                     (- 576a b c  + 108a b c + 9a b )d e
+--R                   + 
+--R                            4 3       3 2 2       2 4   3 2
+--R                     (- 576a c  + 648a b c  - 126a b c)d e
+--R                   + 
+--R                          3   3       2 3 2        5   4
+--R                     (360a b c  - 270a b c  + 45a b c)d e
+--R                   + 
+--R                          3 4       2 2 3        4 2     6   5
+--R                     (144a c  - 180a b c  + 72a b c  - 9b c)d
+--R                *
+--R                     ROOT
+--R                                     3 2      2 2
+--R                              (- 108a c  + 27a b c)
+--R                           *
+--R                              ROOT
+--R                                        4 2 6      4       5
+--R                                     - a b e  + 12a b c d e
+--R                                   + 
+--R                                           4 2     3 2   2 4
+--R                                     (- 36a c  - 6a b c)d e
+--R                                   + 
+--R                                         3   2     2 3   3 3
+--R                                     (32a b c  + 2a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  4 2
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                           2   3       3 2  5
+--R                                     (- 12a b c  + 6a b c )d e
+--R                                   + 
+--R                                          2 4       2 3    4 2  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           7 5         6 2 4        5 4 3
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           4 6 2
+--R                                     - 729a b c
+--R                          + 
+--R                               2 3         2         3
+--R                            - a e  + 3a c d e - b c d
+--R                       /
+--R                              3 2      2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               6 3        5 2 2       4 4   3
+--R                         (2592a c  - 1296a b c  + 162a b c)e
+--R                       + 
+--R                                 5   3        4 3 2       3 5     2
+--R                         (- 3888a b c  + 1944a b c  - 243a b c)d e
+--R                       + 
+--R                               5 4       3 4 2      2 6   2
+--R                         (2592a c  - 486a b c  + 81a b c)d e
+--R                       + 
+--R                                 4   4       3 3 3      2 5 2  3
+--R                         (- 1296a b c  + 648a b c  - 81a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4       5         4 2     3 2   2 4
+--R                              - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                            + 
+--R                                  3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                              (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                            + 
+--R                                    2   3       3 2  5
+--R                              (- 12a b c  + 6a b c )d e
+--R                            + 
+--R                                   2 4       2 3    4 2  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  7 5         6 2 4        5 4 3       4 6 2
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                               4        3 3    5       4 2     3 2      2 4  2 4
+--R                         (- 12a b c + 3a b )d e  + (72a c  - 6a b c - 3a b )d e
+--R                       + 
+--R                                3   2      2 3   3 3
+--R                         (- 120a b c  + 30a b c)d e
+--R                       + 
+--R                             3 3      2 2 2        4   4 2
+--R                         (48a c  + 36a b c  - 12a b c)d e
+--R                       + 
+--R                               2   3       3 2     5   5
+--R                         (- 12a b c  - 9a b c  + 3b c)d e
+--R                       + 
+--R                               2 4        2 3     4 2  6
+--R                         (- 24a c  + 18a b c  - 3b c )d
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                   3 2      2 2
+--R                            (- 108a c  + 27a b c)
+--R                         *
+--R                            ROOT
+--R                                      4 2 6      4       5
+--R                                   - a b e  + 12a b c d e
+--R                                 + 
+--R                                         4 2     3 2   2 4
+--R                                   (- 36a c  - 6a b c)d e
+--R                                 + 
+--R                                       3   2     2 3   3 3
+--R                                   (32a b c  + 2a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  4 2
+--R                                   (24a c  - 21a b c )d e
+--R                                 + 
+--R                                         2   3       3 2  5
+--R                                   (- 12a b c  + 6a b c )d e
+--R                                 + 
+--R                                        2 4       2 3    4 2  6
+--R                                   (- 4a c  + 4a b c  - b c )d
+--R                              /
+--R                                         7 5         6 2 4        5 4 3
+--R                                   46656a c  - 34992a b c  + 8748a b c
+--R                                 + 
+--R                                         4 6 2
+--R                                   - 729a b c
+--R                        + 
+--R                             2 3         2         3
+--R                          - a e  + 3a c d e - b c d
+--R                     /
+--R                            3 2      2 2
+--R                        216a c  - 54a b c
+--R                  ,
+--R                      3
+--R               + 
+--R                       4   7         4      3 2    6       3        2 3  2 5
+--R                     2a b e  + (- 12a c - 4a b )d e  + (34a b c + 2a b )d e
+--R                   + 
+--R                           3 2      2 2   3 4       2   2        3   4 3
+--R                     (- 20a c  - 30a b c)d e  + (30a b c  + 10a b c)d e
+--R                   + 
+--R                          2 3        2 2     4   5 2            3     3 2  6
+--R                     (- 4a c  - 12a b c  - 2b c)d e  + (- 2a b c  + 4b c )d e
+--R                   + 
+--R                          4     2 3  7
+--R                     (4a c  - 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R           +-+
+--R         2\|3
+--R      *
+--R         ROOT
+--R                       3 2      2 2
+--R                  (108a c  - 27a b c)
+--R               *
+--R                  ROOT
+--R                            4 2 6      4       5         4 2     3 2   2 4
+--R                         - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                       + 
+--R                             3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                         (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                       + 
+--R                             2   3       3 2  5         2 4       2 3    4 2  6
+--R                       (- 12a b c  + 6a b c )d e + (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             7 5         6 2 4        5 4 3       4 6 2
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                   2 3         2         3
+--R                - a e  + 3a c d e - b c d
+--R           /
+--R                  3 2      2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                            5 3        4 2 2       3 4
+--R                      (2592a c  - 1296a b c  + 162a b c)e
+--R                    + 
+--R                              4   3       3 3 2      2 5
+--R                      (- 1296a b c  + 648a b c  - 81a b c)d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4       5         4 2     3 2   2 4
+--R                           - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                         + 
+--R                               3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                           (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                                 2   3       3 2  5
+--R                           (- 12a b c  + 6a b c )d e
+--R                         + 
+--R                                2 4       2 3    4 2  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               7 5         6 2 4        5 4 3       4 6 2
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                          3        2 3    3         3 2      2 2   2 2
+--R                      (12a b c - 3a b )d e  + (- 72a c  + 18a b c)d e
+--R                    + 
+--R                          2   2       3   3        2 3        2 2     4   4
+--R                      (36a b c  - 9a b c)d e + (24a c  - 18a b c  + 3b c)d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                              3 2      2 2
+--R                         (108a c  - 27a b c)
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4       5
+--R                                - a b e  + 12a b c d e
+--R                              + 
+--R                                      4 2     3 2   2 4
+--R                                (- 36a c  - 6a b c)d e
+--R                              + 
+--R                                    3   2     2 3   3 3
+--R                                (32a b c  + 2a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  4 2
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                      2   3       3 2  5
+--R                                (- 12a b c  + 6a b c )d e
+--R                              + 
+--R                                     2 4       2 3    4 2  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    7 5         6 2 4        5 4 3       4 6 2
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                          2 3         2         3
+--R                       - a e  + 3a c d e - b c d
+--R                  /
+--R                         3 2      2 2
+--R                     216a c  - 54a b c
+--R               ,
+--R                   3
+--R           /
+--R                              5 3        4 2 2       3 4
+--R                        (2592a c  - 1296a b c  + 162a b c)e
+--R                      + 
+--R                                4   3       3 3 2      2 5
+--R                        (- 1296a b c  + 648a b c  - 81a b c)d
+--R                   *
+--R                      ROOT
+--R                                4 2 6      4       5         4 2     3 2   2 4
+--R                             - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                           + 
+--R                                 3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                             (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                           + 
+--R                                   2   3       3 2  5
+--R                             (- 12a b c  + 6a b c )d e
+--R                           + 
+--R                                  2 4       2 3    4 2  6
+--R                             (- 4a c  + 4a b c  - b c )d
+--R                        /
+--R                                 7 5         6 2 4        5 4 3       4 6 2
+--R                           46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                  + 
+--R                        3        2 3    3         3 2      2 2   2 2
+--R                    (12a b c - 3a b )d e  + (- 72a c  + 18a b c)d e
+--R                  + 
+--R                        2   2       3   3        2 3        2 2     4   4
+--R                    (36a b c  - 9a b c)d e + (24a c  - 18a b c  + 3b c)d
+--R               *
+--R                  ROOT
+--R                                3 2      2 2
+--R                           (108a c  - 27a b c)
+--R                        *
+--R                           ROOT
+--R                                     4 2 6      4       5
+--R                                  - a b e  + 12a b c d e
+--R                                + 
+--R                                        4 2     3 2   2 4
+--R                                  (- 36a c  - 6a b c)d e
+--R                                + 
+--R                                      3   2     2 3   3 3
+--R                                  (32a b c  + 2a b c)d e
+--R                                + 
+--R                                      3 3      2 2 2  4 2
+--R                                  (24a c  - 21a b c )d e
+--R                                + 
+--R                                        2   3       3 2  5
+--R                                  (- 12a b c  + 6a b c )d e
+--R                                + 
+--R                                       2 4       2 3    4 2  6
+--R                                  (- 4a c  + 4a b c  - b c )d
+--R                             /
+--R                                      7 5         6 2 4        5 4 3       4 6 2
+--R                                46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                       + 
+--R                            2 3         2         3
+--R                         - a e  + 3a c d e - b c d
+--R                    /
+--R                           3 2      2 2
+--R                       216a c  - 54a b c
+--R                 ,
+--R                     3
+--R              + 
+--R                        3   5       3      2 2    4      2     2 3
+--R                    - 4a b e  + (24a c + 4a b )d e  - 40a b c d e
+--R                  + 
+--R                        2 2        2   3 2            2     3   4
+--R                    (16a c  + 16a b c)d e  + (- 4a b c  - 4b c)d e
+--R                  + 
+--R                           3     2 2  5
+--R                    (- 8a c  + 4b c )d
+--R               *
+--R                  x
+--R     + 
+--R           +-+
+--R         2\|3
+--R      *
+--R         ROOT
+--R                         3 2      2 2
+--R                  (- 108a c  + 27a b c)
+--R               *
+--R                  ROOT
+--R                            4 2 6      4       5         4 2     3 2   2 4
+--R                         - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                       + 
+--R                             3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                         (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                       + 
+--R                             2   3       3 2  5         2 4       2 3    4 2  6
+--R                       (- 12a b c  + 6a b c )d e + (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             7 5         6 2 4        5 4 3       4 6 2
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                   2 3         2         3
+--R                - a e  + 3a c d e - b c d
+--R           /
+--R                  3 2      2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                            5 3        4 2 2       3 4
+--R                      (2592a c  - 1296a b c  + 162a b c)e
+--R                    + 
+--R                              4   3       3 3 2      2 5
+--R                      (- 1296a b c  + 648a b c  - 81a b c)d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4       5         4 2     3 2   2 4
+--R                           - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                         + 
+--R                               3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                           (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                                 2   3       3 2  5
+--R                           (- 12a b c  + 6a b c )d e
+--R                         + 
+--R                                2 4       2 3    4 2  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               7 5         6 2 4        5 4 3       4 6 2
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                            3        2 3    3       3 2      2 2   2 2
+--R                      (- 12a b c + 3a b )d e  + (72a c  - 18a b c)d e
+--R                    + 
+--R                            2   2       3   3          2 3        2 2     4   4
+--R                      (- 36a b c  + 9a b c)d e + (- 24a c  + 18a b c  - 3b c)d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                                3 2      2 2
+--R                         (- 108a c  + 27a b c)
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4       5
+--R                                - a b e  + 12a b c d e
+--R                              + 
+--R                                      4 2     3 2   2 4
+--R                                (- 36a c  - 6a b c)d e
+--R                              + 
+--R                                    3   2     2 3   3 3
+--R                                (32a b c  + 2a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  4 2
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                      2   3       3 2  5
+--R                                (- 12a b c  + 6a b c )d e
+--R                              + 
+--R                                     2 4       2 3    4 2  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    7 5         6 2 4        5 4 3       4 6 2
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                          2 3         2         3
+--R                       - a e  + 3a c d e - b c d
+--R                  /
+--R                         3 2      2 2
+--R                     216a c  - 54a b c
+--R               ,
+--R                   3
+--R           /
+--R                              5 3        4 2 2       3 4
+--R                        (2592a c  - 1296a b c  + 162a b c)e
+--R                      + 
+--R                                4   3       3 3 2      2 5
+--R                        (- 1296a b c  + 648a b c  - 81a b c)d
+--R                   *
+--R                      ROOT
+--R                                4 2 6      4       5         4 2     3 2   2 4
+--R                             - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                           + 
+--R                                 3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                             (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                           + 
+--R                                   2   3       3 2  5
+--R                             (- 12a b c  + 6a b c )d e
+--R                           + 
+--R                                  2 4       2 3    4 2  6
+--R                             (- 4a c  + 4a b c  - b c )d
+--R                        /
+--R                                 7 5         6 2 4        5 4 3       4 6 2
+--R                           46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                  + 
+--R                          3        2 3    3       3 2      2 2   2 2
+--R                    (- 12a b c + 3a b )d e  + (72a c  - 18a b c)d e
+--R                  + 
+--R                          2   2       3   3          2 3        2 2     4   4
+--R                    (- 36a b c  + 9a b c)d e + (- 24a c  + 18a b c  - 3b c)d
+--R               *
+--R                  ROOT
+--R                                  3 2      2 2
+--R                           (- 108a c  + 27a b c)
+--R                        *
+--R                           ROOT
+--R                                     4 2 6      4       5
+--R                                  - a b e  + 12a b c d e
+--R                                + 
+--R                                        4 2     3 2   2 4
+--R                                  (- 36a c  - 6a b c)d e
+--R                                + 
+--R                                      3   2     2 3   3 3
+--R                                  (32a b c  + 2a b c)d e
+--R                                + 
+--R                                      3 3      2 2 2  4 2
+--R                                  (24a c  - 21a b c )d e
+--R                                + 
+--R                                        2   3       3 2  5
+--R                                  (- 12a b c  + 6a b c )d e
+--R                                + 
+--R                                       2 4       2 3    4 2  6
+--R                                  (- 4a c  + 4a b c  - b c )d
+--R                             /
+--R                                      7 5         6 2 4        5 4 3       4 6 2
+--R                                46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                       + 
+--R                            2 3         2         3
+--R                         - a e  + 3a c d e - b c d
+--R                    /
+--R                           3 2      2 2
+--R                       216a c  - 54a b c
+--R                 ,
+--R                     3
+--R              + 
+--R                      3   5         3      2 2    4      2     2 3
+--R                    4a b e  + (- 24a c - 4a b )d e  + 40a b c d e
+--R                  + 
+--R                          2 2        2   3 2          2     3   4
+--R                    (- 16a c  - 16a b c)d e  + (4a b c  + 4b c)d e
+--R                  + 
+--R                         3     2 2  5
+--R                    (8a c  - 4b c )d
+--R               *
+--R                  x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 25
+
+--S 26 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                  +--------------------+2
+--R                +-----------+                     |   +-----------+
+--R            +-+ |          2                 +-+ 3|   |          2
+--R         (e\|3 \|- 4a c + b   + (b e - 2c d)\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                        +--------------------+2
+--R                   +-----------+                        |   +-----------+
+--R               +-+ |          2                    +-+ 3|   |          2
+--R         (- 2e\|3 \|- 4a c + b   + (- 2b e + 4c d)\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                                        +--------------------+2
+--R                      +-----------+     |   +-----------+
+--R             3+-+ +-+ |          2 3+-+3|   |          2
+--R            3\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          3 2      2 2
+--R                     (108a c  - 27a b c)
+--R                  *
+--R                     ROOT
+--R                               4 2 6      4       5         4 2     3 2   2 4
+--R                            - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                          + 
+--R                                3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                            (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                  2   3       3 2  5
+--R                            (- 12a b c  + 6a b c )d e
+--R                          + 
+--R                                 2 4       2 3    4 2  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                7 5         6 2 4        5 4 3       4 6 2
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                      2 3         2         3
+--R                   - a e  + 3a c d e - b c d
+--R              /
+--R                     3 2      2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+2
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                6 4         5 2 3        4 4 2       3 6
+--R                         (31104a c  - 23328a b c  + 5832a b c  - 486a b c)d e
+--R                       + 
+--R                                5   4         4 3 3        3 5 2       2 7   2
+--R                       (- 15552a b c  + 11664a b c  - 2916a b c  + 243a b c)d
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4       5         4 2     3 2   2 4
+--R                              - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                            + 
+--R                                  3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                              (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                            + 
+--R                                    2   3       3 2  5
+--R                              (- 12a b c  + 6a b c )d e
+--R                            + 
+--R                                   2 4       2 3    4 2  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  7 5         6 2 4        5 4 3       4 6 2
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                           5         4 3  5        5 2      4 2       3 4    4
+--R                     (- 72a b c + 18a b )e  + (432a c  - 36a b c - 18a b )d e
+--R                   + 
+--R                            4   2       3 3      2 5  2 3
+--R                     (- 576a b c  + 108a b c + 9a b )d e
+--R                   + 
+--R                            4 3       3 2 2       2 4   3 2
+--R                     (- 576a c  + 648a b c  - 126a b c)d e
+--R                   + 
+--R                          3   3       2 3 2        5   4
+--R                     (360a b c  - 270a b c  + 45a b c)d e
+--R                   + 
+--R                          3 4       2 2 3        4 2     6   5
+--R                     (144a c  - 180a b c  + 72a b c  - 9b c)d
+--R                *
+--R                     ROOT
+--R                                   3 2      2 2
+--R                              (108a c  - 27a b c)
+--R                           *
+--R                              ROOT
+--R                                        4 2 6      4       5
+--R                                     - a b e  + 12a b c d e
+--R                                   + 
+--R                                           4 2     3 2   2 4
+--R                                     (- 36a c  - 6a b c)d e
+--R                                   + 
+--R                                         3   2     2 3   3 3
+--R                                     (32a b c  + 2a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  4 2
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                           2   3       3 2  5
+--R                                     (- 12a b c  + 6a b c )d e
+--R                                   + 
+--R                                          2 4       2 3    4 2  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           7 5         6 2 4        5 4 3
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           4 6 2
+--R                                     - 729a b c
+--R                          + 
+--R                               2 3         2         3
+--R                            - a e  + 3a c d e - b c d
+--R                       /
+--R                              3 2      2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 6 3        5 2 2       4 4   3
+--R                         (- 2592a c  + 1296a b c  - 162a b c)e
+--R                       + 
+--R                               5   3        4 3 2       3 5     2
+--R                         (3888a b c  - 1944a b c  + 243a b c)d e
+--R                       + 
+--R                                 5 4       3 4 2      2 6   2
+--R                         (- 2592a c  + 486a b c  - 81a b c)d e
+--R                       + 
+--R                               4   4       3 3 3      2 5 2  3
+--R                         (1296a b c  - 648a b c  + 81a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4       5         4 2     3 2   2 4
+--R                              - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                            + 
+--R                                  3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                              (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                            + 
+--R                                    2   3       3 2  5
+--R                              (- 12a b c  + 6a b c )d e
+--R                            + 
+--R                                   2 4       2 3    4 2  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  7 5         6 2 4        5 4 3       4 6 2
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                               4        3 3    5       4 2     3 2      2 4  2 4
+--R                         (- 12a b c + 3a b )d e  + (72a c  - 6a b c - 3a b )d e
+--R                       + 
+--R                                3   2      2 3   3 3
+--R                         (- 120a b c  + 30a b c)d e
+--R                       + 
+--R                             3 3      2 2 2        4   4 2
+--R                         (48a c  + 36a b c  - 12a b c)d e
+--R                       + 
+--R                               2   3       3 2     5   5
+--R                         (- 12a b c  - 9a b c  + 3b c)d e
+--R                       + 
+--R                               2 4        2 3     4 2  6
+--R                         (- 24a c  + 18a b c  - 3b c )d
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                 3 2      2 2
+--R                            (108a c  - 27a b c)
+--R                         *
+--R                            ROOT
+--R                                      4 2 6      4       5
+--R                                   - a b e  + 12a b c d e
+--R                                 + 
+--R                                         4 2     3 2   2 4
+--R                                   (- 36a c  - 6a b c)d e
+--R                                 + 
+--R                                       3   2     2 3   3 3
+--R                                   (32a b c  + 2a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  4 2
+--R                                   (24a c  - 21a b c )d e
+--R                                 + 
+--R                                         2   3       3 2  5
+--R                                   (- 12a b c  + 6a b c )d e
+--R                                 + 
+--R                                        2 4       2 3    4 2  6
+--R                                   (- 4a c  + 4a b c  - b c )d
+--R                              /
+--R                                         7 5         6 2 4        5 4 3
+--R                                   46656a c  - 34992a b c  + 8748a b c
+--R                                 + 
+--R                                         4 6 2
+--R                                   - 729a b c
+--R                        + 
+--R                             2 3         2         3
+--R                          - a e  + 3a c d e - b c d
+--R                     /
+--R                            3 2      2 2
+--R                        216a c  - 54a b c
+--R                  ,
+--R                      3
+--R               + 
+--R                       4   7         4      3 2    6       3        2 3  2 5
+--R                     2a b e  + (- 12a c - 4a b )d e  + (34a b c + 2a b )d e
+--R                   + 
+--R                           3 2      2 2   3 4       2   2        3   4 3
+--R                     (- 20a c  - 30a b c)d e  + (30a b c  + 10a b c)d e
+--R                   + 
+--R                          2 3        2 2     4   5 2            3     3 2  6
+--R                     (- 4a c  - 12a b c  - 2b c)d e  + (- 2a b c  + 4b c )d e
+--R                   + 
+--R                          4     2 3  7
+--R                     (4a c  - 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                                     +--------------------+2
+--R                   +-----------+     |   +-----------+
+--R          3+-+ +-+ |          2 3+-+3|   |          2
+--R         6\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       3 2      2 2
+--R                  (108a c  - 27a b c)
+--R               *
+--R                  ROOT
+--R                            4 2 6      4       5         4 2     3 2   2 4
+--R                         - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                       + 
+--R                             3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                         (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                       + 
+--R                             2   3       3 2  5         2 4       2 3    4 2  6
+--R                       (- 12a b c  + 6a b c )d e + (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             7 5         6 2 4        5 4 3       4 6 2
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                   2 3         2         3
+--R                - a e  + 3a c d e - b c d
+--R           /
+--R                  3 2      2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            5 3        4 2 2       3 4
+--R                      (2592a c  - 1296a b c  + 162a b c)e
+--R                    + 
+--R                              4   3       3 3 2      2 5
+--R                      (- 1296a b c  + 648a b c  - 81a b c)d
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4       5         4 2     3 2   2 4
+--R                           - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                         + 
+--R                               3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                           (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                                 2   3       3 2  5
+--R                           (- 12a b c  + 6a b c )d e
+--R                         + 
+--R                                2 4       2 3    4 2  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               7 5         6 2 4        5 4 3       4 6 2
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                      3        2 3    3         3 2      2 2   2 2
+--R                  (12a b c - 3a b )d e  + (- 72a c  + 18a b c)d e
+--R                + 
+--R                      2   2       3   3        2 3        2 2     4   4
+--R                  (36a b c  - 9a b c)d e + (24a c  - 18a b c  + 3b c)d
+--R             *
+--R                ROOT
+--R                              3 2      2 2
+--R                         (108a c  - 27a b c)
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4       5
+--R                                - a b e  + 12a b c d e
+--R                              + 
+--R                                      4 2     3 2   2 4
+--R                                (- 36a c  - 6a b c)d e
+--R                              + 
+--R                                    3   2     2 3   3 3
+--R                                (32a b c  + 2a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  4 2
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                      2   3       3 2  5
+--R                                (- 12a b c  + 6a b c )d e
+--R                              + 
+--R                                     2 4       2 3    4 2  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    7 5         6 2 4        5 4 3       4 6 2
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                          2 3         2         3
+--R                       - a e  + 3a c d e - b c d
+--R                  /
+--R                         3 2      2 2
+--R                     216a c  - 54a b c
+--R               ,
+--R                   3
+--R            + 
+--R                    3   5         3      2 2    4      2     2 3
+--R                  2a b e  + (- 12a c - 2a b )d e  + 20a b c d e
+--R                + 
+--R                     2 2       2   3 2          2     3   4         3     2 2  5
+--R                (- 8a c  - 8a b c)d e  + (2a b c  + 2b c)d e + (4a c  - 2b c )d
+--R             *
+--R                x
+--R     + 
+--R                                                    +------------------+2
+--R                +-----------+                       | +-----------+
+--R            +-+ |          2                   +-+ 3| |          2
+--R         (e\|3 \|- 4a c + b   + (- b e + 2c d)\|3 )\|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                      +------------------+2
+--R                   +-----------+                      | +-----------+
+--R               +-+ |          2                  +-+ 3| |          2
+--R         (- 2e\|3 \|- 4a c + b   + (2b e - 4c d)\|3 )\|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                     +--------------------+2
+--R                   +-----------+     |   +-----------+
+--R          3+-+ +-+ |          2 3+-+3|   |          2
+--R         6\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         3 2      2 2
+--R                  (- 108a c  + 27a b c)
+--R               *
+--R                  ROOT
+--R                            4 2 6      4       5         4 2     3 2   2 4
+--R                         - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                       + 
+--R                             3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                         (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                       + 
+--R                             2   3       3 2  5         2 4       2 3    4 2  6
+--R                       (- 12a b c  + 6a b c )d e + (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             7 5         6 2 4        5 4 3       4 6 2
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                   2 3         2         3
+--R                - a e  + 3a c d e - b c d
+--R           /
+--R                  3 2      2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              5 3        4 2 2       3 4
+--R                      (- 2592a c  + 1296a b c  - 162a b c)e
+--R                    + 
+--R                            4   3       3 3 2      2 5
+--R                      (1296a b c  - 648a b c  + 81a b c)d
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4       5         4 2     3 2   2 4
+--R                           - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                         + 
+--R                               3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                           (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                                 2   3       3 2  5
+--R                           (- 12a b c  + 6a b c )d e
+--R                         + 
+--R                                2 4       2 3    4 2  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               7 5         6 2 4        5 4 3       4 6 2
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                      3        2 3    3         3 2      2 2   2 2
+--R                  (12a b c - 3a b )d e  + (- 72a c  + 18a b c)d e
+--R                + 
+--R                      2   2       3   3        2 3        2 2     4   4
+--R                  (36a b c  - 9a b c)d e + (24a c  - 18a b c  + 3b c)d
+--R             *
+--R                ROOT
+--R                                3 2      2 2
+--R                         (- 108a c  + 27a b c)
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4       5
+--R                                - a b e  + 12a b c d e
+--R                              + 
+--R                                      4 2     3 2   2 4
+--R                                (- 36a c  - 6a b c)d e
+--R                              + 
+--R                                    3   2     2 3   3 3
+--R                                (32a b c  + 2a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  4 2
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                      2   3       3 2  5
+--R                                (- 12a b c  + 6a b c )d e
+--R                              + 
+--R                                     2 4       2 3    4 2  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    7 5         6 2 4        5 4 3       4 6 2
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                          2 3         2         3
+--R                       - a e  + 3a c d e - b c d
+--R                  /
+--R                         3 2      2 2
+--R                     216a c  - 54a b c
+--R               ,
+--R                   3
+--R            + 
+--R                    3   5         3      2 2    4      2     2 3
+--R                  2a b e  + (- 12a c - 2a b )d e  + 20a b c d e
+--R                + 
+--R                     2 2       2   3 2          2     3   4         3     2 2  5
+--R                (- 8a c  - 8a b c)d e  + (2a b c  + 2b c)d e + (4a c  - 2b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                        +--------------------+2
+--R                      +-----------+     |   +-----------+
+--R             3+-+ +-+ |          2 3+-+3|   |          2
+--R            3\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            3 2      2 2
+--R                     (- 108a c  + 27a b c)
+--R                  *
+--R                     ROOT
+--R                               4 2 6      4       5         4 2     3 2   2 4
+--R                            - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                          + 
+--R                                3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                            (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                          + 
+--R                                  2   3       3 2  5
+--R                            (- 12a b c  + 6a b c )d e
+--R                          + 
+--R                                 2 4       2 3    4 2  6
+--R                            (- 4a c  + 4a b c  - b c )d
+--R                       /
+--R                                7 5         6 2 4        5 4 3       4 6 2
+--R                          46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                 + 
+--R                      2 3         2         3
+--R                   - a e  + 3a c d e - b c d
+--R              /
+--R                     3 2      2 2
+--R                 216a c  - 54a b c
+--R           ,
+--R               3
+--R         *
+--R             +------------------+2
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                  6 4         5 2 3        4 4 2       3 6
+--R                         (- 31104a c  + 23328a b c  - 5832a b c  + 486a b c)d e
+--R                       + 
+--R                                5   4         4 3 3        3 5 2       2 7   2
+--R                         (15552a b c  - 11664a b c  + 2916a b c  - 243a b c)d
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4       5         4 2     3 2   2 4
+--R                              - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                            + 
+--R                                  3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                              (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                            + 
+--R                                    2   3       3 2  5
+--R                              (- 12a b c  + 6a b c )d e
+--R                            + 
+--R                                   2 4       2 3    4 2  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  7 5         6 2 4        5 4 3       4 6 2
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                           5         4 3  5        5 2      4 2       3 4    4
+--R                     (- 72a b c + 18a b )e  + (432a c  - 36a b c - 18a b )d e
+--R                   + 
+--R                            4   2       3 3      2 5  2 3
+--R                     (- 576a b c  + 108a b c + 9a b )d e
+--R                   + 
+--R                            4 3       3 2 2       2 4   3 2
+--R                     (- 576a c  + 648a b c  - 126a b c)d e
+--R                   + 
+--R                          3   3       2 3 2        5   4
+--R                     (360a b c  - 270a b c  + 45a b c)d e
+--R                   + 
+--R                          3 4       2 2 3        4 2     6   5
+--R                     (144a c  - 180a b c  + 72a b c  - 9b c)d
+--R                *
+--R                     ROOT
+--R                                     3 2      2 2
+--R                              (- 108a c  + 27a b c)
+--R                           *
+--R                              ROOT
+--R                                        4 2 6      4       5
+--R                                     - a b e  + 12a b c d e
+--R                                   + 
+--R                                           4 2     3 2   2 4
+--R                                     (- 36a c  - 6a b c)d e
+--R                                   + 
+--R                                         3   2     2 3   3 3
+--R                                     (32a b c  + 2a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  4 2
+--R                                     (24a c  - 21a b c )d e
+--R                                   + 
+--R                                           2   3       3 2  5
+--R                                     (- 12a b c  + 6a b c )d e
+--R                                   + 
+--R                                          2 4       2 3    4 2  6
+--R                                     (- 4a c  + 4a b c  - b c )d
+--R                                /
+--R                                           7 5         6 2 4        5 4 3
+--R                                     46656a c  - 34992a b c  + 8748a b c
+--R                                   + 
+--R                                           4 6 2
+--R                                     - 729a b c
+--R                          + 
+--R                               2 3         2         3
+--R                            - a e  + 3a c d e - b c d
+--R                       /
+--R                              3 2      2 2
+--R                          216a c  - 54a b c
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               6 3        5 2 2       4 4   3
+--R                         (2592a c  - 1296a b c  + 162a b c)e
+--R                       + 
+--R                                 5   3        4 3 2       3 5     2
+--R                         (- 3888a b c  + 1944a b c  - 243a b c)d e
+--R                       + 
+--R                               5 4       3 4 2      2 6   2
+--R                         (2592a c  - 486a b c  + 81a b c)d e
+--R                       + 
+--R                                 4   4       3 3 3      2 5 2  3
+--R                         (- 1296a b c  + 648a b c  - 81a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                 4 2 6      4       5         4 2     3 2   2 4
+--R                              - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                            + 
+--R                                  3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                              (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                            + 
+--R                                    2   3       3 2  5
+--R                              (- 12a b c  + 6a b c )d e
+--R                            + 
+--R                                   2 4       2 3    4 2  6
+--R                              (- 4a c  + 4a b c  - b c )d
+--R                         /
+--R                                  7 5         6 2 4        5 4 3       4 6 2
+--R                            46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                   + 
+--R                               4        3 3    5       4 2     3 2      2 4  2 4
+--R                         (- 12a b c + 3a b )d e  + (72a c  - 6a b c - 3a b )d e
+--R                       + 
+--R                                3   2      2 3   3 3
+--R                         (- 120a b c  + 30a b c)d e
+--R                       + 
+--R                             3 3      2 2 2        4   4 2
+--R                         (48a c  + 36a b c  - 12a b c)d e
+--R                       + 
+--R                               2   3       3 2     5   5
+--R                         (- 12a b c  - 9a b c  + 3b c)d e
+--R                       + 
+--R                               2 4        2 3     4 2  6
+--R                         (- 24a c  + 18a b c  - 3b c )d
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                   3 2      2 2
+--R                            (- 108a c  + 27a b c)
+--R                         *
+--R                            ROOT
+--R                                      4 2 6      4       5
+--R                                   - a b e  + 12a b c d e
+--R                                 + 
+--R                                         4 2     3 2   2 4
+--R                                   (- 36a c  - 6a b c)d e
+--R                                 + 
+--R                                       3   2     2 3   3 3
+--R                                   (32a b c  + 2a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  4 2
+--R                                   (24a c  - 21a b c )d e
+--R                                 + 
+--R                                         2   3       3 2  5
+--R                                   (- 12a b c  + 6a b c )d e
+--R                                 + 
+--R                                        2 4       2 3    4 2  6
+--R                                   (- 4a c  + 4a b c  - b c )d
+--R                              /
+--R                                         7 5         6 2 4        5 4 3
+--R                                   46656a c  - 34992a b c  + 8748a b c
+--R                                 + 
+--R                                         4 6 2
+--R                                   - 729a b c
+--R                        + 
+--R                             2 3         2         3
+--R                          - a e  + 3a c d e - b c d
+--R                     /
+--R                            3 2      2 2
+--R                        216a c  - 54a b c
+--R                  ,
+--R                      3
+--R               + 
+--R                       4   7         4      3 2    6       3        2 3  2 5
+--R                     2a b e  + (- 12a c - 4a b )d e  + (34a b c + 2a b )d e
+--R                   + 
+--R                           3 2      2 2   3 4       2   2        3   4 3
+--R                     (- 20a c  - 30a b c)d e  + (30a b c  + 10a b c)d e
+--R                   + 
+--R                          2 3        2 2     4   5 2            3     3 2  6
+--R                     (- 4a c  - 12a b c  - 2b c)d e  + (- 2a b c  + 4b c )d e
+--R                   + 
+--R                          4     2 3  7
+--R                     (4a c  - 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                                  +--------------------+2
+--R                +-----------+     |   +-----------+
+--R           3+-+ |          2 3+-+3|   |          2
+--R         18\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       3 2      2 2
+--R                  (108a c  - 27a b c)
+--R               *
+--R                  ROOT
+--R                            4 2 6      4       5         4 2     3 2   2 4
+--R                         - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                       + 
+--R                             3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                         (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                       + 
+--R                             2   3       3 2  5         2 4       2 3    4 2  6
+--R                       (- 12a b c  + 6a b c )d e + (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             7 5         6 2 4        5 4 3       4 6 2
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                   2 3         2         3
+--R                - a e  + 3a c d e - b c d
+--R           /
+--R                  3 2      2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                            5 3        4 2 2       3 4
+--R                      (2592a c  - 1296a b c  + 162a b c)e
+--R                    + 
+--R                              4   3       3 3 2      2 5
+--R                      (- 1296a b c  + 648a b c  - 81a b c)d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4       5         4 2     3 2   2 4
+--R                           - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                         + 
+--R                               3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                           (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                                 2   3       3 2  5
+--R                           (- 12a b c  + 6a b c )d e
+--R                         + 
+--R                                2 4       2 3    4 2  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               7 5         6 2 4        5 4 3       4 6 2
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                          3        2 3    3         3 2      2 2   2 2
+--R                      (12a b c - 3a b )d e  + (- 72a c  + 18a b c)d e
+--R                    + 
+--R                          2   2       3   3        2 3        2 2     4   4
+--R                      (36a b c  - 9a b c)d e + (24a c  - 18a b c  + 3b c)d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                              3 2      2 2
+--R                         (108a c  - 27a b c)
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4       5
+--R                                - a b e  + 12a b c d e
+--R                              + 
+--R                                      4 2     3 2   2 4
+--R                                (- 36a c  - 6a b c)d e
+--R                              + 
+--R                                    3   2     2 3   3 3
+--R                                (32a b c  + 2a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  4 2
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                      2   3       3 2  5
+--R                                (- 12a b c  + 6a b c )d e
+--R                              + 
+--R                                     2 4       2 3    4 2  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    7 5         6 2 4        5 4 3       4 6 2
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                          2 3         2         3
+--R                       - a e  + 3a c d e - b c d
+--R                  /
+--R                         3 2      2 2
+--R                     216a c  - 54a b c
+--R               ,
+--R                   3
+--R           /
+--R                              5 3        4 2 2       3 4
+--R                        (2592a c  - 1296a b c  + 162a b c)e
+--R                      + 
+--R                                4   3       3 3 2      2 5
+--R                        (- 1296a b c  + 648a b c  - 81a b c)d
+--R                   *
+--R                      ROOT
+--R                                4 2 6      4       5         4 2     3 2   2 4
+--R                             - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                           + 
+--R                                 3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                             (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                           + 
+--R                                   2   3       3 2  5
+--R                             (- 12a b c  + 6a b c )d e
+--R                           + 
+--R                                  2 4       2 3    4 2  6
+--R                             (- 4a c  + 4a b c  - b c )d
+--R                        /
+--R                                 7 5         6 2 4        5 4 3       4 6 2
+--R                           46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                  + 
+--R                        3        2 3    3         3 2      2 2   2 2
+--R                    (12a b c - 3a b )d e  + (- 72a c  + 18a b c)d e
+--R                  + 
+--R                        2   2       3   3        2 3        2 2     4   4
+--R                    (36a b c  - 9a b c)d e + (24a c  - 18a b c  + 3b c)d
+--R               *
+--R                  ROOT
+--R                                3 2      2 2
+--R                           (108a c  - 27a b c)
+--R                        *
+--R                           ROOT
+--R                                     4 2 6      4       5
+--R                                  - a b e  + 12a b c d e
+--R                                + 
+--R                                        4 2     3 2   2 4
+--R                                  (- 36a c  - 6a b c)d e
+--R                                + 
+--R                                      3   2     2 3   3 3
+--R                                  (32a b c  + 2a b c)d e
+--R                                + 
+--R                                      3 3      2 2 2  4 2
+--R                                  (24a c  - 21a b c )d e
+--R                                + 
+--R                                        2   3       3 2  5
+--R                                  (- 12a b c  + 6a b c )d e
+--R                                + 
+--R                                       2 4       2 3    4 2  6
+--R                                  (- 4a c  + 4a b c  - b c )d
+--R                             /
+--R                                      7 5         6 2 4        5 4 3       4 6 2
+--R                                46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                       + 
+--R                            2 3         2         3
+--R                         - a e  + 3a c d e - b c d
+--R                    /
+--R                           3 2      2 2
+--R                       216a c  - 54a b c
+--R                 ,
+--R                     3
+--R              + 
+--R                        3   5       3      2 2    4      2     2 3
+--R                    - 4a b e  + (24a c + 4a b )d e  - 40a b c d e
+--R                  + 
+--R                        2 2        2   3 2            2     3   4
+--R                    (16a c  + 16a b c)d e  + (- 4a b c  - 4b c)d e
+--R                  + 
+--R                           3     2 2  5
+--R                    (- 8a c  + 4b c )d
+--R               *
+--R                  x
+--R     + 
+--R                                  +--------------------+2
+--R                +-----------+     |   +-----------+
+--R           3+-+ |          2 3+-+3|   |          2
+--R         18\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         3 2      2 2
+--R                  (- 108a c  + 27a b c)
+--R               *
+--R                  ROOT
+--R                            4 2 6      4       5         4 2     3 2   2 4
+--R                         - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                       + 
+--R                             3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                         (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                       + 
+--R                             2   3       3 2  5         2 4       2 3    4 2  6
+--R                       (- 12a b c  + 6a b c )d e + (- 4a c  + 4a b c  - b c )d
+--R                    /
+--R                             7 5         6 2 4        5 4 3       4 6 2
+--R                       46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R              + 
+--R                   2 3         2         3
+--R                - a e  + 3a c d e - b c d
+--R           /
+--R                  3 2      2 2
+--R              216a c  - 54a b c
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                            5 3        4 2 2       3 4
+--R                      (2592a c  - 1296a b c  + 162a b c)e
+--R                    + 
+--R                              4   3       3 3 2      2 5
+--R                      (- 1296a b c  + 648a b c  - 81a b c)d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                              4 2 6      4       5         4 2     3 2   2 4
+--R                           - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                         + 
+--R                               3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                           (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                         + 
+--R                                 2   3       3 2  5
+--R                           (- 12a b c  + 6a b c )d e
+--R                         + 
+--R                                2 4       2 3    4 2  6
+--R                           (- 4a c  + 4a b c  - b c )d
+--R                      /
+--R                               7 5         6 2 4        5 4 3       4 6 2
+--R                         46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                + 
+--R                            3        2 3    3       3 2      2 2   2 2
+--R                      (- 12a b c + 3a b )d e  + (72a c  - 18a b c)d e
+--R                    + 
+--R                            2   2       3   3          2 3        2 2     4   4
+--R                      (- 36a b c  + 9a b c)d e + (- 24a c  + 18a b c  - 3b c)d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                                3 2      2 2
+--R                         (- 108a c  + 27a b c)
+--R                      *
+--R                         ROOT
+--R                                   4 2 6      4       5
+--R                                - a b e  + 12a b c d e
+--R                              + 
+--R                                      4 2     3 2   2 4
+--R                                (- 36a c  - 6a b c)d e
+--R                              + 
+--R                                    3   2     2 3   3 3
+--R                                (32a b c  + 2a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  4 2
+--R                                (24a c  - 21a b c )d e
+--R                              + 
+--R                                      2   3       3 2  5
+--R                                (- 12a b c  + 6a b c )d e
+--R                              + 
+--R                                     2 4       2 3    4 2  6
+--R                                (- 4a c  + 4a b c  - b c )d
+--R                           /
+--R                                    7 5         6 2 4        5 4 3       4 6 2
+--R                              46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                     + 
+--R                          2 3         2         3
+--R                       - a e  + 3a c d e - b c d
+--R                  /
+--R                         3 2      2 2
+--R                     216a c  - 54a b c
+--R               ,
+--R                   3
+--R           /
+--R                              5 3        4 2 2       3 4
+--R                        (2592a c  - 1296a b c  + 162a b c)e
+--R                      + 
+--R                                4   3       3 3 2      2 5
+--R                        (- 1296a b c  + 648a b c  - 81a b c)d
+--R                   *
+--R                      ROOT
+--R                                4 2 6      4       5         4 2     3 2   2 4
+--R                             - a b e  + 12a b c d e  + (- 36a c  - 6a b c)d e
+--R                           + 
+--R                                 3   2     2 3   3 3       3 3      2 2 2  4 2
+--R                             (32a b c  + 2a b c)d e  + (24a c  - 21a b c )d e
+--R                           + 
+--R                                   2   3       3 2  5
+--R                             (- 12a b c  + 6a b c )d e
+--R                           + 
+--R                                  2 4       2 3    4 2  6
+--R                             (- 4a c  + 4a b c  - b c )d
+--R                        /
+--R                                 7 5         6 2 4        5 4 3       4 6 2
+--R                           46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                  + 
+--R                          3        2 3    3       3 2      2 2   2 2
+--R                    (- 12a b c + 3a b )d e  + (72a c  - 18a b c)d e
+--R                  + 
+--R                          2   2       3   3          2 3        2 2     4   4
+--R                    (- 36a b c  + 9a b c)d e + (- 24a c  + 18a b c  - 3b c)d
+--R               *
+--R                  ROOT
+--R                                  3 2      2 2
+--R                           (- 108a c  + 27a b c)
+--R                        *
+--R                           ROOT
+--R                                     4 2 6      4       5
+--R                                  - a b e  + 12a b c d e
+--R                                + 
+--R                                        4 2     3 2   2 4
+--R                                  (- 36a c  - 6a b c)d e
+--R                                + 
+--R                                      3   2     2 3   3 3
+--R                                  (32a b c  + 2a b c)d e
+--R                                + 
+--R                                      3 3      2 2 2  4 2
+--R                                  (24a c  - 21a b c )d e
+--R                                + 
+--R                                        2   3       3 2  5
+--R                                  (- 12a b c  + 6a b c )d e
+--R                                + 
+--R                                       2 4       2 3    4 2  6
+--R                                  (- 4a c  + 4a b c  - b c )d
+--R                             /
+--R                                      7 5         6 2 4        5 4 3       4 6 2
+--R                                46656a c  - 34992a b c  + 8748a b c  - 729a b c
+--R                       + 
+--R                            2 3         2         3
+--R                         - a e  + 3a c d e - b c d
+--R                    /
+--R                           3 2      2 2
+--R                       216a c  - 54a b c
+--R                 ,
+--R                     3
+--R              + 
+--R                      3   5         3      2 2    4      2     2 3
+--R                    4a b e  + (- 24a c - 4a b )d e  + 40a b c d e
+--R                  + 
+--R                          2 2        2   3 2          2     3   4
+--R                    (- 16a c  - 16a b c)d e  + (4a b c  + 4b c)d e
+--R                  + 
+--R                         3     2 2  5
+--R                    (8a c  - 4b c )d
+--R               *
+--R                  x
+--R     + 
+--R                                           +--------------------+2
+--R             +-----------+                 |   +-----------+
+--R             |          2                 3|   |          2
+--R         (6e\|- 4a c + b   + 6b e - 12c d)\|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                           +------------------+2
+--R             +-----------+                 | +-----------+
+--R             |          2                 3| |          2
+--R         (6e\|- 4a c + b   - 6b e + 12c d)\|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                                 +--------------------+2  +------------------+2
+--R               +-----------+     |   +-----------+        | +-----------+
+--R      3+-+ +-+ |          2 3+-+3|   |          2        3| |          2
+--R     6\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 649
+t0:=(d+e*x^3)/(x*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                3
+--R             e x  + d
+--R   (1)  -----------------
+--R           7      4
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 28
+
+--S 29 of 649
+r0:=d*log(x)/a-1/6*d*log(a+b*x^3+c*x^6)/a+1/3*(b*d-2*a*e)*_
+   atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                   3
+--R                               2c x  + b
+--R       (- 4a e + 2b d)atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                              +-----------+
+--R                   6      3                   |          2
+--R       (- d log(c x  + b x  + a) + 6d log(x))\|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     6a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           (2a e - b d)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 6         3           2  |          2         2     2   3
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   6      3
+--R                c x  + b x  + a
+--R       + 
+--R                                                +-----------+
+--R                     6      3                   |          2
+--R         (- d log(c x  + b x  + a) + 6d log(x))\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       6a\|- 4a c + b
+--R     ,
+--R
+--R                                       +---------+
+--R                                3      |        2
+--R                           (2c x  + b)\|4a c - b
+--R         (4a e - 2b d)atan(-----------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                                                +---------+
+--R                     6      3                   |        2
+--R         (- d log(c x  + b x  + a) + 6d log(x))\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       6a\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 30
+
+--S 31 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (2a e - b d)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 6         3           2  |          2         2     2   3
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 6      3
+--R              c x  + b x  + a
+--R     + 
+--R                                 3
+--R                             2c x  + b
+--R       (4a e - 2b d)atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     6a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    +---------+             3
+--R                    |        2          2c x  + b
+--R       (2a e - b d)\|4a c - b  atanh(--------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                    +-----------+          3      |        2
+--R                    |          2      (2c x  + b)\|4a c - b
+--R       (2a e - b d)\|- 4a c + b  atan(-----------------------)
+--R                                                     2
+--R                                             4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     3a\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 33
+
+--S 34 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 34
+
+)clear all
+
+--S 35 of 649
+t0:=(d+e*x^3)/(x^2*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                3
+--R             e x  + d
+--R   (1)  ------------------
+--R           8      5      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 35
+
+--S 36 of 649
+r0:=-d/(a*x)+1/3*c^(1/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*_
+   (d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b-sqrt(b^2-4*a*c))^(1/3))-_
+   1/6*c^(1/3)*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-_
+   sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(d+(b*d-2*a*e)/_
+   sqrt(b^2-4*a*c))/(2^(2/3)*a*(b-sqrt(b^2-4*a*c))^(1/3))+c^(1/3)*_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/_
+   (2^(2/3)*a*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3))+1/3*c^(1/3)*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/_
+   (2^(2/3)*a*(b+sqrt(b^2-4*a*c))^(1/3))-1/6*c^(1/3)*log(2^(2/3)*c^(2/3)*_
+   x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-_
+   4*a*c))^(2/3))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b+_
+   sqrt(b^2-4*a*c))^(1/3))+c^(1/3)*atan((-4*c^(1/3)*x+2^(2/3)*_
+   (b+sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3)))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(2/3)*a*_
+   sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3))
+--R 
+--R
+--R   (2)
+--R                    +-----------+
+--R                +-+ |          2                    +-+ 3+-+
+--R         (- d x\|3 \|- 4a c + b   + (- 2a e + b d)x\|3 )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+
+--R         3|   |          2
+--R         \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                   +-----------+
+--R               +-+ |          2                   +-+ 3+-+
+--R         (2d x\|3 \|- 4a c + b   + (4a e - 2b d)x\|3 )\|c
+--R      *
+--R          +--------------------+     +------------------+
+--R          |   +-----------+          | +-----------+
+--R         3|   |          2          3| |          2          3+-+3+-+
+--R         \|- \|- 4a c + b   + b log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                           +------------------+
+--R                    +-----------+                          | +-----------+
+--R                +-+ |          2                  +-+ 3+-+3| |          2
+--R         (- d x\|3 \|- 4a c + b   + (2a e - b d)x\|3 )\|c \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                   +-----------+
+--R               +-+ |          2                     +-+ 3+-+
+--R         (2d x\|3 \|- 4a c + b   + (- 4a e + 2b d)x\|3 )\|c
+--R      *
+--R          +------------------+     +--------------------+
+--R          | +-----------+          |   +-----------+
+--R         3| |          2          3|   |          2          3+-+3+-+
+--R         \|\|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                    +--------------------+
+--R               +-----------+                        |   +-----------+
+--R               |          2                    3+-+3|   |          2
+--R         (6d x\|- 4a c + b   + (12a e - 6b d)x)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                                      +------------------+
+--R               +-----------+                          | +-----------+
+--R               |          2                      3+-+3| |          2
+--R         (6d x\|- 4a c + b   + (- 12a e + 6b d)x)\|c \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                    +--------------------+ +------------------+
+--R                      +-----------+ |   +-----------+      | +-----------+
+--R            3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R       - 6d \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R          3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R     6a x \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                          5       4 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                     ROOT
+--R                               6 2 6         6        5 3    5
+--R                            - a b e  + (- 12a b c + 6a b )d e
+--R                          + 
+--R                                  6 2      5 2       4 4  2 4
+--R                            (- 36a c  + 54a b c - 15a b )d e
+--R                          + 
+--R                                 5   2      4 3       3 5  3 3
+--R                            (112a b c  - 98a b c + 20a b )d e
+--R                          + 
+--R                                5 3       4 2 2      3 4       2 6  4 2
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                  4   3      3 3 2      2 5        7  5
+--R                            (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                          + 
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                       /
+--R                                11 3         10 2 2        9 4        8 6
+--R                          46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                    3 3     2     2        2        2  2               3  3
+--R                   a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                9 3         8 2 2        7 4        6 6  2
+--R                         (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                       + 
+--R                                  8   3         7 3 2        6 5        5 7
+--R                         (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )d e
+--R                       + 
+--R                                     8 4         7 2 3         6 4 2        5 6
+--R                             - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                           + 
+--R                                   4 8
+--R                             - 243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                             6 2      5 4  5
+--R                         (36a b c - 9a b )e
+--R                       + 
+--R                              6   2       5 3       4 5    4
+--R                         (360a b c  - 270a b c + 45a b )d e
+--R                       + 
+--R                              6 3        5 2 2       4 4       3 6  2 3
+--R                         (864a c  - 1512a b c  + 684a b c - 90a b )d e
+--R                       + 
+--R                                 5   3        4 3 2       3 5       2 7  3 2
+--R                         (- 2016a b c  + 2268a b c  - 801a b c + 90a b )d e
+--R                       + 
+--R                                   5 4        4 2 3        3 4 2       2 6
+--R                             - 288a c  + 1764a b c  - 1503a b c  + 450a b c
+--R                           + 
+--R                                    8
+--R                             - 45a b
+--R                        *
+--R                            4
+--R                           d e
+--R                       + 
+--R                              4   4       3 3 3       2 5 2        7      9  5
+--R                         (216a b c  - 558a b c  + 378a b c  - 99a b c + 9b )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                   5       4 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                              ROOT
+--R                                        6 2 6         6        5 3    5
+--R                                     - a b e  + (- 12a b c + 6a b )d e
+--R                                   + 
+--R                                           6 2      5 2       4 4  2 4
+--R                                     (- 36a c  + 54a b c - 15a b )d e
+--R                                   + 
+--R                                          5   2      4 3       3 5  3 3
+--R                                     (112a b c  - 98a b c + 20a b )d e
+--R                                   + 
+--R                                         5 3       4 2 2      3 4       2 6  4 2
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 36a b c  + 84a b c  - 42a b c + 6a b )
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           11 3         10 2 2        9 4
+--R                                     46656a  c  - 34992a  b c  + 8748a b c
+--R                                   + 
+--R                                           8 6
+--R                                     - 729a b
+--R                          + 
+--R                             3 3     2     2        2        2  2
+--R                            a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                                       3  3
+--R                            (2a b c - b )d
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               8   2       7 3       6 5  3
+--R                         (1296a b c  - 648a b c + 81a b )e
+--R                       + 
+--R                               8 3        7 2 2        6 4        5 6    2
+--R                         (2592a c  - 3888a b c  + 1458a b c - 162a b )d e
+--R                       + 
+--R                                 7   3        6 3 2       5 5       4 7  2
+--R                         (- 1296a b c  + 1944a b c  - 729a b c + 81a b )d e
+--R                       + 
+--R                               7 4        6 2 3       5 4 2      4 6   3
+--R                         (2592a c  - 2592a b c  + 810a b c  - 81a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                           6        5 3  6         6 2      5 2       4 4    5
+--R                     (- 12a b c + 3a b )e  + (- 72a c  + 78a b c - 15a b )d e
+--R                   + 
+--R                          5   2       4 3       3 5  2 4
+--R                     (240a b c  - 180a b c + 30a b )d e
+--R                   + 
+--R                           5 3       4 2 2       3 4       2 6  3 3
+--R                     (- 48a c  - 276a b c  + 192a b c - 30a b )d e
+--R                   + 
+--R                          4   3      3 3 2      2 5         7  4 2
+--R                     (132a b c  + 99a b c  - 93a b c + 15a b )d e
+--R                   + 
+--R                         4 4       3 2 3      2 4 2        6      8  5
+--R                     (24a c  - 138a b c  + 33a b c  + 12a b c - 3b )d e
+--R                   + 
+--R                           3   4      2 3 3        5 2     7   6
+--R                     (- 24a b c  + 54a b c  - 24a b c  + 3b c)d
+--R                *
+--R                   ROOT
+--R                                 5       4 2
+--R                            (108a c - 27a b )
+--R                         *
+--R                            ROOT
+--R                                      6 2 6         6        5 3    5
+--R                                   - a b e  + (- 12a b c + 6a b )d e
+--R                                 + 
+--R                                         6 2      5 2       4 4  2 4
+--R                                   (- 36a c  + 54a b c - 15a b )d e
+--R                                 + 
+--R                                        5   2      4 3       3 5  3 3
+--R                                   (112a b c  - 98a b c + 20a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2      3 4       2 6  4 2
+--R                                   (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  5
+--R                                   (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                                 + 
+--R                                      4 4      3 2 3      2 4 2       6     8  6
+--R                                 (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                              /
+--R                                       11 3         10 2 2        9 4        8 6
+--R                                 46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                        + 
+--R                         3 3     2     2        2        2  2               3  3
+--R                        a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R                     /
+--R                            5       4 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                       5     7       5 2      4 2     6
+--R                     2a b c e  + (12a c  - 10a b c)d e
+--R                   + 
+--R                           4   2      3 3   2 5
+--R                     (- 38a b c  + 20a b c)d e
+--R                   + 
+--R                         4 3      3 2 2      2 4   3 4
+--R                     (20a c  + 40a b c  - 20a b c)d e
+--R                   + 
+--R                           3   3      2 3 2        5   4 3
+--R                     (- 50a b c  - 10a b c  + 10a b c)d e
+--R                   + 
+--R                        3 4      2 2 3       4 2     6   5 2
+--R                     (4a c  + 42a b c  - 8a b c  - 2b c)d e
+--R                   + 
+--R                           2   4        3 3     5 2  6
+--R                     (- 10a b c  - 10a b c  + 4b c )d e
+--R                   + 
+--R                          2 5       2 4     4 3  7
+--R                     (- 4a c  + 8a b c  - 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R         2a x
+--R      *
+--R         ROOT
+--R                         5       4 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                  ROOT
+--R                            6 2 6         6        5 3    5
+--R                         - a b e  + (- 12a b c + 6a b )d e
+--R                       + 
+--R                               6 2      5 2       4 4  2 4
+--R                         (- 36a c  + 54a b c - 15a b )d e
+--R                       + 
+--R                              5   2      4 3       3 5  3 3
+--R                         (112a b c  - 98a b c + 20a b )d e
+--R                       + 
+--R                             5 3       4 2 2      3 4       2 6  4 2
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                               4   3      3 3 2      2 5        7  5
+--R                         (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                       + 
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                    /
+--R                             11 3         10 2 2        9 4        8 6
+--R                       46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R              + 
+--R                 3 3     2     2        2        2  2               3  3
+--R                a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R           /
+--R                  5       4 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                             9 3         8 2 2        7 4        6 6  2
+--R                      (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                    + 
+--R                               8   3         7 3 2        6 5        5 7
+--R                      (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )d e
+--R                    + 
+--R                                  8 4         7 2 3         6 4 2        5 6
+--R                          - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                        + 
+--R                                4 8
+--R                          - 243a b
+--R                     *
+--R                         2
+--R                        d
+--R                 *
+--R                    ROOT
+--R                              6 2 6         6        5 3    5
+--R                           - a b e  + (- 12a b c + 6a b )d e
+--R                         + 
+--R                                 6 2      5 2       4 4  2 4
+--R                           (- 36a c  + 54a b c - 15a b )d e
+--R                         + 
+--R                                5   2      4 3       3 5  3 3
+--R                           (112a b c  - 98a b c + 20a b )d e
+--R                         + 
+--R                               5 3       4 2 2      3 4       2 6  4 2
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  5
+--R                           (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                         + 
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                      /
+--R                               11 3         10 2 2        9 4        8 6
+--R                         46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                + 
+--R                        6 2      5 4  5          6   2       5 3       4 5    4
+--R                  (- 36a b c + 9a b )e  + (- 360a b c  + 270a b c - 45a b )d e
+--R                + 
+--R                         6 3        5 2 2       4 4       3 6  2 3
+--R                  (- 864a c  + 1512a b c  - 684a b c + 90a b )d e
+--R                + 
+--R                        5   3        4 3 2       3 5       2 7  3 2
+--R                  (2016a b c  - 2268a b c  + 801a b c - 90a b )d e
+--R                + 
+--R                       5 4        4 2 3        3 4 2       2 6         8  4
+--R                  (288a c  - 1764a b c  + 1503a b c  - 450a b c + 45a b )d e
+--R                + 
+--R                         4   4       3 3 3       2 5 2        7      9  5
+--R                  (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )d
+--R             *
+--R                  ROOT
+--R                                  5       4 2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                           ROOT
+--R                                     6 2 6         6        5 3    5
+--R                                  - a b e  + (- 12a b c + 6a b )d e
+--R                                + 
+--R                                        6 2      5 2       4 4  2 4
+--R                                  (- 36a c  + 54a b c - 15a b )d e
+--R                                + 
+--R                                       5   2      4 3       3 5  3 3
+--R                                  (112a b c  - 98a b c + 20a b )d e
+--R                                + 
+--R                                      5 3       4 2 2      3 4       2 6  4 2
+--R                                  (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  5
+--R                                  (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                                + 
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                             /
+--R                                      11 3         10 2 2        9 4        8 6
+--R                                46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                       + 
+--R                        3 3     2     2        2        2  2               3  3
+--R                       a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R                    /
+--R                           5       4 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                    5     7       5 2      4 2     6
+--R                  2a b c e  + (12a c  - 10a b c)d e
+--R                + 
+--R                        4   2      3 3   2 5       4 3      3 2 2      2 4   3 4
+--R                  (- 38a b c  + 20a b c)d e  + (20a c  + 40a b c  - 20a b c)d e
+--R                + 
+--R                        3   3      2 3 2        5   4 3
+--R                  (- 50a b c  - 10a b c  + 10a b c)d e
+--R                + 
+--R                     3 4      2 2 3       4 2     6   5 2
+--R                  (4a c  + 42a b c  - 8a b c  - 2b c)d e
+--R                + 
+--R                        2   4        3 3     5 2  6
+--R                  (- 10a b c  - 10a b c  + 4b c )d e
+--R                + 
+--R                       2 5       2 4     4 3  7
+--R                  (- 4a c  + 8a b c  - 2b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                            5       4 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                     ROOT
+--R                               6 2 6         6        5 3    5
+--R                            - a b e  + (- 12a b c + 6a b )d e
+--R                          + 
+--R                                  6 2      5 2       4 4  2 4
+--R                            (- 36a c  + 54a b c - 15a b )d e
+--R                          + 
+--R                                 5   2      4 3       3 5  3 3
+--R                            (112a b c  - 98a b c + 20a b )d e
+--R                          + 
+--R                                5 3       4 2 2      3 4       2 6  4 2
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                  4   3      3 3 2      2 5        7  5
+--R                            (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                          + 
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                       /
+--R                                11 3         10 2 2        9 4        8 6
+--R                          46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                    3 3     2     2        2        2  2               3  3
+--R                   a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                  9 3         8 2 2        7 4        6 6  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c + 243a b )e
+--R                       + 
+--R                                8   3         7 3 2        6 5        5 7
+--R                         (31104a b c  - 23328a b c  + 5832a b c - 486a b )d e
+--R                       + 
+--R                                   8 4         7 2 3         6 4 2        5 6
+--R                             15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                           + 
+--R                                 4 8
+--R                             243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                             6 2      5 4  5
+--R                         (36a b c - 9a b )e
+--R                       + 
+--R                              6   2       5 3       4 5    4
+--R                         (360a b c  - 270a b c + 45a b )d e
+--R                       + 
+--R                              6 3        5 2 2       4 4       3 6  2 3
+--R                         (864a c  - 1512a b c  + 684a b c - 90a b )d e
+--R                       + 
+--R                                 5   3        4 3 2       3 5       2 7  3 2
+--R                         (- 2016a b c  + 2268a b c  - 801a b c + 90a b )d e
+--R                       + 
+--R                                   5 4        4 2 3        3 4 2       2 6
+--R                             - 288a c  + 1764a b c  - 1503a b c  + 450a b c
+--R                           + 
+--R                                    8
+--R                             - 45a b
+--R                        *
+--R                            4
+--R                           d e
+--R                       + 
+--R                              4   4       3 3 3       2 5 2        7      9  5
+--R                         (216a b c  - 558a b c  + 378a b c  - 99a b c + 9b )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                     5       4 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                              ROOT
+--R                                        6 2 6         6        5 3    5
+--R                                     - a b e  + (- 12a b c + 6a b )d e
+--R                                   + 
+--R                                           6 2      5 2       4 4  2 4
+--R                                     (- 36a c  + 54a b c - 15a b )d e
+--R                                   + 
+--R                                          5   2      4 3       3 5  3 3
+--R                                     (112a b c  - 98a b c + 20a b )d e
+--R                                   + 
+--R                                         5 3       4 2 2      3 4       2 6  4 2
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 36a b c  + 84a b c  - 42a b c + 6a b )
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           11 3         10 2 2        9 4
+--R                                     46656a  c  - 34992a  b c  + 8748a b c
+--R                                   + 
+--R                                           8 6
+--R                                     - 729a b
+--R                          + 
+--R                             3 3     2     2        2        2  2
+--R                            a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                                       3  3
+--R                            (2a b c - b )d
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 8   2       7 3       6 5  3
+--R                         (- 1296a b c  + 648a b c - 81a b )e
+--R                       + 
+--R                                 8 3        7 2 2        6 4        5 6    2
+--R                         (- 2592a c  + 3888a b c  - 1458a b c + 162a b )d e
+--R                       + 
+--R                               7   3        6 3 2       5 5       4 7  2
+--R                         (1296a b c  - 1944a b c  + 729a b c - 81a b )d e
+--R                       + 
+--R                                 7 4        6 2 3       5 4 2      4 6   3
+--R                         (- 2592a c  + 2592a b c  - 810a b c  + 81a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                           6        5 3  6         6 2      5 2       4 4    5
+--R                     (- 12a b c + 3a b )e  + (- 72a c  + 78a b c - 15a b )d e
+--R                   + 
+--R                          5   2       4 3       3 5  2 4
+--R                     (240a b c  - 180a b c + 30a b )d e
+--R                   + 
+--R                           5 3       4 2 2       3 4       2 6  3 3
+--R                     (- 48a c  - 276a b c  + 192a b c - 30a b )d e
+--R                   + 
+--R                          4   3      3 3 2      2 5         7  4 2
+--R                     (132a b c  + 99a b c  - 93a b c + 15a b )d e
+--R                   + 
+--R                         4 4       3 2 3      2 4 2        6      8  5
+--R                     (24a c  - 138a b c  + 33a b c  + 12a b c - 3b )d e
+--R                   + 
+--R                           3   4      2 3 3        5 2     7   6
+--R                     (- 24a b c  + 54a b c  - 24a b c  + 3b c)d
+--R                *
+--R                   ROOT
+--R                                   5       4 2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                            ROOT
+--R                                      6 2 6         6        5 3    5
+--R                                   - a b e  + (- 12a b c + 6a b )d e
+--R                                 + 
+--R                                         6 2      5 2       4 4  2 4
+--R                                   (- 36a c  + 54a b c - 15a b )d e
+--R                                 + 
+--R                                        5   2      4 3       3 5  3 3
+--R                                   (112a b c  - 98a b c + 20a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2      3 4       2 6  4 2
+--R                                   (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  5
+--R                                   (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                                 + 
+--R                                      4 4      3 2 3      2 4 2       6     8  6
+--R                                 (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                              /
+--R                                       11 3         10 2 2        9 4        8 6
+--R                                 46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                        + 
+--R                         3 3     2     2        2        2  2               3  3
+--R                        a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R                     /
+--R                            5       4 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                       5     7       5 2      4 2     6
+--R                     2a b c e  + (12a c  - 10a b c)d e
+--R                   + 
+--R                           4   2      3 3   2 5
+--R                     (- 38a b c  + 20a b c)d e
+--R                   + 
+--R                         4 3      3 2 2      2 4   3 4
+--R                     (20a c  + 40a b c  - 20a b c)d e
+--R                   + 
+--R                           3   3      2 3 2        5   4 3
+--R                     (- 50a b c  - 10a b c  + 10a b c)d e
+--R                   + 
+--R                        3 4      2 2 3       4 2     6   5 2
+--R                     (4a c  + 42a b c  - 8a b c  - 2b c)d e
+--R                   + 
+--R                           2   4        3 3     5 2  6
+--R                     (- 10a b c  - 10a b c  + 4b c )d e
+--R                   + 
+--R                          2 5       2 4     4 3  7
+--R                     (- 4a c  + 8a b c  - 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R         2a x
+--R      *
+--R         ROOT
+--R                       5       4 2
+--R                  (108a c - 27a b )
+--R               *
+--R                  ROOT
+--R                            6 2 6         6        5 3    5
+--R                         - a b e  + (- 12a b c + 6a b )d e
+--R                       + 
+--R                               6 2      5 2       4 4  2 4
+--R                         (- 36a c  + 54a b c - 15a b )d e
+--R                       + 
+--R                              5   2      4 3       3 5  3 3
+--R                         (112a b c  - 98a b c + 20a b )d e
+--R                       + 
+--R                             5 3       4 2 2      3 4       2 6  4 2
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                               4   3      3 3 2      2 5        7  5
+--R                         (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                       + 
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                    /
+--R                             11 3         10 2 2        9 4        8 6
+--R                       46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R              + 
+--R                 3 3     2     2        2        2  2               3  3
+--R                a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R           /
+--R                  5       4 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                               9 3         8 2 2        7 4        6 6  2
+--R                      (- 15552a c  + 11664a b c  - 2916a b c + 243a b )e
+--R                    + 
+--R                             8   3         7 3 2        6 5        5 7
+--R                      (31104a b c  - 23328a b c  + 5832a b c - 486a b )d e
+--R                    + 
+--R                                8 4         7 2 3         6 4 2        5 6
+--R                          15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                        + 
+--R                              4 8
+--R                          243a b
+--R                     *
+--R                         2
+--R                        d
+--R                 *
+--R                    ROOT
+--R                              6 2 6         6        5 3    5
+--R                           - a b e  + (- 12a b c + 6a b )d e
+--R                         + 
+--R                                 6 2      5 2       4 4  2 4
+--R                           (- 36a c  + 54a b c - 15a b )d e
+--R                         + 
+--R                                5   2      4 3       3 5  3 3
+--R                           (112a b c  - 98a b c + 20a b )d e
+--R                         + 
+--R                               5 3       4 2 2      3 4       2 6  4 2
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  5
+--R                           (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                         + 
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                      /
+--R                               11 3         10 2 2        9 4        8 6
+--R                         46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                + 
+--R                        6 2      5 4  5          6   2       5 3       4 5    4
+--R                  (- 36a b c + 9a b )e  + (- 360a b c  + 270a b c - 45a b )d e
+--R                + 
+--R                         6 3        5 2 2       4 4       3 6  2 3
+--R                  (- 864a c  + 1512a b c  - 684a b c + 90a b )d e
+--R                + 
+--R                        5   3        4 3 2       3 5       2 7  3 2
+--R                  (2016a b c  - 2268a b c  + 801a b c - 90a b )d e
+--R                + 
+--R                       5 4        4 2 3        3 4 2       2 6         8  4
+--R                  (288a c  - 1764a b c  + 1503a b c  - 450a b c + 45a b )d e
+--R                + 
+--R                         4   4       3 3 3       2 5 2        7      9  5
+--R                  (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )d
+--R             *
+--R                  ROOT
+--R                                5       4 2
+--R                           (108a c - 27a b )
+--R                        *
+--R                           ROOT
+--R                                     6 2 6         6        5 3    5
+--R                                  - a b e  + (- 12a b c + 6a b )d e
+--R                                + 
+--R                                        6 2      5 2       4 4  2 4
+--R                                  (- 36a c  + 54a b c - 15a b )d e
+--R                                + 
+--R                                       5   2      4 3       3 5  3 3
+--R                                  (112a b c  - 98a b c + 20a b )d e
+--R                                + 
+--R                                      5 3       4 2 2      3 4       2 6  4 2
+--R                                  (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  5
+--R                                  (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                                + 
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                             /
+--R                                      11 3         10 2 2        9 4        8 6
+--R                                46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                       + 
+--R                        3 3     2     2        2        2  2               3  3
+--R                       a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R                    /
+--R                           5       4 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                    5     7       5 2      4 2     6
+--R                  2a b c e  + (12a c  - 10a b c)d e
+--R                + 
+--R                        4   2      3 3   2 5       4 3      3 2 2      2 4   3 4
+--R                  (- 38a b c  + 20a b c)d e  + (20a c  + 40a b c  - 20a b c)d e
+--R                + 
+--R                        3   3      2 3 2        5   4 3
+--R                  (- 50a b c  - 10a b c  + 10a b c)d e
+--R                + 
+--R                     3 4      2 2 3       4 2     6   5 2
+--R                  (4a c  + 42a b c  - 8a b c  - 2b c)d e
+--R                + 
+--R                        2   4        3 3     5 2  6
+--R                  (- 10a b c  - 10a b c  + 4b c )d e
+--R                + 
+--R                       2 5       2 4     4 3  7
+--R                  (- 4a c  + 8a b c  - 2b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                 +-+
+--R            2a x\|3
+--R         *
+--R            ROOT
+--R                            5       4 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                     ROOT
+--R                               6 2 6         6        5 3    5
+--R                            - a b e  + (- 12a b c + 6a b )d e
+--R                          + 
+--R                                  6 2      5 2       4 4  2 4
+--R                            (- 36a c  + 54a b c - 15a b )d e
+--R                          + 
+--R                                 5   2      4 3       3 5  3 3
+--R                            (112a b c  - 98a b c + 20a b )d e
+--R                          + 
+--R                                5 3       4 2 2      3 4       2 6  4 2
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                  4   3      3 3 2      2 5        7  5
+--R                            (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                          + 
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                       /
+--R                                11 3         10 2 2        9 4        8 6
+--R                          46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                    3 3     2     2        2        2  2               3  3
+--R                   a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                                9 3         8 2 2        7 4        6 6  2
+--R                         (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                       + 
+--R                                  8   3         7 3 2        6 5        5 7
+--R                         (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )d e
+--R                       + 
+--R                                     8 4         7 2 3         6 4 2        5 6
+--R                             - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                           + 
+--R                                   4 8
+--R                             - 243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                               6 2      5 4  5
+--R                         (- 36a b c + 9a b )e
+--R                       + 
+--R                                6   2       5 3       4 5    4
+--R                         (- 360a b c  + 270a b c - 45a b )d e
+--R                       + 
+--R                                6 3        5 2 2       4 4       3 6  2 3
+--R                         (- 864a c  + 1512a b c  - 684a b c + 90a b )d e
+--R                       + 
+--R                               5   3        4 3 2       3 5       2 7  3 2
+--R                         (2016a b c  - 2268a b c  + 801a b c - 90a b )d e
+--R                       + 
+--R                                   5 4        4 2 3        3 4 2       2 6
+--R                               288a c  - 1764a b c  + 1503a b c  - 450a b c
+--R                             + 
+--R                                    8
+--R                               45a b
+--R                        *
+--R                            4
+--R                           d e
+--R                       + 
+--R                              4   4       3 3 3       2 5 2        7      9  5
+--R                       (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                     5       4 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                              ROOT
+--R                                        6 2 6         6        5 3    5
+--R                                     - a b e  + (- 12a b c + 6a b )d e
+--R                                   + 
+--R                                           6 2      5 2       4 4  2 4
+--R                                     (- 36a c  + 54a b c - 15a b )d e
+--R                                   + 
+--R                                          5   2      4 3       3 5  3 3
+--R                                     (112a b c  - 98a b c + 20a b )d e
+--R                                   + 
+--R                                         5 3       4 2 2      3 4       2 6  4 2
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 36a b c  + 84a b c  - 42a b c + 6a b )
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           11 3         10 2 2        9 4
+--R                                     46656a  c  - 34992a  b c  + 8748a b c
+--R                                   + 
+--R                                           8 6
+--R                                     - 729a b
+--R                          + 
+--R                             3 3     2     2        2        2  2
+--R                            a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                                       3  3
+--R                            (2a b c - b )d
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                  9 3         8 2 2        7 4        6 6  2
+--R                           (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                         + 
+--R                                      8   3         7 3 2        6 5        5 7
+--R                             (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )
+--R                          *
+--R                             d e
+--R                         + 
+--R                                       8 4         7 2 3         6 4 2
+--R                               - 15552a c  + 27216a b c  - 14580a b c
+--R                             + 
+--R                                    5 6        4 8
+--R                               3159a b c - 243a b
+--R                          *
+--R                              2
+--R                             d
+--R                      *
+--R                         ROOT
+--R                                   6 2 6         6        5 3    5
+--R                                - a b e  + (- 12a b c + 6a b )d e
+--R                              + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                (- 36a c  + 54a b c - 15a b )d e
+--R                              + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                (112a b c  - 98a b c + 20a b )d e
+--R                              + 
+--R                                    5 3       4 2 2      3 4       2 6  4 2
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  5
+--R                                (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                              + 
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                           /
+--R                                    11 3         10 2 2        9 4        8 6
+--R                              46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                     + 
+--R                             6 2      5 4  5
+--R                       (- 36a b c + 9a b )e
+--R                     + 
+--R                              6   2       5 3       4 5    4
+--R                       (- 360a b c  + 270a b c - 45a b )d e
+--R                     + 
+--R                              6 3        5 2 2       4 4       3 6  2 3
+--R                       (- 864a c  + 1512a b c  - 684a b c + 90a b )d e
+--R                     + 
+--R                             5   3        4 3 2       3 5       2 7  3 2
+--R                       (2016a b c  - 2268a b c  + 801a b c - 90a b )d e
+--R                     + 
+--R                              5 4        4 2 3        3 4 2       2 6         8
+--R                         (288a c  - 1764a b c  + 1503a b c  - 450a b c + 45a b )
+--R                      *
+--R                          4
+--R                         d e
+--R                     + 
+--R                              4   4       3 3 3       2 5 2        7      9  5
+--R                       (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )d
+--R                  *
+--R                       ROOT
+--R                                       5       4 2
+--R                                (- 108a c + 27a b )
+--R                             *
+--R                                ROOT
+--R                                          6 2 6         6        5 3    5
+--R                                       - a b e  + (- 12a b c + 6a b )d e
+--R                                     + 
+--R                                             6 2      5 2       4 4  2 4
+--R                                       (- 36a c  + 54a b c - 15a b )d e
+--R                                     + 
+--R                                            5   2      4 3       3 5  3 3
+--R                                       (112a b c  - 98a b c + 20a b )d e
+--R                                     + 
+--R                                             5 3       4 2 2      3 4       2 6
+--R                                         (24a c  - 141a b c  + 90a b c - 15a b )
+--R                                      *
+--R                                          4 2
+--R                                         d e
+--R                                     + 
+--R                                                  4   3      3 3 2      2 5
+--R                                             - 36a b c  + 84a b c  - 42a b c
+--R                                           + 
+--R                                                 7
+--R                                             6a b
+--R                                      *
+--R                                          5
+--R                                         d e
+--R                                     + 
+--R                                               4 4      3 2 3      2 4 2
+--R                                           - 4a c  + 16a b c  - 20a b c
+--R                                         + 
+--R                                               6     8
+--R                                           8a b c - b
+--R                                      *
+--R                                          6
+--R                                         d
+--R                                  /
+--R                                             11 3         10 2 2        9 4
+--R                                       46656a  c  - 34992a  b c  + 8748a b c
+--R                                     + 
+--R                                             8 6
+--R                                       - 729a b
+--R                            + 
+--R                               3 3     2     2        2        2  2
+--R                              a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                            + 
+--R                                         3  3
+--R                              (2a b c - b )d
+--R                         /
+--R                                5       4 2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                           5     7         5 2      4 2     6
+--R                       - 4a b c e  + (- 24a c  + 20a b c)d e
+--R                     + 
+--R                           4   2      3 3   2 5
+--R                       (76a b c  - 40a b c)d e
+--R                     + 
+--R                             4 3      3 2 2      2 4   3 4
+--R                       (- 40a c  - 80a b c  + 40a b c)d e
+--R                     + 
+--R                            3   3      2 3 2        5   4 3
+--R                       (100a b c  + 20a b c  - 20a b c)d e
+--R                     + 
+--R                            3 4      2 2 3        4 2     6   5 2
+--R                       (- 8a c  - 84a b c  + 16a b c  + 4b c)d e
+--R                     + 
+--R                           2   4        3 3     5 2  6
+--R                       (20a b c  + 20a b c  - 8b c )d e
+--R                     + 
+--R                          2 5        2 4     4 3  7
+--R                       (8a c  - 16a b c  + 4b c )d
+--R                  *
+--R                     x
+--R     + 
+--R       -
+--R                 +-+
+--R            2a x\|3
+--R         *
+--R            ROOT
+--R                          5       4 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                     ROOT
+--R                               6 2 6         6        5 3    5
+--R                            - a b e  + (- 12a b c + 6a b )d e
+--R                          + 
+--R                                  6 2      5 2       4 4  2 4
+--R                            (- 36a c  + 54a b c - 15a b )d e
+--R                          + 
+--R                                 5   2      4 3       3 5  3 3
+--R                            (112a b c  - 98a b c + 20a b )d e
+--R                          + 
+--R                                5 3       4 2 2      3 4       2 6  4 2
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                  4   3      3 3 2      2 5        7  5
+--R                            (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                          + 
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                       /
+--R                                11 3         10 2 2        9 4        8 6
+--R                          46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                    3 3     2     2        2        2  2               3  3
+--R                   a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            atan
+--R                                9 3         8 2 2        7 4        6 6  2
+--R                         (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                       + 
+--R                                  8   3         7 3 2        6 5        5 7
+--R                         (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )d e
+--R                       + 
+--R                                     8 4         7 2 3         6 4 2        5 6
+--R                             - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                           + 
+--R                                   4 8
+--R                             - 243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                             6 2      5 4  5
+--R                         (36a b c - 9a b )e
+--R                       + 
+--R                              6   2       5 3       4 5    4
+--R                         (360a b c  - 270a b c + 45a b )d e
+--R                       + 
+--R                              6 3        5 2 2       4 4       3 6  2 3
+--R                         (864a c  - 1512a b c  + 684a b c - 90a b )d e
+--R                       + 
+--R                                 5   3        4 3 2       3 5       2 7  3 2
+--R                         (- 2016a b c  + 2268a b c  - 801a b c + 90a b )d e
+--R                       + 
+--R                                   5 4        4 2 3        3 4 2       2 6
+--R                             - 288a c  + 1764a b c  - 1503a b c  + 450a b c
+--R                           + 
+--R                                    8
+--R                             - 45a b
+--R                        *
+--R                            4
+--R                           d e
+--R                       + 
+--R                              4   4       3 3 3       2 5 2        7      9  5
+--R                         (216a b c  - 558a b c  + 378a b c  - 99a b c + 9b )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                   5       4 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                              ROOT
+--R                                        6 2 6         6        5 3    5
+--R                                     - a b e  + (- 12a b c + 6a b )d e
+--R                                   + 
+--R                                           6 2      5 2       4 4  2 4
+--R                                     (- 36a c  + 54a b c - 15a b )d e
+--R                                   + 
+--R                                          5   2      4 3       3 5  3 3
+--R                                     (112a b c  - 98a b c + 20a b )d e
+--R                                   + 
+--R                                         5 3       4 2 2      3 4       2 6  4 2
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 36a b c  + 84a b c  - 42a b c + 6a b )
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           11 3         10 2 2        9 4
+--R                                     46656a  c  - 34992a  b c  + 8748a b c
+--R                                   + 
+--R                                           8 6
+--R                                     - 729a b
+--R                          + 
+--R                             3 3     2     2        2        2  2
+--R                            a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                                       3  3
+--R                            (2a b c - b )d
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                  9 3         8 2 2        7 4        6 6  2
+--R                           (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                         + 
+--R                                      8   3         7 3 2        6 5        5 7
+--R                             (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )
+--R                          *
+--R                             d e
+--R                         + 
+--R                                       8 4         7 2 3         6 4 2
+--R                               - 15552a c  + 27216a b c  - 14580a b c
+--R                             + 
+--R                                    5 6        4 8
+--R                               3159a b c - 243a b
+--R                          *
+--R                              2
+--R                             d
+--R                      *
+--R                         ROOT
+--R                                   6 2 6         6        5 3    5
+--R                                - a b e  + (- 12a b c + 6a b )d e
+--R                              + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                (- 36a c  + 54a b c - 15a b )d e
+--R                              + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                (112a b c  - 98a b c + 20a b )d e
+--R                              + 
+--R                                    5 3       4 2 2      3 4       2 6  4 2
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  5
+--R                                (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                              + 
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                           /
+--R                                    11 3         10 2 2        9 4        8 6
+--R                              46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                     + 
+--R                           6 2      5 4  5        6   2       5 3       4 5    4
+--R                       (36a b c - 9a b )e  + (360a b c  - 270a b c + 45a b )d e
+--R                     + 
+--R                            6 3        5 2 2       4 4       3 6  2 3
+--R                       (864a c  - 1512a b c  + 684a b c - 90a b )d e
+--R                     + 
+--R                               5   3        4 3 2       3 5       2 7  3 2
+--R                       (- 2016a b c  + 2268a b c  - 801a b c + 90a b )d e
+--R                     + 
+--R                                   5 4        4 2 3        3 4 2       2 6
+--R                             - 288a c  + 1764a b c  - 1503a b c  + 450a b c
+--R                           + 
+--R                                    8
+--R                             - 45a b
+--R                      *
+--R                          4
+--R                         d e
+--R                     + 
+--R                            4   4       3 3 3       2 5 2        7      9  5
+--R                       (216a b c  - 558a b c  + 378a b c  - 99a b c + 9b )d
+--R                  *
+--R                       ROOT
+--R                                     5       4 2
+--R                                (108a c - 27a b )
+--R                             *
+--R                                ROOT
+--R                                          6 2 6         6        5 3    5
+--R                                       - a b e  + (- 12a b c + 6a b )d e
+--R                                     + 
+--R                                             6 2      5 2       4 4  2 4
+--R                                       (- 36a c  + 54a b c - 15a b )d e
+--R                                     + 
+--R                                            5   2      4 3       3 5  3 3
+--R                                       (112a b c  - 98a b c + 20a b )d e
+--R                                     + 
+--R                                             5 3       4 2 2      3 4       2 6
+--R                                         (24a c  - 141a b c  + 90a b c - 15a b )
+--R                                      *
+--R                                          4 2
+--R                                         d e
+--R                                     + 
+--R                                                  4   3      3 3 2      2 5
+--R                                             - 36a b c  + 84a b c  - 42a b c
+--R                                           + 
+--R                                                 7
+--R                                             6a b
+--R                                      *
+--R                                          5
+--R                                         d e
+--R                                     + 
+--R                                               4 4      3 2 3      2 4 2
+--R                                           - 4a c  + 16a b c  - 20a b c
+--R                                         + 
+--R                                               6     8
+--R                                           8a b c - b
+--R                                      *
+--R                                          6
+--R                                         d
+--R                                  /
+--R                                             11 3         10 2 2        9 4
+--R                                       46656a  c  - 34992a  b c  + 8748a b c
+--R                                     + 
+--R                                             8 6
+--R                                       - 729a b
+--R                            + 
+--R                               3 3     2     2        2        2  2
+--R                              a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                            + 
+--R                                         3  3
+--R                              (2a b c - b )d
+--R                         /
+--R                                5       4 2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                         5     7       5 2      4 2     6
+--R                       4a b c e  + (24a c  - 20a b c)d e
+--R                     + 
+--R                             4   2      3 3   2 5
+--R                       (- 76a b c  + 40a b c)d e
+--R                     + 
+--R                           4 3      3 2 2      2 4   3 4
+--R                       (40a c  + 80a b c  - 40a b c)d e
+--R                     + 
+--R                              3   3      2 3 2        5   4 3
+--R                       (- 100a b c  - 20a b c  + 20a b c)d e
+--R                     + 
+--R                          3 4      2 2 3        4 2     6   5 2
+--R                       (8a c  + 84a b c  - 16a b c  - 4b c)d e
+--R                     + 
+--R                             2   4        3 3     5 2  6
+--R                       (- 20a b c  - 20a b c  + 8b c )d e
+--R                     + 
+--R                            2 5        2 4     4 3  7
+--R                       (- 8a c  + 16a b c  - 4b c )d
+--R                  *
+--R                     x
+--R     + 
+--R       - 2d
+--R  /
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 37
+
+--S 38 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +--------------------+
+--R                +-----------+                         |   +-----------+
+--R            +-+ |          2                 +-+ 3+-+3|   |          2
+--R         (d\|3 \|- 4a c + b   + (2a e - b d)\|3 )\|c \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                   +-----------+
+--R               +-+ |          2                    +-+ 3+-+
+--R         (- 2d\|3 \|- 4a c + b   + (- 4a e + 2b d)\|3 )\|c
+--R      *
+--R          +--------------------+     +------------------+
+--R          |   +-----------+          | +-----------+
+--R         3|   |          2          3| |          2          3+-+3+-+
+--R         \|- \|- 4a c + b   + b log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                                       +--------------------+
+--R                         +-----------+ |   +-----------+
+--R               3+-+2 +-+ |          2 3|   |          2
+--R            3a \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          5       4 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                     ROOT
+--R                               6 2 6         6        5 3    5
+--R                            - a b e  + (- 12a b c + 6a b )d e
+--R                          + 
+--R                                  6 2      5 2       4 4  2 4
+--R                            (- 36a c  + 54a b c - 15a b )d e
+--R                          + 
+--R                                 5   2      4 3       3 5  3 3
+--R                            (112a b c  - 98a b c + 20a b )d e
+--R                          + 
+--R                                5 3       4 2 2      3 4       2 6  4 2
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                  4   3      3 3 2      2 5        7  5
+--R                            (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                          + 
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                       /
+--R                                11 3         10 2 2        9 4        8 6
+--R                          46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                    3 3     2     2        2        2  2               3  3
+--R                   a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                9 3         8 2 2        7 4        6 6  2
+--R                         (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                       + 
+--R                                  8   3         7 3 2        6 5        5 7
+--R                         (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )d e
+--R                       + 
+--R                                     8 4         7 2 3         6 4 2        5 6
+--R                             - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                           + 
+--R                                   4 8
+--R                             - 243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                             6 2      5 4  5
+--R                         (36a b c - 9a b )e
+--R                       + 
+--R                              6   2       5 3       4 5    4
+--R                         (360a b c  - 270a b c + 45a b )d e
+--R                       + 
+--R                              6 3        5 2 2       4 4       3 6  2 3
+--R                         (864a c  - 1512a b c  + 684a b c - 90a b )d e
+--R                       + 
+--R                                 5   3        4 3 2       3 5       2 7  3 2
+--R                         (- 2016a b c  + 2268a b c  - 801a b c + 90a b )d e
+--R                       + 
+--R                                   5 4        4 2 3        3 4 2       2 6
+--R                             - 288a c  + 1764a b c  - 1503a b c  + 450a b c
+--R                           + 
+--R                                    8
+--R                             - 45a b
+--R                        *
+--R                            4
+--R                           d e
+--R                       + 
+--R                              4   4       3 3 3       2 5 2        7      9  5
+--R                         (216a b c  - 558a b c  + 378a b c  - 99a b c + 9b )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                   5       4 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                              ROOT
+--R                                        6 2 6         6        5 3    5
+--R                                     - a b e  + (- 12a b c + 6a b )d e
+--R                                   + 
+--R                                           6 2      5 2       4 4  2 4
+--R                                     (- 36a c  + 54a b c - 15a b )d e
+--R                                   + 
+--R                                          5   2      4 3       3 5  3 3
+--R                                     (112a b c  - 98a b c + 20a b )d e
+--R                                   + 
+--R                                         5 3       4 2 2      3 4       2 6  4 2
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 36a b c  + 84a b c  - 42a b c + 6a b )
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           11 3         10 2 2        9 4
+--R                                     46656a  c  - 34992a  b c  + 8748a b c
+--R                                   + 
+--R                                           8 6
+--R                                     - 729a b
+--R                          + 
+--R                             3 3     2     2        2        2  2
+--R                            a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                                       3  3
+--R                            (2a b c - b )d
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               8   2       7 3       6 5  3
+--R                         (1296a b c  - 648a b c + 81a b )e
+--R                       + 
+--R                               8 3        7 2 2        6 4        5 6    2
+--R                         (2592a c  - 3888a b c  + 1458a b c - 162a b )d e
+--R                       + 
+--R                                 7   3        6 3 2       5 5       4 7  2
+--R                         (- 1296a b c  + 1944a b c  - 729a b c + 81a b )d e
+--R                       + 
+--R                               7 4        6 2 3       5 4 2      4 6   3
+--R                         (2592a c  - 2592a b c  + 810a b c  - 81a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                           6        5 3  6         6 2      5 2       4 4    5
+--R                     (- 12a b c + 3a b )e  + (- 72a c  + 78a b c - 15a b )d e
+--R                   + 
+--R                          5   2       4 3       3 5  2 4
+--R                     (240a b c  - 180a b c + 30a b )d e
+--R                   + 
+--R                           5 3       4 2 2       3 4       2 6  3 3
+--R                     (- 48a c  - 276a b c  + 192a b c - 30a b )d e
+--R                   + 
+--R                          4   3      3 3 2      2 5         7  4 2
+--R                     (132a b c  + 99a b c  - 93a b c + 15a b )d e
+--R                   + 
+--R                         4 4       3 2 3      2 4 2        6      8  5
+--R                     (24a c  - 138a b c  + 33a b c  + 12a b c - 3b )d e
+--R                   + 
+--R                           3   4      2 3 3        5 2     7   6
+--R                     (- 24a b c  + 54a b c  - 24a b c  + 3b c)d
+--R                *
+--R                   ROOT
+--R                                 5       4 2
+--R                            (108a c - 27a b )
+--R                         *
+--R                            ROOT
+--R                                      6 2 6         6        5 3    5
+--R                                   - a b e  + (- 12a b c + 6a b )d e
+--R                                 + 
+--R                                         6 2      5 2       4 4  2 4
+--R                                   (- 36a c  + 54a b c - 15a b )d e
+--R                                 + 
+--R                                        5   2      4 3       3 5  3 3
+--R                                   (112a b c  - 98a b c + 20a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2      3 4       2 6  4 2
+--R                                   (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  5
+--R                                   (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                                 + 
+--R                                      4 4      3 2 3      2 4 2       6     8  6
+--R                                 (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                              /
+--R                                       11 3         10 2 2        9 4        8 6
+--R                                 46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                        + 
+--R                         3 3     2     2        2        2  2               3  3
+--R                        a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R                     /
+--R                            5       4 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                       5     7       5 2      4 2     6
+--R                     2a b c e  + (12a c  - 10a b c)d e
+--R                   + 
+--R                           4   2      3 3   2 5
+--R                     (- 38a b c  + 20a b c)d e
+--R                   + 
+--R                         4 3      3 2 2      2 4   3 4
+--R                     (20a c  + 40a b c  - 20a b c)d e
+--R                   + 
+--R                           3   3      2 3 2        5   4 3
+--R                     (- 50a b c  - 10a b c  + 10a b c)d e
+--R                   + 
+--R                        3 4      2 2 3       4 2     6   5 2
+--R                     (4a c  + 42a b c  - 8a b c  - 2b c)d e
+--R                   + 
+--R                           2   4        3 3     5 2  6
+--R                     (- 10a b c  - 10a b c  + 4b c )d e
+--R                   + 
+--R                          2 5       2 4     4 3  7
+--R                     (- 4a c  + 8a b c  - 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                                    +--------------------+
+--R                      +-----------+ |   +-----------+
+--R            3+-+2 +-+ |          2 3|   |          2
+--R         6a \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         5       4 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                  ROOT
+--R                            6 2 6         6        5 3    5
+--R                         - a b e  + (- 12a b c + 6a b )d e
+--R                       + 
+--R                               6 2      5 2       4 4  2 4
+--R                         (- 36a c  + 54a b c - 15a b )d e
+--R                       + 
+--R                              5   2      4 3       3 5  3 3
+--R                         (112a b c  - 98a b c + 20a b )d e
+--R                       + 
+--R                             5 3       4 2 2      3 4       2 6  4 2
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                               4   3      3 3 2      2 5        7  5
+--R                         (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                       + 
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                    /
+--R                             11 3         10 2 2        9 4        8 6
+--R                       46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R              + 
+--R                 3 3     2     2        2        2  2               3  3
+--R                a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R           /
+--R                  5       4 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                             9 3         8 2 2        7 4        6 6  2
+--R                      (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                    + 
+--R                               8   3         7 3 2        6 5        5 7
+--R                      (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )d e
+--R                    + 
+--R                                  8 4         7 2 3         6 4 2        5 6
+--R                          - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                        + 
+--R                                4 8
+--R                          - 243a b
+--R                     *
+--R                         2
+--R                        d
+--R                 *
+--R                    ROOT
+--R                              6 2 6         6        5 3    5
+--R                           - a b e  + (- 12a b c + 6a b )d e
+--R                         + 
+--R                                 6 2      5 2       4 4  2 4
+--R                           (- 36a c  + 54a b c - 15a b )d e
+--R                         + 
+--R                                5   2      4 3       3 5  3 3
+--R                           (112a b c  - 98a b c + 20a b )d e
+--R                         + 
+--R                               5 3       4 2 2      3 4       2 6  4 2
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  5
+--R                           (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                         + 
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                      /
+--R                               11 3         10 2 2        9 4        8 6
+--R                         46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                + 
+--R                        6 2      5 4  5          6   2       5 3       4 5    4
+--R                  (- 36a b c + 9a b )e  + (- 360a b c  + 270a b c - 45a b )d e
+--R                + 
+--R                         6 3        5 2 2       4 4       3 6  2 3
+--R                  (- 864a c  + 1512a b c  - 684a b c + 90a b )d e
+--R                + 
+--R                        5   3        4 3 2       3 5       2 7  3 2
+--R                  (2016a b c  - 2268a b c  + 801a b c - 90a b )d e
+--R                + 
+--R                       5 4        4 2 3        3 4 2       2 6         8  4
+--R                  (288a c  - 1764a b c  + 1503a b c  - 450a b c + 45a b )d e
+--R                + 
+--R                         4   4       3 3 3       2 5 2        7      9  5
+--R                  (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )d
+--R             *
+--R                  ROOT
+--R                                  5       4 2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                           ROOT
+--R                                     6 2 6         6        5 3    5
+--R                                  - a b e  + (- 12a b c + 6a b )d e
+--R                                + 
+--R                                        6 2      5 2       4 4  2 4
+--R                                  (- 36a c  + 54a b c - 15a b )d e
+--R                                + 
+--R                                       5   2      4 3       3 5  3 3
+--R                                  (112a b c  - 98a b c + 20a b )d e
+--R                                + 
+--R                                      5 3       4 2 2      3 4       2 6  4 2
+--R                                  (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  5
+--R                                  (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                                + 
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                             /
+--R                                      11 3         10 2 2        9 4        8 6
+--R                                46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                       + 
+--R                        3 3     2     2        2        2  2               3  3
+--R                       a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R                    /
+--R                           5       4 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                    5     7       5 2      4 2     6
+--R                  2a b c e  + (12a c  - 10a b c)d e
+--R                + 
+--R                        4   2      3 3   2 5       4 3      3 2 2      2 4   3 4
+--R                  (- 38a b c  + 20a b c)d e  + (20a c  + 40a b c  - 20a b c)d e
+--R                + 
+--R                        3   3      2 3 2        5   4 3
+--R                  (- 50a b c  - 10a b c  + 10a b c)d e
+--R                + 
+--R                     3 4      2 2 3       4 2     6   5 2
+--R                  (4a c  + 42a b c  - 8a b c  - 2b c)d e
+--R                + 
+--R                        2   4        3 3     5 2  6
+--R                  (- 10a b c  - 10a b c  + 4b c )d e
+--R                + 
+--R                       2 5       2 4     4 3  7
+--R                  (- 4a c  + 8a b c  - 2b c )d
+--R             *
+--R                x
+--R     + 
+--R                                                        +------------------+
+--R                +-----------+                           | +-----------+
+--R            +-+ |          2                   +-+ 3+-+3| |          2
+--R         (d\|3 \|- 4a c + b   + (- 2a e + b d)\|3 )\|c \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                          +------------------+
+--R                   +-----------+                          | +-----------+
+--R               +-+ |          2                  +-+ 3+-+3| |          2
+--R         (- 2d\|3 \|- 4a c + b   + (4a e - 2b d)\|3 )\|c \|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                                       +--------------------+
+--R                         +-----------+ |   +-----------+
+--R               3+-+2 +-+ |          2 3|   |          2
+--R            3a \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            5       4 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                     ROOT
+--R                               6 2 6         6        5 3    5
+--R                            - a b e  + (- 12a b c + 6a b )d e
+--R                          + 
+--R                                  6 2      5 2       4 4  2 4
+--R                            (- 36a c  + 54a b c - 15a b )d e
+--R                          + 
+--R                                 5   2      4 3       3 5  3 3
+--R                            (112a b c  - 98a b c + 20a b )d e
+--R                          + 
+--R                                5 3       4 2 2      3 4       2 6  4 2
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                  4   3      3 3 2      2 5        7  5
+--R                            (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                          + 
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                       /
+--R                                11 3         10 2 2        9 4        8 6
+--R                          46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                    3 3     2     2        2        2  2               3  3
+--R                   a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                  9 3         8 2 2        7 4        6 6  2
+--R                         (- 15552a c  + 11664a b c  - 2916a b c + 243a b )e
+--R                       + 
+--R                                8   3         7 3 2        6 5        5 7
+--R                         (31104a b c  - 23328a b c  + 5832a b c - 486a b )d e
+--R                       + 
+--R                                   8 4         7 2 3         6 4 2        5 6
+--R                             15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                           + 
+--R                                 4 8
+--R                             243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                             6 2      5 4  5
+--R                         (36a b c - 9a b )e
+--R                       + 
+--R                              6   2       5 3       4 5    4
+--R                         (360a b c  - 270a b c + 45a b )d e
+--R                       + 
+--R                              6 3        5 2 2       4 4       3 6  2 3
+--R                         (864a c  - 1512a b c  + 684a b c - 90a b )d e
+--R                       + 
+--R                                 5   3        4 3 2       3 5       2 7  3 2
+--R                         (- 2016a b c  + 2268a b c  - 801a b c + 90a b )d e
+--R                       + 
+--R                                   5 4        4 2 3        3 4 2       2 6
+--R                             - 288a c  + 1764a b c  - 1503a b c  + 450a b c
+--R                           + 
+--R                                    8
+--R                             - 45a b
+--R                        *
+--R                            4
+--R                           d e
+--R                       + 
+--R                              4   4       3 3 3       2 5 2        7      9  5
+--R                         (216a b c  - 558a b c  + 378a b c  - 99a b c + 9b )d
+--R                    *
+--R                       x
+--R                *
+--R                     ROOT
+--R                                     5       4 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                              ROOT
+--R                                        6 2 6         6        5 3    5
+--R                                     - a b e  + (- 12a b c + 6a b )d e
+--R                                   + 
+--R                                           6 2      5 2       4 4  2 4
+--R                                     (- 36a c  + 54a b c - 15a b )d e
+--R                                   + 
+--R                                          5   2      4 3       3 5  3 3
+--R                                     (112a b c  - 98a b c + 20a b )d e
+--R                                   + 
+--R                                         5 3       4 2 2      3 4       2 6  4 2
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 36a b c  + 84a b c  - 42a b c + 6a b )
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           11 3         10 2 2        9 4
+--R                                     46656a  c  - 34992a  b c  + 8748a b c
+--R                                   + 
+--R                                           8 6
+--R                                     - 729a b
+--R                          + 
+--R                             3 3     2     2        2        2  2
+--R                            a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                                       3  3
+--R                            (2a b c - b )d
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 8   2       7 3       6 5  3
+--R                         (- 1296a b c  + 648a b c - 81a b )e
+--R                       + 
+--R                                 8 3        7 2 2        6 4        5 6    2
+--R                         (- 2592a c  + 3888a b c  - 1458a b c + 162a b )d e
+--R                       + 
+--R                               7   3        6 3 2       5 5       4 7  2
+--R                         (1296a b c  - 1944a b c  + 729a b c - 81a b )d e
+--R                       + 
+--R                                 7 4        6 2 3       5 4 2      4 6   3
+--R                         (- 2592a c  + 2592a b c  - 810a b c  + 81a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                           6        5 3  6         6 2      5 2       4 4    5
+--R                     (- 12a b c + 3a b )e  + (- 72a c  + 78a b c - 15a b )d e
+--R                   + 
+--R                          5   2       4 3       3 5  2 4
+--R                     (240a b c  - 180a b c + 30a b )d e
+--R                   + 
+--R                           5 3       4 2 2       3 4       2 6  3 3
+--R                     (- 48a c  - 276a b c  + 192a b c - 30a b )d e
+--R                   + 
+--R                          4   3      3 3 2      2 5         7  4 2
+--R                     (132a b c  + 99a b c  - 93a b c + 15a b )d e
+--R                   + 
+--R                         4 4       3 2 3      2 4 2        6      8  5
+--R                     (24a c  - 138a b c  + 33a b c  + 12a b c - 3b )d e
+--R                   + 
+--R                           3   4      2 3 3        5 2     7   6
+--R                     (- 24a b c  + 54a b c  - 24a b c  + 3b c)d
+--R                *
+--R                   ROOT
+--R                                   5       4 2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                            ROOT
+--R                                      6 2 6         6        5 3    5
+--R                                   - a b e  + (- 12a b c + 6a b )d e
+--R                                 + 
+--R                                         6 2      5 2       4 4  2 4
+--R                                   (- 36a c  + 54a b c - 15a b )d e
+--R                                 + 
+--R                                        5   2      4 3       3 5  3 3
+--R                                   (112a b c  - 98a b c + 20a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2      3 4       2 6  4 2
+--R                                   (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  5
+--R                                   (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                                 + 
+--R                                      4 4      3 2 3      2 4 2       6     8  6
+--R                                 (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                              /
+--R                                       11 3         10 2 2        9 4        8 6
+--R                                 46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                        + 
+--R                         3 3     2     2        2        2  2               3  3
+--R                        a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R                     /
+--R                            5       4 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                       5     7       5 2      4 2     6
+--R                     2a b c e  + (12a c  - 10a b c)d e
+--R                   + 
+--R                           4   2      3 3   2 5
+--R                     (- 38a b c  + 20a b c)d e
+--R                   + 
+--R                         4 3      3 2 2      2 4   3 4
+--R                     (20a c  + 40a b c  - 20a b c)d e
+--R                   + 
+--R                           3   3      2 3 2        5   4 3
+--R                     (- 50a b c  - 10a b c  + 10a b c)d e
+--R                   + 
+--R                        3 4      2 2 3       4 2     6   5 2
+--R                     (4a c  + 42a b c  - 8a b c  - 2b c)d e
+--R                   + 
+--R                           2   4        3 3     5 2  6
+--R                     (- 10a b c  - 10a b c  + 4b c )d e
+--R                   + 
+--R                          2 5       2 4     4 3  7
+--R                     (- 4a c  + 8a b c  - 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                                    +--------------------+
+--R                      +-----------+ |   +-----------+
+--R            3+-+2 +-+ |          2 3|   |          2
+--R         6a \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       5       4 2
+--R                  (108a c - 27a b )
+--R               *
+--R                  ROOT
+--R                            6 2 6         6        5 3    5
+--R                         - a b e  + (- 12a b c + 6a b )d e
+--R                       + 
+--R                               6 2      5 2       4 4  2 4
+--R                         (- 36a c  + 54a b c - 15a b )d e
+--R                       + 
+--R                              5   2      4 3       3 5  3 3
+--R                         (112a b c  - 98a b c + 20a b )d e
+--R                       + 
+--R                             5 3       4 2 2      3 4       2 6  4 2
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                               4   3      3 3 2      2 5        7  5
+--R                         (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                       + 
+--R                              4 4      3 2 3      2 4 2       6     8  6
+--R                         (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                    /
+--R                             11 3         10 2 2        9 4        8 6
+--R                       46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R              + 
+--R                 3 3     2     2        2        2  2               3  3
+--R                a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R           /
+--R                  5       4 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               9 3         8 2 2        7 4        6 6  2
+--R                      (- 15552a c  + 11664a b c  - 2916a b c + 243a b )e
+--R                    + 
+--R                             8   3         7 3 2        6 5        5 7
+--R                      (31104a b c  - 23328a b c  + 5832a b c - 486a b )d e
+--R                    + 
+--R                                8 4         7 2 3         6 4 2        5 6
+--R                          15552a c  - 27216a b c  + 14580a b c  - 3159a b c
+--R                        + 
+--R                              4 8
+--R                          243a b
+--R                     *
+--R                         2
+--R                        d
+--R                 *
+--R                    ROOT
+--R                              6 2 6         6        5 3    5
+--R                           - a b e  + (- 12a b c + 6a b )d e
+--R                         + 
+--R                                 6 2      5 2       4 4  2 4
+--R                           (- 36a c  + 54a b c - 15a b )d e
+--R                         + 
+--R                                5   2      4 3       3 5  3 3
+--R                           (112a b c  - 98a b c + 20a b )d e
+--R                         + 
+--R                               5 3       4 2 2      3 4       2 6  4 2
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  5
+--R                           (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                         + 
+--R                                4 4      3 2 3      2 4 2       6     8  6
+--R                           (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                      /
+--R                               11 3         10 2 2        9 4        8 6
+--R                         46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                + 
+--R                        6 2      5 4  5          6   2       5 3       4 5    4
+--R                  (- 36a b c + 9a b )e  + (- 360a b c  + 270a b c - 45a b )d e
+--R                + 
+--R                         6 3        5 2 2       4 4       3 6  2 3
+--R                  (- 864a c  + 1512a b c  - 684a b c + 90a b )d e
+--R                + 
+--R                        5   3        4 3 2       3 5       2 7  3 2
+--R                  (2016a b c  - 2268a b c  + 801a b c - 90a b )d e
+--R                + 
+--R                       5 4        4 2 3        3 4 2       2 6         8  4
+--R                  (288a c  - 1764a b c  + 1503a b c  - 450a b c + 45a b )d e
+--R                + 
+--R                         4   4       3 3 3       2 5 2        7      9  5
+--R                  (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )d
+--R             *
+--R                  ROOT
+--R                                5       4 2
+--R                           (108a c - 27a b )
+--R                        *
+--R                           ROOT
+--R                                     6 2 6         6        5 3    5
+--R                                  - a b e  + (- 12a b c + 6a b )d e
+--R                                + 
+--R                                        6 2      5 2       4 4  2 4
+--R                                  (- 36a c  + 54a b c - 15a b )d e
+--R                                + 
+--R                                       5   2      4 3       3 5  3 3
+--R                                  (112a b c  - 98a b c + 20a b )d e
+--R                                + 
+--R                                      5 3       4 2 2      3 4       2 6  4 2
+--R                                  (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  5
+--R                                  (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                                + 
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                             /
+--R                                      11 3         10 2 2        9 4        8 6
+--R                                46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                       + 
+--R                        3 3     2     2        2        2  2               3  3
+--R                       a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R                    /
+--R                           5       4 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R               **
+--R                  2
+--R            + 
+--R                    5     7       5 2      4 2     6
+--R                  2a b c e  + (12a c  - 10a b c)d e
+--R                + 
+--R                        4   2      3 3   2 5       4 3      3 2 2      2 4   3 4
+--R                  (- 38a b c  + 20a b c)d e  + (20a c  + 40a b c  - 20a b c)d e
+--R                + 
+--R                        3   3      2 3 2        5   4 3
+--R                  (- 50a b c  - 10a b c  + 10a b c)d e
+--R                + 
+--R                     3 4      2 2 3       4 2     6   5 2
+--R                  (4a c  + 42a b c  - 8a b c  - 2b c)d e
+--R                + 
+--R                        2   4        3 3     5 2  6
+--R                  (- 10a b c  - 10a b c  + 4b c )d e
+--R                + 
+--R                       2 5       2 4     4 3  7
+--R                  (- 4a c  + 8a b c  - 2b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                    +--------------------+
+--R                      +-----------+ |   +-----------+
+--R                3+-+2 |          2 3|   |          2
+--R            18a \|2  \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            5       4 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                     ROOT
+--R                               6 2 6         6        5 3    5
+--R                            - a b e  + (- 12a b c + 6a b )d e
+--R                          + 
+--R                                  6 2      5 2       4 4  2 4
+--R                            (- 36a c  + 54a b c - 15a b )d e
+--R                          + 
+--R                                 5   2      4 3       3 5  3 3
+--R                            (112a b c  - 98a b c + 20a b )d e
+--R                          + 
+--R                                5 3       4 2 2      3 4       2 6  4 2
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                  4   3      3 3 2      2 5        7  5
+--R                            (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                          + 
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                       /
+--R                                11 3         10 2 2        9 4        8 6
+--R                          46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                    3 3     2     2        2        2  2               3  3
+--R                   a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            atan
+--R                                9 3         8 2 2        7 4        6 6  2
+--R                         (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                       + 
+--R                                  8   3         7 3 2        6 5        5 7
+--R                         (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )d e
+--R                       + 
+--R                                     8 4         7 2 3         6 4 2        5 6
+--R                             - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                           + 
+--R                                   4 8
+--R                             - 243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                               6 2      5 4  5
+--R                         (- 36a b c + 9a b )e
+--R                       + 
+--R                                6   2       5 3       4 5    4
+--R                         (- 360a b c  + 270a b c - 45a b )d e
+--R                       + 
+--R                                6 3        5 2 2       4 4       3 6  2 3
+--R                         (- 864a c  + 1512a b c  - 684a b c + 90a b )d e
+--R                       + 
+--R                               5   3        4 3 2       3 5       2 7  3 2
+--R                         (2016a b c  - 2268a b c  + 801a b c - 90a b )d e
+--R                       + 
+--R                                   5 4        4 2 3        3 4 2       2 6
+--R                               288a c  - 1764a b c  + 1503a b c  - 450a b c
+--R                             + 
+--R                                    8
+--R                               45a b
+--R                        *
+--R                            4
+--R                           d e
+--R                       + 
+--R                              4   4       3 3 3       2 5 2        7      9  5
+--R                       (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                     5       4 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                              ROOT
+--R                                        6 2 6         6        5 3    5
+--R                                     - a b e  + (- 12a b c + 6a b )d e
+--R                                   + 
+--R                                           6 2      5 2       4 4  2 4
+--R                                     (- 36a c  + 54a b c - 15a b )d e
+--R                                   + 
+--R                                          5   2      4 3       3 5  3 3
+--R                                     (112a b c  - 98a b c + 20a b )d e
+--R                                   + 
+--R                                         5 3       4 2 2      3 4       2 6  4 2
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 36a b c  + 84a b c  - 42a b c + 6a b )
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           11 3         10 2 2        9 4
+--R                                     46656a  c  - 34992a  b c  + 8748a b c
+--R                                   + 
+--R                                           8 6
+--R                                     - 729a b
+--R                          + 
+--R                             3 3     2     2        2        2  2
+--R                            a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                                       3  3
+--R                            (2a b c - b )d
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                  9 3         8 2 2        7 4        6 6  2
+--R                           (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                         + 
+--R                                      8   3         7 3 2        6 5        5 7
+--R                             (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )
+--R                          *
+--R                             d e
+--R                         + 
+--R                                       8 4         7 2 3         6 4 2
+--R                               - 15552a c  + 27216a b c  - 14580a b c
+--R                             + 
+--R                                    5 6        4 8
+--R                               3159a b c - 243a b
+--R                          *
+--R                              2
+--R                             d
+--R                      *
+--R                         ROOT
+--R                                   6 2 6         6        5 3    5
+--R                                - a b e  + (- 12a b c + 6a b )d e
+--R                              + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                (- 36a c  + 54a b c - 15a b )d e
+--R                              + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                (112a b c  - 98a b c + 20a b )d e
+--R                              + 
+--R                                    5 3       4 2 2      3 4       2 6  4 2
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  5
+--R                                (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                              + 
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                           /
+--R                                    11 3         10 2 2        9 4        8 6
+--R                              46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                     + 
+--R                             6 2      5 4  5
+--R                       (- 36a b c + 9a b )e
+--R                     + 
+--R                              6   2       5 3       4 5    4
+--R                       (- 360a b c  + 270a b c - 45a b )d e
+--R                     + 
+--R                              6 3        5 2 2       4 4       3 6  2 3
+--R                       (- 864a c  + 1512a b c  - 684a b c + 90a b )d e
+--R                     + 
+--R                             5   3        4 3 2       3 5       2 7  3 2
+--R                       (2016a b c  - 2268a b c  + 801a b c - 90a b )d e
+--R                     + 
+--R                              5 4        4 2 3        3 4 2       2 6         8
+--R                         (288a c  - 1764a b c  + 1503a b c  - 450a b c + 45a b )
+--R                      *
+--R                          4
+--R                         d e
+--R                     + 
+--R                              4   4       3 3 3       2 5 2        7      9  5
+--R                       (- 216a b c  + 558a b c  - 378a b c  + 99a b c - 9b )d
+--R                  *
+--R                       ROOT
+--R                                       5       4 2
+--R                                (- 108a c + 27a b )
+--R                             *
+--R                                ROOT
+--R                                          6 2 6         6        5 3    5
+--R                                       - a b e  + (- 12a b c + 6a b )d e
+--R                                     + 
+--R                                             6 2      5 2       4 4  2 4
+--R                                       (- 36a c  + 54a b c - 15a b )d e
+--R                                     + 
+--R                                            5   2      4 3       3 5  3 3
+--R                                       (112a b c  - 98a b c + 20a b )d e
+--R                                     + 
+--R                                             5 3       4 2 2      3 4       2 6
+--R                                         (24a c  - 141a b c  + 90a b c - 15a b )
+--R                                      *
+--R                                          4 2
+--R                                         d e
+--R                                     + 
+--R                                                  4   3      3 3 2      2 5
+--R                                             - 36a b c  + 84a b c  - 42a b c
+--R                                           + 
+--R                                                 7
+--R                                             6a b
+--R                                      *
+--R                                          5
+--R                                         d e
+--R                                     + 
+--R                                               4 4      3 2 3      2 4 2
+--R                                           - 4a c  + 16a b c  - 20a b c
+--R                                         + 
+--R                                               6     8
+--R                                           8a b c - b
+--R                                      *
+--R                                          6
+--R                                         d
+--R                                  /
+--R                                             11 3         10 2 2        9 4
+--R                                       46656a  c  - 34992a  b c  + 8748a b c
+--R                                     + 
+--R                                             8 6
+--R                                       - 729a b
+--R                            + 
+--R                               3 3     2     2        2        2  2
+--R                              a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                            + 
+--R                                         3  3
+--R                              (2a b c - b )d
+--R                         /
+--R                                5       4 2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                           5     7         5 2      4 2     6
+--R                       - 4a b c e  + (- 24a c  + 20a b c)d e
+--R                     + 
+--R                           4   2      3 3   2 5
+--R                       (76a b c  - 40a b c)d e
+--R                     + 
+--R                             4 3      3 2 2      2 4   3 4
+--R                       (- 40a c  - 80a b c  + 40a b c)d e
+--R                     + 
+--R                            3   3      2 3 2        5   4 3
+--R                       (100a b c  + 20a b c  - 20a b c)d e
+--R                     + 
+--R                            3 4      2 2 3        4 2     6   5 2
+--R                       (- 8a c  - 84a b c  + 16a b c  + 4b c)d e
+--R                     + 
+--R                           2   4        3 3     5 2  6
+--R                       (20a b c  + 20a b c  - 8b c )d e
+--R                     + 
+--R                          2 5        2 4     4 3  7
+--R                       (8a c  - 16a b c  + 4b c )d
+--R                  *
+--R                     x
+--R     + 
+--R       -
+--R                                    +--------------------+
+--R                      +-----------+ |   +-----------+
+--R                3+-+2 |          2 3|   |          2
+--R            18a \|2  \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          5       4 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                     ROOT
+--R                               6 2 6         6        5 3    5
+--R                            - a b e  + (- 12a b c + 6a b )d e
+--R                          + 
+--R                                  6 2      5 2       4 4  2 4
+--R                            (- 36a c  + 54a b c - 15a b )d e
+--R                          + 
+--R                                 5   2      4 3       3 5  3 3
+--R                            (112a b c  - 98a b c + 20a b )d e
+--R                          + 
+--R                                5 3       4 2 2      3 4       2 6  4 2
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                  4   3      3 3 2      2 5        7  5
+--R                            (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                          + 
+--R                                 4 4      3 2 3      2 4 2       6     8  6
+--R                            (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                       /
+--R                                11 3         10 2 2        9 4        8 6
+--R                          46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                 + 
+--R                    3 3     2     2        2        2  2               3  3
+--R                   a e  - 3a b d e  + (- 3a c + 3a b )d e + (2a b c - b )d
+--R              /
+--R                     5       4 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            atan
+--R                                9 3         8 2 2        7 4        6 6  2
+--R                         (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                       + 
+--R                                  8   3         7 3 2        6 5        5 7
+--R                         (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )d e
+--R                       + 
+--R                                     8 4         7 2 3         6 4 2        5 6
+--R                             - 15552a c  + 27216a b c  - 14580a b c  + 3159a b c
+--R                           + 
+--R                                   4 8
+--R                             - 243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                    *
+--R                       ROOT
+--R                                 6 2 6         6        5 3    5
+--R                              - a b e  + (- 12a b c + 6a b )d e
+--R                            + 
+--R                                    6 2      5 2       4 4  2 4
+--R                              (- 36a c  + 54a b c - 15a b )d e
+--R                            + 
+--R                                   5   2      4 3       3 5  3 3
+--R                              (112a b c  - 98a b c + 20a b )d e
+--R                            + 
+--R                                  5 3       4 2 2      3 4       2 6  4 2
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  5
+--R                              (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                            + 
+--R                                   4 4      3 2 3      2 4 2       6     8  6
+--R                              (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                         /
+--R                                  11 3         10 2 2        9 4        8 6
+--R                            46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                   + 
+--R                             6 2      5 4  5
+--R                         (36a b c - 9a b )e
+--R                       + 
+--R                              6   2       5 3       4 5    4
+--R                         (360a b c  - 270a b c + 45a b )d e
+--R                       + 
+--R                              6 3        5 2 2       4 4       3 6  2 3
+--R                         (864a c  - 1512a b c  + 684a b c - 90a b )d e
+--R                       + 
+--R                                 5   3        4 3 2       3 5       2 7  3 2
+--R                         (- 2016a b c  + 2268a b c  - 801a b c + 90a b )d e
+--R                       + 
+--R                                   5 4        4 2 3        3 4 2       2 6
+--R                             - 288a c  + 1764a b c  - 1503a b c  + 450a b c
+--R                           + 
+--R                                    8
+--R                             - 45a b
+--R                        *
+--R                            4
+--R                           d e
+--R                       + 
+--R                              4   4       3 3 3       2 5 2        7      9  5
+--R                         (216a b c  - 558a b c  + 378a b c  - 99a b c + 9b )d
+--R                    *
+--R                        +-+
+--R                       \|3
+--R                *
+--R                     ROOT
+--R                                   5       4 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                              ROOT
+--R                                        6 2 6         6        5 3    5
+--R                                     - a b e  + (- 12a b c + 6a b )d e
+--R                                   + 
+--R                                           6 2      5 2       4 4  2 4
+--R                                     (- 36a c  + 54a b c - 15a b )d e
+--R                                   + 
+--R                                          5   2      4 3       3 5  3 3
+--R                                     (112a b c  - 98a b c + 20a b )d e
+--R                                   + 
+--R                                         5 3       4 2 2      3 4       2 6  4 2
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 36a b c  + 84a b c  - 42a b c + 6a b )
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                             4 4      3 2 3      2 4 2       6
+--R                                         - 4a c  + 16a b c  - 20a b c  + 8a b c
+--R                                       + 
+--R                                            8
+--R                                         - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           11 3         10 2 2        9 4
+--R                                     46656a  c  - 34992a  b c  + 8748a b c
+--R                                   + 
+--R                                           8 6
+--R                                     - 729a b
+--R                          + 
+--R                             3 3     2     2        2        2  2
+--R                            a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                                       3  3
+--R                            (2a b c - b )d
+--R                       /
+--R                              5       4 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R              /
+--R                                  9 3         8 2 2        7 4        6 6  2
+--R                           (15552a c  - 11664a b c  + 2916a b c - 243a b )e
+--R                         + 
+--R                                      8   3         7 3 2        6 5        5 7
+--R                             (- 31104a b c  + 23328a b c  - 5832a b c + 486a b )
+--R                          *
+--R                             d e
+--R                         + 
+--R                                       8 4         7 2 3         6 4 2
+--R                               - 15552a c  + 27216a b c  - 14580a b c
+--R                             + 
+--R                                    5 6        4 8
+--R                               3159a b c - 243a b
+--R                          *
+--R                              2
+--R                             d
+--R                      *
+--R                         ROOT
+--R                                   6 2 6         6        5 3    5
+--R                                - a b e  + (- 12a b c + 6a b )d e
+--R                              + 
+--R                                      6 2      5 2       4 4  2 4
+--R                                (- 36a c  + 54a b c - 15a b )d e
+--R                              + 
+--R                                     5   2      4 3       3 5  3 3
+--R                                (112a b c  - 98a b c + 20a b )d e
+--R                              + 
+--R                                    5 3       4 2 2      3 4       2 6  4 2
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  5
+--R                                (- 36a b c  + 84a b c  - 42a b c + 6a b )d e
+--R                              + 
+--R                                     4 4      3 2 3      2 4 2       6     8  6
+--R                                (- 4a c  + 16a b c  - 20a b c  + 8a b c - b )d
+--R                           /
+--R                                    11 3         10 2 2        9 4        8 6
+--R                              46656a  c  - 34992a  b c  + 8748a b c - 729a b
+--R                     + 
+--R                           6 2      5 4  5        6   2       5 3       4 5    4
+--R                       (36a b c - 9a b )e  + (360a b c  - 270a b c + 45a b )d e
+--R                     + 
+--R                            6 3        5 2 2       4 4       3 6  2 3
+--R                       (864a c  - 1512a b c  + 684a b c - 90a b )d e
+--R                     + 
+--R                               5   3        4 3 2       3 5       2 7  3 2
+--R                       (- 2016a b c  + 2268a b c  - 801a b c + 90a b )d e
+--R                     + 
+--R                                   5 4        4 2 3        3 4 2       2 6
+--R                             - 288a c  + 1764a b c  - 1503a b c  + 450a b c
+--R                           + 
+--R                                    8
+--R                             - 45a b
+--R                      *
+--R                          4
+--R                         d e
+--R                     + 
+--R                            4   4       3 3 3       2 5 2        7      9  5
+--R                       (216a b c  - 558a b c  + 378a b c  - 99a b c + 9b )d
+--R                  *
+--R                       ROOT
+--R                                     5       4 2
+--R                                (108a c - 27a b )
+--R                             *
+--R                                ROOT
+--R                                          6 2 6         6        5 3    5
+--R                                       - a b e  + (- 12a b c + 6a b )d e
+--R                                     + 
+--R                                             6 2      5 2       4 4  2 4
+--R                                       (- 36a c  + 54a b c - 15a b )d e
+--R                                     + 
+--R                                            5   2      4 3       3 5  3 3
+--R                                       (112a b c  - 98a b c + 20a b )d e
+--R                                     + 
+--R                                             5 3       4 2 2      3 4       2 6
+--R                                         (24a c  - 141a b c  + 90a b c - 15a b )
+--R                                      *
+--R                                          4 2
+--R                                         d e
+--R                                     + 
+--R                                                  4   3      3 3 2      2 5
+--R                                             - 36a b c  + 84a b c  - 42a b c
+--R                                           + 
+--R                                                 7
+--R                                             6a b
+--R                                      *
+--R                                          5
+--R                                         d e
+--R                                     + 
+--R                                               4 4      3 2 3      2 4 2
+--R                                           - 4a c  + 16a b c  - 20a b c
+--R                                         + 
+--R                                               6     8
+--R                                           8a b c - b
+--R                                      *
+--R                                          6
+--R                                         d
+--R                                  /
+--R                                             11 3         10 2 2        9 4
+--R                                       46656a  c  - 34992a  b c  + 8748a b c
+--R                                     + 
+--R                                             8 6
+--R                                       - 729a b
+--R                            + 
+--R                               3 3     2     2        2        2  2
+--R                              a e  - 3a b d e  + (- 3a c + 3a b )d e
+--R                            + 
+--R                                         3  3
+--R                              (2a b c - b )d
+--R                         /
+--R                                5       4 2
+--R                            216a c - 54a b
+--R                      ,
+--R                          3
+--R                    **
+--R                       2
+--R                 + 
+--R                         5     7       5 2      4 2     6
+--R                       4a b c e  + (24a c  - 20a b c)d e
+--R                     + 
+--R                             4   2      3 3   2 5
+--R                       (- 76a b c  + 40a b c)d e
+--R                     + 
+--R                           4 3      3 2 2      2 4   3 4
+--R                       (40a c  + 80a b c  - 40a b c)d e
+--R                     + 
+--R                              3   3      2 3 2        5   4 3
+--R                       (- 100a b c  - 20a b c  + 20a b c)d e
+--R                     + 
+--R                          3 4      2 2 3        4 2     6   5 2
+--R                       (8a c  + 84a b c  - 16a b c  - 4b c)d e
+--R                     + 
+--R                             2   4        3 3     5 2  6
+--R                       (- 20a b c  - 20a b c  + 8b c )d e
+--R                     + 
+--R                            2 5        2 4     4 3  7
+--R                       (- 8a c  + 16a b c  - 4b c )d
+--R                  *
+--R                     x
+--R     + 
+--R                                                 +--------------------+
+--R               +-----------+                     |   +-----------+
+--R               |          2                 3+-+3|   |          2
+--R         (- 6d\|- 4a c + b   - 12a e + 6b d)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                                 +------------------+
+--R               +-----------+                     | +-----------+
+--R               |          2                 3+-+3| |          2
+--R         (- 6d\|- 4a c + b   + 12a e - 6b d)\|c \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R        3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R     6a \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 649
+t0:=(d+e*x^3)/(x^3*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                3
+--R             e x  + d
+--R   (1)  ------------------
+--R           9      6      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 40
+
+--S 41 of 649
+r0:=-1/2*d/(a*x^2)-1/3*c^(2/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-_
+   4*a*c))^(1/3))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(1/3)*a*_
+   (b-sqrt(b^2-4*a*c))^(2/3))+1/6*c^(2/3)*log(2^(2/3)*c^(2/3)*x^2-_
+   2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-_
+   4*a*c))^(2/3))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b-_
+   sqrt(b^2-4*a*c))^(2/3))+c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b-sqrt(b^2-_
+   4*a*c))^(1/3)))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(1/3)*a*sqrt(3)*_
+   (b-sqrt(b^2-4*a*c))^(2/3))-1/3*c^(2/3)*log(2^(1/3)*c^(1/3)*x+_
+   (b+sqrt(b^2-4*a*c))^(1/3))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(1/3)*_
+   a*(b+sqrt(b^2-4*a*c))^(2/3))+1/6*c^(2/3)*log(2^(2/3)*c^(2/3)*x^2-_
+   2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*_
+   (d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b+sqrt(b^2-4*a*c))^(2/3))+_
+   c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*a*sqrt(3)*(b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                   +-----------+
+--R             2 +-+ |          2                 2 +-+ 3+-+2
+--R         (d x \|3 \|- 4a c + b   + (2a e - b d)x \|3 )\|c
+--R      *
+--R          +--------------------+2
+--R          |   +-----------+
+--R         3|   |          2
+--R         \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                      +-----------+
+--R                2 +-+ |          2                    2 +-+ 3+-+2
+--R         (- 2d x \|3 \|- 4a c + b   + (- 4a e + 2b d)x \|3 )\|c
+--R      *
+--R          +--------------------+2     +------------------+
+--R          |   +-----------+           | +-----------+
+--R         3|   |          2           3| |          2          3+-+3+-+
+--R         \|- \|- 4a c + b   + b  log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                   +-----------+
+--R             2 +-+ |          2                   2 +-+ 3+-+2
+--R         (d x \|3 \|- 4a c + b   + (- 2a e + b d)x \|3 )\|c
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                      +-----------+
+--R                2 +-+ |          2                  2 +-+ 3+-+2
+--R         (- 2d x \|3 \|- 4a c + b   + (4a e - 2b d)x \|3 )\|c
+--R      *
+--R          +------------------+2     +--------------------+
+--R          | +-----------+           |   +-----------+
+--R         3| |          2           3|   |          2          3+-+3+-+
+--R         \|\|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                        +--------------------+2
+--R                +-----------+                           |   +-----------+
+--R              2 |          2                   2 3+-+2 3|   |          2
+--R         (6d x \|- 4a c + b   + (12a e - 6b d)x )\|c   \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                                          +------------------+2
+--R                +-----------+                             | +-----------+
+--R              2 |          2                     2 3+-+2 3| |          2
+--R         (6d x \|- 4a c + b   + (- 12a e + 6b d)x )\|c   \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                  +--------------------+2  +------------------+2
+--R                    +-----------+ |   +-----------+        | +-----------+
+--R           3+-+ +-+ |          2 3|   |          2        3| |          2
+--R       - 3d\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+2  +------------------+2
+--R                    +-----------+ |   +-----------+        | +-----------+
+--R         2 3+-+ +-+ |          2 3|   |          2        3| |          2
+--R     6a x  \|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R               2
+--R            a x
+--R         *
+--R            ROOT
+--R                            6       5 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                     ROOT
+--R                                 8 2     7 2     6 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                7   2      6 3      5 5    5
+--R                            (36a b c  - 30a b c + 6a b )d e
+--R                          + 
+--R                                7 3       6 2 2      5 4       4 6  2 4
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                   6   3       5 3 2       4 5       3 7  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                          + 
+--R                                     6 4       5 2 3       4 4 2       3 6
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     2 8
+--R                                - 15a b
+--R                           *
+--R                               4 2
+--R                              d e
+--R                          + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                           *
+--R                               5
+--R                              d e
+--R                          + 
+--R                                4 2 4      3 4 3      2 6 2        8     10  6
+--R                          (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                       /
+--R                                13 3         12 2 2        11 4        10 6
+--R                          46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                 + 
+--R                      3   3        3      2 2    2      2          3  2
+--R                   - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                 + 
+--R                     2 2       2     4  3
+--R                   (a c  - 3a b c + b )d
+--R              /
+--R                     6       5 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                10   3         9 3 2        8 5        7 7  2
+--R                         (15552a  b c  - 11664a b c  + 2916a b c - 243a b )e
+--R                       + 
+--R                                   10 4         9 2 3         8 4 2        7 6
+--R                             31104a  c  - 54432a b c  + 29160a b c  - 6318a b c
+--R                           + 
+--R                                 6 8
+--R                             486a b
+--R                        *
+--R                           d e
+--R                       + 
+--R                                     9   4         8 3 3         7 5 2
+--R                             - 31104a b c  + 38880a b c  - 17496a b c
+--R                           + 
+--R                                  6 7        5 9
+--R                             3402a b c - 243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                       ROOT
+--R                                   8 2     7 2     6 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                  7   2      6 3      5 5    5
+--R                              (36a b c  - 30a b c + 6a b )d e
+--R                            + 
+--R                                  7 3       6 2 2      5 4       4 6  2 4
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                     6   3       5 3 2       4 5       3 7  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                            + 
+--R                                       6 4       5 2 3       4 4 2       3 6
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       2 8
+--R                                  - 15a b
+--R                             *
+--R                                 4 2
+--R                                d e
+--R                            + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                             *
+--R                                 5
+--R                                d e
+--R                            + 
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                         /
+--R                                  13 3         12 2 2        11 4        10 6
+--R                            46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                          8 3       7 2 2      6 4      5 6  5
+--R                     (144a c  - 180a b c  + 72a b c - 9a b )e
+--R                   + 
+--R                             7   3        6 3 2       5 5       4 7    4
+--R                     (- 1080a b c  + 1170a b c  - 405a b c + 45a b )d e
+--R                   + 
+--R                              7 4        6 2 3        5 4 2       4 6       3 8
+--R                       (- 576a c  + 3528a b c  - 3006a b c  + 900a b c - 90a b )
+--R                    *
+--R                        2 3
+--R                       d e
+--R                   + 
+--R                                6   4        5 3 3        4 5 2       3 7
+--R                           2304a b c  - 5652a b c  + 3789a b c  - 990a b c
+--R                         + 
+--R                              2 9
+--R                           90a b
+--R                    *
+--R                        3 2
+--R                       d e
+--R                   + 
+--R                             6 5        5 2 4        4 4 3        3 6 2
+--R                         432a c  - 2916a b c  + 4302a b c  - 2340a b c
+--R                       + 
+--R                             2 8         10
+--R                         540a b c - 45a b
+--R                    *
+--R                        4
+--R                       d e
+--R                   + 
+--R                               5   5        4 3 4        3 5 3       2 7 2
+--R                         - 360a b c  + 1170a b c  - 1242a b c  + 567a b c
+--R                       + 
+--R                                 9      11
+--R                         - 117a b c + 9b
+--R                    *
+--R                        5
+--R                       d
+--R                *
+--R                     ROOT
+--R                                     6       5 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                              ROOT
+--R                                          8 2     7 2     6 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                         7   2      6 3      5 5    5
+--R                                     (36a b c  - 30a b c + 6a b )d e
+--R                                   + 
+--R                                         7 3       6 2 2      5 4       4 6  2 4
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                               6   3       5 3 2       4 5
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            3 7
+--R                                         20a b
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                              6 4       5 2 3       4 4 2
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                             3 6       2 8
+--R                                         120a b c - 15a b
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                            5   4       4 3 3       3 5 2
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                              2 7        9
+--R                                         - 54a b c + 6a b
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           13 3         12 2 2        11 4
+--R                                     46656a  c  - 34992a  b c  + 8748a  b c
+--R                                   + 
+--R                                           10 6
+--R                                     - 729a  b
+--R                          + 
+--R                               3   3        3      2 2    2
+--R                            - a b e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                               2          3  2      2 2       2     4  3
+--R                            (6a b c - 3a b )d e + (a c  - 3a b c + b )d
+--R                       /
+--R                              6       5 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 9   3       8 3 2      7 5   3
+--R                         (- 1296a b c  + 648a b c  - 81a b c)e
+--R                       + 
+--R                                 9 4        8 2 3        7 4 2       6 6     2
+--R                         (- 2592a c  + 3888a b c  - 1458a b c  + 162a b c)d e
+--R                       + 
+--R                               8   4        7 3 3       6 5 2      5 7   2
+--R                         (1296a b c  - 1944a b c  + 729a b c  - 81a b c)d e
+--R                       + 
+--R                                 8 5        7 2 4       6 4 3      5 6 2  3
+--R                         (- 2592a c  + 2592a b c  - 810a b c  + 81a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   8 2     7 2     6 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                  7   2      6 3      5 5    5
+--R                              (36a b c  - 30a b c + 6a b )d e
+--R                            + 
+--R                                  7 3       6 2 2      5 4       4 6  2 4
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                     6   3       5 3 2       4 5       3 7  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                            + 
+--R                                       6 4       5 2 3       4 4 2       3 6
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       2 8
+--R                                  - 15a b
+--R                             *
+--R                                 4 2
+--R                                d e
+--R                            + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                             *
+--R                                 5
+--R                                d e
+--R                            + 
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                         /
+--R                                  13 3         12 2 2        11 4        10 6
+--R                            46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                               7 3      6 2 2     5 4   6
+--R                         (- 24a c  + 18a b c  - 3a b c)e
+--R                       + 
+--R                              6   3      5 3 2      4 5     5
+--R                         (156a b c  - 99a b c  + 15a b c)d e
+--R                       + 
+--R                             6 4       5 2 3       4 4 2      3 6   2 4
+--R                         (48a c  - 384a b c  + 213a b c  - 30a b c)d e
+--R                       + 
+--R                               5   4       4 3 3       3 5 2      2 7   3 3
+--R                         (- 72a b c  + 426a b c  - 222a b c  + 30a b c)d e
+--R                       + 
+--R                               5 5      4 2 4       3 4 3       2 6 2        8
+--R                           (72a c  - 78a b c  - 177a b c  + 108a b c  - 15a b c)
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                                     4   5       3 3 4      2 5 3        7 2
+--R                               - 132a b c  + 177a b c  - 24a b c  - 15a b c
+--R                             + 
+--R                                 9
+--R                               3b c
+--R                        *
+--R                            5
+--R                           d e
+--R                       + 
+--R                             3 2 5      2 4 4        6 3     8 2  6
+--R                         (60a b c  - 75a b c  + 27a b c  - 3b c )d
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                   6       5 2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                            ROOT
+--R                                        8 2     7 2     6 4  6
+--R                                   (- 4a c  + 4a b c - a b )e
+--R                                 + 
+--R                                       7   2      6 3      5 5    5
+--R                                   (36a b c  - 30a b c + 6a b )d e
+--R                                 + 
+--R                                       7 3       6 2 2      5 4       4 6  2 4
+--R                                   (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                 + 
+--R                                               6   3       5 3 2       4 5
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            3 7
+--R                                         20a b
+--R                                  *
+--R                                      3 3
+--R                                     d e
+--R                                 + 
+--R                                            6 4       5 2 3       4 4 2
+--R                                       - 36a c  + 234a b c  - 300a b c
+--R                                     + 
+--R                                           3 6       2 8
+--R                                       120a b c - 15a b
+--R                                  *
+--R                                      4 2
+--R                                     d e
+--R                                 + 
+--R                                          5   4       4 3 3       3 5 2
+--R                                       60a b c  - 180a b c  + 162a b c
+--R                                     + 
+--R                                            2 7        9
+--R                                       - 54a b c + 6a b
+--R                                  *
+--R                                      5
+--R                                     d e
+--R                                 + 
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  *
+--R                                      6
+--R                                     d
+--R                              /
+--R                                         13 3         12 2 2        11 4
+--R                                   46656a  c  - 34992a  b c  + 8748a  b c
+--R                                 + 
+--R                                         10 6
+--R                                   - 729a  b
+--R                        + 
+--R                             3   3        3      2 2    2      2          3  2
+--R                          - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                        + 
+--R                            2 2       2     4  3
+--R                          (a c  - 3a b c + b )d
+--R                     /
+--R                            6       5 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                        6 3     5 2 2  7         5   3      4 3 2    6
+--R                     (4a c  - 2a b c )e  + (- 26a b c  + 10a b c )d e
+--R                   + 
+--R                          5 4      4 2 3      3 4 2  2 5
+--R                     (- 4a c  + 60a b c  - 20a b c )d e
+--R                   + 
+--R                           4   4      3 3 3      2 5 2  3 4
+--R                     (- 10a b c  - 60a b c  + 20a b c )d e
+--R                   + 
+--R                           4 5      3 2 4      2 4 3        6 2  4 3
+--R                     (- 20a c  + 50a b c  + 20a b c  - 10a b c )d e
+--R                   + 
+--R                         3   5      2 3 4       5 3     7 2  5 2
+--R                     (26a b c  - 52a b c  + 6a b c  + 2b c )d e
+--R                   + 
+--R                           3 6     2 2 5        4 4     6 3  6
+--R                     (- 12a c  + 4a b c  + 14a b c  - 4b c )d e
+--R                   + 
+--R                         2   6        3 5     5 4  7
+--R                     (10a b c  - 10a b c  + 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R             2
+--R         2a x
+--R      *
+--R         ROOT
+--R                         6       5 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                  ROOT
+--R                              8 2     7 2     6 4  6
+--R                         (- 4a c  + 4a b c - a b )e
+--R                       + 
+--R                             7   2      6 3      5 5    5
+--R                         (36a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             7 3       6 2 2      5 4       4 6  2 4
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                                6   3       5 3 2       4 5       3 7  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                       + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                             5   4       4 3 3       3 5 2      2 7        9  5
+--R                         (60a b c  - 180a b c  + 162a b c  - 54a b c + 6a b )d e
+--R                       + 
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                   3   3        3      2 2    2      2          3  2
+--R                - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R              + 
+--R                  2 2       2     4  3
+--R                (a c  - 3a b c + b )d
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                            8   2       7 3       6 5
+--R                      (1296a b c  - 648a b c + 81a b )e
+--R                    + 
+--R                            8 3        7 2 2       6 4       5 6
+--R                      (2592a c  - 2592a b c  + 810a b c - 81a b )d
+--R                 *
+--R                    ROOT
+--R                                8 2     7 2     6 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                               7   2      6 3      5 5    5
+--R                           (36a b c  - 30a b c + 6a b )d e
+--R                         + 
+--R                               7 3       6 2 2      5 4       4 6  2 4
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                  6   3       5 3 2       4 5       3 7  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                         + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                          *
+--R                              4 2
+--R                             d e
+--R                         + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                          *
+--R                              5
+--R                             d e
+--R                         + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                      6 2      5 2      4 4  4
+--R                  (24a c  - 18a b c + 3a b )e
+--R                + 
+--R                         5   2      4 3       3 5    3
+--R                  (- 132a b c  + 81a b c - 12a b )d e
+--R                + 
+--R                        5 3       4 2 2       3 4       2 6  2 2
+--R                  (- 72a c  + 270a b c  - 135a b c + 18a b )d e
+--R                + 
+--R                       4   3       3 3 2      2 5         7  3
+--R                  (132a b c  - 237a b c  + 99a b c - 12a b )d e
+--R                + 
+--R                        3 2 3      2 4 2        6      8  4
+--R                  (- 60a b c  + 75a b c  - 27a b c + 3b )d
+--R             *
+--R                ROOT
+--R                                6       5 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                         ROOT
+--R                                     8 2     7 2     6 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                    7   2      6 3      5 5    5
+--R                                (36a b c  - 30a b c + 6a b )d e
+--R                              + 
+--R                                    7 3       6 2 2      5 4       4 6  2 4
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                         6   3       5 3 2       4 5       3 7
+--R                                  (- 128a b c  + 282a b c  - 140a b c + 20a b )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                         6 4       5 2 3       4 4 2       3 6
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         2 8
+--R                                    - 15a b
+--R                               *
+--R                                   4 2
+--R                                  d e
+--R                              + 
+--R                                       5   4       4 3 3       3 5 2      2 7
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                        9
+--R                                    6a b
+--R                               *
+--R                                   5
+--R                                  d e
+--R                              + 
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  d
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                          3   3        3      2 2    2      2          3  2
+--R                       - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                     + 
+--R                         2 2       2     4  3
+--R                       (a c  - 3a b c + b )d
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                     5 2     4 2   5         4   2     3 3     4
+--R                  (4a c  - 2a b c)e  + (- 22a b c  + 8a b c)d e
+--R                + 
+--R                       4 3      3 2 2      2 4   2 3
+--R                  (- 8a c  + 40a b c  - 12a b c)d e
+--R                + 
+--R                     3   3      2 3 2       5   3 2
+--R                  (4a b c  - 28a b c  + 8a b c)d e
+--R                + 
+--R                        3 4      2 2 3       4 2     6   4
+--R                  (- 12a c  + 14a b c  + 4a b c  - 2b c)d e
+--R                + 
+--R                      2   4        3 3     5 2  5
+--R                  (10a b c  - 10a b c  + 2b c )d
+--R             *
+--R                x
+--R     + 
+--R             2
+--R         2a x
+--R      *
+--R         ROOT
+--R                       6       5 2
+--R                  (108a c - 27a b )
+--R               *
+--R                  ROOT
+--R                              8 2     7 2     6 4  6
+--R                         (- 4a c  + 4a b c - a b )e
+--R                       + 
+--R                             7   2      6 3      5 5    5
+--R                         (36a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             7 3       6 2 2      5 4       4 6  2 4
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                                6   3       5 3 2       4 5       3 7  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                       + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                             5   4       4 3 3       3 5 2      2 7        9  5
+--R                         (60a b c  - 180a b c  + 162a b c  - 54a b c + 6a b )d e
+--R                       + 
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                   3   3        3      2 2    2      2          3  2
+--R                - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R              + 
+--R                  2 2       2     4  3
+--R                (a c  - 3a b c + b )d
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         log
+--R                              8   2       7 3       6 5
+--R                      (- 1296a b c  + 648a b c - 81a b )e
+--R                    + 
+--R                              8 3        7 2 2       6 4       5 6
+--R                      (- 2592a c  + 2592a b c  - 810a b c + 81a b )d
+--R                 *
+--R                    ROOT
+--R                                8 2     7 2     6 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                               7   2      6 3      5 5    5
+--R                           (36a b c  - 30a b c + 6a b )d e
+--R                         + 
+--R                               7 3       6 2 2      5 4       4 6  2 4
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                  6   3       5 3 2       4 5       3 7  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                         + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                          *
+--R                              4 2
+--R                             d e
+--R                         + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                          *
+--R                              5
+--R                             d e
+--R                         + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                      6 2      5 2      4 4  4
+--R                  (24a c  - 18a b c + 3a b )e
+--R                + 
+--R                         5   2      4 3       3 5    3
+--R                  (- 132a b c  + 81a b c - 12a b )d e
+--R                + 
+--R                        5 3       4 2 2       3 4       2 6  2 2
+--R                  (- 72a c  + 270a b c  - 135a b c + 18a b )d e
+--R                + 
+--R                       4   3       3 3 2      2 5         7  3
+--R                  (132a b c  - 237a b c  + 99a b c - 12a b )d e
+--R                + 
+--R                        3 2 3      2 4 2        6      8  4
+--R                  (- 60a b c  + 75a b c  - 27a b c + 3b )d
+--R             *
+--R                ROOT
+--R                              6       5 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                         ROOT
+--R                                     8 2     7 2     6 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                    7   2      6 3      5 5    5
+--R                                (36a b c  - 30a b c + 6a b )d e
+--R                              + 
+--R                                    7 3       6 2 2      5 4       4 6  2 4
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                         6   3       5 3 2       4 5       3 7
+--R                                  (- 128a b c  + 282a b c  - 140a b c + 20a b )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                         6 4       5 2 3       4 4 2       3 6
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         2 8
+--R                                    - 15a b
+--R                               *
+--R                                   4 2
+--R                                  d e
+--R                              + 
+--R                                       5   4       4 3 3       3 5 2      2 7
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                        9
+--R                                    6a b
+--R                               *
+--R                                   5
+--R                                  d e
+--R                              + 
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  d
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                          3   3        3      2 2    2      2          3  2
+--R                       - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                     + 
+--R                         2 2       2     4  3
+--R                       (a c  - 3a b c + b )d
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                     5 2     4 2   5         4   2     3 3     4
+--R                  (4a c  - 2a b c)e  + (- 22a b c  + 8a b c)d e
+--R                + 
+--R                       4 3      3 2 2      2 4   2 3
+--R                  (- 8a c  + 40a b c  - 12a b c)d e
+--R                + 
+--R                     3   3      2 3 2       5   3 2
+--R                  (4a b c  - 28a b c  + 8a b c)d e
+--R                + 
+--R                        3 4      2 2 3       4 2     6   4
+--R                  (- 12a c  + 14a b c  + 4a b c  - 2b c)d e
+--R                + 
+--R                      2   4        3 3     5 2  5
+--R                  (10a b c  - 10a b c  + 2b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R               2
+--R            a x
+--R         *
+--R            ROOT
+--R                          6       5 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                     ROOT
+--R                                 8 2     7 2     6 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                7   2      6 3      5 5    5
+--R                            (36a b c  - 30a b c + 6a b )d e
+--R                          + 
+--R                                7 3       6 2 2      5 4       4 6  2 4
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                   6   3       5 3 2       4 5       3 7  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                          + 
+--R                                     6 4       5 2 3       4 4 2       3 6
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     2 8
+--R                                - 15a b
+--R                           *
+--R                               4 2
+--R                              d e
+--R                          + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                           *
+--R                               5
+--R                              d e
+--R                          + 
+--R                                4 2 4      3 4 3      2 6 2        8     10  6
+--R                          (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                       /
+--R                                13 3         12 2 2        11 4        10 6
+--R                          46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                 + 
+--R                      3   3        3      2 2    2      2          3  2
+--R                   - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                 + 
+--R                     2 2       2     4  3
+--R                   (a c  - 3a b c + b )d
+--R              /
+--R                     6       5 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R            log
+--R                                  10   3         9 3 2        8 5        7 7  2
+--R                         (- 15552a  b c  + 11664a b c  - 2916a b c + 243a b )e
+--R                       + 
+--R                                     10 4         9 2 3         8 4 2
+--R                             - 31104a  c  + 54432a b c  - 29160a b c
+--R                           + 
+--R                                  7 6        6 8
+--R                             6318a b c - 486a b
+--R                        *
+--R                           d e
+--R                       + 
+--R                                   9   4         8 3 3         7 5 2        6 7
+--R                             31104a b c  - 38880a b c  + 17496a b c  - 3402a b c
+--R                           + 
+--R                                 5 9
+--R                             243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                       ROOT
+--R                                   8 2     7 2     6 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                  7   2      6 3      5 5    5
+--R                              (36a b c  - 30a b c + 6a b )d e
+--R                            + 
+--R                                  7 3       6 2 2      5 4       4 6  2 4
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                     6   3       5 3 2       4 5       3 7  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                            + 
+--R                                       6 4       5 2 3       4 4 2       3 6
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       2 8
+--R                                  - 15a b
+--R                             *
+--R                                 4 2
+--R                                d e
+--R                            + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                             *
+--R                                 5
+--R                                d e
+--R                            + 
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                         /
+--R                                  13 3         12 2 2        11 4        10 6
+--R                            46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                          8 3       7 2 2      6 4      5 6  5
+--R                     (144a c  - 180a b c  + 72a b c - 9a b )e
+--R                   + 
+--R                             7   3        6 3 2       5 5       4 7    4
+--R                     (- 1080a b c  + 1170a b c  - 405a b c + 45a b )d e
+--R                   + 
+--R                              7 4        6 2 3        5 4 2       4 6       3 8
+--R                       (- 576a c  + 3528a b c  - 3006a b c  + 900a b c - 90a b )
+--R                    *
+--R                        2 3
+--R                       d e
+--R                   + 
+--R                                6   4        5 3 3        4 5 2       3 7
+--R                           2304a b c  - 5652a b c  + 3789a b c  - 990a b c
+--R                         + 
+--R                              2 9
+--R                           90a b
+--R                    *
+--R                        3 2
+--R                       d e
+--R                   + 
+--R                             6 5        5 2 4        4 4 3        3 6 2
+--R                         432a c  - 2916a b c  + 4302a b c  - 2340a b c
+--R                       + 
+--R                             2 8         10
+--R                         540a b c - 45a b
+--R                    *
+--R                        4
+--R                       d e
+--R                   + 
+--R                               5   5        4 3 4        3 5 3       2 7 2
+--R                         - 360a b c  + 1170a b c  - 1242a b c  + 567a b c
+--R                       + 
+--R                                 9      11
+--R                         - 117a b c + 9b
+--R                    *
+--R                        5
+--R                       d
+--R                *
+--R                     ROOT
+--R                                   6       5 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                              ROOT
+--R                                          8 2     7 2     6 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                         7   2      6 3      5 5    5
+--R                                     (36a b c  - 30a b c + 6a b )d e
+--R                                   + 
+--R                                         7 3       6 2 2      5 4       4 6  2 4
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                               6   3       5 3 2       4 5
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            3 7
+--R                                         20a b
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                              6 4       5 2 3       4 4 2
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                             3 6       2 8
+--R                                         120a b c - 15a b
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                            5   4       4 3 3       3 5 2
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                              2 7        9
+--R                                         - 54a b c + 6a b
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           13 3         12 2 2        11 4
+--R                                     46656a  c  - 34992a  b c  + 8748a  b c
+--R                                   + 
+--R                                           10 6
+--R                                     - 729a  b
+--R                          + 
+--R                               3   3        3      2 2    2
+--R                            - a b e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                               2          3  2      2 2       2     4  3
+--R                            (6a b c - 3a b )d e + (a c  - 3a b c + b )d
+--R                       /
+--R                              6       5 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               9   3       8 3 2      7 5   3
+--R                         (1296a b c  - 648a b c  + 81a b c)e
+--R                       + 
+--R                               9 4        8 2 3        7 4 2       6 6     2
+--R                         (2592a c  - 3888a b c  + 1458a b c  - 162a b c)d e
+--R                       + 
+--R                                 8   4        7 3 3       6 5 2      5 7   2
+--R                         (- 1296a b c  + 1944a b c  - 729a b c  + 81a b c)d e
+--R                       + 
+--R                               8 5        7 2 4       6 4 3      5 6 2  3
+--R                         (2592a c  - 2592a b c  + 810a b c  - 81a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   8 2     7 2     6 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                  7   2      6 3      5 5    5
+--R                              (36a b c  - 30a b c + 6a b )d e
+--R                            + 
+--R                                  7 3       6 2 2      5 4       4 6  2 4
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                     6   3       5 3 2       4 5       3 7  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                            + 
+--R                                       6 4       5 2 3       4 4 2       3 6
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       2 8
+--R                                  - 15a b
+--R                             *
+--R                                 4 2
+--R                                d e
+--R                            + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                             *
+--R                                 5
+--R                                d e
+--R                            + 
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                         /
+--R                                  13 3         12 2 2        11 4        10 6
+--R                            46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                               7 3      6 2 2     5 4   6
+--R                         (- 24a c  + 18a b c  - 3a b c)e
+--R                       + 
+--R                              6   3      5 3 2      4 5     5
+--R                         (156a b c  - 99a b c  + 15a b c)d e
+--R                       + 
+--R                             6 4       5 2 3       4 4 2      3 6   2 4
+--R                         (48a c  - 384a b c  + 213a b c  - 30a b c)d e
+--R                       + 
+--R                               5   4       4 3 3       3 5 2      2 7   3 3
+--R                         (- 72a b c  + 426a b c  - 222a b c  + 30a b c)d e
+--R                       + 
+--R                               5 5      4 2 4       3 4 3       2 6 2        8
+--R                           (72a c  - 78a b c  - 177a b c  + 108a b c  - 15a b c)
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                                     4   5       3 3 4      2 5 3        7 2
+--R                               - 132a b c  + 177a b c  - 24a b c  - 15a b c
+--R                             + 
+--R                                 9
+--R                               3b c
+--R                        *
+--R                            5
+--R                           d e
+--R                       + 
+--R                             3 2 5      2 4 4        6 3     8 2  6
+--R                         (60a b c  - 75a b c  + 27a b c  - 3b c )d
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                 6       5 2
+--R                            (108a c - 27a b )
+--R                         *
+--R                            ROOT
+--R                                        8 2     7 2     6 4  6
+--R                                   (- 4a c  + 4a b c - a b )e
+--R                                 + 
+--R                                       7   2      6 3      5 5    5
+--R                                   (36a b c  - 30a b c + 6a b )d e
+--R                                 + 
+--R                                       7 3       6 2 2      5 4       4 6  2 4
+--R                                   (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                 + 
+--R                                               6   3       5 3 2       4 5
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            3 7
+--R                                         20a b
+--R                                  *
+--R                                      3 3
+--R                                     d e
+--R                                 + 
+--R                                            6 4       5 2 3       4 4 2
+--R                                       - 36a c  + 234a b c  - 300a b c
+--R                                     + 
+--R                                           3 6       2 8
+--R                                       120a b c - 15a b
+--R                                  *
+--R                                      4 2
+--R                                     d e
+--R                                 + 
+--R                                          5   4       4 3 3       3 5 2
+--R                                       60a b c  - 180a b c  + 162a b c
+--R                                     + 
+--R                                            2 7        9
+--R                                       - 54a b c + 6a b
+--R                                  *
+--R                                      5
+--R                                     d e
+--R                                 + 
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  *
+--R                                      6
+--R                                     d
+--R                              /
+--R                                         13 3         12 2 2        11 4
+--R                                   46656a  c  - 34992a  b c  + 8748a  b c
+--R                                 + 
+--R                                         10 6
+--R                                   - 729a  b
+--R                        + 
+--R                             3   3        3      2 2    2      2          3  2
+--R                          - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                        + 
+--R                            2 2       2     4  3
+--R                          (a c  - 3a b c + b )d
+--R                     /
+--R                            6       5 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                        6 3     5 2 2  7         5   3      4 3 2    6
+--R                     (4a c  - 2a b c )e  + (- 26a b c  + 10a b c )d e
+--R                   + 
+--R                          5 4      4 2 3      3 4 2  2 5
+--R                     (- 4a c  + 60a b c  - 20a b c )d e
+--R                   + 
+--R                           4   4      3 3 3      2 5 2  3 4
+--R                     (- 10a b c  - 60a b c  + 20a b c )d e
+--R                   + 
+--R                           4 5      3 2 4      2 4 3        6 2  4 3
+--R                     (- 20a c  + 50a b c  + 20a b c  - 10a b c )d e
+--R                   + 
+--R                         3   5      2 3 4       5 3     7 2  5 2
+--R                     (26a b c  - 52a b c  + 6a b c  + 2b c )d e
+--R                   + 
+--R                           3 6     2 2 5        4 4     6 3  6
+--R                     (- 12a c  + 4a b c  + 14a b c  - 4b c )d e
+--R                   + 
+--R                         2   6        3 5     5 4  7
+--R                     (10a b c  - 10a b c  + 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R             2 +-+
+--R         2a x \|3
+--R      *
+--R         ROOT
+--R                         6       5 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                  ROOT
+--R                              8 2     7 2     6 4  6
+--R                         (- 4a c  + 4a b c - a b )e
+--R                       + 
+--R                             7   2      6 3      5 5    5
+--R                         (36a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             7 3       6 2 2      5 4       4 6  2 4
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                                6   3       5 3 2       4 5       3 7  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                       + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                             5   4       4 3 3       3 5 2      2 7        9  5
+--R                         (60a b c  - 180a b c  + 162a b c  - 54a b c + 6a b )d e
+--R                       + 
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                   3   3        3      2 2    2      2          3  2
+--R                - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R              + 
+--R                  2 2       2     4  3
+--R                (a c  - 3a b c + b )d
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                            8   2       7 3       6 5
+--R                      (1296a b c  - 648a b c + 81a b )e
+--R                    + 
+--R                            8 3        7 2 2       6 4       5 6
+--R                      (2592a c  - 2592a b c  + 810a b c - 81a b )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                                8 2     7 2     6 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                               7   2      6 3      5 5    5
+--R                           (36a b c  - 30a b c + 6a b )d e
+--R                         + 
+--R                               7 3       6 2 2      5 4       4 6  2 4
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                  6   3       5 3 2       4 5       3 7  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                         + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                          *
+--R                              4 2
+--R                             d e
+--R                         + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                          *
+--R                              5
+--R                             d e
+--R                         + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                          6 2      5 2      4 4  4
+--R                      (24a c  - 18a b c + 3a b )e
+--R                    + 
+--R                             5   2      4 3       3 5    3
+--R                      (- 132a b c  + 81a b c - 12a b )d e
+--R                    + 
+--R                            5 3       4 2 2       3 4       2 6  2 2
+--R                      (- 72a c  + 270a b c  - 135a b c + 18a b )d e
+--R                    + 
+--R                           4   3       3 3 2      2 5         7  3
+--R                      (132a b c  - 237a b c  + 99a b c - 12a b )d e
+--R                    + 
+--R                            3 2 3      2 4 2        6      8  4
+--R                      (- 60a b c  + 75a b c  - 27a b c + 3b )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                                6       5 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                         ROOT
+--R                                     8 2     7 2     6 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                    7   2      6 3      5 5    5
+--R                                (36a b c  - 30a b c + 6a b )d e
+--R                              + 
+--R                                    7 3       6 2 2      5 4       4 6  2 4
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                         6   3       5 3 2       4 5       3 7
+--R                                  (- 128a b c  + 282a b c  - 140a b c + 20a b )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                         6 4       5 2 3       4 4 2       3 6
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         2 8
+--R                                    - 15a b
+--R                               *
+--R                                   4 2
+--R                                  d e
+--R                              + 
+--R                                       5   4       4 3 3       3 5 2      2 7
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                        9
+--R                                    6a b
+--R                               *
+--R                                   5
+--R                                  d e
+--R                              + 
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  d
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                          3   3        3      2 2    2      2          3  2
+--R                       - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                     + 
+--R                         2 2       2     4  3
+--R                       (a c  - 3a b c + b )d
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                              8   2       7 3       6 5
+--R                        (1296a b c  - 648a b c + 81a b )e
+--R                      + 
+--R                              8 3        7 2 2       6 4       5 6
+--R                        (2592a c  - 2592a b c  + 810a b c - 81a b )d
+--R                   *
+--R                      ROOT
+--R                                  8 2     7 2     6 4  6
+--R                             (- 4a c  + 4a b c - a b )e
+--R                           + 
+--R                                 7   2      6 3      5 5    5
+--R                             (36a b c  - 30a b c + 6a b )d e
+--R                           + 
+--R                                 7 3       6 2 2      5 4       4 6  2 4
+--R                             (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                           + 
+--R                                    6   3       5 3 2       4 5       3 7  3 3
+--R                             (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                           + 
+--R                                      6 4       5 2 3       4 4 2       3 6
+--R                                 - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                               + 
+--R                                      2 8
+--R                                 - 15a b
+--R                            *
+--R                                4 2
+--R                               d e
+--R                           + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                            *
+--R                                5
+--R                               d e
+--R                           + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                        /
+--R                                 13 3         12 2 2        11 4        10 6
+--R                           46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                  + 
+--R                        6 2      5 2      4 4  4
+--R                    (24a c  - 18a b c + 3a b )e
+--R                  + 
+--R                           5   2      4 3       3 5    3
+--R                    (- 132a b c  + 81a b c - 12a b )d e
+--R                  + 
+--R                          5 3       4 2 2       3 4       2 6  2 2
+--R                    (- 72a c  + 270a b c  - 135a b c + 18a b )d e
+--R                  + 
+--R                         4   3       3 3 2      2 5         7  3
+--R                    (132a b c  - 237a b c  + 99a b c - 12a b )d e
+--R                  + 
+--R                          3 2 3      2 4 2        6      8  4
+--R                    (- 60a b c  + 75a b c  - 27a b c + 3b )d
+--R               *
+--R                  ROOT
+--R                                  6       5 2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                           ROOT
+--R                                       8 2     7 2     6 4  6
+--R                                  (- 4a c  + 4a b c - a b )e
+--R                                + 
+--R                                      7   2      6 3      5 5    5
+--R                                  (36a b c  - 30a b c + 6a b )d e
+--R                                + 
+--R                                      7 3       6 2 2      5 4       4 6  2 4
+--R                                  (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                + 
+--R                                              6   3       5 3 2       4 5
+--R                                        - 128a b c  + 282a b c  - 140a b c
+--R                                      + 
+--R                                           3 7
+--R                                        20a b
+--R                                 *
+--R                                     3 3
+--R                                    d e
+--R                                + 
+--R                                           6 4       5 2 3       4 4 2
+--R                                      - 36a c  + 234a b c  - 300a b c
+--R                                    + 
+--R                                          3 6       2 8
+--R                                      120a b c - 15a b
+--R                                 *
+--R                                     4 2
+--R                                    d e
+--R                                + 
+--R                                         5   4       4 3 3       3 5 2      2 7
+--R                                      60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                    + 
+--R                                          9
+--R                                      6a b
+--R                                 *
+--R                                     5
+--R                                    d e
+--R                                + 
+--R                                           4 2 4      3 4 3      2 6 2        8
+--R                                      - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                    + 
+--R                                         10
+--R                                      - b
+--R                                 *
+--R                                     6
+--R                                    d
+--R                             /
+--R                                        13 3         12 2 2        11 4
+--R                                  46656a  c  - 34992a  b c  + 8748a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 729a  b
+--R                       + 
+--R                            3   3        3      2 2    2      2          3  2
+--R                         - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                       + 
+--R                           2 2       2     4  3
+--R                         (a c  - 3a b c + b )d
+--R                    /
+--R                           6       5 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                         5 2     4 2   5       4   2      3 3     4
+--R                    (- 8a c  + 4a b c)e  + (44a b c  - 16a b c)d e
+--R                  + 
+--R                        4 3      3 2 2      2 4   2 3
+--R                    (16a c  - 80a b c  + 24a b c)d e
+--R                  + 
+--R                         3   3      2 3 2        5   3 2
+--R                    (- 8a b c  + 56a b c  - 16a b c)d e
+--R                  + 
+--R                        3 4      2 2 3       4 2     6   4
+--R                    (24a c  - 28a b c  - 8a b c  + 4b c)d e
+--R                  + 
+--R                          2   4        3 3     5 2  5
+--R                    (- 20a b c  + 20a b c  - 4b c )d
+--R               *
+--R                  x
+--R     + 
+--R             2 +-+
+--R         2a x \|3
+--R      *
+--R         ROOT
+--R                       6       5 2
+--R                  (108a c - 27a b )
+--R               *
+--R                  ROOT
+--R                              8 2     7 2     6 4  6
+--R                         (- 4a c  + 4a b c - a b )e
+--R                       + 
+--R                             7   2      6 3      5 5    5
+--R                         (36a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             7 3       6 2 2      5 4       4 6  2 4
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                                6   3       5 3 2       4 5       3 7  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                       + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                             5   4       4 3 3       3 5 2      2 7        9  5
+--R                         (60a b c  - 180a b c  + 162a b c  - 54a b c + 6a b )d e
+--R                       + 
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                   3   3        3      2 2    2      2          3  2
+--R                - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R              + 
+--R                  2 2       2     4  3
+--R                (a c  - 3a b c + b )d
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R         atan
+--R                            8   2       7 3       6 5
+--R                      (1296a b c  - 648a b c + 81a b )e
+--R                    + 
+--R                            8 3        7 2 2       6 4       5 6
+--R                      (2592a c  - 2592a b c  + 810a b c - 81a b )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                                8 2     7 2     6 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                               7   2      6 3      5 5    5
+--R                           (36a b c  - 30a b c + 6a b )d e
+--R                         + 
+--R                               7 3       6 2 2      5 4       4 6  2 4
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                  6   3       5 3 2       4 5       3 7  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                         + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                          *
+--R                              4 2
+--R                             d e
+--R                         + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                          *
+--R                              5
+--R                             d e
+--R                         + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                            6 2      5 2      4 4  4
+--R                      (- 24a c  + 18a b c - 3a b )e
+--R                    + 
+--R                           5   2      4 3       3 5    3
+--R                      (132a b c  - 81a b c + 12a b )d e
+--R                    + 
+--R                          5 3       4 2 2       3 4       2 6  2 2
+--R                      (72a c  - 270a b c  + 135a b c - 18a b )d e
+--R                    + 
+--R                             4   3       3 3 2      2 5         7  3
+--R                      (- 132a b c  + 237a b c  - 99a b c + 12a b )d e
+--R                    + 
+--R                          3 2 3      2 4 2        6      8  4
+--R                      (60a b c  - 75a b c  + 27a b c - 3b )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                              6       5 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                         ROOT
+--R                                     8 2     7 2     6 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                    7   2      6 3      5 5    5
+--R                                (36a b c  - 30a b c + 6a b )d e
+--R                              + 
+--R                                    7 3       6 2 2      5 4       4 6  2 4
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                         6   3       5 3 2       4 5       3 7
+--R                                  (- 128a b c  + 282a b c  - 140a b c + 20a b )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                         6 4       5 2 3       4 4 2       3 6
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         2 8
+--R                                    - 15a b
+--R                               *
+--R                                   4 2
+--R                                  d e
+--R                              + 
+--R                                       5   4       4 3 3       3 5 2      2 7
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                        9
+--R                                    6a b
+--R                               *
+--R                                   5
+--R                                  d e
+--R                              + 
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  d
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                          3   3        3      2 2    2      2          3  2
+--R                       - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                     + 
+--R                         2 2       2     4  3
+--R                       (a c  - 3a b c + b )d
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                              8   2       7 3       6 5
+--R                        (1296a b c  - 648a b c + 81a b )e
+--R                      + 
+--R                              8 3        7 2 2       6 4       5 6
+--R                        (2592a c  - 2592a b c  + 810a b c - 81a b )d
+--R                   *
+--R                      ROOT
+--R                                  8 2     7 2     6 4  6
+--R                             (- 4a c  + 4a b c - a b )e
+--R                           + 
+--R                                 7   2      6 3      5 5    5
+--R                             (36a b c  - 30a b c + 6a b )d e
+--R                           + 
+--R                                 7 3       6 2 2      5 4       4 6  2 4
+--R                             (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                           + 
+--R                                    6   3       5 3 2       4 5       3 7  3 3
+--R                             (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                           + 
+--R                                      6 4       5 2 3       4 4 2       3 6
+--R                                 - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                               + 
+--R                                      2 8
+--R                                 - 15a b
+--R                            *
+--R                                4 2
+--R                               d e
+--R                           + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                            *
+--R                                5
+--R                               d e
+--R                           + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                        /
+--R                                 13 3         12 2 2        11 4        10 6
+--R                           46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                  + 
+--R                          6 2      5 2      4 4  4
+--R                    (- 24a c  + 18a b c - 3a b )e
+--R                  + 
+--R                         5   2      4 3       3 5    3
+--R                    (132a b c  - 81a b c + 12a b )d e
+--R                  + 
+--R                        5 3       4 2 2       3 4       2 6  2 2
+--R                    (72a c  - 270a b c  + 135a b c - 18a b )d e
+--R                  + 
+--R                           4   3       3 3 2      2 5         7  3
+--R                    (- 132a b c  + 237a b c  - 99a b c + 12a b )d e
+--R                  + 
+--R                        3 2 3      2 4 2        6      8  4
+--R                    (60a b c  - 75a b c  + 27a b c - 3b )d
+--R               *
+--R                  ROOT
+--R                                6       5 2
+--R                           (108a c - 27a b )
+--R                        *
+--R                           ROOT
+--R                                       8 2     7 2     6 4  6
+--R                                  (- 4a c  + 4a b c - a b )e
+--R                                + 
+--R                                      7   2      6 3      5 5    5
+--R                                  (36a b c  - 30a b c + 6a b )d e
+--R                                + 
+--R                                      7 3       6 2 2      5 4       4 6  2 4
+--R                                  (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                + 
+--R                                              6   3       5 3 2       4 5
+--R                                        - 128a b c  + 282a b c  - 140a b c
+--R                                      + 
+--R                                           3 7
+--R                                        20a b
+--R                                 *
+--R                                     3 3
+--R                                    d e
+--R                                + 
+--R                                           6 4       5 2 3       4 4 2
+--R                                      - 36a c  + 234a b c  - 300a b c
+--R                                    + 
+--R                                          3 6       2 8
+--R                                      120a b c - 15a b
+--R                                 *
+--R                                     4 2
+--R                                    d e
+--R                                + 
+--R                                         5   4       4 3 3       3 5 2      2 7
+--R                                      60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                    + 
+--R                                          9
+--R                                      6a b
+--R                                 *
+--R                                     5
+--R                                    d e
+--R                                + 
+--R                                           4 2 4      3 4 3      2 6 2        8
+--R                                      - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                    + 
+--R                                         10
+--R                                      - b
+--R                                 *
+--R                                     6
+--R                                    d
+--R                             /
+--R                                        13 3         12 2 2        11 4
+--R                                  46656a  c  - 34992a  b c  + 8748a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 729a  b
+--R                       + 
+--R                            3   3        3      2 2    2      2          3  2
+--R                         - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                       + 
+--R                           2 2       2     4  3
+--R                         (a c  - 3a b c + b )d
+--R                    /
+--R                           6       5 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                       5 2     4 2   5         4   2      3 3     4
+--R                    (8a c  - 4a b c)e  + (- 44a b c  + 16a b c)d e
+--R                  + 
+--R                          4 3      3 2 2      2 4   2 3
+--R                    (- 16a c  + 80a b c  - 24a b c)d e
+--R                  + 
+--R                       3   3      2 3 2        5   3 2
+--R                    (8a b c  - 56a b c  + 16a b c)d e
+--R                  + 
+--R                          3 4      2 2 3       4 2     6   4
+--R                    (- 24a c  + 28a b c  + 8a b c  - 4b c)d e
+--R                  + 
+--R                        2   4        3 3     5 2  5
+--R                    (20a b c  - 20a b c  + 4b c )d
+--R               *
+--R                  x
+--R     + 
+--R       - d
+--R  /
+--R         2
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 42
+
+--S 43 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +-----------+
+--R              +-+ |          2                   +-+ 3+-+2
+--R         (- d\|3 \|- 4a c + b   + (- 2a e + b d)\|3 )\|c
+--R      *
+--R          +--------------------+2
+--R          |   +-----------+
+--R         3|   |          2
+--R         \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                          +--------------------+2
+--R                 +-----------+                            |   +-----------+
+--R             +-+ |          2                  +-+ 3+-+2 3|   |          2
+--R         (2d\|3 \|- 4a c + b   + (4a e - 2b d)\|3 )\|c   \|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                                     +--------------------+2
+--R                       +-----------+ |   +-----------+
+--R              3+-+ +-+ |          2 3|   |          2
+--R            3a\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                            6       5 2
+--R                     (- 108a c + 27a b )
+--R                  *
+--R                     ROOT
+--R                                 8 2     7 2     6 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                7   2      6 3      5 5    5
+--R                            (36a b c  - 30a b c + 6a b )d e
+--R                          + 
+--R                                7 3       6 2 2      5 4       4 6  2 4
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                   6   3       5 3 2       4 5       3 7  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                          + 
+--R                                     6 4       5 2 3       4 4 2       3 6
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     2 8
+--R                                - 15a b
+--R                           *
+--R                               4 2
+--R                              d e
+--R                          + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                           *
+--R                               5
+--R                              d e
+--R                          + 
+--R                                4 2 4      3 4 3      2 6 2        8     10  6
+--R                          (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                       /
+--R                                13 3         12 2 2        11 4        10 6
+--R                          46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                 + 
+--R                      3   3        3      2 2    2      2          3  2
+--R                   - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                 + 
+--R                     2 2       2     4  3
+--R                   (a c  - 3a b c + b )d
+--R              /
+--R                     6       5 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +------------------+2
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                10   3         9 3 2        8 5        7 7  2
+--R                         (15552a  b c  - 11664a b c  + 2916a b c - 243a b )e
+--R                       + 
+--R                                   10 4         9 2 3         8 4 2        7 6
+--R                             31104a  c  - 54432a b c  + 29160a b c  - 6318a b c
+--R                           + 
+--R                                 6 8
+--R                             486a b
+--R                        *
+--R                           d e
+--R                       + 
+--R                                     9   4         8 3 3         7 5 2
+--R                             - 31104a b c  + 38880a b c  - 17496a b c
+--R                           + 
+--R                                  6 7        5 9
+--R                             3402a b c - 243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                       ROOT
+--R                                   8 2     7 2     6 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                  7   2      6 3      5 5    5
+--R                              (36a b c  - 30a b c + 6a b )d e
+--R                            + 
+--R                                  7 3       6 2 2      5 4       4 6  2 4
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                     6   3       5 3 2       4 5       3 7  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                            + 
+--R                                       6 4       5 2 3       4 4 2       3 6
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       2 8
+--R                                  - 15a b
+--R                             *
+--R                                 4 2
+--R                                d e
+--R                            + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                             *
+--R                                 5
+--R                                d e
+--R                            + 
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                         /
+--R                                  13 3         12 2 2        11 4        10 6
+--R                            46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                          8 3       7 2 2      6 4      5 6  5
+--R                     (144a c  - 180a b c  + 72a b c - 9a b )e
+--R                   + 
+--R                             7   3        6 3 2       5 5       4 7    4
+--R                     (- 1080a b c  + 1170a b c  - 405a b c + 45a b )d e
+--R                   + 
+--R                              7 4        6 2 3        5 4 2       4 6       3 8
+--R                       (- 576a c  + 3528a b c  - 3006a b c  + 900a b c - 90a b )
+--R                    *
+--R                        2 3
+--R                       d e
+--R                   + 
+--R                                6   4        5 3 3        4 5 2       3 7
+--R                           2304a b c  - 5652a b c  + 3789a b c  - 990a b c
+--R                         + 
+--R                              2 9
+--R                           90a b
+--R                    *
+--R                        3 2
+--R                       d e
+--R                   + 
+--R                             6 5        5 2 4        4 4 3        3 6 2
+--R                         432a c  - 2916a b c  + 4302a b c  - 2340a b c
+--R                       + 
+--R                             2 8         10
+--R                         540a b c - 45a b
+--R                    *
+--R                        4
+--R                       d e
+--R                   + 
+--R                               5   5        4 3 4        3 5 3       2 7 2
+--R                         - 360a b c  + 1170a b c  - 1242a b c  + 567a b c
+--R                       + 
+--R                                 9      11
+--R                         - 117a b c + 9b
+--R                    *
+--R                        5
+--R                       d
+--R                *
+--R                     ROOT
+--R                                     6       5 2
+--R                              (- 108a c + 27a b )
+--R                           *
+--R                              ROOT
+--R                                          8 2     7 2     6 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                         7   2      6 3      5 5    5
+--R                                     (36a b c  - 30a b c + 6a b )d e
+--R                                   + 
+--R                                         7 3       6 2 2      5 4       4 6  2 4
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                               6   3       5 3 2       4 5
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            3 7
+--R                                         20a b
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                              6 4       5 2 3       4 4 2
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                             3 6       2 8
+--R                                         120a b c - 15a b
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                            5   4       4 3 3       3 5 2
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                              2 7        9
+--R                                         - 54a b c + 6a b
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           13 3         12 2 2        11 4
+--R                                     46656a  c  - 34992a  b c  + 8748a  b c
+--R                                   + 
+--R                                           10 6
+--R                                     - 729a  b
+--R                          + 
+--R                               3   3        3      2 2    2
+--R                            - a b e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                               2          3  2      2 2       2     4  3
+--R                            (6a b c - 3a b )d e + (a c  - 3a b c + b )d
+--R                       /
+--R                              6       5 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                                 9   3       8 3 2      7 5   3
+--R                         (- 1296a b c  + 648a b c  - 81a b c)e
+--R                       + 
+--R                                 9 4        8 2 3        7 4 2       6 6     2
+--R                         (- 2592a c  + 3888a b c  - 1458a b c  + 162a b c)d e
+--R                       + 
+--R                               8   4        7 3 3       6 5 2      5 7   2
+--R                         (1296a b c  - 1944a b c  + 729a b c  - 81a b c)d e
+--R                       + 
+--R                                 8 5        7 2 4       6 4 3      5 6 2  3
+--R                         (- 2592a c  + 2592a b c  - 810a b c  + 81a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   8 2     7 2     6 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                  7   2      6 3      5 5    5
+--R                              (36a b c  - 30a b c + 6a b )d e
+--R                            + 
+--R                                  7 3       6 2 2      5 4       4 6  2 4
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                     6   3       5 3 2       4 5       3 7  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                            + 
+--R                                       6 4       5 2 3       4 4 2       3 6
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       2 8
+--R                                  - 15a b
+--R                             *
+--R                                 4 2
+--R                                d e
+--R                            + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                             *
+--R                                 5
+--R                                d e
+--R                            + 
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                         /
+--R                                  13 3         12 2 2        11 4        10 6
+--R                            46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                               7 3      6 2 2     5 4   6
+--R                         (- 24a c  + 18a b c  - 3a b c)e
+--R                       + 
+--R                              6   3      5 3 2      4 5     5
+--R                         (156a b c  - 99a b c  + 15a b c)d e
+--R                       + 
+--R                             6 4       5 2 3       4 4 2      3 6   2 4
+--R                         (48a c  - 384a b c  + 213a b c  - 30a b c)d e
+--R                       + 
+--R                               5   4       4 3 3       3 5 2      2 7   3 3
+--R                         (- 72a b c  + 426a b c  - 222a b c  + 30a b c)d e
+--R                       + 
+--R                               5 5      4 2 4       3 4 3       2 6 2        8
+--R                           (72a c  - 78a b c  - 177a b c  + 108a b c  - 15a b c)
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                                     4   5       3 3 4      2 5 3        7 2
+--R                               - 132a b c  + 177a b c  - 24a b c  - 15a b c
+--R                             + 
+--R                                 9
+--R                               3b c
+--R                        *
+--R                            5
+--R                           d e
+--R                       + 
+--R                             3 2 5      2 4 4        6 3     8 2  6
+--R                         (60a b c  - 75a b c  + 27a b c  - 3b c )d
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                   6       5 2
+--R                            (- 108a c + 27a b )
+--R                         *
+--R                            ROOT
+--R                                        8 2     7 2     6 4  6
+--R                                   (- 4a c  + 4a b c - a b )e
+--R                                 + 
+--R                                       7   2      6 3      5 5    5
+--R                                   (36a b c  - 30a b c + 6a b )d e
+--R                                 + 
+--R                                       7 3       6 2 2      5 4       4 6  2 4
+--R                                   (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                 + 
+--R                                               6   3       5 3 2       4 5
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            3 7
+--R                                         20a b
+--R                                  *
+--R                                      3 3
+--R                                     d e
+--R                                 + 
+--R                                            6 4       5 2 3       4 4 2
+--R                                       - 36a c  + 234a b c  - 300a b c
+--R                                     + 
+--R                                           3 6       2 8
+--R                                       120a b c - 15a b
+--R                                  *
+--R                                      4 2
+--R                                     d e
+--R                                 + 
+--R                                          5   4       4 3 3       3 5 2
+--R                                       60a b c  - 180a b c  + 162a b c
+--R                                     + 
+--R                                            2 7        9
+--R                                       - 54a b c + 6a b
+--R                                  *
+--R                                      5
+--R                                     d e
+--R                                 + 
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  *
+--R                                      6
+--R                                     d
+--R                              /
+--R                                         13 3         12 2 2        11 4
+--R                                   46656a  c  - 34992a  b c  + 8748a  b c
+--R                                 + 
+--R                                         10 6
+--R                                   - 729a  b
+--R                        + 
+--R                             3   3        3      2 2    2      2          3  2
+--R                          - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                        + 
+--R                            2 2       2     4  3
+--R                          (a c  - 3a b c + b )d
+--R                     /
+--R                            6       5 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                        6 3     5 2 2  7         5   3      4 3 2    6
+--R                     (4a c  - 2a b c )e  + (- 26a b c  + 10a b c )d e
+--R                   + 
+--R                          5 4      4 2 3      3 4 2  2 5
+--R                     (- 4a c  + 60a b c  - 20a b c )d e
+--R                   + 
+--R                           4   4      3 3 3      2 5 2  3 4
+--R                     (- 10a b c  - 60a b c  + 20a b c )d e
+--R                   + 
+--R                           4 5      3 2 4      2 4 3        6 2  4 3
+--R                     (- 20a c  + 50a b c  + 20a b c  - 10a b c )d e
+--R                   + 
+--R                         3   5      2 3 4       5 3     7 2  5 2
+--R                     (26a b c  - 52a b c  + 6a b c  + 2b c )d e
+--R                   + 
+--R                           3 6     2 2 5        4 4     6 3  6
+--R                     (- 12a c  + 4a b c  + 14a b c  - 4b c )d e
+--R                   + 
+--R                         2   6        3 5     5 4  7
+--R                     (10a b c  - 10a b c  + 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                                  +--------------------+2
+--R                    +-----------+ |   +-----------+
+--R           3+-+ +-+ |          2 3|   |          2
+--R         6a\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         6       5 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                  ROOT
+--R                              8 2     7 2     6 4  6
+--R                         (- 4a c  + 4a b c - a b )e
+--R                       + 
+--R                             7   2      6 3      5 5    5
+--R                         (36a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             7 3       6 2 2      5 4       4 6  2 4
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                                6   3       5 3 2       4 5       3 7  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                       + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                             5   4       4 3 3       3 5 2      2 7        9  5
+--R                         (60a b c  - 180a b c  + 162a b c  - 54a b c + 6a b )d e
+--R                       + 
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                   3   3        3      2 2    2      2          3  2
+--R                - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R              + 
+--R                  2 2       2     4  3
+--R                (a c  - 3a b c + b )d
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            8   2       7 3       6 5
+--R                      (1296a b c  - 648a b c + 81a b )e
+--R                    + 
+--R                            8 3        7 2 2       6 4       5 6
+--R                      (2592a c  - 2592a b c  + 810a b c - 81a b )d
+--R                 *
+--R                    ROOT
+--R                                8 2     7 2     6 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                               7   2      6 3      5 5    5
+--R                           (36a b c  - 30a b c + 6a b )d e
+--R                         + 
+--R                               7 3       6 2 2      5 4       4 6  2 4
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                  6   3       5 3 2       4 5       3 7  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                         + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                          *
+--R                              4 2
+--R                             d e
+--R                         + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                          *
+--R                              5
+--R                             d e
+--R                         + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                      6 2      5 2      4 4  4
+--R                  (24a c  - 18a b c + 3a b )e
+--R                + 
+--R                         5   2      4 3       3 5    3
+--R                  (- 132a b c  + 81a b c - 12a b )d e
+--R                + 
+--R                        5 3       4 2 2       3 4       2 6  2 2
+--R                  (- 72a c  + 270a b c  - 135a b c + 18a b )d e
+--R                + 
+--R                       4   3       3 3 2      2 5         7  3
+--R                  (132a b c  - 237a b c  + 99a b c - 12a b )d e
+--R                + 
+--R                        3 2 3      2 4 2        6      8  4
+--R                  (- 60a b c  + 75a b c  - 27a b c + 3b )d
+--R             *
+--R                ROOT
+--R                                6       5 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                         ROOT
+--R                                     8 2     7 2     6 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                    7   2      6 3      5 5    5
+--R                                (36a b c  - 30a b c + 6a b )d e
+--R                              + 
+--R                                    7 3       6 2 2      5 4       4 6  2 4
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                         6   3       5 3 2       4 5       3 7
+--R                                  (- 128a b c  + 282a b c  - 140a b c + 20a b )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                         6 4       5 2 3       4 4 2       3 6
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         2 8
+--R                                    - 15a b
+--R                               *
+--R                                   4 2
+--R                                  d e
+--R                              + 
+--R                                       5   4       4 3 3       3 5 2      2 7
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                        9
+--R                                    6a b
+--R                               *
+--R                                   5
+--R                                  d e
+--R                              + 
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  d
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                          3   3        3      2 2    2      2          3  2
+--R                       - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                     + 
+--R                         2 2       2     4  3
+--R                       (a c  - 3a b c + b )d
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                     5 2     4 2   5         4   2     3 3     4
+--R                  (4a c  - 2a b c)e  + (- 22a b c  + 8a b c)d e
+--R                + 
+--R                       4 3      3 2 2      2 4   2 3
+--R                  (- 8a c  + 40a b c  - 12a b c)d e
+--R                + 
+--R                     3   3      2 3 2       5   3 2
+--R                  (4a b c  - 28a b c  + 8a b c)d e
+--R                + 
+--R                        3 4      2 2 3       4 2     6   4
+--R                  (- 12a c  + 14a b c  + 4a b c  - 2b c)d e
+--R                + 
+--R                      2   4        3 3     5 2  5
+--R                  (10a b c  - 10a b c  + 2b c )d
+--R             *
+--R                x
+--R     + 
+--R                                                          +------------------+2
+--R                  +-----------+                           | +-----------+
+--R              +-+ |          2                 +-+ 3+-+2 3| |          2
+--R         (- d\|3 \|- 4a c + b   + (2a e - b d)\|3 )\|c   \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                            +------------------+2
+--R                 +-----------+                              | +-----------+
+--R             +-+ |          2                    +-+ 3+-+2 3| |          2
+--R         (2d\|3 \|- 4a c + b   + (- 4a e + 2b d)\|3 )\|c   \|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                  +--------------------+2
+--R                    +-----------+ |   +-----------+
+--R           3+-+ +-+ |          2 3|   |          2
+--R         6a\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       6       5 2
+--R                  (108a c - 27a b )
+--R               *
+--R                  ROOT
+--R                              8 2     7 2     6 4  6
+--R                         (- 4a c  + 4a b c - a b )e
+--R                       + 
+--R                             7   2      6 3      5 5    5
+--R                         (36a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             7 3       6 2 2      5 4       4 6  2 4
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                                6   3       5 3 2       4 5       3 7  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                       + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                             5   4       4 3 3       3 5 2      2 7        9  5
+--R                         (60a b c  - 180a b c  + 162a b c  - 54a b c + 6a b )d e
+--R                       + 
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                   3   3        3      2 2    2      2          3  2
+--R                - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R              + 
+--R                  2 2       2     4  3
+--R                (a c  - 3a b c + b )d
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              8   2       7 3       6 5
+--R                      (- 1296a b c  + 648a b c - 81a b )e
+--R                    + 
+--R                              8 3        7 2 2       6 4       5 6
+--R                      (- 2592a c  + 2592a b c  - 810a b c + 81a b )d
+--R                 *
+--R                    ROOT
+--R                                8 2     7 2     6 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                               7   2      6 3      5 5    5
+--R                           (36a b c  - 30a b c + 6a b )d e
+--R                         + 
+--R                               7 3       6 2 2      5 4       4 6  2 4
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                  6   3       5 3 2       4 5       3 7  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                         + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                          *
+--R                              4 2
+--R                             d e
+--R                         + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                          *
+--R                              5
+--R                             d e
+--R                         + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                      6 2      5 2      4 4  4
+--R                  (24a c  - 18a b c + 3a b )e
+--R                + 
+--R                         5   2      4 3       3 5    3
+--R                  (- 132a b c  + 81a b c - 12a b )d e
+--R                + 
+--R                        5 3       4 2 2       3 4       2 6  2 2
+--R                  (- 72a c  + 270a b c  - 135a b c + 18a b )d e
+--R                + 
+--R                       4   3       3 3 2      2 5         7  3
+--R                  (132a b c  - 237a b c  + 99a b c - 12a b )d e
+--R                + 
+--R                        3 2 3      2 4 2        6      8  4
+--R                  (- 60a b c  + 75a b c  - 27a b c + 3b )d
+--R             *
+--R                ROOT
+--R                              6       5 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                         ROOT
+--R                                     8 2     7 2     6 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                    7   2      6 3      5 5    5
+--R                                (36a b c  - 30a b c + 6a b )d e
+--R                              + 
+--R                                    7 3       6 2 2      5 4       4 6  2 4
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                         6   3       5 3 2       4 5       3 7
+--R                                  (- 128a b c  + 282a b c  - 140a b c + 20a b )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                         6 4       5 2 3       4 4 2       3 6
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         2 8
+--R                                    - 15a b
+--R                               *
+--R                                   4 2
+--R                                  d e
+--R                              + 
+--R                                       5   4       4 3 3       3 5 2      2 7
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                        9
+--R                                    6a b
+--R                               *
+--R                                   5
+--R                                  d e
+--R                              + 
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  d
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                          3   3        3      2 2    2      2          3  2
+--R                       - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                     + 
+--R                         2 2       2     4  3
+--R                       (a c  - 3a b c + b )d
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R            + 
+--R                     5 2     4 2   5         4   2     3 3     4
+--R                  (4a c  - 2a b c)e  + (- 22a b c  + 8a b c)d e
+--R                + 
+--R                       4 3      3 2 2      2 4   2 3
+--R                  (- 8a c  + 40a b c  - 12a b c)d e
+--R                + 
+--R                     3   3      2 3 2       5   3 2
+--R                  (4a b c  - 28a b c  + 8a b c)d e
+--R                + 
+--R                        3 4      2 2 3       4 2     6   4
+--R                  (- 12a c  + 14a b c  + 4a b c  - 2b c)d e
+--R                + 
+--R                      2   4        3 3     5 2  5
+--R                  (10a b c  - 10a b c  + 2b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                     +--------------------+2
+--R                       +-----------+ |   +-----------+
+--R              3+-+ +-+ |          2 3|   |          2
+--R            3a\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                          6       5 2
+--R                     (108a c - 27a b )
+--R                  *
+--R                     ROOT
+--R                                 8 2     7 2     6 4  6
+--R                            (- 4a c  + 4a b c - a b )e
+--R                          + 
+--R                                7   2      6 3      5 5    5
+--R                            (36a b c  - 30a b c + 6a b )d e
+--R                          + 
+--R                                7 3       6 2 2      5 4       4 6  2 4
+--R                            (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                          + 
+--R                                   6   3       5 3 2       4 5       3 7  3 3
+--R                            (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                          + 
+--R                                     6 4       5 2 3       4 4 2       3 6
+--R                                - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                              + 
+--R                                     2 8
+--R                                - 15a b
+--R                           *
+--R                               4 2
+--R                              d e
+--R                          + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                           *
+--R                               5
+--R                              d e
+--R                          + 
+--R                                4 2 4      3 4 3      2 6 2        8     10  6
+--R                          (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                       /
+--R                                13 3         12 2 2        11 4        10 6
+--R                          46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                 + 
+--R                      3   3        3      2 2    2      2          3  2
+--R                   - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                 + 
+--R                     2 2       2     4  3
+--R                   (a c  - 3a b c + b )d
+--R              /
+--R                     6       5 2
+--R                 216a c - 54a b
+--R           ,
+--R               3
+--R         *
+--R             +------------------+2
+--R             | +-----------+
+--R            3| |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                  10   3         9 3 2        8 5        7 7  2
+--R                         (- 15552a  b c  + 11664a b c  - 2916a b c + 243a b )e
+--R                       + 
+--R                                     10 4         9 2 3         8 4 2
+--R                             - 31104a  c  + 54432a b c  - 29160a b c
+--R                           + 
+--R                                  7 6        6 8
+--R                             6318a b c - 486a b
+--R                        *
+--R                           d e
+--R                       + 
+--R                                   9   4         8 3 3         7 5 2        6 7
+--R                             31104a b c  - 38880a b c  + 17496a b c  - 3402a b c
+--R                           + 
+--R                                 5 9
+--R                             243a b
+--R                        *
+--R                            2
+--R                           d
+--R                    *
+--R                       ROOT
+--R                                   8 2     7 2     6 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                  7   2      6 3      5 5    5
+--R                              (36a b c  - 30a b c + 6a b )d e
+--R                            + 
+--R                                  7 3       6 2 2      5 4       4 6  2 4
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                     6   3       5 3 2       4 5       3 7  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                            + 
+--R                                       6 4       5 2 3       4 4 2       3 6
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       2 8
+--R                                  - 15a b
+--R                             *
+--R                                 4 2
+--R                                d e
+--R                            + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                             *
+--R                                 5
+--R                                d e
+--R                            + 
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                         /
+--R                                  13 3         12 2 2        11 4        10 6
+--R                            46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                          8 3       7 2 2      6 4      5 6  5
+--R                     (144a c  - 180a b c  + 72a b c - 9a b )e
+--R                   + 
+--R                             7   3        6 3 2       5 5       4 7    4
+--R                     (- 1080a b c  + 1170a b c  - 405a b c + 45a b )d e
+--R                   + 
+--R                              7 4        6 2 3        5 4 2       4 6       3 8
+--R                       (- 576a c  + 3528a b c  - 3006a b c  + 900a b c - 90a b )
+--R                    *
+--R                        2 3
+--R                       d e
+--R                   + 
+--R                                6   4        5 3 3        4 5 2       3 7
+--R                           2304a b c  - 5652a b c  + 3789a b c  - 990a b c
+--R                         + 
+--R                              2 9
+--R                           90a b
+--R                    *
+--R                        3 2
+--R                       d e
+--R                   + 
+--R                             6 5        5 2 4        4 4 3        3 6 2
+--R                         432a c  - 2916a b c  + 4302a b c  - 2340a b c
+--R                       + 
+--R                             2 8         10
+--R                         540a b c - 45a b
+--R                    *
+--R                        4
+--R                       d e
+--R                   + 
+--R                               5   5        4 3 4        3 5 3       2 7 2
+--R                         - 360a b c  + 1170a b c  - 1242a b c  + 567a b c
+--R                       + 
+--R                                 9      11
+--R                         - 117a b c + 9b
+--R                    *
+--R                        5
+--R                       d
+--R                *
+--R                     ROOT
+--R                                   6       5 2
+--R                              (108a c - 27a b )
+--R                           *
+--R                              ROOT
+--R                                          8 2     7 2     6 4  6
+--R                                     (- 4a c  + 4a b c - a b )e
+--R                                   + 
+--R                                         7   2      6 3      5 5    5
+--R                                     (36a b c  - 30a b c + 6a b )d e
+--R                                   + 
+--R                                         7 3       6 2 2      5 4       4 6  2 4
+--R                                     (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                   + 
+--R                                               6   3       5 3 2       4 5
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            3 7
+--R                                         20a b
+--R                                    *
+--R                                        3 3
+--R                                       d e
+--R                                   + 
+--R                                              6 4       5 2 3       4 4 2
+--R                                         - 36a c  + 234a b c  - 300a b c
+--R                                       + 
+--R                                             3 6       2 8
+--R                                         120a b c - 15a b
+--R                                    *
+--R                                        4 2
+--R                                       d e
+--R                                   + 
+--R                                            5   4       4 3 3       3 5 2
+--R                                         60a b c  - 180a b c  + 162a b c
+--R                                       + 
+--R                                              2 7        9
+--R                                         - 54a b c + 6a b
+--R                                    *
+--R                                        5
+--R                                       d e
+--R                                   + 
+--R                                              4 2 4      3 4 3      2 6 2
+--R                                         - 25a b c  + 50a b c  - 35a b c
+--R                                       + 
+--R                                              8     10
+--R                                         10a b c - b
+--R                                    *
+--R                                        6
+--R                                       d
+--R                                /
+--R                                           13 3         12 2 2        11 4
+--R                                     46656a  c  - 34992a  b c  + 8748a  b c
+--R                                   + 
+--R                                           10 6
+--R                                     - 729a  b
+--R                          + 
+--R                               3   3        3      2 2    2
+--R                            - a b e  + (- 3a c + 3a b )d e
+--R                          + 
+--R                               2          3  2      2 2       2     4  3
+--R                            (6a b c - 3a b )d e + (a c  - 3a b c + b )d
+--R                       /
+--R                              6       5 2
+--R                          216a c - 54a b
+--R                    ,
+--R                        3
+--R                  **
+--R                     2
+--R               + 
+--R                               9   3       8 3 2      7 5   3
+--R                         (1296a b c  - 648a b c  + 81a b c)e
+--R                       + 
+--R                               9 4        8 2 3        7 4 2       6 6     2
+--R                         (2592a c  - 3888a b c  + 1458a b c  - 162a b c)d e
+--R                       + 
+--R                                 8   4        7 3 3       6 5 2      5 7   2
+--R                         (- 1296a b c  + 1944a b c  - 729a b c  + 81a b c)d e
+--R                       + 
+--R                               8 5        7 2 4       6 4 3      5 6 2  3
+--R                         (2592a c  - 2592a b c  + 810a b c  - 81a b c )d
+--R                    *
+--R                       x
+--R                    *
+--R                       ROOT
+--R                                   8 2     7 2     6 4  6
+--R                              (- 4a c  + 4a b c - a b )e
+--R                            + 
+--R                                  7   2      6 3      5 5    5
+--R                              (36a b c  - 30a b c + 6a b )d e
+--R                            + 
+--R                                  7 3       6 2 2      5 4       4 6  2 4
+--R                              (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                            + 
+--R                                     6   3       5 3 2       4 5       3 7  3 3
+--R                              (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                            + 
+--R                                       6 4       5 2 3       4 4 2       3 6
+--R                                  - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                + 
+--R                                       2 8
+--R                                  - 15a b
+--R                             *
+--R                                 4 2
+--R                                d e
+--R                            + 
+--R                                     5   4       4 3 3       3 5 2      2 7
+--R                                  60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                + 
+--R                                      9
+--R                                  6a b
+--R                             *
+--R                                 5
+--R                                d e
+--R                            + 
+--R                                  4 2 4      3 4 3      2 6 2        8     10  6
+--R                            (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                         /
+--R                                  13 3         12 2 2        11 4        10 6
+--R                            46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                   + 
+--R                               7 3      6 2 2     5 4   6
+--R                         (- 24a c  + 18a b c  - 3a b c)e
+--R                       + 
+--R                              6   3      5 3 2      4 5     5
+--R                         (156a b c  - 99a b c  + 15a b c)d e
+--R                       + 
+--R                             6 4       5 2 3       4 4 2      3 6   2 4
+--R                         (48a c  - 384a b c  + 213a b c  - 30a b c)d e
+--R                       + 
+--R                               5   4       4 3 3       3 5 2      2 7   3 3
+--R                         (- 72a b c  + 426a b c  - 222a b c  + 30a b c)d e
+--R                       + 
+--R                               5 5      4 2 4       3 4 3       2 6 2        8
+--R                           (72a c  - 78a b c  - 177a b c  + 108a b c  - 15a b c)
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                                     4   5       3 3 4      2 5 3        7 2
+--R                               - 132a b c  + 177a b c  - 24a b c  - 15a b c
+--R                             + 
+--R                                 9
+--R                               3b c
+--R                        *
+--R                            5
+--R                           d e
+--R                       + 
+--R                             3 2 5      2 4 4        6 3     8 2  6
+--R                         (60a b c  - 75a b c  + 27a b c  - 3b c )d
+--R                    *
+--R                       x
+--R                *
+--R                   ROOT
+--R                                 6       5 2
+--R                            (108a c - 27a b )
+--R                         *
+--R                            ROOT
+--R                                        8 2     7 2     6 4  6
+--R                                   (- 4a c  + 4a b c - a b )e
+--R                                 + 
+--R                                       7   2      6 3      5 5    5
+--R                                   (36a b c  - 30a b c + 6a b )d e
+--R                                 + 
+--R                                       7 3       6 2 2      5 4       4 6  2 4
+--R                                   (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                 + 
+--R                                               6   3       5 3 2       4 5
+--R                                         - 128a b c  + 282a b c  - 140a b c
+--R                                       + 
+--R                                            3 7
+--R                                         20a b
+--R                                  *
+--R                                      3 3
+--R                                     d e
+--R                                 + 
+--R                                            6 4       5 2 3       4 4 2
+--R                                       - 36a c  + 234a b c  - 300a b c
+--R                                     + 
+--R                                           3 6       2 8
+--R                                       120a b c - 15a b
+--R                                  *
+--R                                      4 2
+--R                                     d e
+--R                                 + 
+--R                                          5   4       4 3 3       3 5 2
+--R                                       60a b c  - 180a b c  + 162a b c
+--R                                     + 
+--R                                            2 7        9
+--R                                       - 54a b c + 6a b
+--R                                  *
+--R                                      5
+--R                                     d e
+--R                                 + 
+--R                                            4 2 4      3 4 3      2 6 2
+--R                                       - 25a b c  + 50a b c  - 35a b c
+--R                                     + 
+--R                                            8     10
+--R                                       10a b c - b
+--R                                  *
+--R                                      6
+--R                                     d
+--R                              /
+--R                                         13 3         12 2 2        11 4
+--R                                   46656a  c  - 34992a  b c  + 8748a  b c
+--R                                 + 
+--R                                         10 6
+--R                                   - 729a  b
+--R                        + 
+--R                             3   3        3      2 2    2      2          3  2
+--R                          - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                        + 
+--R                            2 2       2     4  3
+--R                          (a c  - 3a b c + b )d
+--R                     /
+--R                            6       5 2
+--R                        216a c - 54a b
+--R                  ,
+--R                      3
+--R               + 
+--R                        6 3     5 2 2  7         5   3      4 3 2    6
+--R                     (4a c  - 2a b c )e  + (- 26a b c  + 10a b c )d e
+--R                   + 
+--R                          5 4      4 2 3      3 4 2  2 5
+--R                     (- 4a c  + 60a b c  - 20a b c )d e
+--R                   + 
+--R                           4   4      3 3 3      2 5 2  3 4
+--R                     (- 10a b c  - 60a b c  + 20a b c )d e
+--R                   + 
+--R                           4 5      3 2 4      2 4 3        6 2  4 3
+--R                     (- 20a c  + 50a b c  + 20a b c  - 10a b c )d e
+--R                   + 
+--R                         3   5      2 3 4       5 3     7 2  5 2
+--R                     (26a b c  - 52a b c  + 6a b c  + 2b c )d e
+--R                   + 
+--R                           3 6     2 2 5        4 4     6 3  6
+--R                     (- 12a c  + 4a b c  + 14a b c  - 4b c )d e
+--R                   + 
+--R                         2   6        3 5     5 4  7
+--R                     (10a b c  - 10a b c  + 2b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                               +--------------------+2
+--R                 +-----------+ |   +-----------+
+--R            3+-+ |          2 3|   |          2
+--R         18a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                         6       5 2
+--R                  (- 108a c + 27a b )
+--R               *
+--R                  ROOT
+--R                              8 2     7 2     6 4  6
+--R                         (- 4a c  + 4a b c - a b )e
+--R                       + 
+--R                             7   2      6 3      5 5    5
+--R                         (36a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             7 3       6 2 2      5 4       4 6  2 4
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                                6   3       5 3 2       4 5       3 7  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                       + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                             5   4       4 3 3       3 5 2      2 7        9  5
+--R                         (60a b c  - 180a b c  + 162a b c  - 54a b c + 6a b )d e
+--R                       + 
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                   3   3        3      2 2    2      2          3  2
+--R                - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R              + 
+--R                  2 2       2     4  3
+--R                (a c  - 3a b c + b )d
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                            8   2       7 3       6 5
+--R                      (1296a b c  - 648a b c + 81a b )e
+--R                    + 
+--R                            8 3        7 2 2       6 4       5 6
+--R                      (2592a c  - 2592a b c  + 810a b c - 81a b )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                                8 2     7 2     6 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                               7   2      6 3      5 5    5
+--R                           (36a b c  - 30a b c + 6a b )d e
+--R                         + 
+--R                               7 3       6 2 2      5 4       4 6  2 4
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                  6   3       5 3 2       4 5       3 7  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                         + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                          *
+--R                              4 2
+--R                             d e
+--R                         + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                          *
+--R                              5
+--R                             d e
+--R                         + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                          6 2      5 2      4 4  4
+--R                      (24a c  - 18a b c + 3a b )e
+--R                    + 
+--R                             5   2      4 3       3 5    3
+--R                      (- 132a b c  + 81a b c - 12a b )d e
+--R                    + 
+--R                            5 3       4 2 2       3 4       2 6  2 2
+--R                      (- 72a c  + 270a b c  - 135a b c + 18a b )d e
+--R                    + 
+--R                           4   3       3 3 2      2 5         7  3
+--R                      (132a b c  - 237a b c  + 99a b c - 12a b )d e
+--R                    + 
+--R                            3 2 3      2 4 2        6      8  4
+--R                      (- 60a b c  + 75a b c  - 27a b c + 3b )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                                6       5 2
+--R                         (- 108a c + 27a b )
+--R                      *
+--R                         ROOT
+--R                                     8 2     7 2     6 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                    7   2      6 3      5 5    5
+--R                                (36a b c  - 30a b c + 6a b )d e
+--R                              + 
+--R                                    7 3       6 2 2      5 4       4 6  2 4
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                         6   3       5 3 2       4 5       3 7
+--R                                  (- 128a b c  + 282a b c  - 140a b c + 20a b )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                         6 4       5 2 3       4 4 2       3 6
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         2 8
+--R                                    - 15a b
+--R                               *
+--R                                   4 2
+--R                                  d e
+--R                              + 
+--R                                       5   4       4 3 3       3 5 2      2 7
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                        9
+--R                                    6a b
+--R                               *
+--R                                   5
+--R                                  d e
+--R                              + 
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  d
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                          3   3        3      2 2    2      2          3  2
+--R                       - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                     + 
+--R                         2 2       2     4  3
+--R                       (a c  - 3a b c + b )d
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                              8   2       7 3       6 5
+--R                        (1296a b c  - 648a b c + 81a b )e
+--R                      + 
+--R                              8 3        7 2 2       6 4       5 6
+--R                        (2592a c  - 2592a b c  + 810a b c - 81a b )d
+--R                   *
+--R                      ROOT
+--R                                  8 2     7 2     6 4  6
+--R                             (- 4a c  + 4a b c - a b )e
+--R                           + 
+--R                                 7   2      6 3      5 5    5
+--R                             (36a b c  - 30a b c + 6a b )d e
+--R                           + 
+--R                                 7 3       6 2 2      5 4       4 6  2 4
+--R                             (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                           + 
+--R                                    6   3       5 3 2       4 5       3 7  3 3
+--R                             (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                           + 
+--R                                      6 4       5 2 3       4 4 2       3 6
+--R                                 - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                               + 
+--R                                      2 8
+--R                                 - 15a b
+--R                            *
+--R                                4 2
+--R                               d e
+--R                           + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                            *
+--R                                5
+--R                               d e
+--R                           + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                        /
+--R                                 13 3         12 2 2        11 4        10 6
+--R                           46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                  + 
+--R                        6 2      5 2      4 4  4
+--R                    (24a c  - 18a b c + 3a b )e
+--R                  + 
+--R                           5   2      4 3       3 5    3
+--R                    (- 132a b c  + 81a b c - 12a b )d e
+--R                  + 
+--R                          5 3       4 2 2       3 4       2 6  2 2
+--R                    (- 72a c  + 270a b c  - 135a b c + 18a b )d e
+--R                  + 
+--R                         4   3       3 3 2      2 5         7  3
+--R                    (132a b c  - 237a b c  + 99a b c - 12a b )d e
+--R                  + 
+--R                          3 2 3      2 4 2        6      8  4
+--R                    (- 60a b c  + 75a b c  - 27a b c + 3b )d
+--R               *
+--R                  ROOT
+--R                                  6       5 2
+--R                           (- 108a c + 27a b )
+--R                        *
+--R                           ROOT
+--R                                       8 2     7 2     6 4  6
+--R                                  (- 4a c  + 4a b c - a b )e
+--R                                + 
+--R                                      7   2      6 3      5 5    5
+--R                                  (36a b c  - 30a b c + 6a b )d e
+--R                                + 
+--R                                      7 3       6 2 2      5 4       4 6  2 4
+--R                                  (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                + 
+--R                                              6   3       5 3 2       4 5
+--R                                        - 128a b c  + 282a b c  - 140a b c
+--R                                      + 
+--R                                           3 7
+--R                                        20a b
+--R                                 *
+--R                                     3 3
+--R                                    d e
+--R                                + 
+--R                                           6 4       5 2 3       4 4 2
+--R                                      - 36a c  + 234a b c  - 300a b c
+--R                                    + 
+--R                                          3 6       2 8
+--R                                      120a b c - 15a b
+--R                                 *
+--R                                     4 2
+--R                                    d e
+--R                                + 
+--R                                         5   4       4 3 3       3 5 2      2 7
+--R                                      60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                    + 
+--R                                          9
+--R                                      6a b
+--R                                 *
+--R                                     5
+--R                                    d e
+--R                                + 
+--R                                           4 2 4      3 4 3      2 6 2        8
+--R                                      - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                    + 
+--R                                         10
+--R                                      - b
+--R                                 *
+--R                                     6
+--R                                    d
+--R                             /
+--R                                        13 3         12 2 2        11 4
+--R                                  46656a  c  - 34992a  b c  + 8748a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 729a  b
+--R                       + 
+--R                            3   3        3      2 2    2      2          3  2
+--R                         - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                       + 
+--R                           2 2       2     4  3
+--R                         (a c  - 3a b c + b )d
+--R                    /
+--R                           6       5 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                         5 2     4 2   5       4   2      3 3     4
+--R                    (- 8a c  + 4a b c)e  + (44a b c  - 16a b c)d e
+--R                  + 
+--R                        4 3      3 2 2      2 4   2 3
+--R                    (16a c  - 80a b c  + 24a b c)d e
+--R                  + 
+--R                         3   3      2 3 2        5   3 2
+--R                    (- 8a b c  + 56a b c  - 16a b c)d e
+--R                  + 
+--R                        3 4      2 2 3       4 2     6   4
+--R                    (24a c  - 28a b c  - 8a b c  + 4b c)d e
+--R                  + 
+--R                          2   4        3 3     5 2  5
+--R                    (- 20a b c  + 20a b c  - 4b c )d
+--R               *
+--R                  x
+--R     + 
+--R                               +--------------------+2
+--R                 +-----------+ |   +-----------+
+--R            3+-+ |          2 3|   |          2
+--R         18a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                       6       5 2
+--R                  (108a c - 27a b )
+--R               *
+--R                  ROOT
+--R                              8 2     7 2     6 4  6
+--R                         (- 4a c  + 4a b c - a b )e
+--R                       + 
+--R                             7   2      6 3      5 5    5
+--R                         (36a b c  - 30a b c + 6a b )d e
+--R                       + 
+--R                             7 3       6 2 2      5 4       4 6  2 4
+--R                         (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                       + 
+--R                                6   3       5 3 2       4 5       3 7  3 3
+--R                         (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                       + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                        *
+--R                            4 2
+--R                           d e
+--R                       + 
+--R                             5   4       4 3 3       3 5 2      2 7        9  5
+--R                         (60a b c  - 180a b c  + 162a b c  - 54a b c + 6a b )d e
+--R                       + 
+--R                               4 2 4      3 4 3      2 6 2        8     10  6
+--R                         (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                    /
+--R                             13 3         12 2 2        11 4        10 6
+--R                       46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R              + 
+--R                   3   3        3      2 2    2      2          3  2
+--R                - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R              + 
+--R                  2 2       2     4  3
+--R                (a c  - 3a b c + b )d
+--R           /
+--R                  6       5 2
+--R              216a c - 54a b
+--R        ,
+--R            3
+--R      *
+--R          +------------------+2
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         atan
+--R                            8   2       7 3       6 5
+--R                      (1296a b c  - 648a b c + 81a b )e
+--R                    + 
+--R                            8 3        7 2 2       6 4       5 6
+--R                      (2592a c  - 2592a b c  + 810a b c - 81a b )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R                 *
+--R                    ROOT
+--R                                8 2     7 2     6 4  6
+--R                           (- 4a c  + 4a b c - a b )e
+--R                         + 
+--R                               7   2      6 3      5 5    5
+--R                           (36a b c  - 30a b c + 6a b )d e
+--R                         + 
+--R                               7 3       6 2 2      5 4       4 6  2 4
+--R                           (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                         + 
+--R                                  6   3       5 3 2       4 5       3 7  3 3
+--R                           (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                         + 
+--R                                    6 4       5 2 3       4 4 2       3 6
+--R                               - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                             + 
+--R                                    2 8
+--R                               - 15a b
+--R                          *
+--R                              4 2
+--R                             d e
+--R                         + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                          *
+--R                              5
+--R                             d e
+--R                         + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                      /
+--R                               13 3         12 2 2        11 4        10 6
+--R                         46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                + 
+--R                            6 2      5 2      4 4  4
+--R                      (- 24a c  + 18a b c - 3a b )e
+--R                    + 
+--R                           5   2      4 3       3 5    3
+--R                      (132a b c  - 81a b c + 12a b )d e
+--R                    + 
+--R                          5 3       4 2 2       3 4       2 6  2 2
+--R                      (72a c  - 270a b c  + 135a b c - 18a b )d e
+--R                    + 
+--R                             4   3       3 3 2      2 5         7  3
+--R                      (- 132a b c  + 237a b c  - 99a b c + 12a b )d e
+--R                    + 
+--R                          3 2 3      2 4 2        6      8  4
+--R                      (60a b c  - 75a b c  + 27a b c - 3b )d
+--R                 *
+--R                     +-+
+--R                    \|3
+--R             *
+--R                ROOT
+--R                              6       5 2
+--R                         (108a c - 27a b )
+--R                      *
+--R                         ROOT
+--R                                     8 2     7 2     6 4  6
+--R                                (- 4a c  + 4a b c - a b )e
+--R                              + 
+--R                                    7   2      6 3      5 5    5
+--R                                (36a b c  - 30a b c + 6a b )d e
+--R                              + 
+--R                                    7 3       6 2 2      5 4       4 6  2 4
+--R                                (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                              + 
+--R                                         6   3       5 3 2       4 5       3 7
+--R                                  (- 128a b c  + 282a b c  - 140a b c + 20a b )
+--R                               *
+--R                                   3 3
+--R                                  d e
+--R                              + 
+--R                                         6 4       5 2 3       4 4 2       3 6
+--R                                    - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                                  + 
+--R                                         2 8
+--R                                    - 15a b
+--R                               *
+--R                                   4 2
+--R                                  d e
+--R                              + 
+--R                                       5   4       4 3 3       3 5 2      2 7
+--R                                    60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                  + 
+--R                                        9
+--R                                    6a b
+--R                               *
+--R                                   5
+--R                                  d e
+--R                              + 
+--R                                         4 2 4      3 4 3      2 6 2        8
+--R                                    - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                  + 
+--R                                       10
+--R                                    - b
+--R                               *
+--R                                   6
+--R                                  d
+--R                           /
+--R                                    13 3         12 2 2        11 4        10 6
+--R                              46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                     + 
+--R                          3   3        3      2 2    2      2          3  2
+--R                       - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                     + 
+--R                         2 2       2     4  3
+--R                       (a c  - 3a b c + b )d
+--R                  /
+--R                         6       5 2
+--R                     216a c - 54a b
+--R               ,
+--R                   3
+--R           /
+--R                              8   2       7 3       6 5
+--R                        (1296a b c  - 648a b c + 81a b )e
+--R                      + 
+--R                              8 3        7 2 2       6 4       5 6
+--R                        (2592a c  - 2592a b c  + 810a b c - 81a b )d
+--R                   *
+--R                      ROOT
+--R                                  8 2     7 2     6 4  6
+--R                             (- 4a c  + 4a b c - a b )e
+--R                           + 
+--R                                 7   2      6 3      5 5    5
+--R                             (36a b c  - 30a b c + 6a b )d e
+--R                           + 
+--R                                 7 3       6 2 2      5 4       4 6  2 4
+--R                             (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                           + 
+--R                                    6   3       5 3 2       4 5       3 7  3 3
+--R                             (- 128a b c  + 282a b c  - 140a b c + 20a b )d e
+--R                           + 
+--R                                      6 4       5 2 3       4 4 2       3 6
+--R                                 - 36a c  + 234a b c  - 300a b c  + 120a b c
+--R                               + 
+--R                                      2 8
+--R                                 - 15a b
+--R                            *
+--R                                4 2
+--R                               d e
+--R                           + 
+--R                                    5   4       4 3 3       3 5 2      2 7
+--R                                 60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                               + 
+--R                                     9
+--R                                 6a b
+--R                            *
+--R                                5
+--R                               d e
+--R                           + 
+--R                                 4 2 4      3 4 3      2 6 2        8     10  6
+--R                           (- 25a b c  + 50a b c  - 35a b c  + 10a b c - b  )d
+--R                        /
+--R                                 13 3         12 2 2        11 4        10 6
+--R                           46656a  c  - 34992a  b c  + 8748a  b c - 729a  b
+--R                  + 
+--R                          6 2      5 2      4 4  4
+--R                    (- 24a c  + 18a b c - 3a b )e
+--R                  + 
+--R                         5   2      4 3       3 5    3
+--R                    (132a b c  - 81a b c + 12a b )d e
+--R                  + 
+--R                        5 3       4 2 2       3 4       2 6  2 2
+--R                    (72a c  - 270a b c  + 135a b c - 18a b )d e
+--R                  + 
+--R                           4   3       3 3 2      2 5         7  3
+--R                    (- 132a b c  + 237a b c  - 99a b c + 12a b )d e
+--R                  + 
+--R                        3 2 3      2 4 2        6      8  4
+--R                    (60a b c  - 75a b c  + 27a b c - 3b )d
+--R               *
+--R                  ROOT
+--R                                6       5 2
+--R                           (108a c - 27a b )
+--R                        *
+--R                           ROOT
+--R                                       8 2     7 2     6 4  6
+--R                                  (- 4a c  + 4a b c - a b )e
+--R                                + 
+--R                                      7   2      6 3      5 5    5
+--R                                  (36a b c  - 30a b c + 6a b )d e
+--R                                + 
+--R                                      7 3       6 2 2      5 4       4 6  2 4
+--R                                  (24a c  - 141a b c  + 90a b c - 15a b )d e
+--R                                + 
+--R                                              6   3       5 3 2       4 5
+--R                                        - 128a b c  + 282a b c  - 140a b c
+--R                                      + 
+--R                                           3 7
+--R                                        20a b
+--R                                 *
+--R                                     3 3
+--R                                    d e
+--R                                + 
+--R                                           6 4       5 2 3       4 4 2
+--R                                      - 36a c  + 234a b c  - 300a b c
+--R                                    + 
+--R                                          3 6       2 8
+--R                                      120a b c - 15a b
+--R                                 *
+--R                                     4 2
+--R                                    d e
+--R                                + 
+--R                                         5   4       4 3 3       3 5 2      2 7
+--R                                      60a b c  - 180a b c  + 162a b c  - 54a b c
+--R                                    + 
+--R                                          9
+--R                                      6a b
+--R                                 *
+--R                                     5
+--R                                    d e
+--R                                + 
+--R                                           4 2 4      3 4 3      2 6 2        8
+--R                                      - 25a b c  + 50a b c  - 35a b c  + 10a b c
+--R                                    + 
+--R                                         10
+--R                                      - b
+--R                                 *
+--R                                     6
+--R                                    d
+--R                             /
+--R                                        13 3         12 2 2        11 4
+--R                                  46656a  c  - 34992a  b c  + 8748a  b c
+--R                                + 
+--R                                        10 6
+--R                                  - 729a  b
+--R                       + 
+--R                            3   3        3      2 2    2      2          3  2
+--R                         - a b e  + (- 3a c + 3a b )d e  + (6a b c - 3a b )d e
+--R                       + 
+--R                           2 2       2     4  3
+--R                         (a c  - 3a b c + b )d
+--R                    /
+--R                           6       5 2
+--R                       216a c - 54a b
+--R                 ,
+--R                     3
+--R              + 
+--R                       5 2     4 2   5         4   2      3 3     4
+--R                    (8a c  - 4a b c)e  + (- 44a b c  + 16a b c)d e
+--R                  + 
+--R                          4 3      3 2 2      2 4   2 3
+--R                    (- 16a c  + 80a b c  - 24a b c)d e
+--R                  + 
+--R                       3   3      2 3 2        5   3 2
+--R                    (8a b c  - 56a b c  + 16a b c)d e
+--R                  + 
+--R                          3 4      2 2 3       4 2     6   4
+--R                    (- 24a c  + 28a b c  + 8a b c  - 4b c)d e
+--R                  + 
+--R                        2   4        3 3     5 2  5
+--R                    (20a b c  - 20a b c  + 4b c )d
+--R               *
+--R                  x
+--R     + 
+--R                                                   +--------------------+2
+--R               +-----------+                       |   +-----------+
+--R               |          2                 3+-+2 3|   |          2
+--R         (- 6d\|- 4a c + b   - 12a e + 6b d)\|c   \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                                   +------------------+2
+--R               +-----------+                       | +-----------+
+--R               |          2                 3+-+2 3| |          2
+--R         (- 6d\|- 4a c + b   + 12a e - 6b d)\|c   \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                              +--------------------+2  +------------------+2
+--R                +-----------+ |   +-----------+        | +-----------+
+--R       3+-+ +-+ |          2 3|   |          2        3| |          2
+--R     6a\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 649
+--d0:=D(m0,x)
+--E 44
+
+)clear all
+
+--S 45 of 649
+t0:=(d+e*x^3)/(x^4*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                 3
+--R              e x  + d
+--R   (1)  -------------------
+--R           10      7      4
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 45
+
+--S 46 of 649
+r0:=-1/3*d/(a*x^3)-(b*d-a*e)*log(x)/a^2+1/6*(b*d-a*e)*log(a+b*x^3+c*x^6)/a^2-_
+   1/3*(b^2*d-2*a*c*d-a*b*e)*atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/(a^2*_
+   sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                              3
+--R                           2    3         2c x  + b
+--R       (2a b e + (4a c - 2b )d)x atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                        3       6      3                      3
+--R         ((- a e + b d)x log(c x  + b x  + a) + (6a e - 6b d)x log(x) - 2a d)
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       2 3 |          2
+--R     6a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             2    3
+--R           (a b e + (2a c - b )d)x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 6         3           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   3             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   6      3
+--R                c x  + b x  + a
+--R       + 
+--R                          3       6      3                      3
+--R           ((- a e + b d)x log(c x  + b x  + a) + (6a e - 6b d)x log(x) - 2a d)
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             +-----------+
+--R         2 3 |          2
+--R       6a x \|- 4a c + b
+--R     ,
+--R
+--R                                                        +---------+
+--R                                                 3      |        2
+--R                                 2    3     (2c x  + b)\|4a c - b
+--R         (- 2a b e + (- 4a c + 2b )d)x atan(-----------------------)
+--R                                                           2
+--R                                                   4a c - b
+--R       + 
+--R                          3       6      3                      3
+--R           ((- a e + b d)x log(c x  + b x  + a) + (6a e - 6b d)x log(x) - 2a d)
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R             +---------+
+--R         2 3 |        2
+--R       6a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 47
+
+--S 48 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           2
+--R         (a b e + (2a c - b )d)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 6         3           2  |          2           2     2   3
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 6      3
+--R              c x  + b x  + a
+--R     + 
+--R                                                3
+--R                               2            2c x  + b
+--R       (- 2a b e + (- 4a c + 2b )d)atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     6a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 48
+
+--S 49 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------+             3
+--R                             2    |        2          2c x  + b
+--R       (- a b e + (- 2a c + b )d)\|4a c - b  atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R     + 
+--R                                                                +---------+
+--R                                  +-----------+          3      |        2
+--R                             2    |          2      (2c x  + b)\|4a c - b
+--R       (- a b e + (- 2a c + b )d)\|- 4a c + b  atan(-----------------------)
+--R                                                                   2
+--R                                                           4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     3a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 649
+t0:=x^6*(1-x^3)/(1-x^3+x^6)
+--R 
+--R
+--R            9    6
+--R         - x  + x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 52
+
+--S 53 of 649
+r0:=-1/4*x^4+1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1+%i*_
+   sqrt(3))^(2/3))+1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*_
+   sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*x^2+2^(1/3)*_
+   x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3))+1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3+%i*sqrt(3))/_
+   (2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/3*atan((4*x+2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))*(%i+_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))
+--R 
+--R
+--R   (2)
+--R                       +------------+2
+--R              +-+     3|     +-+
+--R         (2%i\|3  - 6)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                        +------------+2     +----------+
+--R              +-+      3|     +-+          3|   +-+         3+-+
+--R       (- 4%i\|3  + 12)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                         +----------+2
+--R                +-+     3|   +-+
+--R         (- 2%i\|3  - 6)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                      +----------+2     +------------+
+--R            +-+      3|   +-+          3|     +-+         3+-+
+--R       (4%i\|3  + 12)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                  +------------+
+--R                         +----------+2     3+-+2 3|     +-+
+--R             +-+        3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (- 12\|3  - 12%i)\|%i\|3  + 1  atan(-------------------------)
+--R                                                      +------------+
+--R                                            3+-+2 +-+3|     +-+
+--R                                            \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                    +----------+
+--R                         +------------+2     3+-+2 3|   +-+
+--R             +-+        3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (- 12\|3  + 12%i)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                        +----------+
+--R                                              3+-+2 +-+3|   +-+
+--R                                              \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                  +------------+2  +----------+2
+--R           4 3+-+3|     +-+       3|   +-+
+--R       - 9x  \|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R  /
+--R            +------------+2  +----------+2
+--R       3+-+3|     +-+       3|   +-+
+--R     36\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 53
+
+--S 54 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          1                  1
+--R                   atan(----)         atan(----)
+--R                         +-+                +-+
+--R            +-+         \|3                \|3
+--R         (2\|3 sin(----------) - 2cos(----------))
+--R                        3                  3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                              1
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            3
+--R     + 
+--R                            1                  1
+--R                     atan(----)         atan(----)
+--R                           +-+                +-+
+--R              +-+         \|3                \|3
+--R         (- 2\|3 sin(----------) - 2cos(----------))
+--R                          3                  3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                                1
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              3
+--R     + 
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         4cos(----------)
+--R                   3
+--R      *
+--R                        1   2                 1                 1   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                      3                     3                 3
+--R     + 
+--R                        1                      1
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|3        +-+         \|3
+--R         (- 4sin(----------) + 4\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) + cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) - \|3 cos(----------) + 2x
+--R                       3                     3
+--R     + 
+--R                      1                      1
+--R               atan(----)             atan(----)
+--R                     +-+                    +-+
+--R                    \|3        +-+         \|3
+--R         (4sin(----------) + 4\|3 cos(----------))
+--R                    3                      3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) - cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) + \|3 cos(----------) + 2x
+--R                       3                     3
+--R     + 
+--R                                         1
+--R                                  atan(----)
+--R                   1                    +-+
+--R            atan(----)                 \|3
+--R                  +-+         cos(----------)
+--R                 \|3                   3             4 +-+
+--R       8sin(----------)atan(-------------------) - 3x \|3
+--R                 3                     1
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------) - x
+--R                                     3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 54
+
+--S 55 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +------------+2
+--R           +-+      3|     +-+
+--R         (\|3  - %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +------------+2     +----------+
+--R            +-+       3|     +-+          3|   +-+         3+-+
+--R       (- 2\|3  + 2%i)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                     +----------+2
+--R           +-+      3|   +-+
+--R         (\|3  + %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +----------+2     +------------+
+--R            +-+       3|   +-+          3|     +-+         3+-+
+--R       (- 2\|3  - 2%i)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                           +------------+2  +----------+2
+--R          3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (\|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                       18             18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  + x sin(---) + cos(---)  + x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                                             +------------+2  +----------+2
+--R            3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (- \|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                         18             18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  + x sin(---) + cos(---)  - x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                       +------------+2  +----------+2
+--R          3+-+    %pi 3|     +-+       3|   +-+
+--R         2\|2 cos(---)\|- %i\|3  + 1   \|%i\|3  + 1
+--R                   18
+--R      *
+--R                 %pi 2          %pi        %pi 2    2
+--R         log(sin(---)  - 2x sin(---) + cos(---)  + x )
+--R                  18             18         18
+--R     + 
+--R                                               +------------+2  +----------+2
+--R             3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (- 2\|2 sin(---) + 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18                  18
+--R      *
+--R                  +-+    %pi        %pi
+--R                 \|3 sin(---) + cos(---)
+--R                          18         18
+--R         atan(----------------------------)
+--R                  %pi     +-+    %pi
+--R              sin(---) - \|3 cos(---) + 2x
+--R                   18             18
+--R     + 
+--R                                             +------------+2  +----------+2
+--R           3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (2\|2 sin(---) + 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                    18                  18
+--R      *
+--R                  +-+    %pi        %pi
+--R                 \|3 sin(---) - cos(---)
+--R                          18         18
+--R         atan(----------------------------)
+--R                  %pi     +-+    %pi
+--R              sin(---) + \|3 cos(---) + 2x
+--R                   18             18
+--R     + 
+--R                                              +------------+
+--R                     +----------+2     3+-+2 3|     +-+
+--R            +-+     3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (2%i\|3  + 6)\|%i\|3  + 1  atan(-------------------------)
+--R                                                  +------------+
+--R                                        3+-+2 +-+3|     +-+
+--R                                        \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                  +----------+
+--R                       +------------+2     3+-+2 3|   +-+
+--R              +-+     3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (- 2%i\|3  + 6)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                      +----------+
+--R                                            3+-+2 +-+3|   +-+
+--R                                            \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                              %pi
+--R                     +------------+2  +----------+2       cos(---)
+--R        3+-+    %pi 3|     +-+       3|   +-+                  18
+--R       4\|2 sin(---)\|- %i\|3  + 1   \|%i\|3  + 1  atan(------------)
+--R                 18                                         %pi
+--R                                                        sin(---) - x
+--R                                                             18
+--R  /
+--R               +------------+2  +----------+2
+--R      3+-+ +-+3|     +-+       3|   +-+
+--R     6\|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 55
+
+--S 56 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                   5    %pi 6      5    %pi 2    %pi 4      8    %pi 3
+--R               - 6x sin(---)  - 18x cos(---) sin(---)  + 12x sin(---)
+--R                         18              18       18              18
+--R             + 
+--R                     5    %pi 4       11      8      5  +-+    %pi      %pi 2
+--R               (- 18x cos(---)  + (12x   - 12x  + 12x )\|3 cos(---))sin(---)
+--R                           18                                   18       18
+--R             + 
+--R                    8    %pi 2    %pi      5    %pi 6
+--R               - 36x cos(---) sin(---) - 6x cos(---)
+--R                          18       18            18
+--R             + 
+--R                    11     8     5  +-+    %pi 3     11
+--R               (- 4x   + 4x  - 4x )\|3 cos(---)  - 6x
+--R                                            18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   6 3+-+    %pi 6     6 3+-+    %pi 2    %pi 4
+--R               - 6x  \|2 sin(---) - 18x  \|2 cos(---) sin(---)
+--R                              18                  18       18
+--R             + 
+--R                  9 3+-+    %pi 3
+--R               12x  \|2 sin(---)
+--R                             18
+--R             + 
+--R                       6 3+-+    %pi 4      12      9      6 3+-+ +-+    %pi
+--R                 (- 18x  \|2 cos(---) + (12x   - 12x  + 12x )\|2 \|3 cos(---))
+--R                                  18                                      18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    9 3+-+    %pi 2    %pi     6 3+-+    %pi 6
+--R               - 36x  \|2 cos(---) sin(--- - 6x  \|2 cos(---)
+--R                               18       18                18
+--R             + 
+--R                    12     9     6 3+-+ +-+    %pi 3     12 3+-+
+--R               (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  - 6x   \|2
+--R                                                18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 - 3x  \|2 )sin(---)
+--R                                            18
+--R         + 
+--R                 4 3+-+2 +-+    4 3+-+2    %pi 2    %pi 4
+--R           (9%i x  \|2  \|3 - 9x  \|2 )cos(---) sin(---)
+--R                                            18       18
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 3
+--R           (- 6%i x  \|2  \|3 + 6x  \|2 )sin(---)
+--R                                              18
+--R         + 
+--R                     4 3+-+2 +-+    4 3+-+2    %pi 4
+--R               (9%i x  \|2  \|3 - 9x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                      10     7     4 3+-+2 +-+
+--R                   (6x   - 6x  + 6x )\|2  \|3
+--R                 + 
+--R                            10         7         4 3+-+2
+--R                   (- 18%i x   + 18%i x  - 18%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  7 3+-+2 +-+     7 3+-+2    %pi 2    %pi
+--R           (18%i x  \|2  \|3 - 18x  \|2 )cos(---) sin(---)
+--R                                              18       18
+--R         + 
+--R                 4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 - 3x  \|2 )cos(---)
+--R                                            18
+--R         + 
+--R                   10     7     4 3+-+2 +-+         10        7        4 3+-+2
+--R             ((- 2x   + 2x  - 2x )\|2  \|3  + (6%i x   - 6%i x  + 6%i x )\|2  )
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                10 3+-+2 +-+    10 3+-+2
+--R           3%i x   \|2  \|3 - 3x   \|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                   6 3+-+    %pi 6     6 3+-+    %pi 2    %pi 4
+--R               - 6x  \|2 sin(---) - 18x  \|2 cos(---) sin(---)
+--R                              18                  18       18
+--R             + 
+--R                  9 3+-+    %pi 3
+--R               12x  \|2 sin(---)
+--R                             18
+--R             + 
+--R                       6 3+-+    %pi 4      12      9      6 3+-+ +-+    %pi
+--R                 (- 18x  \|2 cos(---) + (12x   - 12x  + 12x )\|2 \|3 cos(---))
+--R                                  18                                      18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    9 3+-+    %pi 2    %pi     6 3+-+    %pi 6
+--R               - 36x  \|2 cos(---) sin(--- - 6x  \|2 cos(---)
+--R                               18       18                18
+--R             + 
+--R                    12     9     6 3+-+ +-+    %pi 3     12 3+-+
+--R               (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  - 6x   \|2
+--R                                                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   7 3+-+2    %pi 6     7 3+-+2    %pi 2    %pi 4
+--R               - 6x  \|2  sin(---) - 18x  \|2  cos(---) sin(---)
+--R                               18                   18       18
+--R             + 
+--R                  10 3+-+2    %pi 3
+--R               12x   \|2  sin(---)
+--R                               18
+--R             + 
+--R                          7 3+-+2    %pi 4
+--R                     - 18x  \|2  cos(---)
+--R                                      18
+--R                   + 
+--R                         13      10      7 3+-+2 +-+    %pi
+--R                     (12x   - 12x   + 12x )\|2  \|3 cos(---)
+--R                                                         18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    10 3+-+2    %pi 2    %pi     7 3+-+2    %pi 6
+--R               - 36x   \|2  cos(---) sin(--- - 6x  \|2  cos(---)
+--R                                 18       18                 18
+--R             + 
+--R                    13     10     7 3+-+2 +-+    %pi 3     13 3+-+2
+--R               (- 4x   + 4x   - 4x )\|2  \|3 cos(---)  - 6x   \|2
+--R                                                  18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 5 +-+     5     %pi 6          5 +-+      5     %pi 2    %pi 4
+--R           (6%i x \|3  - 6x )sin(---)  + (18%i x \|3  - 18x )cos(---) sin(---)
+--R                                  18                              18       18
+--R         + 
+--R                    8 +-+      8     %pi 3
+--R           (- 12%i x \|3  + 12x )sin(---)
+--R                                      18
+--R         + 
+--R                      5 +-+      5     %pi 4
+--R               (18%i x \|3  - 18x )cos(---)
+--R                                        18
+--R             + 
+--R                  11      8      5  +-+         11         8         5     %pi
+--R             ((12x   - 12x  + 12x )\|3  - 36%i x   + 36%i x  - 36%i x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  8 +-+      8     %pi 2    %pi          5 +-+     5     %pi 6
+--R           (36%i x \|3  - 36x )cos(---) sin(---) + (6%i x \|3  - 6x )cos(---)
+--R                                    18       18                           18
+--R         + 
+--R                 11     8     5  +-+         11         8         5     %pi 3
+--R           ((- 4x   + 4x  - 4x )\|3  + 12%i x   - 12%i x  + 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                11 +-+     11
+--R           6%i x  \|3  - 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                   4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 - 3x  \|2 )sin(---)
+--R                                              18
+--R         + 
+--R                   4 3+-+2 +-+    4 3+-+2    %pi 2    %pi 4
+--R           (- 9%i x  \|2  \|3 - 9x  \|2 )cos(---) sin(---)
+--R                                              18       18
+--R         + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 3
+--R           (6%i x  \|2  \|3 + 6x  \|2 )sin(---)
+--R                                            18
+--R         + 
+--R                       4 3+-+2 +-+    4 3+-+2    %pi 4
+--R               (- 9%i x  \|2  \|3 - 9x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                      10     7     4 3+-+2 +-+
+--R                   (6x   - 6x  + 6x )\|2  \|3
+--R                 + 
+--R                          10         7         4 3+-+2
+--R                   (18%i x   - 18%i x  + 18%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7 3+-+2 +-+     7 3+-+2    %pi 2    %pi
+--R           (- 18%i x  \|2  \|3 - 18x  \|2 )cos(---) sin(---)
+--R                                                18       18
+--R         + 
+--R                   4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 - 3x  \|2 )cos(---)
+--R                                              18
+--R         + 
+--R                      10     7     4 3+-+2 +-+
+--R                 (- 2x   + 2x  - 2x )\|2  \|3
+--R               + 
+--R                         10        7        4 3+-+2
+--R                 (- 6%i x   + 6%i x  - 6%i x )\|2
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                  10 3+-+2 +-+    10 3+-+2
+--R           - 3%i x   \|2  \|3 - 3x   \|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                   5 +-+     5     %pi 6
+--R           (- 6%i x \|3  - 6x )sin(---)
+--R                                    18
+--R         + 
+--R                    5 +-+      5     %pi 2    %pi 4
+--R           (- 18%i x \|3  - 18x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                  8 +-+      8     %pi 3
+--R           (12%i x \|3  + 12x )sin(---)
+--R                                    18
+--R         + 
+--R                        5 +-+      5     %pi 4
+--R               (- 18%i x \|3  - 18x )cos(---)
+--R                                          18
+--R             + 
+--R                  11      8      5  +-+         11         8         5     %pi
+--R             ((12x   - 12x  + 12x )\|3  + 36%i x   - 36%i x  + 36%i x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8 +-+      8     %pi 2    %pi
+--R           (- 36%i x \|3  - 36x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                   5 +-+     5     %pi 6
+--R           (- 6%i x \|3  - 6x )cos(---)
+--R                                    18
+--R         + 
+--R                 11     8     5  +-+         11         8         5     %pi 3
+--R           ((- 4x   + 4x  - 4x )\|3  - 12%i x   + 12%i x  - 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                  11 +-+     11
+--R           - 6%i x  \|3  - 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R            3 3+-+    %pi 6     3 3+-+    %pi 2    %pi 4     6 3+-+    %pi 3
+--R       - 12x  \|2 sin(---) - 36x  \|2 cos(---) sin(---) + 24x  \|2 sin(---)
+--R                       18                  18       18                  18
+--R     + 
+--R             3 3+-+    %pi 4      9      6      3 3+-+ +-+    %pi      %pi 2
+--R       (- 36x  \|2 cos(---) + (24x  - 24x  + 24x )\|2 \|3 cos(---))sin(---)
+--R                        18                                     18       18
+--R     + 
+--R            6 3+-+    %pi 2    %pi      3 3+-+    %pi 6
+--R       - 72x  \|2 cos(---) sin(--- - 12x  \|2 cos(---)
+--R                       18       18                 18
+--R     + 
+--R            9     6     3 3+-+ +-+    %pi 3      9 3+-+
+--R       (- 8x  + 8x  - 8x )\|2 \|3 cos(---)  - 12x  \|2
+--R                                       18
+--R  /
+--R                  8     5     2     %pi 6
+--R               (6x  - 6x  + 6x )sin(---)
+--R                                     18
+--R             + 
+--R                   8      5      2     %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                     11      8      5     %pi 3
+--R               (- 12x   + 12x  - 12x )sin(---)
+--R                                           18
+--R             + 
+--R                   8      5      2     %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                   11      8      5     %pi 2    %pi
+--R               (36x   - 36x  + 36x )cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                  8     5     2     %pi 6     14     11     8
+--R               (6x  - 6x  + 6x )cos(---)  + 6x   - 6x   + 6x
+--R                                     18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 3
+--R               (- 12x   + 12x  - 12x )\|2 sin(---)
+--R                                               18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                    10        7        4 3+-+2 +-+        10     7     4 3+-+2
+--R             ((6%i x   - 6%i x  + 6%i x )\|2  \|3  + (- 6x   + 6x  - 6x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                        10         7         4 3+-+2 +-+
+--R               (- 18%i x   + 18%i x  - 18%i x )\|2  \|3
+--R             + 
+--R                   10      7      4 3+-+2
+--R               (18x   - 18x  + 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 3
+--R               (- 12x   + 12x  - 12x )\|2 sin(---)
+--R                                               18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  10     7     4 3+-+2    %pi 6
+--R               (6x   - 6x  + 6x )\|2  sin(---)
+--R                                           18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 2    %pi 4
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                     13      10      7 3+-+2    %pi 3
+--R               (- 12x   + 12x   - 12x )\|2  sin(---)
+--R                                                 18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 4    %pi 2
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                   13      10      7 3+-+2    %pi 2    %pi
+--R               (36x   - 36x   + 36x )\|2  cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                  10     7     4 3+-+2    %pi 6      16     13     10 3+-+2
+--R               (6x   - 6x  + 6x )\|2  cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                           18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 2
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   11         8         5  +-+      11      8      5     %pi 3
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  - 12x   + 12x  - 12x )sin(---)
+--R                                                                          18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 4
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       11         8         5  +-+      11      8      5
+--R             ((- 36%i x   + 36%i x  - 36%i x )\|3  + 36x   - 36x  + 36x )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   14        11        8  +-+     14     11     8
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )sin(---)
+--R                                                                            18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                         10        7        4 3+-+2 +-+
+--R                 (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R               + 
+--R                      10     7     4 3+-+2
+--R                 (- 6x   + 6x  - 6x )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      10         7         4 3+-+2 +-+
+--R               (18%i x   - 18%i x  + 18%i x )\|2  \|3
+--R             + 
+--R                   10      7      4 3+-+2
+--R               (18x   - 18x  + 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )cos(---)
+--R                                                                            18
+--R         + 
+--R                 13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 2
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 3
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  - 12x   + 12x  - 12x )sin(---)
+--R                                                                            18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 4
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 2
+--R             ((36%i x   - 36%i x  + 36%i x )\|3  + 36x   - 36x  + 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                 14        11        8  +-+     14     11     8
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           6      3      3+-+    %pi 6
+--R       (12x  - 12x  + 12)\|2 sin(---)
+--R                                  18
+--R     + 
+--R           6      3      3+-+    %pi 2    %pi 4
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R             9      6      3 3+-+    %pi 3
+--R       (- 24x  + 24x  - 24x )\|2 sin(---)
+--R                                      18
+--R     + 
+--R           6      3      3+-+    %pi 4    %pi 2
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R           9      6      3 3+-+    %pi 2    %pi
+--R       (72x  - 72x  + 72x )\|2 cos(---) sin(---)
+--R                                    18       18
+--R     + 
+--R           6      3      3+-+    %pi 6       12      9      6 3+-+
+--R       (12x  - 12x  + 12)\|2 cos(---)  + (12x   - 12x  + 12x )\|2
+--R                                  18
+--R                                           Type: Expression(Complex(Integer))
+--E 56
+
+)clear all
+
+--S 57 of 649
+t0:=x^5*(1-x^3)/(1-x^3+x^6)
+--R 
+--R
+--R            8    5
+--R         - x  + x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 57
+
+--S 58 of 649
+r0:=-1/3*x^3-2/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                 3      +-+
+--R              (2x  - 1)\|3      3 +-+
+--R        2atan(-------------) - x \|3
+--R                    3
+--R   (2)  -----------------------------
+--R                      +-+
+--R                    3\|3
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 3      +-+
+--R              (2x  - 1)\|3      3 +-+
+--R        2atan(-------------) - x \|3
+--R                    3
+--R   (3)  -----------------------------
+--R                      +-+
+--R                    3\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 59
+
+--S 60 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+--S 61 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 61
+
+)clear all
+
+--S 62 of 649
+t0:=x^4*(1-x^3)/(1-x^3+x^6)
+--R 
+--R
+--R            7    4
+--R         - x  + x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 62
+
+--S 63 of 649
+r0:=-1/2*x^2+1/3*%i*2^(1/3)*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/_
+   (2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))/(1-%i*sqrt(3))^(1/3)-_
+   1/3*%i*2^(1/3)*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3)*sqrt(3)))/(1+%i*sqrt(3))^(1/3)+1/3*%i*2^(1/3)*_
+   log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))/((1-%i*sqrt(3))^(1/3)*sqrt(3))-_
+   1/3*%i*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*_
+   sqrt(3))^(2/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3))-1/3*%i*2^(1/3)*_
+   log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))/((1+%i*sqrt(3))^(1/3)*sqrt(3))+_
+   1/3*%i*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*_
+   sqrt(3))^(2/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +------------+     +----------+2         +----------+
+--R       1   3|     +-+         3|   +-+          3+-+3|   +-+         2 3+-+2
+--R       - %i\|- %i\|3  + 1 log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R       3
+--R     + 
+--R              +------------+     +----------+
+--R         2   3|     +-+         3|   +-+         3+-+
+--R       - - %i\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R         3
+--R     + 
+--R              +----------+     +------------+2         +------------+
+--R         1   3|   +-+         3|     +-+          3+-+3|     +-+         2 3+-+2
+--R       - - %i\|%i\|3  + 1 log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R         3
+--R     + 
+--R            +----------+     +------------+
+--R       2   3|   +-+         3|     +-+         3+-+
+--R       - %i\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R       3
+--R     + 
+--R                                        +------------+
+--R                +----------+     3+-+2 3|     +-+
+--R       2    +-+3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       - %i\|3 \|%i\|3  + 1 atan(-------------------------)
+--R       3                                    +------------+
+--R                                  3+-+2 +-+3|     +-+
+--R                                  \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                            +----------+
+--R                  +------------+     3+-+2 3|   +-+
+--R         2    +-+3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       - - %i\|3 \|- %i\|3  + 1 atan(-----------------------)
+--R         3                                      +----------+
+--R                                      3+-+2 +-+3|   +-+
+--R                                      \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                        +------------+ +----------+
+--R         1  2 3+-+2 +-+3|     +-+     3|   +-+
+--R       - - x  \|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R         2
+--R  /
+--R               +------------+ +----------+
+--R     3+-+2 +-+3|     +-+     3|   +-+
+--R     \|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 63
+
+--S 64 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         1                 1
+--R                  atan(----)        atan(----)
+--R                        +-+               +-+
+--R           +-+         \|3               \|3
+--R         (\|3 sin(----------) - cos(----------))
+--R                       3                 3
+--R      *
+--R         log
+--R                         1   4                1   2                 1   2
+--R                  atan(----)           atan(----)            atan(----)
+--R                        +-+                  +-+                   +-+
+--R                       \|3                  \|3                   \|3
+--R              sin(----------)  + (2cos(----------)  + 2x)sin(----------)
+--R                       3                    3                     3
+--R            + 
+--R                         1   4                 1   2
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3                   \|3        2
+--R              cos(----------)  - 2x cos(----------)  + x
+--R                       3                     3
+--R     + 
+--R                           1                 1
+--R                    atan(----)        atan(----)
+--R                          +-+               +-+
+--R             +-+         \|3               \|3
+--R         (- \|3 sin(----------) - cos(----------))
+--R                         3                 3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                               1              1                 1   4
+--R                        atan(----)     atan(----)        atan(----)
+--R                              +-+            +-+               +-+
+--R                 +-+         \|3            \|3               \|3
+--R              2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                             3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                                 1              1                 1   4
+--R                          atan(----)     atan(----)        atan(----)
+--R                                +-+            +-+               +-+
+--R                   +-+         \|3            \|3               \|3
+--R              - 2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                               3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                        1                      1
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|3        +-+         \|3
+--R         (- 2sin(----------) + 2\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R         atan
+--R                            1   2                   1              1
+--R                     atan(----)              atan(----)     atan(----)
+--R                           +-+                     +-+            +-+
+--R                          \|3         +-+         \|3            \|3
+--R                3sin(----------)  + 2\|3 cos(----------)sin(----------)
+--R                          3                       3              3
+--R              + 
+--R                              1   2
+--R                       atan(----)
+--R                             +-+
+--R                            \|3
+--R                - 3cos(----------)
+--R                            3
+--R           /
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  - 6cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3          +-+
+--R                - \|3 cos(----------)  - 2x\|3
+--R                               3
+--R     + 
+--R       -
+--R                        1
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            4sin(----------)
+--R                      3
+--R         *
+--R            atan
+--R                               1   2                   1              1
+--R                        atan(----)              atan(----)     atan(----)
+--R                              +-+                     +-+            +-+
+--R                             \|3         +-+         \|3            \|3
+--R                   3sin(----------)  - 2\|3 cos(----------)sin(----------)
+--R                             3                       3              3
+--R                 + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                   - 3cos(----------)
+--R                               3
+--R              /
+--R                                  1   2               1              1
+--R                           atan(----)          atan(----)     atan(----)
+--R                                 +-+                 +-+            +-+
+--R                    +-+         \|3                 \|3            \|3
+--R                   \|3 sin(----------)  + 6cos(----------)sin(----------)
+--R                                3                   3              3
+--R                 + 
+--R                                    1   2
+--R                             atan(----)
+--R                                   +-+
+--R                      +-+         \|3          +-+
+--R                   - \|3 cos(----------)  - 2x\|3
+--R                                  3
+--R     + 
+--R                        1                      1
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|3        +-+         \|3
+--R         (- 2sin(----------) - 2\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R                              1              1
+--R                       atan(----)     atan(----)
+--R                             +-+            +-+
+--R                            \|3            \|3
+--R                  2cos(----------)sin(----------)
+--R                            3              3
+--R         atan(---------------------------------------)
+--R                         1   2              1   2
+--R                  atan(----)         atan(----)
+--R                        +-+                +-+
+--R                       \|3                \|3
+--R              sin(----------)  - cos(----------)  + x
+--R                       3                  3
+--R     + 
+--R           2 +-+
+--R       - 3x \|3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 64
+
+--S 65 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +------------+     +----------+2         +----------+
+--R         1   3|     +-+         3|   +-+          3+-+3|   +-+         2 3+-+2
+--R       - - %i\|- %i\|3  + 1 log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R         3
+--R     + 
+--R            +------------+     +----------+
+--R       2   3|     +-+         3|   +-+         3+-+
+--R       - %i\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R       3
+--R     + 
+--R            +----------+     +------------+2         +------------+
+--R       1   3|   +-+         3|     +-+          3+-+3|     +-+         2 3+-+2
+--R       - %i\|%i\|3  + 1 log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R       3
+--R     + 
+--R              +----------+     +------------+
+--R         2   3|   +-+         3|     +-+         3+-+
+--R       - - %i\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R         3
+--R     + 
+--R                                                       +------------+
+--R          1 3+-+2 +-+     1        1 3+-+2     1      3|     +-+
+--R         (- \|2  \|3 sin(-- %pi) - - \|2  cos(-- %pi))\|- %i\|3  + 1
+--R          6              18        6          18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R      *
+--R         log
+--R                   1     4          1     2           1     2        1     4
+--R              sin(-- %pi)  + (2cos(-- %pi)  + 2x)sin(-- %pi)  + cos(-- %pi)
+--R                  18               18                18             18
+--R            + 
+--R                        1     2    2
+--R              - 2x cos(-- %pi)  + x
+--R                       18
+--R     + 
+--R                                                         +------------+
+--R            1 3+-+2 +-+     1        1 3+-+2     1      3|     +-+
+--R         (- - \|2  \|3 sin(-- %pi) - - \|2  cos(-- %pi))\|- %i\|3  + 1
+--R            6              18        6          18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R      *
+--R         log
+--R                   1     4          1     2          1     2
+--R              sin(-- %pi)  + (2cos(-- %pi)  - x)sin(-- %pi)
+--R                  18               18               18
+--R            + 
+--R                 +-+     1          1             1     4          1     2    2
+--R              2x\|3 cos(-- %pi)sin(-- %pi) + cos(-- %pi)  + x cos(-- %pi)  + x
+--R                        18         18            18               18
+--R     + 
+--R                            +------------+ +----------+
+--R         1 3+-+2     1     3|     +-+     3|   +-+
+--R         - \|2  cos(-- %pi)\|- %i\|3  + 1 \|%i\|3  + 1
+--R         3          18
+--R      *
+--R         log
+--R                   1     4          1     2          1     2
+--R              sin(-- %pi)  + (2cos(-- %pi)  - x)sin(-- %pi)
+--R                  18               18               18
+--R            + 
+--R                 +-+     1          1             1     4          1     2    2
+--R            - 2x\|3 cos(-- %pi)sin(-- %pi) + cos(-- %pi)  + x cos(-- %pi)  + x
+--R                        18         18            18               18
+--R     + 
+--R                                                         +------------+
+--R            1 3+-+2     1        1 3+-+2 +-+     1      3|     +-+
+--R         (- - \|2  sin(-- %pi) + - \|2  \|3 cos(-- %pi))\|- %i\|3  + 1
+--R            3          18        3              18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R      *
+--R         atan
+--R                    1     2     +-+     1          1              1     2
+--R              3sin(-- %pi)  + 2\|3 cos(-- %pi)sin(-- %pi) - 3cos(-- %pi)
+--R                   18                  18         18             18
+--R           /
+--R                 +-+     1     2         1          1         +-+     1     2
+--R                \|3 sin(-- %pi)  - 6cos(-- %pi)sin(-- %pi) - \|3 cos(-- %pi)
+--R                        18              18         18                18
+--R              + 
+--R                     +-+
+--R                - 2x\|3
+--R     + 
+--R       -
+--R                               +------------+ +----------+
+--R            2 3+-+2     1     3|     +-+     3|   +-+
+--R            - \|2  sin(-- %pi)\|- %i\|3  + 1 \|%i\|3  + 1
+--R            3          18
+--R         *
+--R            atan
+--R                       1     2     +-+     1          1              1     2
+--R                 3sin(-- %pi)  - 2\|3 cos(-- %pi)sin(-- %pi) - 3cos(-- %pi)
+--R                      18                  18         18             18
+--R              /
+--R                    +-+     1     2         1          1         +-+     1     2
+--R                   \|3 sin(-- %pi)  + 6cos(-- %pi)sin(-- %pi) - \|3 cos(-- %pi)
+--R                           18              18         18                18
+--R                 + 
+--R                        +-+
+--R                   - 2x\|3
+--R     + 
+--R                                          +------------+
+--R                  +----------+     3+-+2 3|     +-+
+--R         2    +-+3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       - - %i\|3 \|%i\|3  + 1 atan(-------------------------)
+--R         3                                    +------------+
+--R                                    3+-+2 +-+3|     +-+
+--R                                    \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                          +----------+
+--R                +------------+     3+-+2 3|   +-+
+--R       2    +-+3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       - %i\|3 \|- %i\|3  + 1 atan(-----------------------)
+--R       3                                      +----------+
+--R                                    3+-+2 +-+3|   +-+
+--R                                    \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                         +------------+
+--R            1 3+-+2     1        1 3+-+2 +-+     1      3|     +-+
+--R         (- - \|2  sin(-- %pi) - - \|2  \|3 cos(-- %pi))\|- %i\|3  + 1
+--R            3          18        3              18
+--R      *
+--R                                     1          1
+--R          +----------+         2cos(-- %pi)sin(-- %pi)
+--R         3|   +-+                   18         18
+--R         \|%i\|3  + 1 atan(-------------------------------)
+--R                                1     2        1     2
+--R                           sin(-- %pi)  - cos(-- %pi)  + x
+--R                               18             18
+--R  /
+--R               +------------+ +----------+
+--R     3+-+2 +-+3|     +-+     3|   +-+
+--R     \|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 65
+
+--S 66 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  5 3+-+     1     12    5 3+-+     1     2     1     10
+--R               - x  \|2 sin(-- %pi)  - 6x  \|2 cos(-- %pi) sin(-- %pi)
+--R                            18                     18          18
+--R             + 
+--R                   11    8    5 3+-+     1     9
+--R               (- x   + x  - x )\|2 sin(-- %pi)
+--R                                        18
+--R             + 
+--R                       5 3+-+     1     4      11    8    5 3+-+ +-+     1
+--R                 (- 15x  \|2 cos(-- %pi) + (- x   + x  - x )\|2 \|3 cos(-- %pi))
+--R                                 18                                     18
+--R              *
+--R                      1     8
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                        5 3+-+     1     6
+--R                   - 20x  \|2 cos(-- %pi)
+--R                                  18
+--R                 + 
+--R                      8  11   8  8   8  5 3+-+ +-+     1     3     8 3+-+
+--R                   (- - x   + - x  - - x )\|2 \|3 cos(-- %pi)  - 2x  \|2
+--R                      3       3      3                18
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                  11     8     5 3+-+     1     4     1     5
+--R               (6x   - 6x  + 6x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                         18          18
+--R             + 
+--R                        5 3+-+     1     8
+--R                   - 15x  \|2 cos(-- %pi)
+--R                                  18
+--R                 + 
+--R                      11     8     5 3+-+ +-+     1     5      8 3+-+     1     2
+--R                 (- 2x   + 2x  - 2x )\|2 \|3 cos(-- %pi)  + 30x  \|2 cos(-- %pi)
+--R                                                 18                      18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                     11     8     5 3+-+     1     6       14    11    8 3+-+
+--R                 ((8x   - 8x  + 8x )\|2 cos(-- %pi)  + (- x   + x   - x )\|2 )
+--R                                            18
+--R              *
+--R                      1     3
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                       5 3+-+     1     10     8 3+-+     1     4
+--R                   - 6x  \|2 cos(-- %pi)  - 30x  \|2 cos(-- %pi)
+--R                                 18                      18
+--R                 + 
+--R                     14    11    8 3+-+ +-+     1
+--R                   (x   - x   + x )\|2 \|3 cos(-- %pi)
+--R                                               18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                      11     8     5 3+-+     1     8
+--R                   (3x   - 3x  + 3x )\|2 cos(-- %pi)
+--R                                             18
+--R                 + 
+--R                      14     11     8 3+-+     1     2
+--R                   (3x   - 3x   + 3x )\|2 cos(-- %pi)
+--R                                              18
+--R              *
+--R                      1
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                  5 3+-+     1     12   1  11   1  8   1  5 3+-+ +-+     1     9
+--R               - x  \|2 cos(-- %pi)  + (- x   - - x  + - x )\|2 \|3 cos(-- %pi)
+--R                            18          3       3      3                18
+--R             + 
+--R                 8 3+-+     1     6
+--R               2x  \|2 cos(-- %pi)
+--R                           18
+--R             + 
+--R                  1  14   1  11   1  8 3+-+ +-+     1     3    11 3+-+
+--R               (- - x   + - x   - - x )\|2 \|3 cos(-- %pi)  - x   \|2
+--R                  3       3       3                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                1     3 3+-+2 +-+  1  3 3+-+2     1     12
+--R               (- %i x  \|2  \|3 - - x  \|2 )sin(-- %pi)
+--R                2                  2             18
+--R             + 
+--R                     3 3+-+2 +-+    3 3+-+2     1     2     1     10
+--R               (3%i x  \|2  \|3 - 3x  \|2 )cos(-- %pi) sin(-- %pi)
+--R                                               18          18
+--R             + 
+--R                    1     9   1     6   1     3 3+-+2 +-+
+--R                   (- %i x  - - %i x  + - %i x )\|2  \|3
+--R                    2         2         2
+--R                 + 
+--R                      1  9   1  6   1  3 3+-+2
+--R                   (- - x  + - x  - - x )\|2
+--R                      2      2      2
+--R              *
+--R                      1     9
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                    15     3 3+-+2 +-+  15  3 3+-+2     1     4
+--R                   (-- %i x  \|2  \|3 - -- x  \|2 )cos(-- %pi)
+--R                     2                   2             18
+--R                 + 
+--R                          1  9   1  6   1  3 3+-+2 +-+
+--R                       (- - x  + - x  - - x )\|2  \|3
+--R                          2      2      2
+--R                     + 
+--R                        3     9   3     6   3     3 3+-+2
+--R                       (- %i x  - - %i x  + - %i x )\|2
+--R                        2         2         2
+--R                  *
+--R                          1
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     8
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                          3 3+-+2 +-+     3 3+-+2     1     6
+--R                   (10%i x  \|2  \|3 - 10x  \|2 )cos(-- %pi)
+--R                                                     18
+--R                 + 
+--R                          4  9   4  6   4  3 3+-+2 +-+
+--R                       (- - x  + - x  - - x )\|2  \|3
+--R                          3      3      3
+--R                     + 
+--R                             9        6        3 3+-+2
+--R                       (4%i x  - 4%i x  + 4%i x )\|2
+--R                  *
+--R                          1     3
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                       6 3+-+2 +-+   6 3+-+2
+--R                   %i x  \|2  \|3 - x  \|2
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                             9        6        3 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        9     6     3 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                      1     4     1     5
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                    15     3 3+-+2 +-+  15  3 3+-+2     1     8
+--R                   (-- %i x  \|2  \|3 - -- x  \|2 )cos(-- %pi)
+--R                     2                   2             18
+--R                 + 
+--R                             9    6    3 3+-+2 +-+
+--R                         (- x  + x  - x )\|2  \|3
+--R                       + 
+--R                               9        6        3 3+-+2
+--R                         (3%i x  - 3%i x  + 3%i x )\|2
+--R                  *
+--R                          1     5
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                            6 3+-+2 +-+     6 3+-+2     1     2
+--R                   (- 15%i x  \|2  \|3 + 15x  \|2 )cos(-- %pi)
+--R                                                       18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                               9        6        3 3+-+2 +-+
+--R                       (- 4%i x  + 4%i x  - 4%i x )\|2  \|3
+--R                     + 
+--R                          9     6     3 3+-+2
+--R                       (4x  - 4x  + 4x )\|2
+--R                  *
+--R                          1     6
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                    1     12   1     9   1     6 3+-+2 +-+
+--R                   (- %i x   - - %i x  + - %i x )\|2  \|3
+--R                    2          2         2
+--R                 + 
+--R                      1  12   1  9   1  6 3+-+2
+--R                   (- - x   + - x  - - x )\|2
+--R                      2       2      2
+--R              *
+--R                      1     3
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                         3 3+-+2 +-+    3 3+-+2     1     10
+--R                   (3%i x  \|2  \|3 - 3x  \|2 )cos(-- %pi)
+--R                                                   18
+--R                 + 
+--R                          6 3+-+2 +-+     6 3+-+2     1     4
+--R                   (15%i x  \|2  \|3 - 15x  \|2 )cos(-- %pi)
+--R                                                     18
+--R                 + 
+--R                        1  12   1  9   1  6 3+-+2 +-+
+--R                       (- x   - - x  + - x )\|2  \|3
+--R                        2       2      2
+--R                     + 
+--R                          3     12   3     9   3     6 3+-+2
+--R                       (- - %i x   + - %i x  - - %i x )\|2
+--R                          2          2         2
+--R                  *
+--R                          1
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                          3     9   3     6   3     3 3+-+2 +-+
+--R                       (- - %i x  + - %i x  - - %i x )\|2  \|3
+--R                          2         2         2
+--R                     + 
+--R                        3  9   3  6   3  3 3+-+2
+--R                       (- x  - - x  + - x )\|2
+--R                        2      2      2
+--R                  *
+--R                          1     8
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                          3     12   3     9   3     6 3+-+2 +-+
+--R                       (- - %i x   + - %i x  - - %i x )\|2  \|3
+--R                          2          2         2
+--R                     + 
+--R                        3  12   3  9   3  6 3+-+2
+--R                       (- x   - - x  + - x )\|2
+--R                        2       2      2
+--R                  *
+--R                          1     2
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                1     3 3+-+2 +-+  1  3 3+-+2     1     12
+--R               (- %i x  \|2  \|3 - - x  \|2 )cos(-- %pi)
+--R                2                  2             18
+--R             + 
+--R                    1  9   1  6   1  3 3+-+2 +-+
+--R                   (- x  - - x  + - x )\|2  \|3
+--R                    6      6      6
+--R                 + 
+--R                      1     9   1     6   1     3 3+-+2
+--R                   (- - %i x  + - %i x  - - %i x )\|2
+--R                      2         2         2
+--R              *
+--R                      1     9
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                      6 3+-+2 +-+   6 3+-+2     1     6
+--R               (- %i x  \|2  \|3 + x  \|2 )cos(-- %pi)
+--R                                               18
+--R             + 
+--R                      1  12   1  9   1  6 3+-+2 +-+
+--R                   (- - x   + - x  - - x )\|2  \|3
+--R                      6       6      6
+--R                 + 
+--R                    1     12   1     9   1     6 3+-+2
+--R                   (- %i x   - - %i x  + - %i x )\|2
+--R                    2          2         2
+--R              *
+--R                      1     3
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R               1     9 3+-+2 +-+  1  9 3+-+2
+--R               - %i x  \|2  \|3 - - x  \|2
+--R               2                  2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                4 +-+    4      1     12
+--R           (%i x \|3  - x )sin(-- %pi)
+--R                               18
+--R         + 
+--R                 4 +-+     4      1     2     1     10
+--R           (6%i x \|3  - 6x )cos(-- %pi) sin(-- %pi)
+--R                                 18          18
+--R         + 
+--R                 10       7       4  +-+    10    7    4      1     9
+--R           ((%i x   - %i x  + %i x )\|3  - x   + x  - x )sin(-- %pi)
+--R                                                             18
+--R         + 
+--R                      4 +-+      4      1     4
+--R               (15%i x \|3  - 15x )cos(-- %pi)
+--R                                       18
+--R             + 
+--R                    10    7    4  +-+        10        7        4      1
+--R               ((- x   + x  - x )\|3  + 3%i x   - 3%i x  + 3%i x )cos(-- %pi)
+--R                                                                      18
+--R          *
+--R                  1     8
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      4 +-+      4      1     6
+--R               (20%i x \|3  - 20x )cos(-- %pi)
+--R                                       18
+--R             + 
+--R                     8  10   8  7   8  4  +-+        10        7        4
+--R                 ((- - x   + - x  - - x )\|3  + 8%i x   - 8%i x  + 8%i x )
+--R                     3       3      3
+--R              *
+--R                      1     3
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                    7 +-+     7
+--R               2%i x \|3  - 2x
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      10        7        4  +-+     10     7     4      1     4
+--R             ((- 6%i x   + 6%i x  - 6%i x )\|3  + 6x   - 6x  + 6x )cos(-- %pi)
+--R                                                                       18
+--R          *
+--R                  1     5
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      4 +-+      4      1     8
+--R               (15%i x \|3  - 15x )cos(-- %pi)
+--R                                       18
+--R             + 
+--R                       10     7     4  +-+        10        7        4
+--R                 ((- 2x   + 2x  - 2x )\|3  + 6%i x   - 6%i x  + 6%i x )
+--R              *
+--R                      1     5
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                        7 +-+      7      1     2
+--R               (- 30%i x \|3  + 30x )cos(-- %pi)
+--R                                         18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                          10        7        4  +-+     10     7     4
+--R                 ((- 8%i x   + 8%i x  - 8%i x )\|3  + 8x   - 8x  + 8x )
+--R              *
+--R                      1     6
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                    13       10       7  +-+    13    10    7
+--R               (%i x   - %i x   + %i x )\|3  - x   + x   - x
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                     4 +-+     4      1     10
+--R               (6%i x \|3  - 6x )cos(-- %pi)
+--R                                     18
+--R             + 
+--R                      7 +-+      7      1     4
+--R               (30%i x \|3  - 30x )cos(-- %pi)
+--R                                       18
+--R             + 
+--R                  13    10    7  +-+        13        10        7      1
+--R               ((x   - x   + x )\|3  - 3%i x   + 3%i x   - 3%i x )cos(-- %pi)
+--R                                                                      18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                          10        7        4  +-+     10     7     4
+--R                 ((- 3%i x   + 3%i x  - 3%i x )\|3  + 3x   - 3x  + 3x )
+--R              *
+--R                      1     8
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                          13        10        7  +-+     13     10     7
+--R                 ((- 3%i x   + 3%i x   - 3%i x )\|3  + 3x   - 3x   + 3x )
+--R              *
+--R                      1     2
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                4 +-+    4      1     12
+--R           (%i x \|3  - x )cos(-- %pi)
+--R                               18
+--R         + 
+--R             1  10   1  7   1  4  +-+       10       7       4      1     9
+--R           ((- x   - - x  + - x )\|3  - %i x   + %i x  - %i x )cos(-- %pi)
+--R             3       3      3                                      18
+--R         + 
+--R                   7 +-+     7      1     6
+--R           (- 2%i x \|3  + 2x )cos(-- %pi)
+--R                                   18
+--R         + 
+--R               1  13   1  10   1  7  +-+       13       10       7      1     3
+--R           ((- - x   + - x   - - x )\|3  + %i x   - %i x   + %i x )cos(-- %pi)
+--R               3       3       3                                       18
+--R         + 
+--R               10 +-+    10
+--R           %i x  \|3  - x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  1     3 3+-+2 +-+  1  3 3+-+2     1     12
+--R               (- - %i x  \|2  \|3 - - x  \|2 )sin(-- %pi)
+--R                  2                  2             18
+--R             + 
+--R                       3 3+-+2 +-+    3 3+-+2     1     2     1     10
+--R               (- 3%i x  \|2  \|3 - 3x  \|2 )cos(-- %pi) sin(-- %pi)
+--R                                                 18          18
+--R             + 
+--R                      1     9   1     6   1     3 3+-+2 +-+
+--R                   (- - %i x  + - %i x  - - %i x )\|2  \|3
+--R                      2         2         2
+--R                 + 
+--R                      1  9   1  6   1  3 3+-+2
+--R                   (- - x  + - x  - - x )\|2
+--R                      2      2      2
+--R              *
+--R                      1     9
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                      15     3 3+-+2 +-+  15  3 3+-+2     1     4
+--R                   (- -- %i x  \|2  \|3 - -- x  \|2 )cos(-- %pi)
+--R                       2                   2             18
+--R                 + 
+--R                          1  9   1  6   1  3 3+-+2 +-+
+--R                       (- - x  + - x  - - x )\|2  \|3
+--R                          2      2      2
+--R                     + 
+--R                          3     9   3     6   3     3 3+-+2
+--R                       (- - %i x  + - %i x  - - %i x )\|2
+--R                          2         2         2
+--R                  *
+--R                          1
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     8
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                            3 3+-+2 +-+     3 3+-+2     1     6
+--R                   (- 10%i x  \|2  \|3 - 10x  \|2 )cos(-- %pi)
+--R                                                       18
+--R                 + 
+--R                          4  9   4  6   4  3 3+-+2 +-+
+--R                       (- - x  + - x  - - x )\|2  \|3
+--R                          3      3      3
+--R                     + 
+--R                               9        6        3 3+-+2
+--R                       (- 4%i x  + 4%i x  - 4%i x )\|2
+--R                  *
+--R                          1     3
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                         6 3+-+2 +-+   6 3+-+2
+--R                   - %i x  \|2  \|3 - x  \|2
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                        9        6        3 3+-+2 +-+      9     6     3 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                      1     4     1     5
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                      15     3 3+-+2 +-+  15  3 3+-+2     1     8
+--R                   (- -- %i x  \|2  \|3 - -- x  \|2 )cos(-- %pi)
+--R                       2                   2             18
+--R                 + 
+--R                           9    6    3 3+-+2 +-+
+--R                       (- x  + x  - x )\|2  \|3
+--R                     + 
+--R                               9        6        3 3+-+2
+--R                       (- 3%i x  + 3%i x  - 3%i x )\|2
+--R                  *
+--R                          1     5
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                          6 3+-+2 +-+     6 3+-+2     1     2
+--R                   (15%i x  \|2  \|3 + 15x  \|2 )cos(-- %pi)
+--R                                                     18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                             9        6        3 3+-+2 +-+
+--R                       (4%i x  - 4%i x  + 4%i x )\|2  \|3
+--R                     + 
+--R                          9     6     3 3+-+2
+--R                       (4x  - 4x  + 4x )\|2
+--R                  *
+--R                          1     6
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                      1     12   1     9   1     6 3+-+2 +-+
+--R                   (- - %i x   + - %i x  - - %i x )\|2  \|3
+--R                      2          2         2
+--R                 + 
+--R                      1  12   1  9   1  6 3+-+2
+--R                   (- - x   + - x  - - x )\|2
+--R                      2       2      2
+--R              *
+--R                      1     3
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                           3 3+-+2 +-+    3 3+-+2     1     10
+--R                   (- 3%i x  \|2  \|3 - 3x  \|2 )cos(-- %pi)
+--R                                                     18
+--R                 + 
+--R                            6 3+-+2 +-+     6 3+-+2     1     4
+--R                   (- 15%i x  \|2  \|3 - 15x  \|2 )cos(-- %pi)
+--R                                                       18
+--R                 + 
+--R                        1  12   1  9   1  6 3+-+2 +-+
+--R                       (- x   - - x  + - x )\|2  \|3
+--R                        2       2      2
+--R                     + 
+--R                        3     12   3     9   3     6 3+-+2
+--R                       (- %i x   - - %i x  + - %i x )\|2
+--R                        2          2         2
+--R                  *
+--R                          1
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                        3     9   3     6   3     3 3+-+2 +-+
+--R                       (- %i x  - - %i x  + - %i x )\|2  \|3
+--R                        2         2         2
+--R                     + 
+--R                        3  9   3  6   3  3 3+-+2
+--R                       (- x  - - x  + - x )\|2
+--R                        2      2      2
+--R                  *
+--R                          1     8
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                        3     12   3     9   3     6 3+-+2 +-+
+--R                       (- %i x   - - %i x  + - %i x )\|2  \|3
+--R                        2          2         2
+--R                     + 
+--R                        3  12   3  9   3  6 3+-+2
+--R                       (- x   - - x  + - x )\|2
+--R                        2       2      2
+--R                  *
+--R                          1     2
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                  1     3 3+-+2 +-+  1  3 3+-+2     1     12
+--R               (- - %i x  \|2  \|3 - - x  \|2 )cos(-- %pi)
+--R                  2                  2             18
+--R             + 
+--R                    1  9   1  6   1  3 3+-+2 +-+
+--R                   (- x  - - x  + - x )\|2  \|3
+--R                    6      6      6
+--R                 + 
+--R                    1     9   1     6   1     3 3+-+2
+--R                   (- %i x  - - %i x  + - %i x )\|2
+--R                    2         2         2
+--R              *
+--R                      1     9
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                    6 3+-+2 +-+   6 3+-+2     1     6
+--R               (%i x  \|2  \|3 + x  \|2 )cos(-- %pi)
+--R                                             18
+--R             + 
+--R                      1  12   1  9   1  6 3+-+2 +-+
+--R                   (- - x   + - x  - - x )\|2  \|3
+--R                      6       6      6
+--R                 + 
+--R                      1     12   1     9   1     6 3+-+2
+--R                   (- - %i x   + - %i x  - - %i x )\|2
+--R                      2          2         2
+--R              *
+--R                      1     3
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                 1     9 3+-+2 +-+  1  9 3+-+2
+--R               - - %i x  \|2  \|3 - - x  \|2
+--R                 2                  2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                         1     12            1     2     1     10
+--R               - 2x sin(-- %pi)   - 12x cos(-- %pi) sin(-- %pi)
+--R                        18                  18          18
+--R             + 
+--R                    7     4           1     9
+--R               (- 2x  + 2x  - 2x)sin(-- %pi)
+--R                                     18
+--R             + 
+--R                             1     4        7     4       +-+     1
+--R                 (- 30x cos(-- %pi)  + (- 2x  + 2x  - 2x)\|3 cos(-- %pi))
+--R                            18                                   18
+--R              *
+--R                      1     8
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                              1     6      16  7   16  4   16    +-+     1     3
+--R                   - 40x cos(-- %pi)  + (- -- x  + -- x  - -- x)\|3 cos(-- %pi)
+--R                             18             3       3       3           18
+--R                 + 
+--R                       4
+--R                   - 4x
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                   7      4            1     4     1     5
+--R               (12x  - 12x  + 12x)cos(-- %pi) sin(-- %pi)
+--R                                      18          18
+--R             + 
+--R                              1     8        7     4       +-+     1     5
+--R                   - 30x cos(-- %pi)  + (- 4x  + 4x  - 4x)\|3 cos(-- %pi)
+--R                             18                                   18
+--R                 + 
+--R                      4     1     2
+--R                   60x cos(-- %pi)
+--R                           18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                    7      4            1     6     10     7     4      1     3
+--R               ((16x  - 16x  + 16x)cos(-- %pi)  - 2x   + 2x  - 2x )sin(-- %pi)
+--R                                       18                              18
+--R             + 
+--R                              1     10      4     1     4
+--R                   - 12x cos(-- %pi)   - 60x cos(-- %pi)
+--R                             18                  18
+--R                 + 
+--R                      10     7     4  +-+     1
+--R                   (2x   - 2x  + 2x )\|3 cos(-- %pi)
+--R                                             18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                     7     4           1     8      10     7     4      1     2
+--R                 ((6x  - 6x  + 6x)cos(-- %pi)  + (6x   - 6x  + 6x )cos(-- %pi) )
+--R                                      18                               18
+--R              *
+--R                      1
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                         1     12    2  7   2  4   2    +-+     1     9
+--R               - 2x cos(-- %pi)   + (- x  - - x  + - x)\|3 cos(-- %pi)
+--R                        18           3      3      3           18
+--R             + 
+--R                 4     1     6      2  10   2  7   2  4  +-+     1     3     7
+--R               4x cos(-- %pi)  + (- - x   + - x  - - x )\|3 cos(-- %pi)  - 2x
+--R                      18            3       3      3            18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R               2 3+-+     1     12     2 3+-+     1     2     1     10
+--R           - 2x  \|2 sin(-- %pi)  - 12x  \|2 cos(-- %pi) sin(-- %pi)
+--R                         18                      18          18
+--R         + 
+--R                8     5     2 3+-+     1     9
+--R           (- 2x  + 2x  - 2x )\|2 sin(-- %pi)
+--R                                      18
+--R         + 
+--R                   2 3+-+     1     4       8     5     2 3+-+ +-+     1
+--R             (- 30x  \|2 cos(-- %pi) + (- 2x  + 2x  - 2x )\|2 \|3 cos(-- %pi))
+--R                             18                                       18
+--R          *
+--R                  1     8
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    2 3+-+     1     6
+--R               - 40x  \|2 cos(-- %pi)
+--R                              18
+--R             + 
+--R                  16  8   16  5   16  2 3+-+ +-+     1     3     5 3+-+
+--R               (- -- x  + -- x  - -- x )\|2 \|3 cos(-- %pi)  - 4x  \|2
+--R                   3       3       3                18
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R               8      5      2 3+-+     1     4     1     5
+--R           (12x  - 12x  + 12x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                       18          18
+--R         + 
+--R                    2 3+-+     1     8       8     5     2 3+-+ +-+     1     5
+--R               - 30x  \|2 cos(-- %pi) + (- 4x  + 4x  - 4x )\|2 \|3 cos(-- %pi)
+--R                              18                                       18
+--R             + 
+--R                  5 3+-+     1     2
+--R               60x  \|2 cos(-- %pi)
+--R                            18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  8      5      2 3+-+     1     6        11     8     5 3+-+
+--R             ((16x  - 16x  + 16x )\|2 cos(-- %pi)  + (- 2x   + 2x  - 2x )\|2 )
+--R                                          18
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    2 3+-+     1     10     5 3+-+     1     4
+--R               - 12x  \|2 cos(-- %pi)  - 60x  \|2 cos(-- %pi)
+--R                              18                      18
+--R             + 
+--R                  11     8     5 3+-+ +-+     1
+--R               (2x   - 2x  + 2x )\|2 \|3 cos(-- %pi)
+--R                                             18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  8     5     2 3+-+     1     8
+--R               (6x  - 6x  + 6x )\|2 cos(-- %pi)
+--R                                        18
+--R             + 
+--R                  11     8     5 3+-+     1     2
+--R               (6x   - 6x  + 6x )\|2 cos(-- %pi)
+--R                                         18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R               2 3+-+     1     12   2  8   2  5   2  2 3+-+ +-+     1     9
+--R           - 2x  \|2 cos(-- %pi)  + (- x  - - x  + - x )\|2 \|3 cos(-- %pi)
+--R                         18          3      3      3                18
+--R         + 
+--R             5 3+-+     1     6     2  11   2  8   2  5 3+-+ +-+     1     3
+--R           4x  \|2 cos(-- %pi) + (- - x   + - x  - - x )\|2 \|3 cos(-- %pi)
+--R                       18           3       3      3                18
+--R         + 
+--R               8 3+-+
+--R           - 2x  \|2
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  4 +-+    4      1     12
+--R           (- %i x \|3  - x )sin(-- %pi)
+--R                                 18
+--R         + 
+--R                   4 +-+     4      1     2     1     10
+--R           (- 6%i x \|3  - 6x )cos(-- %pi) sin(-- %pi)
+--R                                   18          18
+--R         + 
+--R                   10       7       4  +-+    10    7    4      1     9
+--R           ((- %i x   + %i x  - %i x )\|3  - x   + x  - x )sin(-- %pi)
+--R                                                               18
+--R         + 
+--R                        4 +-+      4      1     4
+--R               (- 15%i x \|3  - 15x )cos(-- %pi)
+--R                                         18
+--R             + 
+--R                    10    7    4  +-+        10        7        4      1
+--R               ((- x   + x  - x )\|3  - 3%i x   + 3%i x  - 3%i x )cos(-- %pi)
+--R                                                                      18
+--R          *
+--R                  1     8
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                        4 +-+      4      1     6
+--R               (- 20%i x \|3  - 20x )cos(-- %pi)
+--R                                         18
+--R             + 
+--R                     8  10   8  7   8  4  +-+        10        7        4
+--R                 ((- - x   + - x  - - x )\|3  - 8%i x   + 8%i x  - 8%i x )
+--R                     3       3      3
+--R              *
+--R                      1     3
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                      7 +-+     7
+--R               - 2%i x \|3  - 2x
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    10        7        4  +-+     10     7     4      1     4
+--R             ((6%i x   - 6%i x  + 6%i x )\|3  + 6x   - 6x  + 6x )cos(-- %pi)
+--R                                                                     18
+--R          *
+--R                  1     5
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                        4 +-+      4      1     8
+--R               (- 15%i x \|3  - 15x )cos(-- %pi)
+--R                                         18
+--R             + 
+--R                       10     7     4  +-+        10        7        4
+--R                 ((- 2x   + 2x  - 2x )\|3  - 6%i x   + 6%i x  - 6%i x )
+--R              *
+--R                      1     5
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                      7 +-+      7      1     2
+--R               (30%i x \|3  + 30x )cos(-- %pi)
+--R                                       18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      10        7        4  +-+     10     7     4      1     6
+--R               ((8%i x   - 8%i x  + 8%i x )\|3  + 8x   - 8x  + 8x )cos(-- %pi)
+--R                                                                       18
+--R             + 
+--R                      13       10       7  +-+    13    10    7
+--R               (- %i x   + %i x   - %i x )\|3  - x   + x   - x
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                       4 +-+     4      1     10
+--R               (- 6%i x \|3  - 6x )cos(-- %pi)
+--R                                       18
+--R             + 
+--R                        7 +-+      7      1     4
+--R               (- 30%i x \|3  - 30x )cos(-- %pi)
+--R                                         18
+--R             + 
+--R                  13    10    7  +-+        13        10        7      1
+--R               ((x   - x   + x )\|3  + 3%i x   - 3%i x   + 3%i x )cos(-- %pi)
+--R                                                                      18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      10        7        4  +-+     10     7     4      1     8
+--R               ((3%i x   - 3%i x  + 3%i x )\|3  + 3x   - 3x  + 3x )cos(-- %pi)
+--R                                                                       18
+--R             + 
+--R                    13        10        7  +-+     13     10     7      1     2
+--R             ((3%i x   - 3%i x   + 3%i x )\|3  + 3x   - 3x   + 3x )cos(-- %pi)
+--R                                                                       18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  4 +-+    4      1     12
+--R           (- %i x \|3  - x )cos(-- %pi)
+--R                                 18
+--R         + 
+--R             1  10   1  7   1  4  +-+       10       7       4      1     9
+--R           ((- x   - - x  + - x )\|3  + %i x   - %i x  + %i x )cos(-- %pi)
+--R             3       3      3                                      18
+--R         + 
+--R                 7 +-+     7      1     6
+--R           (2%i x \|3  + 2x )cos(-- %pi)
+--R                                 18
+--R         + 
+--R               1  13   1  10   1  7  +-+       13       10       7      1     3
+--R           ((- - x   + - x   - - x )\|3  - %i x   + %i x   - %i x )cos(-- %pi)
+--R               3       3       3                                       18
+--R         + 
+--R                 10 +-+    10
+--R           - %i x  \|3  - x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R               2 3+-+     1     12     2 3+-+     1     2     1     10
+--R           - 2x  \|2 sin(-- %pi)  - 12x  \|2 cos(-- %pi) sin(-- %pi)
+--R                         18                      18          18
+--R         + 
+--R                8     5     2 3+-+     1     9
+--R           (- 2x  + 2x  - 2x )\|2 sin(-- %pi)
+--R                                      18
+--R         + 
+--R                   2 3+-+     1     4       8     5     2 3+-+ +-+     1
+--R             (- 30x  \|2 cos(-- %pi) + (- 2x  + 2x  - 2x )\|2 \|3 cos(-- %pi))
+--R                             18                                       18
+--R          *
+--R                  1     8
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    2 3+-+     1     6
+--R               - 40x  \|2 cos(-- %pi)
+--R                              18
+--R             + 
+--R                  16  8   16  5   16  2 3+-+ +-+     1     3     5 3+-+
+--R               (- -- x  + -- x  - -- x )\|2 \|3 cos(-- %pi)  - 4x  \|2
+--R                   3       3       3                18
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R               8      5      2 3+-+     1     4     1     5
+--R           (12x  - 12x  + 12x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                       18          18
+--R         + 
+--R                    2 3+-+     1     8       8     5     2 3+-+ +-+     1     5
+--R               - 30x  \|2 cos(-- %pi) + (- 4x  + 4x  - 4x )\|2 \|3 cos(-- %pi)
+--R                              18                                       18
+--R             + 
+--R                  5 3+-+     1     2
+--R               60x  \|2 cos(-- %pi)
+--R                            18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  8      5      2 3+-+     1     6        11     8     5 3+-+
+--R             ((16x  - 16x  + 16x )\|2 cos(-- %pi)  + (- 2x   + 2x  - 2x )\|2 )
+--R                                          18
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    2 3+-+     1     10     5 3+-+     1     4
+--R               - 12x  \|2 cos(-- %pi)  - 60x  \|2 cos(-- %pi)
+--R                              18                      18
+--R             + 
+--R                  11     8     5 3+-+ +-+     1
+--R               (2x   - 2x  + 2x )\|2 \|3 cos(-- %pi)
+--R                                             18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  8     5     2 3+-+     1     8
+--R               (6x  - 6x  + 6x )\|2 cos(-- %pi)
+--R                                        18
+--R             + 
+--R                  11     8     5 3+-+     1     2
+--R               (6x   - 6x  + 6x )\|2 cos(-- %pi)
+--R                                         18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R               2 3+-+     1     12   2  8   2  5   2  2 3+-+ +-+     1     9
+--R           - 2x  \|2 cos(-- %pi)  + (- x  - - x  + - x )\|2 \|3 cos(-- %pi)
+--R                         18          3      3      3                18
+--R         + 
+--R             5 3+-+     1     6     2  11   2  8   2  5 3+-+ +-+     1     3
+--R           4x  \|2 cos(-- %pi) + (- - x   + - x  - - x )\|2 \|3 cos(-- %pi)
+--R                       18           3       3      3                18
+--R         + 
+--R               8 3+-+
+--R           - 2x  \|2
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           3 3+-+2     1     12     3 3+-+2     1     2     1     10
+--R       - 2x  \|2  sin(-- %pi)  - 12x  \|2  cos(-- %pi) sin(-- %pi)
+--R                      18                       18          18
+--R     + 
+--R            9     6     3 3+-+2     1     9
+--R       (- 2x  + 2x  - 2x )\|2  sin(-- %pi)
+--R                                   18
+--R     + 
+--R               3 3+-+2     1     4       9     6     3 3+-+2 +-+     1
+--R         (- 30x  \|2  cos(-- %pi) + (- 2x  + 2x  - 2x )\|2  \|3 cos(-- %pi))
+--R                          18                                        18
+--R      *
+--R              1     8
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R                3 3+-+2     1     6
+--R           - 40x  \|2  cos(-- %pi)
+--R                           18
+--R         + 
+--R              16  9   16  6   16  3 3+-+2 +-+     1     3     6 3+-+2
+--R           (- -- x  + -- x  - -- x )\|2  \|3 cos(-- %pi)  - 4x  \|2
+--R               3       3       3                 18
+--R      *
+--R              1     6
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R           9      6      3 3+-+2     1     4     1     5
+--R       (12x  - 12x  + 12x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                    18          18
+--R     + 
+--R                3 3+-+2     1     8       9     6     3 3+-+2 +-+     1     5
+--R           - 30x  \|2  cos(-- %pi) + (- 4x  + 4x  - 4x )\|2  \|3 cos(-- %pi)
+--R                           18                                        18
+--R         + 
+--R              6 3+-+2     1     2
+--R           60x  \|2  cos(-- %pi)
+--R                         18
+--R      *
+--R              1     4
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R              9      6      3 3+-+2     1     6        12     9     6 3+-+2
+--R         ((16x  - 16x  + 16x )\|2  cos(-- %pi)  + (- 2x   + 2x  - 2x )\|2  )
+--R                                       18
+--R      *
+--R              1     3
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R                3 3+-+2     1     10     6 3+-+2     1     4
+--R           - 12x  \|2  cos(-- %pi)  - 60x  \|2  cos(-- %pi)
+--R                           18                       18
+--R         + 
+--R              12     9     6 3+-+2 +-+     1
+--R           (2x   - 2x  + 2x )\|2  \|3 cos(-- %pi)
+--R                                          18
+--R      *
+--R              1     2
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R              9     6     3 3+-+2     1     8
+--R           (6x  - 6x  + 6x )\|2  cos(-- %pi)
+--R                                     18
+--R         + 
+--R              12     9     6 3+-+2     1     2
+--R           (6x   - 6x  + 6x )\|2  cos(-- %pi)
+--R                                      18
+--R      *
+--R              1
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R           3 3+-+2     1     12   2  9   2  6   2  3 3+-+2 +-+     1     9
+--R       - 2x  \|2  cos(-- %pi)  + (- x  - - x  + - x )\|2  \|3 cos(-- %pi)
+--R                      18          3      3      3                 18
+--R     + 
+--R         6 3+-+2     1     6     2  12   2  9   2  6 3+-+2 +-+     1     3
+--R       4x  \|2  cos(-- %pi) + (- - x   + - x  - - x )\|2  \|3 cos(-- %pi)
+--R                    18           3       3      3                 18
+--R     + 
+--R           9 3+-+2
+--R       - 2x  \|2
+--R  /
+--R                 10    7    4 3+-+     1     12
+--R               (x   - x  + x )\|2 sin(-- %pi)
+--R                                      18
+--R             + 
+--R                  10     7     4 3+-+     1     2     1     10
+--R               (6x   - 6x  + 6x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                         18          18
+--R             + 
+--R                   10      7      4 3+-+     1     4     1     8
+--R               (15x   - 15x  + 15x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                            18          18
+--R             + 
+--R                         10      7      4 3+-+     1     6
+--R                     (20x   - 20x  + 20x )\|2 cos(-- %pi)
+--R                                                  18
+--R                   + 
+--R                        13     10     7 3+-+
+--R                     (2x   - 2x   + 2x )\|2
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                       10      7      4 3+-+     1     8
+--R                   (15x   - 15x  + 15x )\|2 cos(-- %pi)
+--R                                                18
+--R                 + 
+--R                         13      10      7 3+-+     1     2
+--R                   (- 30x   + 30x   - 30x )\|2 cos(-- %pi)
+--R                                                   18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                      10     7     4 3+-+     1     10
+--R                   (6x   - 6x  + 6x )\|2 cos(-- %pi)
+--R                                             18
+--R                 + 
+--R                       13      10      7 3+-+     1     4
+--R                   (30x   - 30x   + 30x )\|2 cos(-- %pi)
+--R                                                 18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                 10    7    4 3+-+     1     12
+--R               (x   - x  + x )\|2 cos(-- %pi)
+--R                                      18
+--R             + 
+--R                    13     10     7 3+-+     1     6     16    13    10 3+-+
+--R               (- 2x   + 2x   - 2x )\|2 cos(-- %pi)  + (x   - x   + x  )\|2
+--R                                            18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                      1     8   1     5   1     2 3+-+2 +-+
+--R                   (- - %i x  + - %i x  - - %i x )\|2  \|3
+--R                      2         2         2
+--R                 + 
+--R                    1  8   1  5   1  2 3+-+2
+--R                   (- x  - - x  + - x )\|2
+--R                    2      2      2
+--R              *
+--R                      1     12
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                      1     2     1     10
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                      15     8   15     5   15     2 3+-+2 +-+
+--R                   (- -- %i x  + -- %i x  - -- %i x )\|2  \|3
+--R                       2          2          2
+--R                 + 
+--R                    15  8   15  5   15  2 3+-+2
+--R                   (-- x  - -- x  + -- x )\|2
+--R                     2       2       2
+--R              *
+--R                      1     4     1     8
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 10%i x  + 10%i x  - 10%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (10x  - 10x  + 10x )\|2
+--R                  *
+--R                          1     6
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                          11       8       5 3+-+2 +-+     11    8    5 3+-+2
+--R                   (- %i x   + %i x  - %i x )\|2  \|3  + (x   - x  + x )\|2
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                          15     8   15     5   15     2 3+-+2 +-+
+--R                       (- -- %i x  + -- %i x  - -- %i x )\|2  \|3
+--R                           2          2          2
+--R                     + 
+--R                        15  8   15  5   15  2 3+-+2
+--R                       (-- x  - -- x  + -- x )\|2
+--R                         2       2       2
+--R                  *
+--R                          1     8
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (15%i x   - 15%i x  + 15%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 15x   + 15x  - 15x )\|2
+--R                  *
+--R                          1     2
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                               8        5        2 3+-+2 +-+
+--R                       (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                     + 
+--R                          8     5     2 3+-+2
+--R                       (3x  - 3x  + 3x )\|2
+--R                  *
+--R                          1     10
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 15%i x   + 15%i x  - 15%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (15x   - 15x  + 15x )\|2
+--R                  *
+--R                          1     4
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                      1     8   1     5   1     2 3+-+2 +-+
+--R                   (- - %i x  + - %i x  - - %i x )\|2  \|3
+--R                      2         2         2
+--R                 + 
+--R                    1  8   1  5   1  2 3+-+2
+--R                   (- x  - - x  + - x )\|2
+--R                    2      2      2
+--R              *
+--R                      1     12
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                       11       8       5 3+-+2 +-+       11    8    5 3+-+2
+--R                 ((%i x   - %i x  + %i x )\|2  \|3  + (- x   + x  - x )\|2  )
+--R              *
+--R                      1     6
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                  1     14   1     11   1     8 3+-+2 +-+
+--R               (- - %i x   + - %i x   - - %i x )\|2  \|3
+--R                  2          2          2
+--R             + 
+--R                1  14   1  11   1  8 3+-+2
+--R               (- x   - - x   + - x )\|2
+--R                2       2       2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   9       6       3  +-+    9    6    3      1     12
+--R           ((- %i x  + %i x  - %i x )\|3  + x  - x  + x )sin(-- %pi)
+--R                                                             18
+--R         + 
+--R                      9        6        3  +-+     9     6     3      1     2
+--R             ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(-- %pi)
+--R                                                                     18
+--R          *
+--R                  1     10
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                       9         6         3  +-+      9      6      3
+--R             ((- 15%i x  + 15%i x  - 15%i x )\|3  + 15x  - 15x  + 15x )
+--R          *
+--R                  1     4     1     8
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 20%i x  + 20%i x  - 20%i x )\|3  + 20x  - 20x  + 20x )
+--R              *
+--R                      1     6
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                       12        9        6  +-+     12     9     6
+--R               (- 2%i x   + 2%i x  - 2%i x )\|3  + 2x   - 2x  + 2x
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 15%i x  + 15%i x  - 15%i x )\|3  + 15x  - 15x  + 15x )
+--R              *
+--R                      1     8
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                         12         9         6  +-+      12      9      6
+--R                 ((30%i x   - 30%i x  + 30%i x )\|3  - 30x   + 30x  - 30x )
+--R              *
+--R                      1     2
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                        9        6        3  +-+     9     6     3      1     10
+--R               ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(-- %pi)
+--R                                                                       18
+--R             + 
+--R                           12         9         6  +-+      12      9      6
+--R                 ((- 30%i x   + 30%i x  - 30%i x )\|3  + 30x   - 30x  + 30x )
+--R              *
+--R                      1     4
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   9       6       3  +-+    9    6    3      1     12
+--R           ((- %i x  + %i x  - %i x )\|3  + x  - x  + x )cos(-- %pi)
+--R                                                             18
+--R         + 
+--R                  12        9        6  +-+     12     9     6      1     6
+--R           ((2%i x   - 2%i x  + 2%i x )\|3  - 2x   + 2x  - 2x )cos(-- %pi)
+--R                                                                   18
+--R         + 
+--R                  15       12       9  +-+    15    12    9
+--R           (- %i x   + %i x   - %i x )\|3  + x   - x   + x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                    1     8   1     5   1     2 3+-+2 +-+
+--R                   (- %i x  - - %i x  + - %i x )\|2  \|3
+--R                    2         2         2
+--R                 + 
+--R                    1  8   1  5   1  2 3+-+2
+--R                   (- x  - - x  + - x )\|2
+--R                    2      2      2
+--R              *
+--R                      1     12
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                      1     2     1     10
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                    15     8   15     5   15     2 3+-+2 +-+
+--R                   (-- %i x  - -- %i x  + -- %i x )\|2  \|3
+--R                     2          2          2
+--R                 + 
+--R                    15  8   15  5   15  2 3+-+2
+--R                   (-- x  - -- x  + -- x )\|2
+--R                     2       2       2
+--R              *
+--R                      1     4     1     8
+--R                 cos(-- %pi) sin(-- %pi)
+--R                     18          18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (10%i x  - 10%i x  + 10%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (10x  - 10x  + 10x )\|2
+--R                  *
+--R                          1     6
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                        11       8       5 3+-+2 +-+     11    8    5 3+-+2
+--R                   (%i x   - %i x  + %i x )\|2  \|3  + (x   - x  + x )\|2
+--R              *
+--R                      1     6
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                        15     8   15     5   15     2 3+-+2 +-+
+--R                       (-- %i x  - -- %i x  + -- %i x )\|2  \|3
+--R                         2          2          2
+--R                     + 
+--R                        15  8   15  5   15  2 3+-+2
+--R                       (-- x  - -- x  + -- x )\|2
+--R                         2       2       2
+--R                  *
+--R                          1     8
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 15%i x   + 15%i x  - 15%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 15x   + 15x  - 15x )\|2
+--R                  *
+--R                          1     2
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                             8        5        2 3+-+2 +-+
+--R                       (3%i x  - 3%i x  + 3%i x )\|2  \|3
+--R                     + 
+--R                          8     5     2 3+-+2
+--R                       (3x  - 3x  + 3x )\|2
+--R                  *
+--R                          1     10
+--R                     cos(-- %pi)
+--R                         18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (15%i x   - 15%i x  + 15%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (15x   - 15x  + 15x )\|2
+--R                  *
+--R                          1     4
+--R                     cos(-- %pi)
+--R                         18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                    1     8   1     5   1     2 3+-+2 +-+
+--R                   (- %i x  - - %i x  + - %i x )\|2  \|3
+--R                    2         2         2
+--R                 + 
+--R                    1  8   1  5   1  2 3+-+2
+--R                   (- x  - - x  + - x )\|2
+--R                    2      2      2
+--R              *
+--R                      1     12
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                         11       8       5 3+-+2 +-+       11    8    5 3+-+2
+--R                 ((- %i x   + %i x  - %i x )\|2  \|3  + (- x   + x  - x )\|2  )
+--R              *
+--R                      1     6
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                1     14   1     11   1     8 3+-+2 +-+
+--R               (- %i x   - - %i x   + - %i x )\|2  \|3
+--R                2          2          2
+--R             + 
+--R                1  14   1  11   1  8 3+-+2
+--R               (- x   - - x   + - x )\|2
+--R                2       2       2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  6     3          1     12
+--R               (2x  - 2x  + 2)sin(-- %pi)
+--R                                  18
+--R             + 
+--R                   6      3           1     2     1     10
+--R               (12x  - 12x  + 12)cos(-- %pi) sin(-- %pi)
+--R                                     18          18
+--R             + 
+--R                   6      3           1     4     1     8
+--R               (30x  - 30x  + 30)cos(-- %pi) sin(-- %pi)
+--R                                     18          18
+--R             + 
+--R                    6      3           1     6     9     6     3      1     6
+--R               ((40x  - 40x  + 40)cos(-- %pi)  + 4x  - 4x  + 4x )sin(-- %pi)
+--R                                      18                             18
+--R             + 
+--R                       6      3           1     8
+--R                   (30x  - 30x  + 30)cos(-- %pi)
+--R                                         18
+--R                 + 
+--R                         9      6      3      1     2
+--R                   (- 60x  + 60x  - 60x )cos(-- %pi)
+--R                                             18
+--R              *
+--R                      1     4
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                       6      3           1     10
+--R                   (12x  - 12x  + 12)cos(-- %pi)
+--R                                         18
+--R                 + 
+--R                       9      6      3      1     4
+--R                   (60x  - 60x  + 60x )cos(-- %pi)
+--R                                           18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                  6     3          1     12        9     6     3      1     6
+--R               (2x  - 2x  + 2)cos(-- %pi)   + (- 4x  + 4x  - 4x )cos(-- %pi)
+--R                                  18                                 18
+--R             + 
+--R                 12     9     6
+--R               2x   - 2x  + 2x
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R              7     4      3+-+     1     12
+--R           (2x  - 2x  + 2x)\|2 sin(-- %pi)
+--R                                   18
+--R         + 
+--R               7      4       3+-+     1     2     1     10
+--R           (12x  - 12x  + 12x)\|2 cos(-- %pi) sin(-- %pi)
+--R                                      18          18
+--R         + 
+--R               7      4       3+-+     1     4     1     8
+--R           (30x  - 30x  + 30x)\|2 cos(-- %pi) sin(-- %pi)
+--R                                      18          18
+--R         + 
+--R                  7      4       3+-+     1     6      10     7     4 3+-+
+--R             ((40x  - 40x  + 40x)\|2 cos(-- %pi)  + (4x   - 4x  + 4x )\|2 )
+--R                                         18
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   7      4       3+-+     1     8
+--R               (30x  - 30x  + 30x)\|2 cos(-- %pi)
+--R                                          18
+--R             + 
+--R                     10      7      4 3+-+     1     2
+--R               (- 60x   + 60x  - 60x )\|2 cos(-- %pi)
+--R                                              18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   7      4       3+-+     1     10
+--R               (12x  - 12x  + 12x)\|2 cos(-- %pi)
+--R                                          18
+--R             + 
+--R                   10      7      4 3+-+     1     4
+--R               (60x   - 60x  + 60x )\|2 cos(-- %pi)
+--R                                            18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R              7     4      3+-+     1     12
+--R           (2x  - 2x  + 2x)\|2 cos(-- %pi)
+--R                                   18
+--R         + 
+--R                10     7     4 3+-+     1     6      13     10     7 3+-+
+--R           (- 4x   + 4x  - 4x )\|2 cos(-- %pi)  + (2x   - 2x   + 2x )\|2
+--R                                       18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 9       6       3  +-+    9    6    3      1     12
+--R           ((%i x  - %i x  + %i x )\|3  + x  - x  + x )sin(-- %pi)
+--R                                                           18
+--R         + 
+--R                    9        6        3  +-+     9     6     3      1     2
+--R             ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(-- %pi)
+--R                                                                   18
+--R          *
+--R                  1     10
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                     9         6         3  +-+      9      6      3
+--R             ((15%i x  - 15%i x  + 15%i x )\|3  + 15x  - 15x  + 15x )
+--R          *
+--R                  1     4     1     8
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R                         9         6         3  +-+      9      6      3
+--R                 ((20%i x  - 20%i x  + 20%i x )\|3  + 20x  - 20x  + 20x )
+--R              *
+--R                      1     6
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                     12        9        6  +-+     12     9     6
+--R               (2%i x   - 2%i x  + 2%i x )\|3  + 2x   - 2x  + 2x
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                         9         6         3  +-+      9      6      3
+--R                 ((15%i x  - 15%i x  + 15%i x )\|3  + 15x  - 15x  + 15x )
+--R              *
+--R                      1     8
+--R                 cos(-- %pi)
+--R                     18
+--R             + 
+--R                           12         9         6  +-+      12      9      6
+--R                 ((- 30%i x   + 30%i x  - 30%i x )\|3  - 30x   + 30x  - 30x )
+--R              *
+--R                      1     2
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      9        6        3  +-+     9     6     3      1     10
+--R               ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(-- %pi)
+--R                                                                     18
+--R             + 
+--R                         12         9         6  +-+      12      9      6
+--R                 ((30%i x   - 30%i x  + 30%i x )\|3  + 30x   - 30x  + 30x )
+--R              *
+--R                      1     4
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                 9       6       3  +-+    9    6    3      1     12
+--R           ((%i x  - %i x  + %i x )\|3  + x  - x  + x )cos(-- %pi)
+--R                                                           18
+--R         + 
+--R                    12        9        6  +-+     12     9     6      1     6
+--R           ((- 2%i x   + 2%i x  - 2%i x )\|3  - 2x   + 2x  - 2x )cos(-- %pi)
+--R                                                                     18
+--R         + 
+--R                15       12       9  +-+    15    12    9
+--R           (%i x   - %i x   + %i x )\|3  + x   - x   + x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R              7     4      3+-+     1     12
+--R           (2x  - 2x  + 2x)\|2 sin(-- %pi)
+--R                                   18
+--R         + 
+--R               7      4       3+-+     1     2     1     10
+--R           (12x  - 12x  + 12x)\|2 cos(-- %pi) sin(-- %pi)
+--R                                      18          18
+--R         + 
+--R               7      4       3+-+     1     4     1     8
+--R           (30x  - 30x  + 30x)\|2 cos(-- %pi) sin(-- %pi)
+--R                                      18          18
+--R         + 
+--R                  7      4       3+-+     1     6      10     7     4 3+-+
+--R             ((40x  - 40x  + 40x)\|2 cos(-- %pi)  + (4x   - 4x  + 4x )\|2 )
+--R                                         18
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   7      4       3+-+     1     8
+--R               (30x  - 30x  + 30x)\|2 cos(-- %pi)
+--R                                          18
+--R             + 
+--R                     10      7      4 3+-+     1     2
+--R               (- 60x   + 60x  - 60x )\|2 cos(-- %pi)
+--R                                              18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   7      4       3+-+     1     10
+--R               (12x  - 12x  + 12x)\|2 cos(-- %pi)
+--R                                          18
+--R             + 
+--R                   10      7      4 3+-+     1     4
+--R               (60x   - 60x  + 60x )\|2 cos(-- %pi)
+--R                                            18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R              7     4      3+-+     1     12
+--R           (2x  - 2x  + 2x)\|2 cos(-- %pi)
+--R                                   18
+--R         + 
+--R                10     7     4 3+-+     1     6      13     10     7 3+-+
+--R           (- 4x   + 4x  - 4x )\|2 cos(-- %pi)  + (2x   - 2x   + 2x )\|2
+--R                                       18
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R          8     5     2 3+-+2     1     12
+--R       (2x  - 2x  + 2x )\|2  sin(-- %pi)
+--R                                 18
+--R     + 
+--R           8      5      2 3+-+2     1     2     1     10
+--R       (12x  - 12x  + 12x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                    18          18
+--R     + 
+--R           8      5      2 3+-+2     1     4     1     8
+--R       (30x  - 30x  + 30x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                    18          18
+--R     + 
+--R              8      5      2 3+-+2     1     6      11     8     5 3+-+2
+--R         ((40x  - 40x  + 40x )\|2  cos(-- %pi)  + (4x   - 4x  + 4x )\|2  )
+--R                                       18
+--R      *
+--R              1     6
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R               8      5      2 3+-+2     1     8
+--R           (30x  - 30x  + 30x )\|2  cos(-- %pi)
+--R                                        18
+--R         + 
+--R                 11      8      5 3+-+2     1     2
+--R           (- 60x   + 60x  - 60x )\|2  cos(-- %pi)
+--R                                           18
+--R      *
+--R              1     4
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R               8      5      2 3+-+2     1     10
+--R           (12x  - 12x  + 12x )\|2  cos(-- %pi)
+--R                                        18
+--R         + 
+--R               11      8      5 3+-+2     1     4
+--R           (60x   - 60x  + 60x )\|2  cos(-- %pi)
+--R                                         18
+--R      *
+--R              1     2
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R          8     5     2 3+-+2     1     12
+--R       (2x  - 2x  + 2x )\|2  cos(-- %pi)
+--R                                 18
+--R     + 
+--R            11     8     5 3+-+2     1     6      14     11     8 3+-+2
+--R       (- 4x   + 4x  - 4x )\|2  cos(-- %pi)  + (2x   - 2x   + 2x )\|2
+--R                                    18
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 66
+
+)clear all
+
+--S 67 of 649
+t0:=x^3*(1-x^3)/(1-x^3+x^6)
+--R 
+--R
+--R            6    3
+--R         - x  + x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 67
+
+--S 68 of 649
+r0:=-x-1/3*%i*2^(2/3)*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3)*sqrt(3)))/(1-%i*sqrt(3))^(2/3)+1/3*%i*2^(2/3)*_
+   atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*_
+   sqrt(3)))/(1+%i*sqrt(3))^(2/3)+1/3*%i*2^(2/3)*log(-2^(1/3)*x+(1-%i*_
+   sqrt(3))^(1/3))/((1-%i*sqrt(3))^(2/3)*sqrt(3))-1/3*%i*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))/(2^(1/3)*_
+   (1-%i*sqrt(3))^(2/3)*sqrt(3))-1/3*%i*2^(2/3)*log(-2^(1/3)*x+(1+%i*_
+   sqrt(3))^(1/3))/((1+%i*sqrt(3))^(2/3)*sqrt(3))+1/3*%i*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R             +------------+2     +----------+2         +----------+
+--R       1    3|     +-+          3|   +-+          3+-+3|   +-+         2 3+-+2
+--R       - %i \|- %i\|3  + 1  log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R       3
+--R     + 
+--R               +------------+2     +----------+
+--R         2    3|     +-+          3|   +-+         3+-+
+--R       - - %i \|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R         3
+--R     + 
+--R       -
+--R                  +----------+2
+--R            1    3|   +-+
+--R            - %i \|%i\|3  + 1
+--R            3
+--R         *
+--R                 +------------+2         +------------+
+--R                3|     +-+          3+-+3|     +-+         2 3+-+2
+--R            log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R             +----------+2     +------------+
+--R       2    3|   +-+          3|     +-+         3+-+
+--R       - %i \|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R       3
+--R     + 
+--R                                           +------------+
+--R                  +----------+2     3+-+2 3|     +-+
+--R         2    +-+3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       - - %i\|3 \|%i\|3  + 1  atan(-------------------------)
+--R         3                                     +------------+
+--R                                     3+-+2 +-+3|     +-+
+--R                                     \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                           +----------+
+--R                +------------+2     3+-+2 3|   +-+
+--R       2    +-+3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       - %i\|3 \|- %i\|3  + 1  atan(-----------------------)
+--R       3                                       +----------+
+--R                                     3+-+2 +-+3|   +-+
+--R                                     \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                   +------------+2  +----------+2
+--R          3+-+ +-+3|     +-+       3|   +-+
+--R       - x\|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R  /
+--R              +------------+2  +----------+2
+--R     3+-+ +-+3|     +-+       3|   +-+
+--R     \|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 68
+
+--S 69 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         1                 1
+--R                  atan(----)        atan(----)
+--R                        +-+               +-+
+--R           +-+         \|3               \|3
+--R         (\|3 sin(----------) - cos(----------))
+--R                       3                 3
+--R      *
+--R                        1   2                 1                 1   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      3                     3                 3
+--R     + 
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                              1
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            3
+--R     + 
+--R                           1                 1
+--R                    atan(----)        atan(----)
+--R                          +-+               +-+
+--R             +-+         \|3               \|3
+--R         (- \|3 sin(----------) - cos(----------))
+--R                         3                 3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                                1
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              3
+--R     + 
+--R                                              1                 1
+--R                                       atan(----)        atan(----)
+--R                   1                         +-+               +-+
+--R            atan(----)          +-+         \|3               \|3
+--R                  +-+          \|3 sin(----------) + cos(----------)
+--R                 \|3                        3                 3
+--R       4sin(----------)atan(------------------------------------------)
+--R                 3                     1                     1
+--R                                atan(----)            atan(----)
+--R                                      +-+                   +-+
+--R                                     \|3       +-+         \|3
+--R                            sin(----------) - \|3 cos(----------) - 2x
+--R                                     3                     3
+--R     + 
+--R                      1                      1
+--R               atan(----)             atan(----)
+--R                     +-+                    +-+
+--R                    \|3        +-+         \|3
+--R         (2sin(----------) - 2\|3 cos(----------))
+--R                    3                      3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) - cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) + \|3 cos(----------) - 2x
+--R                       3                     3
+--R     + 
+--R                                                                    1
+--R                                                             atan(----)
+--R                      1                      1                     +-+
+--R               atan(----)             atan(----)                  \|3
+--R                     +-+                    +-+          cos(----------)
+--R                    \|3        +-+         \|3                    3
+--R       (- 2sin(----------) - 2\|3 cos(----------))atan(-------------------)
+--R                    3                      3                      1
+--R                                                           atan(----)
+--R                                                                 +-+
+--R                                                                \|3
+--R                                                       sin(----------) + x
+--R                                                                3
+--R     + 
+--R            +-+
+--R       - 6x\|3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 69
+
+--S 70 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +------------+2     +----------+2         +----------+
+--R         1    3|     +-+          3|   +-+          3+-+3|   +-+         2 3+-+2
+--R       - - %i \|- %i\|3  + 1  log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R         3
+--R     + 
+--R             +------------+2     +----------+
+--R       2    3|     +-+          3|   +-+         3+-+
+--R       - %i \|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R       3
+--R     + 
+--R             +----------+2     +------------+2         +------------+
+--R       1    3|   +-+          3|     +-+          3+-+3|     +-+         2 3+-+2
+--R       - %i \|%i\|3  + 1  log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R       3
+--R     + 
+--R               +----------+2     +------------+
+--R         2    3|   +-+          3|     +-+         3+-+
+--R       - - %i \|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R         3
+--R     + 
+--R                                                     +------------+2
+--R          1 3+-+ +-+     1        1 3+-+     1      3|     +-+
+--R         (- \|2 \|3 sin(-- %pi) - - \|2 cos(-- %pi))\|- %i\|3  + 1
+--R          6             18        6         18
+--R      *
+--R          +----------+2
+--R         3|   +-+               1     2           1             1     2    2
+--R         \|%i\|3  + 1  log(sin(-- %pi)  + 2x sin(-- %pi) + cos(-- %pi)  + x )
+--R                               18                18            18
+--R     + 
+--R                           +------------+2  +----------+2
+--R         1 3+-+     1     3|     +-+       3|   +-+
+--R         - \|2 cos(-- %pi)\|- %i\|3  + 1   \|%i\|3  + 1
+--R         3         18
+--R      *
+--R                1     2          1             1     2     +-+     1         2
+--R       log(sin(-- %pi)  - x sin(-- %pi) + cos(-- %pi)  + x\|3 cos(-- %pi) + x )
+--R               18               18            18                  18
+--R     + 
+--R                                                       +------------+2
+--R            1 3+-+ +-+     1        1 3+-+     1      3|     +-+
+--R         (- - \|2 \|3 sin(-- %pi) - - \|2 cos(-- %pi))\|- %i\|3  + 1
+--R            6             18        6         18
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R      *
+--R                1     2          1             1     2     +-+     1         2
+--R       log(sin(-- %pi)  - x sin(-- %pi) + cos(-- %pi)  - x\|3 cos(-- %pi) + x )
+--R               18               18            18                  18
+--R     + 
+--R                           +------------+2  +----------+2
+--R         2 3+-+     1     3|     +-+       3|   +-+
+--R         - \|2 sin(-- %pi)\|- %i\|3  + 1   \|%i\|3  + 1
+--R         3         18
+--R      *
+--R                  +-+     1             1
+--R                 \|3 sin(-- %pi) + cos(-- %pi)
+--R                         18            18
+--R         atan(----------------------------------)
+--R                   1         +-+     1
+--R              sin(-- %pi) - \|3 cos(-- %pi) - 2x
+--R                  18                18
+--R     + 
+--R                                                     +------------+2
+--R          1 3+-+     1        1 3+-+ +-+     1      3|     +-+
+--R         (- \|2 sin(-- %pi) - - \|2 \|3 cos(-- %pi))\|- %i\|3  + 1
+--R          3         18        3             18
+--R      *
+--R                                +-+     1             1
+--R          +----------+2        \|3 sin(-- %pi) - cos(-- %pi)
+--R         3|   +-+                      18            18
+--R         \|%i\|3  + 1  atan(----------------------------------)
+--R                                 1         +-+     1
+--R                            sin(-- %pi) + \|3 cos(-- %pi) - 2x
+--R                                18                18
+--R     + 
+--R                                         +------------+
+--R                +----------+2     3+-+2 3|     +-+
+--R       2    +-+3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       - %i\|3 \|%i\|3  + 1  atan(-------------------------)
+--R       3                                     +------------+
+--R                                   3+-+2 +-+3|     +-+
+--R                                   \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                             +----------+
+--R                  +------------+2     3+-+2 3|   +-+
+--R         2    +-+3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       - - %i\|3 \|- %i\|3  + 1  atan(-----------------------)
+--R         3                                       +----------+
+--R                                       3+-+2 +-+3|   +-+
+--R                                       \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                       +------------+2
+--R            1 3+-+     1        1 3+-+ +-+     1      3|     +-+
+--R         (- - \|2 sin(-- %pi) - - \|2 \|3 cos(-- %pi))\|- %i\|3  + 1
+--R            3         18        3             18
+--R      *
+--R                                   1
+--R          +----------+2       cos(-- %pi)
+--R         3|   +-+                 18
+--R         \|%i\|3  + 1  atan(---------------)
+--R                                 1
+--R                            sin(-- %pi) + x
+--R                                18
+--R  /
+--R              +------------+2  +----------+2
+--R     3+-+ +-+3|     +-+       3|   +-+
+--R     \|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 70
+
+--S 71 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 8    5      1     6      8     5      1     2     1     4
+--R               (x  - x )sin(-- %pi)  + (3x  - 3x )cos(-- %pi) sin(-- %pi)
+--R                            18                        18          18
+--R             + 
+--R                 11    8    5      1     3
+--R               (x   - x  - x )sin(-- %pi)
+--R                                  18
+--R             + 
+--R                     8     5      1     4       11    8    5  +-+     1
+--R                 ((3x  - 3x )cos(-- %pi)  + (- x   + x  - x )\|3 cos(-- %pi))
+--R                                 18                                  18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                    11     8     5      1     2     1
+--R               (- 3x   + 3x  + 3x )cos(-- %pi) sin(-- %pi)
+--R                                       18          18
+--R             + 
+--R               8    5      1     6    1  11   1  8   1  5  +-+     1     3    8
+--R             (x  - x )cos(-- %pi)  + (- x   - - x  + - x )\|3 cos(-- %pi)  - x
+--R                          18          3       3      3            18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 9    6 3+-+     1     6
+--R               (x  - x )\|2 sin(-- %pi)
+--R                                18
+--R             + 
+--R                  9     6 3+-+     1     2     1     4
+--R               (3x  - 3x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                  18          18
+--R             + 
+--R                 12    9    6 3+-+     1     3
+--R               (x   - x  - x )\|2 sin(-- %pi)
+--R                                      18
+--R             + 
+--R                      9     6 3+-+     1     4
+--R                   (3x  - 3x )\|2 cos(-- %pi)
+--R                                      18
+--R                 + 
+--R                       12    9    6 3+-+ +-+     1
+--R                   (- x   + x  - x )\|2 \|3 cos(-- %pi)
+--R                                                18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                    12     9     6 3+-+     1     2     1
+--R               (- 3x   + 3x  + 3x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                           18          18
+--R             + 
+--R                 9    6 3+-+     1     6
+--R               (x  - x )\|2 cos(-- %pi)
+--R                                18
+--R             + 
+--R                1  12   1  9   1  6 3+-+ +-+     1     3    9 3+-+
+--R               (- x   - - x  + - x )\|2 \|3 cos(-- %pi)  - x  \|2
+--R                3       3      3                18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R               1     7   1     4 3+-+2 +-+    1  7   1  4 3+-+2      1     6
+--R           ((- - %i x  + - %i x )\|2  \|3  + (- x  - - x )\|2  )sin(-- %pi)
+--R               2         2                    2      2              18
+--R         + 
+--R                 3     7   3     4 3+-+2 +-+    3  7   3  4 3+-+2      1     2
+--R             ((- - %i x  + - %i x )\|2  \|3  + (- x  - - x )\|2  )cos(-- %pi)
+--R                 2         2                    2      2              18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  1     10   1     7   1     4 3+-+2 +-+
+--R               (- - %i x   + - %i x  + - %i x )\|2  \|3
+--R                  2          2         2
+--R             + 
+--R                1  10   1  7   1  4 3+-+2
+--R               (- x   - - x  - - x )\|2
+--R                2       2      2
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   3     7   3     4 3+-+2 +-+    3  7   3  4 3+-+2      1     4
+--R               ((- - %i x  + - %i x )\|2  \|3  + (- x  - - x )\|2  )cos(-- %pi)
+--R                   2         2                    2      2              18
+--R             + 
+--R                      1  10   1  7   1  4 3+-+2 +-+
+--R                   (- - x   + - x  - - x )\|2  \|3
+--R                      2       2      2
+--R                 + 
+--R                    3     10   3     7   3     4 3+-+2
+--R                   (- %i x   - - %i x  + - %i x )\|2
+--R                    2          2         2
+--R              *
+--R                      1
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                3     10   3     7   3     4 3+-+2 +-+
+--R               (- %i x   - - %i x  - - %i x )\|2  \|3
+--R                2          2         2
+--R             + 
+--R                  3  10   3  7   3  4 3+-+2
+--R               (- - x   + - x  + - x )\|2
+--R                  2       2      2
+--R          *
+--R                  1     2     1
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R               1     7   1     4 3+-+2 +-+    1  7   1  4 3+-+2      1     6
+--R           ((- - %i x  + - %i x )\|2  \|3  + (- x  - - x )\|2  )cos(-- %pi)
+--R               2         2                    2      2              18
+--R         + 
+--R                1  10   1  7   1  4 3+-+2 +-+
+--R               (- x   - - x  + - x )\|2  \|3
+--R                6       6      6
+--R             + 
+--R                  1     10   1     7   1     4 3+-+2
+--R               (- - %i x   + - %i x  - - %i x )\|2
+--R                  2          2         2
+--R          *
+--R                  1     3
+--R             cos(-- %pi)
+--R                 18
+--R         + 
+--R           1     7 3+-+2 +-+  1  7 3+-+2
+--R           - %i x  \|2  \|3 - - x  \|2
+--R           2                  2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 9    6 3+-+     1     6
+--R               (x  - x )\|2 sin(-- %pi)
+--R                                18
+--R             + 
+--R                  9     6 3+-+     1     2     1     4
+--R               (3x  - 3x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                  18          18
+--R             + 
+--R                 12    9    6 3+-+     1     3
+--R               (x   - x  - x )\|2 sin(-- %pi)
+--R                                      18
+--R             + 
+--R                      9     6 3+-+     1     4
+--R                   (3x  - 3x )\|2 cos(-- %pi)
+--R                                      18
+--R                 + 
+--R                       12    9    6 3+-+ +-+     1
+--R                   (- x   + x  - x )\|2 \|3 cos(-- %pi)
+--R                                                18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                    12     9     6 3+-+     1     2     1
+--R               (- 3x   + 3x  + 3x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                           18          18
+--R             + 
+--R                 9    6 3+-+     1     6
+--R               (x  - x )\|2 cos(-- %pi)
+--R                                18
+--R             + 
+--R                1  12   1  9   1  6 3+-+ +-+     1     3    9 3+-+
+--R               (- x   - - x  + - x )\|2 \|3 cos(-- %pi)  - x  \|2
+--R                3       3      3                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 10    7 3+-+2     1     6
+--R               (x   - x )\|2  sin(-- %pi)
+--R                                  18
+--R             + 
+--R                  10     7 3+-+2     1     2     1     4
+--R               (3x   - 3x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                    18          18
+--R             + 
+--R                 13    10    7 3+-+2     1     3
+--R               (x   - x   - x )\|2  sin(-- %pi)
+--R                                        18
+--R             + 
+--R                      10     7 3+-+2     1     4
+--R                   (3x   - 3x )\|2  cos(-- %pi)
+--R                                        18
+--R                 + 
+--R                       13    10    7 3+-+2 +-+     1
+--R                   (- x   + x   - x )\|2  \|3 cos(-- %pi)
+--R                                                  18
+--R              *
+--R                      1     2
+--R                 sin(-- %pi)
+--R                     18
+--R             + 
+--R                    13     10     7 3+-+2     1     2     1
+--R               (- 3x   + 3x   + 3x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                             18          18
+--R             + 
+--R                 10    7 3+-+2     1     6
+--R               (x   - x )\|2  cos(-- %pi)
+--R                                  18
+--R             + 
+--R                1  13   1  10   1  7 3+-+2 +-+     1     3    10 3+-+2
+--R               (- x   - - x   + - x )\|2  \|3 cos(-- %pi)  - x   \|2
+--R                3       3       3                 18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   8       5  +-+    8    5      1     6
+--R           ((- %i x  + %i x )\|3  + x  - x )sin(-- %pi)
+--R                                                18
+--R         + 
+--R                    8        5  +-+     8     5      1     2     1     4
+--R           ((- 3%i x  + 3%i x )\|3  + 3x  - 3x )cos(-- %pi) sin(-- %pi)
+--R                                                    18          18
+--R         + 
+--R                   11       8       5  +-+    11    8    5      1     3
+--R           ((- %i x   + %i x  + %i x )\|3  + x   - x  - x )sin(-- %pi)
+--R                                                               18
+--R         + 
+--R                        8        5  +-+     8     5      1     4
+--R               ((- 3%i x  + 3%i x )\|3  + 3x  - 3x )cos(-- %pi)
+--R                                                        18
+--R             + 
+--R                    11    8    5  +-+        11        8        5      1
+--R               ((- x   + x  - x )\|3  + 3%i x   - 3%i x  + 3%i x )cos(-- %pi)
+--R                                                                      18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    11        8        5  +-+     11     8     5      1     2
+--R             ((3%i x   - 3%i x  - 3%i x )\|3  - 3x   + 3x  + 3x )cos(-- %pi)
+--R                                                                     18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   8       5  +-+    8    5      1     6
+--R           ((- %i x  + %i x )\|3  + x  - x )cos(-- %pi)
+--R                                                18
+--R         + 
+--R             1  11   1  8   1  5  +-+       11       8       5      1     3
+--R           ((- x   - - x  + - x )\|3  - %i x   + %i x  - %i x )cos(-- %pi)
+--R             3       3      3                                      18
+--R         + 
+--R               8 +-+    8
+--R           %i x \|3  - x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R             1     7   1     4 3+-+2 +-+    1  7   1  4 3+-+2      1     6
+--R           ((- %i x  - - %i x )\|2  \|3  + (- x  - - x )\|2  )sin(-- %pi)
+--R             2         2                    2      2              18
+--R         + 
+--R               3     7   3     4 3+-+2 +-+    3  7   3  4 3+-+2      1     2
+--R             ((- %i x  - - %i x )\|2  \|3  + (- x  - - x )\|2  )cos(-- %pi)
+--R               2         2                    2      2              18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                1     10   1     7   1     4 3+-+2 +-+
+--R               (- %i x   - - %i x  - - %i x )\|2  \|3
+--R                2          2         2
+--R             + 
+--R                1  10   1  7   1  4 3+-+2
+--R               (- x   - - x  - - x )\|2
+--R                2       2      2
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                 3     7   3     4 3+-+2 +-+    3  7   3  4 3+-+2      1     4
+--R               ((- %i x  - - %i x )\|2  \|3  + (- x  - - x )\|2  )cos(-- %pi)
+--R                 2         2                    2      2              18
+--R             + 
+--R                      1  10   1  7   1  4 3+-+2 +-+
+--R                   (- - x   + - x  - - x )\|2  \|3
+--R                      2       2      2
+--R                 + 
+--R                      3     10   3     7   3     4 3+-+2
+--R                   (- - %i x   + - %i x  - - %i x )\|2
+--R                      2          2         2
+--R              *
+--R                      1
+--R                 cos(-- %pi)
+--R                     18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  3     10   3     7   3     4 3+-+2 +-+
+--R               (- - %i x   + - %i x  + - %i x )\|2  \|3
+--R                  2          2         2
+--R             + 
+--R                  3  10   3  7   3  4 3+-+2
+--R               (- - x   + - x  + - x )\|2
+--R                  2       2      2
+--R          *
+--R                  1     2     1
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R             1     7   1     4 3+-+2 +-+    1  7   1  4 3+-+2      1     6
+--R           ((- %i x  - - %i x )\|2  \|3  + (- x  - - x )\|2  )cos(-- %pi)
+--R             2         2                    2      2              18
+--R         + 
+--R                1  10   1  7   1  4 3+-+2 +-+
+--R               (- x   - - x  + - x )\|2  \|3
+--R                6       6      6
+--R             + 
+--R                1     10   1     7   1     4 3+-+2
+--R               (- %i x   - - %i x  + - %i x )\|2
+--R                2          2         2
+--R          *
+--R                  1     3
+--R             cos(-- %pi)
+--R                 18
+--R         + 
+--R             1     7 3+-+2 +-+  1  7 3+-+2
+--R           - - %i x  \|2  \|3 - - x  \|2
+--R             2                  2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                 8       5  +-+    8    5      1     6
+--R           ((%i x  - %i x )\|3  + x  - x )sin(-- %pi)
+--R                                              18
+--R         + 
+--R                  8        5  +-+     8     5      1     2     1     4
+--R           ((3%i x  - 3%i x )\|3  + 3x  - 3x )cos(-- %pi) sin(-- %pi)
+--R                                                  18          18
+--R         + 
+--R                 11       8       5  +-+    11    8    5      1     3
+--R           ((%i x   - %i x  - %i x )\|3  + x   - x  - x )sin(-- %pi)
+--R                                                             18
+--R         + 
+--R                      8        5  +-+     8     5      1     4
+--R               ((3%i x  - 3%i x )\|3  + 3x  - 3x )cos(-- %pi)
+--R                                                      18
+--R             + 
+--R                    11    8    5  +-+        11        8        5      1
+--R               ((- x   + x  - x )\|3  - 3%i x   + 3%i x  - 3%i x )cos(-- %pi)
+--R                                                                      18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      11        8        5  +-+     11     8     5      1     2
+--R             ((- 3%i x   + 3%i x  + 3%i x )\|3  - 3x   + 3x  + 3x )cos(-- %pi)
+--R                                                                       18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                 8       5  +-+    8    5      1     6
+--R           ((%i x  - %i x )\|3  + x  - x )cos(-- %pi)
+--R                                              18
+--R         + 
+--R             1  11   1  8   1  5  +-+       11       8       5      1     3
+--R           ((- x   - - x  + - x )\|3  + %i x   - %i x  + %i x )cos(-- %pi)
+--R             3       3      3                                      18
+--R         + 
+--R                 8 +-+    8
+--R           - %i x \|3  - x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R          6     3 3+-+     1     6      6     3 3+-+     1     2     1     4
+--R       (2x  - 2x )\|2 sin(-- %pi)  + (6x  - 6x )\|2 cos(-- %pi) sin(-- %pi)
+--R                          18                            18          18
+--R     + 
+--R          9     6     3 3+-+     1     3
+--R       (2x  - 2x  - 2x )\|2 sin(-- %pi)
+--R                                18
+--R     + 
+--R             6     3 3+-+     1     4        9     6     3 3+-+ +-+     1
+--R         ((6x  - 6x )\|2 cos(-- %pi)  + (- 2x  + 2x  - 2x )\|2 \|3 cos(-- %pi))
+--R                             18                                        18
+--R      *
+--R              1     2
+--R         sin(-- %pi)
+--R             18
+--R     + 
+--R            9     6     3 3+-+     1     2     1
+--R       (- 6x  + 6x  + 6x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                  18          18
+--R     + 
+--R          6     3 3+-+     1     6    2  9   2  6   2  3 3+-+ +-+     1     3
+--R       (2x  - 2x )\|2 cos(-- %pi)  + (- x  - - x  + - x )\|2 \|3 cos(-- %pi)
+--R                          18          3      3      3                18
+--R     + 
+--R           6 3+-+
+--R       - 2x  \|2
+--R  /
+--R                 8    5    2      1     6
+--R               (x  - x  + x )sin(-- %pi)
+--R                                 18
+--R             + 
+--R                  8     5     2      1     2     1     4
+--R               (3x  - 3x  + 3x )cos(-- %pi) sin(-- %pi)
+--R                                    18          18
+--R             + 
+--R                  11     8     5      1     3
+--R               (2x   - 2x  + 2x )sin(-- %pi)
+--R                                     18
+--R             + 
+--R                  8     5     2      1     4     1     2
+--R               (3x  - 3x  + 3x )cos(-- %pi) sin(-- %pi)
+--R                                    18          18
+--R             + 
+--R                    11     8     5      1     2     1
+--R               (- 6x   + 6x  - 6x )cos(-- %pi) sin(-- %pi)
+--R                                       18          18
+--R             + 
+--R                 8    5    2      1     6    14    11    8
+--R               (x  - x  + x )cos(-- %pi)  + x   - x   + x
+--R                                 18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 9    6    3 3+-+     1     6
+--R               (x  - x  + x )\|2 sin(-- %pi)
+--R                                     18
+--R             + 
+--R                  9     6     3 3+-+     1     2     1     4
+--R               (3x  - 3x  + 3x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                        18          18
+--R             + 
+--R                  12     9     6 3+-+     1     3
+--R               (2x   - 2x  + 2x )\|2 sin(-- %pi)
+--R                                         18
+--R             + 
+--R                  9     6     3 3+-+     1     4     1     2
+--R               (3x  - 3x  + 3x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                        18          18
+--R             + 
+--R                    12     9     6 3+-+     1     2     1
+--R               (- 6x   + 6x  - 6x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                           18          18
+--R             + 
+--R                 9    6    3 3+-+     1     6     15    12    9 3+-+
+--R               (x  - x  + x )\|2 cos(-- %pi)  + (x   - x   + x )\|2
+--R                                     18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    1     7   1     4   1      3+-+2 +-+
+--R                 (- - %i x  + - %i x  - - %i x)\|2  \|3
+--R                    2         2         2
+--R               + 
+--R                  1  7   1  4   1   3+-+2
+--R                 (- x  - - x  + - x)\|2
+--R                  2      2      2
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    3     7   3     4   3      3+-+2 +-+
+--R                 (- - %i x  + - %i x  - - %i x)\|2  \|3
+--R                    2         2         2
+--R               + 
+--R                  3  7   3  4   3   3+-+2
+--R                 (- x  - - x  + - x)\|2
+--R                  2      2      2
+--R          *
+--R                  1     2     1     4
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R                     10       7       4 3+-+2 +-+     10    7    4 3+-+2
+--R             ((- %i x   + %i x  - %i x )\|2  \|3  + (x   - x  + x )\|2  )
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    3     7   3     4   3      3+-+2 +-+
+--R                 (- - %i x  + - %i x  - - %i x)\|2  \|3
+--R                    2         2         2
+--R               + 
+--R                  3  7   3  4   3   3+-+2
+--R                 (- x  - - x  + - x)\|2
+--R                  2      2      2
+--R          *
+--R                  1     4     1     2
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R                    10        7        4 3+-+2 +-+        10     7     4 3+-+2
+--R             ((3%i x   - 3%i x  + 3%i x )\|2  \|3  + (- 3x   + 3x  - 3x )\|2  )
+--R          *
+--R                  1     2     1
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R                    1     7   1     4   1      3+-+2 +-+
+--R                 (- - %i x  + - %i x  - - %i x)\|2  \|3
+--R                    2         2         2
+--R               + 
+--R                  1  7   1  4   1   3+-+2
+--R                 (- x  - - x  + - x)\|2
+--R                  2      2      2
+--R          *
+--R                  1     6
+--R             cos(-- %pi)
+--R                 18
+--R         + 
+--R              1     13   1     10   1     7 3+-+2 +-+
+--R           (- - %i x   + - %i x   - - %i x )\|2  \|3
+--R              2          2          2
+--R         + 
+--R            1  13   1  10   1  7 3+-+2
+--R           (- x   - - x   + - x )\|2
+--R            2       2       2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 9    6    3 3+-+     1     6
+--R               (x  - x  + x )\|2 sin(-- %pi)
+--R                                     18
+--R             + 
+--R                  9     6     3 3+-+     1     2     1     4
+--R               (3x  - 3x  + 3x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                        18          18
+--R             + 
+--R                  12     9     6 3+-+     1     3
+--R               (2x   - 2x  + 2x )\|2 sin(-- %pi)
+--R                                         18
+--R             + 
+--R                  9     6     3 3+-+     1     4     1     2
+--R               (3x  - 3x  + 3x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                        18          18
+--R             + 
+--R                    12     9     6 3+-+     1     2     1
+--R               (- 6x   + 6x  - 6x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                           18          18
+--R             + 
+--R                 9    6    3 3+-+     1     6     15    12    9 3+-+
+--R               (x  - x  + x )\|2 cos(-- %pi)  + (x   - x   + x )\|2
+--R                                     18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 10    7    4 3+-+2     1     6
+--R               (x   - x  + x )\|2  sin(-- %pi)
+--R                                       18
+--R             + 
+--R                  10     7     4 3+-+2     1     2     1     4
+--R               (3x   - 3x  + 3x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                          18          18
+--R             + 
+--R                  13     10     7 3+-+2     1     3
+--R               (2x   - 2x   + 2x )\|2  sin(-- %pi)
+--R                                           18
+--R             + 
+--R                  10     7     4 3+-+2     1     4     1     2
+--R               (3x   - 3x  + 3x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                          18          18
+--R             + 
+--R                    13     10     7 3+-+2     1     2     1
+--R               (- 6x   + 6x   - 6x )\|2  cos(-- %pi) sin(-- %pi)
+--R                                             18          18
+--R             + 
+--R                 10    7    4 3+-+2     1     6     16    13    10 3+-+2
+--R               (x   - x  + x )\|2  cos(-- %pi)  + (x   - x   + x  )\|2
+--R                                       18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   8       5       2  +-+    8    5    2      1     6
+--R           ((- %i x  + %i x  - %i x )\|3  + x  - x  + x )sin(-- %pi)
+--R                                                             18
+--R         + 
+--R                      8        5        2  +-+     8     5     2      1     2
+--R             ((- 3%i x  + 3%i x  - 3%i x )\|3  + 3x  - 3x  + 3x )cos(-- %pi)
+--R                                                                     18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    11        8        5  +-+     11     8     5      1     3
+--R           ((- 2%i x   + 2%i x  - 2%i x )\|3  + 2x   - 2x  + 2x )sin(-- %pi)
+--R                                                                     18
+--R         + 
+--R                      8        5        2  +-+     8     5     2      1     4
+--R             ((- 3%i x  + 3%i x  - 3%i x )\|3  + 3x  - 3x  + 3x )cos(-- %pi)
+--R                                                                     18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                    11        8        5  +-+     11     8     5      1     2
+--R             ((6%i x   - 6%i x  + 6%i x )\|3  - 6x   + 6x  - 6x )cos(-- %pi)
+--R                                                                     18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                   8       5       2  +-+    8    5    2      1     6
+--R           ((- %i x  + %i x  - %i x )\|3  + x  - x  + x )cos(-- %pi)
+--R                                                             18
+--R         + 
+--R                  14       11       8  +-+    14    11    8
+--R           (- %i x   + %i x   - %i x )\|3  + x   - x   + x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R               1     7   1     4   1      3+-+2 +-+    1  7   1  4   1   3+-+2
+--R             ((- %i x  - - %i x  + - %i x)\|2  \|3  + (- x  - - x  + - x)\|2  )
+--R               2         2         2                   2      2      2
+--R          *
+--R                  1     6
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R               3     7   3     4   3      3+-+2 +-+    3  7   3  4   3   3+-+2
+--R             ((- %i x  - - %i x  + - %i x)\|2  \|3  + (- x  - - x  + - x)\|2  )
+--R               2         2         2                   2      2      2
+--R          *
+--R                  1     2     1     4
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R                   10       7       4 3+-+2 +-+     10    7    4 3+-+2
+--R             ((%i x   - %i x  + %i x )\|2  \|3  + (x   - x  + x )\|2  )
+--R          *
+--R                  1     3
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R               3     7   3     4   3      3+-+2 +-+    3  7   3  4   3   3+-+2
+--R             ((- %i x  - - %i x  + - %i x)\|2  \|3  + (- x  - - x  + - x)\|2  )
+--R               2         2         2                   2      2      2
+--R          *
+--R                  1     4     1     2
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R                         10        7        4 3+-+2 +-+
+--R                 (- 3%i x   + 3%i x  - 3%i x )\|2  \|3
+--R               + 
+--R                      10     7     4 3+-+2
+--R                 (- 3x   + 3x  - 3x )\|2
+--R          *
+--R                  1     2     1
+--R             cos(-- %pi) sin(-- %pi)
+--R                 18          18
+--R         + 
+--R               1     7   1     4   1      3+-+2 +-+    1  7   1  4   1   3+-+2
+--R             ((- %i x  - - %i x  + - %i x)\|2  \|3  + (- x  - - x  + - x)\|2  )
+--R               2         2         2                   2      2      2
+--R          *
+--R                  1     6
+--R             cos(-- %pi)
+--R                 18
+--R         + 
+--R          1     13   1     10   1     7 3+-+2 +-+    1  13   1  10   1  7 3+-+2
+--R         (- %i x   - - %i x   + - %i x )\|2  \|3  + (- x   - - x   + - x )\|2
+--R          2          2          2                    2       2       2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                 8       5       2  +-+    8    5    2      1     6
+--R           ((%i x  - %i x  + %i x )\|3  + x  - x  + x )sin(-- %pi)
+--R                                                           18
+--R         + 
+--R                    8        5        2  +-+     8     5     2      1     2
+--R             ((3%i x  - 3%i x  + 3%i x )\|3  + 3x  - 3x  + 3x )cos(-- %pi)
+--R                                                                   18
+--R          *
+--R                  1     4
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                  11        8        5  +-+     11     8     5      1     3
+--R           ((2%i x   - 2%i x  + 2%i x )\|3  + 2x   - 2x  + 2x )sin(-- %pi)
+--R                                                                   18
+--R         + 
+--R                    8        5        2  +-+     8     5     2      1     4
+--R             ((3%i x  - 3%i x  + 3%i x )\|3  + 3x  - 3x  + 3x )cos(-- %pi)
+--R                                                                   18
+--R          *
+--R                  1     2
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                      11        8        5  +-+     11     8     5      1     2
+--R             ((- 6%i x   + 6%i x  - 6%i x )\|3  - 6x   + 6x  - 6x )cos(-- %pi)
+--R                                                                       18
+--R          *
+--R                  1
+--R             sin(-- %pi)
+--R                 18
+--R         + 
+--R                 8       5       2  +-+    8    5    2      1     6
+--R           ((%i x  - %i x  + %i x )\|3  + x  - x  + x )cos(-- %pi)
+--R                                                           18
+--R         + 
+--R                14       11       8  +-+    14    11    8
+--R           (%i x   - %i x   + %i x )\|3  + x   - x   + x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R          6     3     3+-+     1     6
+--R       (2x  - 2x  + 2)\|2 sin(-- %pi)
+--R                              18
+--R     + 
+--R          6     3     3+-+     1     2     1     4
+--R       (6x  - 6x  + 6)\|2 cos(-- %pi) sin(-- %pi)
+--R                              18          18
+--R     + 
+--R          9     6     3 3+-+     1     3
+--R       (4x  - 4x  + 4x )\|2 sin(-- %pi)
+--R                                18
+--R     + 
+--R          6     3     3+-+     1     4     1     2
+--R       (6x  - 6x  + 6)\|2 cos(-- %pi) sin(-- %pi)
+--R                              18          18
+--R     + 
+--R             9      6      3 3+-+     1     2     1
+--R       (- 12x  + 12x  - 12x )\|2 cos(-- %pi) sin(-- %pi)
+--R                                     18          18
+--R     + 
+--R          6     3     3+-+     1     6      12     9     6 3+-+
+--R       (2x  - 2x  + 2)\|2 cos(-- %pi)  + (2x   - 2x  + 2x )\|2
+--R                              18
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 71
+
+)clear all
+
+--S 72 of 649
+t0:=x^2*(1-x^3)/(1-x^3+x^6)
+--R 
+--R
+--R            5    2
+--R         - x  + x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 72
+
+--S 73 of 649
+r0:=-1/6*log(1-x^3+x^6)-1/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                          3      +-+
+--R           +-+     6    3              (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                             3
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            6\|3
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                          3      +-+
+--R           +-+     6    3              (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                             3
+--R   (3)  ---------------------------------------------
+--R                              +-+
+--R                            6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 74
+
+--S 75 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+--S 76 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 76
+
+)clear all
+
+--S 77 of 649
+t0:=x*(1-x^3)/(1-x^3+x^6)
+--R 
+--R
+--R             4
+--R          - x  + x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 77
+
+--S 78 of 649
+r0:=1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))-_
+   1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*_
+   sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(2/3)*(1-_
+   %i*sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3+%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*x^2+2^(1/3)*_
+   x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3+%i*sqrt(3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3))-1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/_
+   (2^(2/3)*(1+%i*sqrt(3))^(1/3)*sqrt(3)))*(%i+sqrt(3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3))
+--R 
+--R
+--R   (2)
+--R                      +------------+
+--R             +-+     3|     +-+
+--R         (%i\|3  + 3)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +------------+     +----------+
+--R              +-+     3|     +-+         3|   +-+         3+-+
+--R       (- 2%i\|3  - 6)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                        +----------+
+--R               +-+     3|   +-+
+--R         (- %i\|3  + 3)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+     +------------+
+--R            +-+     3|   +-+         3|     +-+         3+-+
+--R       (2%i\|3  - 6)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                               +------------+
+--R                       +----------+     3+-+2 3|     +-+
+--R            +-+       3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (- 6\|3  + 6%i)\|%i\|3  + 1 atan(-------------------------)
+--R                                                   +------------+
+--R                                         3+-+2 +-+3|     +-+
+--R                                         \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                 +----------+
+--R                       +------------+     3+-+2 3|   +-+
+--R            +-+       3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (- 6\|3  - 6%i)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                     +----------+
+--R                                           3+-+2 +-+3|   +-+
+--R                                           \|2  \|3 \|%i\|3  + 1
+--R  /
+--R              +------------+ +----------+
+--R       3+-+2 3|     +-+     3|   +-+
+--R     18\|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 78
+
+--S 79 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   3
+--R      *
+--R         log
+--R                         1   4                1   2                 1   2
+--R                  atan(----)           atan(----)            atan(----)
+--R                        +-+                  +-+                   +-+
+--R                       \|3                  \|3                   \|3
+--R              sin(----------)  + (2cos(----------)  + 2x)sin(----------)
+--R                       3                    3                     3
+--R            + 
+--R                         1   4                 1   2
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3                   \|3        2
+--R              cos(----------)  - 2x cos(----------)  + x
+--R                       3                     3
+--R     + 
+--R                         1                 1
+--R                  atan(----)        atan(----)
+--R                        +-+               +-+
+--R           +-+         \|3               \|3
+--R         (\|3 sin(----------) - cos(----------))
+--R                       3                 3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                               1              1                 1   4
+--R                        atan(----)     atan(----)        atan(----)
+--R                              +-+            +-+               +-+
+--R                 +-+         \|3            \|3               \|3
+--R              2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                             3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                           1                 1
+--R                    atan(----)        atan(----)
+--R                          +-+               +-+
+--R             +-+         \|3               \|3
+--R         (- \|3 sin(----------) - cos(----------))
+--R                         3                 3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                                 1              1                 1   4
+--R                          atan(----)     atan(----)        atan(----)
+--R                                +-+            +-+               +-+
+--R                   +-+         \|3            \|3               \|3
+--R              - 2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                               3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                        1                      1
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|3        +-+         \|3
+--R         (- 2sin(----------) - 2\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R         atan
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  + 2cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3
+--R                - \|3 cos(----------)
+--R                               3
+--R           /
+--R                           1   2                   1              1
+--R                    atan(----)              atan(----)     atan(----)
+--R                          +-+                     +-+            +-+
+--R                         \|3         +-+         \|3            \|3
+--R                sin(----------)  - 2\|3 cos(----------)sin(----------)
+--R                         3                       3              3
+--R              + 
+--R                             1   2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                - cos(----------)  - 2x
+--R                           3
+--R     + 
+--R                      1                      1
+--R               atan(----)             atan(----)
+--R                     +-+                    +-+
+--R                    \|3        +-+         \|3
+--R         (2sin(----------) - 2\|3 cos(----------))
+--R                    3                      3
+--R      *
+--R         atan
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  - 2cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3
+--R                - \|3 cos(----------)
+--R                               3
+--R           /
+--R                           1   2                   1              1
+--R                    atan(----)              atan(----)     atan(----)
+--R                          +-+                     +-+            +-+
+--R                         \|3         +-+         \|3            \|3
+--R                sin(----------)  + 2\|3 cos(----------)sin(----------)
+--R                         3                       3              3
+--R              + 
+--R                             1   2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                - cos(----------)  - 2x
+--R                           3
+--R     + 
+--R                                            1              1
+--R                                     atan(----)     atan(----)
+--R                   1                       +-+            +-+
+--R            atan(----)                    \|3            \|3
+--R                  +-+           2cos(----------)sin(----------)
+--R                 \|3                      3              3
+--R       4sin(----------)atan(---------------------------------------)
+--R                 3                     1   2              1   2
+--R                                atan(----)         atan(----)
+--R                                      +-+                +-+
+--R                                     \|3                \|3
+--R                            sin(----------)  - cos(----------)  + x
+--R                                     3                  3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 79
+
+--S 80 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +------------+
+--R             +-+      3|     +-+
+--R         (- \|3  - %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +------------+     +----------+
+--R          +-+       3|     +-+         3|   +-+         3+-+
+--R       (2\|3  + 2%i)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                       +----------+
+--R             +-+      3|   +-+
+--R         (- \|3  + %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+     +------------+
+--R          +-+       3|   +-+         3|     +-+         3+-+
+--R       (2\|3  - 2%i)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                        +------------+ +----------+
+--R          3+-+2    %pi 3|     +-+     3|   +-+
+--R         2\|2  cos(---)\|- %i\|3  + 1 \|%i\|3  + 1
+--R                    18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2          %pi 2       %pi 4          %pi 2
+--R              sin(---)  + (2cos(---)  + 2x)sin(---)  + cos(---)  - 2x cos(---)
+--R                   18            18             18          18             18
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R                                             +------------+ +----------+
+--R          3+-+2 +-+    %pi    3+-+2    %pi  3|     +-+     3|   +-+
+--R         (\|2  \|3 sin(---) - \|2  cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                        18              18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2         %pi 2      +-+    %pi     %pi
+--R              sin(---)  + (2cos(---)  - x)sin(---)  + 2x\|3 cos(---)sin(---)
+--R                   18            18            18                18      18
+--R            + 
+--R                  %pi 4         %pi 2    2
+--R              cos(---)  + x cos(---)  + x
+--R                   18            18
+--R     + 
+--R                                               +------------+ +----------+
+--R            3+-+2 +-+    %pi    3+-+2    %pi  3|     +-+     3|   +-+
+--R         (- \|2  \|3 sin(---) - \|2  cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                          18              18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2         %pi 2      +-+    %pi     %pi
+--R              sin(---)  + (2cos(---)  - x)sin(---)  - 2x\|3 cos(---)sin(---)
+--R                   18            18            18                18      18
+--R            + 
+--R                  %pi 4         %pi 2    2
+--R              cos(---)  + x cos(---)  + x
+--R                   18            18
+--R     + 
+--R                                                 +------------+ +----------+
+--R             3+-+2    %pi     3+-+2 +-+    %pi  3|     +-+     3|   +-+
+--R         (- 2\|2  sin(---) - 2\|2  \|3 cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                       18                   18
+--R      *
+--R                +-+    %pi 2        %pi     %pi     +-+    %pi 2
+--R               \|3 sin(---)  + 2cos(---)sin(---) - \|3 cos(---)
+--R                        18           18      18             18
+--R         atan(--------------------------------------------------)
+--R                  %pi 2     +-+    %pi     %pi        %pi 2
+--R              sin(---)  - 2\|3 cos(---)sin(---) - cos(---)  - 2x
+--R                   18               18      18         18
+--R     + 
+--R                                               +------------+ +----------+
+--R           3+-+2    %pi     3+-+2 +-+    %pi  3|     +-+     3|   +-+
+--R         (2\|2  sin(---) - 2\|2  \|3 cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                     18                   18
+--R      *
+--R                +-+    %pi 2        %pi     %pi     +-+    %pi 2
+--R               \|3 sin(---)  - 2cos(---)sin(---) - \|3 cos(---)
+--R                        18           18      18             18
+--R         atan(--------------------------------------------------)
+--R                  %pi 2     +-+    %pi     %pi        %pi 2
+--R              sin(---)  + 2\|3 cos(---)sin(---) - cos(---)  - 2x
+--R                   18               18      18         18
+--R     + 
+--R                                               +------------+
+--R                       +----------+     3+-+2 3|     +-+
+--R              +-+     3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (- 2%i\|3  + 6)\|%i\|3  + 1 atan(-------------------------)
+--R                                                   +------------+
+--R                                         3+-+2 +-+3|     +-+
+--R                                         \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                               +----------+
+--R                     +------------+     3+-+2 3|   +-+
+--R            +-+     3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (2%i\|3  + 6)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                   +----------+
+--R                                         3+-+2 +-+3|   +-+
+--R                                         \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                             %pi     %pi
+--R                    +------------+ +----------+         2cos(---)sin(---)
+--R      3+-+2    %pi 3|     +-+     3|   +-+                    18      18
+--R     4\|2  sin(---)\|- %i\|3  + 1 \|%i\|3  + 1 atan(-------------------------)
+--R                18                                      %pi 2       %pi 2
+--R                                                    sin(---)  - cos(---)  + x
+--R                                                         18          18
+--R  /
+--R                +------------+ +----------+
+--R      3+-+2 +-+3|     +-+     3|   +-+
+--R     6\|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 80
+
+--S 81 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  8     5 3+-+    %pi 12       8      5 3+-+    %pi 2    %pi 10
+--R               (6x  - 6x )\|2 sin(---)   + (36x  - 36x )\|2 cos(---) sin(---)
+--R                                   18                            18       18
+--R             + 
+--R                       8      5 3+-+    %pi 4
+--R                   (90x  - 90x )\|2 cos(---)
+--R                                         18
+--R                 + 
+--R                       11      8      5 3+-+ +-+    %pi
+--R                   (12x   - 12x  + 12x )\|2 \|3 cos(---)
+--R                                                     18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        8       5 3+-+    %pi 6
+--R                   (120x  - 120x )\|2 cos(---)
+--R                                           18
+--R                 + 
+--R                       11      8      5 3+-+ +-+    %pi 3       11      8 3+-+
+--R                   (32x   - 32x  + 32x )\|2 \|3 cos(---)  + (12x   - 12x )\|2
+--R                                                     18
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       8      5 3+-+    %pi 8
+--R                   (90x  - 90x )\|2 cos(---)
+--R                                         18
+--R                 + 
+--R                       11      8      5 3+-+ +-+    %pi 5
+--R                   (24x   - 24x  + 24x )\|2 \|3 cos(---)
+--R                                                     18
+--R                 + 
+--R                          11       8 3+-+    %pi 2
+--R                   (- 180x   + 180x )\|2 cos(---)
+--R                                              18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       8      5 3+-+    %pi 10        11       8 3+-+    %pi 4
+--R                   (36x  - 36x )\|2 cos(---)   + (180x   - 180x )\|2 cos(---)
+--R                                         18                               18
+--R                 + 
+--R                         14      11      8 3+-+ +-+    %pi
+--R                   (- 12x   + 12x   - 12x )\|2 \|3 cos(---)
+--R                                                        18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                  8     5 3+-+    %pi 12        11     8     5 3+-+ +-+    %pi 9
+--R               (6x  - 6x )\|2 cos(---)   + (- 4x   + 4x  - 4x )\|2 \|3 cos(---)
+--R                                   18                                       18
+--R             + 
+--R                     11      8 3+-+    %pi 6
+--R               (- 12x   + 12x )\|2 cos(---)
+--R                                        18
+--R             + 
+--R                  14     11     8 3+-+ +-+    %pi 3      14     11 3+-+
+--R               (4x   - 4x   + 4x )\|2 \|3 cos(---)  + (6x   - 6x  )\|2
+--R                                               18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                        6        3 3+-+2 +-+      6     3 3+-+2     %pi 12
+--R               ((- 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x )\|2  )sin(---)
+--R                                                                     18
+--R             + 
+--R                           6         3 3+-+2 +-+       6      3 3+-+2     %pi 2
+--R                 ((- 18%i x  + 18%i x )\|2  \|3  + (18x  - 18x )\|2  )cos(---)
+--R                                                                           18
+--R              *
+--R                     %pi 10
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               6         3 3+-+2 +-+       6      3 3+-+2
+--R                     ((- 45%i x  + 45%i x )\|2  \|3  + (45x  - 45x )\|2  )
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                          9     6     3 3+-+2 +-+
+--R                       (6x  - 6x  + 6x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 18%i x  + 18%i x  - 18%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               6         3 3+-+2 +-+       6      3 3+-+2
+--R                     ((- 60%i x  + 60%i x )\|2  \|3  + (60x  - 60x )\|2  )
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           9      6      3 3+-+2 +-+
+--R                       (16x  - 16x  + 16x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 48%i x  + 48%i x  - 48%i x )\|2
+--R                  *
+--R                         %pi 3
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           9        6 3+-+2 +-+      9     6 3+-+2
+--R                   (- 6%i x  + 6%i x )\|2  \|3  + (6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               6         3 3+-+2 +-+       6      3 3+-+2
+--R                     ((- 45%i x  + 45%i x )\|2  \|3  + (45x  - 45x )\|2  )
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           9      6      3 3+-+2 +-+
+--R                       (12x  - 12x  + 12x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 36%i x  + 36%i x  - 36%i x )\|2
+--R                  *
+--R                         %pi 5
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                         9         6 3+-+2 +-+         9      6 3+-+2     %pi 2
+--R                 ((90%i x  - 90%i x )\|2  \|3  + (- 90x  + 90x )\|2  )cos(---)
+--R                                                                           18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               6         3 3+-+2 +-+       6      3 3+-+2
+--R                     ((- 18%i x  + 18%i x )\|2  \|3  + (18x  - 18x )\|2  )
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                               9         6 3+-+2 +-+       9      6 3+-+2
+--R                     ((- 90%i x  + 90%i x )\|2  \|3  + (90x  - 90x )\|2  )
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                            12     9     6 3+-+2 +-+
+--R                       (- 6x   + 6x  - 6x )\|2  \|3
+--R                     + 
+--R                              12         9         6 3+-+2
+--R                       (18%i x   - 18%i x  + 18%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        6        3 3+-+2 +-+      6     3 3+-+2     %pi 12
+--R               ((- 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x )\|2  )cos(---)
+--R                                                                     18
+--R             + 
+--R                          9     6     3 3+-+2 +-+
+--R                     (- 2x  + 2x  - 2x )\|2  \|3
+--R                   + 
+--R                           9        6        3 3+-+2
+--R                     (6%i x  - 6%i x  + 6%i x )\|2
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      9        6 3+-+2 +-+        9     6 3+-+2     %pi 6
+--R               ((6%i x  - 6%i x )\|2  \|3  + (- 6x  + 6x )\|2  )cos(---)
+--R                                                                     18
+--R             + 
+--R                      12     9     6 3+-+2 +-+
+--R                   (2x   - 2x  + 2x )\|2  \|3
+--R                 + 
+--R                           12        9        6 3+-+2
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       12        9 3+-+2 +-+      12     9 3+-+2
+--R               (- 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x )\|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    7        4  +-+     7     4     %pi 12
+--R           ((- 6%i x  + 6%i x )\|3  + 6x  - 6x )sin(---)
+--R                                                     18
+--R         + 
+--R                     7         4  +-+      7      4     %pi 2    %pi 10
+--R           ((- 36%i x  + 36%i x )\|3  + 36x  - 36x )cos(---) sin(---)
+--R                                                         18       18
+--R         + 
+--R                         7         4  +-+      7      4     %pi 4
+--R               ((- 90%i x  + 90%i x )\|3  + 90x  - 90x )cos(---)
+--R                                                             18
+--R             + 
+--R                  10      7      4  +-+         10         7         4     %pi
+--R             ((12x   - 12x  + 12x )\|3  - 36%i x   + 36%i x  - 36%i x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          7          4  +-+       7       4     %pi 6
+--R               ((- 120%i x  + 120%i x )\|3  + 120x  - 120x )cos(---)
+--R                                                                 18
+--R             + 
+--R                      10      7      4  +-+         10         7         4
+--R                 ((32x   - 32x  + 32x )\|3  - 96%i x   + 96%i x  - 96%i x )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        10         7  +-+      10      7
+--R               (- 12%i x   + 12%i x )\|3  + 12x   - 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         7         4  +-+      7      4     %pi 8
+--R               ((- 90%i x  + 90%i x )\|3  + 90x  - 90x )cos(---)
+--R                                                             18
+--R             + 
+--R                      10      7      4  +-+         10         7         4
+--R                 ((24x   - 24x  + 24x )\|3  - 72%i x   + 72%i x  - 72%i x )
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        10          7  +-+       10       7     %pi 2
+--R               ((180%i x   - 180%i x )\|3  - 180x   + 180x )cos(---)
+--R                                                                 18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         7         4  +-+      7      4     %pi 10
+--R               ((- 36%i x  + 36%i x )\|3  + 36x  - 36x )cos(---)
+--R                                                             18
+--R             + 
+--R                          10          7  +-+       10       7     %pi 4
+--R               ((- 180%i x   + 180%i x )\|3  + 180x   - 180x )cos(---)
+--R                                                                   18
+--R             + 
+--R                        13      10      7  +-+         13         10         7
+--R                 ((- 12x   + 12x   - 12x )\|3  + 36%i x   - 36%i x   + 36%i x )
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7        4  +-+     7     4     %pi 12
+--R           ((- 6%i x  + 6%i x )\|3  + 6x  - 6x )cos(---)
+--R                                                     18
+--R         + 
+--R                 10     7     4  +-+         10         7         4     %pi 9
+--R           ((- 4x   + 4x  - 4x )\|3  + 12%i x   - 12%i x  + 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                   10         7  +-+      10      7     %pi 6
+--R           ((12%i x   - 12%i x )\|3  - 12x   + 12x )cos(---)
+--R                                                         18
+--R         + 
+--R               13     10     7  +-+         13         10         7     %pi 3
+--R           ((4x   - 4x   + 4x )\|3  - 12%i x   + 12%i x   - 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                   13        10  +-+     13     10
+--R           (- 6%i x   + 6%i x  )\|3  + 6x   - 6x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                      6        3 3+-+2 +-+      6     3 3+-+2     %pi 12
+--R               ((3%i x  - 3%i x )\|2  \|3  + (3x  - 3x )\|2  )sin(---)
+--R                                                                   18
+--R             + 
+--R                         6         3 3+-+2 +-+       6      3 3+-+2     %pi 2
+--R                 ((18%i x  - 18%i x )\|2  \|3  + (18x  - 18x )\|2  )cos(---)
+--R                                                                         18
+--R              *
+--R                     %pi 10
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           6         3 3+-+2 +-+       6      3 3+-+2     %pi 4
+--R                   ((45%i x  - 45%i x )\|2  \|3  + (45x  - 45x )\|2  )cos(---)
+--R                                                                           18
+--R                 + 
+--R                          9     6     3 3+-+2 +-+
+--R                       (6x  - 6x  + 6x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (18%i x  - 18%i x  + 18%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           6         3 3+-+2 +-+       6      3 3+-+2     %pi 6
+--R                   ((60%i x  - 60%i x )\|2  \|3  + (60x  - 60x )\|2  )cos(---)
+--R                                                                           18
+--R                 + 
+--R                           9      6      3 3+-+2 +-+
+--R                       (16x  - 16x  + 16x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (48%i x  - 48%i x  + 48%i x )\|2
+--R                  *
+--R                         %pi 3
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                         9        6 3+-+2 +-+      9     6 3+-+2
+--R                   (6%i x  - 6%i x )\|2  \|3  + (6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           6         3 3+-+2 +-+       6      3 3+-+2     %pi 8
+--R                   ((45%i x  - 45%i x )\|2  \|3  + (45x  - 45x )\|2  )cos(---)
+--R                                                                           18
+--R                 + 
+--R                           9      6      3 3+-+2 +-+
+--R                       (12x  - 12x  + 12x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (36%i x  - 36%i x  + 36%i x )\|2
+--R                  *
+--R                         %pi 5
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                               9         6 3+-+2 +-+         9      6 3+-+2
+--R                     ((- 90%i x  + 90%i x )\|2  \|3  + (- 90x  + 90x )\|2  )
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           6         3 3+-+2 +-+       6      3 3+-+2     %pi 10
+--R                   ((18%i x  - 18%i x )\|2  \|3  + (18x  - 18x )\|2  )cos(---)
+--R                                                                           18
+--R                 + 
+--R                           9         6 3+-+2 +-+       9      6 3+-+2     %pi 4
+--R                   ((90%i x  - 90%i x )\|2  \|3  + (90x  - 90x )\|2  )cos(---)
+--R                                                                           18
+--R                 + 
+--R                            12     9     6 3+-+2 +-+
+--R                       (- 6x   + 6x  - 6x )\|2  \|3
+--R                     + 
+--R                                12         9         6 3+-+2
+--R                       (- 18%i x   + 18%i x  - 18%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                      6        3 3+-+2 +-+      6     3 3+-+2     %pi 12
+--R               ((3%i x  - 3%i x )\|2  \|3  + (3x  - 3x )\|2  )cos(---)
+--R                                                                   18
+--R             + 
+--R                        9     6     3 3+-+2 +-+
+--R                   (- 2x  + 2x  - 2x )\|2  \|3
+--R                 + 
+--R                           9        6        3 3+-+2
+--R                   (- 6%i x  + 6%i x  - 6%i x )\|2
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        9        6 3+-+2 +-+        9     6 3+-+2     %pi 6
+--R               ((- 6%i x  + 6%i x )\|2  \|3  + (- 6x  + 6x )\|2  )cos(---)
+--R                                                                       18
+--R             + 
+--R                        12     9     6 3+-+2 +-+
+--R                     (2x   - 2x  + 2x )\|2  \|3
+--R                   + 
+--R                           12        9        6 3+-+2
+--R                     (6%i x   - 6%i x  + 6%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     12        9 3+-+2 +-+      12     9 3+-+2
+--R               (3%i x   - 3%i x )\|2  \|3  + (3x   - 3x )\|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   4           %pi 12       4           %pi 2    %pi 10
+--R               (12x  - 12x)sin(---)   + (72x  - 72x)cos(---) sin(---)
+--R                                18                       18       18
+--R             + 
+--R                       4            %pi 4       7      4        +-+    %pi
+--R                 ((180x  - 180x)cos(---)  + (24x  - 24x  + 24x)\|3 cos(---))
+--R                                     18                                 18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        4            %pi 6       7      4        +-+    %pi 3
+--R                   (240x  - 240x)cos(---)  + (64x  - 64x  + 64x)\|3 cos(---)
+--R                                      18                                 18
+--R                 + 
+--R                      7      4
+--R                   24x  - 24x
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        4            %pi 8       7      4        +-+    %pi 5
+--R                   (180x  - 180x)cos(---)  + (48x  - 48x  + 48x)\|3 cos(---)
+--R                                      18                                 18
+--R                 + 
+--R                          7       4     %pi 2
+--R                   (- 360x  + 360x )cos(---)
+--R                                         18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       4           %pi 10        7       4     %pi 4
+--R                   (72x  - 72x)cos(---)   + (360x  - 360x )cos(---)
+--R                                    18                          18
+--R                 + 
+--R                         10      7      4  +-+    %pi
+--R                   (- 24x   + 24x  - 24x )\|3 cos(---)
+--R                                                   18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   4           %pi 12        7     4       +-+    %pi 9
+--R               (12x  - 12x)cos(---)   + (- 8x  + 8x  - 8x)\|3 cos(---)
+--R                                18                                 18
+--R             + 
+--R                     7      4     %pi 6      10     7     4  +-+    %pi 3
+--R               (- 24x  + 24x )cos(---)  + (8x   - 8x  + 8x )\|3 cos(---)
+--R                                   18                                18
+--R             + 
+--R                  10      7
+--R               12x   - 12x
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R               5      2 3+-+    %pi 12       5      2 3+-+    %pi 2    %pi 10
+--R           (12x  - 12x )\|2 sin(---)   + (72x  - 72x )\|2 cos(---) sin(---)
+--R                                 18                            18       18
+--R         + 
+--R                      5       2 3+-+    %pi 4
+--R                 (180x  - 180x )\|2 cos(---)
+--R                                         18
+--R               + 
+--R                     8      5      2 3+-+ +-+    %pi
+--R                 (24x  - 24x  + 24x )\|2 \|3 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    5       2 3+-+    %pi 6
+--R               (240x  - 240x )\|2 cos(---)
+--R                                       18
+--R             + 
+--R                   8      5      2 3+-+ +-+    %pi 3       8      5 3+-+
+--R               (64x  - 64x  + 64x )\|2 \|3 cos(---)  + (24x  - 24x )\|2
+--R                                                18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    5       2 3+-+    %pi 8
+--R               (180x  - 180x )\|2 cos(---)
+--R                                       18
+--R             + 
+--R                   8      5      2 3+-+ +-+    %pi 5
+--R               (48x  - 48x  + 48x )\|2 \|3 cos(---)
+--R                                                18
+--R             + 
+--R                      8       5 3+-+    %pi 2
+--R               (- 360x  + 360x )\|2 cos(---)
+--R                                         18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   5      2 3+-+    %pi 10        8       5 3+-+    %pi 4
+--R               (72x  - 72x )\|2 cos(---)   + (360x  - 360x )\|2 cos(---)
+--R                                     18                              18
+--R             + 
+--R                     11      8      5 3+-+ +-+    %pi
+--R               (- 24x   + 24x  - 24x )\|2 \|3 cos(---)
+--R                                                   18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               5      2 3+-+    %pi 12        8     5     2 3+-+ +-+    %pi 9
+--R           (12x  - 12x )\|2 cos(---)   + (- 8x  + 8x  - 8x )\|2 \|3 cos(---)
+--R                                 18                                      18
+--R         + 
+--R                 8      5 3+-+    %pi 6      11     8     5 3+-+ +-+    %pi 3
+--R           (- 24x  + 24x )\|2 cos(---)  + (8x   - 8x  + 8x )\|2 \|3 cos(---)
+--R                                   18                                    18
+--R         + 
+--R               11      8 3+-+
+--R           (12x   - 12x )\|2
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  7        4  +-+     7     4     %pi 12
+--R           ((6%i x  - 6%i x )\|3  + 6x  - 6x )sin(---)
+--R                                                   18
+--R         + 
+--R                   7         4  +-+      7      4     %pi 2    %pi 10
+--R           ((36%i x  - 36%i x )\|3  + 36x  - 36x )cos(---) sin(---)
+--R                                                       18       18
+--R         + 
+--R                       7         4  +-+      7      4     %pi 4
+--R               ((90%i x  - 90%i x )\|3  + 90x  - 90x )cos(---)
+--R                                                           18
+--R             + 
+--R                  10      7      4  +-+         10         7         4     %pi
+--R             ((12x   - 12x  + 12x )\|3  + 36%i x   - 36%i x  + 36%i x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        7          4  +-+       7       4     %pi 6
+--R               ((120%i x  - 120%i x )\|3  + 120x  - 120x )cos(---)
+--R                                                               18
+--R             + 
+--R                      10      7      4  +-+         10         7         4
+--R                 ((32x   - 32x  + 32x )\|3  + 96%i x   - 96%i x  + 96%i x )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      10         7  +-+      10      7
+--R               (12%i x   - 12%i x )\|3  + 12x   - 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7         4  +-+      7      4     %pi 8
+--R               ((90%i x  - 90%i x )\|3  + 90x  - 90x )cos(---)
+--R                                                           18
+--R             + 
+--R                      10      7      4  +-+         10         7         4
+--R                 ((24x   - 24x  + 24x )\|3  + 72%i x   - 72%i x  + 72%i x )
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                          10          7  +-+       10       7     %pi 2
+--R               ((- 180%i x   + 180%i x )\|3  - 180x   + 180x )cos(---)
+--R                                                                   18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7         4  +-+      7      4     %pi 10
+--R               ((36%i x  - 36%i x )\|3  + 36x  - 36x )cos(---)
+--R                                                           18
+--R             + 
+--R                        10          7  +-+       10       7     %pi 4
+--R               ((180%i x   - 180%i x )\|3  + 180x   - 180x )cos(---)
+--R                                                                 18
+--R             + 
+--R                        13      10      7  +-+         13         10         7
+--R                 ((- 12x   + 12x   - 12x )\|3  - 36%i x   + 36%i x   - 36%i x )
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  7        4  +-+     7     4     %pi 12
+--R           ((6%i x  - 6%i x )\|3  + 6x  - 6x )cos(---)
+--R                                                   18
+--R         + 
+--R                 10     7     4  +-+         10         7         4     %pi 9
+--R           ((- 4x   + 4x  - 4x )\|3  - 12%i x   + 12%i x  - 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                     10         7  +-+      10      7     %pi 6
+--R           ((- 12%i x   + 12%i x )\|3  - 12x   + 12x )cos(---)
+--R                                                           18
+--R         + 
+--R               13     10     7  +-+         13         10         7     %pi 3
+--R           ((4x   - 4x   + 4x )\|3  + 12%i x   - 12%i x   + 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                 13        10  +-+     13     10
+--R           (6%i x   - 6%i x  )\|3  + 6x   - 6x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R               5      2 3+-+    %pi 12       5      2 3+-+    %pi 2    %pi 10
+--R           (12x  - 12x )\|2 sin(---)   + (72x  - 72x )\|2 cos(---) sin(---)
+--R                                 18                            18       18
+--R         + 
+--R                      5       2 3+-+    %pi 4
+--R                 (180x  - 180x )\|2 cos(---)
+--R                                         18
+--R               + 
+--R                     8      5      2 3+-+ +-+    %pi
+--R                 (24x  - 24x  + 24x )\|2 \|3 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    5       2 3+-+    %pi 6
+--R               (240x  - 240x )\|2 cos(---)
+--R                                       18
+--R             + 
+--R                   8      5      2 3+-+ +-+    %pi 3       8      5 3+-+
+--R               (64x  - 64x  + 64x )\|2 \|3 cos(---)  + (24x  - 24x )\|2
+--R                                                18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    5       2 3+-+    %pi 8
+--R               (180x  - 180x )\|2 cos(---)
+--R                                       18
+--R             + 
+--R                   8      5      2 3+-+ +-+    %pi 5
+--R               (48x  - 48x  + 48x )\|2 \|3 cos(---)
+--R                                                18
+--R             + 
+--R                      8       5 3+-+    %pi 2
+--R               (- 360x  + 360x )\|2 cos(---)
+--R                                         18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   5      2 3+-+    %pi 10        8       5 3+-+    %pi 4
+--R               (72x  - 72x )\|2 cos(---)   + (360x  - 360x )\|2 cos(---)
+--R                                     18                              18
+--R             + 
+--R                     11      8      5 3+-+ +-+    %pi
+--R               (- 24x   + 24x  - 24x )\|2 \|3 cos(---)
+--R                                                   18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               5      2 3+-+    %pi 12        8     5     2 3+-+ +-+    %pi 9
+--R           (12x  - 12x )\|2 cos(---)   + (- 8x  + 8x  - 8x )\|2 \|3 cos(---)
+--R                                 18                                      18
+--R         + 
+--R                 8      5 3+-+    %pi 6      11     8     5 3+-+ +-+    %pi 3
+--R           (- 24x  + 24x )\|2 cos(---)  + (8x   - 8x  + 8x )\|2 \|3 cos(---)
+--R                                   18                                    18
+--R         + 
+--R               11      8 3+-+
+--R           (12x   - 12x )\|2
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           6      3 3+-+2    %pi 12       6      3 3+-+2    %pi 2    %pi 10
+--R       (12x  - 12x )\|2  sin(---)   + (72x  - 72x )\|2  cos(---) sin(---)
+--R                              18                             18       18
+--R     + 
+--R               6       3 3+-+2    %pi 4       9      6      3 3+-+2 +-+    %pi
+--R         ((180x  - 180x )\|2  cos(---)  + (24x  - 24x  + 24x )\|2  \|3 cos(---))
+--R                                   18                                       18
+--R      *
+--R             %pi 8
+--R         sin(---)
+--R              18
+--R     + 
+--R                6       3 3+-+2    %pi 6
+--R           (240x  - 240x )\|2  cos(---)
+--R                                    18
+--R         + 
+--R               9      6      3 3+-+2 +-+    %pi 3       9      6 3+-+2
+--R           (64x  - 64x  + 64x )\|2  \|3 cos(---)  + (24x  - 24x )\|2
+--R                                             18
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R                6       3 3+-+2    %pi 8
+--R           (180x  - 180x )\|2  cos(---)
+--R                                    18
+--R         + 
+--R               9      6      3 3+-+2 +-+    %pi 5
+--R           (48x  - 48x  + 48x )\|2  \|3 cos(---)
+--R                                             18
+--R         + 
+--R                  9       6 3+-+2    %pi 2
+--R           (- 360x  + 360x )\|2  cos(---)
+--R                                      18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R               6      3 3+-+2    %pi 10        9       6 3+-+2    %pi 4
+--R           (72x  - 72x )\|2  cos(---)   + (360x  - 360x )\|2  cos(---)
+--R                                  18                               18
+--R         + 
+--R                 12      9      6 3+-+2 +-+    %pi
+--R           (- 24x   + 24x  - 24x )\|2  \|3 cos(---)
+--R                                                18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R           6      3 3+-+2    %pi 12        9     6     3 3+-+2 +-+    %pi 9
+--R       (12x  - 12x )\|2  cos(---)   + (- 8x  + 8x  - 8x )\|2  \|3 cos(---)
+--R                              18                                       18
+--R     + 
+--R             9      6 3+-+2    %pi 6      12     9     6 3+-+2 +-+    %pi 3
+--R       (- 24x  + 24x )\|2  cos(---)  + (8x   - 8x  + 8x )\|2  \|3 cos(---)
+--R                                18                                     18
+--R     + 
+--R           12      9 3+-+2
+--R       (12x   - 12x )\|2
+--R  /
+--R                  10     7     4 3+-+    %pi 12
+--R               (6x   - 6x  + 6x )\|2 sin(---)
+--R                                          18
+--R             + 
+--R                   10      7      4 3+-+    %pi 2    %pi 10
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                   10      7      4 3+-+    %pi 4    %pi 8
+--R               (90x   - 90x  + 90x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                        10       7       4 3+-+    %pi 6
+--R                   (120x   - 120x  + 120x )\|2 cos(---)
+--R                                                    18
+--R                 + 
+--R                       13      10      7 3+-+
+--R                   (12x   - 12x   + 12x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       10      7      4 3+-+    %pi 8
+--R                   (90x   - 90x  + 90x )\|2 cos(---)
+--R                                                 18
+--R                 + 
+--R                          13       10       7 3+-+    %pi 2
+--R                   (- 180x   + 180x   - 180x )\|2 cos(---)
+--R                                                       18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       10      7      4 3+-+    %pi 10
+--R                   (36x   - 36x  + 36x )\|2 cos(---)
+--R                                                 18
+--R                 + 
+--R                        13       10       7 3+-+    %pi 4
+--R                   (180x   - 180x   + 180x )\|2 cos(---)
+--R                                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                  10     7     4 3+-+    %pi 12
+--R               (6x   - 6x  + 6x )\|2 cos(---)
+--R                                          18
+--R             + 
+--R                     13      10      7 3+-+    %pi 6      16     13     10 3+-+
+--R               (- 12x   + 12x   - 12x )\|2 cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 12
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            8         5         2 3+-+2 +-+
+--R                   (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (18x  - 18x  + 18x )\|2
+--R              *
+--R                     %pi 2    %pi 10
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                            8         5         2 3+-+2 +-+
+--R                   (- 45%i x  + 45%i x  - 45%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (45x  - 45x  + 45x )\|2
+--R              *
+--R                     %pi 4    %pi 8
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 60%i x  + 60%i x  - 60%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (60x  - 60x  + 60x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           11        8        5 3+-+2 +-+
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R                 + 
+--R                      11     8     5 3+-+2
+--R                   (6x   - 6x  + 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 45%i x  + 45%i x  - 45%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (45x  - 45x  + 45x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (90%i x   - 90%i x  + 90%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 90x   + 90x  - 90x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (18x  - 18x  + 18x )\|2
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 90%i x   + 90%i x  - 90%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (90x   - 90x  + 90x )\|2
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 12
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         11        8        5 3+-+2 +-+
+--R                   (6%i x   - 6%i x  + 6%i x )\|2  \|3
+--R                 + 
+--R                        11     8     5 3+-+2
+--R                   (- 6x   + 6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     14        11        8 3+-+2 +-+      14     11     8 3+-+2
+--R             (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    9        6        3  +-+     9     6     3     %pi 12
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 2
+--R             ((- 36%i x  + 36%i x  - 36%i x )\|3  + 36x  - 36x  + 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 4
+--R             ((- 90%i x  + 90%i x  - 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                               9          6          3  +-+       9       6
+--R                     (- 120%i x  + 120%i x  - 120%i x )\|3  + 120x  - 120x
+--R                   + 
+--R                         3
+--R                     120x
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        12         9         6  +-+      12      9      6
+--R               (- 12%i x   + 12%i x  - 12%i x )\|3  + 12x   - 12x  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 90%i x  + 90%i x  - 90%i x )\|3  + 90x  - 90x  + 90x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                     (180%i x   - 180%i x  + 180%i x )\|3  - 180x   + 180x
+--R                   + 
+--R                           6
+--R                     - 180x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 36%i x  + 36%i x  - 36%i x )\|3  + 36x  - 36x  + 36x )
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                   (- 180%i x   + 180%i x  - 180%i x )\|3  + 180x   - 180x
+--R                 + 
+--R                       6
+--R                   180x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    9        6        3  +-+     9     6     3     %pi 12
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   12         9         6  +-+      12      9      6     %pi 6
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  - 12x   + 12x  - 12x )cos(---)
+--R                                                                          18
+--R         + 
+--R                   15        12        9  +-+     15     12     9
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 12
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          8         5         2 3+-+2 +-+
+--R                   (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (18x  - 18x  + 18x )\|2
+--R              *
+--R                     %pi 2    %pi 10
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                          8         5         2 3+-+2 +-+
+--R                   (45%i x  - 45%i x  + 45%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (45x  - 45x  + 45x )\|2
+--R              *
+--R                     %pi 4    %pi 8
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (60%i x  - 60%i x  + 60%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (60x  - 60x  + 60x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                       11        8        5 3+-+2 +-+      11     8     5 3+-+2
+--R                 (6%i x   - 6%i x  + 6%i x )\|2  \|3  + (6x   - 6x  + 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (45%i x  - 45%i x  + 45%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (45x  - 45x  + 45x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 90%i x   + 90%i x  - 90%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 90x   + 90x  - 90x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (18x  - 18x  + 18x )\|2
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (90%i x   - 90%i x  + 90%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (90x   - 90x  + 90x )\|2
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 12
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           11        8        5 3+-+2 +-+
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R                 + 
+--R                        11     8     5 3+-+2
+--R                   (- 6x   + 6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     14        11        8 3+-+2 +-+      14     11     8 3+-+2
+--R               (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   6      3          %pi 12
+--R               (12x  - 12x  + 12)sin(---)
+--R                                      18
+--R             + 
+--R                   6      3          %pi 2    %pi 10
+--R               (72x  - 72x  + 72)cos(---) sin(---)
+--R                                      18       18
+--R             + 
+--R                    6       3           %pi 4    %pi 8
+--R               (180x  - 180x  + 180)cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                     6       3           %pi 6      9      6      3     %pi 6
+--R               ((240x  - 240x  + 240)cos(---)  + 24x  - 24x  + 24x )sin(---)
+--R                                          18                             18
+--R             + 
+--R                        6       3           %pi 8
+--R                   (180x  - 180x  + 180)cos(---)
+--R                                             18
+--R                 + 
+--R                          9       6       3     %pi 2
+--R                   (- 360x  + 360x  - 360x )cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         6      3          %pi 10
+--R                     (72x  - 72x  + 72)cos(---)
+--R                                            18
+--R                   + 
+--R                          9       6       3     %pi 4
+--R                     (360x  - 360x  + 360x )cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   6      3          %pi 12         9      6      3     %pi 6
+--R               (12x  - 12x  + 12)cos(---)   + (- 24x  + 24x  - 24x )cos(---)
+--R                                      18                                 18
+--R             + 
+--R                  12      9      6
+--R               12x   - 12x  + 12x
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 sin(---)
+--R                                       18
+--R         + 
+--R               7      4       3+-+    %pi 2    %pi 10
+--R           (72x  - 72x  + 72x)\|2 cos(---) sin(---)
+--R                                       18       18
+--R         + 
+--R                7       4        3+-+    %pi 4    %pi 8
+--R           (180x  - 180x  + 180x)\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   7       4        3+-+    %pi 6       10      7      4 3+-+
+--R             ((240x  - 240x  + 240x)\|2 cos(---)  + (24x   - 24x  + 24x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7       4        3+-+    %pi 8
+--R               (180x  - 180x  + 180x)\|2 cos(---)
+--R                                              18
+--R             + 
+--R                      10       7       4 3+-+    %pi 2
+--R               (- 360x   + 360x  - 360x )\|2 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7      4       3+-+    %pi 10
+--R               (72x  - 72x  + 72x)\|2 cos(---)
+--R                                           18
+--R             + 
+--R                    10       7       4 3+-+    %pi 4
+--R               (360x   - 360x  + 360x )\|2 cos(---)
+--R                                                18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 cos(---)
+--R                                       18
+--R         + 
+--R                 10      7      4 3+-+    %pi 6       13      10      7 3+-+
+--R           (- 24x   + 24x  - 24x )\|2 cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                           18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9        6        3  +-+     9     6     3     %pi 12
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     9         6         3  +-+      9      6      3     %pi 2
+--R             ((36%i x  - 36%i x  + 36%i x )\|3  + 36x  - 36x  + 36x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     9         6         3  +-+      9      6      3     %pi 4
+--R             ((90%i x  - 90%i x  + 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          9          6          3  +-+       9       6       3
+--R                 ((120%i x  - 120%i x  + 120%i x )\|3  + 120x  - 120x  + 120x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      12         9         6  +-+      12      9      6
+--R               (12%i x   - 12%i x  + 12%i x )\|3  + 12x   - 12x  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 8
+--R               ((90%i x  - 90%i x  + 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                            18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                   (- 180%i x   + 180%i x  - 180%i x )\|3  - 180x   + 180x
+--R                 + 
+--R                         6
+--R                   - 180x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         9         6         3  +-+      9      6      3
+--R                 ((36%i x  - 36%i x  + 36%i x )\|3  + 36x  - 36x  + 36x )
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                     (180%i x   - 180%i x  + 180%i x )\|3  + 180x   - 180x
+--R                   + 
+--R                         6
+--R                     180x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  9        6        3  +-+     9     6     3     %pi 12
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                     12         9         6  +-+      12      9      6     %pi 6
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  - 12x   + 12x  - 12x )cos(---)
+--R                                                                            18
+--R         + 
+--R                 15        12        9  +-+     15     12     9
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 sin(---)
+--R                                       18
+--R         + 
+--R               7      4       3+-+    %pi 2    %pi 10
+--R           (72x  - 72x  + 72x)\|2 cos(---) sin(---)
+--R                                       18       18
+--R         + 
+--R                7       4        3+-+    %pi 4    %pi 8
+--R           (180x  - 180x  + 180x)\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   7       4        3+-+    %pi 6       10      7      4 3+-+
+--R             ((240x  - 240x  + 240x)\|2 cos(---)  + (24x   - 24x  + 24x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7       4        3+-+    %pi 8
+--R               (180x  - 180x  + 180x)\|2 cos(---)
+--R                                              18
+--R             + 
+--R                      10       7       4 3+-+    %pi 2
+--R               (- 360x   + 360x  - 360x )\|2 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7      4       3+-+    %pi 10
+--R               (72x  - 72x  + 72x)\|2 cos(---)
+--R                                           18
+--R             + 
+--R                    10       7       4 3+-+    %pi 4
+--R               (360x   - 360x  + 360x )\|2 cos(---)
+--R                                                18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 cos(---)
+--R                                       18
+--R         + 
+--R                 10      7      4 3+-+    %pi 6       13      10      7 3+-+
+--R           (- 24x   + 24x  - 24x )\|2 cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                           18
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           8      5      2 3+-+2    %pi 12
+--R       (12x  - 12x  + 12x )\|2  sin(---)
+--R                                     18
+--R     + 
+--R           8      5      2 3+-+2    %pi 2    %pi 10
+--R       (72x  - 72x  + 72x )\|2  cos(---) sin(---)
+--R                                     18       18
+--R     + 
+--R            8       5       2 3+-+2    %pi 4    %pi 8
+--R       (180x  - 180x  + 180x )\|2  cos(---) sin(---)
+--R                                        18       18
+--R     + 
+--R               8       5       2 3+-+2    %pi 6       11      8      5 3+-+2
+--R         ((240x  - 240x  + 240x )\|2  cos(---)  + (24x   - 24x  + 24x )\|2  )
+--R                                           18
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R                8       5       2 3+-+2    %pi 8
+--R           (180x  - 180x  + 180x )\|2  cos(---)
+--R                                            18
+--R         + 
+--R                  11       8       5 3+-+2    %pi 2
+--R           (- 360x   + 360x  - 360x )\|2  cos(---)
+--R                                               18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R               8      5      2 3+-+2    %pi 10
+--R           (72x  - 72x  + 72x )\|2  cos(---)
+--R                                         18
+--R         + 
+--R                11       8       5 3+-+2    %pi 4
+--R           (360x   - 360x  + 360x )\|2  cos(---)
+--R                                             18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R           8      5      2 3+-+2    %pi 12
+--R       (12x  - 12x  + 12x )\|2  cos(---)
+--R                                     18
+--R     + 
+--R             11      8      5 3+-+2    %pi 6       14      11      8 3+-+2
+--R       (- 24x   + 24x  - 24x )\|2  cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                        18
+--R                                           Type: Expression(Complex(Integer))
+--E 81
+
+)clear all
+
+--S 82 of 649
+t0:=(1-x^3)/(1-x^3+x^6)
+--R 
+--R
+--R             3
+--R          - x  + 1
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 82
+
+--S 83 of 649
+r0:=-1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-_
+   %i*sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1-%i*_
+   sqrt(3))^(2/3))-1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*(3-%i*_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))+1/18*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/_
+   (2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/9*log(-2^(1/3)*x+(1+%i*_
+   sqrt(3))^(1/3))*(3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))+_
+   1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*_
+   sqrt(3))^(2/3))*(3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))+_
+   1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i+sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))
+--R 
+--R
+--R   (2)
+--R                      +------------+2
+--R             +-+     3|     +-+
+--R         (%i\|3  + 3)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +------------+2     +----------+
+--R              +-+     3|     +-+          3|   +-+         3+-+
+--R       (- 2%i\|3  - 6)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                        +----------+2
+--R               +-+     3|   +-+
+--R         (- %i\|3  + 3)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+2     +------------+
+--R            +-+     3|   +-+          3|     +-+         3+-+
+--R       (2%i\|3  - 6)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                              +------------+
+--R                     +----------+2     3+-+2 3|     +-+
+--R          +-+       3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (6\|3  - 6%i)\|%i\|3  + 1  atan(-------------------------)
+--R                                                  +------------+
+--R                                        3+-+2 +-+3|     +-+
+--R                                        \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                +----------+
+--R                     +------------+2     3+-+2 3|   +-+
+--R          +-+       3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (6\|3  + 6%i)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                    +----------+
+--R                                          3+-+2 +-+3|   +-+
+--R                                          \|2  \|3 \|%i\|3  + 1
+--R  /
+--R            +------------+2  +----------+2
+--R       3+-+3|     +-+       3|   +-+
+--R     18\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 83
+
+--S 84 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     1
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                              1
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            3
+--R     + 
+--R                         1                 1
+--R                  atan(----)        atan(----)
+--R                        +-+               +-+
+--R           +-+         \|3               \|3
+--R         (\|3 sin(----------) - cos(----------))
+--R                       3                 3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  + x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                                1
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              3
+--R     + 
+--R                           1                 1
+--R                    atan(----)        atan(----)
+--R                          +-+               +-+
+--R             +-+         \|3               \|3
+--R         (- \|3 sin(----------) - cos(----------))
+--R                         3                 3
+--R      *
+--R                        1   2                 1                 1   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                      3                     3                 3
+--R     + 
+--R                        1                      1
+--R                 atan(----)             atan(----)
+--R                       +-+                    +-+
+--R                      \|3        +-+         \|3
+--R         (- 2sin(----------) - 2\|3 cos(----------))
+--R                      3                      3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) + cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) - \|3 cos(----------) + 2x
+--R                       3                     3
+--R     + 
+--R                                                1                 1
+--R                                         atan(----)        atan(----)
+--R                     1                         +-+               +-+
+--R              atan(----)          +-+         \|3               \|3
+--R                    +-+          \|3 sin(----------) - cos(----------)
+--R                   \|3                        3                 3
+--R       - 4sin(----------)atan(------------------------------------------)
+--R                   3                     1                     1
+--R                                  atan(----)            atan(----)
+--R                                        +-+                   +-+
+--R                                       \|3       +-+         \|3
+--R                              sin(----------) + \|3 cos(----------) + 2x
+--R                                       3                     3
+--R     + 
+--R                                                                    1
+--R                                                             atan(----)
+--R                      1                      1                     +-+
+--R               atan(----)             atan(----)                  \|3
+--R                     +-+                    +-+          cos(----------)
+--R                    \|3        +-+         \|3                    3
+--R       (- 2sin(----------) + 2\|3 cos(----------))atan(-------------------)
+--R                    3                      3                      1
+--R                                                           atan(----)
+--R                                                                 +-+
+--R                                                                \|3
+--R                                                       sin(----------) - x
+--R                                                                3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 84
+
+--S 85 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +------------+2
+--R             +-+      3|     +-+
+--R         (- \|3  - %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +------------+2     +----------+
+--R          +-+       3|     +-+          3|   +-+         3+-+
+--R       (2\|3  + 2%i)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                       +----------+2
+--R             +-+      3|   +-+
+--R         (- \|3  + %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+2     +------------+
+--R          +-+       3|   +-+          3|     +-+         3+-+
+--R       (2\|3  - 2%i)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                       +------------+2  +----------+2
+--R          3+-+    %pi 3|     +-+       3|   +-+
+--R         2\|2 cos(---)\|- %i\|3  + 1   \|%i\|3  + 1
+--R                   18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  + x sin(---) + cos(---)  + x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                                           +------------+2  +----------+2
+--R          3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (\|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                       18             18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  + x sin(---) + cos(---)  - x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                                             +------------+2  +----------+2
+--R            3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (- \|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                         18             18
+--R      *
+--R                 %pi 2          %pi        %pi 2    2
+--R         log(sin(---)  - 2x sin(---) + cos(---)  + x )
+--R                  18             18         18
+--R     + 
+--R                                               +------------+2  +----------+2
+--R             3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (- 2\|2 sin(---) - 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18                  18
+--R      *
+--R                  +-+    %pi        %pi
+--R                 \|3 sin(---) + cos(---)
+--R                          18         18
+--R         atan(----------------------------)
+--R                  %pi     +-+    %pi
+--R              sin(---) - \|3 cos(---) + 2x
+--R                   18             18
+--R     + 
+--R       -
+--R                          +------------+2  +----------+2
+--R             3+-+    %pi 3|     +-+       3|   +-+
+--R            4\|2 sin(---)\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18
+--R         *
+--R                     +-+    %pi        %pi
+--R                    \|3 sin(---) - cos(---)
+--R                             18         18
+--R            atan(----------------------------)
+--R                     %pi     +-+    %pi
+--R                 sin(---) + \|3 cos(---) + 2x
+--R                      18             18
+--R     + 
+--R                                              +------------+
+--R                     +----------+2     3+-+2 3|     +-+
+--R            +-+     3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (2%i\|3  - 6)\|%i\|3  + 1  atan(-------------------------)
+--R                                                  +------------+
+--R                                        3+-+2 +-+3|     +-+
+--R                                        \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                  +----------+
+--R                       +------------+2     3+-+2 3|   +-+
+--R              +-+     3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (- 2%i\|3  - 6)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                      +----------+
+--R                                            3+-+2 +-+3|   +-+
+--R                                            \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                               +------------+2  +----------+2
+--R             3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (- 2\|2 sin(---) + 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18                  18
+--R      *
+--R                    %pi
+--R                cos(---)
+--R                     18
+--R         atan(------------)
+--R                  %pi
+--R              sin(---) - x
+--R                   18
+--R  /
+--R               +------------+2  +----------+2
+--R      3+-+ +-+3|     +-+       3|   +-+
+--R     6\|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 85
+
+--S 86 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 8    %pi 6      8    %pi 2    %pi 4
+--R               6x sin(---)  + 18x cos(---) sin(---)
+--R                       18              18       18
+--R             + 
+--R                    11     8     5     %pi 3
+--R               (- 6x   - 6x  + 6x )sin(---)
+--R                                        18
+--R             + 
+--R                   8    %pi 4        11     8     5  +-+    %pi      %pi 2
+--R               (18x cos(---)  + (- 6x   + 6x  - 6x )\|3 cos(---))sin(---)
+--R                         18                                  18       18
+--R             + 
+--R                   11      8      5     %pi 2    %pi      8    %pi 6
+--R               (18x   + 18x  - 18x )cos(---) sin(---) + 6x cos(---)
+--R                                         18       18            18
+--R             + 
+--R                  11     8     5  +-+    %pi 3     11     8
+--R               (2x   - 2x  + 2x )\|3 cos(---)  + 6x   - 6x
+--R                                          18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 9 3+-+    %pi 6     9 3+-+    %pi 2    %pi 4
+--R               6x  \|2 sin(---) + 18x  \|2 cos(---) sin(---)
+--R                            18                  18       18
+--R             + 
+--R                    12     9     6 3+-+    %pi 3
+--R               (- 6x   - 6x  + 6x )\|2 sin(---)
+--R                                            18
+--R             + 
+--R                     9 3+-+    %pi 4       12     9     6 3+-+ +-+    %pi
+--R                 (18x  \|2 cos(---) + (- 6x   + 6x  - 6x )\|2 \|3 cos(---))
+--R                                18                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi      9 3+-+    %pi 6
+--R               (18x   + 18x  - 18x )\|2 cos(---) sin(---) + 6x  \|2 cos(---)
+--R                                             18       18                 18
+--R             + 
+--R                  12     9     6 3+-+ +-+    %pi 3      12     9 3+-+
+--R               (2x   - 2x  + 2x )\|2 \|3 cos(---)  + (6x   - 6x )\|2
+--R                                              18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 + 3x  \|2 )sin(---)
+--R                                              18
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 2    %pi 4
+--R           (- 9%i x  \|2  \|3 + 9x  \|2 )cos(---) sin(---)
+--R                                              18       18
+--R         + 
+--R                    10        7        4 3+-+2 +-+        10     7     4 3+-+2
+--R             ((3%i x   + 3%i x  - 3%i x )\|2  \|3  + (- 3x   - 3x  + 3x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7 3+-+2 +-+    7 3+-+2    %pi 4
+--R               (- 9%i x  \|2  \|3 + 9x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                        10     7     4 3+-+2 +-+
+--R                   (- 3x   + 3x  - 3x )\|2  \|3
+--R                 + 
+--R                         10        7        4 3+-+2
+--R                   (9%i x   - 9%i x  + 9%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      10        7        4 3+-+2 +-+      10     7     4 3+-+2
+--R             ((- 9%i x   - 9%i x  + 9%i x )\|2  \|3  + (9x   + 9x  - 9x )\|2  )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 + 3x  \|2 )cos(---)
+--R                                              18
+--R         + 
+--R                10    7    4 3+-+2 +-+           10        7        4 3+-+2
+--R             ((x   - x  + x )\|2  \|3  + (- 3%i x   + 3%i x  - 3%i x )\|2  )
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   10        7 3+-+2 +-+      10     7 3+-+2
+--R           (- 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 9 3+-+    %pi 6     9 3+-+    %pi 2    %pi 4
+--R               6x  \|2 sin(---) + 18x  \|2 cos(---) sin(---)
+--R                            18                  18       18
+--R             + 
+--R                    12     9     6 3+-+    %pi 3
+--R               (- 6x   - 6x  + 6x )\|2 sin(---)
+--R                                            18
+--R             + 
+--R                     9 3+-+    %pi 4       12     9     6 3+-+ +-+    %pi
+--R                 (18x  \|2 cos(---) + (- 6x   + 6x  - 6x )\|2 \|3 cos(---))
+--R                                18                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi      9 3+-+    %pi 6
+--R               (18x   + 18x  - 18x )\|2 cos(---) sin(---) + 6x  \|2 cos(---)
+--R                                             18       18                 18
+--R             + 
+--R                  12     9     6 3+-+ +-+    %pi 3      12     9 3+-+
+--R               (2x   - 2x  + 2x )\|2 \|3 cos(---)  + (6x   - 6x )\|2
+--R                                              18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 10 3+-+2    %pi 6     10 3+-+2    %pi 2    %pi 4
+--R               6x   \|2  sin(---) + 18x   \|2  cos(---) sin(---)
+--R                              18                    18       18
+--R             + 
+--R                    13     10     7 3+-+2    %pi 3
+--R               (- 6x   - 6x   + 6x )\|2  sin(---)
+--R                                              18
+--R             + 
+--R                     10 3+-+2    %pi 4       13     10     7 3+-+2 +-+    %pi
+--R                 (18x   \|2  cos(---) + (- 6x   + 6x   - 6x )\|2  \|3 cos(---))
+--R                                  18                                       18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   13      10      7 3+-+2    %pi 2    %pi      10 3+-+2    %pi 6
+--R               (18x   + 18x   - 18x )\|2  cos(---) sin(---) + 6x   \|2  cos(---)
+--R                                               18       18                   18
+--R             + 
+--R                  13     10     7 3+-+2 +-+    %pi 3      13     10 3+-+2
+--R               (2x   - 2x   + 2x )\|2  \|3 cos(---)  + (6x   - 6x  )\|2
+--R                                                18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   8 +-+     8     %pi 6
+--R           (- 6%i x \|3  + 6x )sin(---)
+--R                                    18
+--R         + 
+--R                    8 +-+      8     %pi 2    %pi 4
+--R           (- 18%i x \|3  + 18x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                  11        8        5  +-+     11     8     5     %pi 3
+--R           ((6%i x   + 6%i x  - 6%i x )\|3  - 6x   - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                        8 +-+      8     %pi 4
+--R               (- 18%i x \|3  + 18x )cos(---)
+--R                                          18
+--R             + 
+--R                   11     8     5  +-+         11         8         5     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  + 18%i x   - 18%i x  + 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       11         8         5  +-+      11      8      5
+--R             ((- 18%i x   - 18%i x  + 18%i x )\|3  + 18x   + 18x  - 18x )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                   8 +-+     8     %pi 6
+--R           (- 6%i x \|3  + 6x )cos(---)
+--R                                    18
+--R         + 
+--R               11     8     5  +-+        11        8        5     %pi 3
+--R           ((2x   - 2x  + 2x )\|3  - 6%i x   + 6%i x  - 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   11        8  +-+     11     8
+--R           (- 6%i x   + 6%i x )\|3  + 6x   - 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 + 3x  \|2 )sin(---)
+--R                                            18
+--R         + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 2    %pi 4
+--R           (9%i x  \|2  \|3 + 9x  \|2 )cos(---) sin(---)
+--R                                            18       18
+--R         + 
+--R                         10        7        4 3+-+2 +-+
+--R                 (- 3%i x   - 3%i x  + 3%i x )\|2  \|3
+--R               + 
+--R                      10     7     4 3+-+2
+--R                 (- 3x   - 3x  + 3x )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     7 3+-+2 +-+    7 3+-+2    %pi 4
+--R               (9%i x  \|2  \|3 + 9x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                        10     7     4 3+-+2 +-+
+--R                   (- 3x   + 3x  - 3x )\|2  \|3
+--R                 + 
+--R                           10        7        4 3+-+2
+--R                   (- 9%i x   + 9%i x  - 9%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    10        7        4 3+-+2 +-+      10     7     4 3+-+2
+--R             ((9%i x   + 9%i x  - 9%i x )\|2  \|3  + (9x   + 9x  - 9x )\|2  )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 + 3x  \|2 )cos(---)
+--R                                            18
+--R         + 
+--R                10    7    4 3+-+2 +-+         10        7        4 3+-+2
+--R             ((x   - x  + x )\|2  \|3  + (3%i x   - 3%i x  + 3%i x )\|2  )
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                 10        7 3+-+2 +-+      10     7 3+-+2
+--R           (3%i x   - 3%i x )\|2  \|3  + (3x   - 3x )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                 8 +-+     8     %pi 6          8 +-+      8     %pi 2    %pi 4
+--R           (6%i x \|3  + 6x )sin(---)  + (18%i x \|3  + 18x )cos(---) sin(---)
+--R                                  18                              18       18
+--R         + 
+--R                    11        8        5  +-+     11     8     5     %pi 3
+--R           ((- 6%i x   - 6%i x  + 6%i x )\|3  - 6x   - 6x  + 6x )sin(---)
+--R                                                                      18
+--R         + 
+--R                      8 +-+      8     %pi 4
+--R               (18%i x \|3  + 18x )cos(---)
+--R                                        18
+--R             + 
+--R                   11     8     5  +-+         11         8         5     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  - 18%i x   + 18%i x  - 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 2
+--R             ((18%i x   + 18%i x  - 18%i x )\|3  + 18x   + 18x  - 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 8 +-+     8     %pi 6
+--R           (6%i x \|3  + 6x )cos(---)
+--R                                  18
+--R         + 
+--R               11     8     5  +-+        11        8        5     %pi 3
+--R           ((2x   - 2x  + 2x )\|3  + 6%i x   - 6%i x  + 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                 11        8  +-+     11     8
+--R           (6%i x   - 6%i x )\|3  + 6x   - 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R          6 3+-+    %pi 6     6 3+-+    %pi 2    %pi 4
+--R       12x  \|2 sin(---) + 36x  \|2 cos(---) sin(---)
+--R                     18                  18       18
+--R     + 
+--R             9      6      3 3+-+    %pi 3
+--R       (- 12x  - 12x  + 12x )\|2 sin(---)
+--R                                      18
+--R     + 
+--R           6 3+-+    %pi 4        9      6      3 3+-+ +-+    %pi      %pi 2
+--R       (36x  \|2 cos(---) + (- 12x  + 12x  - 12x )\|2 \|3 cos(---))sin(---)
+--R                      18                                       18       18
+--R     + 
+--R           9      6      3 3+-+    %pi 2    %pi       6 3+-+    %pi 6
+--R       (36x  + 36x  - 36x )\|2 cos(---) sin(---) + 12x  \|2 cos(---)
+--R                                    18       18                  18
+--R     + 
+--R          9     6     3 3+-+ +-+    %pi 3       9      6 3+-+
+--R       (4x  - 4x  + 4x )\|2 \|3 cos(---)  + (12x  - 12x )\|2
+--R                                     18
+--R  /
+--R                  8     5     2     %pi 6
+--R               (6x  - 6x  + 6x )sin(---)
+--R                                     18
+--R             + 
+--R                   8      5      2     %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                     11      8      5     %pi 3
+--R               (- 12x   + 12x  - 12x )sin(---)
+--R                                           18
+--R             + 
+--R                   8      5      2     %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                   11      8      5     %pi 2    %pi
+--R               (36x   - 36x  + 36x )cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                  8     5     2     %pi 6     14     11     8
+--R               (6x  - 6x  + 6x )cos(---)  + 6x   - 6x   + 6x
+--R                                     18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 3
+--R               (- 12x   + 12x  - 12x )\|2 sin(---)
+--R                                               18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                    10        7        4 3+-+2 +-+        10     7     4 3+-+2
+--R             ((6%i x   - 6%i x  + 6%i x )\|2  \|3  + (- 6x   + 6x  - 6x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                        10         7         4 3+-+2 +-+
+--R               (- 18%i x   + 18%i x  - 18%i x )\|2  \|3
+--R             + 
+--R                   10      7      4 3+-+2
+--R               (18x   - 18x  + 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 3
+--R               (- 12x   + 12x  - 12x )\|2 sin(---)
+--R                                               18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 2    %pi
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  10     7     4 3+-+2    %pi 6
+--R               (6x   - 6x  + 6x )\|2  sin(---)
+--R                                           18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 2    %pi 4
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                     13      10      7 3+-+2    %pi 3
+--R               (- 12x   + 12x   - 12x )\|2  sin(---)
+--R                                                 18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 4    %pi 2
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                   13      10      7 3+-+2    %pi 2    %pi
+--R               (36x   - 36x   + 36x )\|2  cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                  10     7     4 3+-+2    %pi 6      16     13     10 3+-+2
+--R               (6x   - 6x  + 6x )\|2  cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                           18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 2
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   11         8         5  +-+      11      8      5     %pi 3
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  - 12x   + 12x  - 12x )sin(---)
+--R                                                                          18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 4
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       11         8         5  +-+      11      8      5
+--R             ((- 36%i x   + 36%i x  - 36%i x )\|3  + 36x   - 36x  + 36x )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   14        11        8  +-+     14     11     8
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )sin(---)
+--R                                                                            18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                         10        7        4 3+-+2 +-+
+--R                 (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R               + 
+--R                      10     7     4 3+-+2
+--R                 (- 6x   + 6x  - 6x )\|2
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      10         7         4 3+-+2 +-+
+--R               (18%i x   - 18%i x  + 18%i x )\|2  \|3
+--R             + 
+--R                   10      7      4 3+-+2
+--R               (18x   - 18x  + 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )cos(---)
+--R                                                                            18
+--R         + 
+--R                 13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 2
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 3
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  - 12x   + 12x  - 12x )sin(---)
+--R                                                                            18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 4
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 2
+--R             ((36%i x   - 36%i x  + 36%i x )\|3  + 36x   - 36x  + 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                 14        11        8  +-+     14     11     8
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           6      3      3+-+    %pi 6
+--R       (12x  - 12x  + 12)\|2 sin(---)
+--R                                  18
+--R     + 
+--R           6      3      3+-+    %pi 2    %pi 4
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R             9      6      3 3+-+    %pi 3
+--R       (- 24x  + 24x  - 24x )\|2 sin(---)
+--R                                      18
+--R     + 
+--R           6      3      3+-+    %pi 4    %pi 2
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R           9      6      3 3+-+    %pi 2    %pi
+--R       (72x  - 72x  + 72x )\|2 cos(---) sin(---)
+--R                                    18       18
+--R     + 
+--R           6      3      3+-+    %pi 6       12      9      6 3+-+
+--R       (12x  - 12x  + 12)\|2 cos(---)  + (12x   - 12x  + 12x )\|2
+--R                                  18
+--R                                           Type: Expression(Complex(Integer))
+--E 86
+
+)clear all
+
+--S 87 of 649
+t0:=(1-x^3)/(x*(1-x^3+x^6))
+--R 
+--R
+--R             3
+--R          - x  + 1
+--R   (1)  -----------
+--R         7    4
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 87
+
+--S 88 of 649
+r0:=log(x)-1/6*log(1-x^3+x^6)+1/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                        3      +-+
+--R           +-+     6    3          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 6\|3 log(x) - 2atan(-------------)
+--R                                                           3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   6\|3
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        3      +-+
+--R           +-+     6    3          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 6\|3 log(x) - 2atan(-------------)
+--R                                                           3
+--R   (3)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 89
+
+--S 90 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+--S 91 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 91
+
+)clear all
+
+--S 92 of 649
+t0:=(1-x^3)/(x^2*(1-x^3+x^6))
+--R 
+--R
+--R             3
+--R          - x  + 1
+--R   (1)  ------------
+--R         8    5    2
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 92
+
+--S 93 of 649
+r0:=(-1)/x+1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+(1-%i*_
+   sqrt(3))^(1/3))*(3+%i*sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))+_
+   1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*_
+   sqrt(3))^(2/3))*(3+%i*sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))-_
+   1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i+sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))
+--R 
+--R
+--R   (2)
+--R                           +------------+
+--R                 +-+      3|     +-+
+--R         (- %i x\|3  + 3x)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                        +------------+     +----------+
+--R              +-+      3|     +-+         3|   +-+         3+-+
+--R       (2%i x\|3  - 6x)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                         +----------+
+--R               +-+      3|   +-+
+--R         (%i x\|3  + 3x)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                          +----------+     +------------+
+--R                +-+      3|   +-+         3|     +-+         3+-+
+--R       (- 2%i x\|3  - 6x)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                  +------------+
+--R                          +----------+     3+-+2 3|     +-+
+--R             +-+         3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (- 6x\|3  - 6%i x)\|%i\|3  + 1 atan(-------------------------)
+--R                                                      +------------+
+--R                                            3+-+2 +-+3|     +-+
+--R                                            \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                    +----------+
+--R                          +------------+     3+-+2 3|   +-+
+--R             +-+         3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (- 6x\|3  + 6%i x)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                        +----------+
+--R                                              3+-+2 +-+3|   +-+
+--R                                              \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                  +------------+ +----------+
+--R           3+-+2 3|     +-+     3|   +-+
+--R       - 18\|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R  /
+--R                +------------+ +----------+
+--R         3+-+2 3|     +-+     3|   +-+
+--R     18x \|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 93
+
+--S 94 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                            1                   1
+--R                     atan(----)          atan(----)
+--R                           +-+                 +-+
+--R              +-+         \|3                 \|3
+--R         (- x\|3 sin(----------) - x cos(----------))
+--R                          3                   3
+--R      *
+--R         log
+--R                         1   4                1   2                 1   2
+--R                  atan(----)           atan(----)            atan(----)
+--R                        +-+                  +-+                   +-+
+--R                       \|3                  \|3                   \|3
+--R              sin(----------)  + (2cos(----------)  + 2x)sin(----------)
+--R                       3                    3                     3
+--R            + 
+--R                         1   4                 1   2
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3                   \|3        2
+--R              cos(----------)  - 2x cos(----------)  + x
+--R                       3                     3
+--R     + 
+--R                       1
+--R                atan(----)
+--R                      +-+
+--R                     \|3
+--R         2x cos(----------)
+--R                     3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                               1              1                 1   4
+--R                        atan(----)     atan(----)        atan(----)
+--R                              +-+            +-+               +-+
+--R                 +-+         \|3            \|3               \|3
+--R              2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                             3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                          1                   1
+--R                   atan(----)          atan(----)
+--R                         +-+                 +-+
+--R            +-+         \|3                 \|3
+--R         (x\|3 sin(----------) - x cos(----------))
+--R                        3                   3
+--R      *
+--R         log
+--R                         1   4                1   2                1   2
+--R                  atan(----)           atan(----)           atan(----)
+--R                        +-+                  +-+                  +-+
+--R                       \|3                  \|3                  \|3
+--R              sin(----------)  + (2cos(----------)  - x)sin(----------)
+--R                       3                    3                    3
+--R            + 
+--R                                 1              1                 1   4
+--R                          atan(----)     atan(----)        atan(----)
+--R                                +-+            +-+               +-+
+--R                   +-+         \|3            \|3               \|3
+--R              - 2x\|3 cos(----------)sin(----------) + cos(----------)
+--R                               3              3                 3
+--R            + 
+--R                           1   2
+--R                    atan(----)
+--R                          +-+
+--R                         \|3        2
+--R              x cos(----------)  + x
+--R                         3
+--R     + 
+--R                       1
+--R                atan(----)
+--R                      +-+
+--R                     \|3
+--R         4x sin(----------)
+--R                     3
+--R      *
+--R         atan
+--R                            1   2                   1              1
+--R                     atan(----)              atan(----)     atan(----)
+--R                           +-+                     +-+            +-+
+--R                          \|3         +-+         \|3            \|3
+--R                3sin(----------)  + 2\|3 cos(----------)sin(----------)
+--R                          3                       3              3
+--R              + 
+--R                              1   2
+--R                       atan(----)
+--R                             +-+
+--R                            \|3
+--R                - 3cos(----------)
+--R                            3
+--R           /
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  - 6cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3          +-+
+--R                - \|3 cos(----------)  - 2x\|3
+--R                               3
+--R     + 
+--R                        1                       1
+--R                 atan(----)              atan(----)
+--R                       +-+                     +-+
+--R                      \|3         +-+         \|3
+--R         (2x sin(----------) + 2x\|3 cos(----------))
+--R                      3                       3
+--R      *
+--R         atan
+--R                            1   2                   1              1
+--R                     atan(----)              atan(----)     atan(----)
+--R                           +-+                     +-+            +-+
+--R                          \|3         +-+         \|3            \|3
+--R                3sin(----------)  - 2\|3 cos(----------)sin(----------)
+--R                          3                       3              3
+--R              + 
+--R                              1   2
+--R                       atan(----)
+--R                             +-+
+--R                            \|3
+--R                - 3cos(----------)
+--R                            3
+--R           /
+--R                               1   2               1              1
+--R                        atan(----)          atan(----)     atan(----)
+--R                              +-+                 +-+            +-+
+--R                 +-+         \|3                 \|3            \|3
+--R                \|3 sin(----------)  + 6cos(----------)sin(----------)
+--R                             3                   3              3
+--R              + 
+--R                                 1   2
+--R                          atan(----)
+--R                                +-+
+--R                   +-+         \|3          +-+
+--R                - \|3 cos(----------)  - 2x\|3
+--R                               3
+--R     + 
+--R                          1                       1
+--R                   atan(----)              atan(----)
+--R                         +-+                     +-+
+--R                        \|3         +-+         \|3
+--R         (- 2x sin(----------) + 2x\|3 cos(----------))
+--R                        3                       3
+--R      *
+--R                              1              1
+--R                       atan(----)     atan(----)
+--R                             +-+            +-+
+--R                            \|3            \|3
+--R                  2cos(----------)sin(----------)
+--R                            3              3
+--R         atan(---------------------------------------)
+--R                         1   2              1   2
+--R                  atan(----)         atan(----)
+--R                        +-+                +-+
+--R                       \|3                \|3
+--R              sin(----------)  - cos(----------)  + x
+--R                       3                  3
+--R     + 
+--R           +-+
+--R       - 6\|3
+--R  /
+--R        +-+
+--R     6x\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 94
+
+--S 95 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +------------+
+--R             +-+      3|     +-+
+--R         (- \|3  + %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +------------+     +----------+
+--R          +-+       3|     +-+         3|   +-+         3+-+
+--R       (2\|3  - 2%i)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                       +----------+
+--R             +-+      3|   +-+
+--R         (- \|3  - %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+     +------------+
+--R          +-+       3|   +-+         3|     +-+         3+-+
+--R       (2\|3  + 2%i)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                               +------------+ +----------+
+--R            3+-+2 +-+    %pi    3+-+2    %pi  3|     +-+     3|   +-+
+--R         (- \|2  \|3 sin(---) - \|2  cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                          18              18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2          %pi 2       %pi 4          %pi 2
+--R              sin(---)  + (2cos(---)  + 2x)sin(---)  + cos(---)  - 2x cos(---)
+--R                   18            18             18          18             18
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R                        +------------+ +----------+
+--R          3+-+2    %pi 3|     +-+     3|   +-+
+--R         2\|2  cos(---)\|- %i\|3  + 1 \|%i\|3  + 1
+--R                    18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2         %pi 2      +-+    %pi     %pi
+--R              sin(---)  + (2cos(---)  - x)sin(---)  + 2x\|3 cos(---)sin(---)
+--R                   18            18            18                18      18
+--R            + 
+--R                  %pi 4         %pi 2    2
+--R              cos(---)  + x cos(---)  + x
+--R                   18            18
+--R     + 
+--R                                             +------------+ +----------+
+--R          3+-+2 +-+    %pi    3+-+2    %pi  3|     +-+     3|   +-+
+--R         (\|2  \|3 sin(---) - \|2  cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                        18              18
+--R      *
+--R         log
+--R                  %pi 4         %pi 2         %pi 2      +-+    %pi     %pi
+--R              sin(---)  + (2cos(---)  - x)sin(---)  - 2x\|3 cos(---)sin(---)
+--R                   18            18            18                18      18
+--R            + 
+--R                  %pi 4         %pi 2    2
+--R              cos(---)  + x cos(---)  + x
+--R                   18            18
+--R     + 
+--R                        +------------+ +----------+
+--R          3+-+2    %pi 3|     +-+     3|   +-+
+--R         4\|2  sin(---)\|- %i\|3  + 1 \|%i\|3  + 1
+--R                    18
+--R      *
+--R                         %pi 2     +-+    %pi     %pi         %pi 2
+--R                    3sin(---)  + 2\|3 cos(---)sin(---) - 3cos(---)
+--R                          18               18      18          18
+--R         atan(----------------------------------------------------------)
+--R               +-+    %pi 2        %pi     %pi     +-+    %pi 2      +-+
+--R              \|3 sin(---)  - 6cos(---)sin(---) - \|3 cos(---)  - 2x\|3
+--R                       18           18      18             18
+--R     + 
+--R                                               +------------+ +----------+
+--R           3+-+2    %pi     3+-+2 +-+    %pi  3|     +-+     3|   +-+
+--R         (2\|2  sin(---) + 2\|2  \|3 cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                     18                   18
+--R      *
+--R                         %pi 2     +-+    %pi     %pi         %pi 2
+--R                    3sin(---)  - 2\|3 cos(---)sin(---) - 3cos(---)
+--R                          18               18      18          18
+--R         atan(----------------------------------------------------------)
+--R               +-+    %pi 2        %pi     %pi     +-+    %pi 2      +-+
+--R              \|3 sin(---)  + 6cos(---)sin(---) - \|3 cos(---)  - 2x\|3
+--R                       18           18      18             18
+--R     + 
+--R                                             +------------+
+--R                     +----------+     3+-+2 3|     +-+
+--R            +-+     3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (2%i\|3  + 6)\|%i\|3  + 1 atan(-------------------------)
+--R                                                 +------------+
+--R                                       3+-+2 +-+3|     +-+
+--R                                       \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                 +----------+
+--R                       +------------+     3+-+2 3|   +-+
+--R              +-+     3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (- 2%i\|3  + 6)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                     +----------+
+--R                                           3+-+2 +-+3|   +-+
+--R                                           \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                 +------------+ +----------+
+--R             3+-+2    %pi     3+-+2 +-+    %pi  3|     +-+     3|   +-+
+--R         (- 2\|2  sin(---) + 2\|2  \|3 cos(---))\|- %i\|3  + 1 \|%i\|3  + 1
+--R                       18                   18
+--R      *
+--R                       %pi     %pi
+--R                  2cos(---)sin(---)
+--R                        18      18
+--R         atan(-------------------------)
+--R                  %pi 2       %pi 2
+--R              sin(---)  - cos(---)  + x
+--R                   18          18
+--R  /
+--R                +------------+ +----------+
+--R      3+-+2 +-+3|     +-+     3|   +-+
+--R     6\|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 95
+
+--S 96 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 8 3+-+    %pi 12     8 3+-+    %pi 2    %pi 10
+--R               6x  \|2 sin(---)  + 36x  \|2 cos(---) sin(---)
+--R                            18                   18       18
+--R             + 
+--R                  11     8     5 3+-+    %pi 9
+--R               (6x   - 6x  + 6x )\|2 sin(---)
+--R                                          18
+--R             + 
+--R                     8 3+-+    %pi 4       11     8     5 3+-+ +-+    %pi
+--R                 (90x  \|2 cos(---) + (- 6x   + 6x  - 6x )\|2 \|3 cos(---))
+--R                                18                                     18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       8 3+-+    %pi 6        11      8      5 3+-+ +-+    %pi 3
+--R                   120x  \|2 cos(---) + (- 16x   + 16x  - 16x )\|2 \|3 cos(---)
+--R                                  18                                        18
+--R                 + 
+--R                      11 3+-+
+--R                   12x   \|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     11      8      5 3+-+    %pi 4    %pi 5
+--R               (- 36x   + 36x  - 36x )\|2 cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                      8 3+-+    %pi 8        11      8      5 3+-+ +-+    %pi 5
+--R                   90x  \|2 cos(---) + (- 12x   + 12x  - 12x )\|2 \|3 cos(---)
+--R                                 18                                        18
+--R                 + 
+--R                         11 3+-+    %pi 2
+--R                   - 180x   \|2 cos(---)
+--R                                     18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                           11      8      5 3+-+    %pi 6
+--R                     (- 48x   + 48x  - 48x )\|2 cos(---)
+--R                                                     18
+--R                   + 
+--R                        14     11     8 3+-+
+--R                     (6x   - 6x   + 6x )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                      8 3+-+    %pi 10      11 3+-+    %pi 4
+--R                   36x  \|2 cos(---)  + 180x   \|2 cos(---)
+--R                                 18                     18
+--R                 + 
+--R                      14     11     8 3+-+ +-+    %pi
+--R                   (6x   - 6x   + 6x )\|2 \|3 cos(---)
+--R                                                   18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         11      8      5 3+-+    %pi 8
+--R                   (- 18x   + 18x  - 18x )\|2 cos(---)
+--R                                                   18
+--R                 + 
+--R                         14      11      8 3+-+    %pi 2
+--R                   (- 18x   + 18x   - 18x )\|2 cos(---)
+--R                                                    18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                 8 3+-+    %pi 12     11     8     5 3+-+ +-+    %pi 9
+--R               6x  \|2 cos(---)  + (2x   - 2x  + 2x )\|2 \|3 cos(---)
+--R                            18                                    18
+--R             + 
+--R                    11 3+-+    %pi 6       14     11     8 3+-+ +-+    %pi 3
+--R               - 12x   \|2 cos(---) + (- 2x   + 2x   - 2x )\|2 \|3 cos(---)
+--R                                18                                      18
+--R             + 
+--R                 14 3+-+
+--R               6x   \|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                       6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (- 3%i x  \|2  \|3 + 3x  \|2 )sin(---)
+--R                                                  18
+--R             + 
+--R                        6 3+-+2 +-+     6 3+-+2    %pi 2    %pi 10
+--R               (- 18%i x  \|2  \|3 + 18x  \|2 )cos(---) sin(---)
+--R                                                    18       18
+--R             + 
+--R                             9        6        3 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        9     6     3 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 9
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 4
+--R                   (- 45%i x  \|2  \|3 + 45x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 3x  + 3x  - 3x )\|2  \|3
+--R                     + 
+--R                             9        6        3 3+-+2
+--R                       (9%i x  - 9%i x  + 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 6
+--R                   (- 60%i x  \|2  \|3 + 60x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 8x  + 8x  - 8x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (24%i x  - 24%i x  + 24%i x )\|2
+--R                  *
+--R                         %pi 3
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                          9 3+-+2 +-+    9 3+-+2
+--R                   - 6%i x  \|2  \|3 + 6x  \|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          9         6         3 3+-+2 +-+
+--R                   (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                 + 
+--R                         9      6      3 3+-+2
+--R                   (- 18x  + 18x  - 18x )\|2
+--R              *
+--R                     %pi 4    %pi 5
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 8
+--R                   (- 45%i x  \|2  \|3 + 45x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 6x  + 6x  - 6x )\|2  \|3
+--R                     + 
+--R                              9         6         3 3+-+2
+--R                       (18%i x  - 18%i x  + 18%i x )\|2
+--R                  *
+--R                         %pi 5
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                          9 3+-+2 +-+     9 3+-+2    %pi 2
+--R                   (90%i x  \|2  \|3 - 90x  \|2 )cos(---)
+--R                                                      18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              9         6         3 3+-+2 +-+
+--R                       (24%i x  - 24%i x  + 24%i x )\|2  \|3
+--R                     + 
+--R                             9      6      3 3+-+2
+--R                       (- 24x  + 24x  - 24x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           12        9        6 3+-+2 +-+
+--R                   (- 3%i x   + 3%i x  - 3%i x )\|2  \|3
+--R                 + 
+--R                      12     9     6 3+-+2
+--R                   (3x   - 3x  + 3x )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            6 3+-+2 +-+     6 3+-+2    %pi 10
+--R                   (- 18%i x  \|2  \|3 + 18x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                            9 3+-+2 +-+     9 3+-+2    %pi 4
+--R                   (- 90%i x  \|2  \|3 + 90x  \|2 )cos(---)
+--R                                                        18
+--R                 + 
+--R                          12     9     6 3+-+2 +-+
+--R                       (3x   - 3x  + 3x )\|2  \|3
+--R                     + 
+--R                               12        9        6 3+-+2
+--R                       (- 9%i x   + 9%i x  - 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                             9        6        3 3+-+2 +-+
+--R                       (9%i x  - 9%i x  + 9%i x )\|2  \|3
+--R                     + 
+--R                            9     6     3 3+-+2
+--R                       (- 9x  + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                             12        9        6 3+-+2 +-+
+--R                       (9%i x   - 9%i x  + 9%i x )\|2  \|3
+--R                     + 
+--R                            12     9     6 3+-+2
+--R                       (- 9x   + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (- 3%i x  \|2  \|3 + 3x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                    9    6    3 3+-+2 +-+           9        6        3 3+-+2
+--R                 ((x  - x  + x )\|2  \|3  + (- 3%i x  + 3%i x  - 3%i x )\|2  )
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     9 3+-+2 +-+    9 3+-+2    %pi 6
+--R               (6%i x  \|2  \|3 - 6x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                      12    9    6 3+-+2 +-+         12        9        6 3+-+2
+--R                 ((- x   + x  - x )\|2  \|3  + (3%i x   - 3%i x  + 3%i x )\|2  )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      12 3+-+2 +-+    12 3+-+2
+--R               - 3%i x   \|2  \|3 + 3x   \|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   7 +-+     7     %pi 12
+--R           (- 6%i x \|3  + 6x )sin(---)
+--R                                    18
+--R         + 
+--R                    7 +-+      7     %pi 2    %pi 10
+--R           (- 36%i x \|3  + 36x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                    10        7        4  +-+     10     7     4     %pi 9
+--R           ((- 6%i x   + 6%i x  - 6%i x )\|3  + 6x   - 6x  + 6x )sin(---)
+--R                                                                      18
+--R         + 
+--R                        7 +-+      7     %pi 4
+--R               (- 90%i x \|3  + 90x )cos(---)
+--R                                          18
+--R             + 
+--R                   10     7     4  +-+         10         7         4     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  + 18%i x   - 18%i x  + 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         7 +-+       7     %pi 6
+--R               (- 120%i x \|3  + 120x )cos(---)
+--R                                            18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 16x   + 16x  - 16x )\|3  + 48%i x   - 48%i x  + 48%i x )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       10 +-+      10
+--R               - 12%i x  \|3  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     10         7         4  +-+      10      7      4     %pi 4
+--R             ((36%i x   - 36%i x  + 36%i x )\|3  - 36x   + 36x  - 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        7 +-+      7     %pi 8
+--R               (- 90%i x \|3  + 90x )cos(---)
+--R                                          18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 12x   + 12x  - 12x )\|3  + 36%i x   - 36%i x  + 36%i x )
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       10 +-+       10     %pi 2
+--R               (180%i x  \|3  - 180x  )cos(---)
+--R                                            18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         10         7         4  +-+      10      7      4
+--R                 ((48%i x   - 48%i x  + 48%i x )\|3  - 48x   + 48x  - 48x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       13        10        7  +-+     13     10     7
+--R               (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                        7 +-+      7     %pi 10
+--R               (- 36%i x \|3  + 36x )cos(---)
+--R                                          18
+--R             + 
+--R                         10 +-+       10     %pi 4
+--R               (- 180%i x  \|3  + 180x  )cos(---)
+--R                                              18
+--R             + 
+--R                 13     10     7  +-+         13         10         7     %pi
+--R             ((6x   - 6x   + 6x )\|3  - 18%i x   + 18%i x   - 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         10         7         4  +-+      10      7      4
+--R                 ((18%i x   - 18%i x  + 18%i x )\|3  - 18x   + 18x  - 18x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         13         10         7  +-+      13      10      7
+--R                 ((18%i x   - 18%i x   + 18%i x )\|3  - 18x   + 18x   - 18x )
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7 +-+     7     %pi 12
+--R           (- 6%i x \|3  + 6x )cos(---)
+--R                                    18
+--R         + 
+--R               10     7     4  +-+        10        7        4     %pi 9
+--R           ((2x   - 2x  + 2x )\|3  - 6%i x   + 6%i x  - 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                  10 +-+      10     %pi 6
+--R           (12%i x  \|3  - 12x  )cos(---)
+--R                                      18
+--R         + 
+--R                 13     10     7  +-+        13        10        7     %pi 3
+--R           ((- 2x   + 2x   - 2x )\|3  + 6%i x   - 6%i x   + 6%i x )cos(---)
+--R                                                                        18
+--R         + 
+--R                  13 +-+     13
+--R           - 6%i x  \|3  + 6x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                     6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (3%i x  \|2  \|3 + 3x  \|2 )sin(---)
+--R                                                18
+--R             + 
+--R                      6 3+-+2 +-+     6 3+-+2    %pi 2    %pi 10
+--R               (18%i x  \|2  \|3 + 18x  \|2 )cos(---) sin(---)
+--R                                                  18       18
+--R             + 
+--R                        9        6        3 3+-+2 +-+      9     6     3 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 9
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 4
+--R                   (45%i x  \|2  \|3 + 45x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 3x  + 3x  - 3x )\|2  \|3
+--R                     + 
+--R                               9        6        3 3+-+2
+--R                       (- 9%i x  + 9%i x  - 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 8
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 6
+--R                   (60%i x  \|2  \|3 + 60x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 8x  + 8x  - 8x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 24%i x  + 24%i x  - 24%i x )\|2
+--R                  *
+--R                         %pi 3
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                        9 3+-+2 +-+    9 3+-+2
+--R                   6%i x  \|2  \|3 + 6x  \|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            9         6         3 3+-+2 +-+
+--R                   (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                 + 
+--R                         9      6      3 3+-+2
+--R                   (- 18x  + 18x  - 18x )\|2
+--R              *
+--R                     %pi 4    %pi 5
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 8
+--R                   (45%i x  \|2  \|3 + 45x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                            9     6     3 3+-+2 +-+
+--R                       (- 6x  + 6x  - 6x )\|2  \|3
+--R                     + 
+--R                                9         6         3 3+-+2
+--R                       (- 18%i x  + 18%i x  - 18%i x )\|2
+--R                  *
+--R                         %pi 5
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                            9 3+-+2 +-+     9 3+-+2    %pi 2
+--R                   (- 90%i x  \|2  \|3 - 90x  \|2 )cos(---)
+--R                                                        18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                9         6         3 3+-+2 +-+
+--R                       (- 24%i x  + 24%i x  - 24%i x )\|2  \|3
+--R                     + 
+--R                             9      6      3 3+-+2
+--R                       (- 24x  + 24x  - 24x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                       12        9        6 3+-+2 +-+      12     9     6 3+-+2
+--R                 (3%i x   - 3%i x  + 3%i x )\|2  \|3  + (3x   - 3x  + 3x )\|2
+--R              *
+--R                     %pi 3
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          6 3+-+2 +-+     6 3+-+2    %pi 10
+--R                   (18%i x  \|2  \|3 + 18x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                          9 3+-+2 +-+     9 3+-+2    %pi 4
+--R                   (90%i x  \|2  \|3 + 90x  \|2 )cos(---)
+--R                                                      18
+--R                 + 
+--R                          12     9     6 3+-+2 +-+
+--R                       (3x   - 3x  + 3x )\|2  \|3
+--R                     + 
+--R                             12        9        6 3+-+2
+--R                       (9%i x   - 9%i x  + 9%i x )\|2
+--R                  *
+--R                         %pi
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                               9        6        3 3+-+2 +-+
+--R                       (- 9%i x  + 9%i x  - 9%i x )\|2  \|3
+--R                     + 
+--R                            9     6     3 3+-+2
+--R                       (- 9x  + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                               12        9        6 3+-+2 +-+
+--R                       (- 9%i x   + 9%i x  - 9%i x )\|2  \|3
+--R                     + 
+--R                            12     9     6 3+-+2
+--R                       (- 9x   + 9x  - 9x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     6 3+-+2 +-+    6 3+-+2    %pi 12
+--R               (3%i x  \|2  \|3 + 3x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                    9    6    3 3+-+2 +-+         9        6        3 3+-+2
+--R                 ((x  - x  + x )\|2  \|3  + (3%i x  - 3%i x  + 3%i x )\|2  )
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                       9 3+-+2 +-+    9 3+-+2    %pi 6
+--R               (- 6%i x  \|2  \|3 - 6x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                         12    9    6 3+-+2 +-+
+--R                     (- x   + x  - x )\|2  \|3
+--R                   + 
+--R                             12        9        6 3+-+2
+--R                     (- 3%i x   + 3%i x  - 3%i x )\|2
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                    12 3+-+2 +-+    12 3+-+2
+--R               3%i x   \|2  \|3 + 3x   \|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  4    %pi 12      4    %pi 2    %pi 10
+--R               12x sin(---)   + 72x cos(---) sin(---)
+--R                        18               18       18
+--R             + 
+--R                   7      4           %pi 9
+--R               (12x  - 12x  + 12x)sin(---)
+--R                                       18
+--R             + 
+--R                    4    %pi 4         7      4        +-+    %pi      %pi 8
+--R               (180x cos(---)  + (- 12x  + 12x  - 12x)\|3 cos(---))sin(---)
+--R                          18                                   18       18
+--R             + 
+--R                      4    %pi 6         7      4        +-+    %pi 3      7
+--R                 (240x cos(---)  + (- 32x  + 32x  - 32x)\|3 cos(---)  + 24x )
+--R                            18                                   18
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                     7      4           %pi 4    %pi 5
+--R               (- 72x  + 72x  - 72x)cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                       4    %pi 8         7      4        +-+    %pi 5
+--R                   180x cos(---)  + (- 24x  + 24x  - 24x)\|3 cos(---)
+--R                             18                                   18
+--R                 + 
+--R                         7    %pi 2
+--R                   - 360x cos(---)
+--R                               18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                      7      4           %pi 6      10      7      4     %pi 3
+--R               ((- 96x  + 96x  - 96x)cos(---)  + 12x   - 12x  + 12x )sin(---)
+--R                                          18                              18
+--R             + 
+--R                      4    %pi 10       7    %pi 4
+--R                   72x cos(---)   + 360x cos(---)
+--R                            18                18
+--R                 + 
+--R                       10      7      4  +-+    %pi
+--R                   (12x   - 12x  + 12x )\|3 cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         7      4           %pi 8
+--R                   (- 36x  + 36x  - 36x)cos(---)
+--R                                             18
+--R                 + 
+--R                         10      7      4     %pi 2
+--R                   (- 36x   + 36x  - 36x )cos(---)
+--R                                               18
+--R              *
+--R                     %pi
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                  4    %pi 12      7     4       +-+    %pi 9      7    %pi 6
+--R               12x cos(---)   + (4x  - 4x  + 4x)\|3 cos(---)  - 24x cos(---)
+--R                        18                               18              18
+--R             + 
+--R                    10     7     4  +-+    %pi 3      10
+--R               (- 4x   + 4x  - 4x )\|3 cos(---)  + 12x
+--R                                            18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R              5 3+-+    %pi 12     5 3+-+    %pi 2    %pi 10
+--R           12x  \|2 sin(---)  + 72x  \|2 cos(---) sin(---)
+--R                         18                   18       18
+--R         + 
+--R               8      5      2 3+-+    %pi 9
+--R           (12x  - 12x  + 12x )\|2 sin(---)
+--R                                        18
+--R         + 
+--R                  5 3+-+    %pi 4        8      5      2 3+-+ +-+    %pi
+--R             (180x  \|2 cos(---) + (- 12x  + 12x  - 12x )\|2 \|3 cos(---))
+--R                             18                                       18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   5 3+-+    %pi 6        8      5      2 3+-+ +-+    %pi 3
+--R               240x  \|2 cos(---) + (- 32x  + 32x  - 32x )\|2 \|3 cos(---)
+--R                              18                                       18
+--R             + 
+--R                  8 3+-+
+--R               24x  \|2
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 8      5      2 3+-+    %pi 4    %pi 5
+--R           (- 72x  + 72x  - 72x )\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   5 3+-+    %pi 8        8      5      2 3+-+ +-+    %pi 5
+--R               180x  \|2 cos(---) + (- 24x  + 24x  - 24x )\|2 \|3 cos(---)
+--R                              18                                       18
+--R             + 
+--R                     8 3+-+    %pi 2
+--R               - 360x  \|2 cos(---)
+--R                                18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8      5      2 3+-+    %pi 6       11      8      5 3+-+
+--R             ((- 96x  + 96x  - 96x )\|2 cos(---)  + (12x   - 12x  + 12x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  5 3+-+    %pi 10      8 3+-+    %pi 4
+--R               72x  \|2 cos(---)  + 360x  \|2 cos(---)
+--R                             18                    18
+--R             + 
+--R                   11      8      5 3+-+ +-+    %pi
+--R               (12x   - 12x  + 12x )\|2 \|3 cos(---)
+--R                                                 18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     8      5      2 3+-+    %pi 8
+--R               (- 36x  + 36x  - 36x )\|2 cos(---)
+--R                                              18
+--R             + 
+--R                     11      8      5 3+-+    %pi 2
+--R               (- 36x   + 36x  - 36x )\|2 cos(---)
+--R                                               18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R              5 3+-+    %pi 12     8     5     2 3+-+ +-+    %pi 9
+--R           12x  \|2 cos(---)  + (4x  - 4x  + 4x )\|2 \|3 cos(---)
+--R                         18                                   18
+--R         + 
+--R              8 3+-+    %pi 6       11     8     5 3+-+ +-+    %pi 3      11 3+-+
+--R         - 24x  \|2 cos(---) + (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  + 12x   \|2
+--R                         18                                     18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 7 +-+     7     %pi 12
+--R           (6%i x \|3  + 6x )sin(---)
+--R                                  18
+--R         + 
+--R                  7 +-+      7     %pi 2    %pi 10
+--R           (36%i x \|3  + 36x )cos(---) sin(---)
+--R                                    18       18
+--R         + 
+--R                  10        7        4  +-+     10     7     4     %pi 9
+--R           ((6%i x   - 6%i x  + 6%i x )\|3  + 6x   - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                      7 +-+      7     %pi 4
+--R               (90%i x \|3  + 90x )cos(---)
+--R                                        18
+--R             + 
+--R                   10     7     4  +-+         10         7         4     %pi
+--R             ((- 6x   + 6x  - 6x )\|3  - 18%i x   + 18%i x  - 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       7 +-+       7     %pi 6
+--R               (120%i x \|3  + 120x )cos(---)
+--R                                          18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 16x   + 16x  - 16x )\|3  - 48%i x   + 48%i x  - 48%i x )
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     10 +-+      10
+--R               12%i x  \|3  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       10         7         4  +-+      10      7      4
+--R             ((- 36%i x   + 36%i x  - 36%i x )\|3  - 36x   + 36x  - 36x )
+--R          *
+--R                 %pi 4    %pi 5
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      7 +-+      7     %pi 8
+--R               (90%i x \|3  + 90x )cos(---)
+--R                                        18
+--R             + 
+--R                        10      7      4  +-+         10         7         4
+--R                 ((- 12x   + 12x  - 12x )\|3  - 36%i x   + 36%i x  - 36%i x )
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         10 +-+       10     %pi 2
+--R               (- 180%i x  \|3  - 180x  )cos(---)
+--R                                              18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           10         7         4  +-+      10      7      4
+--R                 ((- 48%i x   + 48%i x  - 48%i x )\|3  - 48x   + 48x  - 48x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     13        10        7  +-+     13     10     7
+--R               (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7 +-+      7     %pi 10
+--R               (36%i x \|3  + 36x )cos(---)
+--R                                        18
+--R             + 
+--R                       10 +-+       10     %pi 4
+--R               (180%i x  \|3  + 180x  )cos(---)
+--R                                            18
+--R             + 
+--R                 13     10     7  +-+         13         10         7     %pi
+--R             ((6x   - 6x   + 6x )\|3  + 18%i x   - 18%i x   + 18%i x )cos(---)
+--R                                                                           18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           10         7         4  +-+      10      7      4
+--R                 ((- 18%i x   + 18%i x  - 18%i x )\|3  - 18x   + 18x  - 18x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           13         10         7  +-+      13      10      7
+--R                 ((- 18%i x   + 18%i x   - 18%i x )\|3  - 18x   + 18x   - 18x )
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 7 +-+     7     %pi 12
+--R           (6%i x \|3  + 6x )cos(---)
+--R                                  18
+--R         + 
+--R               10     7     4  +-+        10        7        4     %pi 9
+--R           ((2x   - 2x  + 2x )\|3  + 6%i x   - 6%i x  + 6%i x )cos(---)
+--R                                                                    18
+--R         + 
+--R                    10 +-+      10     %pi 6
+--R           (- 12%i x  \|3  - 12x  )cos(---)
+--R                                        18
+--R         + 
+--R                 13     10     7  +-+        13        10        7     %pi 3
+--R           ((- 2x   + 2x   - 2x )\|3  - 6%i x   + 6%i x   - 6%i x )cos(---)
+--R                                                                        18
+--R         + 
+--R                13 +-+     13
+--R           6%i x  \|3  + 6x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R              5 3+-+    %pi 12     5 3+-+    %pi 2    %pi 10
+--R           12x  \|2 sin(---)  + 72x  \|2 cos(---) sin(---)
+--R                         18                   18       18
+--R         + 
+--R               8      5      2 3+-+    %pi 9
+--R           (12x  - 12x  + 12x )\|2 sin(---)
+--R                                        18
+--R         + 
+--R                  5 3+-+    %pi 4        8      5      2 3+-+ +-+    %pi
+--R             (180x  \|2 cos(---) + (- 12x  + 12x  - 12x )\|2 \|3 cos(---))
+--R                             18                                       18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   5 3+-+    %pi 6        8      5      2 3+-+ +-+    %pi 3
+--R               240x  \|2 cos(---) + (- 32x  + 32x  - 32x )\|2 \|3 cos(---)
+--R                              18                                       18
+--R             + 
+--R                  8 3+-+
+--R               24x  \|2
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                 8      5      2 3+-+    %pi 4    %pi 5
+--R           (- 72x  + 72x  - 72x )\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   5 3+-+    %pi 8        8      5      2 3+-+ +-+    %pi 5
+--R               180x  \|2 cos(---) + (- 24x  + 24x  - 24x )\|2 \|3 cos(---)
+--R                              18                                       18
+--R             + 
+--R                     8 3+-+    %pi 2
+--R               - 360x  \|2 cos(---)
+--R                                18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8      5      2 3+-+    %pi 6       11      8      5 3+-+
+--R             ((- 96x  + 96x  - 96x )\|2 cos(---)  + (12x   - 12x  + 12x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  5 3+-+    %pi 10      8 3+-+    %pi 4
+--R               72x  \|2 cos(---)  + 360x  \|2 cos(---)
+--R                             18                    18
+--R             + 
+--R                   11      8      5 3+-+ +-+    %pi
+--R               (12x   - 12x  + 12x )\|2 \|3 cos(---)
+--R                                                 18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     8      5      2 3+-+    %pi 8
+--R               (- 36x  + 36x  - 36x )\|2 cos(---)
+--R                                              18
+--R             + 
+--R                     11      8      5 3+-+    %pi 2
+--R               (- 36x   + 36x  - 36x )\|2 cos(---)
+--R                                               18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R              5 3+-+    %pi 12     8     5     2 3+-+ +-+    %pi 9
+--R           12x  \|2 cos(---)  + (4x  - 4x  + 4x )\|2 \|3 cos(---)
+--R                         18                                   18
+--R         + 
+--R              8 3+-+    %pi 6       11     8     5 3+-+ +-+    %pi 3      11 3+-+
+--R         - 24x  \|2 cos(---) + (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  + 12x   \|2
+--R                         18                                     18
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R          6 3+-+2    %pi 12     6 3+-+2    %pi 2    %pi 10
+--R       12x  \|2  sin(---)  + 72x  \|2  cos(---) sin(---)
+--R                      18                    18       18
+--R     + 
+--R           9      6      3 3+-+2    %pi 9
+--R       (12x  - 12x  + 12x )\|2  sin(---)
+--R                                     18
+--R     + 
+--R            6 3+-+2    %pi 4        9      6      3 3+-+2 +-+    %pi      %pi 8
+--R       (180x  \|2  cos(---) + (- 12x  + 12x  - 12x )\|2  \|3 cos(---))sin(---)
+--R                        18                                        18       18
+--R     + 
+--R               6 3+-+2    %pi 6        9      6      3 3+-+2 +-+    %pi 3
+--R           240x  \|2  cos(---) + (- 32x  + 32x  - 32x )\|2  \|3 cos(---)
+--R                           18                                        18
+--R         + 
+--R              9 3+-+2
+--R           24x  \|2
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R             9      6      3 3+-+2    %pi 4    %pi 5
+--R       (- 72x  + 72x  - 72x )\|2  cos(---) sin(---)
+--R                                       18       18
+--R     + 
+--R               6 3+-+2    %pi 8        9      6      3 3+-+2 +-+    %pi 5
+--R           180x  \|2  cos(---) + (- 24x  + 24x  - 24x )\|2  \|3 cos(---)
+--R                           18                                        18
+--R         + 
+--R                 9 3+-+2    %pi 2
+--R           - 360x  \|2  cos(---)
+--R                             18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R                9      6      3 3+-+2    %pi 6       12      9      6 3+-+2
+--R         ((- 96x  + 96x  - 96x )\|2  cos(---)  + (12x   - 12x  + 12x )\|2  )
+--R                                          18
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              18
+--R     + 
+--R              6 3+-+2    %pi 10      9 3+-+2    %pi 4
+--R           72x  \|2  cos(---)  + 360x  \|2  cos(---)
+--R                          18                     18
+--R         + 
+--R               12      9      6 3+-+2 +-+    %pi
+--R           (12x   - 12x  + 12x )\|2  \|3 cos(---)
+--R                                              18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R                 9      6      3 3+-+2    %pi 8
+--R           (- 36x  + 36x  - 36x )\|2  cos(---)
+--R                                           18
+--R         + 
+--R                 12      9      6 3+-+2    %pi 2
+--R           (- 36x   + 36x  - 36x )\|2  cos(---)
+--R                                            18
+--R      *
+--R             %pi
+--R         sin(---)
+--R              18
+--R     + 
+--R          6 3+-+2    %pi 12     9     6     3 3+-+2 +-+    %pi 9
+--R       12x  \|2  cos(---)  + (4x  - 4x  + 4x )\|2  \|3 cos(---)
+--R                      18                                    18
+--R     + 
+--R          9 3+-+2    %pi 6       12     9     6 3+-+2 +-+    %pi 3      12 3+-+2
+--R     - 24x  \|2  cos(---) + (- 4x   + 4x  - 4x )\|2  \|3 cos(---)  + 12x   \|2
+--R                      18                                      18
+--R  /
+--R                  10     7     4 3+-+    %pi 12
+--R               (6x   - 6x  + 6x )\|2 sin(---)
+--R                                          18
+--R             + 
+--R                   10      7      4 3+-+    %pi 2    %pi 10
+--R               (36x   - 36x  + 36x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                   10      7      4 3+-+    %pi 4    %pi 8
+--R               (90x   - 90x  + 90x )\|2 cos(---) sin(---)
+--R                                             18       18
+--R             + 
+--R                        10       7       4 3+-+    %pi 6
+--R                   (120x   - 120x  + 120x )\|2 cos(---)
+--R                                                    18
+--R                 + 
+--R                       13      10      7 3+-+
+--R                   (12x   - 12x   + 12x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       10      7      4 3+-+    %pi 8
+--R                   (90x   - 90x  + 90x )\|2 cos(---)
+--R                                                 18
+--R                 + 
+--R                          13       10       7 3+-+    %pi 2
+--R                   (- 180x   + 180x   - 180x )\|2 cos(---)
+--R                                                       18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                       10      7      4 3+-+    %pi 10
+--R                   (36x   - 36x  + 36x )\|2 cos(---)
+--R                                                 18
+--R                 + 
+--R                        13       10       7 3+-+    %pi 4
+--R                   (180x   - 180x   + 180x )\|2 cos(---)
+--R                                                     18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                  10     7     4 3+-+    %pi 12
+--R               (6x   - 6x  + 6x )\|2 cos(---)
+--R                                          18
+--R             + 
+--R                     13      10      7 3+-+    %pi 6      16     13     10 3+-+
+--R               (- 12x   + 12x   - 12x )\|2 cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 12
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                            8         5         2 3+-+2 +-+
+--R                   (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (18x  - 18x  + 18x )\|2
+--R              *
+--R                     %pi 2    %pi 10
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                            8         5         2 3+-+2 +-+
+--R                   (- 45%i x  + 45%i x  - 45%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (45x  - 45x  + 45x )\|2
+--R              *
+--R                     %pi 4    %pi 8
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 60%i x  + 60%i x  - 60%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (60x  - 60x  + 60x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                           11        8        5 3+-+2 +-+
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R                 + 
+--R                      11     8     5 3+-+2
+--R                   (6x   - 6x  + 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 45%i x  + 45%i x  - 45%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (45x  - 45x  + 45x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (90%i x   - 90%i x  + 90%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 90x   + 90x  - 90x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                                8         5         2 3+-+2 +-+
+--R                       (- 18%i x  + 18%i x  - 18%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (18x  - 18x  + 18x )\|2
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 90%i x   + 90%i x  - 90%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (90x   - 90x  + 90x )\|2
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                             8        5        2 3+-+2 +-+
+--R                     (- 3%i x  + 3%i x  - 3%i x )\|2  \|3
+--R                   + 
+--R                        8     5     2 3+-+2
+--R                     (3x  - 3x  + 3x )\|2
+--R              *
+--R                     %pi 12
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                         11        8        5 3+-+2 +-+
+--R                   (6%i x   - 6%i x  + 6%i x )\|2  \|3
+--R                 + 
+--R                        11     8     5 3+-+2
+--R                   (- 6x   + 6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     14        11        8 3+-+2 +-+      14     11     8 3+-+2
+--R             (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    9        6        3  +-+     9     6     3     %pi 12
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 2
+--R             ((- 36%i x  + 36%i x  - 36%i x )\|3  + 36x  - 36x  + 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 4
+--R             ((- 90%i x  + 90%i x  - 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                               9          6          3  +-+       9       6
+--R                     (- 120%i x  + 120%i x  - 120%i x )\|3  + 120x  - 120x
+--R                   + 
+--R                         3
+--R                     120x
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                        12         9         6  +-+      12      9      6
+--R               (- 12%i x   + 12%i x  - 12%i x )\|3  + 12x   - 12x  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 90%i x  + 90%i x  - 90%i x )\|3  + 90x  - 90x  + 90x )
+--R              *
+--R                     %pi 8
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                     (180%i x   - 180%i x  + 180%i x )\|3  - 180x   + 180x
+--R                   + 
+--R                           6
+--R                     - 180x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                           9         6         3  +-+      9      6      3
+--R                 ((- 36%i x  + 36%i x  - 36%i x )\|3  + 36x  - 36x  + 36x )
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                   (- 180%i x   + 180%i x  - 180%i x )\|3  + 180x   - 180x
+--R                 + 
+--R                       6
+--R                   180x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    9        6        3  +-+     9     6     3     %pi 12
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   12         9         6  +-+      12      9      6     %pi 6
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  - 12x   + 12x  - 12x )cos(---)
+--R                                                                          18
+--R         + 
+--R                   15        12        9  +-+     15     12     9
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 12
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                          8         5         2 3+-+2 +-+
+--R                   (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (18x  - 18x  + 18x )\|2
+--R              *
+--R                     %pi 2    %pi 10
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                          8         5         2 3+-+2 +-+
+--R                   (45%i x  - 45%i x  + 45%i x )\|2  \|3
+--R                 + 
+--R                       8      5      2 3+-+2
+--R                   (45x  - 45x  + 45x )\|2
+--R              *
+--R                     %pi 4    %pi 8
+--R                 cos(---) sin(---)
+--R                      18       18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (60%i x  - 60%i x  + 60%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (60x  - 60x  + 60x )\|2
+--R                  *
+--R                         %pi 6
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                       11        8        5 3+-+2 +-+      11     8     5 3+-+2
+--R                 (6%i x   - 6%i x  + 6%i x )\|2  \|3  + (6x   - 6x  + 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (45%i x  - 45%i x  + 45%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (45x  - 45x  + 45x )\|2
+--R                  *
+--R                         %pi 8
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                                11         8         5 3+-+2 +-+
+--R                       (- 90%i x   + 90%i x  - 90%i x )\|2  \|3
+--R                     + 
+--R                             11      8      5 3+-+2
+--R                       (- 90x   + 90x  - 90x )\|2
+--R                  *
+--R                         %pi 2
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                              8         5         2 3+-+2 +-+
+--R                       (18%i x  - 18%i x  + 18%i x )\|2  \|3
+--R                     + 
+--R                           8      5      2 3+-+2
+--R                       (18x  - 18x  + 18x )\|2
+--R                  *
+--R                         %pi 10
+--R                     cos(---)
+--R                          18
+--R                 + 
+--R                              11         8         5 3+-+2 +-+
+--R                       (90%i x   - 90%i x  + 90%i x )\|2  \|3
+--R                     + 
+--R                           11      8      5 3+-+2
+--R                       (90x   - 90x  + 90x )\|2
+--R                  *
+--R                         %pi 4
+--R                     cos(---)
+--R                          18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                        8        5        2 3+-+2 +-+      8     5     2 3+-+2
+--R                 ((3%i x  - 3%i x  + 3%i x )\|2  \|3  + (3x  - 3x  + 3x )\|2  )
+--R              *
+--R                     %pi 12
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                           11        8        5 3+-+2 +-+
+--R                   (- 6%i x   + 6%i x  - 6%i x )\|2  \|3
+--R                 + 
+--R                        11     8     5 3+-+2
+--R                   (- 6x   + 6x  - 6x )\|2
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                     14        11        8 3+-+2 +-+      14     11     8 3+-+2
+--R               (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   6      3          %pi 12
+--R               (12x  - 12x  + 12)sin(---)
+--R                                      18
+--R             + 
+--R                   6      3          %pi 2    %pi 10
+--R               (72x  - 72x  + 72)cos(---) sin(---)
+--R                                      18       18
+--R             + 
+--R                    6       3           %pi 4    %pi 8
+--R               (180x  - 180x  + 180)cos(---) sin(---)
+--R                                         18       18
+--R             + 
+--R                     6       3           %pi 6      9      6      3     %pi 6
+--R               ((240x  - 240x  + 240)cos(---)  + 24x  - 24x  + 24x )sin(---)
+--R                                          18                             18
+--R             + 
+--R                        6       3           %pi 8
+--R                   (180x  - 180x  + 180)cos(---)
+--R                                             18
+--R                 + 
+--R                          9       6       3     %pi 2
+--R                   (- 360x  + 360x  - 360x )cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 4
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                         6      3          %pi 10
+--R                     (72x  - 72x  + 72)cos(---)
+--R                                            18
+--R                   + 
+--R                          9       6       3     %pi 4
+--R                     (360x  - 360x  + 360x )cos(---)
+--R                                                 18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                   6      3          %pi 12         9      6      3     %pi 6
+--R               (12x  - 12x  + 12)cos(---)   + (- 24x  + 24x  - 24x )cos(---)
+--R                                      18                                 18
+--R             + 
+--R                  12      9      6
+--R               12x   - 12x  + 12x
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 sin(---)
+--R                                       18
+--R         + 
+--R               7      4       3+-+    %pi 2    %pi 10
+--R           (72x  - 72x  + 72x)\|2 cos(---) sin(---)
+--R                                       18       18
+--R         + 
+--R                7       4        3+-+    %pi 4    %pi 8
+--R           (180x  - 180x  + 180x)\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   7       4        3+-+    %pi 6       10      7      4 3+-+
+--R             ((240x  - 240x  + 240x)\|2 cos(---)  + (24x   - 24x  + 24x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7       4        3+-+    %pi 8
+--R               (180x  - 180x  + 180x)\|2 cos(---)
+--R                                              18
+--R             + 
+--R                      10       7       4 3+-+    %pi 2
+--R               (- 360x   + 360x  - 360x )\|2 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7      4       3+-+    %pi 10
+--R               (72x  - 72x  + 72x)\|2 cos(---)
+--R                                           18
+--R             + 
+--R                    10       7       4 3+-+    %pi 4
+--R               (360x   - 360x  + 360x )\|2 cos(---)
+--R                                                18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 cos(---)
+--R                                       18
+--R         + 
+--R                 10      7      4 3+-+    %pi 6       13      10      7 3+-+
+--R           (- 24x   + 24x  - 24x )\|2 cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                           18
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9        6        3  +-+     9     6     3     %pi 12
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     9         6         3  +-+      9      6      3     %pi 2
+--R             ((36%i x  - 36%i x  + 36%i x )\|3  + 36x  - 36x  + 36x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     9         6         3  +-+      9      6      3     %pi 4
+--R             ((90%i x  - 90%i x  + 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  18
+--R         + 
+--R                          9          6          3  +-+       9       6       3
+--R                 ((120%i x  - 120%i x  + 120%i x )\|3  + 120x  - 120x  + 120x )
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                      12         9         6  +-+      12      9      6
+--R               (12%i x   - 12%i x  + 12%i x )\|3  + 12x   - 12x  + 12x
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       9         6         3  +-+      9      6      3     %pi 8
+--R               ((90%i x  - 90%i x  + 90%i x )\|3  + 90x  - 90x  + 90x )cos(---)
+--R                                                                            18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                   (- 180%i x   + 180%i x  - 180%i x )\|3  - 180x   + 180x
+--R                 + 
+--R                         6
+--R                   - 180x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                         9         6         3  +-+      9      6      3
+--R                 ((36%i x  - 36%i x  + 36%i x )\|3  + 36x  - 36x  + 36x )
+--R              *
+--R                     %pi 10
+--R                 cos(---)
+--R                      18
+--R             + 
+--R                             12          9          6  +-+       12       9
+--R                     (180%i x   - 180%i x  + 180%i x )\|3  + 180x   - 180x
+--R                   + 
+--R                         6
+--R                     180x
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  9        6        3  +-+     9     6     3     %pi 12
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                     12         9         6  +-+      12      9      6     %pi 6
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  - 12x   + 12x  - 12x )cos(---)
+--R                                                                            18
+--R         + 
+--R                 15        12        9  +-+     15     12     9
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 sin(---)
+--R                                       18
+--R         + 
+--R               7      4       3+-+    %pi 2    %pi 10
+--R           (72x  - 72x  + 72x)\|2 cos(---) sin(---)
+--R                                       18       18
+--R         + 
+--R                7       4        3+-+    %pi 4    %pi 8
+--R           (180x  - 180x  + 180x)\|2 cos(---) sin(---)
+--R                                          18       18
+--R         + 
+--R                   7       4        3+-+    %pi 6       10      7      4 3+-+
+--R             ((240x  - 240x  + 240x)\|2 cos(---)  + (24x   - 24x  + 24x )\|2 )
+--R                                             18
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7       4        3+-+    %pi 8
+--R               (180x  - 180x  + 180x)\|2 cos(---)
+--R                                              18
+--R             + 
+--R                      10       7       4 3+-+    %pi 2
+--R               (- 360x   + 360x  - 360x )\|2 cos(---)
+--R                                                  18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   7      4       3+-+    %pi 10
+--R               (72x  - 72x  + 72x)\|2 cos(---)
+--R                                           18
+--R             + 
+--R                    10       7       4 3+-+    %pi 4
+--R               (360x   - 360x  + 360x )\|2 cos(---)
+--R                                                18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R               7      4       3+-+    %pi 12
+--R           (12x  - 12x  + 12x)\|2 cos(---)
+--R                                       18
+--R         + 
+--R                 10      7      4 3+-+    %pi 6       13      10      7 3+-+
+--R           (- 24x   + 24x  - 24x )\|2 cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                           18
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           8      5      2 3+-+2    %pi 12
+--R       (12x  - 12x  + 12x )\|2  sin(---)
+--R                                     18
+--R     + 
+--R           8      5      2 3+-+2    %pi 2    %pi 10
+--R       (72x  - 72x  + 72x )\|2  cos(---) sin(---)
+--R                                     18       18
+--R     + 
+--R            8       5       2 3+-+2    %pi 4    %pi 8
+--R       (180x  - 180x  + 180x )\|2  cos(---) sin(---)
+--R                                        18       18
+--R     + 
+--R               8       5       2 3+-+2    %pi 6       11      8      5 3+-+2
+--R         ((240x  - 240x  + 240x )\|2  cos(---)  + (24x   - 24x  + 24x )\|2  )
+--R                                           18
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              18
+--R     + 
+--R                8       5       2 3+-+2    %pi 8
+--R           (180x  - 180x  + 180x )\|2  cos(---)
+--R                                            18
+--R         + 
+--R                  11       8       5 3+-+2    %pi 2
+--R           (- 360x   + 360x  - 360x )\|2  cos(---)
+--R                                               18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              18
+--R     + 
+--R               8      5      2 3+-+2    %pi 10
+--R           (72x  - 72x  + 72x )\|2  cos(---)
+--R                                         18
+--R         + 
+--R                11       8       5 3+-+2    %pi 4
+--R           (360x   - 360x  + 360x )\|2  cos(---)
+--R                                             18
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              18
+--R     + 
+--R           8      5      2 3+-+2    %pi 12
+--R       (12x  - 12x  + 12x )\|2  cos(---)
+--R                                     18
+--R     + 
+--R             11      8      5 3+-+2    %pi 6       14      11      8 3+-+2
+--R       (- 24x   + 24x  - 24x )\|2  cos(---)  + (12x   - 12x   + 12x )\|2
+--R                                        18
+--R                                           Type: Expression(Complex(Integer))
+--E 96
+
+)clear all
+
+--S 97 of 649
+t0:=(1-x^3)/(x^3*(1-x^3+x^6))
+--R 
+--R
+--R             3
+--R          - x  + 1
+--R   (1)  ------------
+--R         9    6    3
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 97
+
+--S 98 of 649
+r0:=(-1/2)/x^2-1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))-_
+   1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3))+1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*_
+   sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3))-1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))+1/18*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3+%i*_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))+1/3*atan((4*x+2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))*_
+   (%i+sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))
+--R 
+--R
+--R   (2)
+--R                             +------------+2
+--R                2 +-+     2 3|     +-+
+--R         (- %i x \|3  + 3x )\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                          +------------+2     +----------+
+--R             2 +-+     2 3|     +-+          3|   +-+         3+-+
+--R       (2%i x \|3  - 6x )\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                           +----------+2
+--R              2 +-+     2 3|   +-+
+--R         (%i x \|3  + 3x )\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                            +----------+2     +------------+
+--R               2 +-+     2 3|   +-+          3|     +-+         3+-+
+--R       (- 2%i x \|3  - 6x )\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                   +------------+
+--R                          +----------+2     3+-+2 3|     +-+
+--R          2 +-+        2 3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (6x \|3  + 6%i x )\|%i\|3  + 1  atan(-------------------------)
+--R                                                       +------------+
+--R                                             3+-+2 +-+3|     +-+
+--R                                             \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                     +----------+
+--R                          +------------+2     3+-+2 3|   +-+
+--R          2 +-+        2 3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (6x \|3  - 6%i x )\|- %i\|3  + 1  atan(-----------------------)
+--R                                                         +----------+
+--R                                               3+-+2 +-+3|   +-+
+--R                                               \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R               +------------+2  +----------+2
+--R          3+-+3|     +-+       3|   +-+
+--R       - 9\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R  /
+--R               +------------+2  +----------+2
+--R        2 3+-+3|     +-+       3|   +-+
+--R     18x  \|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 98
+
+--S 99 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       1
+--R                atan(----)
+--R                      +-+
+--R           2         \|3
+--R         2x cos(----------)
+--R                     3
+--R      *
+--R                        1   2                 1                 1   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3                   \|3               \|3        2
+--R         log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                      3                     3                 3
+--R     + 
+--R                             1                   1
+--R                      atan(----)          atan(----)
+--R                            +-+                 +-+
+--R             2 +-+         \|3       2         \|3
+--R         (- x \|3 sin(----------) - x cos(----------))
+--R                           3                   3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                              1
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            3
+--R     + 
+--R                           1                   1
+--R                    atan(----)          atan(----)
+--R                          +-+                 +-+
+--R           2 +-+         \|3       2         \|3
+--R         (x \|3 sin(----------) - x cos(----------))
+--R                         3                   3
+--R      *
+--R         log
+--R                         1   2                1                 1   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       3                    3                 3
+--R            + 
+--R                                1
+--R                         atan(----)
+--R                               +-+
+--R                  +-+         \|3       2
+--R              - x\|3 cos(----------) + x
+--R                              3
+--R     + 
+--R                          1                        1
+--R                   atan(----)               atan(----)
+--R                         +-+                      +-+
+--R              2         \|3        2 +-+         \|3
+--R         (- 2x sin(----------) + 2x \|3 cos(----------))
+--R                        3                        3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) + cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) - \|3 cos(----------) - 2x
+--R                       3                     3
+--R     + 
+--R                        1                        1
+--R                 atan(----)               atan(----)
+--R                       +-+                      +-+
+--R            2         \|3        2 +-+         \|3
+--R         (2x sin(----------) + 2x \|3 cos(----------))
+--R                      3                        3
+--R      *
+--R                                1                 1
+--R                         atan(----)        atan(----)
+--R                               +-+               +-+
+--R                  +-+         \|3               \|3
+--R                 \|3 sin(----------) - cos(----------)
+--R                              3                 3
+--R         atan(------------------------------------------)
+--R                         1                     1
+--R                  atan(----)            atan(----)
+--R                        +-+                   +-+
+--R                       \|3       +-+         \|3
+--R              sin(----------) + \|3 cos(----------) - 2x
+--R                       3                     3
+--R     + 
+--R                                           1
+--R                                    atan(----)
+--R                     1                    +-+
+--R              atan(----)                 \|3
+--R                    +-+         cos(----------)
+--R         2         \|3                   3             +-+
+--R       4x sin(----------)atan(-------------------) - 3\|3
+--R                   3                     1
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------) + x
+--R                                       3
+--R  /
+--R       2 +-+
+--R     6x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 99
+
+--S 100 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +------------+2
+--R             +-+      3|     +-+
+--R         (- \|3  + %i)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +------------+2     +----------+
+--R          +-+       3|     +-+          3|   +-+         3+-+
+--R       (2\|3  - 2%i)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                       +----------+2
+--R             +-+      3|   +-+
+--R         (- \|3  - %i)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+2     +------------+
+--R          +-+       3|   +-+          3|     +-+         3+-+
+--R       (2\|3  + 2%i)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                       +------------+2  +----------+2
+--R          3+-+    %pi 3|     +-+       3|   +-+
+--R         2\|2 cos(---)\|- %i\|3  + 1   \|%i\|3  + 1
+--R                   18
+--R      *
+--R                 %pi 2          %pi        %pi 2    2
+--R         log(sin(---)  + 2x sin(---) + cos(---)  + x )
+--R                  18             18         18
+--R     + 
+--R                                             +------------+2  +----------+2
+--R            3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (- \|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                         18             18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  - x sin(---) + cos(---)  + x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                                           +------------+2  +----------+2
+--R          3+-+ +-+    %pi    3+-+    %pi  3|     +-+       3|   +-+
+--R         (\|2 \|3 sin(---) - \|2 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                       18             18
+--R      *
+--R                 %pi 2         %pi        %pi 2     +-+    %pi     2
+--R         log(sin(---)  - x sin(---) + cos(---)  - x\|3 cos(---) + x )
+--R                  18            18         18               18
+--R     + 
+--R                                               +------------+2  +----------+2
+--R             3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (- 2\|2 sin(---) + 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                      18                  18
+--R      *
+--R                  +-+    %pi        %pi
+--R                 \|3 sin(---) + cos(---)
+--R                          18         18
+--R         atan(----------------------------)
+--R                  %pi     +-+    %pi
+--R              sin(---) - \|3 cos(---) - 2x
+--R                   18             18
+--R     + 
+--R                                             +------------+2  +----------+2
+--R           3+-+    %pi     3+-+ +-+    %pi  3|     +-+       3|   +-+
+--R         (2\|2 sin(---) + 2\|2 \|3 cos(---))\|- %i\|3  + 1   \|%i\|3  + 1
+--R                    18                  18
+--R      *
+--R                  +-+    %pi        %pi
+--R                 \|3 sin(---) - cos(---)
+--R                          18         18
+--R         atan(----------------------------)
+--R                  %pi     +-+    %pi
+--R              sin(---) + \|3 cos(---) - 2x
+--R                   18             18
+--R     + 
+--R                                                +------------+
+--R                       +----------+2     3+-+2 3|     +-+
+--R              +-+     3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (- 2%i\|3  - 6)\|%i\|3  + 1  atan(-------------------------)
+--R                                                    +------------+
+--R                                          3+-+2 +-+3|     +-+
+--R                                          \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                +----------+
+--R                     +------------+2     3+-+2 3|   +-+
+--R            +-+     3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (2%i\|3  - 6)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                    +----------+
+--R                                          3+-+2 +-+3|   +-+
+--R                                          \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                                                              %pi
+--R                     +------------+2  +----------+2       cos(---)
+--R        3+-+    %pi 3|     +-+       3|   +-+                  18
+--R       4\|2 sin(---)\|- %i\|3  + 1   \|%i\|3  + 1  atan(------------)
+--R                 18                                         %pi
+--R                                                        sin(---) + x
+--R                                                             18
+--R  /
+--R               +------------+2  +----------+2
+--R      3+-+ +-+3|     +-+       3|   +-+
+--R     6\|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 100
+
+--S 101 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 5    %pi 6      5    %pi 2    %pi 4      8    %pi 3
+--R               6x sin(---)  + 18x cos(---) sin(---)  + 12x sin(---)
+--R                       18              18       18              18
+--R             + 
+--R                   5    %pi 4       11      8      5  +-+    %pi      %pi 2
+--R               (18x cos(---)  + (12x   - 12x  + 12x )\|3 cos(---))sin(---)
+--R                         18                                   18       18
+--R             + 
+--R                    8    %pi 2    %pi      5    %pi 6
+--R               - 36x cos(---) sin(---) + 6x cos(---)
+--R                          18       18            18
+--R             + 
+--R                    11     8     5  +-+    %pi 3     11
+--R               (- 4x   + 4x  - 4x )\|3 cos(---)  + 6x
+--R                                            18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 6 3+-+    %pi 6     6 3+-+    %pi 2    %pi 4     9 3+-+    %pi 3
+--R               6x  \|2 sin(---) + 18x  \|2 cos(---) sin(---) + 12x  \|2 sin(---)
+--R                            18                  18       18                  18
+--R             + 
+--R                     6 3+-+    %pi 4      12      9      6 3+-+ +-+    %pi
+--R                 (18x  \|2 cos(---) + (12x   - 12x  + 12x )\|2 \|3 cos(---))
+--R                                18                                      18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    9 3+-+    %pi 2    %pi     6 3+-+    %pi 6
+--R               - 36x  \|2 cos(---) sin(--- + 6x  \|2 cos(---)
+--R                               18       18                18
+--R             + 
+--R                    12     9     6 3+-+ +-+    %pi 3     12 3+-+
+--R               (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  + 6x   \|2
+--R                                                18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 + 3x  \|2 )sin(---)
+--R                                              18
+--R         + 
+--R                   4 3+-+2 +-+    4 3+-+2    %pi 2    %pi 4
+--R           (- 9%i x  \|2  \|3 + 9x  \|2 )cos(---) sin(---)
+--R                                              18       18
+--R         + 
+--R                   7 3+-+2 +-+    7 3+-+2    %pi 3
+--R           (- 6%i x  \|2  \|3 + 6x  \|2 )sin(---)
+--R                                              18
+--R         + 
+--R                       4 3+-+2 +-+    4 3+-+2    %pi 4
+--R               (- 9%i x  \|2  \|3 + 9x  \|2 )cos(---)
+--R                                                  18
+--R             + 
+--R                      10     7     4 3+-+2 +-+
+--R                   (6x   - 6x  + 6x )\|2  \|3
+--R                 + 
+--R                            10         7         4 3+-+2
+--R                   (- 18%i x   + 18%i x  - 18%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  7 3+-+2 +-+     7 3+-+2    %pi 2    %pi
+--R           (18%i x  \|2  \|3 - 18x  \|2 )cos(---) sin(---)
+--R                                              18       18
+--R         + 
+--R                   4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (- 3%i x  \|2  \|3 + 3x  \|2 )cos(---)
+--R                                              18
+--R         + 
+--R                   10     7     4 3+-+2 +-+         10        7        4 3+-+2
+--R             ((- 2x   + 2x  - 2x )\|2  \|3  + (6%i x   - 6%i x  + 6%i x )\|2  )
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                  10 3+-+2 +-+    10 3+-+2
+--R           - 3%i x   \|2  \|3 + 3x   \|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 6 3+-+    %pi 6     6 3+-+    %pi 2    %pi 4     9 3+-+    %pi 3
+--R               6x  \|2 sin(---) + 18x  \|2 cos(---) sin(---) + 12x  \|2 sin(---)
+--R                            18                  18       18                  18
+--R             + 
+--R                     6 3+-+    %pi 4      12      9      6 3+-+ +-+    %pi
+--R                 (18x  \|2 cos(---) + (12x   - 12x  + 12x )\|2 \|3 cos(---))
+--R                                18                                      18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    9 3+-+    %pi 2    %pi     6 3+-+    %pi 6
+--R               - 36x  \|2 cos(---) sin(--- + 6x  \|2 cos(---)
+--R                               18       18                18
+--R             + 
+--R                    12     9     6 3+-+ +-+    %pi 3     12 3+-+
+--R               (- 4x   + 4x  - 4x )\|2 \|3 cos(---)  + 6x   \|2
+--R                                                18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                 7 3+-+2    %pi 6     7 3+-+2    %pi 2    %pi 4
+--R               6x  \|2  sin(---) + 18x  \|2  cos(---) sin(---)
+--R                             18                   18       18
+--R             + 
+--R                  10 3+-+2    %pi 3
+--R               12x   \|2  sin(---)
+--R                               18
+--R             + 
+--R                     7 3+-+2    %pi 4      13      10      7 3+-+2 +-+    %pi
+--R                 (18x  \|2  cos(---) + (12x   - 12x   + 12x )\|2  \|3 cos(---))
+--R                                 18                                        18
+--R              *
+--R                     %pi 2
+--R                 sin(---)
+--R                      18
+--R             + 
+--R                    10 3+-+2    %pi 2    %pi     7 3+-+2    %pi 6
+--R               - 36x   \|2  cos(---) sin(--- + 6x  \|2  cos(---)
+--R                                 18       18                 18
+--R             + 
+--R                    13     10     7 3+-+2 +-+    %pi 3     13 3+-+2
+--R               (- 4x   + 4x   - 4x )\|2  \|3 cos(---)  + 6x   \|2
+--R                                                  18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                   5 +-+     5     %pi 6
+--R           (- 6%i x \|3  + 6x )sin(---)
+--R                                    18
+--R         + 
+--R                    5 +-+      5     %pi 2    %pi 4
+--R           (- 18%i x \|3  + 18x )cos(---) sin(---)
+--R                                      18       18
+--R         + 
+--R                    8 +-+      8     %pi 3
+--R           (- 12%i x \|3  + 12x )sin(---)
+--R                                      18
+--R         + 
+--R                        5 +-+      5     %pi 4
+--R               (- 18%i x \|3  + 18x )cos(---)
+--R                                          18
+--R             + 
+--R                  11      8      5  +-+         11         8         5     %pi
+--R             ((12x   - 12x  + 12x )\|3  - 36%i x   + 36%i x  - 36%i x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                  8 +-+      8     %pi 2    %pi            5 +-+     5     %pi 6
+--R           (36%i x \|3  - 36x )cos(---) sin(---) + (- 6%i x \|3  + 6x )cos(---)
+--R                                    18       18                             18
+--R         + 
+--R                 11     8     5  +-+         11         8         5     %pi 3
+--R           ((- 4x   + 4x  - 4x )\|3  + 12%i x   - 12%i x  + 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                  11 +-+     11
+--R           - 6%i x  \|3  + 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                 4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 + 3x  \|2 )sin(---)
+--R                                            18
+--R         + 
+--R                 4 3+-+2 +-+    4 3+-+2    %pi 2    %pi 4
+--R           (9%i x  \|2  \|3 + 9x  \|2 )cos(---) sin(---)
+--R                                            18       18
+--R         + 
+--R                 7 3+-+2 +-+    7 3+-+2    %pi 3
+--R           (6%i x  \|2  \|3 + 6x  \|2 )sin(---)
+--R                                            18
+--R         + 
+--R                     4 3+-+2 +-+    4 3+-+2    %pi 4
+--R               (9%i x  \|2  \|3 + 9x  \|2 )cos(---)
+--R                                                18
+--R             + 
+--R                      10     7     4 3+-+2 +-+
+--R                   (6x   - 6x  + 6x )\|2  \|3
+--R                 + 
+--R                          10         7         4 3+-+2
+--R                   (18%i x   - 18%i x  + 18%i x )\|2
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7 3+-+2 +-+     7 3+-+2    %pi 2    %pi
+--R           (- 18%i x  \|2  \|3 - 18x  \|2 )cos(---) sin(---)
+--R                                                18       18
+--R         + 
+--R                 4 3+-+2 +-+    4 3+-+2    %pi 6
+--R           (3%i x  \|2  \|3 + 3x  \|2 )cos(---)
+--R                                            18
+--R         + 
+--R                      10     7     4 3+-+2 +-+
+--R                 (- 2x   + 2x  - 2x )\|2  \|3
+--R               + 
+--R                         10        7        4 3+-+2
+--R                 (- 6%i x   + 6%i x  - 6%i x )\|2
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  18
+--R         + 
+--R                10 3+-+2 +-+    10 3+-+2
+--R           3%i x   \|2  \|3 + 3x   \|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                 5 +-+     5     %pi 6          5 +-+      5     %pi 2    %pi 4
+--R           (6%i x \|3  + 6x )sin(---)  + (18%i x \|3  + 18x )cos(---) sin(---)
+--R                                  18                              18       18
+--R         + 
+--R                  8 +-+      8     %pi 3
+--R           (12%i x \|3  + 12x )sin(---)
+--R                                    18
+--R         + 
+--R                      5 +-+      5     %pi 4
+--R               (18%i x \|3  + 18x )cos(---)
+--R                                        18
+--R             + 
+--R                  11      8      5  +-+         11         8         5     %pi
+--R             ((12x   - 12x  + 12x )\|3  + 36%i x   - 36%i x  + 36%i x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8 +-+      8     %pi 2    %pi          5 +-+     5     %pi 6
+--R           (- 36%i x \|3  - 36x )cos(---) sin(---) + (6%i x \|3  + 6x )cos(---)
+--R                                      18       18                           18
+--R         + 
+--R                 11     8     5  +-+         11         8         5     %pi 3
+--R           ((- 4x   + 4x  - 4x )\|3  - 12%i x   + 12%i x  - 12%i x )cos(---)
+--R                                                                         18
+--R         + 
+--R                11 +-+     11
+--R           6%i x  \|3  + 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R          3 3+-+    %pi 6     3 3+-+    %pi 2    %pi 4     6 3+-+    %pi 3
+--R       12x  \|2 sin(---) + 36x  \|2 cos(---) sin(---) + 24x  \|2 sin(---)
+--R                     18                  18       18                  18
+--R     + 
+--R           3 3+-+    %pi 4      9      6      3 3+-+ +-+    %pi      %pi 2
+--R       (36x  \|2 cos(---) + (24x  - 24x  + 24x )\|2 \|3 cos(---))sin(---)
+--R                      18                                     18       18
+--R     + 
+--R            6 3+-+    %pi 2    %pi      3 3+-+    %pi 6
+--R       - 72x  \|2 cos(---) sin(--- + 12x  \|2 cos(---)
+--R                       18       18                 18
+--R     + 
+--R            9     6     3 3+-+ +-+    %pi 3      9 3+-+
+--R       (- 8x  + 8x  - 8x )\|2 \|3 cos(---)  + 12x  \|2
+--R                                       18
+--R  /
+--R                  8     5     2     %pi 6
+--R               (6x  - 6x  + 6x )sin(---)
+--R                                     18
+--R             + 
+--R                   8      5      2     %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                   11      8      5     %pi 3
+--R               (12x   - 12x  + 12x )sin(---)
+--R                                         18
+--R             + 
+--R                   8      5      2     %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )cos(---) sin(---)
+--R                                        18       18
+--R             + 
+--R                     11      8      5     %pi 2    %pi
+--R               (- 36x   + 36x  - 36x )cos(---) sin(---)
+--R                                           18       18
+--R             + 
+--R                  8     5     2     %pi 6     14     11     8
+--R               (6x  - 6x  + 6x )cos(---)  + 6x   - 6x   + 6x
+--R                                     18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 3
+--R               (12x   - 12x  + 12x )\|2 sin(---)
+--R                                             18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 2    %pi
+--R               (- 36x   + 36x  - 36x )\|2 cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      10        7        4 3+-+2 +-+      10     7     4 3+-+2
+--R             ((- 6%i x   + 6%i x  - 6%i x )\|2  \|3  + (6x   - 6x  + 6x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 9%i x  + 9%i x  - 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      10         7         4 3+-+2 +-+
+--R               (18%i x   - 18%i x  + 18%i x )\|2  \|3
+--R             + 
+--R                     10      7      4 3+-+2
+--R               (- 18x   + 18x  - 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                      7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((- 3%i x  + 3%i x  - 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  18
+--R         + 
+--R                   13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (- 3%i x   + 3%i x   - 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  9     6     3 3+-+    %pi 6
+--R               (6x  - 6x  + 6x )\|2 sin(---)
+--R                                         18
+--R             + 
+--R                   9      6      3 3+-+    %pi 2    %pi 4
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                   12      9      6 3+-+    %pi 3
+--R               (12x   - 12x  + 12x )\|2 sin(---)
+--R                                             18
+--R             + 
+--R                   9      6      3 3+-+    %pi 4    %pi 2
+--R               (18x  - 18x  + 18x )\|2 cos(---) sin(---)
+--R                                            18       18
+--R             + 
+--R                     12      9      6 3+-+    %pi 2    %pi
+--R               (- 36x   + 36x  - 36x )\|2 cos(---) sin(---)
+--R                                               18       18
+--R             + 
+--R                  9     6     3 3+-+    %pi 6      15     12     9 3+-+
+--R               (6x  - 6x  + 6x )\|2 cos(---)  + (6x   - 6x   + 6x )\|2
+--R                                         18
+--R          *
+--R              +------------+2
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                  10     7     4 3+-+2    %pi 6
+--R               (6x   - 6x  + 6x )\|2  sin(---)
+--R                                           18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 2    %pi 4
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                   13      10      7 3+-+2    %pi 3
+--R               (12x   - 12x   + 12x )\|2  sin(---)
+--R                                               18
+--R             + 
+--R                   10      7      4 3+-+2    %pi 4    %pi 2
+--R               (18x   - 18x  + 18x )\|2  cos(---) sin(---)
+--R                                              18       18
+--R             + 
+--R                     13      10      7 3+-+2    %pi 2    %pi
+--R               (- 36x   + 36x   - 36x )\|2  cos(---) sin(---)
+--R                                                 18       18
+--R             + 
+--R                  10     7     4 3+-+2    %pi 6      16     13     10 3+-+2
+--R               (6x   - 6x  + 6x )\|2  cos(---)  + (6x   - 6x   + 6x  )\|2
+--R                                           18
+--R          *
+--R              +------------+
+--R             3|     +-+
+--R             \|- %i\|3  + 1
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                    18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 2
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 3
+--R           ((- 12%i x   + 12%i x  - 12%i x )\|3  + 12x   - 12x  + 12x )sin(---)
+--R                                                                            18
+--R         + 
+--R                       8         5         2  +-+      8      5      2     %pi 4
+--R             ((- 18%i x  + 18%i x  - 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                     11         8         5  +-+      11      8      5     %pi 2
+--R             ((36%i x   - 36%i x  + 36%i x )\|3  - 36x   + 36x  - 36x )cos(---)
+--R                                                                            18
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    8        5        2  +-+     8     5     2     %pi 6
+--R           ((- 6%i x  + 6%i x  - 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                    18
+--R         + 
+--R                   14        11        8  +-+     14     11     8
+--R           (- 6%i x   + 6%i x   - 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|3  + 1
+--R     + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )sin(---)
+--R                                                                            18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 2    %pi 4
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                    10        7        4 3+-+2 +-+      10     7     4 3+-+2
+--R             ((6%i x   - 6%i x  + 6%i x )\|2  \|3  + (6x   - 6x  + 6x )\|2  )
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  18
+--R         + 
+--R                    7        4         3+-+2 +-+      7     4      3+-+2
+--R             ((9%i x  - 9%i x  + 9%i x)\|2  \|3  + (9x  - 9x  + 9x)\|2  )
+--R          *
+--R                 %pi 4    %pi 2
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                        10         7         4 3+-+2 +-+
+--R               (- 18%i x   + 18%i x  - 18%i x )\|2  \|3
+--R             + 
+--R                     10      7      4 3+-+2
+--R               (- 18x   + 18x  - 18x )\|2
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                  7        4         3+-+2 +-+      7     4      3+-+2     %pi 6
+--R           ((3%i x  - 3%i x  + 3%i x)\|2  \|3  + (3x  - 3x  + 3x)\|2  )cos(---)
+--R                                                                            18
+--R         + 
+--R                 13        10        7 3+-+2 +-+      13     10     7 3+-+2
+--R           (3%i x   - 3%i x   + 3%i x )\|2  \|3  + (3x   - 3x   + 3x )\|2
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )sin(---)
+--R                                                                  18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 2
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  18
+--R         + 
+--R                   11         8         5  +-+      11      8      5     %pi 3
+--R           ((12%i x   - 12%i x  + 12%i x )\|3  + 12x   - 12x  + 12x )sin(---)
+--R                                                                          18
+--R         + 
+--R                     8         5         2  +-+      8      5      2     %pi 4
+--R             ((18%i x  - 18%i x  + 18%i x )\|3  + 18x  - 18x  + 18x )cos(---)
+--R                                                                          18
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  18
+--R         + 
+--R                       11         8         5  +-+      11      8      5
+--R             ((- 36%i x   + 36%i x  - 36%i x )\|3  - 36x   + 36x  - 36x )
+--R          *
+--R                 %pi 2    %pi
+--R             cos(---) sin(---)
+--R                  18       18
+--R         + 
+--R                  8        5        2  +-+     8     5     2     %pi 6
+--R           ((6%i x  - 6%i x  + 6%i x )\|3  + 6x  - 6x  + 6x )cos(---)
+--R                                                                  18
+--R         + 
+--R                 14        11        8  +-+     14     11     8
+--R           (6%i x   - 6%i x   + 6%i x )\|3  + 6x   - 6x   + 6x
+--R      *
+--R          +------------+
+--R         3|     +-+
+--R         \|- %i\|3  + 1
+--R     + 
+--R           6      3      3+-+    %pi 6
+--R       (12x  - 12x  + 12)\|2 sin(---)
+--R                                  18
+--R     + 
+--R           6      3      3+-+    %pi 2    %pi 4
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R           9      6      3 3+-+    %pi 3
+--R       (24x  - 24x  + 24x )\|2 sin(---)
+--R                                    18
+--R     + 
+--R           6      3      3+-+    %pi 4    %pi 2
+--R       (36x  - 36x  + 36)\|2 cos(---) sin(---)
+--R                                  18       18
+--R     + 
+--R             9      6      3 3+-+    %pi 2    %pi
+--R       (- 72x  + 72x  - 72x )\|2 cos(---) sin(---)
+--R                                      18       18
+--R     + 
+--R           6      3      3+-+    %pi 6       12      9      6 3+-+
+--R       (12x  - 12x  + 12)\|2 cos(---)  + (12x   - 12x  + 12x )\|2
+--R                                  18
+--R                                           Type: Expression(Complex(Integer))
+--E 101
+
+)clear all
+
+--S 102 of 649
+t0:=(1-x^3)/(x^4*(1-x^3+x^6))
+--R 
+--R
+--R              3
+--R           - x  + 1
+--R   (1)  -------------
+--R         10    7    4
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 102
+
+--S 103 of 649
+r0:=(-1/3)/x^3+2/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                     3      +-+
+--R            3     (2x  - 1)\|3      +-+
+--R        - 2x atan(-------------) - \|3
+--R                        3
+--R   (2)  -------------------------------
+--R                      3 +-+
+--R                    3x \|3
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     3      +-+
+--R            3     (2x  - 1)\|3      +-+
+--R        - 2x atan(-------------) - \|3
+--R                        3
+--R   (3)  -------------------------------
+--R                      3 +-+
+--R                    3x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 104
+
+--S 105 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+--S 106 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 106
+
+)clear all
+
+--S 107 of 649
+t0:=x^2*(-2+x^3)/(1-x^3+x^6)
+--R 
+--R
+--R           5     2
+--R          x  - 2x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 107
+
+--S 108 of 649
+r0:=1/6*log(1-x^3+x^6)+atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                        3      +-+
+--R         +-+     6    3              (2x  - 1)\|3
+--R        \|3 log(x  - x  + 1) - 6atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           6\|3
+--R                                                    Type: Expression(Integer)
+--E 108
+
+--S 109 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        3      +-+
+--R         +-+     6    3              (2x  - 1)\|3
+--R        \|3 log(x  - x  + 1) - 6atan(-------------)
+--R                                           3
+--R   (3)  -------------------------------------------
+--R                             +-+
+--R                           6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 109
+
+--S 110 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 649
+t0:=(1+x^3)/(x*(1-x^3+x^6))
+--R 
+--R
+--R            3
+--R           x  + 1
+--R   (1)  -----------
+--R         7    4
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 112
+
+--S 113 of 649
+r0:=log(x)-1/6*log(1-x^3+x^6)-atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                        3      +-+
+--R           +-+     6    3          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 6\|3 log(x) + 6atan(-------------)
+--R                                                           3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   6\|3
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        3      +-+
+--R           +-+     6    3          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 6\|3 log(x) + 6atan(-------------)
+--R                                                           3
+--R   (3)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 114
+
+--S 115 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 116
+
+)clear all
+
+--S 117 of 649
+t0:=(d+e*x^3)^5*(a+b*x^3+c*x^6)
+--R 
+--R
+--R   (1)
+--R        5 21       5         4  18       5         4        2 3  15
+--R     c e x   + (b e  + 5c d e )x   + (a e  + 5b d e  + 10c d e )x
+--R   + 
+--R            4        2 3        3 2  12         2 3        3 2       4   9
+--R     (5a d e  + 10b d e  + 10c d e )x   + (10a d e  + 10b d e  + 5c d e)x
+--R   + 
+--R           3 2       4       5  6        4       5  3      5
+--R     (10a d e  + 5b d e + c d )x  + (5a d e + b d )x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 117
+
+--S 118 of 649
+r0:=a*d^5*x+1/4*d^4*(b*d+5*a*e)*x^4+1/7*d^3*(c*d^2+5*e*(b*d+2*a*e))*x^7+_
+   1/2*d^2*e*(c*d^2+2*e*(b*d+a*e))*x^10+5/13*d*e^2*(2*c*d^2+e*_
+   (2*b*d+a*e))*x^13+1/16*e^3*(10*c*d^2+e*(5*b*d+a*e))*x^16+_
+   1/19*e^4*(5*c*d+b*e)*x^19+1/22*c*e^5*x^22
+--R 
+--R
+--R   (2)
+--R      1    5 22     1    5    5      4  19     1    5    5      4   5    2 3  16
+--R     -- c e x   + (-- b e  + -- c d e )x   + (-- a e  + -- b d e  + - c d e )x
+--R     22            19        19               16        16          8
+--R   + 
+--R       5      4   10    2 3   10    3 2  13       2 3      3 2   1    4   10
+--R     (-- a d e  + -- b d e  + -- c d e )x   + (a d e  + b d e  + - c d e)x
+--R      13          13          13                                 2
+--R   + 
+--R      10    3 2   5    4    1    5  7    5    4    1    5  4      5
+--R     (-- a d e  + - b d e + - c d )x  + (- a d e + - b d )x  + a d x
+--R       7          7         7            4         4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 118
+
+--S 119 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    5 22     1    5    5      4  19     1    5    5      4   5    2 3  16
+--R     -- c e x   + (-- b e  + -- c d e )x   + (-- a e  + -- b d e  + - c d e )x
+--R     22            19        19               16        16          8
+--R   + 
+--R       5      4   10    2 3   10    3 2  13       2 3      3 2   1    4   10
+--R     (-- a d e  + -- b d e  + -- c d e )x   + (a d e  + b d e  + - c d e)x
+--R      13          13          13                                 2
+--R   + 
+--R      10    3 2   5    4    1    5  7    5    4    1    5  4      5
+--R     (-- a d e  + - b d e + - c d )x  + (- a d e + - b d )x  + a d x
+--R       7          7         7            4         4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 119
+
+--S 120 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 120
+
+--S 121 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 121
+
+)clear all
+
+--S 122 of 649
+t0:=(d+e*x^3)^4*(a+b*x^3+c*x^6)
+--R 
+--R
+--R   (1)
+--R        4 18       4         3  15       4         3       2 2  12
+--R     c e x   + (b e  + 4c d e )x   + (a e  + 4b d e  + 6c d e )x
+--R   + 
+--R            3       2 2       3   9        2 2       3       4  6
+--R     (4a d e  + 6b d e  + 4c d e)x  + (6a d e  + 4b d e + c d )x
+--R   + 
+--R          3       4  3      4
+--R     (4a d e + b d )x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 122
+
+--S 123 of 649
+r0:=a*d^4*x+1/4*d^3*(b*d+4*a*e)*x^4+1/7*d^2*(c*d^2+4*b*d*e+6*a*e^2)*x^7+_
+   1/5*d*e*(2*c*d^2+e*(3*b*d+2*a*e))*x^10+1/13*e^2*(6*c*d^2+_
+   e*(4*b*d+a*e))*x^13+1/16*e^3*(4*c*d+b*e)*x^16+1/19*c*e^4*x^19
+--R 
+--R
+--R   (2)
+--R      1    4 19     1    4   1      3  16     1    4    4      3    6    2 2  13
+--R     -- c e x   + (-- b e  + - c d e )x   + (-- a e  + -- b d e  + -- c d e )x
+--R     19            16        4               13        13          13
+--R   + 
+--R      2      3   3    2 2   2    3   10    6    2 2   4    3    1    4  7
+--R     (- a d e  + - b d e  + - c d e)x   + (- a d e  + - b d e + - c d )x
+--R      5          5          5              7          7         7
+--R   + 
+--R         3    1    4  4      4
+--R     (a d e + - b d )x  + a d x
+--R              4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 123
+
+--S 124 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    4 19     1    4   1      3  16     1    4    4      3    6    2 2  13
+--R     -- c e x   + (-- b e  + - c d e )x   + (-- a e  + -- b d e  + -- c d e )x
+--R     19            16        4               13        13          13
+--R   + 
+--R      2      3   3    2 2   2    3   10    6    2 2   4    3    1    4  7
+--R     (- a d e  + - b d e  + - c d e)x   + (- a d e  + - b d e + - c d )x
+--R      5          5          5              7          7         7
+--R   + 
+--R         3    1    4  4      4
+--R     (a d e + - b d )x  + a d x
+--R              4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 124
+
+--S 125 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 125
+
+--S 126 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 126
+
+)clear all
+
+--S 127 of 649
+t0:=(d+e*x^3)^3*(a+b*x^3+c*x^6)
+--R 
+--R
+--R   (1)
+--R        3 15       3         2  12       3         2       2   9
+--R     c e x   + (b e  + 3c d e )x   + (a e  + 3b d e  + 3c d e)x
+--R   + 
+--R            2       2       3  6        2       3  3      3
+--R     (3a d e  + 3b d e + c d )x  + (3a d e + b d )x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 127
+
+--S 128 of 649
+r0:=a*d^3*x+1/4*d^2*(b*d+3*a*e)*x^4+1/7*d*(c*d^2+3*e*(b*d+a*e))*x^7+_
+   1/10*e*(3*c*d^2+e*(3*b*d+a*e))*x^10+1/13*e^2*(3*c*d+b*e)*x^13+_
+   1/16*c*e^3*x^16
+--R 
+--R
+--R   (2)
+--R      1    3 16     1    3    3      2  13     1    3    3      2    3    2   10
+--R     -- c e x   + (-- b e  + -- c d e )x   + (-- a e  + -- b d e  + -- c d e)x
+--R     16            13        13               10        10          10
+--R   + 
+--R      3      2   3    2    1    3  7    3    2    1    3  4      3
+--R     (- a d e  + - b d e + - c d )x  + (- a d e + - b d )x  + a d x
+--R      7          7         7            4         4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 128
+
+--S 129 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    3 16     1    3    3      2  13     1    3    3      2    3    2   10
+--R     -- c e x   + (-- b e  + -- c d e )x   + (-- a e  + -- b d e  + -- c d e)x
+--R     16            13        13               10        10          10
+--R   + 
+--R      3      2   3    2    1    3  7    3    2    1    3  4      3
+--R     (- a d e  + - b d e + - c d )x  + (- a d e + - b d )x  + a d x
+--R      7          7         7            4         4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 129
+
+--S 130 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 130
+
+--S 131 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 131
+
+)clear all
+
+--S 132 of 649
+t0:=(d+e*x^3)^2*(a+b*x^3+c*x^6)
+--R 
+--R
+--R   (1)
+--R        2 12       2           9       2               2  6                2  3
+--R     c e x   + (b e  + 2c d e)x  + (a e  + 2b d e + c d )x  + (2a d e + b d )x
+--R   + 
+--R        2
+--R     a d
+--R                                                    Type: Polynomial(Integer)
+--E 132
+
+--S 133 of 649
+r0:=a*d^2*x+1/4*d*(b*d+2*a*e)*x^4+1/7*(c*d^2+e*(2*b*d+a*e))*x^7+_
+   1/10*e*(2*c*d+b*e)*x^10+1/13*c*e^2*x^13
+--R 
+--R
+--R   (2)
+--R      1    2 13     1    2   1        10    1    2   2         1    2  7
+--R     -- c e x   + (-- b e  + - c d e)x   + (- a e  + - b d e + - c d )x
+--R     13            10        5              7        7         7
+--R   + 
+--R      1         1    2  4      2
+--R     (- a d e + - b d )x  + a d x
+--R      2         4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 133
+
+--S 134 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    2 13     1    2   1        10    1    2   2         1    2  7
+--R     -- c e x   + (-- b e  + - c d e)x   + (- a e  + - b d e + - c d )x
+--R     13            10        5              7        7         7
+--R   + 
+--R      1         1    2  4      2
+--R     (- a d e + - b d )x  + a d x
+--R      2         4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 134
+
+--S 135 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 135
+
+--S 136 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 136
+
+)clear all
+
+--S 137 of 649
+t0:=(d+e*x^3)*(a+b*x^3+c*x^6)
+--R 
+--R
+--R             9               6               3
+--R   (1)  c e x  + (b e + c d)x  + (a e + b d)x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 137
+
+--S 138 of 649
+r0:=a*d*x+1/4*(b*d+a*e)*x^4+1/7*(c*d+b*e)*x^7+1/10*c*e*x^10
+--R 
+--R
+--R         1      10    1       1      7    1       1      4
+--R   (2)  -- c e x   + (- b e + - c d)x  + (- a e + - b d)x  + a d x
+--R        10            7       7           4       4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 138
+
+--S 139 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1      10    1       1      7    1       1      4
+--R   (3)  -- c e x   + (- b e + - c d)x  + (- a e + - b d)x  + a d x
+--R        10            7       7           4       4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 139
+
+--S 140 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 140
+
+--S 141 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 141
+
+)clear all
+
+--S 142 of 649
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)
+--R 
+--R
+--R           6      3
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R               3
+--R            e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 142
+
+--S 143 of 649
+r0:=-(c*d-b*e)*x/e^2+1/4*c*x^4/e+1/3*(c*d^2-b*d*e+a*e^2)*log(d^(1/3)+_
+   e^(1/3)*x)/(d^(2/3)*e^(7/3))-1/6*(c*d^2-b*d*e+a*e^2)*log(d^(2/3)-_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(2/3)*e^(7/3))-(c*d^2-b*d*e+a*e^2)*_
+   atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(7/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              2                2  +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- 2a e  + 2b d e - 2c d )\|3 log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R            2                2  +-+     3+-+   3+-+
+--R       (4a e  - 4b d e + 4c d )\|3 log(x\|e  + \|d )
+--R     + 
+--R                                         3+-+   3+-+
+--R             2                  2      2x\|e  - \|d
+--R       (12a e  - 12b d e + 12c d )atan(-------------)
+--R                                           +-+3+-+
+--R                                          \|3 \|d
+--R     + 
+--R              4                     +-+3+-+2 3+-+
+--R       (3c e x  + (12b e - 12c d)x)\|3 \|d   \|e
+--R  /
+--R        2 +-+3+-+2 3+-+
+--R     12e \|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                             +---+2      +---+
+--R              2                2  +-+     2 3| 2        3| 2      2
+--R       (- 2a e  + 2b d e - 2c d )\|3 log(x  \|d e  - d x\|d e  + d )
+--R     + 
+--R                                         +---+
+--R            2                2  +-+     3| 2
+--R       (4a e  - 4b d e + 4c d )\|3 log(x\|d e  + d)
+--R     + 
+--R                                              +---+
+--R                                          +-+3| 2       +-+
+--R             2                  2      2x\|3 \|d e  - d\|3
+--R       (12a e  - 12b d e + 12c d )atan(--------------------)
+--R                                                3d
+--R     + 
+--R                                        +---+
+--R              4                     +-+3| 2
+--R       (3c e x  + (12b e - 12c d)x)\|3 \|d e
+--R  /
+--R              +---+
+--R        2 +-+3| 2
+--R     12e \|3 \|d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 144
+
+--S 145 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +---+2      +---+
+--R             2              2  +-+3+-+2 3+-+     2 3| 2        3| 2      2
+--R       (- a e  + b d e - c d )\|3 \|d   \|e log(x  \|d e  - d x\|d e  + d )
+--R     + 
+--R                                                   +---+
+--R            2                2  +-+3+-+2 3+-+     3| 2
+--R       (2a e  - 2b d e + 2c d )\|3 \|d   \|e log(x\|d e  + d)
+--R     + 
+--R                                 +---+
+--R           2              2  +-+3| 2       2 3+-+2   3+-+3+-+   3+-+2
+--R       (a e  - b d e + c d )\|3 \|d e log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R                                      +---+
+--R              2                2  +-+3| 2       3+-+   3+-+
+--R       (- 2a e  + 2b d e - 2c d )\|3 \|d e log(x\|e  + \|d )
+--R     + 
+--R                                                     +---+
+--R                                                 +-+3| 2       +-+
+--R            2                2 3+-+2 3+-+     2x\|3 \|d e  - d\|3
+--R       (6a e  - 6b d e + 6c d )\|d   \|e atan(--------------------)
+--R                                                       3d
+--R     + 
+--R                                  +---+       3+-+   3+-+
+--R              2                2 3| 2       2x\|e  - \|d
+--R       (- 6a e  + 6b d e - 6c d )\|d e atan(-------------)
+--R                                                +-+3+-+
+--R                                               \|3 \|d
+--R  /
+--R                       +---+
+--R       2 +-+3+-+2 3+-+3| 2
+--R     6e \|3 \|d   \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 146
+
+)clear all
+
+--S 147 of 649
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^2
+--R 
+--R
+--R             6      3
+--R          c x  + b x  + a
+--R   (1)  -------------------
+--R         2 6         3    2
+--R        e x  + 2d e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 147
+
+--S 148 of 649
+r0:=c*x/e^2+1/3*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3))-1/9*(4*c*d^2-_
+   e*(b*d+2*a*e))*log(d^(1/3)+e^(1/3)*x)/(d^(5/3)*e^(7/3))+1/18*(4*c*d^2-_
+   e*(b*d+2*a*e))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(5/3)*_
+   e^(7/3))+1/3*(4*c*d^2-e*(b*d+2*a*e))*atan((d^(1/3)-2*e^(1/3)*x)/_
+   (d^(1/3)*sqrt(3)))/(d^(5/3)*e^(7/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                 3        2       2   3         2      2        3  +-+
+--R         ((- 2a e  - b d e  + 4c d e)x  - 2a d e  - b d e + 4c d )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R               3         2       2   3         2       2        3  +-+
+--R         ((4a e  + 2b d e  - 8c d e)x  + 4a d e  + 2b d e - 8c d )\|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|e  + \|d )
+--R     + 
+--R                3         2        2   3          2       2         3
+--R         ((12a e  + 6b d e  - 24c d e)x  + 12a d e  + 6b d e - 24c d )
+--R      *
+--R                3+-+   3+-+
+--R              2x\|e  - \|d
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|d
+--R     + 
+--R                 4        2                 2    +-+3+-+2 3+-+
+--R       (18c d e x  + (6a e  - 6b d e + 24c d )x)\|3 \|d   \|e
+--R  /
+--R           3 3      2 2  +-+3+-+2 3+-+
+--R     (18d e x  + 18d e )\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3        2       2   3         2      2        3  +-+
+--R         ((- 2a e  - b d e  + 4c d e)x  - 2a d e  - b d e + 4c d )\|3
+--R      *
+--R                 +---+2      +---+
+--R              2 3| 2        3| 2      2
+--R         log(x  \|d e  - d x\|d e  + d )
+--R     + 
+--R               3         2       2   3         2       2        3  +-+
+--R         ((4a e  + 2b d e  - 8c d e)x  + 4a d e  + 2b d e - 8c d )\|3
+--R      *
+--R               +---+
+--R              3| 2
+--R         log(x\|d e  + d)
+--R     + 
+--R                3         2        2   3          2       2         3
+--R         ((12a e  + 6b d e  - 24c d e)x  + 12a d e  + 6b d e - 24c d )
+--R      *
+--R                     +---+
+--R                 +-+3| 2       +-+
+--R              2x\|3 \|d e  - d\|3
+--R         atan(--------------------)
+--R                       3d
+--R     + 
+--R                                                     +---+
+--R                 4        2                 2    +-+3| 2
+--R       (18c d e x  + (6a e  - 6b d e + 24c d )x)\|3 \|d e
+--R  /
+--R                             +---+
+--R           3 3      2 2  +-+3| 2
+--R     (18d e x  + 18d e )\|3 \|d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 149
+
+--S 150 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +---+2      +---+
+--R              2               2  +-+3+-+2 3+-+     2 3| 2        3| 2      2
+--R       (- 2a e  - b d e + 4c d )\|3 \|d   \|e log(x  \|d e  - d x\|d e  + d )
+--R     + 
+--R                                                   +---+
+--R            2                2  +-+3+-+2 3+-+     3| 2
+--R       (4a e  + 2b d e - 8c d )\|3 \|d   \|e log(x\|d e  + d)
+--R     + 
+--R                                   +---+
+--R            2               2  +-+3| 2       2 3+-+2   3+-+3+-+   3+-+2
+--R       (2a e  + b d e - 4c d )\|3 \|d e log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R                                      +---+
+--R              2                2  +-+3| 2       3+-+   3+-+
+--R       (- 4a e  - 2b d e + 8c d )\|3 \|d e log(x\|e  + \|d )
+--R     + 
+--R                                                       +---+
+--R                                                   +-+3| 2       +-+
+--R             2                 2 3+-+2 3+-+     2x\|3 \|d e  - d\|3
+--R       (12a e  + 6b d e - 24c d )\|d   \|e atan(--------------------)
+--R                                                         3d
+--R     + 
+--R                                    +---+       3+-+   3+-+
+--R               2                 2 3| 2       2x\|e  - \|d
+--R       (- 12a e  - 6b d e + 24c d )\|d e atan(-------------)
+--R                                                  +-+3+-+
+--R                                                 \|3 \|d
+--R  /
+--R                          +---+
+--R          2 +-+3+-+2 3+-+3| 2
+--R     18d e \|3 \|d   \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 150
+
+--S 151 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 151
+
+)clear all
+
+--S 152 of 649
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^3
+--R 
+--R
+--R                  6      3
+--R               c x  + b x  + a
+--R   (1)  -----------------------------
+--R         3 9       2 6     2   3    3
+--R        e x  + 3d e x  + 3d e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 152
+
+--S 153 of 649
+r0:=1/6*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3)^2)-1/18*(7*c*d^2-_
+   e*(b*d+5*a*e))*x/(d^2*e^2*(d+e*x^3))+1/27*(2*c*d^2+e*(b*d+5*a*e))*_
+   log(d^(1/3)+e^(1/3)*x)/(d^(8/3)*e^(7/3))-1/54*(2*c*d^2+e*(b*d+5*a*e))*_
+   log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(8/3)*e^(7/3))-_
+   1/9*(2*c*d^2+e*(b*d+5*a*e))*atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*_
+   sqrt(3)))/(d^(8/3)*e^(7/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                  4        3       2 2  6             3       2 2       3   3
+--R           (- 5a e  - b d e  - 2c d e )x  + (- 10a d e  - 2b d e  - 4c d e)x
+--R         + 
+--R                 2 2      3        4
+--R           - 5a d e  - b d e - 2c d
+--R      *
+--R          +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R         \|3 log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R                 4         3       2 2  6           3       2 2       3   3
+--R           (10a e  + 2b d e  + 4c d e )x  + (20a d e  + 4b d e  + 8c d e)x
+--R         + 
+--R                2 2       3        4
+--R           10a d e  + 2b d e + 4c d
+--R      *
+--R          +-+     3+-+   3+-+
+--R         \|3 log(x\|e  + \|d )
+--R     + 
+--R                 4         3        2 2  6           3        2 2        3   3
+--R           (30a e  + 6b d e  + 12c d e )x  + (60a d e  + 12b d e  + 24c d e)x
+--R         + 
+--R                2 2       3         4
+--R           30a d e  + 6b d e + 12c d
+--R      *
+--R                3+-+   3+-+
+--R              2x\|e  - \|d
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|d
+--R     + 
+--R                3         2        2   4           2       2         3    +-+
+--R         ((15a e  + 3b d e  - 21c d e)x  + (24a d e  - 6b d e - 12c d )x)\|3
+--R      *
+--R         3+-+2 3+-+
+--R         \|d   \|e
+--R  /
+--R         2 4 6       3 3 3      4 2  +-+3+-+2 3+-+
+--R     (54d e x  + 108d e x  + 54d e )\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 153
+
+--S 154 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  4        3       2 2  6             3       2 2       3   3
+--R           (- 5a e  - b d e  - 2c d e )x  + (- 10a d e  - 2b d e  - 4c d e)x
+--R         + 
+--R                 2 2      3        4
+--R           - 5a d e  - b d e - 2c d
+--R      *
+--R                     +---+2      +---+
+--R          +-+     2 3| 2        3| 2      2
+--R         \|3 log(x  \|d e  - d x\|d e  + d )
+--R     + 
+--R                 4         3       2 2  6           3       2 2       3   3
+--R           (10a e  + 2b d e  + 4c d e )x  + (20a d e  + 4b d e  + 8c d e)x
+--R         + 
+--R                2 2       3        4
+--R           10a d e  + 2b d e + 4c d
+--R      *
+--R                   +---+
+--R          +-+     3| 2
+--R         \|3 log(x\|d e  + d)
+--R     + 
+--R                 4         3        2 2  6           3        2 2        3   3
+--R           (30a e  + 6b d e  + 12c d e )x  + (60a d e  + 12b d e  + 24c d e)x
+--R         + 
+--R                2 2       3         4
+--R           30a d e  + 6b d e + 12c d
+--R      *
+--R                     +---+
+--R                 +-+3| 2       +-+
+--R              2x\|3 \|d e  - d\|3
+--R         atan(--------------------)
+--R                       3d
+--R     + 
+--R                                                                          +---+
+--R            3         2        2   4           2       2         3    +-+3| 2
+--R     ((15a e  + 3b d e  - 21c d e)x  + (24a d e  - 6b d e - 12c d )x)\|3 \|d e
+--R  /
+--R                                         +---+
+--R         2 4 6       3 3 3      4 2  +-+3| 2
+--R     (54d e x  + 108d e x  + 54d e )\|3 \|d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 154
+
+--S 155 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +---+2      +---+
+--R              2               2  +-+3+-+2 3+-+     2 3| 2        3| 2      2
+--R       (- 5a e  - b d e - 2c d )\|3 \|d   \|e log(x  \|d e  - d x\|d e  + d )
+--R     + 
+--R                                                    +---+
+--R             2                2  +-+3+-+2 3+-+     3| 2
+--R       (10a e  + 2b d e + 4c d )\|3 \|d   \|e log(x\|d e  + d)
+--R     + 
+--R                                   +---+
+--R            2               2  +-+3| 2       2 3+-+2   3+-+3+-+   3+-+2
+--R       (5a e  + b d e + 2c d )\|3 \|d e log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R                                       +---+
+--R               2                2  +-+3| 2       3+-+   3+-+
+--R       (- 10a e  - 2b d e - 4c d )\|3 \|d e log(x\|e  + \|d )
+--R     + 
+--R                                                       +---+
+--R                                                   +-+3| 2       +-+
+--R             2                 2 3+-+2 3+-+     2x\|3 \|d e  - d\|3
+--R       (30a e  + 6b d e + 12c d )\|d   \|e atan(--------------------)
+--R                                                         3d
+--R     + 
+--R                                    +---+       3+-+   3+-+
+--R               2                 2 3| 2       2x\|e  - \|d
+--R       (- 30a e  - 6b d e - 12c d )\|d e atan(-------------)
+--R                                                  +-+3+-+
+--R                                                 \|3 \|d
+--R  /
+--R                          +---+
+--R        2 2 +-+3+-+2 3+-+3| 2
+--R     54d e \|3 \|d   \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 649
+t0:=(d+e*x^3)^(3/2)*(a+b*x^3+c*x^6)
+--R 
+--R
+--R                                                       +--------+
+--R              9               6               3        |   3
+--R   (1)  (c e x  + (b e + c d)x  + (a e + b d)x  + a d)\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 649
+--r0:=2/4301*(16*c*d^2-46*b*d*e+391*a*e^2)*x*(d+e*x^3)^(3/2)/e^2-_
+--  2/15*(c*d^2-b*d*e+a*e^2)*x*(d+e*x^3)^(5/2)/(d*e^2)+2/5865*(16*c*d^2-_
+--  46*b*d*e+391*a*e^2)*x*(d+e*x^3)^(5/2)/(d*e^2)+2/23*c*x*_
+--  (d+e*x^3)^(7/2)/e^2+18/21505*d*(16*c*d^2-46*b*d*e+391*a*e^2)*x*_
+--  sqrt(d+e*x^3)/e^2+27/21505*d^(13/6)*(16*c*d^2-23*e*(2*b*d-17*a*e))*_
+--  elliptic_f(asin(e^(1/6)*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3)))/(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)*sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*_
+--  sqrt((2*e^(2/3)*x+d^(1/3)*(-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*_
+--  (-3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*_
+--  (e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))/(e^(5/2)*sqrt(d+e*x^3))
+--E 158
+
+--S 159 of 649
+--a0:=integrate(t0,x)
+--E 159
+
+--S 160 of 649
+--m0:=a0-r0
+--E 160
+
+--S 161 of 649
+--d0:=D(m0,x)
+--E 161
+
+)clear all
+
+--S 162 of 649
+t0:=(d+e*x^3)^(1/2)*(a+b*x^3+c*x^6)
+--R 
+--R
+--R                          +--------+
+--R            6      3      |   3
+--R   (1)  (c x  + b x  + a)\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 649
+--r0:=-2/9*(c*d^2-b*d*e+a*e^2)*x*(d+e*x^3)^(3/2)/(d*e^2)+2/1683*_
+--  (16*c*d^2-34*b*d*e+187*a*e^2)*x*(d+e*x^3)^(3/2)/(d*e^2)+2/17*c*x*_
+--  (d+e*x^3)^(5/2)/e^2+2/935*(16*c*d^2-34*b*d*e+187*a*e^2)*x*_
+--  sqrt(d+e*x^3)/e^2+3/935*d^(7/6)*(16*c*d^2-17*e*(2*b*d-11*a*e))*_
+--  elliptic_f(asin(e^(1/6)*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3)))/(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)*sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*_
+--  sqrt((2*e^(2/3)*x+d^(1/3)*(-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*_
+--  (-3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*_
+--  (e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))/(e^(5/2)*sqrt(d+e*x^3))
+--E 163
+
+--S 164 of 649
+--a0:=integrate(t0,x)
+--E 164
+
+--S 165 of 649
+--m0:=a0-r0
+--E 165
+
+--S 166 of 649
+--d0:=D(m0,x)
+--E 166
+
+)clear all
+
+--S 167 of 649
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(1/2)
+--R 
+--R
+--R           6      3
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R           +--------+
+--R           |   3
+--R          \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 649
+--r0:=2/11*c*x*(d+e*x^3)^(3/2)/e^2-2/3*(c*d^2-b*d*e+a*e^2)*x*_
+--  sqrt(d+e*x^3)/(d*e^2)+2/165*(16*c*d^2-22*b*d*e+55*a*e^2)*x*_
+--  sqrt(d+e*x^3)/(d*e^2)+1/55*d^(1/6)*(16*c*d^2-11*e*(2*b*d-5*a*e))*_
+--  elliptic_f(asin(e^(1/6)*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3)))/(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)*sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*_
+--  sqrt((2*e^(2/3)*x+d^(1/3)*(-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*_
+--  (-3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*_
+--  (e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))/(e^(5/2)*sqrt(d+e*x^3))
+--E 168
+
+--S 169 of 649
+--a0:=integrate(t0,x)
+--E 169
+
+--S 170 of 649
+--m0:=a0-r0
+--E 170
+
+--S 171 of 649
+--d0:=D(m0,x)
+--E 171
+
+)clear all
+
+--S 172 of 649
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(3/2)
+--R 
+--R
+--R              6      3
+--R           c x  + b x  + a
+--R   (1)  ---------------------
+--R                   +--------+
+--R            3      |   3
+--R        (e x  + d)\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 649
+--r0:=2/3*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*sqrt(d+e*x^3))+2/5*c*x*_
+--  sqrt(d+e*x^3)/e^2-1/15*(16*c*d^2-5*e*(2*b*d+a*e))*_
+--  elliptic_f(asin(e^(1/6)*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3)))/(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)*sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*_
+--  sqrt((2*e^(2/3)*x+d^(1/3)*(-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*_
+--  (-3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*_
+--  (e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))/(d^(5/6)*e^(5/2)*sqrt(d+e*x^3))
+--E 173
+
+--S 174 of 649
+--a0:=integrate(t0,x)
+--E 174
+
+--S 175 of 649
+--m0:=a0-r0
+--E 175
+
+--S 176 of 649
+--d0:=D(m0,x)
+--E 176
+
+)clear all
+
+--S 177 of 649
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(5/2)
+--R 
+--R
+--R                    6      3
+--R                 c x  + b x  + a
+--R   (1)  --------------------------------
+--R                              +--------+
+--R          2 6         3    2  |   3
+--R        (e x  + 2d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 649
+--r0:=2/9*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3)^(3/2))-_
+--  2/27*(11*c*d^2-2*b*d*e-7*a*e^2)*x/(d^2*e^2*sqrt(d+e*x^3))+_
+--  1/27*(16*c*d^2+e*(2*b*d+7*a*e))*elliptic_f(asin(e^(1/6)*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*sqrt(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))/(3*e^(1/3)+_
+--  sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*sqrt((2*e^(2/3)*x+d^(1/3)*_
+--  (-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(-3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*(e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))/_
+--  (d^(11/6)*e^(5/2)*sqrt(d+e*x^3))
+--E 178
+
+--S 179 of 649
+--a0:=integrate(t0,x)
+--E 179
+
+--S 180 of 649
+--m0:=a0-r0
+--E 180
+
+--S 181 of 649
+--d0:=D(m0,x)
+--E 181
+
+)clear all
+
+--S 182 of 649
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(7/2)
+--R 
+--R
+--R                         6      3
+--R                      c x  + b x  + a
+--R   (1)  ------------------------------------------
+--R                                        +--------+
+--R          3 9       2 6     2   3    3  |   3
+--R        (e x  + 3d e x  + 3d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 649
+--r0:=2/15*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3)^(5/2))-_
+--  2/135*(17*c*d^2-2*b*d*e-13*a*e^2)*x/(d^2*e^2*(d+e*x^3)^(3/2))+_
+--  2/405*(16*c*d^2+14*b*d*e+91*a*e^2)*x/(d^3*e^2*sqrt(d+e*x^3))+_
+--  1/405*(16*c*d^2+7*e*(2*b*d+13*a*e))*elliptic_f(asin(e^(1/6)*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*sqrt(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))/(3*e^(1/3)+_
+--  sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*sqrt((2*e^(2/3)*x+d^(1/3)*_
+--  (-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(-3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*(e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))/_
+--  (d^(17/6)*e^(5/2)*sqrt(d+e*x^3))
+--E 183
+
+--S 184 of 649
+--a0:=integrate(t0,x)
+--E 184
+
+--S 185 of 649
+--m0:=a0-r0
+--E 185
+
+--S 186 of 649
+--d0:=D(m0,x)
+--E 186
+
+)clear all
+
+--S 187 of 649
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(9/2)
+--R 
+--R
+--R                              6      3
+--R                           c x  + b x  + a
+--R   (1)  -----------------------------------------------------
+--R                                                   +--------+
+--R          4 12       3 9     2 2 6     3   3    4  |   3
+--R        (e x   + 4d e x  + 6d e x  + 4d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 649
+--r0:=2/21*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3)^(7/2))-_
+--  2/315*(23*c*d^2-2*b*d*e-19*a*e^2)*x/(d^2*e^2*(d+e*x^3)^(5/2))+_
+--  2/2835*(16*c*d^2+26*b*d*e+247*a*e^2)*x/(d^3*e^2*(d+e*x^3)^(3/2))+_
+--  2/1215*(16*c*d^2+26*b*d*e+247*a*e^2)*x/(d^4*e^2*sqrt(d+e*x^3))+_
+--  1/1215*(16*c*d^2+13*e*(2*b*d+19*a*e))*elliptic_f(asin(e^(1/6)*_
+--  sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*sqrt(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))/(3*e^(1/3)+_
+--  sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*sqrt((2*e^(2/3)*x+d^(1/3)*_
+--  (-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(-3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*(e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))/_
+--  (d^(23/6)*e^(5/2)*sqrt(d+e*x^3))
+--E 188
+
+--S 189 of 649
+--a0:=integrate(t0,x)
+--E 189
+
+--S 190 of 649
+--m0:=a0-r0
+--E 190
+
+--S 191 of 649
+--d0:=D(m0,x)
+--E 191
+
+)clear all
+
+--S 192 of 649
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(11/2)
+--R 
+--R
+--R                                     6      3
+--R                                  c x  + b x  + a
+--R   (1)  ------------------------------------------------------------------
+--R                                                                +--------+
+--R          5 15       4 12      2 3 9      3 2 6     4   3    5  |   3
+--R        (e x   + 5d e x   + 10d e x  + 10d e x  + 5d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 649
+--r0:=2/27*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3)^(9/2))-_
+--  2/567*(29*c*d^2-2*b*d*e-25*a*e^2)*x/(d^2*e^2*(d+e*x^3)^(7/2))+_
+--  2/8505*(16*c*d^2+38*b*d*e+475*a*e^2)*x/(d^3*e^2*(d+e*x^3)^(5/2))+_
+--  26/76545*(16*c*d^2+38*b*d*e+475*a*e^2)*x/(d^4*e^2*(d+e*x^3)^(3/2))+_
+--  26/32805*(16*c*d^2+38*b*d*e+475*a*e^2)*x/(d^5*e^2*sqrt(d+e*x^3))+_
+--  13/32805*(16*c*d^2+19*e*(2*b*d+25*a*e))*elliptic_f(asin(e^(1/6)*_
+--  sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*sqrt(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))/(3*e^(1/3)+_
+--  sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*sqrt((2*e^(2/3)*x+d^(1/3)*_
+--  (-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(-3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*(e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))/_
+--  (d^(29/6)*e^(5/2)*sqrt(d+e*x^3))
+--E 193
+
+--S 194 of 649
+--a0:=integrate(t0,x)
+--E 194
+
+--S 195 of 649
+--m0:=a0-r0
+--E 195
+
+--S 196 of 649
+--d0:=D(m0,x)
+--E 196
+
+)clear all
+
+--S 197 of 649
+t0:=x^4*(d+e*x^4)/(a+b*x^4+c*x^8)
+--R 
+--R
+--R             8      4
+--R          e x  + d x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 197
+
+--S 198 of 649
+r0:=e*x/c-1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-_
+   4*a*c))/(2^(1/4)*c^(5/4)*(-b-sqrt(b^2-4*a*c))^(3/4))-_
+   1/2*atan(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(c*d-b*e+_
+   (-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(5/4)*(-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                      +-----------+
+--R                      |          2               2
+--R         ((b e - c d)\|- 4a c + b   + (- 2a c + b )e - b c d)
+--R      *
+--R          +------------------+3
+--R          | +-----------+                    4+-+4+-+
+--R         4| |          2                    x\|2 \|c
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                      +-----------+
+--R                      |          2             2
+--R         ((b e - c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                   4+-+4+-+
+--R         4|   |          2                   x\|2 \|c
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                      +-----------+
+--R                      |          2               2
+--R         ((b e - c d)\|- 4a c + b   + (- 2a c + b )e - b c d)
+--R      *
+--R          +------------------+3
+--R          | +-----------+                   4+-+4+-+
+--R         4| |          2                   x\|2 \|c
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                      +-----------+
+--R                      |          2             2
+--R         ((b e - c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                  4+-+4+-+
+--R         4|   |          2                  x\|2 \|c
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                  +--------------------+3  +------------------+3
+--R                +-----------+     |   +-----------+        | +-----------+
+--R           4+-+ |          2 4+-+4|   |          2        4| |          2
+--R       2e x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+3  +------------------+3
+--R            +-----------+     |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 198
+
+--S 199 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 7          2 6       4 5
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                          2   2       3     5  4      2 3        2 2     4     3
+--R                     (- 5a b c  + 5a b c - b )e  + (8a c  - 16a b c  + 4b c)d e
+--R                   + 
+--R                             3     3 2  2 2          4     2 3  3       4 4
+--R                     (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                            2   7          3 6       5 5
+--R                      (4096a b c  - 2048a b c  + 256b c )e
+--R                    + 
+--R                              2 8          2 7       4 6
+--R                      (- 8192a c  + 4096a b c  - 512b c )d
+--R                 *
+--R                    ROOT
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     7
+--R                           (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                         + 
+--R                               3 5       2 2 4         4 3      6 2  2 6
+--R                           (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                         + 
+--R                                2   5         3 4      5 3  3 5
+--R                           (104a b c  - 168a b c  + 56b c )d e
+--R                         + 
+--R                                 2 6         2 5      4 4  4 4
+--R                           (- 38a c  + 142a b c  - 70b c )d e
+--R                         + 
+--R                                     6      3 5  5 3         7      2 6  6 2
+--R                           (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                         + 
+--R                               7 7     8 8
+--R                           8b c d e - c d
+--R                      /
+--R                                   3 13           2 2 12            4 11
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 10
+--R                           - 65536b c
+--R                + 
+--R                       3 3      2 2 2       4     6  5
+--R                  (- 4a c  + 13a b c  - 7a b c + b )e
+--R                + 
+--R                        2   3        3 2     5     4
+--R                  (- 32a b c  + 24a b c  - 4b c)d e
+--R                + 
+--R                      2 4        2 3     4 2  2 3           4     3 3  3 2
+--R                  (24a c  - 30a b c  + 6b c )d e  + (16a b c  - 4b c )d e
+--R                + 
+--R                         5    2 4  4
+--R                  (- 4a c  + b c )d e
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 7          2 6       4 5
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                              4 4     3 2 3      2 4 2       6
+--R                                           - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                         + 
+--R                                              8
+--R                                           - b
+--R                                    *
+--R                                        8
+--R                                       e
+--R                                   + 
+--R                                             3   4      2 3 3        5 2     7
+--R                                       (- 16a b c  + 56a b c  - 40a b c  + 8b c)
+--R                                    *
+--R                                          7
+--R                                       d e
+--R                                   + 
+--R                                           3 5       2 2 4         4 3      6 2
+--R                                       (12a c  - 112a b c  + 112a b c  - 28b c )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                          2   5         3 4      5 3  3 5
+--R                                     (104a b c  - 168a b c  + 56b c )d e
+--R                                   + 
+--R                                           2 6         2 5      4 4  4 4
+--R                                     (- 38a c  + 142a b c  - 70b c )d e
+--R                                   + 
+--R                                               6      3 5  5 3
+--R                                     (- 64a b c  + 56b c )d e
+--R                                   + 
+--R                                           7      2 6  6 2       7 7     8 8
+--R                                     (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )e
+--R                          + 
+--R                               2 3        2 2     4     3
+--R                            (8a c  - 16a b c  + 4b c)d e
+--R                          + 
+--R                                  3     3 2  2 2          4     2 3  3       4 4
+--R                          (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                    3 2     2 2       4  6      2   2      3     5    5
+--R                  (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                + 
+--R                       2 3       2 2     4   2 4           3      3 2  3 3
+--R                  (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                + 
+--R                         4      2 3  4 2       4 5     5 6
+--R                  (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 7          2 6       4 5
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                               + 
+--R                                       3   4      2 3 3        5 2     7     7
+--R                                 (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                               + 
+--R                                     3 5       2 2 4         4 3      6 2  2 6
+--R                                 (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                               + 
+--R                                      2   5         3 4      5 3  3 5
+--R                                 (104a b c  - 168a b c  + 56b c )d e
+--R                               + 
+--R                                       2 6         2 5      4 4  4 4
+--R                                 (- 38a c  + 142a b c  - 70b c )d e
+--R                               + 
+--R                                           6      3 5  5 3
+--R                                 (- 64a b c  + 56b c )d e
+--R                               + 
+--R                                       7      2 6  6 2       7 7     8 8
+--R                                 (12a c  - 28b c )d e  + 8b c d e - c d
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                             2   2       3     5  4
+--R                        (- 5a b c  + 5a b c - b )e
+--R                      + 
+--R                           2 3        2 2     4     3           3     3 2  2 2
+--R                        (8a c  - 16a b c  + 4b c)d e  + (18a b c  - 6b c )d e
+--R                      + 
+--R                               4     2 3  3       4 4
+--R                        (- 8a c  + 4b c )d e - b c d
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                               2   7          3 6       5 5
+--R                         (4096a b c  - 2048a b c  + 256b c )e
+--R                       + 
+--R                                 2 8          2 7       4 6
+--R                         (- 8192a c  + 4096a b c  - 512b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                        3 3      2 2 2       4     6  5
+--R                     (4a c  - 13a b c  + 7a b c - b )e
+--R                   + 
+--R                         2   3        3 2     5     4
+--R                     (32a b c  - 24a b c  + 4b c)d e
+--R                   + 
+--R                           2 4        2 3     4 2  2 3
+--R                     (- 24a c  + 30a b c  - 6b c )d e
+--R                   + 
+--R                               4     3 3  3 2        5    2 4  4
+--R                     (- 16a b c  + 4b c )d e  + (4a c  - b c )d e
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 7          2 6       4 5
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          e
+--R                                      + 
+--R                                                 3   4      2 3 3        5 2
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                              7
+--R                                            8b c
+--R                                       *
+--R                                             7
+--R                                          d e
+--R                                      + 
+--R                                               3 5       2 2 4         4 3
+--R                                            12a c  - 112a b c  + 112a b c
+--R                                          + 
+--R                                                 6 2
+--R                                            - 28b c
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                             2   5         3 4      5 3  3 5
+--R                                        (104a b c  - 168a b c  + 56b c )d e
+--R                                      + 
+--R                                              2 6         2 5      4 4  4 4
+--R                                        (- 38a c  + 142a b c  - 70b c )d e
+--R                                      + 
+--R                                                  6      3 5  5 3
+--R                                        (- 64a b c  + 56b c )d e
+--R                                      + 
+--R                                              7      2 6  6 2       7 7     8 8
+--R                                        (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )e
+--R                             + 
+--R                                  2 3        2 2     4     3
+--R                               (8a c  - 16a b c  + 4b c)d e
+--R                             + 
+--R                                       3     3 2  2 2          4     2 3  3
+--R                               (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e
+--R                             + 
+--R                                    4 4
+--R                               - b c d
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                       3 2     2 2       4  6      2   2      3     5    5
+--R                     (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                   + 
+--R                          2 3       2 2     4   2 4           3      3 2  3 3
+--R                     (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                   + 
+--R                            4      2 3  4 2       4 5     5 6
+--R                     (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R                *
+--R                   x
+--R     + 
+--R         c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 7          2 6       4 5
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                          2   2       3     5  4      2 3        2 2     4     3
+--R                     (- 5a b c  + 5a b c - b )e  + (8a c  - 16a b c  + 4b c)d e
+--R                   + 
+--R                             3     3 2  2 2          4     2 3  3       4 4
+--R                     (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                              2   7          3 6       5 5
+--R                      (- 4096a b c  + 2048a b c  - 256b c )e
+--R                    + 
+--R                            2 8          2 7       4 6
+--R                      (8192a c  - 4096a b c  + 512b c )d
+--R                 *
+--R                    ROOT
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     7
+--R                           (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                         + 
+--R                               3 5       2 2 4         4 3      6 2  2 6
+--R                           (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                         + 
+--R                                2   5         3 4      5 3  3 5
+--R                           (104a b c  - 168a b c  + 56b c )d e
+--R                         + 
+--R                                 2 6         2 5      4 4  4 4
+--R                           (- 38a c  + 142a b c  - 70b c )d e
+--R                         + 
+--R                                     6      3 5  5 3         7      2 6  6 2
+--R                           (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                         + 
+--R                               7 7     8 8
+--R                           8b c d e - c d
+--R                      /
+--R                                   3 13           2 2 12            4 11
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 10
+--R                           - 65536b c
+--R                + 
+--R                       3 3      2 2 2       4     6  5
+--R                  (- 4a c  + 13a b c  - 7a b c + b )e
+--R                + 
+--R                        2   3        3 2     5     4
+--R                  (- 32a b c  + 24a b c  - 4b c)d e
+--R                + 
+--R                      2 4        2 3     4 2  2 3           4     3 3  3 2
+--R                  (24a c  - 30a b c  + 6b c )d e  + (16a b c  - 4b c )d e
+--R                + 
+--R                         5    2 4  4
+--R                  (- 4a c  + b c )d e
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 7          2 6       4 5
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                              4 4     3 2 3      2 4 2       6
+--R                                           - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                         + 
+--R                                              8
+--R                                           - b
+--R                                    *
+--R                                        8
+--R                                       e
+--R                                   + 
+--R                                             3   4      2 3 3        5 2     7
+--R                                       (- 16a b c  + 56a b c  - 40a b c  + 8b c)
+--R                                    *
+--R                                          7
+--R                                       d e
+--R                                   + 
+--R                                           3 5       2 2 4         4 3      6 2
+--R                                       (12a c  - 112a b c  + 112a b c  - 28b c )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                          2   5         3 4      5 3  3 5
+--R                                     (104a b c  - 168a b c  + 56b c )d e
+--R                                   + 
+--R                                           2 6         2 5      4 4  4 4
+--R                                     (- 38a c  + 142a b c  - 70b c )d e
+--R                                   + 
+--R                                               6      3 5  5 3
+--R                                     (- 64a b c  + 56b c )d e
+--R                                   + 
+--R                                           7      2 6  6 2       7 7     8 8
+--R                                     (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )e
+--R                          + 
+--R                               2 3        2 2     4     3
+--R                            (8a c  - 16a b c  + 4b c)d e
+--R                          + 
+--R                                  3     3 2  2 2          4     2 3  3       4 4
+--R                          (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                    3 2     2 2       4  6      2   2      3     5    5
+--R                  (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                + 
+--R                       2 3       2 2     4   2 4           3      3 2  3 3
+--R                  (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                + 
+--R                         4      2 3  4 2       4 5     5 6
+--R                  (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 7          2 6       4 5
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                               + 
+--R                                       3   4      2 3 3        5 2     7     7
+--R                                 (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                               + 
+--R                                     3 5       2 2 4         4 3      6 2  2 6
+--R                                 (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                               + 
+--R                                      2   5         3 4      5 3  3 5
+--R                                 (104a b c  - 168a b c  + 56b c )d e
+--R                               + 
+--R                                       2 6         2 5      4 4  4 4
+--R                                 (- 38a c  + 142a b c  - 70b c )d e
+--R                               + 
+--R                                           6      3 5  5 3
+--R                                 (- 64a b c  + 56b c )d e
+--R                               + 
+--R                                       7      2 6  6 2       7 7     8 8
+--R                                 (12a c  - 28b c )d e  + 8b c d e - c d
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                             2   2       3     5  4
+--R                        (- 5a b c  + 5a b c - b )e
+--R                      + 
+--R                           2 3        2 2     4     3           3     3 2  2 2
+--R                        (8a c  - 16a b c  + 4b c)d e  + (18a b c  - 6b c )d e
+--R                      + 
+--R                               4     2 3  3       4 4
+--R                        (- 8a c  + 4b c )d e - b c d
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                                 2   7          3 6       5 5
+--R                         (- 4096a b c  + 2048a b c  - 256b c )e
+--R                       + 
+--R                               2 8          2 7       4 6
+--R                         (8192a c  - 4096a b c  + 512b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                        3 3      2 2 2       4     6  5
+--R                     (4a c  - 13a b c  + 7a b c - b )e
+--R                   + 
+--R                         2   3        3 2     5     4
+--R                     (32a b c  - 24a b c  + 4b c)d e
+--R                   + 
+--R                           2 4        2 3     4 2  2 3
+--R                     (- 24a c  + 30a b c  - 6b c )d e
+--R                   + 
+--R                               4     3 3  3 2        5    2 4  4
+--R                     (- 16a b c  + 4b c )d e  + (4a c  - b c )d e
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 7          2 6       4 5
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          e
+--R                                      + 
+--R                                                 3   4      2 3 3        5 2
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                              7
+--R                                            8b c
+--R                                       *
+--R                                             7
+--R                                          d e
+--R                                      + 
+--R                                               3 5       2 2 4         4 3
+--R                                            12a c  - 112a b c  + 112a b c
+--R                                          + 
+--R                                                 6 2
+--R                                            - 28b c
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                             2   5         3 4      5 3  3 5
+--R                                        (104a b c  - 168a b c  + 56b c )d e
+--R                                      + 
+--R                                              2 6         2 5      4 4  4 4
+--R                                        (- 38a c  + 142a b c  - 70b c )d e
+--R                                      + 
+--R                                                  6      3 5  5 3
+--R                                        (- 64a b c  + 56b c )d e
+--R                                      + 
+--R                                              7      2 6  6 2       7 7     8 8
+--R                                        (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )e
+--R                             + 
+--R                                  2 3        2 2     4     3
+--R                               (8a c  - 16a b c  + 4b c)d e
+--R                             + 
+--R                                       3     3 2  2 2          4     2 3  3
+--R                               (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e
+--R                             + 
+--R                                    4 4
+--R                               - b c d
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                       3 2     2 2       4  6      2   2      3     5    5
+--R                     (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                   + 
+--R                          2 3       2 2     4   2 4           3      3 2  3 3
+--R                     (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                   + 
+--R                            4      2 3  4 2       4 5     5 6
+--R                     (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R                *
+--R                   x
+--R     + 
+--R       -
+--R            2c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 7          2 6       4 5
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                               + 
+--R                                       3   4      2 3 3        5 2     7     7
+--R                                 (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                               + 
+--R                                     3 5       2 2 4         4 3      6 2  2 6
+--R                                 (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                               + 
+--R                                      2   5         3 4      5 3  3 5
+--R                                 (104a b c  - 168a b c  + 56b c )d e
+--R                               + 
+--R                                       2 6         2 5      4 4  4 4
+--R                                 (- 38a c  + 142a b c  - 70b c )d e
+--R                               + 
+--R                                           6      3 5  5 3
+--R                                 (- 64a b c  + 56b c )d e
+--R                               + 
+--R                                       7      2 6  6 2       7 7     8 8
+--R                                 (12a c  - 28b c )d e  + 8b c d e - c d
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                             2   2       3     5  4
+--R                        (- 5a b c  + 5a b c - b )e
+--R                      + 
+--R                           2 3        2 2     4     3           3     3 2  2 2
+--R                        (8a c  - 16a b c  + 4b c)d e  + (18a b c  - 6b c )d e
+--R                      + 
+--R                               4     2 3  3       4 4
+--R                        (- 8a c  + 4b c )d e - b c d
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            atan
+--R                               2   7          3 6       5 5
+--R                         (4096a b c  - 2048a b c  + 256b c )e
+--R                       + 
+--R                                 2 8          2 7       4 6
+--R                         (- 8192a c  + 4096a b c  - 512b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                          3 3      2 2 2       4     6  5
+--R                     (- 4a c  + 13a b c  - 7a b c + b )e
+--R                   + 
+--R                           2   3        3 2     5     4
+--R                     (- 32a b c  + 24a b c  - 4b c)d e
+--R                   + 
+--R                         2 4        2 3     4 2  2 3           4     3 3  3 2
+--R                     (24a c  - 30a b c  + 6b c )d e  + (16a b c  - 4b c )d e
+--R                   + 
+--R                            5    2 4  4
+--R                     (- 4a c  + b c )d e
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 7          2 6       4 5
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          e
+--R                                      + 
+--R                                                 3   4      2 3 3        5 2
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                              7
+--R                                            8b c
+--R                                       *
+--R                                             7
+--R                                          d e
+--R                                      + 
+--R                                               3 5       2 2 4         4 3
+--R                                            12a c  - 112a b c  + 112a b c
+--R                                          + 
+--R                                                 6 2
+--R                                            - 28b c
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                             2   5         3 4      5 3  3 5
+--R                                        (104a b c  - 168a b c  + 56b c )d e
+--R                                      + 
+--R                                              2 6         2 5      4 4  4 4
+--R                                        (- 38a c  + 142a b c  - 70b c )d e
+--R                                      + 
+--R                                                  6      3 5  5 3
+--R                                        (- 64a b c  + 56b c )d e
+--R                                      + 
+--R                                              7      2 6  6 2       7 7     8 8
+--R                                        (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )e
+--R                             + 
+--R                                  2 3        2 2     4     3
+--R                               (8a c  - 16a b c  + 4b c)d e
+--R                             + 
+--R                                       3     3 2  2 2          4     2 3  3
+--R                               (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e
+--R                             + 
+--R                                    4 4
+--R                               - b c d
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R              /
+--R                       3 2     2 2       4  6      2   2      3     5    5
+--R                     (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                   + 
+--R                          2 3       2 2     4   2 4           3      3 2  3 3
+--R                     (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                   + 
+--R                            4      2 3  4 2       4 5     5 6
+--R                     (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R                *
+--R                   x
+--R     + 
+--R         2c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 7          2 6       4 5
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                          2   2       3     5  4      2 3        2 2     4     3
+--R                     (- 5a b c  + 5a b c - b )e  + (8a c  - 16a b c  + 4b c)d e
+--R                   + 
+--R                             3     3 2  2 2          4     2 3  3       4 4
+--R                     (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         atan
+--R                            2   7          3 6       5 5
+--R                      (4096a b c  - 2048a b c  + 256b c )e
+--R                    + 
+--R                              2 8          2 7       4 6
+--R                      (- 8192a c  + 4096a b c  - 512b c )d
+--R                 *
+--R                    ROOT
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     7
+--R                           (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                         + 
+--R                               3 5       2 2 4         4 3      6 2  2 6
+--R                           (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                         + 
+--R                                2   5         3 4      5 3  3 5
+--R                           (104a b c  - 168a b c  + 56b c )d e
+--R                         + 
+--R                                 2 6         2 5      4 4  4 4
+--R                           (- 38a c  + 142a b c  - 70b c )d e
+--R                         + 
+--R                                     6      3 5  5 3         7      2 6  6 2
+--R                           (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                         + 
+--R                               7 7     8 8
+--R                           8b c d e - c d
+--R                      /
+--R                                   3 13           2 2 12            4 11
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 10
+--R                           - 65536b c
+--R                + 
+--R                     3 3      2 2 2       4     6  5
+--R                  (4a c  - 13a b c  + 7a b c - b )e
+--R                + 
+--R                      2   3        3 2     5     4
+--R                  (32a b c  - 24a b c  + 4b c)d e
+--R                + 
+--R                        2 4        2 3     4 2  2 3             4     3 3  3 2
+--R                  (- 24a c  + 30a b c  - 6b c )d e  + (- 16a b c  + 4b c )d e
+--R                + 
+--R                       5    2 4  4
+--R                  (4a c  - b c )d e
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 7          2 6       4 5
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                              4 4     3 2 3      2 4 2       6
+--R                                           - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                         + 
+--R                                              8
+--R                                           - b
+--R                                    *
+--R                                        8
+--R                                       e
+--R                                   + 
+--R                                             3   4      2 3 3        5 2     7
+--R                                       (- 16a b c  + 56a b c  - 40a b c  + 8b c)
+--R                                    *
+--R                                          7
+--R                                       d e
+--R                                   + 
+--R                                           3 5       2 2 4         4 3      6 2
+--R                                       (12a c  - 112a b c  + 112a b c  - 28b c )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                          2   5         3 4      5 3  3 5
+--R                                     (104a b c  - 168a b c  + 56b c )d e
+--R                                   + 
+--R                                           2 6         2 5      4 4  4 4
+--R                                     (- 38a c  + 142a b c  - 70b c )d e
+--R                                   + 
+--R                                               6      3 5  5 3
+--R                                     (- 64a b c  + 56b c )d e
+--R                                   + 
+--R                                           7      2 6  6 2       7 7     8 8
+--R                                     (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )e
+--R                          + 
+--R                               2 3        2 2     4     3
+--R                            (8a c  - 16a b c  + 4b c)d e
+--R                          + 
+--R                                  3     3 2  2 2          4     2 3  3       4 4
+--R                          (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R           /
+--R                    3 2     2 2       4  6      2   2      3     5    5
+--R                  (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                + 
+--R                       2 3       2 2     4   2 4           3      3 2  3 3
+--R                  (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                + 
+--R                         4      2 3  4 2       4 5     5 6
+--R                  (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       2e x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 199
+
+--S 200 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------------------+3  +------------------+3
+--R               +-----------+     |   +-----------+        | +-----------+
+--R          4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             2 7          2 6       4 5
+--R                       (4096a c  - 2048a b c  + 256b c )
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                          2   2       3     5  4      2 3        2 2     4     3
+--R                     (- 5a b c  + 5a b c - b )e  + (8a c  - 16a b c  + 4b c)d e
+--R                   + 
+--R                             3     3 2  2 2          4     2 3  3       4 4
+--R                     (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                            2   7          3 6       5 5
+--R                      (4096a b c  - 2048a b c  + 256b c )e
+--R                    + 
+--R                              2 8          2 7       4 6
+--R                      (- 8192a c  + 4096a b c  - 512b c )d
+--R                 *
+--R                    ROOT
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     7
+--R                           (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                         + 
+--R                               3 5       2 2 4         4 3      6 2  2 6
+--R                           (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                         + 
+--R                                2   5         3 4      5 3  3 5
+--R                           (104a b c  - 168a b c  + 56b c )d e
+--R                         + 
+--R                                 2 6         2 5      4 4  4 4
+--R                           (- 38a c  + 142a b c  - 70b c )d e
+--R                         + 
+--R                                     6      3 5  5 3         7      2 6  6 2
+--R                           (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                         + 
+--R                               7 7     8 8
+--R                           8b c d e - c d
+--R                      /
+--R                                   3 13           2 2 12            4 11
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 10
+--R                           - 65536b c
+--R                + 
+--R                       3 3      2 2 2       4     6  5
+--R                  (- 4a c  + 13a b c  - 7a b c + b )e
+--R                + 
+--R                        2   3        3 2     5     4
+--R                  (- 32a b c  + 24a b c  - 4b c)d e
+--R                + 
+--R                      2 4        2 3     4 2  2 3           4     3 3  3 2
+--R                  (24a c  - 30a b c  + 6b c )d e  + (16a b c  - 4b c )d e
+--R                + 
+--R                         5    2 4  4
+--R                  (- 4a c  + b c )d e
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    2 7          2 6       4 5
+--R                              (4096a c  - 2048a b c  + 256b c )
+--R                           *
+--R                              ROOT
+--R                                              4 4     3 2 3      2 4 2       6
+--R                                           - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                         + 
+--R                                              8
+--R                                           - b
+--R                                    *
+--R                                        8
+--R                                       e
+--R                                   + 
+--R                                             3   4      2 3 3        5 2     7
+--R                                       (- 16a b c  + 56a b c  - 40a b c  + 8b c)
+--R                                    *
+--R                                          7
+--R                                       d e
+--R                                   + 
+--R                                           3 5       2 2 4         4 3      6 2
+--R                                       (12a c  - 112a b c  + 112a b c  - 28b c )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                          2   5         3 4      5 3  3 5
+--R                                     (104a b c  - 168a b c  + 56b c )d e
+--R                                   + 
+--R                                           2 6         2 5      4 4  4 4
+--R                                     (- 38a c  + 142a b c  - 70b c )d e
+--R                                   + 
+--R                                               6      3 5  5 3
+--R                                     (- 64a b c  + 56b c )d e
+--R                                   + 
+--R                                           7      2 6  6 2       7 7     8 8
+--R                                     (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )e
+--R                          + 
+--R                               2 3        2 2     4     3
+--R                            (8a c  - 16a b c  + 4b c)d e
+--R                          + 
+--R                                  3     3 2  2 2          4     2 3  3       4 4
+--R                          (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                    3 2     2 2       4  6      2   2      3     5    5
+--R                  (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                + 
+--R                       2 3       2 2     4   2 4           3      3 2  3 3
+--R                  (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                + 
+--R                         4      2 3  4 2       4 5     5 6
+--R                  (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                    +--------------------+3
+--R                  +-----------+     |   +-----------+
+--R             4+-+ |          2 4+-+4|   |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  2 7          2 6       4 5
+--R                          (- 4096a c  + 2048a b c  - 256b c )
+--R                       *
+--R                          ROOT
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                               + 
+--R                                       3   4      2 3 3        5 2     7     7
+--R                                 (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                               + 
+--R                                     3 5       2 2 4         4 3      6 2  2 6
+--R                                 (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                               + 
+--R                                      2   5         3 4      5 3  3 5
+--R                                 (104a b c  - 168a b c  + 56b c )d e
+--R                               + 
+--R                                       2 6         2 5      4 4  4 4
+--R                                 (- 38a c  + 142a b c  - 70b c )d e
+--R                               + 
+--R                                           6      3 5  5 3
+--R                                 (- 64a b c  + 56b c )d e
+--R                               + 
+--R                                       7      2 6  6 2       7 7     8 8
+--R                                 (12a c  - 28b c )d e  + 8b c d e - c d
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                             2   2       3     5  4
+--R                        (- 5a b c  + 5a b c - b )e
+--R                      + 
+--R                           2 3        2 2     4     3           3     3 2  2 2
+--R                        (8a c  - 16a b c  + 4b c)d e  + (18a b c  - 6b c )d e
+--R                      + 
+--R                               4     2 3  3       4 4
+--R                        (- 8a c  + 4b c )d e - b c d
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                               2   7          3 6       5 5
+--R                         (4096a b c  - 2048a b c  + 256b c )e
+--R                       + 
+--R                                 2 8          2 7       4 6
+--R                         (- 8192a c  + 4096a b c  - 512b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                        3 3      2 2 2       4     6  5
+--R                     (4a c  - 13a b c  + 7a b c - b )e
+--R                   + 
+--R                         2   3        3 2     5     4
+--R                     (32a b c  - 24a b c  + 4b c)d e
+--R                   + 
+--R                           2 4        2 3     4 2  2 3
+--R                     (- 24a c  + 30a b c  - 6b c )d e
+--R                   + 
+--R                               4     3 3  3 2        5    2 4  4
+--R                     (- 16a b c  + 4b c )d e  + (4a c  - b c )d e
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         2 7          2 6       4 5
+--R                                 (- 4096a c  + 2048a b c  - 256b c )
+--R                              *
+--R                                 ROOT
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          e
+--R                                      + 
+--R                                                 3   4      2 3 3        5 2
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                              7
+--R                                            8b c
+--R                                       *
+--R                                             7
+--R                                          d e
+--R                                      + 
+--R                                               3 5       2 2 4         4 3
+--R                                            12a c  - 112a b c  + 112a b c
+--R                                          + 
+--R                                                 6 2
+--R                                            - 28b c
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                             2   5         3 4      5 3  3 5
+--R                                        (104a b c  - 168a b c  + 56b c )d e
+--R                                      + 
+--R                                              2 6         2 5      4 4  4 4
+--R                                        (- 38a c  + 142a b c  - 70b c )d e
+--R                                      + 
+--R                                                  6      3 5  5 3
+--R                                        (- 64a b c  + 56b c )d e
+--R                                      + 
+--R                                              7      2 6  6 2       7 7     8 8
+--R                                        (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )e
+--R                             + 
+--R                                  2 3        2 2     4     3
+--R                               (8a c  - 16a b c  + 4b c)d e
+--R                             + 
+--R                                       3     3 2  2 2          4     2 3  3
+--R                               (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e
+--R                             + 
+--R                                    4 4
+--R                               - b c d
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                       3 2     2 2       4  6      2   2      3     5    5
+--R                     (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                   + 
+--R                          2 3       2 2     4   2 4           3      3 2  3 3
+--R                     (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                   + 
+--R                            4      2 3  4 2       4 5     5 6
+--R                     (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R                *
+--R                   x
+--R     + 
+--R                                 +--------------------+3  +------------------+3
+--R               +-----------+     |   +-----------+        | +-----------+
+--R          4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 7          2 6       4 5
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                          2   2       3     5  4      2 3        2 2     4     3
+--R                     (- 5a b c  + 5a b c - b )e  + (8a c  - 16a b c  + 4b c)d e
+--R                   + 
+--R                             3     3 2  2 2          4     2 3  3       4 4
+--R                     (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         log
+--R                              2   7          3 6       5 5
+--R                      (- 4096a b c  + 2048a b c  - 256b c )e
+--R                    + 
+--R                            2 8          2 7       4 6
+--R                      (8192a c  - 4096a b c  + 512b c )d
+--R                 *
+--R                    ROOT
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     7
+--R                           (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                         + 
+--R                               3 5       2 2 4         4 3      6 2  2 6
+--R                           (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                         + 
+--R                                2   5         3 4      5 3  3 5
+--R                           (104a b c  - 168a b c  + 56b c )d e
+--R                         + 
+--R                                 2 6         2 5      4 4  4 4
+--R                           (- 38a c  + 142a b c  - 70b c )d e
+--R                         + 
+--R                                     6      3 5  5 3         7      2 6  6 2
+--R                           (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                         + 
+--R                               7 7     8 8
+--R                           8b c d e - c d
+--R                      /
+--R                                   3 13           2 2 12            4 11
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 10
+--R                           - 65536b c
+--R                + 
+--R                       3 3      2 2 2       4     6  5
+--R                  (- 4a c  + 13a b c  - 7a b c + b )e
+--R                + 
+--R                        2   3        3 2     5     4
+--R                  (- 32a b c  + 24a b c  - 4b c)d e
+--R                + 
+--R                      2 4        2 3     4 2  2 3           4     3 3  3 2
+--R                  (24a c  - 30a b c  + 6b c )d e  + (16a b c  - 4b c )d e
+--R                + 
+--R                         5    2 4  4
+--R                  (- 4a c  + b c )d e
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 7          2 6       4 5
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                              4 4     3 2 3      2 4 2       6
+--R                                           - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                         + 
+--R                                              8
+--R                                           - b
+--R                                    *
+--R                                        8
+--R                                       e
+--R                                   + 
+--R                                             3   4      2 3 3        5 2     7
+--R                                       (- 16a b c  + 56a b c  - 40a b c  + 8b c)
+--R                                    *
+--R                                          7
+--R                                       d e
+--R                                   + 
+--R                                           3 5       2 2 4         4 3      6 2
+--R                                       (12a c  - 112a b c  + 112a b c  - 28b c )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                          2   5         3 4      5 3  3 5
+--R                                     (104a b c  - 168a b c  + 56b c )d e
+--R                                   + 
+--R                                           2 6         2 5      4 4  4 4
+--R                                     (- 38a c  + 142a b c  - 70b c )d e
+--R                                   + 
+--R                                               6      3 5  5 3
+--R                                     (- 64a b c  + 56b c )d e
+--R                                   + 
+--R                                           7      2 6  6 2       7 7     8 8
+--R                                     (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )e
+--R                          + 
+--R                               2 3        2 2     4     3
+--R                            (8a c  - 16a b c  + 4b c)d e
+--R                          + 
+--R                                  3     3 2  2 2          4     2 3  3       4 4
+--R                          (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R            + 
+--R                    3 2     2 2       4  6      2   2      3     5    5
+--R                  (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                + 
+--R                       2 3       2 2     4   2 4           3      3 2  3 3
+--R                  (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                + 
+--R                         4      2 3  4 2       4 5     5 6
+--R                  (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                    +--------------------+3
+--R                  +-----------+     |   +-----------+
+--R             4+-+ |          2 4+-+4|   |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 7          2 6       4 5
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                               + 
+--R                                       3   4      2 3 3        5 2     7     7
+--R                                 (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                               + 
+--R                                     3 5       2 2 4         4 3      6 2  2 6
+--R                                 (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                               + 
+--R                                      2   5         3 4      5 3  3 5
+--R                                 (104a b c  - 168a b c  + 56b c )d e
+--R                               + 
+--R                                       2 6         2 5      4 4  4 4
+--R                                 (- 38a c  + 142a b c  - 70b c )d e
+--R                               + 
+--R                                           6      3 5  5 3
+--R                                 (- 64a b c  + 56b c )d e
+--R                               + 
+--R                                       7      2 6  6 2       7 7     8 8
+--R                                 (12a c  - 28b c )d e  + 8b c d e - c d
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                             2   2       3     5  4
+--R                        (- 5a b c  + 5a b c - b )e
+--R                      + 
+--R                           2 3        2 2     4     3           3     3 2  2 2
+--R                        (8a c  - 16a b c  + 4b c)d e  + (18a b c  - 6b c )d e
+--R                      + 
+--R                               4     2 3  3       4 4
+--R                        (- 8a c  + 4b c )d e - b c d
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            log
+--R                                 2   7          3 6       5 5
+--R                         (- 4096a b c  + 2048a b c  - 256b c )e
+--R                       + 
+--R                               2 8          2 7       4 6
+--R                         (8192a c  - 4096a b c  + 512b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                        3 3      2 2 2       4     6  5
+--R                     (4a c  - 13a b c  + 7a b c - b )e
+--R                   + 
+--R                         2   3        3 2     5     4
+--R                     (32a b c  - 24a b c  + 4b c)d e
+--R                   + 
+--R                           2 4        2 3     4 2  2 3
+--R                     (- 24a c  + 30a b c  - 6b c )d e
+--R                   + 
+--R                               4     3 3  3 2        5    2 4  4
+--R                     (- 16a b c  + 4b c )d e  + (4a c  - b c )d e
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 7          2 6       4 5
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          e
+--R                                      + 
+--R                                                 3   4      2 3 3        5 2
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                              7
+--R                                            8b c
+--R                                       *
+--R                                             7
+--R                                          d e
+--R                                      + 
+--R                                               3 5       2 2 4         4 3
+--R                                            12a c  - 112a b c  + 112a b c
+--R                                          + 
+--R                                                 6 2
+--R                                            - 28b c
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                             2   5         3 4      5 3  3 5
+--R                                        (104a b c  - 168a b c  + 56b c )d e
+--R                                      + 
+--R                                              2 6         2 5      4 4  4 4
+--R                                        (- 38a c  + 142a b c  - 70b c )d e
+--R                                      + 
+--R                                                  6      3 5  5 3
+--R                                        (- 64a b c  + 56b c )d e
+--R                                      + 
+--R                                              7      2 6  6 2       7 7     8 8
+--R                                        (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )e
+--R                             + 
+--R                                  2 3        2 2     4     3
+--R                               (8a c  - 16a b c  + 4b c)d e
+--R                             + 
+--R                                       3     3 2  2 2          4     2 3  3
+--R                               (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e
+--R                             + 
+--R                                    4 4
+--R                               - b c d
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R               + 
+--R                       3 2     2 2       4  6      2   2      3     5    5
+--R                     (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                   + 
+--R                          2 3       2 2     4   2 4           3      3 2  3 3
+--R                     (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                   + 
+--R                            4      2 3  4 2       4 5     5 6
+--R                     (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R                *
+--R                   x
+--R     + 
+--R       -
+--R                                     +--------------------+3
+--R                   +-----------+     |   +-----------+
+--R              4+-+ |          2 4+-+4|   |          2
+--R            2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                2 7          2 6       4 5
+--R                          (4096a c  - 2048a b c  + 256b c )
+--R                       *
+--R                          ROOT
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                               + 
+--R                                       3   4      2 3 3        5 2     7     7
+--R                                 (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                               + 
+--R                                     3 5       2 2 4         4 3      6 2  2 6
+--R                                 (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                               + 
+--R                                      2   5         3 4      5 3  3 5
+--R                                 (104a b c  - 168a b c  + 56b c )d e
+--R                               + 
+--R                                       2 6         2 5      4 4  4 4
+--R                                 (- 38a c  + 142a b c  - 70b c )d e
+--R                               + 
+--R                                           6      3 5  5 3
+--R                                 (- 64a b c  + 56b c )d e
+--R                               + 
+--R                                       7      2 6  6 2       7 7     8 8
+--R                                 (12a c  - 28b c )d e  + 8b c d e - c d
+--R                            /
+--R                                         3 13           2 2 12            4 11
+--R                                 4194304a c   - 3145728a b c   + 786432a b c
+--R                               + 
+--R                                         6 10
+--R                                 - 65536b c
+--R                      + 
+--R                             2   2       3     5  4
+--R                        (- 5a b c  + 5a b c - b )e
+--R                      + 
+--R                           2 3        2 2     4     3           3     3 2  2 2
+--R                        (8a c  - 16a b c  + 4b c)d e  + (18a b c  - 6b c )d e
+--R                      + 
+--R                               4     2 3  3       4 4
+--R                        (- 8a c  + 4b c )d e - b c d
+--R                   /
+--R                           2 7          2 6       4 5
+--R                      2048a c  - 1024a b c  + 128b c
+--R         *
+--R            atan
+--R                               2   7          3 6       5 5
+--R                         (4096a b c  - 2048a b c  + 256b c )e
+--R                       + 
+--R                                 2 8          2 7       4 6
+--R                         (- 8192a c  + 4096a b c  - 512b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                          3 3      2 2 2       4     6  5
+--R                     (- 4a c  + 13a b c  - 7a b c + b )e
+--R                   + 
+--R                           2   3        3 2     5     4
+--R                     (- 32a b c  + 24a b c  - 4b c)d e
+--R                   + 
+--R                         2 4        2 3     4 2  2 3           4     3 3  3 2
+--R                     (24a c  - 30a b c  + 6b c )d e  + (16a b c  - 4b c )d e
+--R                   + 
+--R                            5    2 4  4
+--R                     (- 4a c  + b c )d e
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       2 7          2 6       4 5
+--R                                 (4096a c  - 2048a b c  + 256b c )
+--R                              *
+--R                                 ROOT
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          e
+--R                                      + 
+--R                                                 3   4      2 3 3        5 2
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                              7
+--R                                            8b c
+--R                                       *
+--R                                             7
+--R                                          d e
+--R                                      + 
+--R                                               3 5       2 2 4         4 3
+--R                                            12a c  - 112a b c  + 112a b c
+--R                                          + 
+--R                                                 6 2
+--R                                            - 28b c
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                             2   5         3 4      5 3  3 5
+--R                                        (104a b c  - 168a b c  + 56b c )d e
+--R                                      + 
+--R                                              2 6         2 5      4 4  4 4
+--R                                        (- 38a c  + 142a b c  - 70b c )d e
+--R                                      + 
+--R                                                  6      3 5  5 3
+--R                                        (- 64a b c  + 56b c )d e
+--R                                      + 
+--R                                              7      2 6  6 2       7 7     8 8
+--R                                        (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                   /
+--R                                                3 13           2 2 12
+--R                                        4194304a c   - 3145728a b c
+--R                                      + 
+--R                                                 4 11         6 10
+--R                                        786432a b c   - 65536b c
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )e
+--R                             + 
+--R                                  2 3        2 2     4     3
+--R                               (8a c  - 16a b c  + 4b c)d e
+--R                             + 
+--R                                       3     3 2  2 2          4     2 3  3
+--R                               (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e
+--R                             + 
+--R                                    4 4
+--R                               - b c d
+--R                          /
+--R                                  2 7          2 6       4 5
+--R                             2048a c  - 1024a b c  + 128b c
+--R              /
+--R                       3 2     2 2       4  6      2   2      3     5    5
+--R                     (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                   + 
+--R                          2 3       2 2     4   2 4           3      3 2  3 3
+--R                     (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                   + 
+--R                            4      2 3  4 2       4 5     5 6
+--R                     (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R                *
+--R                   x
+--R     + 
+--R                                  +--------------------+3  +------------------+3
+--R                +-----------+     |   +-----------+        | +-----------+
+--R           4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               2 7          2 6       4 5
+--R                       (- 4096a c  + 2048a b c  - 256b c )
+--R                    *
+--R                       ROOT
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                            + 
+--R                                    3   4      2 3 3        5 2     7     7
+--R                              (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                            + 
+--R                                  3 5       2 2 4         4 3      6 2  2 6
+--R                              (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                            + 
+--R                                   2   5         3 4      5 3  3 5
+--R                              (104a b c  - 168a b c  + 56b c )d e
+--R                            + 
+--R                                    2 6         2 5      4 4  4 4
+--R                              (- 38a c  + 142a b c  - 70b c )d e
+--R                            + 
+--R                                        6      3 5  5 3         7      2 6  6 2
+--R                              (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                            + 
+--R                                  7 7     8 8
+--R                              8b c d e - c d
+--R                         /
+--R                                      3 13           2 2 12            4 11
+--R                              4194304a c   - 3145728a b c   + 786432a b c
+--R                            + 
+--R                                      6 10
+--R                              - 65536b c
+--R                   + 
+--R                          2   2       3     5  4      2 3        2 2     4     3
+--R                     (- 5a b c  + 5a b c - b )e  + (8a c  - 16a b c  + 4b c)d e
+--R                   + 
+--R                             3     3 2  2 2          4     2 3  3       4 4
+--R                     (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                /
+--R                        2 7          2 6       4 5
+--R                   2048a c  - 1024a b c  + 128b c
+--R      *
+--R         atan
+--R                            2   7          3 6       5 5
+--R                      (4096a b c  - 2048a b c  + 256b c )e
+--R                    + 
+--R                              2 8          2 7       4 6
+--R                      (- 8192a c  + 4096a b c  - 512b c )d
+--R                 *
+--R                    ROOT
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )e
+--R                         + 
+--R                                 3   4      2 3 3        5 2     7     7
+--R                           (- 16a b c  + 56a b c  - 40a b c  + 8b c)d e
+--R                         + 
+--R                               3 5       2 2 4         4 3      6 2  2 6
+--R                           (12a c  - 112a b c  + 112a b c  - 28b c )d e
+--R                         + 
+--R                                2   5         3 4      5 3  3 5
+--R                           (104a b c  - 168a b c  + 56b c )d e
+--R                         + 
+--R                                 2 6         2 5      4 4  4 4
+--R                           (- 38a c  + 142a b c  - 70b c )d e
+--R                         + 
+--R                                     6      3 5  5 3         7      2 6  6 2
+--R                           (- 64a b c  + 56b c )d e  + (12a c  - 28b c )d e
+--R                         + 
+--R                               7 7     8 8
+--R                           8b c d e - c d
+--R                      /
+--R                                   3 13           2 2 12            4 11
+--R                           4194304a c   - 3145728a b c   + 786432a b c
+--R                         + 
+--R                                   6 10
+--R                           - 65536b c
+--R                + 
+--R                     3 3      2 2 2       4     6  5
+--R                  (4a c  - 13a b c  + 7a b c - b )e
+--R                + 
+--R                      2   3        3 2     5     4
+--R                  (32a b c  - 24a b c  + 4b c)d e
+--R                + 
+--R                        2 4        2 3     4 2  2 3             4     3 3  3 2
+--R                  (- 24a c  + 30a b c  - 6b c )d e  + (- 16a b c  + 4b c )d e
+--R                + 
+--R                       5    2 4  4
+--R                  (4a c  - b c )d e
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      2 7          2 6       4 5
+--R                              (- 4096a c  + 2048a b c  - 256b c )
+--R                           *
+--R                              ROOT
+--R                                              4 4     3 2 3      2 4 2       6
+--R                                           - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                         + 
+--R                                              8
+--R                                           - b
+--R                                    *
+--R                                        8
+--R                                       e
+--R                                   + 
+--R                                             3   4      2 3 3        5 2     7
+--R                                       (- 16a b c  + 56a b c  - 40a b c  + 8b c)
+--R                                    *
+--R                                          7
+--R                                       d e
+--R                                   + 
+--R                                           3 5       2 2 4         4 3      6 2
+--R                                       (12a c  - 112a b c  + 112a b c  - 28b c )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                          2   5         3 4      5 3  3 5
+--R                                     (104a b c  - 168a b c  + 56b c )d e
+--R                                   + 
+--R                                           2 6         2 5      4 4  4 4
+--R                                     (- 38a c  + 142a b c  - 70b c )d e
+--R                                   + 
+--R                                               6      3 5  5 3
+--R                                     (- 64a b c  + 56b c )d e
+--R                                   + 
+--R                                           7      2 6  6 2       7 7     8 8
+--R                                     (12a c  - 28b c )d e  + 8b c d e - c d
+--R                                /
+--R                                             3 13           2 2 12
+--R                                     4194304a c   - 3145728a b c
+--R                                   + 
+--R                                              4 11         6 10
+--R                                     786432a b c   - 65536b c
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )e
+--R                          + 
+--R                               2 3        2 2     4     3
+--R                            (8a c  - 16a b c  + 4b c)d e
+--R                          + 
+--R                                  3     3 2  2 2          4     2 3  3       4 4
+--R                          (18a b c  - 6b c )d e  + (- 8a c  + 4b c )d e - b c d
+--R                       /
+--R                               2 7          2 6       4 5
+--R                          2048a c  - 1024a b c  + 128b c
+--R           /
+--R                    3 2     2 2       4  6      2   2      3     5    5
+--R                  (a c  - 3a b c + a b )e  + (7a b c  - a b c - b )d e
+--R                + 
+--R                       2 3       2 2     4   2 4           3      3 2  3 3
+--R                  (- 5a c  - 5a b c  + 5b c)d e  + (10a b c  - 10b c )d e
+--R                + 
+--R                         4      2 3  4 2       4 5     5 6
+--R                  (- 5a c  + 10b c )d e  - 5b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R                        +-----------+
+--R                        |          2             2
+--R         ((- b e + c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R          +------------------+3
+--R          | +-----------+                    4+-+4+-+
+--R         4| |          2                    x\|2 \|c
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                        |          2               2
+--R         ((- b e + c d)\|- 4a c + b   + (- 2a c + b )e - b c d)
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                   4+-+4+-+
+--R         4|   |          2                   x\|2 \|c
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                        |          2             2
+--R         ((- b e + c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R          +------------------+3
+--R          | +-----------+                   4+-+4+-+
+--R         4| |          2                   x\|2 \|c
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                        |          2               2
+--R         ((- b e + c d)\|- 4a c + b   + (- 2a c + b )e - b c d)
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                  4+-+4+-+
+--R         4|   |          2                  x\|2 \|c
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+3  +------------------+3
+--R            +-----------+     |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 649
+t0:=x^3*(d+e*x^4)/(a+b*x^4+c*x^8)
+--R 
+--R
+--R             7      3
+--R          e x  + d x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 202
+
+--S 203 of 649
+r0:=1/8*e*log(a+b*x^4+c*x^8)/c-1/4*(2*c*d-b*e)*atanh((b+2*c*x^4)/_
+   sqrt(b^2-4*a*c))/(c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                             4                                 +-----------+
+--R                         2c x  + b               8      4      |          2
+--R   (2b e - 4c d)atanh(--------------) + e log(c x  + b x  + a)\|- 4a c + b
+--R                       +-----------+
+--R                       |          2
+--R                      \|- 4a c + b
+--R   -------------------------------------------------------------------------
+--R                                   +-----------+
+--R                                   |          2
+--R                                8c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           (b e - 2c d)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 8         4           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   4             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   8      4
+--R                c x  + b x  + a
+--R       + 
+--R                                +-----------+
+--R                  8      4      |          2
+--R         e log(c x  + b x  + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       8c\|- 4a c + b
+--R     ,
+--R
+--R                                         +---------+
+--R                                  4      |        2
+--R                             (2c x  + b)\|4a c - b
+--R         (- 2b e + 4c d)atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R       + 
+--R                                +---------+
+--R                  8      4      |        2
+--R         e log(c x  + b x  + a)\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       8c\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 204
+
+--S 205 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (b e - 2c d)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 8         4           2  |          2           2     2   4
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 8      4
+--R              c x  + b x  + a
+--R     + 
+--R                                   4
+--R                               2c x  + b
+--R       (- 2b e + 4c d)atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     8c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      +---------+             4
+--R                      |        2          2c x  + b
+--R       (- b e + 2c d)\|4a c - b  atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                                                    +---------+
+--R                      +-----------+          4      |        2
+--R                      |          2      (2c x  + b)\|4a c - b
+--R       (- b e + 2c d)\|- 4a c + b  atan(-----------------------)
+--R                                                       2
+--R                                               4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     4c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 207
+
+--S 208 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 208
+
+)clear all
+
+--S 209 of 649
+t0:=x^2*(d+e*x^4)/(a+b*x^4+c*x^8)
+--R 
+--R
+--R             6      2
+--R          e x  + d x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 209
+
+--S 210 of 649
+r0:=1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*(-b-_
+   sqrt(b^2-4*a*c))^(1/4))-1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   c^(3/4)*(-b-sqrt(b^2-4*a*c))^(1/4))+1/2*atan(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*c^(3/4)*(-b+sqrt(b^2-4*a*c))^(1/4))-1/2*atanh(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-_
+   4*a*c))/(2^(3/4)*c^(3/4)*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                          +------------------+
+--R              +-----------+               | +-----------+
+--R              |          2               4| |          2
+--R         (- e\|- 4a c + b   - b e + 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                          +--------------------+
+--R              +-----------+               |   +-----------+
+--R              |          2               4|   |          2
+--R         (- e\|- 4a c + b   + b e - 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2               4| |          2
+--R         (e\|- 4a c + b   + b e - 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2               4|   |          2
+--R         (e\|- 4a c + b   - b e + 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                +--------------------+ +------------------+
+--R            +-----------+       |   +-----------+      | +-----------+
+--R      4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R     2\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 210
+
+--S 211 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             3 5        2 2 4         4 3
+--R                       (4096a c  - 2048a b c  + 256a b c )
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                        2         3  4        2 2       2     3         2 2 2
+--R                     (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                   + 
+--R                         3 3       3 4
+--R                     8a c d e - b c d
+--R                /
+--R                        3 5        2 2 4         4 3
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                                 6 7          5 2 6          4 4 5         3 6 4
+--R                          262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                        + 
+--R                               2 8 3
+--R                          2048a b c
+--R                     *
+--R                         3
+--R                        e
+--R                    + 
+--R                                5   7          4 3 6         3 5 5        2 7 4
+--R                        (393216a b c  - 294912a b c  + 73728a b c  - 6144a b c )
+--R                     *
+--R                           2
+--R                        d e
+--R                    + 
+--R                                     5 8          4 2 7          3 4 6
+--R                            - 786432a c  + 589824a b c  - 147456a b c
+--R                          + 
+--R                                  2 6 5
+--R                            12288a b c
+--R                     *
+--R                         2
+--R                        d e
+--R                    + 
+--R                              4   8         3 3 7         2 5 6          7 5  3
+--R                      (131072a b c  - 98304a b c  + 24576a b c  - 2048a b c )d
+--R                 *
+--R                    ROOT
+--R                               4 2     3 2     2 4  8        3   2     2 3     7
+--R                           (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                         + 
+--R                               3 3      2 2 2  2 6      2   3 3 5
+--R                           (12a c  - 28a b c )d e  + 48a b c d e
+--R                         + 
+--R                                 2 4       2 3  4 4         4 5 3        5 6 2
+--R                           (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                         + 
+--R                              6 8
+--R                           - c d
+--R                      /
+--R                                   5 9           4 2 8          3 4 7
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   2 6 6
+--R                           - 65536a b c
+--R                + 
+--R                         5   3       4 3 2      3 5      2 7  7
+--R                  (- 128a b c  + 192a b c  - 72a b c + 8a b )e
+--R                + 
+--R                       5 4        4 2 3       3 4 2      2 6     6
+--R                  (384a c  - 1088a b c  + 472a b c  - 56a b c)d e
+--R                + 
+--R                        4   4        3 3 3       2 5 2  2 5
+--R                  (2304a b c  - 1152a b c  + 144a b c )d e
+--R                + 
+--R                          4 5        3 2 4       2 4 3       6 2  3 4
+--R                  (- 2432a c  + 1344a b c  - 216a b c  + 8a b c )d e
+--R                + 
+--R                         3   5       2 3 4        5 3  4 3
+--R                  (- 640a b c  + 320a b c  - 40a b c )d e
+--R                + 
+--R                        3 6       2 2 5        4 4  5 2
+--R                  (1152a c  - 576a b c  + 72a b c )d e
+--R                + 
+--R                         2 7        2 6     4 5  7
+--R                  (- 128a c  + 64a b c  - 8b c )d
+--R             *
+--R                ROOT
+--R                               3 5        2 2 4         4 3
+--R                         (4096a c  - 2048a b c  + 256a b c )
+--R                      *
+--R                         ROOT
+--R                                    4 2     3 2     2 4  8
+--R                                (- a c  + 2a b c - a b )e
+--R                              + 
+--R                                     3   2     2 3     7
+--R                                (- 8a b c  + 8a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 6      2   3 3 5
+--R                                (12a c  - 28a b c )d e  + 48a b c d e
+--R                              + 
+--R                                      2 4       2 3  4 4         4 5 3
+--R                                (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                              + 
+--R                                     5 6 2    6 8
+--R                                12a c d e  - c d
+--R                           /
+--R                                        5 9           4 2 8          3 4 7
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6 6
+--R                                - 65536a b c
+--R                     + 
+--R                          2         3  4        2 2       2     3         2 2 2
+--R                       (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                     + 
+--R                           3 3       3 4
+--R                       8a c d e - b c d
+--R                  /
+--R                          3 5        2 2 4         4 3
+--R                     2048a c  - 1024a b c  + 128a b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    3 5        2 2 4         4 3
+--R                              (4096a c  - 2048a b c  + 256a b c )
+--R                           *
+--R                              ROOT
+--R                                         4 2     3 2     2 4  8
+--R                                     (- a c  + 2a b c - a b )e
+--R                                   + 
+--R                                          3   2     2 3     7
+--R                                     (- 8a b c  + 8a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 6      2   3 3 5
+--R                                     (12a c  - 28a b c )d e  + 48a b c d e
+--R                                   + 
+--R                                           2 4       2 3  4 4         4 5 3
+--R                                     (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                   + 
+--R                                          5 6 2    6 8
+--R                                     12a c d e  - c d
+--R                                /
+--R                                             5 9           4 2 8          3 4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6 6
+--R                                     - 65536a b c
+--R                          + 
+--R                               2         3  4        2 2       2     3
+--R                            (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                          + 
+--R                                    2 2 2       3 3       3 4
+--R                            - 6a b c d e  + 8a c d e - b c d
+--R                       /
+--R                               3 5        2 2 4         4 3
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                    5     4 2  10     4        3 3    9
+--R                  (a c - a b )e   + (a b c + 3a b )d e
+--R                + 
+--R                       4 2      3 2      2 4  2 8
+--R                  (- 3a c  - 12a b c - 3a b )d e
+--R                + 
+--R                      3   2      2 3       5  3 7
+--R                  (24a b c  + 17a b c + a b )d e
+--R                + 
+--R                        3 3      2 2 2       4   4 6       2   3        3 2  5 5
+--R                  (- 14a c  - 42a b c  - 7a b c)d e  + (42a b c  + 21a b c )d e
+--R                + 
+--R                        2 4        2 3  6 4           4    3 3  7 3
+--R                  (- 14a c  - 28a b c )d e  + (16a b c  - b c )d e
+--R                + 
+--R                         5     2 4  8 2       5 9     6 10
+--R                  (- 3a c  + 3b c )d e  - 3b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  3 5        2 2 4         4 3
+--R                          (- 4096a c  + 2048a b c  - 256a b c )
+--R                       *
+--R                          ROOT
+--R                                     4 2     3 2     2 4  8
+--R                                 (- a c  + 2a b c - a b )e
+--R                               + 
+--R                                      3   2     2 3     7
+--R                                 (- 8a b c  + 8a b c)d e
+--R                               + 
+--R                                     3 3      2 2 2  2 6      2   3 3 5
+--R                                 (12a c  - 28a b c )d e  + 48a b c d e
+--R                               + 
+--R                                       2 4       2 3  4 4         4 5 3
+--R                                 (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                               + 
+--R                                      5 6 2    6 8
+--R                                 12a c d e  - c d
+--R                            /
+--R                                         5 9           4 2 8          3 4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         2 6 6
+--R                                 - 65536a b c
+--R                      + 
+--R                           2         3  4        2 2       2     3         2 2 2
+--R                        (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                      + 
+--R                            3 3       3 4
+--R                        8a c d e - b c d
+--R                   /
+--R                           3 5        2 2 4         4 3
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                                    6 7          5 2 6          4 4 5
+--R                             262144a c  - 327680a b c  + 147456a b c
+--R                           + 
+--R                                     3 6 4        2 8 3
+--R                             - 28672a b c  + 2048a b c
+--R                        *
+--R                            3
+--R                           e
+--R                       + 
+--R                                    5   7          4 3 6         3 5 5
+--R                             393216a b c  - 294912a b c  + 73728a b c
+--R                           + 
+--R                                    2 7 4
+--R                             - 6144a b c
+--R                        *
+--R                              2
+--R                           d e
+--R                       + 
+--R                                      5 8          4 2 7          3 4 6
+--R                             - 786432a c  + 589824a b c  - 147456a b c
+--R                           + 
+--R                                   2 6 5
+--R                             12288a b c
+--R                        *
+--R                            2
+--R                           d e
+--R                       + 
+--R                               4   8         3 3 7         2 5 6          7 5  3
+--R                       (131072a b c  - 98304a b c  + 24576a b c  - 2048a b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                          5   3       4 3 2      3 5      2 7  7
+--R                     (128a b c  - 192a b c  + 72a b c - 8a b )e
+--R                   + 
+--R                            5 4        4 2 3       3 4 2      2 6     6
+--R                     (- 384a c  + 1088a b c  - 472a b c  + 56a b c)d e
+--R                   + 
+--R                             4   4        3 3 3       2 5 2  2 5
+--R                     (- 2304a b c  + 1152a b c  - 144a b c )d e
+--R                   + 
+--R                           4 5        3 2 4       2 4 3       6 2  3 4
+--R                     (2432a c  - 1344a b c  + 216a b c  - 8a b c )d e
+--R                   + 
+--R                          3   5       2 3 4        5 3  4 3
+--R                     (640a b c  - 320a b c  + 40a b c )d e
+--R                   + 
+--R                             3 6       2 2 5        4 4  5 2
+--R                     (- 1152a c  + 576a b c  - 72a b c )d e
+--R                   + 
+--R                          2 7        2 6     4 5  7
+--R                     (128a c  - 64a b c  + 8b c )d
+--R                *
+--R                   ROOT
+--R                                    3 5        2 2 4         4 3
+--R                            (- 4096a c  + 2048a b c  - 256a b c )
+--R                         *
+--R                            ROOT
+--R                                       4 2     3 2     2 4  8
+--R                                   (- a c  + 2a b c - a b )e
+--R                                 + 
+--R                                        3   2     2 3     7
+--R                                   (- 8a b c  + 8a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 6      2   3 3 5
+--R                                   (12a c  - 28a b c )d e  + 48a b c d e
+--R                                 + 
+--R                                         2 4       2 3  4 4         4 5 3
+--R                                   (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                 + 
+--R                                        5 6 2    6 8
+--R                                   12a c d e  - c d
+--R                              /
+--R                                           5 9           4 2 8          3 4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           2 6 6
+--R                                   - 65536a b c
+--R                        + 
+--R                             2         3  4        2 2       2     3
+--R                          (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                        + 
+--R                                  2 2 2       3 3       3 4
+--R                          - 6a b c d e  + 8a c d e - b c d
+--R                     /
+--R                             3 5        2 2 4         4 3
+--R                        2048a c  - 1024a b c  + 128a b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         3 5        2 2 4         4 3
+--R                                 (- 4096a c  + 2048a b c  - 256a b c )
+--R                              *
+--R                                 ROOT
+--R                                            4 2     3 2     2 4  8
+--R                                        (- a c  + 2a b c - a b )e
+--R                                      + 
+--R                                             3   2     2 3     7
+--R                                        (- 8a b c  + 8a b c)d e
+--R                                      + 
+--R                                            3 3      2 2 2  2 6      2   3 3 5
+--R                                        (12a c  - 28a b c )d e  + 48a b c d e
+--R                                      + 
+--R                                              2 4       2 3  4 4         4 5 3
+--R                                        (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                      + 
+--R                                             5 6 2    6 8
+--R                                        12a c d e  - c d
+--R                                   /
+--R                                                5 9           4 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4 7         2 6 6
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  2         3  4        2 2       2     3
+--R                               (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                             + 
+--R                                       2 2 2       3 3       3 4
+--R                               - 6a b c d e  + 8a c d e - b c d
+--R                          /
+--R                                  3 5        2 2 4         4 3
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                       5     4 2  10     4        3 3    9
+--R                     (a c - a b )e   + (a b c + 3a b )d e
+--R                   + 
+--R                          4 2      3 2      2 4  2 8
+--R                     (- 3a c  - 12a b c - 3a b )d e
+--R                   + 
+--R                         3   2      2 3       5  3 7
+--R                     (24a b c  + 17a b c + a b )d e
+--R                   + 
+--R                           3 3      2 2 2       4   4 6
+--R                     (- 14a c  - 42a b c  - 7a b c)d e
+--R                   + 
+--R                         2   3        3 2  5 5         2 4        2 3  6 4
+--R                     (42a b c  + 21a b c )d e  + (- 14a c  - 28a b c )d e
+--R                   + 
+--R                             4    3 3  7 3          5     2 4  8 2       5 9
+--R                     (16a b c  - b c )d e  + (- 3a c  + 3b c )d e  - 3b c d e
+--R                   + 
+--R                      6 10
+--R                     c d
+--R                *
+--R                   x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               3 5        2 2 4         4 3
+--R                       (- 4096a c  + 2048a b c  - 256a b c )
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                        2         3  4        2 2       2     3         2 2 2
+--R                     (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                   + 
+--R                         3 3       3 4
+--R                     8a c d e - b c d
+--R                /
+--R                        3 5        2 2 4         4 3
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                                   6 7          5 2 6          4 4 5
+--R                          - 262144a c  + 327680a b c  - 147456a b c
+--R                        + 
+--R                                3 6 4        2 8 3
+--R                          28672a b c  - 2048a b c
+--R                     *
+--R                         3
+--R                        e
+--R                    + 
+--R                                     5   7          4 3 6         3 5 5
+--R                            - 393216a b c  + 294912a b c  - 73728a b c
+--R                          + 
+--R                                 2 7 4
+--R                            6144a b c
+--R                     *
+--R                           2
+--R                        d e
+--R                    + 
+--R                                5 8          4 2 7          3 4 6         2 6 5
+--R                        (786432a c  - 589824a b c  + 147456a b c  - 12288a b c )
+--R                     *
+--R                         2
+--R                        d e
+--R                    + 
+--R                              4   8         3 3 7         2 5 6          7 5  3
+--R                    (- 131072a b c  + 98304a b c  - 24576a b c  + 2048a b c )d
+--R                 *
+--R                    ROOT
+--R                               4 2     3 2     2 4  8        3   2     2 3     7
+--R                           (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                         + 
+--R                               3 3      2 2 2  2 6      2   3 3 5
+--R                           (12a c  - 28a b c )d e  + 48a b c d e
+--R                         + 
+--R                                 2 4       2 3  4 4         4 5 3        5 6 2
+--R                           (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                         + 
+--R                              6 8
+--R                           - c d
+--R                      /
+--R                                   5 9           4 2 8          3 4 7
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   2 6 6
+--R                           - 65536a b c
+--R                + 
+--R                         5   3       4 3 2      3 5      2 7  7
+--R                  (- 128a b c  + 192a b c  - 72a b c + 8a b )e
+--R                + 
+--R                       5 4        4 2 3       3 4 2      2 6     6
+--R                  (384a c  - 1088a b c  + 472a b c  - 56a b c)d e
+--R                + 
+--R                        4   4        3 3 3       2 5 2  2 5
+--R                  (2304a b c  - 1152a b c  + 144a b c )d e
+--R                + 
+--R                          4 5        3 2 4       2 4 3       6 2  3 4
+--R                  (- 2432a c  + 1344a b c  - 216a b c  + 8a b c )d e
+--R                + 
+--R                         3   5       2 3 4        5 3  4 3
+--R                  (- 640a b c  + 320a b c  - 40a b c )d e
+--R                + 
+--R                        3 6       2 2 5        4 4  5 2
+--R                  (1152a c  - 576a b c  + 72a b c )d e
+--R                + 
+--R                         2 7        2 6     4 5  7
+--R                  (- 128a c  + 64a b c  - 8b c )d
+--R             *
+--R                ROOT
+--R                                 3 5        2 2 4         4 3
+--R                         (- 4096a c  + 2048a b c  - 256a b c )
+--R                      *
+--R                         ROOT
+--R                                    4 2     3 2     2 4  8
+--R                                (- a c  + 2a b c - a b )e
+--R                              + 
+--R                                     3   2     2 3     7
+--R                                (- 8a b c  + 8a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 6      2   3 3 5
+--R                                (12a c  - 28a b c )d e  + 48a b c d e
+--R                              + 
+--R                                      2 4       2 3  4 4         4 5 3
+--R                                (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                              + 
+--R                                     5 6 2    6 8
+--R                                12a c d e  - c d
+--R                           /
+--R                                        5 9           4 2 8          3 4 7
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6 6
+--R                                - 65536a b c
+--R                     + 
+--R                          2         3  4        2 2       2     3         2 2 2
+--R                       (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                     + 
+--R                           3 3       3 4
+--R                       8a c d e - b c d
+--R                  /
+--R                          3 5        2 2 4         4 3
+--R                     2048a c  - 1024a b c  + 128a b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      3 5        2 2 4         4 3
+--R                              (- 4096a c  + 2048a b c  - 256a b c )
+--R                           *
+--R                              ROOT
+--R                                         4 2     3 2     2 4  8
+--R                                     (- a c  + 2a b c - a b )e
+--R                                   + 
+--R                                          3   2     2 3     7
+--R                                     (- 8a b c  + 8a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 6      2   3 3 5
+--R                                     (12a c  - 28a b c )d e  + 48a b c d e
+--R                                   + 
+--R                                           2 4       2 3  4 4         4 5 3
+--R                                     (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                   + 
+--R                                          5 6 2    6 8
+--R                                     12a c d e  - c d
+--R                                /
+--R                                             5 9           4 2 8          3 4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6 6
+--R                                     - 65536a b c
+--R                          + 
+--R                               2         3  4        2 2       2     3
+--R                            (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                          + 
+--R                                    2 2 2       3 3       3 4
+--R                            - 6a b c d e  + 8a c d e - b c d
+--R                       /
+--R                               3 5        2 2 4         4 3
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                    5     4 2  10     4        3 3    9
+--R                  (a c - a b )e   + (a b c + 3a b )d e
+--R                + 
+--R                       4 2      3 2      2 4  2 8
+--R                  (- 3a c  - 12a b c - 3a b )d e
+--R                + 
+--R                      3   2      2 3       5  3 7
+--R                  (24a b c  + 17a b c + a b )d e
+--R                + 
+--R                        3 3      2 2 2       4   4 6       2   3        3 2  5 5
+--R                  (- 14a c  - 42a b c  - 7a b c)d e  + (42a b c  + 21a b c )d e
+--R                + 
+--R                        2 4        2 3  6 4           4    3 3  7 3
+--R                  (- 14a c  - 28a b c )d e  + (16a b c  - b c )d e
+--R                + 
+--R                         5     2 4  8 2       5 9     6 10
+--R                  (- 3a c  + 3b c )d e  - 3b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                3 5        2 2 4         4 3
+--R                          (4096a c  - 2048a b c  + 256a b c )
+--R                       *
+--R                          ROOT
+--R                                     4 2     3 2     2 4  8
+--R                                 (- a c  + 2a b c - a b )e
+--R                               + 
+--R                                      3   2     2 3     7
+--R                                 (- 8a b c  + 8a b c)d e
+--R                               + 
+--R                                     3 3      2 2 2  2 6      2   3 3 5
+--R                                 (12a c  - 28a b c )d e  + 48a b c d e
+--R                               + 
+--R                                       2 4       2 3  4 4         4 5 3
+--R                                 (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                               + 
+--R                                      5 6 2    6 8
+--R                                 12a c d e  - c d
+--R                            /
+--R                                         5 9           4 2 8          3 4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         2 6 6
+--R                                 - 65536a b c
+--R                      + 
+--R                           2         3  4        2 2       2     3         2 2 2
+--R                        (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                      + 
+--R                            3 3       3 4
+--R                        8a c d e - b c d
+--R                   /
+--R                           3 5        2 2 4         4 3
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                                      6 7          5 2 6          4 4 5
+--R                             - 262144a c  + 327680a b c  - 147456a b c
+--R                           + 
+--R                                   3 6 4        2 8 3
+--R                             28672a b c  - 2048a b c
+--R                        *
+--R                            3
+--R                           e
+--R                       + 
+--R                                      5   7          4 3 6         3 5 5
+--R                             - 393216a b c  + 294912a b c  - 73728a b c
+--R                           + 
+--R                                  2 7 4
+--R                             6144a b c
+--R                        *
+--R                              2
+--R                           d e
+--R                       + 
+--R                                    5 8          4 2 7          3 4 6
+--R                             786432a c  - 589824a b c  + 147456a b c
+--R                           + 
+--R                                     2 6 5
+--R                             - 12288a b c
+--R                        *
+--R                            2
+--R                           d e
+--R                       + 
+--R                                      4   8         3 3 7         2 5 6
+--R                             - 131072a b c  + 98304a b c  - 24576a b c
+--R                           + 
+--R                                    7 5
+--R                             2048a b c
+--R                        *
+--R                            3
+--R                           d
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                          5   3       4 3 2      3 5      2 7  7
+--R                     (128a b c  - 192a b c  + 72a b c - 8a b )e
+--R                   + 
+--R                            5 4        4 2 3       3 4 2      2 6     6
+--R                     (- 384a c  + 1088a b c  - 472a b c  + 56a b c)d e
+--R                   + 
+--R                             4   4        3 3 3       2 5 2  2 5
+--R                     (- 2304a b c  + 1152a b c  - 144a b c )d e
+--R                   + 
+--R                           4 5        3 2 4       2 4 3       6 2  3 4
+--R                     (2432a c  - 1344a b c  + 216a b c  - 8a b c )d e
+--R                   + 
+--R                          3   5       2 3 4        5 3  4 3
+--R                     (640a b c  - 320a b c  + 40a b c )d e
+--R                   + 
+--R                             3 6       2 2 5        4 4  5 2
+--R                     (- 1152a c  + 576a b c  - 72a b c )d e
+--R                   + 
+--R                          2 7        2 6     4 5  7
+--R                     (128a c  - 64a b c  + 8b c )d
+--R                *
+--R                   ROOT
+--R                                  3 5        2 2 4         4 3
+--R                            (4096a c  - 2048a b c  + 256a b c )
+--R                         *
+--R                            ROOT
+--R                                       4 2     3 2     2 4  8
+--R                                   (- a c  + 2a b c - a b )e
+--R                                 + 
+--R                                        3   2     2 3     7
+--R                                   (- 8a b c  + 8a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 6      2   3 3 5
+--R                                   (12a c  - 28a b c )d e  + 48a b c d e
+--R                                 + 
+--R                                         2 4       2 3  4 4         4 5 3
+--R                                   (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                 + 
+--R                                        5 6 2    6 8
+--R                                   12a c d e  - c d
+--R                              /
+--R                                           5 9           4 2 8          3 4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           2 6 6
+--R                                   - 65536a b c
+--R                        + 
+--R                             2         3  4        2 2       2     3
+--R                          (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                        + 
+--R                                  2 2 2       3 3       3 4
+--R                          - 6a b c d e  + 8a c d e - b c d
+--R                     /
+--R                             3 5        2 2 4         4 3
+--R                        2048a c  - 1024a b c  + 128a b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       3 5        2 2 4         4 3
+--R                                 (4096a c  - 2048a b c  + 256a b c )
+--R                              *
+--R                                 ROOT
+--R                                            4 2     3 2     2 4  8
+--R                                        (- a c  + 2a b c - a b )e
+--R                                      + 
+--R                                             3   2     2 3     7
+--R                                        (- 8a b c  + 8a b c)d e
+--R                                      + 
+--R                                            3 3      2 2 2  2 6      2   3 3 5
+--R                                        (12a c  - 28a b c )d e  + 48a b c d e
+--R                                      + 
+--R                                              2 4       2 3  4 4         4 5 3
+--R                                        (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                      + 
+--R                                             5 6 2    6 8
+--R                                        12a c d e  - c d
+--R                                   /
+--R                                                5 9           4 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4 7         2 6 6
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  2         3  4        2 2       2     3
+--R                               (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                             + 
+--R                                       2 2 2       3 3       3 4
+--R                               - 6a b c d e  + 8a c d e - b c d
+--R                          /
+--R                                  3 5        2 2 4         4 3
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                       5     4 2  10     4        3 3    9
+--R                     (a c - a b )e   + (a b c + 3a b )d e
+--R                   + 
+--R                          4 2      3 2      2 4  2 8
+--R                     (- 3a c  - 12a b c - 3a b )d e
+--R                   + 
+--R                         3   2      2 3       5  3 7
+--R                     (24a b c  + 17a b c + a b )d e
+--R                   + 
+--R                           3 3      2 2 2       4   4 6
+--R                     (- 14a c  - 42a b c  - 7a b c)d e
+--R                   + 
+--R                         2   3        3 2  5 5         2 4        2 3  6 4
+--R                     (42a b c  + 21a b c )d e  + (- 14a c  - 28a b c )d e
+--R                   + 
+--R                             4    3 3  7 3          5     2 4  8 2       5 9
+--R                     (16a b c  - b c )d e  + (- 3a c  + 3b c )d e  - 3b c d e
+--R                   + 
+--R                      6 10
+--R                     c d
+--R                *
+--R                   x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             3 5        2 2 4         4 3
+--R                       (4096a c  - 2048a b c  + 256a b c )
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                        2         3  4        2 2       2     3         2 2 2
+--R                     (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                   + 
+--R                         3 3       3 4
+--R                     8a c d e - b c d
+--R                /
+--R                        3 5        2 2 4         4 3
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         atan
+--R                                 6 7          5 2 6          4 4 5         3 6 4
+--R                          262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                        + 
+--R                               2 8 3
+--R                          2048a b c
+--R                     *
+--R                         3
+--R                        e
+--R                    + 
+--R                                5   7          4 3 6         3 5 5        2 7 4
+--R                        (393216a b c  - 294912a b c  + 73728a b c  - 6144a b c )
+--R                     *
+--R                           2
+--R                        d e
+--R                    + 
+--R                                     5 8          4 2 7          3 4 6
+--R                            - 786432a c  + 589824a b c  - 147456a b c
+--R                          + 
+--R                                  2 6 5
+--R                            12288a b c
+--R                     *
+--R                         2
+--R                        d e
+--R                    + 
+--R                              4   8         3 3 7         2 5 6          7 5  3
+--R                      (131072a b c  - 98304a b c  + 24576a b c  - 2048a b c )d
+--R                 *
+--R                    ROOT
+--R                               4 2     3 2     2 4  8        3   2     2 3     7
+--R                           (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                         + 
+--R                               3 3      2 2 2  2 6      2   3 3 5
+--R                           (12a c  - 28a b c )d e  + 48a b c d e
+--R                         + 
+--R                                 2 4       2 3  4 4         4 5 3        5 6 2
+--R                           (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                         + 
+--R                              6 8
+--R                           - c d
+--R                      /
+--R                                   5 9           4 2 8          3 4 7
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   2 6 6
+--R                           - 65536a b c
+--R                + 
+--R                         5   3       4 3 2      3 5      2 7  7
+--R                  (- 128a b c  + 192a b c  - 72a b c + 8a b )e
+--R                + 
+--R                       5 4        4 2 3       3 4 2      2 6     6
+--R                  (384a c  - 1088a b c  + 472a b c  - 56a b c)d e
+--R                + 
+--R                        4   4        3 3 3       2 5 2  2 5
+--R                  (2304a b c  - 1152a b c  + 144a b c )d e
+--R                + 
+--R                          4 5        3 2 4       2 4 3       6 2  3 4
+--R                  (- 2432a c  + 1344a b c  - 216a b c  + 8a b c )d e
+--R                + 
+--R                         3   5       2 3 4        5 3  4 3
+--R                  (- 640a b c  + 320a b c  - 40a b c )d e
+--R                + 
+--R                        3 6       2 2 5        4 4  5 2
+--R                  (1152a c  - 576a b c  + 72a b c )d e
+--R                + 
+--R                         2 7        2 6     4 5  7
+--R                  (- 128a c  + 64a b c  - 8b c )d
+--R             *
+--R                ROOT
+--R                               3 5        2 2 4         4 3
+--R                         (4096a c  - 2048a b c  + 256a b c )
+--R                      *
+--R                         ROOT
+--R                                    4 2     3 2     2 4  8
+--R                                (- a c  + 2a b c - a b )e
+--R                              + 
+--R                                     3   2     2 3     7
+--R                                (- 8a b c  + 8a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 6      2   3 3 5
+--R                                (12a c  - 28a b c )d e  + 48a b c d e
+--R                              + 
+--R                                      2 4       2 3  4 4         4 5 3
+--R                                (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                              + 
+--R                                     5 6 2    6 8
+--R                                12a c d e  - c d
+--R                           /
+--R                                        5 9           4 2 8          3 4 7
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6 6
+--R                                - 65536a b c
+--R                     + 
+--R                          2         3  4        2 2       2     3         2 2 2
+--R                       (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                     + 
+--R                           3 3       3 4
+--R                       8a c d e - b c d
+--R                  /
+--R                          3 5        2 2 4         4 3
+--R                     2048a c  - 1024a b c  + 128a b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    3 5        2 2 4         4 3
+--R                              (4096a c  - 2048a b c  + 256a b c )
+--R                           *
+--R                              ROOT
+--R                                         4 2     3 2     2 4  8
+--R                                     (- a c  + 2a b c - a b )e
+--R                                   + 
+--R                                          3   2     2 3     7
+--R                                     (- 8a b c  + 8a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 6      2   3 3 5
+--R                                     (12a c  - 28a b c )d e  + 48a b c d e
+--R                                   + 
+--R                                           2 4       2 3  4 4         4 5 3
+--R                                     (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                   + 
+--R                                          5 6 2    6 8
+--R                                     12a c d e  - c d
+--R                                /
+--R                                             5 9           4 2 8          3 4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6 6
+--R                                     - 65536a b c
+--R                          + 
+--R                               2         3  4        2 2       2     3
+--R                            (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                          + 
+--R                                    2 2 2       3 3       3 4
+--R                            - 6a b c d e  + 8a c d e - b c d
+--R                       /
+--R                               3 5        2 2 4         4 3
+--R                          2048a c  - 1024a b c  + 128a b c
+--R           /
+--R                    5     4 2  10     4        3 3    9
+--R                  (a c - a b )e   + (a b c + 3a b )d e
+--R                + 
+--R                       4 2      3 2      2 4  2 8
+--R                  (- 3a c  - 12a b c - 3a b )d e
+--R                + 
+--R                      3   2      2 3       5  3 7
+--R                  (24a b c  + 17a b c + a b )d e
+--R                + 
+--R                        3 3      2 2 2       4   4 6       2   3        3 2  5 5
+--R                  (- 14a c  - 42a b c  - 7a b c)d e  + (42a b c  + 21a b c )d e
+--R                + 
+--R                        2 4        2 3  6 4           4    3 3  7 3
+--R                  (- 14a c  - 28a b c )d e  + (16a b c  - b c )d e
+--R                + 
+--R                         5     2 4  8 2       5 9     6 10
+--R                  (- 3a c  + 3b c )d e  - 3b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  3 5        2 2 4         4 3
+--R                          (- 4096a c  + 2048a b c  - 256a b c )
+--R                       *
+--R                          ROOT
+--R                                     4 2     3 2     2 4  8
+--R                                 (- a c  + 2a b c - a b )e
+--R                               + 
+--R                                      3   2     2 3     7
+--R                                 (- 8a b c  + 8a b c)d e
+--R                               + 
+--R                                     3 3      2 2 2  2 6      2   3 3 5
+--R                                 (12a c  - 28a b c )d e  + 48a b c d e
+--R                               + 
+--R                                       2 4       2 3  4 4         4 5 3
+--R                                 (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                               + 
+--R                                      5 6 2    6 8
+--R                                 12a c d e  - c d
+--R                            /
+--R                                         5 9           4 2 8          3 4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         2 6 6
+--R                                 - 65536a b c
+--R                      + 
+--R                           2         3  4        2 2       2     3         2 2 2
+--R                        (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                      + 
+--R                            3 3       3 4
+--R                        8a c d e - b c d
+--R                   /
+--R                           3 5        2 2 4         4 3
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            atan
+--R                                    6 7          5 2 6          4 4 5
+--R                             262144a c  - 327680a b c  + 147456a b c
+--R                           + 
+--R                                     3 6 4        2 8 3
+--R                             - 28672a b c  + 2048a b c
+--R                        *
+--R                            3
+--R                           e
+--R                       + 
+--R                                    5   7          4 3 6         3 5 5
+--R                             393216a b c  - 294912a b c  + 73728a b c
+--R                           + 
+--R                                    2 7 4
+--R                             - 6144a b c
+--R                        *
+--R                              2
+--R                           d e
+--R                       + 
+--R                                      5 8          4 2 7          3 4 6
+--R                             - 786432a c  + 589824a b c  - 147456a b c
+--R                           + 
+--R                                   2 6 5
+--R                             12288a b c
+--R                        *
+--R                            2
+--R                           d e
+--R                       + 
+--R                               4   8         3 3 7         2 5 6          7 5  3
+--R                       (131072a b c  - 98304a b c  + 24576a b c  - 2048a b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                          5   3       4 3 2      3 5      2 7  7
+--R                     (128a b c  - 192a b c  + 72a b c - 8a b )e
+--R                   + 
+--R                            5 4        4 2 3       3 4 2      2 6     6
+--R                     (- 384a c  + 1088a b c  - 472a b c  + 56a b c)d e
+--R                   + 
+--R                             4   4        3 3 3       2 5 2  2 5
+--R                     (- 2304a b c  + 1152a b c  - 144a b c )d e
+--R                   + 
+--R                           4 5        3 2 4       2 4 3       6 2  3 4
+--R                     (2432a c  - 1344a b c  + 216a b c  - 8a b c )d e
+--R                   + 
+--R                          3   5       2 3 4        5 3  4 3
+--R                     (640a b c  - 320a b c  + 40a b c )d e
+--R                   + 
+--R                             3 6       2 2 5        4 4  5 2
+--R                     (- 1152a c  + 576a b c  - 72a b c )d e
+--R                   + 
+--R                          2 7        2 6     4 5  7
+--R                     (128a c  - 64a b c  + 8b c )d
+--R                *
+--R                   ROOT
+--R                                    3 5        2 2 4         4 3
+--R                            (- 4096a c  + 2048a b c  - 256a b c )
+--R                         *
+--R                            ROOT
+--R                                       4 2     3 2     2 4  8
+--R                                   (- a c  + 2a b c - a b )e
+--R                                 + 
+--R                                        3   2     2 3     7
+--R                                   (- 8a b c  + 8a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 6      2   3 3 5
+--R                                   (12a c  - 28a b c )d e  + 48a b c d e
+--R                                 + 
+--R                                         2 4       2 3  4 4         4 5 3
+--R                                   (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                 + 
+--R                                        5 6 2    6 8
+--R                                   12a c d e  - c d
+--R                              /
+--R                                           5 9           4 2 8          3 4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           2 6 6
+--R                                   - 65536a b c
+--R                        + 
+--R                             2         3  4        2 2       2     3
+--R                          (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                        + 
+--R                                  2 2 2       3 3       3 4
+--R                          - 6a b c d e  + 8a c d e - b c d
+--R                     /
+--R                             3 5        2 2 4         4 3
+--R                        2048a c  - 1024a b c  + 128a b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         3 5        2 2 4         4 3
+--R                                 (- 4096a c  + 2048a b c  - 256a b c )
+--R                              *
+--R                                 ROOT
+--R                                            4 2     3 2     2 4  8
+--R                                        (- a c  + 2a b c - a b )e
+--R                                      + 
+--R                                             3   2     2 3     7
+--R                                        (- 8a b c  + 8a b c)d e
+--R                                      + 
+--R                                            3 3      2 2 2  2 6      2   3 3 5
+--R                                        (12a c  - 28a b c )d e  + 48a b c d e
+--R                                      + 
+--R                                              2 4       2 3  4 4         4 5 3
+--R                                        (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                      + 
+--R                                             5 6 2    6 8
+--R                                        12a c d e  - c d
+--R                                   /
+--R                                                5 9           4 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4 7         2 6 6
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  2         3  4        2 2       2     3
+--R                               (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                             + 
+--R                                       2 2 2       3 3       3 4
+--R                               - 6a b c d e  + 8a c d e - b c d
+--R                          /
+--R                                  3 5        2 2 4         4 3
+--R                             2048a c  - 1024a b c  + 128a b c
+--R              /
+--R                       5     4 2  10     4        3 3    9
+--R                     (a c - a b )e   + (a b c + 3a b )d e
+--R                   + 
+--R                          4 2      3 2      2 4  2 8
+--R                     (- 3a c  - 12a b c - 3a b )d e
+--R                   + 
+--R                         3   2      2 3       5  3 7
+--R                     (24a b c  + 17a b c + a b )d e
+--R                   + 
+--R                           3 3      2 2 2       4   4 6
+--R                     (- 14a c  - 42a b c  - 7a b c)d e
+--R                   + 
+--R                         2   3        3 2  5 5         2 4        2 3  6 4
+--R                     (42a b c  + 21a b c )d e  + (- 14a c  - 28a b c )d e
+--R                   + 
+--R                             4    3 3  7 3          5     2 4  8 2       5 9
+--R                     (16a b c  - b c )d e  + (- 3a c  + 3b c )d e  - 3b c d e
+--R                   + 
+--R                      6 10
+--R                     c d
+--R                *
+--R                   x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 211
+
+--S 212 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   +--------------------+ +------------------+
+--R               +-----------+       |   +-----------+      | +-----------+
+--R         4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R         \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             3 5        2 2 4         4 3
+--R                       (4096a c  - 2048a b c  + 256a b c )
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                        2         3  4        2 2       2     3         2 2 2
+--R                     (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                   + 
+--R                         3 3       3 4
+--R                     8a c d e - b c d
+--R                /
+--R                        3 5        2 2 4         4 3
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                                 6 7          5 2 6          4 4 5         3 6 4
+--R                          262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                        + 
+--R                               2 8 3
+--R                          2048a b c
+--R                     *
+--R                         3
+--R                        e
+--R                    + 
+--R                                5   7          4 3 6         3 5 5        2 7 4
+--R                        (393216a b c  - 294912a b c  + 73728a b c  - 6144a b c )
+--R                     *
+--R                           2
+--R                        d e
+--R                    + 
+--R                                     5 8          4 2 7          3 4 6
+--R                            - 786432a c  + 589824a b c  - 147456a b c
+--R                          + 
+--R                                  2 6 5
+--R                            12288a b c
+--R                     *
+--R                         2
+--R                        d e
+--R                    + 
+--R                              4   8         3 3 7         2 5 6          7 5  3
+--R                      (131072a b c  - 98304a b c  + 24576a b c  - 2048a b c )d
+--R                 *
+--R                    ROOT
+--R                               4 2     3 2     2 4  8        3   2     2 3     7
+--R                           (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                         + 
+--R                               3 3      2 2 2  2 6      2   3 3 5
+--R                           (12a c  - 28a b c )d e  + 48a b c d e
+--R                         + 
+--R                                 2 4       2 3  4 4         4 5 3        5 6 2
+--R                           (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                         + 
+--R                              6 8
+--R                           - c d
+--R                      /
+--R                                   5 9           4 2 8          3 4 7
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   2 6 6
+--R                           - 65536a b c
+--R                + 
+--R                         5   3       4 3 2      3 5      2 7  7
+--R                  (- 128a b c  + 192a b c  - 72a b c + 8a b )e
+--R                + 
+--R                       5 4        4 2 3       3 4 2      2 6     6
+--R                  (384a c  - 1088a b c  + 472a b c  - 56a b c)d e
+--R                + 
+--R                        4   4        3 3 3       2 5 2  2 5
+--R                  (2304a b c  - 1152a b c  + 144a b c )d e
+--R                + 
+--R                          4 5        3 2 4       2 4 3       6 2  3 4
+--R                  (- 2432a c  + 1344a b c  - 216a b c  + 8a b c )d e
+--R                + 
+--R                         3   5       2 3 4        5 3  4 3
+--R                  (- 640a b c  + 320a b c  - 40a b c )d e
+--R                + 
+--R                        3 6       2 2 5        4 4  5 2
+--R                  (1152a c  - 576a b c  + 72a b c )d e
+--R                + 
+--R                         2 7        2 6     4 5  7
+--R                  (- 128a c  + 64a b c  - 8b c )d
+--R             *
+--R                ROOT
+--R                               3 5        2 2 4         4 3
+--R                         (4096a c  - 2048a b c  + 256a b c )
+--R                      *
+--R                         ROOT
+--R                                    4 2     3 2     2 4  8
+--R                                (- a c  + 2a b c - a b )e
+--R                              + 
+--R                                     3   2     2 3     7
+--R                                (- 8a b c  + 8a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 6      2   3 3 5
+--R                                (12a c  - 28a b c )d e  + 48a b c d e
+--R                              + 
+--R                                      2 4       2 3  4 4         4 5 3
+--R                                (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                              + 
+--R                                     5 6 2    6 8
+--R                                12a c d e  - c d
+--R                           /
+--R                                        5 9           4 2 8          3 4 7
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6 6
+--R                                - 65536a b c
+--R                     + 
+--R                          2         3  4        2 2       2     3         2 2 2
+--R                       (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                     + 
+--R                           3 3       3 4
+--R                       8a c d e - b c d
+--R                  /
+--R                          3 5        2 2 4         4 3
+--R                     2048a c  - 1024a b c  + 128a b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    3 5        2 2 4         4 3
+--R                              (4096a c  - 2048a b c  + 256a b c )
+--R                           *
+--R                              ROOT
+--R                                         4 2     3 2     2 4  8
+--R                                     (- a c  + 2a b c - a b )e
+--R                                   + 
+--R                                          3   2     2 3     7
+--R                                     (- 8a b c  + 8a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 6      2   3 3 5
+--R                                     (12a c  - 28a b c )d e  + 48a b c d e
+--R                                   + 
+--R                                           2 4       2 3  4 4         4 5 3
+--R                                     (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                   + 
+--R                                          5 6 2    6 8
+--R                                     12a c d e  - c d
+--R                                /
+--R                                             5 9           4 2 8          3 4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6 6
+--R                                     - 65536a b c
+--R                          + 
+--R                               2         3  4        2 2       2     3
+--R                            (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                          + 
+--R                                    2 2 2       3 3       3 4
+--R                            - 6a b c d e  + 8a c d e - b c d
+--R                       /
+--R                               3 5        2 2 4         4 3
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                    5     4 2  10     4        3 3    9
+--R                  (a c - a b )e   + (a b c + 3a b )d e
+--R                + 
+--R                       4 2      3 2      2 4  2 8
+--R                  (- 3a c  - 12a b c - 3a b )d e
+--R                + 
+--R                      3   2      2 3       5  3 7
+--R                  (24a b c  + 17a b c + a b )d e
+--R                + 
+--R                        3 3      2 2 2       4   4 6       2   3        3 2  5 5
+--R                  (- 14a c  - 42a b c  - 7a b c)d e  + (42a b c  + 21a b c )d e
+--R                + 
+--R                        2 4        2 3  6 4           4    3 3  7 3
+--R                  (- 14a c  - 28a b c )d e  + (16a b c  - b c )d e
+--R                + 
+--R                         5     2 4  8 2       5 9     6 10
+--R                  (- 3a c  + 3b c )d e  - 3b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R            4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R            \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  3 5        2 2 4         4 3
+--R                          (- 4096a c  + 2048a b c  - 256a b c )
+--R                       *
+--R                          ROOT
+--R                                     4 2     3 2     2 4  8
+--R                                 (- a c  + 2a b c - a b )e
+--R                               + 
+--R                                      3   2     2 3     7
+--R                                 (- 8a b c  + 8a b c)d e
+--R                               + 
+--R                                     3 3      2 2 2  2 6      2   3 3 5
+--R                                 (12a c  - 28a b c )d e  + 48a b c d e
+--R                               + 
+--R                                       2 4       2 3  4 4         4 5 3
+--R                                 (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                               + 
+--R                                      5 6 2    6 8
+--R                                 12a c d e  - c d
+--R                            /
+--R                                         5 9           4 2 8          3 4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         2 6 6
+--R                                 - 65536a b c
+--R                      + 
+--R                           2         3  4        2 2       2     3         2 2 2
+--R                        (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                      + 
+--R                            3 3       3 4
+--R                        8a c d e - b c d
+--R                   /
+--R                           3 5        2 2 4         4 3
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                                    6 7          5 2 6          4 4 5
+--R                             262144a c  - 327680a b c  + 147456a b c
+--R                           + 
+--R                                     3 6 4        2 8 3
+--R                             - 28672a b c  + 2048a b c
+--R                        *
+--R                            3
+--R                           e
+--R                       + 
+--R                                    5   7          4 3 6         3 5 5
+--R                             393216a b c  - 294912a b c  + 73728a b c
+--R                           + 
+--R                                    2 7 4
+--R                             - 6144a b c
+--R                        *
+--R                              2
+--R                           d e
+--R                       + 
+--R                                      5 8          4 2 7          3 4 6
+--R                             - 786432a c  + 589824a b c  - 147456a b c
+--R                           + 
+--R                                   2 6 5
+--R                             12288a b c
+--R                        *
+--R                            2
+--R                           d e
+--R                       + 
+--R                               4   8         3 3 7         2 5 6          7 5  3
+--R                       (131072a b c  - 98304a b c  + 24576a b c  - 2048a b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                          5   3       4 3 2      3 5      2 7  7
+--R                     (128a b c  - 192a b c  + 72a b c - 8a b )e
+--R                   + 
+--R                            5 4        4 2 3       3 4 2      2 6     6
+--R                     (- 384a c  + 1088a b c  - 472a b c  + 56a b c)d e
+--R                   + 
+--R                             4   4        3 3 3       2 5 2  2 5
+--R                     (- 2304a b c  + 1152a b c  - 144a b c )d e
+--R                   + 
+--R                           4 5        3 2 4       2 4 3       6 2  3 4
+--R                     (2432a c  - 1344a b c  + 216a b c  - 8a b c )d e
+--R                   + 
+--R                          3   5       2 3 4        5 3  4 3
+--R                     (640a b c  - 320a b c  + 40a b c )d e
+--R                   + 
+--R                             3 6       2 2 5        4 4  5 2
+--R                     (- 1152a c  + 576a b c  - 72a b c )d e
+--R                   + 
+--R                          2 7        2 6     4 5  7
+--R                     (128a c  - 64a b c  + 8b c )d
+--R                *
+--R                   ROOT
+--R                                    3 5        2 2 4         4 3
+--R                            (- 4096a c  + 2048a b c  - 256a b c )
+--R                         *
+--R                            ROOT
+--R                                       4 2     3 2     2 4  8
+--R                                   (- a c  + 2a b c - a b )e
+--R                                 + 
+--R                                        3   2     2 3     7
+--R                                   (- 8a b c  + 8a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 6      2   3 3 5
+--R                                   (12a c  - 28a b c )d e  + 48a b c d e
+--R                                 + 
+--R                                         2 4       2 3  4 4         4 5 3
+--R                                   (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                 + 
+--R                                        5 6 2    6 8
+--R                                   12a c d e  - c d
+--R                              /
+--R                                           5 9           4 2 8          3 4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           2 6 6
+--R                                   - 65536a b c
+--R                        + 
+--R                             2         3  4        2 2       2     3
+--R                          (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                        + 
+--R                                  2 2 2       3 3       3 4
+--R                          - 6a b c d e  + 8a c d e - b c d
+--R                     /
+--R                             3 5        2 2 4         4 3
+--R                        2048a c  - 1024a b c  + 128a b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         3 5        2 2 4         4 3
+--R                                 (- 4096a c  + 2048a b c  - 256a b c )
+--R                              *
+--R                                 ROOT
+--R                                            4 2     3 2     2 4  8
+--R                                        (- a c  + 2a b c - a b )e
+--R                                      + 
+--R                                             3   2     2 3     7
+--R                                        (- 8a b c  + 8a b c)d e
+--R                                      + 
+--R                                            3 3      2 2 2  2 6      2   3 3 5
+--R                                        (12a c  - 28a b c )d e  + 48a b c d e
+--R                                      + 
+--R                                              2 4       2 3  4 4         4 5 3
+--R                                        (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                      + 
+--R                                             5 6 2    6 8
+--R                                        12a c d e  - c d
+--R                                   /
+--R                                                5 9           4 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4 7         2 6 6
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  2         3  4        2 2       2     3
+--R                               (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                             + 
+--R                                       2 2 2       3 3       3 4
+--R                               - 6a b c d e  + 8a c d e - b c d
+--R                          /
+--R                                  3 5        2 2 4         4 3
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                       5     4 2  10     4        3 3    9
+--R                     (a c - a b )e   + (a b c + 3a b )d e
+--R                   + 
+--R                          4 2      3 2      2 4  2 8
+--R                     (- 3a c  - 12a b c - 3a b )d e
+--R                   + 
+--R                         3   2      2 3       5  3 7
+--R                     (24a b c  + 17a b c + a b )d e
+--R                   + 
+--R                           3 3      2 2 2       4   4 6
+--R                     (- 14a c  - 42a b c  - 7a b c)d e
+--R                   + 
+--R                         2   3        3 2  5 5         2 4        2 3  6 4
+--R                     (42a b c  + 21a b c )d e  + (- 14a c  - 28a b c )d e
+--R                   + 
+--R                             4    3 3  7 3          5     2 4  8 2       5 9
+--R                     (16a b c  - b c )d e  + (- 3a c  + 3b c )d e  - 3b c d e
+--R                   + 
+--R                      6 10
+--R                     c d
+--R                *
+--R                   x
+--R     + 
+--R                                   +--------------------+ +------------------+
+--R               +-----------+       |   +-----------+      | +-----------+
+--R         4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R         \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               3 5        2 2 4         4 3
+--R                       (- 4096a c  + 2048a b c  - 256a b c )
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                        2         3  4        2 2       2     3         2 2 2
+--R                     (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                   + 
+--R                         3 3       3 4
+--R                     8a c d e - b c d
+--R                /
+--R                        3 5        2 2 4         4 3
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                                   6 7          5 2 6          4 4 5
+--R                          - 262144a c  + 327680a b c  - 147456a b c
+--R                        + 
+--R                                3 6 4        2 8 3
+--R                          28672a b c  - 2048a b c
+--R                     *
+--R                         3
+--R                        e
+--R                    + 
+--R                                     5   7          4 3 6         3 5 5
+--R                            - 393216a b c  + 294912a b c  - 73728a b c
+--R                          + 
+--R                                 2 7 4
+--R                            6144a b c
+--R                     *
+--R                           2
+--R                        d e
+--R                    + 
+--R                                5 8          4 2 7          3 4 6         2 6 5
+--R                        (786432a c  - 589824a b c  + 147456a b c  - 12288a b c )
+--R                     *
+--R                         2
+--R                        d e
+--R                    + 
+--R                              4   8         3 3 7         2 5 6          7 5  3
+--R                    (- 131072a b c  + 98304a b c  - 24576a b c  + 2048a b c )d
+--R                 *
+--R                    ROOT
+--R                               4 2     3 2     2 4  8        3   2     2 3     7
+--R                           (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                         + 
+--R                               3 3      2 2 2  2 6      2   3 3 5
+--R                           (12a c  - 28a b c )d e  + 48a b c d e
+--R                         + 
+--R                                 2 4       2 3  4 4         4 5 3        5 6 2
+--R                           (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                         + 
+--R                              6 8
+--R                           - c d
+--R                      /
+--R                                   5 9           4 2 8          3 4 7
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   2 6 6
+--R                           - 65536a b c
+--R                + 
+--R                         5   3       4 3 2      3 5      2 7  7
+--R                  (- 128a b c  + 192a b c  - 72a b c + 8a b )e
+--R                + 
+--R                       5 4        4 2 3       3 4 2      2 6     6
+--R                  (384a c  - 1088a b c  + 472a b c  - 56a b c)d e
+--R                + 
+--R                        4   4        3 3 3       2 5 2  2 5
+--R                  (2304a b c  - 1152a b c  + 144a b c )d e
+--R                + 
+--R                          4 5        3 2 4       2 4 3       6 2  3 4
+--R                  (- 2432a c  + 1344a b c  - 216a b c  + 8a b c )d e
+--R                + 
+--R                         3   5       2 3 4        5 3  4 3
+--R                  (- 640a b c  + 320a b c  - 40a b c )d e
+--R                + 
+--R                        3 6       2 2 5        4 4  5 2
+--R                  (1152a c  - 576a b c  + 72a b c )d e
+--R                + 
+--R                         2 7        2 6     4 5  7
+--R                  (- 128a c  + 64a b c  - 8b c )d
+--R             *
+--R                ROOT
+--R                                 3 5        2 2 4         4 3
+--R                         (- 4096a c  + 2048a b c  - 256a b c )
+--R                      *
+--R                         ROOT
+--R                                    4 2     3 2     2 4  8
+--R                                (- a c  + 2a b c - a b )e
+--R                              + 
+--R                                     3   2     2 3     7
+--R                                (- 8a b c  + 8a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 6      2   3 3 5
+--R                                (12a c  - 28a b c )d e  + 48a b c d e
+--R                              + 
+--R                                      2 4       2 3  4 4         4 5 3
+--R                                (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                              + 
+--R                                     5 6 2    6 8
+--R                                12a c d e  - c d
+--R                           /
+--R                                        5 9           4 2 8          3 4 7
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6 6
+--R                                - 65536a b c
+--R                     + 
+--R                          2         3  4        2 2       2     3         2 2 2
+--R                       (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                     + 
+--R                           3 3       3 4
+--R                       8a c d e - b c d
+--R                  /
+--R                          3 5        2 2 4         4 3
+--R                     2048a c  - 1024a b c  + 128a b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      3 5        2 2 4         4 3
+--R                              (- 4096a c  + 2048a b c  - 256a b c )
+--R                           *
+--R                              ROOT
+--R                                         4 2     3 2     2 4  8
+--R                                     (- a c  + 2a b c - a b )e
+--R                                   + 
+--R                                          3   2     2 3     7
+--R                                     (- 8a b c  + 8a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 6      2   3 3 5
+--R                                     (12a c  - 28a b c )d e  + 48a b c d e
+--R                                   + 
+--R                                           2 4       2 3  4 4         4 5 3
+--R                                     (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                   + 
+--R                                          5 6 2    6 8
+--R                                     12a c d e  - c d
+--R                                /
+--R                                             5 9           4 2 8          3 4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6 6
+--R                                     - 65536a b c
+--R                          + 
+--R                               2         3  4        2 2       2     3
+--R                            (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                          + 
+--R                                    2 2 2       3 3       3 4
+--R                            - 6a b c d e  + 8a c d e - b c d
+--R                       /
+--R                               3 5        2 2 4         4 3
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                    5     4 2  10     4        3 3    9
+--R                  (a c - a b )e   + (a b c + 3a b )d e
+--R                + 
+--R                       4 2      3 2      2 4  2 8
+--R                  (- 3a c  - 12a b c - 3a b )d e
+--R                + 
+--R                      3   2      2 3       5  3 7
+--R                  (24a b c  + 17a b c + a b )d e
+--R                + 
+--R                        3 3      2 2 2       4   4 6       2   3        3 2  5 5
+--R                  (- 14a c  - 42a b c  - 7a b c)d e  + (42a b c  + 21a b c )d e
+--R                + 
+--R                        2 4        2 3  6 4           4    3 3  7 3
+--R                  (- 14a c  - 28a b c )d e  + (16a b c  - b c )d e
+--R                + 
+--R                         5     2 4  8 2       5 9     6 10
+--R                  (- 3a c  + 3b c )d e  - 3b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R            4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R            \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                3 5        2 2 4         4 3
+--R                          (4096a c  - 2048a b c  + 256a b c )
+--R                       *
+--R                          ROOT
+--R                                     4 2     3 2     2 4  8
+--R                                 (- a c  + 2a b c - a b )e
+--R                               + 
+--R                                      3   2     2 3     7
+--R                                 (- 8a b c  + 8a b c)d e
+--R                               + 
+--R                                     3 3      2 2 2  2 6      2   3 3 5
+--R                                 (12a c  - 28a b c )d e  + 48a b c d e
+--R                               + 
+--R                                       2 4       2 3  4 4         4 5 3
+--R                                 (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                               + 
+--R                                      5 6 2    6 8
+--R                                 12a c d e  - c d
+--R                            /
+--R                                         5 9           4 2 8          3 4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         2 6 6
+--R                                 - 65536a b c
+--R                      + 
+--R                           2         3  4        2 2       2     3         2 2 2
+--R                        (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                      + 
+--R                            3 3       3 4
+--R                        8a c d e - b c d
+--R                   /
+--R                           3 5        2 2 4         4 3
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                                      6 7          5 2 6          4 4 5
+--R                             - 262144a c  + 327680a b c  - 147456a b c
+--R                           + 
+--R                                   3 6 4        2 8 3
+--R                             28672a b c  - 2048a b c
+--R                        *
+--R                            3
+--R                           e
+--R                       + 
+--R                                      5   7          4 3 6         3 5 5
+--R                             - 393216a b c  + 294912a b c  - 73728a b c
+--R                           + 
+--R                                  2 7 4
+--R                             6144a b c
+--R                        *
+--R                              2
+--R                           d e
+--R                       + 
+--R                                    5 8          4 2 7          3 4 6
+--R                             786432a c  - 589824a b c  + 147456a b c
+--R                           + 
+--R                                     2 6 5
+--R                             - 12288a b c
+--R                        *
+--R                            2
+--R                           d e
+--R                       + 
+--R                                      4   8         3 3 7         2 5 6
+--R                             - 131072a b c  + 98304a b c  - 24576a b c
+--R                           + 
+--R                                    7 5
+--R                             2048a b c
+--R                        *
+--R                            3
+--R                           d
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                          5   3       4 3 2      3 5      2 7  7
+--R                     (128a b c  - 192a b c  + 72a b c - 8a b )e
+--R                   + 
+--R                            5 4        4 2 3       3 4 2      2 6     6
+--R                     (- 384a c  + 1088a b c  - 472a b c  + 56a b c)d e
+--R                   + 
+--R                             4   4        3 3 3       2 5 2  2 5
+--R                     (- 2304a b c  + 1152a b c  - 144a b c )d e
+--R                   + 
+--R                           4 5        3 2 4       2 4 3       6 2  3 4
+--R                     (2432a c  - 1344a b c  + 216a b c  - 8a b c )d e
+--R                   + 
+--R                          3   5       2 3 4        5 3  4 3
+--R                     (640a b c  - 320a b c  + 40a b c )d e
+--R                   + 
+--R                             3 6       2 2 5        4 4  5 2
+--R                     (- 1152a c  + 576a b c  - 72a b c )d e
+--R                   + 
+--R                          2 7        2 6     4 5  7
+--R                     (128a c  - 64a b c  + 8b c )d
+--R                *
+--R                   ROOT
+--R                                  3 5        2 2 4         4 3
+--R                            (4096a c  - 2048a b c  + 256a b c )
+--R                         *
+--R                            ROOT
+--R                                       4 2     3 2     2 4  8
+--R                                   (- a c  + 2a b c - a b )e
+--R                                 + 
+--R                                        3   2     2 3     7
+--R                                   (- 8a b c  + 8a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 6      2   3 3 5
+--R                                   (12a c  - 28a b c )d e  + 48a b c d e
+--R                                 + 
+--R                                         2 4       2 3  4 4         4 5 3
+--R                                   (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                 + 
+--R                                        5 6 2    6 8
+--R                                   12a c d e  - c d
+--R                              /
+--R                                           5 9           4 2 8          3 4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           2 6 6
+--R                                   - 65536a b c
+--R                        + 
+--R                             2         3  4        2 2       2     3
+--R                          (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                        + 
+--R                                  2 2 2       3 3       3 4
+--R                          - 6a b c d e  + 8a c d e - b c d
+--R                     /
+--R                             3 5        2 2 4         4 3
+--R                        2048a c  - 1024a b c  + 128a b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       3 5        2 2 4         4 3
+--R                                 (4096a c  - 2048a b c  + 256a b c )
+--R                              *
+--R                                 ROOT
+--R                                            4 2     3 2     2 4  8
+--R                                        (- a c  + 2a b c - a b )e
+--R                                      + 
+--R                                             3   2     2 3     7
+--R                                        (- 8a b c  + 8a b c)d e
+--R                                      + 
+--R                                            3 3      2 2 2  2 6      2   3 3 5
+--R                                        (12a c  - 28a b c )d e  + 48a b c d e
+--R                                      + 
+--R                                              2 4       2 3  4 4         4 5 3
+--R                                        (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                      + 
+--R                                             5 6 2    6 8
+--R                                        12a c d e  - c d
+--R                                   /
+--R                                                5 9           4 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4 7         2 6 6
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  2         3  4        2 2       2     3
+--R                               (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                             + 
+--R                                       2 2 2       3 3       3 4
+--R                               - 6a b c d e  + 8a c d e - b c d
+--R                          /
+--R                                  3 5        2 2 4         4 3
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                       5     4 2  10     4        3 3    9
+--R                     (a c - a b )e   + (a b c + 3a b )d e
+--R                   + 
+--R                          4 2      3 2      2 4  2 8
+--R                     (- 3a c  - 12a b c - 3a b )d e
+--R                   + 
+--R                         3   2      2 3       5  3 7
+--R                     (24a b c  + 17a b c + a b )d e
+--R                   + 
+--R                           3 3      2 2 2       4   4 6
+--R                     (- 14a c  - 42a b c  - 7a b c)d e
+--R                   + 
+--R                         2   3        3 2  5 5         2 4        2 3  6 4
+--R                     (42a b c  + 21a b c )d e  + (- 14a c  - 28a b c )d e
+--R                   + 
+--R                             4    3 3  7 3          5     2 4  8 2       5 9
+--R                     (16a b c  - b c )d e  + (- 3a c  + 3b c )d e  - 3b c d e
+--R                   + 
+--R                      6 10
+--R                     c d
+--R                *
+--R                   x
+--R     + 
+--R                                    +--------------------+ +------------------+
+--R                +-----------+       |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R         2\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             3 5        2 2 4         4 3
+--R                       (4096a c  - 2048a b c  + 256a b c )
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                        2         3  4        2 2       2     3         2 2 2
+--R                     (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                   + 
+--R                         3 3       3 4
+--R                     8a c d e - b c d
+--R                /
+--R                        3 5        2 2 4         4 3
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         atan
+--R                                 6 7          5 2 6          4 4 5         3 6 4
+--R                          262144a c  - 327680a b c  + 147456a b c  - 28672a b c
+--R                        + 
+--R                               2 8 3
+--R                          2048a b c
+--R                     *
+--R                         3
+--R                        e
+--R                    + 
+--R                                5   7          4 3 6         3 5 5        2 7 4
+--R                        (393216a b c  - 294912a b c  + 73728a b c  - 6144a b c )
+--R                     *
+--R                           2
+--R                        d e
+--R                    + 
+--R                                     5 8          4 2 7          3 4 6
+--R                            - 786432a c  + 589824a b c  - 147456a b c
+--R                          + 
+--R                                  2 6 5
+--R                            12288a b c
+--R                     *
+--R                         2
+--R                        d e
+--R                    + 
+--R                              4   8         3 3 7         2 5 6          7 5  3
+--R                      (131072a b c  - 98304a b c  + 24576a b c  - 2048a b c )d
+--R                 *
+--R                    ROOT
+--R                               4 2     3 2     2 4  8        3   2     2 3     7
+--R                           (- a c  + 2a b c - a b )e  + (- 8a b c  + 8a b c)d e
+--R                         + 
+--R                               3 3      2 2 2  2 6      2   3 3 5
+--R                           (12a c  - 28a b c )d e  + 48a b c d e
+--R                         + 
+--R                                 2 4       2 3  4 4         4 5 3        5 6 2
+--R                           (- 38a c  + 2a b c )d e  - 8a b c d e  + 12a c d e
+--R                         + 
+--R                              6 8
+--R                           - c d
+--R                      /
+--R                                   5 9           4 2 8          3 4 7
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   2 6 6
+--R                           - 65536a b c
+--R                + 
+--R                         5   3       4 3 2      3 5      2 7  7
+--R                  (- 128a b c  + 192a b c  - 72a b c + 8a b )e
+--R                + 
+--R                       5 4        4 2 3       3 4 2      2 6     6
+--R                  (384a c  - 1088a b c  + 472a b c  - 56a b c)d e
+--R                + 
+--R                        4   4        3 3 3       2 5 2  2 5
+--R                  (2304a b c  - 1152a b c  + 144a b c )d e
+--R                + 
+--R                          4 5        3 2 4       2 4 3       6 2  3 4
+--R                  (- 2432a c  + 1344a b c  - 216a b c  + 8a b c )d e
+--R                + 
+--R                         3   5       2 3 4        5 3  4 3
+--R                  (- 640a b c  + 320a b c  - 40a b c )d e
+--R                + 
+--R                        3 6       2 2 5        4 4  5 2
+--R                  (1152a c  - 576a b c  + 72a b c )d e
+--R                + 
+--R                         2 7        2 6     4 5  7
+--R                  (- 128a c  + 64a b c  - 8b c )d
+--R             *
+--R                ROOT
+--R                               3 5        2 2 4         4 3
+--R                         (4096a c  - 2048a b c  + 256a b c )
+--R                      *
+--R                         ROOT
+--R                                    4 2     3 2     2 4  8
+--R                                (- a c  + 2a b c - a b )e
+--R                              + 
+--R                                     3   2     2 3     7
+--R                                (- 8a b c  + 8a b c)d e
+--R                              + 
+--R                                    3 3      2 2 2  2 6      2   3 3 5
+--R                                (12a c  - 28a b c )d e  + 48a b c d e
+--R                              + 
+--R                                      2 4       2 3  4 4         4 5 3
+--R                                (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                              + 
+--R                                     5 6 2    6 8
+--R                                12a c d e  - c d
+--R                           /
+--R                                        5 9           4 2 8          3 4 7
+--R                                4194304a c  - 3145728a b c  + 786432a b c
+--R                              + 
+--R                                        2 6 6
+--R                                - 65536a b c
+--R                     + 
+--R                          2         3  4        2 2       2     3         2 2 2
+--R                       (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                     + 
+--R                           3 3       3 4
+--R                       8a c d e - b c d
+--R                  /
+--R                          3 5        2 2 4         4 3
+--R                     2048a c  - 1024a b c  + 128a b c
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    3 5        2 2 4         4 3
+--R                              (4096a c  - 2048a b c  + 256a b c )
+--R                           *
+--R                              ROOT
+--R                                         4 2     3 2     2 4  8
+--R                                     (- a c  + 2a b c - a b )e
+--R                                   + 
+--R                                          3   2     2 3     7
+--R                                     (- 8a b c  + 8a b c)d e
+--R                                   + 
+--R                                         3 3      2 2 2  2 6      2   3 3 5
+--R                                     (12a c  - 28a b c )d e  + 48a b c d e
+--R                                   + 
+--R                                           2 4       2 3  4 4         4 5 3
+--R                                     (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                   + 
+--R                                          5 6 2    6 8
+--R                                     12a c d e  - c d
+--R                                /
+--R                                             5 9           4 2 8          3 4 7
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             2 6 6
+--R                                     - 65536a b c
+--R                          + 
+--R                               2         3  4        2 2       2     3
+--R                            (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                          + 
+--R                                    2 2 2       3 3       3 4
+--R                            - 6a b c d e  + 8a c d e - b c d
+--R                       /
+--R                               3 5        2 2 4         4 3
+--R                          2048a c  - 1024a b c  + 128a b c
+--R           /
+--R                    5     4 2  10     4        3 3    9
+--R                  (a c - a b )e   + (a b c + 3a b )d e
+--R                + 
+--R                       4 2      3 2      2 4  2 8
+--R                  (- 3a c  - 12a b c - 3a b )d e
+--R                + 
+--R                      3   2      2 3       5  3 7
+--R                  (24a b c  + 17a b c + a b )d e
+--R                + 
+--R                        3 3      2 2 2       4   4 6       2   3        3 2  5 5
+--R                  (- 14a c  - 42a b c  - 7a b c)d e  + (42a b c  + 21a b c )d e
+--R                + 
+--R                        2 4        2 3  6 4           4    3 3  7 3
+--R                  (- 14a c  - 28a b c )d e  + (16a b c  - b c )d e
+--R                + 
+--R                         5     2 4  8 2       5 9     6 10
+--R                  (- 3a c  + 3b c )d e  - 3b c d e + c d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                       +--------------------+
+--R                   +-----------+       |   +-----------+
+--R             4+-+3 |          2 4+-+3 4|   |          2
+--R            2\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  3 5        2 2 4         4 3
+--R                          (- 4096a c  + 2048a b c  - 256a b c )
+--R                       *
+--R                          ROOT
+--R                                     4 2     3 2     2 4  8
+--R                                 (- a c  + 2a b c - a b )e
+--R                               + 
+--R                                      3   2     2 3     7
+--R                                 (- 8a b c  + 8a b c)d e
+--R                               + 
+--R                                     3 3      2 2 2  2 6      2   3 3 5
+--R                                 (12a c  - 28a b c )d e  + 48a b c d e
+--R                               + 
+--R                                       2 4       2 3  4 4         4 5 3
+--R                                 (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                               + 
+--R                                      5 6 2    6 8
+--R                                 12a c d e  - c d
+--R                            /
+--R                                         5 9           4 2 8          3 4 7
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         2 6 6
+--R                                 - 65536a b c
+--R                      + 
+--R                           2         3  4        2 2       2     3         2 2 2
+--R                        (3a b c - a b )e  + (- 8a c  + 4a b c)d e  - 6a b c d e
+--R                      + 
+--R                            3 3       3 4
+--R                        8a c d e - b c d
+--R                   /
+--R                           3 5        2 2 4         4 3
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            atan
+--R                                    6 7          5 2 6          4 4 5
+--R                             262144a c  - 327680a b c  + 147456a b c
+--R                           + 
+--R                                     3 6 4        2 8 3
+--R                             - 28672a b c  + 2048a b c
+--R                        *
+--R                            3
+--R                           e
+--R                       + 
+--R                                    5   7          4 3 6         3 5 5
+--R                             393216a b c  - 294912a b c  + 73728a b c
+--R                           + 
+--R                                    2 7 4
+--R                             - 6144a b c
+--R                        *
+--R                              2
+--R                           d e
+--R                       + 
+--R                                      5 8          4 2 7          3 4 6
+--R                             - 786432a c  + 589824a b c  - 147456a b c
+--R                           + 
+--R                                   2 6 5
+--R                             12288a b c
+--R                        *
+--R                            2
+--R                           d e
+--R                       + 
+--R                               4   8         3 3 7         2 5 6          7 5  3
+--R                       (131072a b c  - 98304a b c  + 24576a b c  - 2048a b c )d
+--R                    *
+--R                       ROOT
+--R                                  4 2     3 2     2 4  8
+--R                              (- a c  + 2a b c - a b )e
+--R                            + 
+--R                                   3   2     2 3     7       3 3      2 2 2  2 6
+--R                              (- 8a b c  + 8a b c)d e  + (12a c  - 28a b c )d e
+--R                            + 
+--R                                 2   3 3 5         2 4       2 3  4 4
+--R                              48a b c d e  + (- 38a c  + 2a b c )d e
+--R                            + 
+--R                                      4 5 3        5 6 2    6 8
+--R                              - 8a b c d e  + 12a c d e  - c d
+--R                         /
+--R                                      5 9           4 2 8          3 4 7
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      2 6 6
+--R                              - 65536a b c
+--R                   + 
+--R                          5   3       4 3 2      3 5      2 7  7
+--R                     (128a b c  - 192a b c  + 72a b c - 8a b )e
+--R                   + 
+--R                            5 4        4 2 3       3 4 2      2 6     6
+--R                     (- 384a c  + 1088a b c  - 472a b c  + 56a b c)d e
+--R                   + 
+--R                             4   4        3 3 3       2 5 2  2 5
+--R                     (- 2304a b c  + 1152a b c  - 144a b c )d e
+--R                   + 
+--R                           4 5        3 2 4       2 4 3       6 2  3 4
+--R                     (2432a c  - 1344a b c  + 216a b c  - 8a b c )d e
+--R                   + 
+--R                          3   5       2 3 4        5 3  4 3
+--R                     (640a b c  - 320a b c  + 40a b c )d e
+--R                   + 
+--R                             3 6       2 2 5        4 4  5 2
+--R                     (- 1152a c  + 576a b c  - 72a b c )d e
+--R                   + 
+--R                          2 7        2 6     4 5  7
+--R                     (128a c  - 64a b c  + 8b c )d
+--R                *
+--R                   ROOT
+--R                                    3 5        2 2 4         4 3
+--R                            (- 4096a c  + 2048a b c  - 256a b c )
+--R                         *
+--R                            ROOT
+--R                                       4 2     3 2     2 4  8
+--R                                   (- a c  + 2a b c - a b )e
+--R                                 + 
+--R                                        3   2     2 3     7
+--R                                   (- 8a b c  + 8a b c)d e
+--R                                 + 
+--R                                       3 3      2 2 2  2 6      2   3 3 5
+--R                                   (12a c  - 28a b c )d e  + 48a b c d e
+--R                                 + 
+--R                                         2 4       2 3  4 4         4 5 3
+--R                                   (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                 + 
+--R                                        5 6 2    6 8
+--R                                   12a c d e  - c d
+--R                              /
+--R                                           5 9           4 2 8          3 4 7
+--R                                   4194304a c  - 3145728a b c  + 786432a b c
+--R                                 + 
+--R                                           2 6 6
+--R                                   - 65536a b c
+--R                        + 
+--R                             2         3  4        2 2       2     3
+--R                          (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                        + 
+--R                                  2 2 2       3 3       3 4
+--R                          - 6a b c d e  + 8a c d e - b c d
+--R                     /
+--R                             3 5        2 2 4         4 3
+--R                        2048a c  - 1024a b c  + 128a b c
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         3 5        2 2 4         4 3
+--R                                 (- 4096a c  + 2048a b c  - 256a b c )
+--R                              *
+--R                                 ROOT
+--R                                            4 2     3 2     2 4  8
+--R                                        (- a c  + 2a b c - a b )e
+--R                                      + 
+--R                                             3   2     2 3     7
+--R                                        (- 8a b c  + 8a b c)d e
+--R                                      + 
+--R                                            3 3      2 2 2  2 6      2   3 3 5
+--R                                        (12a c  - 28a b c )d e  + 48a b c d e
+--R                                      + 
+--R                                              2 4       2 3  4 4         4 5 3
+--R                                        (- 38a c  + 2a b c )d e  - 8a b c d e
+--R                                      + 
+--R                                             5 6 2    6 8
+--R                                        12a c d e  - c d
+--R                                   /
+--R                                                5 9           4 2 8
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               3 4 7         2 6 6
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  2         3  4        2 2       2     3
+--R                               (3a b c - a b )e  + (- 8a c  + 4a b c)d e
+--R                             + 
+--R                                       2 2 2       3 3       3 4
+--R                               - 6a b c d e  + 8a c d e - b c d
+--R                          /
+--R                                  3 5        2 2 4         4 3
+--R                             2048a c  - 1024a b c  + 128a b c
+--R              /
+--R                       5     4 2  10     4        3 3    9
+--R                     (a c - a b )e   + (a b c + 3a b )d e
+--R                   + 
+--R                          4 2      3 2      2 4  2 8
+--R                     (- 3a c  - 12a b c - 3a b )d e
+--R                   + 
+--R                         3   2      2 3       5  3 7
+--R                     (24a b c  + 17a b c + a b )d e
+--R                   + 
+--R                           3 3      2 2 2       4   4 6
+--R                     (- 14a c  - 42a b c  - 7a b c)d e
+--R                   + 
+--R                         2   3        3 2  5 5         2 4        2 3  6 4
+--R                     (42a b c  + 21a b c )d e  + (- 14a c  - 28a b c )d e
+--R                   + 
+--R                             4    3 3  7 3          5     2 4  8 2       5 9
+--R                     (16a b c  - b c )d e  + (- 3a c  + 3b c )d e  - 3b c d e
+--R                   + 
+--R                      6 10
+--R                     c d
+--R                *
+--R                   x
+--R     + 
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2               4| |          2
+--R         (e\|- 4a c + b   + b e - 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2               4|   |          2
+--R         (e\|- 4a c + b   - b e + 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                          +------------------+
+--R              +-----------+               | +-----------+
+--R              |          2               4| |          2
+--R         (- e\|- 4a c + b   - b e + 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                          +--------------------+
+--R              +-----------+               |   +-----------+
+--R              |          2               4|   |          2
+--R         (- e\|- 4a c + b   + b e - 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                                +--------------------+ +------------------+
+--R            +-----------+       |   +-----------+      | +-----------+
+--R      4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R     2\|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 649
+t0:=x*(d+e*x^4)/(a+b*x^4+c*x^8)
+--R 
+--R
+--R              5
+--R           e x  + d x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 214
+
+--S 215 of 649
+r0:=1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(e+(2*c*d-b*e)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2                | |          2
+--R         (e\|- 4a c + b   - b e + 2c d)\|\|- 4a c + b   + b
+--R      *
+--R                      2 +-+ +-+
+--R                     x \|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2                |   |          2
+--R         (e\|- 4a c + b   + b e - 2c d)\|- \|- 4a c + b   + b
+--R      *
+--R                     2 +-+ +-+
+--R                    x \|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R                                   +-------------------------+
+--R                                   |   2 4         2 2    2 4
+--R                    2 2        2   |- a e  + 2a c d e  - c d          2
+--R                (64a c  - 16a b c) |-------------------------  + a b e
+--R                                   |        3 3       2 2 2
+--R                                  \|   1024a c  - 256a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                 2 2       2
+--R              32a c  - 8a b c
+--R      *
+--R         log
+--R                          3 2      2 2            2   2        3
+--R                    ((128a c  - 32a b c)e + (- 64a b c  + 16a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |        3 3       2 2 2
+--R                    \|   1024a c  - 256a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                          +-------------------------+
+--R                                          |   2 4         2 2    2 4
+--R                           2 2        2   |- a e  + 2a c d e  - c d          2
+--R                       (64a c  - 16a b c) |-------------------------  + a b e
+--R                                          |        3 3       2 2 2
+--R                                         \|   1024a c  - 256a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                        2 2       2
+--R                     32a c  - 8a b c
+--R            + 
+--R                2 4          3        3     2 4  2
+--R              (a e  - a b d e  + b c d e - c d )x
+--R     + 
+--R       -
+--R            ROOT
+--R                                        +-------------------------+
+--R                                        |   2 4         2 2    2 4
+--R                         2 2        2   |- a e  + 2a c d e  - c d          2
+--R                   (- 64a c  + 16a b c) |-------------------------  + a b e
+--R                                        |        3 3       2 2 2
+--R                                       \|   1024a c  - 256a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                    2 2       2
+--R                 32a c  - 8a b c
+--R         *
+--R            log
+--R                             3 2      2 2            2   2        3
+--R                       ((128a c  - 32a b c)e + (- 64a b c  + 16a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |        3 3       2 2 2
+--R                       \|   1024a c  - 256a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                               +-------------------------+
+--R                                               |   2 4         2 2    2 4
+--R                                2 2        2   |- a e  + 2a c d e  - c d
+--R                          (- 64a c  + 16a b c) |-------------------------
+--R                                               |        3 3       2 2 2
+--R                                              \|   1024a c  - 256a b c
+--R                        + 
+--R                               2                   2
+--R                          a b e  - 4a c d e + b c d
+--R                     /
+--R                           2 2       2
+--R                        32a c  - 8a b c
+--R               + 
+--R                   2 4          3        3     2 4  2
+--R                 (a e  - a b d e  + b c d e - c d )x
+--R     + 
+--R         ROOT
+--R                                     +-------------------------+
+--R                                     |   2 4         2 2    2 4
+--R                      2 2        2   |- a e  + 2a c d e  - c d          2
+--R                (- 64a c  + 16a b c) |-------------------------  + a b e
+--R                                     |        3 3       2 2 2
+--R                                    \|   1024a c  - 256a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                 2 2       2
+--R              32a c  - 8a b c
+--R      *
+--R         log
+--R                            3 2      2 2          2   2        3
+--R                    ((- 128a c  + 32a b c)e + (64a b c  - 16a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |        3 3       2 2 2
+--R                    \|   1024a c  - 256a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                            +-------------------------+
+--R                                            |   2 4         2 2    2 4
+--R                             2 2        2   |- a e  + 2a c d e  - c d          2
+--R                       (- 64a c  + 16a b c) |-------------------------  + a b e
+--R                                            |        3 3       2 2 2
+--R                                           \|   1024a c  - 256a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                        2 2       2
+--R                     32a c  - 8a b c
+--R            + 
+--R                2 4          3        3     2 4  2
+--R              (a e  - a b d e  + b c d e - c d )x
+--R     + 
+--R       -
+--R            ROOT
+--R                                      +-------------------------+
+--R                                      |   2 4         2 2    2 4
+--R                       2 2        2   |- a e  + 2a c d e  - c d          2
+--R                   (64a c  - 16a b c) |-------------------------  + a b e
+--R                                      |        3 3       2 2 2
+--R                                     \|   1024a c  - 256a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                    2 2       2
+--R                 32a c  - 8a b c
+--R         *
+--R            log
+--R                               3 2      2 2          2   2        3
+--R                       ((- 128a c  + 32a b c)e + (64a b c  - 16a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |        3 3       2 2 2
+--R                       \|   1024a c  - 256a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                             +-------------------------+
+--R                                             |   2 4         2 2    2 4
+--R                              2 2        2   |- a e  + 2a c d e  - c d
+--R                          (64a c  - 16a b c) |-------------------------
+--R                                             |        3 3       2 2 2
+--R                                            \|   1024a c  - 256a b c
+--R                        + 
+--R                               2                   2
+--R                          a b e  - 4a c d e + b c d
+--R                     /
+--R                           2 2       2
+--R                        32a c  - 8a b c
+--R               + 
+--R                   2 4          3        3     2 4  2
+--R                 (a e  - a b d e  + b c d e - c d )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 216
+
+--S 217 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +--------------------+
+--R              +-----------+     |   +-----------+
+--R          +-+ |          2  +-+ |   |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                   +-------------------------+
+--R                                   |   2 4         2 2    2 4
+--R                    2 2        2   |- a e  + 2a c d e  - c d          2
+--R                (64a c  - 16a b c) |-------------------------  + a b e
+--R                                   |        3 3       2 2 2
+--R                                  \|   1024a c  - 256a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                 2 2       2
+--R              32a c  - 8a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          3 2      2 2            2   2        3
+--R                    ((128a c  - 32a b c)e + (- 64a b c  + 16a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |        3 3       2 2 2
+--R                    \|   1024a c  - 256a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                          +-------------------------+
+--R                                          |   2 4         2 2    2 4
+--R                           2 2        2   |- a e  + 2a c d e  - c d          2
+--R                       (64a c  - 16a b c) |-------------------------  + a b e
+--R                                          |        3 3       2 2 2
+--R                                         \|   1024a c  - 256a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                        2 2       2
+--R                     32a c  - 8a b c
+--R            + 
+--R                2 4          3        3     2 4  2
+--R              (a e  - a b d e  + b c d e - c d )x
+--R     + 
+--R       -
+--R                                   +--------------------+
+--R                 +-----------+     |   +-----------+
+--R             +-+ |          2  +-+ |   |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                        +-------------------------+
+--R                                        |   2 4         2 2    2 4
+--R                         2 2        2   |- a e  + 2a c d e  - c d          2
+--R                   (- 64a c  + 16a b c) |-------------------------  + a b e
+--R                                        |        3 3       2 2 2
+--R                                       \|   1024a c  - 256a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                    2 2       2
+--R                 32a c  - 8a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                             3 2      2 2            2   2        3
+--R                       ((128a c  - 32a b c)e + (- 64a b c  + 16a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |        3 3       2 2 2
+--R                       \|   1024a c  - 256a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                               +-------------------------+
+--R                                               |   2 4         2 2    2 4
+--R                                2 2        2   |- a e  + 2a c d e  - c d
+--R                          (- 64a c  + 16a b c) |-------------------------
+--R                                               |        3 3       2 2 2
+--R                                              \|   1024a c  - 256a b c
+--R                        + 
+--R                               2                   2
+--R                          a b e  - 4a c d e + b c d
+--R                     /
+--R                           2 2       2
+--R                        32a c  - 8a b c
+--R               + 
+--R                   2 4          3        3     2 4  2
+--R                 (a e  - a b d e  + b c d e - c d )x
+--R     + 
+--R                                +--------------------+
+--R              +-----------+     |   +-----------+
+--R          +-+ |          2  +-+ |   |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                     +-------------------------+
+--R                                     |   2 4         2 2    2 4
+--R                      2 2        2   |- a e  + 2a c d e  - c d          2
+--R                (- 64a c  + 16a b c) |-------------------------  + a b e
+--R                                     |        3 3       2 2 2
+--R                                    \|   1024a c  - 256a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                 2 2       2
+--R              32a c  - 8a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            3 2      2 2          2   2        3
+--R                    ((- 128a c  + 32a b c)e + (64a b c  - 16a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |        3 3       2 2 2
+--R                    \|   1024a c  - 256a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                            +-------------------------+
+--R                                            |   2 4         2 2    2 4
+--R                             2 2        2   |- a e  + 2a c d e  - c d          2
+--R                       (- 64a c  + 16a b c) |-------------------------  + a b e
+--R                                            |        3 3       2 2 2
+--R                                           \|   1024a c  - 256a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                        2 2       2
+--R                     32a c  - 8a b c
+--R            + 
+--R                2 4          3        3     2 4  2
+--R              (a e  - a b d e  + b c d e - c d )x
+--R     + 
+--R       -
+--R                                   +--------------------+
+--R                 +-----------+     |   +-----------+
+--R             +-+ |          2  +-+ |   |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                      +-------------------------+
+--R                                      |   2 4         2 2    2 4
+--R                       2 2        2   |- a e  + 2a c d e  - c d          2
+--R                   (64a c  - 16a b c) |-------------------------  + a b e
+--R                                      |        3 3       2 2 2
+--R                                     \|   1024a c  - 256a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                    2 2       2
+--R                 32a c  - 8a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                               3 2      2 2          2   2        3
+--R                       ((- 128a c  + 32a b c)e + (64a b c  - 16a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |        3 3       2 2 2
+--R                       \|   1024a c  - 256a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                             +-------------------------+
+--R                                             |   2 4         2 2    2 4
+--R                              2 2        2   |- a e  + 2a c d e  - c d
+--R                          (64a c  - 16a b c) |-------------------------
+--R                                             |        3 3       2 2 2
+--R                                            \|   1024a c  - 256a b c
+--R                        + 
+--R                               2                   2
+--R                          a b e  - 4a c d e + b c d
+--R                     /
+--R                           2 2       2
+--R                        32a c  - 8a b c
+--R               + 
+--R                   2 4          3        3     2 4  2
+--R                 (a e  - a b d e  + b c d e - c d )x
+--R     + 
+--R                                          +------------------+
+--R              +-----------+               | +-----------+
+--R              |          2                | |          2
+--R         (- e\|- 4a c + b   + b e - 2c d)\|\|- 4a c + b   + b
+--R      *
+--R                      2 +-+ +-+
+--R                     x \|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                          +--------------------+
+--R              +-----------+               |   +-----------+
+--R              |          2                |   |          2
+--R         (- e\|- 4a c + b   - b e + 2c d)\|- \|- 4a c + b   + b
+--R      *
+--R                     2 +-+ +-+
+--R                    x \|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 218
+
+)clear all
+
+--S 219 of 649
+t0:=(d+e*x^4)/(a+b*x^4+c*x^8)
+--R 
+--R
+--R               4
+--R            e x  + d
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 219
+
+--S 220 of 649
+r0:=-1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(1/4)*(-b-sqrt(b^2-4*a*c))^(3/4))-1/2*atan(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(1/4)*(-b+sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-_
+   4*a*c))/(2^(1/4)*c^(1/4)*(-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                          +------------------+3
+--R              +-----------+               | +-----------+
+--R              |          2               4| |          2
+--R         (- e\|- 4a c + b   - b e + 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                          +--------------------+3
+--R              +-----------+               |   +-----------+
+--R              |          2               4|   |          2
+--R         (- e\|- 4a c + b   + b e - 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                          +------------------+3
+--R              +-----------+               | +-----------+
+--R              |          2               4| |          2
+--R         (- e\|- 4a c + b   - b e + 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                          +--------------------+3
+--R              +-----------+               |   +-----------+
+--R              |          2               4|   |          2
+--R         (- e\|- 4a c + b   + b e - 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                             +--------------------+3  +------------------+3
+--R           +-----------+     |   +-----------+        | +-----------+
+--R      4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                5 3        4 2 2       3 4
+--R                          (4096a c  - 2048a b c  + 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                               6 3        5 2 2       4 4
+--R                         (8192a c  - 4096a b c  + 512a b c)e
+--R                       + 
+--R                                 5   3        4 3 2       3 5
+--R                         (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                          4     3 2    4       3 2     2 2   3 2
+--R                     (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                   + 
+--R                           2   2       3   4         2 3       2 2    4   5
+--R                     (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       5 3        4 2 2       3 4
+--R                                 (4096a c  - 2048a b c  + 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               5 3        4 2 2       3 4
+--R                       (- 4096a c  + 2048a b c  - 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                            6 3        5 2 2       4 4
+--R                      (8192a c  - 4096a b c  + 512a b c)e
+--R                    + 
+--R                              5   3        4 3 2       3 5
+--R                      (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                     4     3 2    4         3 2     2 2   3 2
+--R                  (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                + 
+--R                      2   2       3   4       2 3       2 2    4   5
+--R                  (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      5 3        4 2 2       3 4
+--R                              (- 4096a c  + 2048a b c  - 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 3        4 2 2       3 4
+--R                          (- 4096a c  + 2048a b c  - 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                                 6 3        5 2 2       4 4
+--R                         (- 8192a c  + 4096a b c  - 512a b c)e
+--R                       + 
+--R                               5   3        4 3 2       3 5
+--R                         (4096a b c  - 2048a b c  + 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                          4     3 2    4       3 2     2 2   3 2
+--R                     (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                   + 
+--R                           2   2       3   4         2 3       2 2    4   5
+--R                     (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 3        4 2 2       3 4
+--R                                 (- 4096a c  + 2048a b c  - 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 3        4 2 2       3 4
+--R                       (4096a c  - 2048a b c  + 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                              6 3        5 2 2       4 4
+--R                      (- 8192a c  + 4096a b c  - 512a b c)e
+--R                    + 
+--R                            5   3        4 3 2       3 5
+--R                      (4096a b c  - 2048a b c  + 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                     4     3 2    4         3 2     2 2   3 2
+--R                  (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                + 
+--R                      2   2       3   4       2 3       2 2    4   5
+--R                  (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 3        4 2 2       3 4
+--R                              (4096a c  - 2048a b c  + 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 3        4 2 2       3 4
+--R                       (4096a c  - 2048a b c  + 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         atan
+--R                            6 3        5 2 2       4 4
+--R                      (8192a c  - 4096a b c  + 512a b c)e
+--R                    + 
+--R                              5   3        4 3 2       3 5
+--R                      (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                       4     3 2    4       3 2     2 2   3 2
+--R                  (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                + 
+--R                        2   2       3   4         2 3       2 2    4   5
+--R                  (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 3        4 2 2       3 4
+--R                              (4096a c  - 2048a b c  + 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R           /
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 3        4 2 2       3 4
+--R                          (- 4096a c  + 2048a b c  - 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            atan
+--R                               6 3        5 2 2       4 4
+--R                         (8192a c  - 4096a b c  + 512a b c)e
+--R                       + 
+--R                                 5   3        4 3 2       3 5
+--R                         (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        4     3 2    4         3 2     2 2   3 2
+--R                     (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                   + 
+--R                         2   2       3   4       2 3       2 2    4   5
+--R                     (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 3        4 2 2       3 4
+--R                                 (- 4096a c  + 2048a b c  - 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R              /
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 221
+
+--S 222 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                   +--------------------+3  +------------------+3
+--R                 +-----------+     |   +-----------+        | +-----------+
+--R            4+-+ |          2 4+-+4|   |          2        4| |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                5 3        4 2 2       3 4
+--R                          (4096a c  - 2048a b c  + 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                               6 3        5 2 2       4 4
+--R                         (8192a c  - 4096a b c  + 512a b c)e
+--R                       + 
+--R                                 5   3        4 3 2       3 5
+--R                         (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                          4     3 2    4       3 2     2 2   3 2
+--R                     (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                   + 
+--R                           2   2       3   4         2 3       2 2    4   5
+--R                     (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       5 3        4 2 2       3 4
+--R                                 (4096a c  - 2048a b c  + 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               5 3        4 2 2       3 4
+--R                       (- 4096a c  + 2048a b c  - 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                            6 3        5 2 2       4 4
+--R                      (8192a c  - 4096a b c  + 512a b c)e
+--R                    + 
+--R                              5   3        4 3 2       3 5
+--R                      (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                     4     3 2    4         3 2     2 2   3 2
+--R                  (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                + 
+--R                      2   2       3   4       2 3       2 2    4   5
+--R                  (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      5 3        4 2 2       3 4
+--R                              (- 4096a c  + 2048a b c  - 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                   +--------------------+3  +------------------+3
+--R                 +-----------+     |   +-----------+        | +-----------+
+--R            4+-+ |          2 4+-+4|   |          2        4| |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 3        4 2 2       3 4
+--R                          (- 4096a c  + 2048a b c  - 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                                 6 3        5 2 2       4 4
+--R                         (- 8192a c  + 4096a b c  - 512a b c)e
+--R                       + 
+--R                               5   3        4 3 2       3 5
+--R                         (4096a b c  - 2048a b c  + 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                          4     3 2    4       3 2     2 2   3 2
+--R                     (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                   + 
+--R                           2   2       3   4         2 3       2 2    4   5
+--R                     (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 3        4 2 2       3 4
+--R                                 (- 4096a c  + 2048a b c  - 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 3        4 2 2       3 4
+--R                       (4096a c  - 2048a b c  + 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                              6 3        5 2 2       4 4
+--R                      (- 8192a c  + 4096a b c  - 512a b c)e
+--R                    + 
+--R                            5   3        4 3 2       3 5
+--R                      (4096a b c  - 2048a b c  + 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                     4     3 2    4         3 2     2 2   3 2
+--R                  (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                + 
+--R                      2   2       3   4       2 3       2 2    4   5
+--R                  (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 3        4 2 2       3 4
+--R                              (4096a c  - 2048a b c  + 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R                                 +--------------------+3  +------------------+3
+--R               +-----------+     |   +-----------+        | +-----------+
+--R          4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 3        4 2 2       3 4
+--R                       (4096a c  - 2048a b c  + 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         atan
+--R                            6 3        5 2 2       4 4
+--R                      (8192a c  - 4096a b c  + 512a b c)e
+--R                    + 
+--R                              5   3        4 3 2       3 5
+--R                      (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                       4     3 2    4       3 2     2 2   3 2
+--R                  (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                + 
+--R                        2   2       3   4         2 3       2 2    4   5
+--R                  (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 3        4 2 2       3 4
+--R                              (4096a c  - 2048a b c  + 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R           /
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                    +--------------------+3
+--R                  +-----------+     |   +-----------+
+--R             4+-+ |          2 4+-+4|   |          2
+--R            2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 3        4 2 2       3 4
+--R                          (- 4096a c  + 2048a b c  - 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            atan
+--R                               6 3        5 2 2       4 4
+--R                         (8192a c  - 4096a b c  + 512a b c)e
+--R                       + 
+--R                                 5   3        4 3 2       3 5
+--R                         (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        4     3 2    4         3 2     2 2   3 2
+--R                     (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                   + 
+--R                         2   2       3   4       2 3       2 2    4   5
+--R                     (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 3        4 2 2       3 4
+--R                                 (- 4096a c  + 2048a b c  - 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R              /
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R                                        +------------------+3
+--R            +-----------+               | +-----------+
+--R            |          2               4| |          2
+--R         (e\|- 4a c + b   + b e - 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+3
+--R            +-----------+               |   +-----------+
+--R            |          2               4|   |          2
+--R         (e\|- 4a c + b   - b e + 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                        +------------------+3
+--R            +-----------+               | +-----------+
+--R            |          2               4| |          2
+--R         (e\|- 4a c + b   + b e - 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+3
+--R            +-----------+               |   +-----------+
+--R            |          2               4|   |          2
+--R         (e\|- 4a c + b   - b e + 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                             +--------------------+3  +------------------+3
+--R           +-----------+     |   +-----------+        | +-----------+
+--R      4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 223
+
+)clear all
+
+--S 224 of 649
+t0:=(d+e*x^4)/(x*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                4
+--R             e x  + d
+--R   (1)  -----------------
+--R           9      5
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 224
+
+--S 225 of 649
+r0:=d*log(x)/a-1/8*d*log(a+b*x^4+c*x^8)/a+1/4*(b*d-2*a*e)*_
+   atanh((b+2*c*x^4)/sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                   4
+--R                               2c x  + b
+--R       (- 4a e + 2b d)atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                              +-----------+
+--R                   8      4                   |          2
+--R       (- d log(c x  + b x  + a) + 8d log(x))\|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     8a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 225
+
+--S 226 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           (2a e - b d)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 8         4           2  |          2         2     2   4
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   8      4
+--R                c x  + b x  + a
+--R       + 
+--R                                                +-----------+
+--R                     8      4                   |          2
+--R         (- d log(c x  + b x  + a) + 8d log(x))\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       8a\|- 4a c + b
+--R     ,
+--R
+--R                                       +---------+
+--R                                4      |        2
+--R                           (2c x  + b)\|4a c - b
+--R         (4a e - 2b d)atan(-----------------------)
+--R                                          2
+--R                                  4a c - b
+--R       + 
+--R                                                +---------+
+--R                     8      4                   |        2
+--R         (- d log(c x  + b x  + a) + 8d log(x))\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       8a\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 226
+
+--S 227 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (2a e - b d)
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 8         4           2  |          2         2     2   4
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 8      4
+--R              c x  + b x  + a
+--R     + 
+--R                                 4
+--R                             2c x  + b
+--R       (4a e - 2b d)atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     8a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+--S 229 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    +---------+             4
+--R                    |        2          2c x  + b
+--R       (2a e - b d)\|4a c - b  atanh(--------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                    +-----------+          4      |        2
+--R                    |          2      (2c x  + b)\|4a c - b
+--R       (2a e - b d)\|- 4a c + b  atan(-----------------------)
+--R                                                     2
+--R                                             4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     4a\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 230
+
+)clear all
+
+--S 231 of 649
+t0:=(d+e*x^4)/(x^2*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 4
+--R              e x  + d
+--R   (1)  -------------------
+--R           10      6      2
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 231
+
+--S 232 of 649
+r0:=-d/(a*x)-1/2*c^(1/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+1/2*c^(1/4)*atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(3/4)*a*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-1/2*c^(1/4)*atan(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*a*(-b+sqrt(b^2-4*a*c))^(1/4))+1/2*c^(1/4)*atanh(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(d+(b*d-2*a*e)/_
+   sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                                 +------------------+
+--R              +-----------+                      | +-----------+
+--R              |          2                  4+-+4| |          2
+--R         (d x\|- 4a c + b   + (2a e - b d)x)\|c \|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                   +--------------------+
+--R              +-----------+                        |   +-----------+
+--R              |          2                    4+-+4|   |          2
+--R         (d x\|- 4a c + b   + (- 2a e + b d)x)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                                     +------------------+
+--R                +-----------+                        | +-----------+
+--R                |          2                    4+-+4| |          2
+--R         (- d x\|- 4a c + b   + (- 2a e + b d)x)\|c \|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                                   +--------------------+
+--R                +-----------+                      |   +-----------+
+--R                |          2                  4+-+4|   |          2
+--R         (- d x\|- 4a c + b   + (2a e - b d)x)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R            4+-+3 |          2 4|   |          2      4| |          2
+--R       - 2d \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R     2a x \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2        6 2        5 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                        4   4        4      3 2    3       3        2 3  2 2
+--R                     - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                   + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                              11   3         10 3 2         9 5         8 7  3
+--R                      (131072a  b c  - 98304a  b c  + 24576a b c - 2048a b )e
+--R                    + 
+--R                                 11 4          10 2 3          9 4 2
+--R                          786432a  c  - 983040a  b c  + 442368a b c
+--R                        + 
+--R                                  8 6         7 8
+--R                          - 86016a b c + 6144a b
+--R                     *
+--R                           2
+--R                        d e
+--R                    + 
+--R                                    10   4           9 3 3          8 5 2
+--R                          - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                        + 
+--R                                7 7         6 9
+--R                          92160a b c - 6144a b
+--R                     *
+--R                         2
+--R                        d e
+--R                    + 
+--R                                   10 5          9 2 4          8 4 3
+--R                          - 262144a  c  + 720896a b c  - 573440a b c
+--R                        + 
+--R                                 7 6 2         6 8         5 10
+--R                          200704a b c  - 32768a b c + 2048a b
+--R                     *
+--R                         3
+--R                        d
+--R                 *
+--R                    ROOT
+--R                              8 8     7     7       7       6 2  2 6
+--R                           - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                         + 
+--R                                 6         5 3  3 5
+--R                           (- 64a b c + 56a b )d e
+--R                         + 
+--R                                 6 2       5 2       4 4  4 4
+--R                           (- 38a c  + 142a b c - 70a b )d e
+--R                         + 
+--R                                5   2       4 3       3 5  5 3
+--R                           (104a b c  - 168a b c + 56a b )d e
+--R                         + 
+--R                               5 3       4 2 2       3 4       2 6  6 2
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  7
+--R                           (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                         + 
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                      /
+--R                                   13 3           12 2 2          11 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   10 6
+--R                           - 65536a  b
+--R                + 
+--R                         9 2      8 2      7 4  7
+--R                  (- 128a c  + 64a b c - 8a b )e
+--R                + 
+--R                       8   2       7 3       6 5    6
+--R                  (896a b c  - 448a b c + 56a b )d e
+--R                + 
+--R                        8 3        7 2 2        6 4        5 6  2 5
+--R                  (1152a c  - 3264a b c  + 1416a b c - 168a b )d e
+--R                + 
+--R                          7   3        6 3 2        5 5        4 7  3 4
+--R                  (- 5120a b c  + 7040a b c  - 2560a b c + 280a b )d e
+--R                + 
+--R                               7 4         6 2 3        5 4 2        4 6
+--R                        - 2432a c  + 10304a b c  - 9176a b c  + 2808a b c
+--R                      + 
+--R                              3 8
+--R                        - 280a b
+--R                 *
+--R                     4 3
+--R                    d e
+--R                + 
+--R                             6   4         5 3 3        4 5 2        3 7
+--R                        4992a b c  - 10560a b c  + 7032a b c  - 1848a b c
+--R                      + 
+--R                            2 9
+--R                        168a b
+--R                 *
+--R                     5 2
+--R                    d e
+--R                + 
+--R                          6 5        5 2 4        4 4 3        3 6 2       2 8
+--R                      384a c  - 3776a b c  + 5400a b c  - 2912a b c  + 672a b c
+--R                    + 
+--R                             10
+--R                      - 56a b
+--R                 *
+--R                     6
+--R                    d e
+--R                + 
+--R                            5   5        4 3 4        3 5 3       2 7 2
+--R                      - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                    + 
+--R                              9      11
+--R                      - 104a b c + 8b
+--R                 *
+--R                     7
+--R                    d
+--R             *
+--R                ROOT
+--R                               7 2        6 2        5 4
+--R                         (4096a c  - 2048a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                          4   4        4      3 2    3       3        2 3  2 2
+--R                       - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                     + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                   7   10     6       9        6 2      5 2   2 8
+--R                  a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                + 
+--R                     5   2      4 3   3 7         5 3      3 4   4 6
+--R                  (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                + 
+--R                      4   3      3 3 2      2 5   5 5
+--R                  (42a b c  - 21a b c  - 21a b c)d e
+--R                + 
+--R                        4 4      3 2 3      2 4 2       6   6 4
+--R                  (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                + 
+--R                      3   4      2 3 3        5 2    7   7 3
+--R                  (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                + 
+--R                       3 5      2 2 4       4 3     6 2  8 2
+--R                  (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                + 
+--R                     2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                  (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  7 2        6 2        5 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8     7     7       7       6 2  2 6
+--R                                 - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                               + 
+--R                                       6         5 3  3 5
+--R                                 (- 64a b c + 56a b )d e
+--R                               + 
+--R                                       6 2       5 2       4 4  4 4
+--R                                 (- 38a c  + 142a b c - 70a b )d e
+--R                               + 
+--R                                      5   2       4 3       3 5  5 3
+--R                                 (104a b c  - 168a b c + 56a b )d e
+--R                               + 
+--R                                     5 3       4 2 2       3 4       2 6  6 2
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  7
+--R                                 (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           4   4        4      3 2    3       3        2 3  2 2
+--R                        - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                      + 
+--R                         3 2      2 2        4  3         2   2       3     5  4
+--R                      (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                                      11   3         10 3 2         9 5
+--R                               131072a  b c  - 98304a  b c  + 24576a b c
+--R                             + 
+--R                                      8 7
+--R                               - 2048a b
+--R                        *
+--R                            3
+--R                           e
+--R                       + 
+--R                                    11 4          10 2 3          9 4 2
+--R                             786432a  c  - 983040a  b c  + 442368a b c
+--R                           + 
+--R                                     8 6         7 8
+--R                             - 86016a b c + 6144a b
+--R                        *
+--R                              2
+--R                           d e
+--R                       + 
+--R                                       10   4           9 3 3          8 5 2
+--R                             - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                           + 
+--R                                   7 7         6 9
+--R                             92160a b c - 6144a b
+--R                        *
+--R                            2
+--R                           d e
+--R                       + 
+--R                                      10 5          9 2 4          8 4 3
+--R                             - 262144a  c  + 720896a b c  - 573440a b c
+--R                           + 
+--R                                    7 6 2         6 8         5 10
+--R                             200704a b c  - 32768a b c + 2048a b
+--R                        *
+--R                            3
+--R                           d
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                          9 2      8 2      7 4  7
+--R                     (128a c  - 64a b c + 8a b )e
+--R                   + 
+--R                            8   2       7 3       6 5    6
+--R                     (- 896a b c  + 448a b c - 56a b )d e
+--R                   + 
+--R                             8 3        7 2 2        6 4        5 6  2 5
+--R                     (- 1152a c  + 3264a b c  - 1416a b c + 168a b )d e
+--R                   + 
+--R                           7   3        6 3 2        5 5        4 7  3 4
+--R                     (5120a b c  - 7040a b c  + 2560a b c - 280a b )d e
+--R                   + 
+--R                                7 4         6 2 3        5 4 2        4 6
+--R                           2432a c  - 10304a b c  + 9176a b c  - 2808a b c
+--R                         + 
+--R                               3 8
+--R                           280a b
+--R                    *
+--R                        4 3
+--R                       d e
+--R                   + 
+--R                                6   4         5 3 3        4 5 2        3 7
+--R                         - 4992a b c  + 10560a b c  - 7032a b c  + 1848a b c
+--R                       + 
+--R                               2 9
+--R                         - 168a b
+--R                    *
+--R                        5 2
+--R                       d e
+--R                   + 
+--R                               6 5        5 2 4        4 4 3        3 6 2
+--R                         - 384a c  + 3776a b c  - 5400a b c  + 2912a b c
+--R                       + 
+--R                               2 8         10
+--R                         - 672a b c + 56a b
+--R                    *
+--R                        6
+--R                       d e
+--R                   + 
+--R                             5   5        4 3 4        3 5 3       2 7 2
+--R                         256a b c  - 1024a b c  + 1104a b c  - 504a b c
+--R                       + 
+--R                               9      11
+--R                         104a b c - 8b
+--R                    *
+--R                        7
+--R                       d
+--R                *
+--R                   ROOT
+--R                                    7 2        6 2        5 4
+--R                            (- 4096a c  + 2048a b c - 256a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8     7     7       7       6 2  2 6
+--R                                   - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                 + 
+--R                                         6         5 3  3 5
+--R                                   (- 64a b c + 56a b )d e
+--R                                 + 
+--R                                         6 2       5 2       4 4  4 4
+--R                                   (- 38a c  + 142a b c - 70a b )d e
+--R                                 + 
+--R                                        5   2       4 3       3 5  5 3
+--R                                   (104a b c  - 168a b c + 56a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2       3 4       2 6  6 2
+--R                                   (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  7
+--R                                   (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                 + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                             4   4        4      3 2    3
+--R                          - a b e  + (- 8a c + 4a b )d e
+--R                        + 
+--R                              3        2 3  2 2      3 2      2 2        4  3
+--R                          (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                        + 
+--R                               2   2       3     5  4
+--R                          (- 5a b c  + 5a b c - b )d
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         7 2        6 2        5 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8     7     7
+--R                                        - a e  + 8a b d e
+--R                                      + 
+--R                                            7       6 2  2 6
+--R                                        (12a c - 28a b )d e
+--R                                      + 
+--R                                              6         5 3  3 5
+--R                                        (- 64a b c + 56a b )d e
+--R                                      + 
+--R                                              6 2       5 2       4 4  4 4
+--R                                        (- 38a c  + 142a b c - 70a b )d e
+--R                                      + 
+--R                                             5   2       4 3       3 5  5 3
+--R                                        (104a b c  - 168a b c + 56a b )d e
+--R                                      + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 4   3      3 3 2      2 5
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                                7
+--R                                            8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  4   4        4      3 2    3
+--R                               - a b e  + (- 8a c + 4a b )d e
+--R                             + 
+--R                                   3        2 3  2 2
+--R                               (18a b c - 6a b )d e
+--R                             + 
+--R                                  3 2      2 2        4  3
+--R                               (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )d
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                      7   10     6       9        6 2      5 2   2 8
+--R                     a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                   + 
+--R                        5   2      4 3   3 7         5 3      3 4   4 6
+--R                     (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                   + 
+--R                         4   3      3 3 2      2 5   5 5
+--R                     (42a b c  - 21a b c  - 21a b c)d e
+--R                   + 
+--R                           4 4      3 2 3      2 4 2       6   6 4
+--R                     (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                   + 
+--R                         3   4      2 3 3        5 2    7   7 3
+--R                     (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                   + 
+--R                          3 5      2 2 4       4 3     6 2  8 2
+--R                     (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                   + 
+--R                      2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                   (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R                *
+--R                   x
+--R     + 
+--R         a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               7 2        6 2        5 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                        4   4        4      3 2    3       3        2 3  2 2
+--R                     - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                   + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                                11   3         10 3 2         9 5         8 7  3
+--R                      (- 131072a  b c  + 98304a  b c  - 24576a b c + 2048a b )e
+--R                    + 
+--R                                   11 4          10 2 3          9 4 2
+--R                          - 786432a  c  + 983040a  b c  - 442368a b c
+--R                        + 
+--R                                8 6         7 8
+--R                          86016a b c - 6144a b
+--R                     *
+--R                           2
+--R                        d e
+--R                    + 
+--R                                  10   4           9 3 3          8 5 2
+--R                          1179648a  b c  - 1277952a b c  + 516096a b c
+--R                        + 
+--R                                  7 7         6 9
+--R                          - 92160a b c + 6144a b
+--R                     *
+--R                         2
+--R                        d e
+--R                    + 
+--R                                 10 5          9 2 4          8 4 3
+--R                          262144a  c  - 720896a b c  + 573440a b c
+--R                        + 
+--R                                   7 6 2         6 8         5 10
+--R                          - 200704a b c  + 32768a b c - 2048a b
+--R                     *
+--R                         3
+--R                        d
+--R                 *
+--R                    ROOT
+--R                              8 8     7     7       7       6 2  2 6
+--R                           - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                         + 
+--R                                 6         5 3  3 5
+--R                           (- 64a b c + 56a b )d e
+--R                         + 
+--R                                 6 2       5 2       4 4  4 4
+--R                           (- 38a c  + 142a b c - 70a b )d e
+--R                         + 
+--R                                5   2       4 3       3 5  5 3
+--R                           (104a b c  - 168a b c + 56a b )d e
+--R                         + 
+--R                               5 3       4 2 2       3 4       2 6  6 2
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  7
+--R                           (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                         + 
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                      /
+--R                                   13 3           12 2 2          11 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   10 6
+--R                           - 65536a  b
+--R                + 
+--R                         9 2      8 2      7 4  7
+--R                  (- 128a c  + 64a b c - 8a b )e
+--R                + 
+--R                       8   2       7 3       6 5    6
+--R                  (896a b c  - 448a b c + 56a b )d e
+--R                + 
+--R                        8 3        7 2 2        6 4        5 6  2 5
+--R                  (1152a c  - 3264a b c  + 1416a b c - 168a b )d e
+--R                + 
+--R                          7   3        6 3 2        5 5        4 7  3 4
+--R                  (- 5120a b c  + 7040a b c  - 2560a b c + 280a b )d e
+--R                + 
+--R                               7 4         6 2 3        5 4 2        4 6
+--R                        - 2432a c  + 10304a b c  - 9176a b c  + 2808a b c
+--R                      + 
+--R                              3 8
+--R                        - 280a b
+--R                 *
+--R                     4 3
+--R                    d e
+--R                + 
+--R                             6   4         5 3 3        4 5 2        3 7
+--R                        4992a b c  - 10560a b c  + 7032a b c  - 1848a b c
+--R                      + 
+--R                            2 9
+--R                        168a b
+--R                 *
+--R                     5 2
+--R                    d e
+--R                + 
+--R                          6 5        5 2 4        4 4 3        3 6 2       2 8
+--R                      384a c  - 3776a b c  + 5400a b c  - 2912a b c  + 672a b c
+--R                    + 
+--R                             10
+--R                      - 56a b
+--R                 *
+--R                     6
+--R                    d e
+--R                + 
+--R                            5   5        4 3 4        3 5 3       2 7 2
+--R                      - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                    + 
+--R                              9      11
+--R                      - 104a b c + 8b
+--R                 *
+--R                     7
+--R                    d
+--R             *
+--R                ROOT
+--R                                 7 2        6 2        5 4
+--R                         (- 4096a c  + 2048a b c - 256a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                          4   4        4      3 2    3       3        2 3  2 2
+--R                       - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                     + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                   7   10     6       9        6 2      5 2   2 8
+--R                  a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                + 
+--R                     5   2      4 3   3 7         5 3      3 4   4 6
+--R                  (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                + 
+--R                      4   3      3 3 2      2 5   5 5
+--R                  (42a b c  - 21a b c  - 21a b c)d e
+--R                + 
+--R                        4 4      3 2 3      2 4 2       6   6 4
+--R                  (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                + 
+--R                      3   4      2 3 3        5 2    7   7 3
+--R                  (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                + 
+--R                       3 5      2 2 4       4 3     6 2  8 2
+--R                  (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                + 
+--R                     2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                  (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                7 2        6 2        5 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8     7     7       7       6 2  2 6
+--R                                 - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                               + 
+--R                                       6         5 3  3 5
+--R                                 (- 64a b c + 56a b )d e
+--R                               + 
+--R                                       6 2       5 2       4 4  4 4
+--R                                 (- 38a c  + 142a b c - 70a b )d e
+--R                               + 
+--R                                      5   2       4 3       3 5  5 3
+--R                                 (104a b c  - 168a b c + 56a b )d e
+--R                               + 
+--R                                     5 3       4 2 2       3 4       2 6  6 2
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  7
+--R                                 (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           4   4        4      3 2    3       3        2 3  2 2
+--R                        - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                      + 
+--R                         3 2      2 2        4  3         2   2       3     5  4
+--R                      (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                                      11   3         10 3 2         9 5
+--R                             - 131072a  b c  + 98304a  b c  - 24576a b c
+--R                           + 
+--R                                  8 7
+--R                             2048a b
+--R                        *
+--R                            3
+--R                           e
+--R                       + 
+--R                                      11 4          10 2 3          9 4 2
+--R                             - 786432a  c  + 983040a  b c  - 442368a b c
+--R                           + 
+--R                                   8 6         7 8
+--R                             86016a b c - 6144a b
+--R                        *
+--R                              2
+--R                           d e
+--R                       + 
+--R                                     10   4           9 3 3          8 5 2
+--R                             1179648a  b c  - 1277952a b c  + 516096a b c
+--R                           + 
+--R                                     7 7         6 9
+--R                             - 92160a b c + 6144a b
+--R                        *
+--R                            2
+--R                           d e
+--R                       + 
+--R                                    10 5          9 2 4          8 4 3
+--R                             262144a  c  - 720896a b c  + 573440a b c
+--R                           + 
+--R                                      7 6 2         6 8         5 10
+--R                             - 200704a b c  + 32768a b c - 2048a b
+--R                        *
+--R                            3
+--R                           d
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                          9 2      8 2      7 4  7
+--R                     (128a c  - 64a b c + 8a b )e
+--R                   + 
+--R                            8   2       7 3       6 5    6
+--R                     (- 896a b c  + 448a b c - 56a b )d e
+--R                   + 
+--R                             8 3        7 2 2        6 4        5 6  2 5
+--R                     (- 1152a c  + 3264a b c  - 1416a b c + 168a b )d e
+--R                   + 
+--R                           7   3        6 3 2        5 5        4 7  3 4
+--R                     (5120a b c  - 7040a b c  + 2560a b c - 280a b )d e
+--R                   + 
+--R                                7 4         6 2 3        5 4 2        4 6
+--R                           2432a c  - 10304a b c  + 9176a b c  - 2808a b c
+--R                         + 
+--R                               3 8
+--R                           280a b
+--R                    *
+--R                        4 3
+--R                       d e
+--R                   + 
+--R                                6   4         5 3 3        4 5 2        3 7
+--R                         - 4992a b c  + 10560a b c  - 7032a b c  + 1848a b c
+--R                       + 
+--R                               2 9
+--R                         - 168a b
+--R                    *
+--R                        5 2
+--R                       d e
+--R                   + 
+--R                               6 5        5 2 4        4 4 3        3 6 2
+--R                         - 384a c  + 3776a b c  - 5400a b c  + 2912a b c
+--R                       + 
+--R                               2 8         10
+--R                         - 672a b c + 56a b
+--R                    *
+--R                        6
+--R                       d e
+--R                   + 
+--R                             5   5        4 3 4        3 5 3       2 7 2
+--R                         256a b c  - 1024a b c  + 1104a b c  - 504a b c
+--R                       + 
+--R                               9      11
+--R                         104a b c - 8b
+--R                    *
+--R                        7
+--R                       d
+--R                *
+--R                   ROOT
+--R                                  7 2        6 2        5 4
+--R                            (4096a c  - 2048a b c + 256a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8     7     7       7       6 2  2 6
+--R                                   - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                 + 
+--R                                         6         5 3  3 5
+--R                                   (- 64a b c + 56a b )d e
+--R                                 + 
+--R                                         6 2       5 2       4 4  4 4
+--R                                   (- 38a c  + 142a b c - 70a b )d e
+--R                                 + 
+--R                                        5   2       4 3       3 5  5 3
+--R                                   (104a b c  - 168a b c + 56a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2       3 4       2 6  6 2
+--R                                   (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  7
+--R                                   (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                 + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                             4   4        4      3 2    3
+--R                          - a b e  + (- 8a c + 4a b )d e
+--R                        + 
+--R                              3        2 3  2 2      3 2      2 2        4  3
+--R                          (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                        + 
+--R                               2   2       3     5  4
+--R                          (- 5a b c  + 5a b c - b )d
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       7 2        6 2        5 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8     7     7
+--R                                        - a e  + 8a b d e
+--R                                      + 
+--R                                            7       6 2  2 6
+--R                                        (12a c - 28a b )d e
+--R                                      + 
+--R                                              6         5 3  3 5
+--R                                        (- 64a b c + 56a b )d e
+--R                                      + 
+--R                                              6 2       5 2       4 4  4 4
+--R                                        (- 38a c  + 142a b c - 70a b )d e
+--R                                      + 
+--R                                             5   2       4 3       3 5  5 3
+--R                                        (104a b c  - 168a b c + 56a b )d e
+--R                                      + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 4   3      3 3 2      2 5
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                                7
+--R                                            8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  4   4        4      3 2    3
+--R                               - a b e  + (- 8a c + 4a b )d e
+--R                             + 
+--R                                   3        2 3  2 2
+--R                               (18a b c - 6a b )d e
+--R                             + 
+--R                                  3 2      2 2        4  3
+--R                               (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )d
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                      7   10     6       9        6 2      5 2   2 8
+--R                     a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                   + 
+--R                        5   2      4 3   3 7         5 3      3 4   4 6
+--R                     (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                   + 
+--R                         4   3      3 3 2      2 5   5 5
+--R                     (42a b c  - 21a b c  - 21a b c)d e
+--R                   + 
+--R                           4 4      3 2 3      2 4 2       6   6 4
+--R                     (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                   + 
+--R                         3   4      2 3 3        5 2    7   7 3
+--R                     (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                   + 
+--R                          3 5      2 2 4       4 3     6 2  8 2
+--R                     (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                   + 
+--R                      2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                   (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R                *
+--R                   x
+--R     + 
+--R         a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               7 2        6 2        5 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                        4   4        4      3 2    3       3        2 3  2 2
+--R                     - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                   + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                            11 4   2          10 5 3
+--R                    (786432a  c d e  - 262144a  c d )
+--R                 *
+--R                    ROOT
+--R                              8 8     7     7       7       6 2  2 6
+--R                           - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                         + 
+--R                                 6         5 3  3 5
+--R                           (- 64a b c + 56a b )d e
+--R                         + 
+--R                                 6 2       5 2       4 4  4 4
+--R                           (- 38a c  + 142a b c - 70a b )d e
+--R                         + 
+--R                                5   2       4 3       3 5  5 3
+--R                           (104a b c  - 168a b c + 56a b )d e
+--R                         + 
+--R                               5 3       4 2 2       3 4       2 6  6 2
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  7
+--R                           (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                         + 
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                      /
+--R                                   13 3           12 2 2          11 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   10 6
+--R                           - 65536a  b
+--R                + 
+--R                       9 2      8      7  7
+--R                  (128a c  + 64a c + 8a )e
+--R                + 
+--R                          8 3        7 2        6        5  2 5
+--R                  (- 1152a c  - 3264a c  - 1416a c - 168a )d e
+--R                + 
+--R                        7 4         6 3        5 2        4        3  4 3
+--R                  (2432a c  + 10304a c  + 9176a c  + 2808a c + 280a )d e
+--R                + 
+--R                       6 5        5 4        4 3        3 2       2         6
+--R                (- 384a c  - 3776a c  - 5400a c  - 2912a c  - 672a c - 56a)d e
+--R             *
+--R                ROOT
+--R                                 7 2        6 2        5 4
+--R                         (- 4096a c  + 2048a b c - 256a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                          4   4        4      3 2    3       3        2 3  2 2
+--R                       - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                     + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                                11 2 3         10 4 2         9 6         8 8  3
+--R                        (131072a  b c  - 98304a  b c  + 24576a b c - 2048a b )e
+--R                      + 
+--R                                       10 3 3          9 5 2         8 7
+--R                              - 983040a  b c  + 442368a b c  - 86016a b c
+--R                            + 
+--R                                   7 9
+--R                              6144a b
+--R                       *
+--R                             2
+--R                          d e
+--R                      + 
+--R                                      10 2 4           9 4 3          8 6 2
+--R                            - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                          + 
+--R                                  7 8         6 10
+--R                            92160a b c - 6144a b
+--R                       *
+--R                           2
+--R                          d e
+--R                      + 
+--R                                   9 3 4          8 5 3          7 7 2
+--R                            720896a b c  - 573440a b c  + 200704a b c
+--R                          + 
+--R                                    6 9         5 11
+--R                            - 32768a b c + 2048a b
+--R                       *
+--R                           3
+--R                          d
+--R                   *
+--R                      ROOT
+--R                                8 8     7     7       7       6 2  2 6
+--R                             - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                           + 
+--R                                   6         5 3  3 5
+--R                             (- 64a b c + 56a b )d e
+--R                           + 
+--R                                   6 2       5 2       4 4  4 4
+--R                             (- 38a c  + 142a b c - 70a b )d e
+--R                           + 
+--R                                  5   2       4 3       3 5  5 3
+--R                             (104a b c  - 168a b c + 56a b )d e
+--R                           + 
+--R                                 5 3       4 2 2       3 4       2 6  6 2
+--R                             (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                           + 
+--R                                   4   3      3 3 2      2 5        7  7
+--R                             (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                           + 
+--R                                 4 4     3 2 3      2 4 2       6     8  8
+--R                             (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                        /
+--R                                     13 3           12 2 2          11 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     10 6
+--R                             - 65536a  b
+--R                  + 
+--R                         8 2       7       6    6
+--R                    (896a c  + 448a c + 56a )d e
+--R                  + 
+--R                            7 3        6 2        5        4  3 4
+--R                    (- 5120a c  - 7040a c  - 2560a c - 280a )d e
+--R                  + 
+--R                          6 4         5 3        4 2        3        2  5 2
+--R                    (4992a c  + 10560a c  + 7032a c  + 1848a c + 168a )d e
+--R                  + 
+--R                            5 2 5        4 4 4        3 6 3       2 8 2
+--R                        256a b c  - 1024a b c  + 1104a b c  - 504a b c
+--R                      + 
+--R                              10      12
+--R                        104a b  c - 8b
+--R                   *
+--R                       7
+--R                      d
+--R               *
+--R                  ROOT
+--R                                   7 2        6 2        5 4
+--R                           (- 4096a c  + 2048a b c - 256a b )
+--R                        *
+--R                           ROOT
+--R                                     8 8     7     7       7       6 2  2 6
+--R                                  - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                + 
+--R                                        6         5 3  3 5
+--R                                  (- 64a b c + 56a b )d e
+--R                                + 
+--R                                        6 2       5 2       4 4  4 4
+--R                                  (- 38a c  + 142a b c - 70a b )d e
+--R                                + 
+--R                                       5   2       4 3       3 5  5 3
+--R                                  (104a b c  - 168a b c + 56a b )d e
+--R                                + 
+--R                                      5 3       4 2 2       3 4       2 6  6 2
+--R                                  (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  7
+--R                                  (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  8
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                          13 3           12 2 2          11 4
+--R                                  4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                + 
+--R                                          10 6
+--R                                  - 65536a  b
+--R                       + 
+--R                            4   4        4      3 2    3       3        2 3  2 2
+--R                         - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                       + 
+--R                            3 2      2 2        4  3
+--R                         (8a c  - 16a b c + 4a b )d e
+--R                       + 
+--R                              2   2       3     5  4
+--R                         (- 5a b c  + 5a b c - b )d
+--R                    /
+--R                            7 2        6 2        5 4
+--R                       2048a c  - 1024a b c + 128a b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                        7 2        6 2        5 4
+--R                                (- 4096a c  + 2048a b c - 256a b )
+--R                             *
+--R                                ROOT
+--R                                          8 8     7     7       7       6 2  2 6
+--R                                       - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                     + 
+--R                                             6         5 3  3 5
+--R                                       (- 64a b c + 56a b )d e
+--R                                     + 
+--R                                             6 2       5 2       4 4  4 4
+--R                                       (- 38a c  + 142a b c - 70a b )d e
+--R                                     + 
+--R                                            5   2       4 3       3 5  5 3
+--R                                       (104a b c  - 168a b c + 56a b )d e
+--R                                     + 
+--R                                                5 3       4 2 2       3 4
+--R                                             12a c  - 112a b c  + 112a b c
+--R                                           + 
+--R                                                  2 6
+--R                                             - 28a b
+--R                                      *
+--R                                          6 2
+--R                                         d e
+--R                                     + 
+--R                                                  4   3      3 3 2      2 5
+--R                                             - 16a b c  + 56a b c  - 40a b c
+--R                                           + 
+--R                                                 7
+--R                                             8a b
+--R                                      *
+--R                                          7
+--R                                         d e
+--R                                     + 
+--R                                              4 4     3 2 3      2 4 2       6
+--R                                           - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                         + 
+--R                                              8
+--R                                           - b
+--R                                      *
+--R                                          8
+--R                                         d
+--R                                  /
+--R                                               13 3           12 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              11 4          10 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                 4   4        4      3 2    3
+--R                              - a b e  + (- 8a c + 4a b )d e
+--R                            + 
+--R                                  3        2 3  2 2
+--R                              (18a b c - 6a b )d e
+--R                            + 
+--R                                 3 2      2 2        4  3
+--R                              (8a c  - 16a b c + 4a b )d e
+--R                            + 
+--R                                   2   2       3     5  4
+--R                              (- 5a b c  + 5a b c - b )d
+--R                         /
+--R                                 7 2        6 2        5 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                       7   10     6       9      6 2      5 2   2 8
+--R                    - a c e   + 7a b c d e  + (3a c  - 21a b c)d e
+--R                  + 
+--R                         5   2      4 3   3 7       5 3      3 4   4 6
+--R                    (- 8a b c  + 35a b c)d e  + (14a c  - 35a b c)d e
+--R                  + 
+--R                          4   3      3 3 2      2 5   5 5
+--R                    (- 42a b c  + 21a b c  + 21a b c)d e
+--R                  + 
+--R                        4 4      3 2 3      2 4 2       6   6 4
+--R                    (14a c  + 42a b c  - 28a b c  - 7a b c)d e
+--R                  + 
+--R                          3   4      2 3 3        5 2    7   7 3
+--R                    (- 32a b c  - 11a b c  + 15a b c  + b c)d e
+--R                  + 
+--R                       3 5      2 2 4       4 3     6 2  8 2
+--R                    (3a c  + 24a b c  - 6a b c  - 3b c )d e
+--R                  + 
+--R                         2   5       3 4     5 3  9
+--R                    (- 5a b c  - 5a b c  + 3b c )d e
+--R                  + 
+--R                        2 6       2 5    4 4  10
+--R                    (- a c  + 3a b c  - b c )d
+--R               *
+--R                  x
+--R     + 
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  7 2        6 2        5 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8     7     7       7       6 2  2 6
+--R                                 - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                               + 
+--R                                       6         5 3  3 5
+--R                                 (- 64a b c + 56a b )d e
+--R                               + 
+--R                                       6 2       5 2       4 4  4 4
+--R                                 (- 38a c  + 142a b c - 70a b )d e
+--R                               + 
+--R                                      5   2       4 3       3 5  5 3
+--R                                 (104a b c  - 168a b c + 56a b )d e
+--R                               + 
+--R                                     5 3       4 2 2       3 4       2 6  6 2
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  7
+--R                                 (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           4   4        4      3 2    3       3        2 3  2 2
+--R                        - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                      + 
+--R                         3 2      2 2        4  3         2   2       3     5  4
+--R                      (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                               11 4   2          10 5 3
+--R                       (786432a  c d e  - 262144a  c d )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                          9 2      8      7  7
+--R                     (128a c  + 64a c + 8a )e
+--R                   + 
+--R                             8 3        7 2        6        5  2 5
+--R                     (- 1152a c  - 3264a c  - 1416a c - 168a )d e
+--R                   + 
+--R                           7 4         6 3        5 2        4        3  4 3
+--R                     (2432a c  + 10304a c  + 9176a c  + 2808a c + 280a )d e
+--R                   + 
+--R                                 6 5        5 4        4 3        3 2       2
+--R                           - 384a c  - 3776a c  - 5400a c  - 2912a c  - 672a c
+--R                         + 
+--R                           - 56a
+--R                    *
+--R                        6
+--R                       d e
+--R                *
+--R                   ROOT
+--R                                    7 2        6 2        5 4
+--R                            (- 4096a c  + 2048a b c - 256a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8     7     7       7       6 2  2 6
+--R                                   - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                 + 
+--R                                         6         5 3  3 5
+--R                                   (- 64a b c + 56a b )d e
+--R                                 + 
+--R                                         6 2       5 2       4 4  4 4
+--R                                   (- 38a c  + 142a b c - 70a b )d e
+--R                                 + 
+--R                                        5   2       4 3       3 5  5 3
+--R                                   (104a b c  - 168a b c + 56a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2       3 4       2 6  6 2
+--R                                   (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  7
+--R                                   (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                 + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                             4   4        4      3 2    3
+--R                          - a b e  + (- 8a c + 4a b )d e
+--R                        + 
+--R                              3        2 3  2 2      3 2      2 2        4  3
+--R                          (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                        + 
+--R                               2   2       3     5  4
+--R                          (- 5a b c  + 5a b c - b )d
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         7 2        6 2        5 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8     7     7
+--R                                        - a e  + 8a b d e
+--R                                      + 
+--R                                            7       6 2  2 6
+--R                                        (12a c - 28a b )d e
+--R                                      + 
+--R                                              6         5 3  3 5
+--R                                        (- 64a b c + 56a b )d e
+--R                                      + 
+--R                                              6 2       5 2       4 4  4 4
+--R                                        (- 38a c  + 142a b c - 70a b )d e
+--R                                      + 
+--R                                             5   2       4 3       3 5  5 3
+--R                                        (104a b c  - 168a b c + 56a b )d e
+--R                                      + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 4   3      3 3 2      2 5
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                                7
+--R                                            8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  4   4        4      3 2    3
+--R                               - a b e  + (- 8a c + 4a b )d e
+--R                             + 
+--R                                   3        2 3  2 2
+--R                               (18a b c - 6a b )d e
+--R                             + 
+--R                                  3 2      2 2        4  3
+--R                               (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )d
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                      11 2 3         10 4 2         9 6
+--R                               131072a  b c  - 98304a  b c  + 24576a b c
+--R                             + 
+--R                                      8 8
+--R                               - 2048a b
+--R                          *
+--R                              3
+--R                             e
+--R                         + 
+--R                                        10 3 3          9 5 2         8 7
+--R                               - 983040a  b c  + 442368a b c  - 86016a b c
+--R                             + 
+--R                                    7 9
+--R                               6144a b
+--R                          *
+--R                                2
+--R                             d e
+--R                         + 
+--R                                         10 2 4           9 4 3          8 6 2
+--R                               - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                             + 
+--R                                     7 8         6 10
+--R                               92160a b c - 6144a b
+--R                          *
+--R                              2
+--R                             d e
+--R                         + 
+--R                                      9 3 4          8 5 3          7 7 2
+--R                               720896a b c  - 573440a b c  + 200704a b c
+--R                             + 
+--R                                       6 9         5 11
+--R                               - 32768a b c + 2048a b
+--R                          *
+--R                              3
+--R                             d
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                            8 2       7       6    6
+--R                       (896a c  + 448a c + 56a )d e
+--R                     + 
+--R                               7 3        6 2        5        4  3 4
+--R                       (- 5120a c  - 7040a c  - 2560a c - 280a )d e
+--R                     + 
+--R                             6 4         5 3        4 2        3        2  5 2
+--R                       (4992a c  + 10560a c  + 7032a c  + 1848a c + 168a )d e
+--R                     + 
+--R                               5 2 5        4 4 4        3 6 3       2 8 2
+--R                           256a b c  - 1024a b c  + 1104a b c  - 504a b c
+--R                         + 
+--R                                 10      12
+--R                           104a b  c - 8b
+--R                      *
+--R                          7
+--R                         d
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                           7 2        6 2        5 4
+--R                                   (- 4096a c  + 2048a b c - 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             8 8     7     7
+--R                                          - a e  + 8a b d e
+--R                                        + 
+--R                                              7       6 2  2 6
+--R                                          (12a c - 28a b )d e
+--R                                        + 
+--R                                                6         5 3  3 5
+--R                                          (- 64a b c + 56a b )d e
+--R                                        + 
+--R                                                6 2       5 2       4 4  4 4
+--R                                          (- 38a c  + 142a b c - 70a b )d e
+--R                                        + 
+--R                                               5   2       4 3       3 5  5 3
+--R                                          (104a b c  - 168a b c + 56a b )d e
+--R                                        + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                         *
+--R                                             6 2
+--R                                            d e
+--R                                        + 
+--R                                                   4   3      3 3 2      2 5
+--R                                              - 16a b c  + 56a b c  - 40a b c
+--R                                            + 
+--R                                                  7
+--R                                              8a b
+--R                                         *
+--R                                             7
+--R                                            d e
+--R                                        + 
+--R                                                 4 4     3 2 3      2 4 2
+--R                                              - a c  + 6a b c  - 11a b c
+--R                                            + 
+--R                                                  6     8
+--R                                              6a b c - b
+--R                                         *
+--R                                             8
+--R                                            d
+--R                                     /
+--R                                                  13 3           12 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 11 4          10 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                    4   4        4      3 2    3
+--R                                 - a b e  + (- 8a c + 4a b )d e
+--R                               + 
+--R                                     3        2 3  2 2
+--R                                 (18a b c - 6a b )d e
+--R                               + 
+--R                                    3 2      2 2        4  3
+--R                                 (8a c  - 16a b c + 4a b )d e
+--R                               + 
+--R                                      2   2       3     5  4
+--R                                 (- 5a b c  + 5a b c - b )d
+--R                            /
+--R                                    7 2        6 2        5 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                        7   10     6       9        6 2      5 2   2 8
+--R                       a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                     + 
+--R                          5   2      4 3   3 7         5 3      3 4   4 6
+--R                       (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                     + 
+--R                           4   3      3 3 2      2 5   5 5
+--R                       (42a b c  - 21a b c  - 21a b c)d e
+--R                     + 
+--R                             4 4      3 2 3      2 4 2       6   6 4
+--R                       (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                     + 
+--R                           3   4      2 3 3        5 2    7   7 3
+--R                       (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                     + 
+--R                            3 5      2 2 4       4 3     6 2  8 2
+--R                       (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                     + 
+--R                        2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                     (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R                  *
+--R                     x
+--R     + 
+--R       -
+--R            a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                7 2        6 2        5 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8     7     7       7       6 2  2 6
+--R                                 - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                               + 
+--R                                       6         5 3  3 5
+--R                                 (- 64a b c + 56a b )d e
+--R                               + 
+--R                                       6 2       5 2       4 4  4 4
+--R                                 (- 38a c  + 142a b c - 70a b )d e
+--R                               + 
+--R                                      5   2       4 3       3 5  5 3
+--R                                 (104a b c  - 168a b c + 56a b )d e
+--R                               + 
+--R                                     5 3       4 2 2       3 4       2 6  6 2
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  7
+--R                                 (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           4   4        4      3 2    3       3        2 3  2 2
+--R                        - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                      + 
+--R                         3 2      2 2        4  3         2   2       3     5  4
+--R                      (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                               11 4   2          10 5 3
+--R                       (786432a  c d e  - 262144a  c d )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                            9 2      8      7  7
+--R                     (- 128a c  - 64a c - 8a )e
+--R                   + 
+--R                           8 3        7 2        6        5  2 5
+--R                     (1152a c  + 3264a c  + 1416a c + 168a )d e
+--R                   + 
+--R                             7 4         6 3        5 2        4        3  4 3
+--R                     (- 2432a c  - 10304a c  - 9176a c  - 2808a c - 280a )d e
+--R                   + 
+--R                        6 5        5 4        4 3        3 2       2         6
+--R                   (384a c  + 3776a c  + 5400a c  + 2912a c  + 672a c + 56a)d e
+--R                *
+--R                   ROOT
+--R                                  7 2        6 2        5 4
+--R                            (4096a c  - 2048a b c + 256a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8     7     7       7       6 2  2 6
+--R                                   - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                 + 
+--R                                         6         5 3  3 5
+--R                                   (- 64a b c + 56a b )d e
+--R                                 + 
+--R                                         6 2       5 2       4 4  4 4
+--R                                   (- 38a c  + 142a b c - 70a b )d e
+--R                                 + 
+--R                                        5   2       4 3       3 5  5 3
+--R                                   (104a b c  - 168a b c + 56a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2       3 4       2 6  6 2
+--R                                   (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  7
+--R                                   (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                 + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                             4   4        4      3 2    3
+--R                          - a b e  + (- 8a c + 4a b )d e
+--R                        + 
+--R                              3        2 3  2 2      3 2      2 2        4  3
+--R                          (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                        + 
+--R                               2   2       3     5  4
+--R                          (- 5a b c  + 5a b c - b )d
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       7 2        6 2        5 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8     7     7
+--R                                        - a e  + 8a b d e
+--R                                      + 
+--R                                            7       6 2  2 6
+--R                                        (12a c - 28a b )d e
+--R                                      + 
+--R                                              6         5 3  3 5
+--R                                        (- 64a b c + 56a b )d e
+--R                                      + 
+--R                                              6 2       5 2       4 4  4 4
+--R                                        (- 38a c  + 142a b c - 70a b )d e
+--R                                      + 
+--R                                             5   2       4 3       3 5  5 3
+--R                                        (104a b c  - 168a b c + 56a b )d e
+--R                                      + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 4   3      3 3 2      2 5
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                                7
+--R                                            8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  4   4        4      3 2    3
+--R                               - a b e  + (- 8a c + 4a b )d e
+--R                             + 
+--R                                   3        2 3  2 2
+--R                               (18a b c - 6a b )d e
+--R                             + 
+--R                                  3 2      2 2        4  3
+--R                               (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )d
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                      11 2 3         10 4 2         9 6
+--R                               131072a  b c  - 98304a  b c  + 24576a b c
+--R                             + 
+--R                                      8 8
+--R                               - 2048a b
+--R                          *
+--R                              3
+--R                             e
+--R                         + 
+--R                                        10 3 3          9 5 2         8 7
+--R                               - 983040a  b c  + 442368a b c  - 86016a b c
+--R                             + 
+--R                                    7 9
+--R                               6144a b
+--R                          *
+--R                                2
+--R                             d e
+--R                         + 
+--R                                         10 2 4           9 4 3          8 6 2
+--R                               - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                             + 
+--R                                     7 8         6 10
+--R                               92160a b c - 6144a b
+--R                          *
+--R                              2
+--R                             d e
+--R                         + 
+--R                                      9 3 4          8 5 3          7 7 2
+--R                               720896a b c  - 573440a b c  + 200704a b c
+--R                             + 
+--R                                       6 9         5 11
+--R                               - 32768a b c + 2048a b
+--R                          *
+--R                              3
+--R                             d
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                              8 2       7       6    6
+--R                       (- 896a c  - 448a c - 56a )d e
+--R                     + 
+--R                             7 3        6 2        5        4  3 4
+--R                       (5120a c  + 7040a c  + 2560a c + 280a )d e
+--R                     + 
+--R                               6 4         5 3        4 2        3        2  5 2
+--R                       (- 4992a c  - 10560a c  - 7032a c  - 1848a c - 168a )d e
+--R                     + 
+--R                                 5 2 5        4 4 4        3 6 3       2 8 2
+--R                           - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                         + 
+--R                                   10      12
+--R                           - 104a b  c + 8b
+--R                      *
+--R                          7
+--R                         d
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         7 2        6 2        5 4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             8 8     7     7
+--R                                          - a e  + 8a b d e
+--R                                        + 
+--R                                              7       6 2  2 6
+--R                                          (12a c - 28a b )d e
+--R                                        + 
+--R                                                6         5 3  3 5
+--R                                          (- 64a b c + 56a b )d e
+--R                                        + 
+--R                                                6 2       5 2       4 4  4 4
+--R                                          (- 38a c  + 142a b c - 70a b )d e
+--R                                        + 
+--R                                               5   2       4 3       3 5  5 3
+--R                                          (104a b c  - 168a b c + 56a b )d e
+--R                                        + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                         *
+--R                                             6 2
+--R                                            d e
+--R                                        + 
+--R                                                   4   3      3 3 2      2 5
+--R                                              - 16a b c  + 56a b c  - 40a b c
+--R                                            + 
+--R                                                  7
+--R                                              8a b
+--R                                         *
+--R                                             7
+--R                                            d e
+--R                                        + 
+--R                                                 4 4     3 2 3      2 4 2
+--R                                              - a c  + 6a b c  - 11a b c
+--R                                            + 
+--R                                                  6     8
+--R                                              6a b c - b
+--R                                         *
+--R                                             8
+--R                                            d
+--R                                     /
+--R                                                  13 3           12 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 11 4          10 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                    4   4        4      3 2    3
+--R                                 - a b e  + (- 8a c + 4a b )d e
+--R                               + 
+--R                                     3        2 3  2 2
+--R                                 (18a b c - 6a b )d e
+--R                               + 
+--R                                    3 2      2 2        4  3
+--R                                 (8a c  - 16a b c + 4a b )d e
+--R                               + 
+--R                                      2   2       3     5  4
+--R                                 (- 5a b c  + 5a b c - b )d
+--R                            /
+--R                                    7 2        6 2        5 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                          7   10     6       9      6 2      5 2   2 8
+--R                       - a c e   + 7a b c d e  + (3a c  - 21a b c)d e
+--R                     + 
+--R                            5   2      4 3   3 7       5 3      3 4   4 6
+--R                       (- 8a b c  + 35a b c)d e  + (14a c  - 35a b c)d e
+--R                     + 
+--R                             4   3      3 3 2      2 5   5 5
+--R                       (- 42a b c  + 21a b c  + 21a b c)d e
+--R                     + 
+--R                           4 4      3 2 3      2 4 2       6   6 4
+--R                       (14a c  + 42a b c  - 28a b c  - 7a b c)d e
+--R                     + 
+--R                             3   4      2 3 3        5 2    7   7 3
+--R                       (- 32a b c  - 11a b c  + 15a b c  + b c)d e
+--R                     + 
+--R                          3 5      2 2 4       4 3     6 2  8 2
+--R                       (3a c  + 24a b c  - 6a b c  - 3b c )d e
+--R                     + 
+--R                            2   5       3 4     5 3  9
+--R                       (- 5a b c  - 5a b c  + 3b c )d e
+--R                     + 
+--R                           2 6       2 5    4 4  10
+--R                       (- a c  + 3a b c  - b c )d
+--R                  *
+--R                     x
+--R     + 
+--R         a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2        6 2        5 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                        4   4        4      3 2    3       3        2 3  2 2
+--R                     - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                   + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                            11 4   2          10 5 3
+--R                    (786432a  c d e  - 262144a  c d )
+--R                 *
+--R                    ROOT
+--R                              8 8     7     7       7       6 2  2 6
+--R                           - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                         + 
+--R                                 6         5 3  3 5
+--R                           (- 64a b c + 56a b )d e
+--R                         + 
+--R                                 6 2       5 2       4 4  4 4
+--R                           (- 38a c  + 142a b c - 70a b )d e
+--R                         + 
+--R                                5   2       4 3       3 5  5 3
+--R                           (104a b c  - 168a b c + 56a b )d e
+--R                         + 
+--R                               5 3       4 2 2       3 4       2 6  6 2
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  7
+--R                           (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                         + 
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                      /
+--R                                   13 3           12 2 2          11 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   10 6
+--R                           - 65536a  b
+--R                + 
+--R                         9 2      8      7  7
+--R                  (- 128a c  - 64a c - 8a )e
+--R                + 
+--R                        8 3        7 2        6        5  2 5
+--R                  (1152a c  + 3264a c  + 1416a c + 168a )d e
+--R                + 
+--R                          7 4         6 3        5 2        4        3  4 3
+--R                  (- 2432a c  - 10304a c  - 9176a c  - 2808a c - 280a )d e
+--R                + 
+--R                       6 5        5 4        4 3        3 2       2         6
+--R                  (384a c  + 3776a c  + 5400a c  + 2912a c  + 672a c + 56a)d e
+--R             *
+--R                ROOT
+--R                               7 2        6 2        5 4
+--R                         (4096a c  - 2048a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                          4   4        4      3 2    3       3        2 3  2 2
+--R                       - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                     + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                                11 2 3         10 4 2         9 6         8 8  3
+--R                        (131072a  b c  - 98304a  b c  + 24576a b c - 2048a b )e
+--R                      + 
+--R                                       10 3 3          9 5 2         8 7
+--R                              - 983040a  b c  + 442368a b c  - 86016a b c
+--R                            + 
+--R                                   7 9
+--R                              6144a b
+--R                       *
+--R                             2
+--R                          d e
+--R                      + 
+--R                                      10 2 4           9 4 3          8 6 2
+--R                            - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                          + 
+--R                                  7 8         6 10
+--R                            92160a b c - 6144a b
+--R                       *
+--R                           2
+--R                          d e
+--R                      + 
+--R                                   9 3 4          8 5 3          7 7 2
+--R                            720896a b c  - 573440a b c  + 200704a b c
+--R                          + 
+--R                                    6 9         5 11
+--R                            - 32768a b c + 2048a b
+--R                       *
+--R                           3
+--R                          d
+--R                   *
+--R                      ROOT
+--R                                8 8     7     7       7       6 2  2 6
+--R                             - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                           + 
+--R                                   6         5 3  3 5
+--R                             (- 64a b c + 56a b )d e
+--R                           + 
+--R                                   6 2       5 2       4 4  4 4
+--R                             (- 38a c  + 142a b c - 70a b )d e
+--R                           + 
+--R                                  5   2       4 3       3 5  5 3
+--R                             (104a b c  - 168a b c + 56a b )d e
+--R                           + 
+--R                                 5 3       4 2 2       3 4       2 6  6 2
+--R                             (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                           + 
+--R                                   4   3      3 3 2      2 5        7  7
+--R                             (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                           + 
+--R                                 4 4     3 2 3      2 4 2       6     8  8
+--R                             (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                        /
+--R                                     13 3           12 2 2          11 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     10 6
+--R                             - 65536a  b
+--R                  + 
+--R                           8 2       7       6    6
+--R                    (- 896a c  - 448a c - 56a )d e
+--R                  + 
+--R                          7 3        6 2        5        4  3 4
+--R                    (5120a c  + 7040a c  + 2560a c + 280a )d e
+--R                  + 
+--R                            6 4         5 3        4 2        3        2  5 2
+--R                    (- 4992a c  - 10560a c  - 7032a c  - 1848a c - 168a )d e
+--R                  + 
+--R                              5 2 5        4 4 4        3 6 3       2 8 2
+--R                        - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                      + 
+--R                                10      12
+--R                        - 104a b  c + 8b
+--R                   *
+--R                       7
+--R                      d
+--R               *
+--R                  ROOT
+--R                                 7 2        6 2        5 4
+--R                           (4096a c  - 2048a b c + 256a b )
+--R                        *
+--R                           ROOT
+--R                                     8 8     7     7       7       6 2  2 6
+--R                                  - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                + 
+--R                                        6         5 3  3 5
+--R                                  (- 64a b c + 56a b )d e
+--R                                + 
+--R                                        6 2       5 2       4 4  4 4
+--R                                  (- 38a c  + 142a b c - 70a b )d e
+--R                                + 
+--R                                       5   2       4 3       3 5  5 3
+--R                                  (104a b c  - 168a b c + 56a b )d e
+--R                                + 
+--R                                      5 3       4 2 2       3 4       2 6  6 2
+--R                                  (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  7
+--R                                  (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  8
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                          13 3           12 2 2          11 4
+--R                                  4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                + 
+--R                                          10 6
+--R                                  - 65536a  b
+--R                       + 
+--R                            4   4        4      3 2    3       3        2 3  2 2
+--R                         - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                       + 
+--R                            3 2      2 2        4  3
+--R                         (8a c  - 16a b c + 4a b )d e
+--R                       + 
+--R                              2   2       3     5  4
+--R                         (- 5a b c  + 5a b c - b )d
+--R                    /
+--R                            7 2        6 2        5 4
+--R                       2048a c  - 1024a b c + 128a b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      7 2        6 2        5 4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                          8 8     7     7       7       6 2  2 6
+--R                                       - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                     + 
+--R                                             6         5 3  3 5
+--R                                       (- 64a b c + 56a b )d e
+--R                                     + 
+--R                                             6 2       5 2       4 4  4 4
+--R                                       (- 38a c  + 142a b c - 70a b )d e
+--R                                     + 
+--R                                            5   2       4 3       3 5  5 3
+--R                                       (104a b c  - 168a b c + 56a b )d e
+--R                                     + 
+--R                                                5 3       4 2 2       3 4
+--R                                             12a c  - 112a b c  + 112a b c
+--R                                           + 
+--R                                                  2 6
+--R                                             - 28a b
+--R                                      *
+--R                                          6 2
+--R                                         d e
+--R                                     + 
+--R                                                  4   3      3 3 2      2 5
+--R                                             - 16a b c  + 56a b c  - 40a b c
+--R                                           + 
+--R                                                 7
+--R                                             8a b
+--R                                      *
+--R                                          7
+--R                                         d e
+--R                                     + 
+--R                                              4 4     3 2 3      2 4 2       6
+--R                                           - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                         + 
+--R                                              8
+--R                                           - b
+--R                                      *
+--R                                          8
+--R                                         d
+--R                                  /
+--R                                               13 3           12 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              11 4          10 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                 4   4        4      3 2    3
+--R                              - a b e  + (- 8a c + 4a b )d e
+--R                            + 
+--R                                  3        2 3  2 2
+--R                              (18a b c - 6a b )d e
+--R                            + 
+--R                                 3 2      2 2        4  3
+--R                              (8a c  - 16a b c + 4a b )d e
+--R                            + 
+--R                                   2   2       3     5  4
+--R                              (- 5a b c  + 5a b c - b )d
+--R                         /
+--R                                 7 2        6 2        5 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                     7   10     6       9        6 2      5 2   2 8
+--R                    a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                  + 
+--R                       5   2      4 3   3 7         5 3      3 4   4 6
+--R                    (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                  + 
+--R                        4   3      3 3 2      2 5   5 5
+--R                    (42a b c  - 21a b c  - 21a b c)d e
+--R                  + 
+--R                          4 4      3 2 3      2 4 2       6   6 4
+--R                    (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                  + 
+--R                        3   4      2 3 3        5 2    7   7 3
+--R                    (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                  + 
+--R                         3 5      2 2 4       4 3     6 2  8 2
+--R                    (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                  + 
+--R                       2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                    (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R               *
+--R                  x
+--R     + 
+--R       - 2d
+--R  /
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 233
+
+--S 234 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4|   |          2      4| |          2
+--R         a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2        6 2        5 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                        4   4        4      3 2    3       3        2 3  2 2
+--R                     - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                   + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                              11   3         10 3 2         9 5         8 7  3
+--R                      (131072a  b c  - 98304a  b c  + 24576a b c - 2048a b )e
+--R                    + 
+--R                                 11 4          10 2 3          9 4 2
+--R                          786432a  c  - 983040a  b c  + 442368a b c
+--R                        + 
+--R                                  8 6         7 8
+--R                          - 86016a b c + 6144a b
+--R                     *
+--R                           2
+--R                        d e
+--R                    + 
+--R                                    10   4           9 3 3          8 5 2
+--R                          - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                        + 
+--R                                7 7         6 9
+--R                          92160a b c - 6144a b
+--R                     *
+--R                         2
+--R                        d e
+--R                    + 
+--R                                   10 5          9 2 4          8 4 3
+--R                          - 262144a  c  + 720896a b c  - 573440a b c
+--R                        + 
+--R                                 7 6 2         6 8         5 10
+--R                          200704a b c  - 32768a b c + 2048a b
+--R                     *
+--R                         3
+--R                        d
+--R                 *
+--R                    ROOT
+--R                              8 8     7     7       7       6 2  2 6
+--R                           - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                         + 
+--R                                 6         5 3  3 5
+--R                           (- 64a b c + 56a b )d e
+--R                         + 
+--R                                 6 2       5 2       4 4  4 4
+--R                           (- 38a c  + 142a b c - 70a b )d e
+--R                         + 
+--R                                5   2       4 3       3 5  5 3
+--R                           (104a b c  - 168a b c + 56a b )d e
+--R                         + 
+--R                               5 3       4 2 2       3 4       2 6  6 2
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  7
+--R                           (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                         + 
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                      /
+--R                                   13 3           12 2 2          11 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   10 6
+--R                           - 65536a  b
+--R                + 
+--R                         9 2      8 2      7 4  7
+--R                  (- 128a c  + 64a b c - 8a b )e
+--R                + 
+--R                       8   2       7 3       6 5    6
+--R                  (896a b c  - 448a b c + 56a b )d e
+--R                + 
+--R                        8 3        7 2 2        6 4        5 6  2 5
+--R                  (1152a c  - 3264a b c  + 1416a b c - 168a b )d e
+--R                + 
+--R                          7   3        6 3 2        5 5        4 7  3 4
+--R                  (- 5120a b c  + 7040a b c  - 2560a b c + 280a b )d e
+--R                + 
+--R                               7 4         6 2 3        5 4 2        4 6
+--R                        - 2432a c  + 10304a b c  - 9176a b c  + 2808a b c
+--R                      + 
+--R                              3 8
+--R                        - 280a b
+--R                 *
+--R                     4 3
+--R                    d e
+--R                + 
+--R                             6   4         5 3 3        4 5 2        3 7
+--R                        4992a b c  - 10560a b c  + 7032a b c  - 1848a b c
+--R                      + 
+--R                            2 9
+--R                        168a b
+--R                 *
+--R                     5 2
+--R                    d e
+--R                + 
+--R                          6 5        5 2 4        4 4 3        3 6 2       2 8
+--R                      384a c  - 3776a b c  + 5400a b c  - 2912a b c  + 672a b c
+--R                    + 
+--R                             10
+--R                      - 56a b
+--R                 *
+--R                     6
+--R                    d e
+--R                + 
+--R                            5   5        4 3 4        3 5 3       2 7 2
+--R                      - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                    + 
+--R                              9      11
+--R                      - 104a b c + 8b
+--R                 *
+--R                     7
+--R                    d
+--R             *
+--R                ROOT
+--R                               7 2        6 2        5 4
+--R                         (4096a c  - 2048a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                          4   4        4      3 2    3       3        2 3  2 2
+--R                       - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                     + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                   7   10     6       9        6 2      5 2   2 8
+--R                  a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                + 
+--R                     5   2      4 3   3 7         5 3      3 4   4 6
+--R                  (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                + 
+--R                      4   3      3 3 2      2 5   5 5
+--R                  (42a b c  - 21a b c  - 21a b c)d e
+--R                + 
+--R                        4 4      3 2 3      2 4 2       6   6 4
+--R                  (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                + 
+--R                      3   4      2 3 3        5 2    7   7 3
+--R                  (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                + 
+--R                       3 5      2 2 4       4 3     6 2  8 2
+--R                  (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                + 
+--R                     2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                  (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              4+-+3 |          2 4|   |          2      4| |          2
+--R            a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  7 2        6 2        5 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8     7     7       7       6 2  2 6
+--R                                 - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                               + 
+--R                                       6         5 3  3 5
+--R                                 (- 64a b c + 56a b )d e
+--R                               + 
+--R                                       6 2       5 2       4 4  4 4
+--R                                 (- 38a c  + 142a b c - 70a b )d e
+--R                               + 
+--R                                      5   2       4 3       3 5  5 3
+--R                                 (104a b c  - 168a b c + 56a b )d e
+--R                               + 
+--R                                     5 3       4 2 2       3 4       2 6  6 2
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  7
+--R                                 (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           4   4        4      3 2    3       3        2 3  2 2
+--R                        - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                      + 
+--R                         3 2      2 2        4  3         2   2       3     5  4
+--R                      (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                                      11   3         10 3 2         9 5
+--R                               131072a  b c  - 98304a  b c  + 24576a b c
+--R                             + 
+--R                                      8 7
+--R                               - 2048a b
+--R                        *
+--R                            3
+--R                           e
+--R                       + 
+--R                                    11 4          10 2 3          9 4 2
+--R                             786432a  c  - 983040a  b c  + 442368a b c
+--R                           + 
+--R                                     8 6         7 8
+--R                             - 86016a b c + 6144a b
+--R                        *
+--R                              2
+--R                           d e
+--R                       + 
+--R                                       10   4           9 3 3          8 5 2
+--R                             - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                           + 
+--R                                   7 7         6 9
+--R                             92160a b c - 6144a b
+--R                        *
+--R                            2
+--R                           d e
+--R                       + 
+--R                                      10 5          9 2 4          8 4 3
+--R                             - 262144a  c  + 720896a b c  - 573440a b c
+--R                           + 
+--R                                    7 6 2         6 8         5 10
+--R                             200704a b c  - 32768a b c + 2048a b
+--R                        *
+--R                            3
+--R                           d
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                          9 2      8 2      7 4  7
+--R                     (128a c  - 64a b c + 8a b )e
+--R                   + 
+--R                            8   2       7 3       6 5    6
+--R                     (- 896a b c  + 448a b c - 56a b )d e
+--R                   + 
+--R                             8 3        7 2 2        6 4        5 6  2 5
+--R                     (- 1152a c  + 3264a b c  - 1416a b c + 168a b )d e
+--R                   + 
+--R                           7   3        6 3 2        5 5        4 7  3 4
+--R                     (5120a b c  - 7040a b c  + 2560a b c - 280a b )d e
+--R                   + 
+--R                                7 4         6 2 3        5 4 2        4 6
+--R                           2432a c  - 10304a b c  + 9176a b c  - 2808a b c
+--R                         + 
+--R                               3 8
+--R                           280a b
+--R                    *
+--R                        4 3
+--R                       d e
+--R                   + 
+--R                                6   4         5 3 3        4 5 2        3 7
+--R                         - 4992a b c  + 10560a b c  - 7032a b c  + 1848a b c
+--R                       + 
+--R                               2 9
+--R                         - 168a b
+--R                    *
+--R                        5 2
+--R                       d e
+--R                   + 
+--R                               6 5        5 2 4        4 4 3        3 6 2
+--R                         - 384a c  + 3776a b c  - 5400a b c  + 2912a b c
+--R                       + 
+--R                               2 8         10
+--R                         - 672a b c + 56a b
+--R                    *
+--R                        6
+--R                       d e
+--R                   + 
+--R                             5   5        4 3 4        3 5 3       2 7 2
+--R                         256a b c  - 1024a b c  + 1104a b c  - 504a b c
+--R                       + 
+--R                               9      11
+--R                         104a b c - 8b
+--R                    *
+--R                        7
+--R                       d
+--R                *
+--R                   ROOT
+--R                                    7 2        6 2        5 4
+--R                            (- 4096a c  + 2048a b c - 256a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8     7     7       7       6 2  2 6
+--R                                   - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                 + 
+--R                                         6         5 3  3 5
+--R                                   (- 64a b c + 56a b )d e
+--R                                 + 
+--R                                         6 2       5 2       4 4  4 4
+--R                                   (- 38a c  + 142a b c - 70a b )d e
+--R                                 + 
+--R                                        5   2       4 3       3 5  5 3
+--R                                   (104a b c  - 168a b c + 56a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2       3 4       2 6  6 2
+--R                                   (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  7
+--R                                   (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                 + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                             4   4        4      3 2    3
+--R                          - a b e  + (- 8a c + 4a b )d e
+--R                        + 
+--R                              3        2 3  2 2      3 2      2 2        4  3
+--R                          (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                        + 
+--R                               2   2       3     5  4
+--R                          (- 5a b c  + 5a b c - b )d
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         7 2        6 2        5 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8     7     7
+--R                                        - a e  + 8a b d e
+--R                                      + 
+--R                                            7       6 2  2 6
+--R                                        (12a c - 28a b )d e
+--R                                      + 
+--R                                              6         5 3  3 5
+--R                                        (- 64a b c + 56a b )d e
+--R                                      + 
+--R                                              6 2       5 2       4 4  4 4
+--R                                        (- 38a c  + 142a b c - 70a b )d e
+--R                                      + 
+--R                                             5   2       4 3       3 5  5 3
+--R                                        (104a b c  - 168a b c + 56a b )d e
+--R                                      + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 4   3      3 3 2      2 5
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                                7
+--R                                            8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  4   4        4      3 2    3
+--R                               - a b e  + (- 8a c + 4a b )d e
+--R                             + 
+--R                                   3        2 3  2 2
+--R                               (18a b c - 6a b )d e
+--R                             + 
+--R                                  3 2      2 2        4  3
+--R                               (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )d
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                      7   10     6       9        6 2      5 2   2 8
+--R                     a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                   + 
+--R                        5   2      4 3   3 7         5 3      3 4   4 6
+--R                     (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                   + 
+--R                         4   3      3 3 2      2 5   5 5
+--R                     (42a b c  - 21a b c  - 21a b c)d e
+--R                   + 
+--R                           4 4      3 2 3      2 4 2       6   6 4
+--R                     (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                   + 
+--R                         3   4      2 3 3        5 2    7   7 3
+--R                     (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                   + 
+--R                          3 5      2 2 4       4 3     6 2  8 2
+--R                     (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                   + 
+--R                      2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                   (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R                *
+--R                   x
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4|   |          2      4| |          2
+--R         a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               7 2        6 2        5 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                        4   4        4      3 2    3       3        2 3  2 2
+--R                     - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                   + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                                11   3         10 3 2         9 5         8 7  3
+--R                      (- 131072a  b c  + 98304a  b c  - 24576a b c + 2048a b )e
+--R                    + 
+--R                                   11 4          10 2 3          9 4 2
+--R                          - 786432a  c  + 983040a  b c  - 442368a b c
+--R                        + 
+--R                                8 6         7 8
+--R                          86016a b c - 6144a b
+--R                     *
+--R                           2
+--R                        d e
+--R                    + 
+--R                                  10   4           9 3 3          8 5 2
+--R                          1179648a  b c  - 1277952a b c  + 516096a b c
+--R                        + 
+--R                                  7 7         6 9
+--R                          - 92160a b c + 6144a b
+--R                     *
+--R                         2
+--R                        d e
+--R                    + 
+--R                                 10 5          9 2 4          8 4 3
+--R                          262144a  c  - 720896a b c  + 573440a b c
+--R                        + 
+--R                                   7 6 2         6 8         5 10
+--R                          - 200704a b c  + 32768a b c - 2048a b
+--R                     *
+--R                         3
+--R                        d
+--R                 *
+--R                    ROOT
+--R                              8 8     7     7       7       6 2  2 6
+--R                           - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                         + 
+--R                                 6         5 3  3 5
+--R                           (- 64a b c + 56a b )d e
+--R                         + 
+--R                                 6 2       5 2       4 4  4 4
+--R                           (- 38a c  + 142a b c - 70a b )d e
+--R                         + 
+--R                                5   2       4 3       3 5  5 3
+--R                           (104a b c  - 168a b c + 56a b )d e
+--R                         + 
+--R                               5 3       4 2 2       3 4       2 6  6 2
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  7
+--R                           (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                         + 
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                      /
+--R                                   13 3           12 2 2          11 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   10 6
+--R                           - 65536a  b
+--R                + 
+--R                         9 2      8 2      7 4  7
+--R                  (- 128a c  + 64a b c - 8a b )e
+--R                + 
+--R                       8   2       7 3       6 5    6
+--R                  (896a b c  - 448a b c + 56a b )d e
+--R                + 
+--R                        8 3        7 2 2        6 4        5 6  2 5
+--R                  (1152a c  - 3264a b c  + 1416a b c - 168a b )d e
+--R                + 
+--R                          7   3        6 3 2        5 5        4 7  3 4
+--R                  (- 5120a b c  + 7040a b c  - 2560a b c + 280a b )d e
+--R                + 
+--R                               7 4         6 2 3        5 4 2        4 6
+--R                        - 2432a c  + 10304a b c  - 9176a b c  + 2808a b c
+--R                      + 
+--R                              3 8
+--R                        - 280a b
+--R                 *
+--R                     4 3
+--R                    d e
+--R                + 
+--R                             6   4         5 3 3        4 5 2        3 7
+--R                        4992a b c  - 10560a b c  + 7032a b c  - 1848a b c
+--R                      + 
+--R                            2 9
+--R                        168a b
+--R                 *
+--R                     5 2
+--R                    d e
+--R                + 
+--R                          6 5        5 2 4        4 4 3        3 6 2       2 8
+--R                      384a c  - 3776a b c  + 5400a b c  - 2912a b c  + 672a b c
+--R                    + 
+--R                             10
+--R                      - 56a b
+--R                 *
+--R                     6
+--R                    d e
+--R                + 
+--R                            5   5        4 3 4        3 5 3       2 7 2
+--R                      - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                    + 
+--R                              9      11
+--R                      - 104a b c + 8b
+--R                 *
+--R                     7
+--R                    d
+--R             *
+--R                ROOT
+--R                                 7 2        6 2        5 4
+--R                         (- 4096a c  + 2048a b c - 256a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                          4   4        4      3 2    3       3        2 3  2 2
+--R                       - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                     + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                   7   10     6       9        6 2      5 2   2 8
+--R                  a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                + 
+--R                     5   2      4 3   3 7         5 3      3 4   4 6
+--R                  (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                + 
+--R                      4   3      3 3 2      2 5   5 5
+--R                  (42a b c  - 21a b c  - 21a b c)d e
+--R                + 
+--R                        4 4      3 2 3      2 4 2       6   6 4
+--R                  (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                + 
+--R                      3   4      2 3 3        5 2    7   7 3
+--R                  (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                + 
+--R                       3 5      2 2 4       4 3     6 2  8 2
+--R                  (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                + 
+--R                     2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                  (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              4+-+3 |          2 4|   |          2      4| |          2
+--R            a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                7 2        6 2        5 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8     7     7       7       6 2  2 6
+--R                                 - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                               + 
+--R                                       6         5 3  3 5
+--R                                 (- 64a b c + 56a b )d e
+--R                               + 
+--R                                       6 2       5 2       4 4  4 4
+--R                                 (- 38a c  + 142a b c - 70a b )d e
+--R                               + 
+--R                                      5   2       4 3       3 5  5 3
+--R                                 (104a b c  - 168a b c + 56a b )d e
+--R                               + 
+--R                                     5 3       4 2 2       3 4       2 6  6 2
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  7
+--R                                 (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           4   4        4      3 2    3       3        2 3  2 2
+--R                        - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                      + 
+--R                         3 2      2 2        4  3         2   2       3     5  4
+--R                      (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                                      11   3         10 3 2         9 5
+--R                             - 131072a  b c  + 98304a  b c  - 24576a b c
+--R                           + 
+--R                                  8 7
+--R                             2048a b
+--R                        *
+--R                            3
+--R                           e
+--R                       + 
+--R                                      11 4          10 2 3          9 4 2
+--R                             - 786432a  c  + 983040a  b c  - 442368a b c
+--R                           + 
+--R                                   8 6         7 8
+--R                             86016a b c - 6144a b
+--R                        *
+--R                              2
+--R                           d e
+--R                       + 
+--R                                     10   4           9 3 3          8 5 2
+--R                             1179648a  b c  - 1277952a b c  + 516096a b c
+--R                           + 
+--R                                     7 7         6 9
+--R                             - 92160a b c + 6144a b
+--R                        *
+--R                            2
+--R                           d e
+--R                       + 
+--R                                    10 5          9 2 4          8 4 3
+--R                             262144a  c  - 720896a b c  + 573440a b c
+--R                           + 
+--R                                      7 6 2         6 8         5 10
+--R                             - 200704a b c  + 32768a b c - 2048a b
+--R                        *
+--R                            3
+--R                           d
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                          9 2      8 2      7 4  7
+--R                     (128a c  - 64a b c + 8a b )e
+--R                   + 
+--R                            8   2       7 3       6 5    6
+--R                     (- 896a b c  + 448a b c - 56a b )d e
+--R                   + 
+--R                             8 3        7 2 2        6 4        5 6  2 5
+--R                     (- 1152a c  + 3264a b c  - 1416a b c + 168a b )d e
+--R                   + 
+--R                           7   3        6 3 2        5 5        4 7  3 4
+--R                     (5120a b c  - 7040a b c  + 2560a b c - 280a b )d e
+--R                   + 
+--R                                7 4         6 2 3        5 4 2        4 6
+--R                           2432a c  - 10304a b c  + 9176a b c  - 2808a b c
+--R                         + 
+--R                               3 8
+--R                           280a b
+--R                    *
+--R                        4 3
+--R                       d e
+--R                   + 
+--R                                6   4         5 3 3        4 5 2        3 7
+--R                         - 4992a b c  + 10560a b c  - 7032a b c  + 1848a b c
+--R                       + 
+--R                               2 9
+--R                         - 168a b
+--R                    *
+--R                        5 2
+--R                       d e
+--R                   + 
+--R                               6 5        5 2 4        4 4 3        3 6 2
+--R                         - 384a c  + 3776a b c  - 5400a b c  + 2912a b c
+--R                       + 
+--R                               2 8         10
+--R                         - 672a b c + 56a b
+--R                    *
+--R                        6
+--R                       d e
+--R                   + 
+--R                             5   5        4 3 4        3 5 3       2 7 2
+--R                         256a b c  - 1024a b c  + 1104a b c  - 504a b c
+--R                       + 
+--R                               9      11
+--R                         104a b c - 8b
+--R                    *
+--R                        7
+--R                       d
+--R                *
+--R                   ROOT
+--R                                  7 2        6 2        5 4
+--R                            (4096a c  - 2048a b c + 256a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8     7     7       7       6 2  2 6
+--R                                   - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                 + 
+--R                                         6         5 3  3 5
+--R                                   (- 64a b c + 56a b )d e
+--R                                 + 
+--R                                         6 2       5 2       4 4  4 4
+--R                                   (- 38a c  + 142a b c - 70a b )d e
+--R                                 + 
+--R                                        5   2       4 3       3 5  5 3
+--R                                   (104a b c  - 168a b c + 56a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2       3 4       2 6  6 2
+--R                                   (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  7
+--R                                   (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                 + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                             4   4        4      3 2    3
+--R                          - a b e  + (- 8a c + 4a b )d e
+--R                        + 
+--R                              3        2 3  2 2      3 2      2 2        4  3
+--R                          (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                        + 
+--R                               2   2       3     5  4
+--R                          (- 5a b c  + 5a b c - b )d
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       7 2        6 2        5 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8     7     7
+--R                                        - a e  + 8a b d e
+--R                                      + 
+--R                                            7       6 2  2 6
+--R                                        (12a c - 28a b )d e
+--R                                      + 
+--R                                              6         5 3  3 5
+--R                                        (- 64a b c + 56a b )d e
+--R                                      + 
+--R                                              6 2       5 2       4 4  4 4
+--R                                        (- 38a c  + 142a b c - 70a b )d e
+--R                                      + 
+--R                                             5   2       4 3       3 5  5 3
+--R                                        (104a b c  - 168a b c + 56a b )d e
+--R                                      + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 4   3      3 3 2      2 5
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                                7
+--R                                            8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  4   4        4      3 2    3
+--R                               - a b e  + (- 8a c + 4a b )d e
+--R                             + 
+--R                                   3        2 3  2 2
+--R                               (18a b c - 6a b )d e
+--R                             + 
+--R                                  3 2      2 2        4  3
+--R                               (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )d
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                      7   10     6       9        6 2      5 2   2 8
+--R                     a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                   + 
+--R                        5   2      4 3   3 7         5 3      3 4   4 6
+--R                     (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                   + 
+--R                         4   3      3 3 2      2 5   5 5
+--R                     (42a b c  - 21a b c  - 21a b c)d e
+--R                   + 
+--R                           4 4      3 2 3      2 4 2       6   6 4
+--R                     (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                   + 
+--R                         3   4      2 3 3        5 2    7   7 3
+--R                     (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                   + 
+--R                          3 5      2 2 4       4 3     6 2  8 2
+--R                     (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                   + 
+--R                      2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                   (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R                *
+--R                   x
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4|   |          2      4| |          2
+--R         a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               7 2        6 2        5 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                        4   4        4      3 2    3       3        2 3  2 2
+--R                     - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                   + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                            11 4   2          10 5 3
+--R                    (786432a  c d e  - 262144a  c d )
+--R                 *
+--R                    ROOT
+--R                              8 8     7     7       7       6 2  2 6
+--R                           - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                         + 
+--R                                 6         5 3  3 5
+--R                           (- 64a b c + 56a b )d e
+--R                         + 
+--R                                 6 2       5 2       4 4  4 4
+--R                           (- 38a c  + 142a b c - 70a b )d e
+--R                         + 
+--R                                5   2       4 3       3 5  5 3
+--R                           (104a b c  - 168a b c + 56a b )d e
+--R                         + 
+--R                               5 3       4 2 2       3 4       2 6  6 2
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  7
+--R                           (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                         + 
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                      /
+--R                                   13 3           12 2 2          11 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   10 6
+--R                           - 65536a  b
+--R                + 
+--R                       9 2      8      7  7
+--R                  (128a c  + 64a c + 8a )e
+--R                + 
+--R                          8 3        7 2        6        5  2 5
+--R                  (- 1152a c  - 3264a c  - 1416a c - 168a )d e
+--R                + 
+--R                        7 4         6 3        5 2        4        3  4 3
+--R                  (2432a c  + 10304a c  + 9176a c  + 2808a c + 280a )d e
+--R                + 
+--R                       6 5        5 4        4 3        3 2       2         6
+--R                (- 384a c  - 3776a c  - 5400a c  - 2912a c  - 672a c - 56a)d e
+--R             *
+--R                ROOT
+--R                                 7 2        6 2        5 4
+--R                         (- 4096a c  + 2048a b c - 256a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                          4   4        4      3 2    3       3        2 3  2 2
+--R                       - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                     + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                                11 2 3         10 4 2         9 6         8 8  3
+--R                        (131072a  b c  - 98304a  b c  + 24576a b c - 2048a b )e
+--R                      + 
+--R                                       10 3 3          9 5 2         8 7
+--R                              - 983040a  b c  + 442368a b c  - 86016a b c
+--R                            + 
+--R                                   7 9
+--R                              6144a b
+--R                       *
+--R                             2
+--R                          d e
+--R                      + 
+--R                                      10 2 4           9 4 3          8 6 2
+--R                            - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                          + 
+--R                                  7 8         6 10
+--R                            92160a b c - 6144a b
+--R                       *
+--R                           2
+--R                          d e
+--R                      + 
+--R                                   9 3 4          8 5 3          7 7 2
+--R                            720896a b c  - 573440a b c  + 200704a b c
+--R                          + 
+--R                                    6 9         5 11
+--R                            - 32768a b c + 2048a b
+--R                       *
+--R                           3
+--R                          d
+--R                   *
+--R                      ROOT
+--R                                8 8     7     7       7       6 2  2 6
+--R                             - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                           + 
+--R                                   6         5 3  3 5
+--R                             (- 64a b c + 56a b )d e
+--R                           + 
+--R                                   6 2       5 2       4 4  4 4
+--R                             (- 38a c  + 142a b c - 70a b )d e
+--R                           + 
+--R                                  5   2       4 3       3 5  5 3
+--R                             (104a b c  - 168a b c + 56a b )d e
+--R                           + 
+--R                                 5 3       4 2 2       3 4       2 6  6 2
+--R                             (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                           + 
+--R                                   4   3      3 3 2      2 5        7  7
+--R                             (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                           + 
+--R                                 4 4     3 2 3      2 4 2       6     8  8
+--R                             (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                        /
+--R                                     13 3           12 2 2          11 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     10 6
+--R                             - 65536a  b
+--R                  + 
+--R                         8 2       7       6    6
+--R                    (896a c  + 448a c + 56a )d e
+--R                  + 
+--R                            7 3        6 2        5        4  3 4
+--R                    (- 5120a c  - 7040a c  - 2560a c - 280a )d e
+--R                  + 
+--R                          6 4         5 3        4 2        3        2  5 2
+--R                    (4992a c  + 10560a c  + 7032a c  + 1848a c + 168a )d e
+--R                  + 
+--R                            5 2 5        4 4 4        3 6 3       2 8 2
+--R                        256a b c  - 1024a b c  + 1104a b c  - 504a b c
+--R                      + 
+--R                              10      12
+--R                        104a b  c - 8b
+--R                   *
+--R                       7
+--R                      d
+--R               *
+--R                  ROOT
+--R                                   7 2        6 2        5 4
+--R                           (- 4096a c  + 2048a b c - 256a b )
+--R                        *
+--R                           ROOT
+--R                                     8 8     7     7       7       6 2  2 6
+--R                                  - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                + 
+--R                                        6         5 3  3 5
+--R                                  (- 64a b c + 56a b )d e
+--R                                + 
+--R                                        6 2       5 2       4 4  4 4
+--R                                  (- 38a c  + 142a b c - 70a b )d e
+--R                                + 
+--R                                       5   2       4 3       3 5  5 3
+--R                                  (104a b c  - 168a b c + 56a b )d e
+--R                                + 
+--R                                      5 3       4 2 2       3 4       2 6  6 2
+--R                                  (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  7
+--R                                  (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  8
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                          13 3           12 2 2          11 4
+--R                                  4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                + 
+--R                                          10 6
+--R                                  - 65536a  b
+--R                       + 
+--R                            4   4        4      3 2    3       3        2 3  2 2
+--R                         - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                       + 
+--R                            3 2      2 2        4  3
+--R                         (8a c  - 16a b c + 4a b )d e
+--R                       + 
+--R                              2   2       3     5  4
+--R                         (- 5a b c  + 5a b c - b )d
+--R                    /
+--R                            7 2        6 2        5 4
+--R                       2048a c  - 1024a b c + 128a b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                        7 2        6 2        5 4
+--R                                (- 4096a c  + 2048a b c - 256a b )
+--R                             *
+--R                                ROOT
+--R                                          8 8     7     7       7       6 2  2 6
+--R                                       - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                     + 
+--R                                             6         5 3  3 5
+--R                                       (- 64a b c + 56a b )d e
+--R                                     + 
+--R                                             6 2       5 2       4 4  4 4
+--R                                       (- 38a c  + 142a b c - 70a b )d e
+--R                                     + 
+--R                                            5   2       4 3       3 5  5 3
+--R                                       (104a b c  - 168a b c + 56a b )d e
+--R                                     + 
+--R                                                5 3       4 2 2       3 4
+--R                                             12a c  - 112a b c  + 112a b c
+--R                                           + 
+--R                                                  2 6
+--R                                             - 28a b
+--R                                      *
+--R                                          6 2
+--R                                         d e
+--R                                     + 
+--R                                                  4   3      3 3 2      2 5
+--R                                             - 16a b c  + 56a b c  - 40a b c
+--R                                           + 
+--R                                                 7
+--R                                             8a b
+--R                                      *
+--R                                          7
+--R                                         d e
+--R                                     + 
+--R                                              4 4     3 2 3      2 4 2       6
+--R                                           - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                         + 
+--R                                              8
+--R                                           - b
+--R                                      *
+--R                                          8
+--R                                         d
+--R                                  /
+--R                                               13 3           12 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              11 4          10 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                 4   4        4      3 2    3
+--R                              - a b e  + (- 8a c + 4a b )d e
+--R                            + 
+--R                                  3        2 3  2 2
+--R                              (18a b c - 6a b )d e
+--R                            + 
+--R                                 3 2      2 2        4  3
+--R                              (8a c  - 16a b c + 4a b )d e
+--R                            + 
+--R                                   2   2       3     5  4
+--R                              (- 5a b c  + 5a b c - b )d
+--R                         /
+--R                                 7 2        6 2        5 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                       7   10     6       9      6 2      5 2   2 8
+--R                    - a c e   + 7a b c d e  + (3a c  - 21a b c)d e
+--R                  + 
+--R                         5   2      4 3   3 7       5 3      3 4   4 6
+--R                    (- 8a b c  + 35a b c)d e  + (14a c  - 35a b c)d e
+--R                  + 
+--R                          4   3      3 3 2      2 5   5 5
+--R                    (- 42a b c  + 21a b c  + 21a b c)d e
+--R                  + 
+--R                        4 4      3 2 3      2 4 2       6   6 4
+--R                    (14a c  + 42a b c  - 28a b c  - 7a b c)d e
+--R                  + 
+--R                          3   4      2 3 3        5 2    7   7 3
+--R                    (- 32a b c  - 11a b c  + 15a b c  + b c)d e
+--R                  + 
+--R                       3 5      2 2 4       4 3     6 2  8 2
+--R                    (3a c  + 24a b c  - 6a b c  - 3b c )d e
+--R                  + 
+--R                         2   5       3 4     5 3  9
+--R                    (- 5a b c  - 5a b c  + 3b c )d e
+--R                  + 
+--R                        2 6       2 5    4 4  10
+--R                    (- a c  + 3a b c  - b c )d
+--R               *
+--R                  x
+--R     + 
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              4+-+3 |          2 4|   |          2      4| |          2
+--R            a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  7 2        6 2        5 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8     7     7       7       6 2  2 6
+--R                                 - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                               + 
+--R                                       6         5 3  3 5
+--R                                 (- 64a b c + 56a b )d e
+--R                               + 
+--R                                       6 2       5 2       4 4  4 4
+--R                                 (- 38a c  + 142a b c - 70a b )d e
+--R                               + 
+--R                                      5   2       4 3       3 5  5 3
+--R                                 (104a b c  - 168a b c + 56a b )d e
+--R                               + 
+--R                                     5 3       4 2 2       3 4       2 6  6 2
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  7
+--R                                 (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           4   4        4      3 2    3       3        2 3  2 2
+--R                        - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                      + 
+--R                         3 2      2 2        4  3         2   2       3     5  4
+--R                      (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                               11 4   2          10 5 3
+--R                       (786432a  c d e  - 262144a  c d )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                          9 2      8      7  7
+--R                     (128a c  + 64a c + 8a )e
+--R                   + 
+--R                             8 3        7 2        6        5  2 5
+--R                     (- 1152a c  - 3264a c  - 1416a c - 168a )d e
+--R                   + 
+--R                           7 4         6 3        5 2        4        3  4 3
+--R                     (2432a c  + 10304a c  + 9176a c  + 2808a c + 280a )d e
+--R                   + 
+--R                                 6 5        5 4        4 3        3 2       2
+--R                           - 384a c  - 3776a c  - 5400a c  - 2912a c  - 672a c
+--R                         + 
+--R                           - 56a
+--R                    *
+--R                        6
+--R                       d e
+--R                *
+--R                   ROOT
+--R                                    7 2        6 2        5 4
+--R                            (- 4096a c  + 2048a b c - 256a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8     7     7       7       6 2  2 6
+--R                                   - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                 + 
+--R                                         6         5 3  3 5
+--R                                   (- 64a b c + 56a b )d e
+--R                                 + 
+--R                                         6 2       5 2       4 4  4 4
+--R                                   (- 38a c  + 142a b c - 70a b )d e
+--R                                 + 
+--R                                        5   2       4 3       3 5  5 3
+--R                                   (104a b c  - 168a b c + 56a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2       3 4       2 6  6 2
+--R                                   (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  7
+--R                                   (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                 + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                             4   4        4      3 2    3
+--R                          - a b e  + (- 8a c + 4a b )d e
+--R                        + 
+--R                              3        2 3  2 2      3 2      2 2        4  3
+--R                          (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                        + 
+--R                               2   2       3     5  4
+--R                          (- 5a b c  + 5a b c - b )d
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         7 2        6 2        5 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8     7     7
+--R                                        - a e  + 8a b d e
+--R                                      + 
+--R                                            7       6 2  2 6
+--R                                        (12a c - 28a b )d e
+--R                                      + 
+--R                                              6         5 3  3 5
+--R                                        (- 64a b c + 56a b )d e
+--R                                      + 
+--R                                              6 2       5 2       4 4  4 4
+--R                                        (- 38a c  + 142a b c - 70a b )d e
+--R                                      + 
+--R                                             5   2       4 3       3 5  5 3
+--R                                        (104a b c  - 168a b c + 56a b )d e
+--R                                      + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 4   3      3 3 2      2 5
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                                7
+--R                                            8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  4   4        4      3 2    3
+--R                               - a b e  + (- 8a c + 4a b )d e
+--R                             + 
+--R                                   3        2 3  2 2
+--R                               (18a b c - 6a b )d e
+--R                             + 
+--R                                  3 2      2 2        4  3
+--R                               (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )d
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                      11 2 3         10 4 2         9 6
+--R                               131072a  b c  - 98304a  b c  + 24576a b c
+--R                             + 
+--R                                      8 8
+--R                               - 2048a b
+--R                          *
+--R                              3
+--R                             e
+--R                         + 
+--R                                        10 3 3          9 5 2         8 7
+--R                               - 983040a  b c  + 442368a b c  - 86016a b c
+--R                             + 
+--R                                    7 9
+--R                               6144a b
+--R                          *
+--R                                2
+--R                             d e
+--R                         + 
+--R                                         10 2 4           9 4 3          8 6 2
+--R                               - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                             + 
+--R                                     7 8         6 10
+--R                               92160a b c - 6144a b
+--R                          *
+--R                              2
+--R                             d e
+--R                         + 
+--R                                      9 3 4          8 5 3          7 7 2
+--R                               720896a b c  - 573440a b c  + 200704a b c
+--R                             + 
+--R                                       6 9         5 11
+--R                               - 32768a b c + 2048a b
+--R                          *
+--R                              3
+--R                             d
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                            8 2       7       6    6
+--R                       (896a c  + 448a c + 56a )d e
+--R                     + 
+--R                               7 3        6 2        5        4  3 4
+--R                       (- 5120a c  - 7040a c  - 2560a c - 280a )d e
+--R                     + 
+--R                             6 4         5 3        4 2        3        2  5 2
+--R                       (4992a c  + 10560a c  + 7032a c  + 1848a c + 168a )d e
+--R                     + 
+--R                               5 2 5        4 4 4        3 6 3       2 8 2
+--R                           256a b c  - 1024a b c  + 1104a b c  - 504a b c
+--R                         + 
+--R                                 10      12
+--R                           104a b  c - 8b
+--R                      *
+--R                          7
+--R                         d
+--R                  *
+--R                     ROOT
+--R                                      7 2        6 2        5 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                           7 2        6 2        5 4
+--R                                   (- 4096a c  + 2048a b c - 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             8 8     7     7
+--R                                          - a e  + 8a b d e
+--R                                        + 
+--R                                              7       6 2  2 6
+--R                                          (12a c - 28a b )d e
+--R                                        + 
+--R                                                6         5 3  3 5
+--R                                          (- 64a b c + 56a b )d e
+--R                                        + 
+--R                                                6 2       5 2       4 4  4 4
+--R                                          (- 38a c  + 142a b c - 70a b )d e
+--R                                        + 
+--R                                               5   2       4 3       3 5  5 3
+--R                                          (104a b c  - 168a b c + 56a b )d e
+--R                                        + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                         *
+--R                                             6 2
+--R                                            d e
+--R                                        + 
+--R                                                   4   3      3 3 2      2 5
+--R                                              - 16a b c  + 56a b c  - 40a b c
+--R                                            + 
+--R                                                  7
+--R                                              8a b
+--R                                         *
+--R                                             7
+--R                                            d e
+--R                                        + 
+--R                                                 4 4     3 2 3      2 4 2
+--R                                              - a c  + 6a b c  - 11a b c
+--R                                            + 
+--R                                                  6     8
+--R                                              6a b c - b
+--R                                         *
+--R                                             8
+--R                                            d
+--R                                     /
+--R                                                  13 3           12 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 11 4          10 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                    4   4        4      3 2    3
+--R                                 - a b e  + (- 8a c + 4a b )d e
+--R                               + 
+--R                                     3        2 3  2 2
+--R                                 (18a b c - 6a b )d e
+--R                               + 
+--R                                    3 2      2 2        4  3
+--R                                 (8a c  - 16a b c + 4a b )d e
+--R                               + 
+--R                                      2   2       3     5  4
+--R                                 (- 5a b c  + 5a b c - b )d
+--R                            /
+--R                                    7 2        6 2        5 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                        7   10     6       9        6 2      5 2   2 8
+--R                       a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                     + 
+--R                          5   2      4 3   3 7         5 3      3 4   4 6
+--R                       (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                     + 
+--R                           4   3      3 3 2      2 5   5 5
+--R                       (42a b c  - 21a b c  - 21a b c)d e
+--R                     + 
+--R                             4 4      3 2 3      2 4 2       6   6 4
+--R                       (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                     + 
+--R                           3   4      2 3 3        5 2    7   7 3
+--R                       (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                     + 
+--R                            3 5      2 2 4       4 3     6 2  8 2
+--R                       (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                     + 
+--R                        2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                     (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R                  *
+--R                     x
+--R     + 
+--R       -
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R              4+-+3 |          2 4|   |          2      4| |          2
+--R            a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                7 2        6 2        5 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                    8 8     7     7       7       6 2  2 6
+--R                                 - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                               + 
+--R                                       6         5 3  3 5
+--R                                 (- 64a b c + 56a b )d e
+--R                               + 
+--R                                       6 2       5 2       4 4  4 4
+--R                                 (- 38a c  + 142a b c - 70a b )d e
+--R                               + 
+--R                                      5   2       4 3       3 5  5 3
+--R                                 (104a b c  - 168a b c + 56a b )d e
+--R                               + 
+--R                                     5 3       4 2 2       3 4       2 6  6 2
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                       4   3      3 3 2      2 5        7  7
+--R                                 (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                               + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                            /
+--R                                         13 3           12 2 2          11 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         10 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           4   4        4      3 2    3       3        2 3  2 2
+--R                        - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                      + 
+--R                         3 2      2 2        4  3         2   2       3     5  4
+--R                      (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                   /
+--R                           7 2        6 2        5 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                               11 4   2          10 5 3
+--R                       (786432a  c d e  - 262144a  c d )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                            9 2      8      7  7
+--R                     (- 128a c  - 64a c - 8a )e
+--R                   + 
+--R                           8 3        7 2        6        5  2 5
+--R                     (1152a c  + 3264a c  + 1416a c + 168a )d e
+--R                   + 
+--R                             7 4         6 3        5 2        4        3  4 3
+--R                     (- 2432a c  - 10304a c  - 9176a c  - 2808a c - 280a )d e
+--R                   + 
+--R                        6 5        5 4        4 3        3 2       2         6
+--R                   (384a c  + 3776a c  + 5400a c  + 2912a c  + 672a c + 56a)d e
+--R                *
+--R                   ROOT
+--R                                  7 2        6 2        5 4
+--R                            (4096a c  - 2048a b c + 256a b )
+--R                         *
+--R                            ROOT
+--R                                      8 8     7     7       7       6 2  2 6
+--R                                   - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                 + 
+--R                                         6         5 3  3 5
+--R                                   (- 64a b c + 56a b )d e
+--R                                 + 
+--R                                         6 2       5 2       4 4  4 4
+--R                                   (- 38a c  + 142a b c - 70a b )d e
+--R                                 + 
+--R                                        5   2       4 3       3 5  5 3
+--R                                   (104a b c  - 168a b c + 56a b )d e
+--R                                 + 
+--R                                       5 3       4 2 2       3 4       2 6  6 2
+--R                                   (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                 + 
+--R                                         4   3      3 3 2      2 5        7  7
+--R                                   (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                 + 
+--R                                     4 4     3 2 3      2 4 2       6     8  8
+--R                                 (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                              /
+--R                                           13 3           12 2 2          11 4
+--R                                   4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                 + 
+--R                                           10 6
+--R                                   - 65536a  b
+--R                        + 
+--R                             4   4        4      3 2    3
+--R                          - a b e  + (- 8a c + 4a b )d e
+--R                        + 
+--R                              3        2 3  2 2      3 2      2 2        4  3
+--R                          (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                        + 
+--R                               2   2       3     5  4
+--R                          (- 5a b c  + 5a b c - b )d
+--R                     /
+--R                             7 2        6 2        5 4
+--R                        2048a c  - 1024a b c + 128a b
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       7 2        6 2        5 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                           8 8     7     7
+--R                                        - a e  + 8a b d e
+--R                                      + 
+--R                                            7       6 2  2 6
+--R                                        (12a c - 28a b )d e
+--R                                      + 
+--R                                              6         5 3  3 5
+--R                                        (- 64a b c + 56a b )d e
+--R                                      + 
+--R                                              6 2       5 2       4 4  4 4
+--R                                        (- 38a c  + 142a b c - 70a b )d e
+--R                                      + 
+--R                                             5   2       4 3       3 5  5 3
+--R                                        (104a b c  - 168a b c + 56a b )d e
+--R                                      + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 4   3      3 3 2      2 5
+--R                                            - 16a b c  + 56a b c  - 40a b c
+--R                                          + 
+--R                                                7
+--R                                            8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               4 4     3 2 3      2 4 2       6
+--R                                            - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                          + 
+--R                                               8
+--R                                            - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                13 3           12 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               11 4          10 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  4   4        4      3 2    3
+--R                               - a b e  + (- 8a c + 4a b )d e
+--R                             + 
+--R                                   3        2 3  2 2
+--R                               (18a b c - 6a b )d e
+--R                             + 
+--R                                  3 2      2 2        4  3
+--R                               (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                    2   2       3     5  4
+--R                               (- 5a b c  + 5a b c - b )d
+--R                          /
+--R                                  7 2        6 2        5 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                      11 2 3         10 4 2         9 6
+--R                               131072a  b c  - 98304a  b c  + 24576a b c
+--R                             + 
+--R                                      8 8
+--R                               - 2048a b
+--R                          *
+--R                              3
+--R                             e
+--R                         + 
+--R                                        10 3 3          9 5 2         8 7
+--R                               - 983040a  b c  + 442368a b c  - 86016a b c
+--R                             + 
+--R                                    7 9
+--R                               6144a b
+--R                          *
+--R                                2
+--R                             d e
+--R                         + 
+--R                                         10 2 4           9 4 3          8 6 2
+--R                               - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                             + 
+--R                                     7 8         6 10
+--R                               92160a b c - 6144a b
+--R                          *
+--R                              2
+--R                             d e
+--R                         + 
+--R                                      9 3 4          8 5 3          7 7 2
+--R                               720896a b c  - 573440a b c  + 200704a b c
+--R                             + 
+--R                                       6 9         5 11
+--R                               - 32768a b c + 2048a b
+--R                          *
+--R                              3
+--R                             d
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                              8 2       7       6    6
+--R                       (- 896a c  - 448a c - 56a )d e
+--R                     + 
+--R                             7 3        6 2        5        4  3 4
+--R                       (5120a c  + 7040a c  + 2560a c + 280a )d e
+--R                     + 
+--R                               6 4         5 3        4 2        3        2  5 2
+--R                       (- 4992a c  - 10560a c  - 7032a c  - 1848a c - 168a )d e
+--R                     + 
+--R                                 5 2 5        4 4 4        3 6 3       2 8 2
+--R                           - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                         + 
+--R                                   10      12
+--R                           - 104a b  c + 8b
+--R                      *
+--R                          7
+--R                         d
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         7 2        6 2        5 4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                             8 8     7     7
+--R                                          - a e  + 8a b d e
+--R                                        + 
+--R                                              7       6 2  2 6
+--R                                          (12a c - 28a b )d e
+--R                                        + 
+--R                                                6         5 3  3 5
+--R                                          (- 64a b c + 56a b )d e
+--R                                        + 
+--R                                                6 2       5 2       4 4  4 4
+--R                                          (- 38a c  + 142a b c - 70a b )d e
+--R                                        + 
+--R                                               5   2       4 3       3 5  5 3
+--R                                          (104a b c  - 168a b c + 56a b )d e
+--R                                        + 
+--R                                                 5 3       4 2 2       3 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   2 6
+--R                                              - 28a b
+--R                                         *
+--R                                             6 2
+--R                                            d e
+--R                                        + 
+--R                                                   4   3      3 3 2      2 5
+--R                                              - 16a b c  + 56a b c  - 40a b c
+--R                                            + 
+--R                                                  7
+--R                                              8a b
+--R                                         *
+--R                                             7
+--R                                            d e
+--R                                        + 
+--R                                                 4 4     3 2 3      2 4 2
+--R                                              - a c  + 6a b c  - 11a b c
+--R                                            + 
+--R                                                  6     8
+--R                                              6a b c - b
+--R                                         *
+--R                                             8
+--R                                            d
+--R                                     /
+--R                                                  13 3           12 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 11 4          10 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                    4   4        4      3 2    3
+--R                                 - a b e  + (- 8a c + 4a b )d e
+--R                               + 
+--R                                     3        2 3  2 2
+--R                                 (18a b c - 6a b )d e
+--R                               + 
+--R                                    3 2      2 2        4  3
+--R                                 (8a c  - 16a b c + 4a b )d e
+--R                               + 
+--R                                      2   2       3     5  4
+--R                                 (- 5a b c  + 5a b c - b )d
+--R                            /
+--R                                    7 2        6 2        5 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                          7   10     6       9      6 2      5 2   2 8
+--R                       - a c e   + 7a b c d e  + (3a c  - 21a b c)d e
+--R                     + 
+--R                            5   2      4 3   3 7       5 3      3 4   4 6
+--R                       (- 8a b c  + 35a b c)d e  + (14a c  - 35a b c)d e
+--R                     + 
+--R                             4   3      3 3 2      2 5   5 5
+--R                       (- 42a b c  + 21a b c  + 21a b c)d e
+--R                     + 
+--R                           4 4      3 2 3      2 4 2       6   6 4
+--R                       (14a c  + 42a b c  - 28a b c  - 7a b c)d e
+--R                     + 
+--R                             3   4      2 3 3        5 2    7   7 3
+--R                       (- 32a b c  - 11a b c  + 15a b c  + b c)d e
+--R                     + 
+--R                          3 5      2 2 4       4 3     6 2  8 2
+--R                       (3a c  + 24a b c  - 6a b c  - 3b c )d e
+--R                     + 
+--R                            2   5       3 4     5 3  9
+--R                       (- 5a b c  - 5a b c  + 3b c )d e
+--R                     + 
+--R                           2 6       2 5    4 4  10
+--R                       (- a c  + 3a b c  - b c )d
+--R                  *
+--R                     x
+--R     + 
+--R                               +--------------------+ +------------------+
+--R                 +-----------+ |   +-----------+      | +-----------+
+--R           4+-+3 |          2 4|   |          2      4| |          2
+--R         a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             7 2        6 2        5 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                 8 8     7     7       7       6 2  2 6
+--R                              - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                            + 
+--R                                    6         5 3  3 5
+--R                              (- 64a b c + 56a b )d e
+--R                            + 
+--R                                    6 2       5 2       4 4  4 4
+--R                              (- 38a c  + 142a b c - 70a b )d e
+--R                            + 
+--R                                   5   2       4 3       3 5  5 3
+--R                              (104a b c  - 168a b c + 56a b )d e
+--R                            + 
+--R                                  5 3       4 2 2       3 4       2 6  6 2
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                    4   3      3 3 2      2 5        7  7
+--R                              (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                            + 
+--R                                  4 4     3 2 3      2 4 2       6     8  8
+--R                              (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                         /
+--R                                      13 3           12 2 2          11 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      10 6
+--R                              - 65536a  b
+--R                   + 
+--R                        4   4        4      3 2    3       3        2 3  2 2
+--R                     - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                   + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                /
+--R                        7 2        6 2        5 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                            11 4   2          10 5 3
+--R                    (786432a  c d e  - 262144a  c d )
+--R                 *
+--R                    ROOT
+--R                              8 8     7     7       7       6 2  2 6
+--R                           - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                         + 
+--R                                 6         5 3  3 5
+--R                           (- 64a b c + 56a b )d e
+--R                         + 
+--R                                 6 2       5 2       4 4  4 4
+--R                           (- 38a c  + 142a b c - 70a b )d e
+--R                         + 
+--R                                5   2       4 3       3 5  5 3
+--R                           (104a b c  - 168a b c + 56a b )d e
+--R                         + 
+--R                               5 3       4 2 2       3 4       2 6  6 2
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                 4   3      3 3 2      2 5        7  7
+--R                           (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                         + 
+--R                               4 4     3 2 3      2 4 2       6     8  8
+--R                           (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                      /
+--R                                   13 3           12 2 2          11 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   10 6
+--R                           - 65536a  b
+--R                + 
+--R                         9 2      8      7  7
+--R                  (- 128a c  - 64a c - 8a )e
+--R                + 
+--R                        8 3        7 2        6        5  2 5
+--R                  (1152a c  + 3264a c  + 1416a c + 168a )d e
+--R                + 
+--R                          7 4         6 3        5 2        4        3  4 3
+--R                  (- 2432a c  - 10304a c  - 9176a c  - 2808a c - 280a )d e
+--R                + 
+--R                       6 5        5 4        4 3        3 2       2         6
+--R                  (384a c  + 3776a c  + 5400a c  + 2912a c  + 672a c + 56a)d e
+--R             *
+--R                ROOT
+--R                               7 2        6 2        5 4
+--R                         (4096a c  - 2048a b c + 256a b )
+--R                      *
+--R                         ROOT
+--R                                   8 8     7     7       7       6 2  2 6
+--R                                - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                              + 
+--R                                      6         5 3  3 5
+--R                                (- 64a b c + 56a b )d e
+--R                              + 
+--R                                      6 2       5 2       4 4  4 4
+--R                                (- 38a c  + 142a b c - 70a b )d e
+--R                              + 
+--R                                     5   2       4 3       3 5  5 3
+--R                                (104a b c  - 168a b c + 56a b )d e
+--R                              + 
+--R                                    5 3       4 2 2       3 4       2 6  6 2
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                      4   3      3 3 2      2 5        7  7
+--R                                (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                              + 
+--R                                    4 4     3 2 3      2 4 2       6     8  8
+--R                                (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                           /
+--R                                        13 3           12 2 2          11 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        10 6
+--R                                - 65536a  b
+--R                     + 
+--R                          4   4        4      3 2    3       3        2 3  2 2
+--R                       - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                     + 
+--R                        3 2      2 2        4  3         2   2       3     5  4
+--R                     (8a c  - 16a b c + 4a b )d e + (- 5a b c  + 5a b c - b )d
+--R                  /
+--R                          7 2        6 2        5 4
+--R                     2048a c  - 1024a b c + 128a b
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    7 2        6 2        5 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                        8 8     7     7       7       6 2  2 6
+--R                                     - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                   + 
+--R                                           6         5 3  3 5
+--R                                     (- 64a b c + 56a b )d e
+--R                                   + 
+--R                                           6 2       5 2       4 4  4 4
+--R                                     (- 38a c  + 142a b c - 70a b )d e
+--R                                   + 
+--R                                          5   2       4 3       3 5  5 3
+--R                                     (104a b c  - 168a b c + 56a b )d e
+--R                                   + 
+--R                                           5 3       4 2 2       3 4       2 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                             4   3      3 3 2      2 5        7
+--R                                       (- 16a b c  + 56a b c  - 40a b c + 8a b )
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                       4 4     3 2 3      2 4 2       6     8  8
+--R                                   (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                                /
+--R                                             13 3           12 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            11 4          10 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               4   4        4      3 2    3
+--R                            - a b e  + (- 8a c + 4a b )d e
+--R                          + 
+--R                                3        2 3  2 2      3 2      2 2        4  3
+--R                            (18a b c - 6a b )d e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                 2   2       3     5  4
+--R                            (- 5a b c  + 5a b c - b )d
+--R                       /
+--R                               7 2        6 2        5 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                                11 2 3         10 4 2         9 6         8 8  3
+--R                        (131072a  b c  - 98304a  b c  + 24576a b c - 2048a b )e
+--R                      + 
+--R                                       10 3 3          9 5 2         8 7
+--R                              - 983040a  b c  + 442368a b c  - 86016a b c
+--R                            + 
+--R                                   7 9
+--R                              6144a b
+--R                       *
+--R                             2
+--R                          d e
+--R                      + 
+--R                                      10 2 4           9 4 3          8 6 2
+--R                            - 1179648a  b c  + 1277952a b c  - 516096a b c
+--R                          + 
+--R                                  7 8         6 10
+--R                            92160a b c - 6144a b
+--R                       *
+--R                           2
+--R                          d e
+--R                      + 
+--R                                   9 3 4          8 5 3          7 7 2
+--R                            720896a b c  - 573440a b c  + 200704a b c
+--R                          + 
+--R                                    6 9         5 11
+--R                            - 32768a b c + 2048a b
+--R                       *
+--R                           3
+--R                          d
+--R                   *
+--R                      ROOT
+--R                                8 8     7     7       7       6 2  2 6
+--R                             - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                           + 
+--R                                   6         5 3  3 5
+--R                             (- 64a b c + 56a b )d e
+--R                           + 
+--R                                   6 2       5 2       4 4  4 4
+--R                             (- 38a c  + 142a b c - 70a b )d e
+--R                           + 
+--R                                  5   2       4 3       3 5  5 3
+--R                             (104a b c  - 168a b c + 56a b )d e
+--R                           + 
+--R                                 5 3       4 2 2       3 4       2 6  6 2
+--R                             (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                           + 
+--R                                   4   3      3 3 2      2 5        7  7
+--R                             (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                           + 
+--R                                 4 4     3 2 3      2 4 2       6     8  8
+--R                             (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                        /
+--R                                     13 3           12 2 2          11 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     10 6
+--R                             - 65536a  b
+--R                  + 
+--R                           8 2       7       6    6
+--R                    (- 896a c  - 448a c - 56a )d e
+--R                  + 
+--R                          7 3        6 2        5        4  3 4
+--R                    (5120a c  + 7040a c  + 2560a c + 280a )d e
+--R                  + 
+--R                            6 4         5 3        4 2        3        2  5 2
+--R                    (- 4992a c  - 10560a c  - 7032a c  - 1848a c - 168a )d e
+--R                  + 
+--R                              5 2 5        4 4 4        3 6 3       2 8 2
+--R                        - 256a b c  + 1024a b c  - 1104a b c  + 504a b c
+--R                      + 
+--R                                10      12
+--R                        - 104a b  c + 8b
+--R                   *
+--R                       7
+--R                      d
+--R               *
+--R                  ROOT
+--R                                 7 2        6 2        5 4
+--R                           (4096a c  - 2048a b c + 256a b )
+--R                        *
+--R                           ROOT
+--R                                     8 8     7     7       7       6 2  2 6
+--R                                  - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                + 
+--R                                        6         5 3  3 5
+--R                                  (- 64a b c + 56a b )d e
+--R                                + 
+--R                                        6 2       5 2       4 4  4 4
+--R                                  (- 38a c  + 142a b c - 70a b )d e
+--R                                + 
+--R                                       5   2       4 3       3 5  5 3
+--R                                  (104a b c  - 168a b c + 56a b )d e
+--R                                + 
+--R                                      5 3       4 2 2       3 4       2 6  6 2
+--R                                  (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                                + 
+--R                                        4   3      3 3 2      2 5        7  7
+--R                                  (- 16a b c  + 56a b c  - 40a b c + 8a b )d e
+--R                                + 
+--R                                      4 4     3 2 3      2 4 2       6     8  8
+--R                                  (- a c  + 6a b c  - 11a b c  + 6a b c - b )d
+--R                             /
+--R                                          13 3           12 2 2          11 4
+--R                                  4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                                + 
+--R                                          10 6
+--R                                  - 65536a  b
+--R                       + 
+--R                            4   4        4      3 2    3       3        2 3  2 2
+--R                         - a b e  + (- 8a c + 4a b )d e  + (18a b c - 6a b )d e
+--R                       + 
+--R                            3 2      2 2        4  3
+--R                         (8a c  - 16a b c + 4a b )d e
+--R                       + 
+--R                              2   2       3     5  4
+--R                         (- 5a b c  + 5a b c - b )d
+--R                    /
+--R                            7 2        6 2        5 4
+--R                       2048a c  - 1024a b c + 128a b
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      7 2        6 2        5 4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                          8 8     7     7       7       6 2  2 6
+--R                                       - a e  + 8a b d e  + (12a c - 28a b )d e
+--R                                     + 
+--R                                             6         5 3  3 5
+--R                                       (- 64a b c + 56a b )d e
+--R                                     + 
+--R                                             6 2       5 2       4 4  4 4
+--R                                       (- 38a c  + 142a b c - 70a b )d e
+--R                                     + 
+--R                                            5   2       4 3       3 5  5 3
+--R                                       (104a b c  - 168a b c + 56a b )d e
+--R                                     + 
+--R                                                5 3       4 2 2       3 4
+--R                                             12a c  - 112a b c  + 112a b c
+--R                                           + 
+--R                                                  2 6
+--R                                             - 28a b
+--R                                      *
+--R                                          6 2
+--R                                         d e
+--R                                     + 
+--R                                                  4   3      3 3 2      2 5
+--R                                             - 16a b c  + 56a b c  - 40a b c
+--R                                           + 
+--R                                                 7
+--R                                             8a b
+--R                                      *
+--R                                          7
+--R                                         d e
+--R                                     + 
+--R                                              4 4     3 2 3      2 4 2       6
+--R                                           - a c  + 6a b c  - 11a b c  + 6a b c
+--R                                         + 
+--R                                              8
+--R                                           - b
+--R                                      *
+--R                                          8
+--R                                         d
+--R                                  /
+--R                                               13 3           12 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              11 4          10 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                 4   4        4      3 2    3
+--R                              - a b e  + (- 8a c + 4a b )d e
+--R                            + 
+--R                                  3        2 3  2 2
+--R                              (18a b c - 6a b )d e
+--R                            + 
+--R                                 3 2      2 2        4  3
+--R                              (8a c  - 16a b c + 4a b )d e
+--R                            + 
+--R                                   2   2       3     5  4
+--R                              (- 5a b c  + 5a b c - b )d
+--R                         /
+--R                                 7 2        6 2        5 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                     7   10     6       9        6 2      5 2   2 8
+--R                    a c e   - 7a b c d e  + (- 3a c  + 21a b c)d e
+--R                  + 
+--R                       5   2      4 3   3 7         5 3      3 4   4 6
+--R                    (8a b c  - 35a b c)d e  + (- 14a c  + 35a b c)d e
+--R                  + 
+--R                        4   3      3 3 2      2 5   5 5
+--R                    (42a b c  - 21a b c  - 21a b c)d e
+--R                  + 
+--R                          4 4      3 2 3      2 4 2       6   6 4
+--R                    (- 14a c  - 42a b c  + 28a b c  + 7a b c)d e
+--R                  + 
+--R                        3   4      2 3 3        5 2    7   7 3
+--R                    (32a b c  + 11a b c  - 15a b c  - b c)d e
+--R                  + 
+--R                         3 5      2 2 4       4 3     6 2  8 2
+--R                    (- 3a c  - 24a b c  + 6a b c  + 3b c )d e
+--R                  + 
+--R                       2   5       3 4     5 3  9      2 6       2 5    4 4  10
+--R                    (5a b c  + 5a b c  - 3b c )d e + (a c  - 3a b c  + b c )d
+--R               *
+--R                  x
+--R     + 
+--R                                              +------------------+
+--R              +-----------+                   | +-----------+
+--R              |          2               4+-+4| |          2
+--R         (- d\|- 4a c + b   - 2a e + b d)\|c \|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                              +--------------------+
+--R              +-----------+                   |   +-----------+
+--R              |          2               4+-+4|   |          2
+--R         (- d\|- 4a c + b   + 2a e - b d)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                            +------------------+
+--R            +-----------+                   | +-----------+
+--R            |          2               4+-+4| |          2
+--R         (d\|- 4a c + b   + 2a e - b d)\|c \|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                            +--------------------+
+--R            +-----------+                   |   +-----------+
+--R            |          2               4+-+4|   |          2
+--R         (d\|- 4a c + b   - 2a e + b d)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4|   |          2      4| |          2
+--R     2a \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 649
+--d0:=D(m0,x)
+--E 235
+
+)clear all
+
+--S 236 of 649
+t0:=(d+e*x^4)/(x^3*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 4
+--R              e x  + d
+--R   (1)  -------------------
+--R           11      7      3
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 236
+
+--S 237 of 649
+r0:=-1/2*d/(a*x^2)-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(a*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                     +------------------+
+--R                 +-----------+                       | +-----------+
+--R               2 |          2                 2  +-+ | |          2
+--R         (- d x \|- 4a c + b   + (2a e - b d)x )\|c \|\|- 4a c + b   + b
+--R      *
+--R                      2 +-+ +-+
+--R                     x \|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                       +--------------------+
+--R                 +-----------+                         |   +-----------+
+--R               2 |          2                   2  +-+ |   |          2
+--R         (- d x \|- 4a c + b   + (- 2a e + b d)x )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                     2 +-+ +-+
+--R                    x \|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R           +-+ |          2  |   |          2       | |          2
+--R       - d\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R         2 +-+ |          2  |   |          2       | |          2
+--R     2a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 237
+
+--S 238 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2
+--R         a x
+--R      *
+--R         ROOT
+--R                      4       3 2
+--R                  (64a c - 16a b )
+--R               *
+--R                  ROOT
+--R                            4 4     3     3      3      2 2  2 2
+--R                         - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                       + 
+--R                              2          3  3        2 2       2     4  4
+--R                         (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                    /
+--R                            7        6 2
+--R                       1024a c - 256a b
+--R              + 
+--R                 2   2      2        2                    3  2
+--R                a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R           /
+--R                 4      3 2
+--R              32a c - 8a b
+--R      *
+--R         log
+--R                         5         4 3          5 2      4 2       3 4
+--R                    ((64a b c - 16a b )e + (128a c  - 96a b c + 16a b )d)
+--R                 *
+--R                    ROOT
+--R                              4 4     3     3      3      2 2  2 2
+--R                           - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                         + 
+--R                                2          3  3        2 2       2     4  4
+--R                           (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                      /
+--R                              7        6 2
+--R                         1024a c - 256a b
+--R                + 
+--R                     4     3 2  3         3        2 3    2
+--R                  (4a c - a b )e  + (- 12a b c + 3a b )d e
+--R                + 
+--R                       3 2      2 2        4  2       2   2       3     5  3
+--R                  (- 4a c  + 13a b c - 3a b )d e + (4a b c  - 5a b c + b )d
+--R             *
+--R                ROOT
+--R                             4       3 2
+--R                         (64a c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                   4 4     3     3      3      2 2  2 2
+--R                                - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                              + 
+--R                                   2          3  3        2 2       2     4  4
+--R                              (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                           /
+--R                                   7        6 2
+--R                              1024a c - 256a b
+--R                     + 
+--R                        2   2      2        2                    3  2
+--R                       a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R                  /
+--R                        4      3 2
+--R                     32a c - 8a b
+--R            + 
+--R                   3   4     2       3       2   2 2           2    3   3
+--R                  a c e  - 3a b c d e  + 3a b c d e  + (- a b c  - b c)d e
+--R                + 
+--R                        3    2 2  4
+--R                  (- a c  + b c )d
+--R             *
+--R                 2
+--R                x
+--R     + 
+--R       -
+--R               2
+--R            a x
+--R         *
+--R            ROOT
+--R                           4       3 2
+--R                     (- 64a c + 16a b )
+--R                  *
+--R                     ROOT
+--R                               4 4     3     3      3      2 2  2 2
+--R                            - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                          + 
+--R                                 2          3  3        2 2       2     4  4
+--R                            (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                       /
+--R                               7        6 2
+--R                          1024a c - 256a b
+--R                 + 
+--R                    2   2      2        2                    3  2
+--R                   a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R              /
+--R                    4      3 2
+--R                 32a c - 8a b
+--R         *
+--R            log
+--R                            5         4 3          5 2      4 2       3 4
+--R                       ((64a b c - 16a b )e + (128a c  - 96a b c + 16a b )d)
+--R                    *
+--R                       ROOT
+--R                                 4 4     3     3      3      2 2  2 2
+--R                              - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                            + 
+--R                                   2          3  3        2 2       2     4  4
+--R                              (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                         /
+--R                                 7        6 2
+--R                            1024a c - 256a b
+--R                   + 
+--R                          4     3 2  3       3        2 3    2
+--R                     (- 4a c + a b )e  + (12a b c - 3a b )d e
+--R                   + 
+--R                        3 2      2 2        4  2         2   2       3     5  3
+--R                     (4a c  - 13a b c + 3a b )d e + (- 4a b c  + 5a b c - b )d
+--R                *
+--R                   ROOT
+--R                                  4       3 2
+--R                            (- 64a c + 16a b )
+--R                         *
+--R                            ROOT
+--R                                      4 4     3     3      3      2 2  2 2
+--R                                   - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                                 + 
+--R                                        2          3  3
+--R                                   (- 4a b c + 4a b )d e
+--R                                 + 
+--R                                       2 2       2     4  4
+--R                                   (- a c  + 2a b c - b )d
+--R                              /
+--R                                      7        6 2
+--R                                 1024a c - 256a b
+--R                        + 
+--R                           2   2      2        2                    3  2
+--R                          a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R                     /
+--R                           4      3 2
+--R                        32a c - 8a b
+--R               + 
+--R                      3   4     2       3       2   2 2           2    3   3
+--R                     a c e  - 3a b c d e  + 3a b c d e  + (- a b c  - b c)d e
+--R                   + 
+--R                           3    2 2  4
+--R                     (- a c  + b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R            2
+--R         a x
+--R      *
+--R         ROOT
+--R                        4       3 2
+--R                  (- 64a c + 16a b )
+--R               *
+--R                  ROOT
+--R                            4 4     3     3      3      2 2  2 2
+--R                         - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                       + 
+--R                              2          3  3        2 2       2     4  4
+--R                         (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                    /
+--R                            7        6 2
+--R                       1024a c - 256a b
+--R              + 
+--R                 2   2      2        2                    3  2
+--R                a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R           /
+--R                 4      3 2
+--R              32a c - 8a b
+--R      *
+--R         log
+--R                           5         4 3            5 2      4 2       3 4
+--R                    ((- 64a b c + 16a b )e + (- 128a c  + 96a b c - 16a b )d)
+--R                 *
+--R                    ROOT
+--R                              4 4     3     3      3      2 2  2 2
+--R                           - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                         + 
+--R                                2          3  3        2 2       2     4  4
+--R                           (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                      /
+--R                              7        6 2
+--R                         1024a c - 256a b
+--R                + 
+--R                     4     3 2  3         3        2 3    2
+--R                  (4a c - a b )e  + (- 12a b c + 3a b )d e
+--R                + 
+--R                       3 2      2 2        4  2       2   2       3     5  3
+--R                  (- 4a c  + 13a b c - 3a b )d e + (4a b c  - 5a b c + b )d
+--R             *
+--R                ROOT
+--R                               4       3 2
+--R                         (- 64a c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                   4 4     3     3      3      2 2  2 2
+--R                                - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                              + 
+--R                                   2          3  3        2 2       2     4  4
+--R                              (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                           /
+--R                                   7        6 2
+--R                              1024a c - 256a b
+--R                     + 
+--R                        2   2      2        2                    3  2
+--R                       a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R                  /
+--R                        4      3 2
+--R                     32a c - 8a b
+--R            + 
+--R                   3   4     2       3       2   2 2           2    3   3
+--R                  a c e  - 3a b c d e  + 3a b c d e  + (- a b c  - b c)d e
+--R                + 
+--R                        3    2 2  4
+--R                  (- a c  + b c )d
+--R             *
+--R                 2
+--R                x
+--R     + 
+--R       -
+--R               2
+--R            a x
+--R         *
+--R            ROOT
+--R                         4       3 2
+--R                     (64a c - 16a b )
+--R                  *
+--R                     ROOT
+--R                               4 4     3     3      3      2 2  2 2
+--R                            - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                          + 
+--R                                 2          3  3        2 2       2     4  4
+--R                            (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                       /
+--R                               7        6 2
+--R                          1024a c - 256a b
+--R                 + 
+--R                    2   2      2        2                    3  2
+--R                   a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R              /
+--R                    4      3 2
+--R                 32a c - 8a b
+--R         *
+--R            log
+--R                              5         4 3            5 2      4 2       3 4
+--R                       ((- 64a b c + 16a b )e + (- 128a c  + 96a b c - 16a b )d)
+--R                    *
+--R                       ROOT
+--R                                 4 4     3     3      3      2 2  2 2
+--R                              - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                            + 
+--R                                   2          3  3        2 2       2     4  4
+--R                              (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                         /
+--R                                 7        6 2
+--R                            1024a c - 256a b
+--R                   + 
+--R                          4     3 2  3       3        2 3    2
+--R                     (- 4a c + a b )e  + (12a b c - 3a b )d e
+--R                   + 
+--R                        3 2      2 2        4  2         2   2       3     5  3
+--R                     (4a c  - 13a b c + 3a b )d e + (- 4a b c  + 5a b c - b )d
+--R                *
+--R                   ROOT
+--R                                4       3 2
+--R                            (64a c - 16a b )
+--R                         *
+--R                            ROOT
+--R                                      4 4     3     3      3      2 2  2 2
+--R                                   - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                                 + 
+--R                                        2          3  3
+--R                                   (- 4a b c + 4a b )d e
+--R                                 + 
+--R                                       2 2       2     4  4
+--R                                   (- a c  + 2a b c - b )d
+--R                              /
+--R                                      7        6 2
+--R                                 1024a c - 256a b
+--R                        + 
+--R                           2   2      2        2                    3  2
+--R                          a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R                     /
+--R                           4      3 2
+--R                        32a c - 8a b
+--R               + 
+--R                      3   4     2       3       2   2 2           2    3   3
+--R                     a c e  - 3a b c d e  + 3a b c d e  + (- a b c  - b c)d e
+--R                   + 
+--R                           3    2 2  4
+--R                     (- a c  + b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R       - d
+--R  /
+--R         2
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 238
+
+--S 239 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +--------------------+
+--R               +-----------+ |   +-----------+
+--R           +-+ |          2  |   |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                      4       3 2
+--R                  (64a c - 16a b )
+--R               *
+--R                  ROOT
+--R                            4 4     3     3      3      2 2  2 2
+--R                         - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                       + 
+--R                              2          3  3        2 2       2     4  4
+--R                         (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                    /
+--R                            7        6 2
+--R                       1024a c - 256a b
+--R              + 
+--R                 2   2      2        2                    3  2
+--R                a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R           /
+--R                 4      3 2
+--R              32a c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                         5         4 3          5 2      4 2       3 4
+--R                    ((64a b c - 16a b )e + (128a c  - 96a b c + 16a b )d)
+--R                 *
+--R                    ROOT
+--R                              4 4     3     3      3      2 2  2 2
+--R                           - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                         + 
+--R                                2          3  3        2 2       2     4  4
+--R                           (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                      /
+--R                              7        6 2
+--R                         1024a c - 256a b
+--R                + 
+--R                     4     3 2  3         3        2 3    2
+--R                  (4a c - a b )e  + (- 12a b c + 3a b )d e
+--R                + 
+--R                       3 2      2 2        4  2       2   2       3     5  3
+--R                  (- 4a c  + 13a b c - 3a b )d e + (4a b c  - 5a b c + b )d
+--R             *
+--R                ROOT
+--R                             4       3 2
+--R                         (64a c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                   4 4     3     3      3      2 2  2 2
+--R                                - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                              + 
+--R                                   2          3  3        2 2       2     4  4
+--R                              (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                           /
+--R                                   7        6 2
+--R                              1024a c - 256a b
+--R                     + 
+--R                        2   2      2        2                    3  2
+--R                       a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R                  /
+--R                        4      3 2
+--R                     32a c - 8a b
+--R            + 
+--R                   3   4     2       3       2   2 2           2    3   3
+--R                  a c e  - 3a b c d e  + 3a b c d e  + (- a b c  - b c)d e
+--R                + 
+--R                        3    2 2  4
+--R                  (- a c  + b c )d
+--R             *
+--R                 2
+--R                x
+--R     + 
+--R       -
+--R                                +--------------------+
+--R                  +-----------+ |   +-----------+
+--R              +-+ |          2  |   |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                           4       3 2
+--R                     (- 64a c + 16a b )
+--R                  *
+--R                     ROOT
+--R                               4 4     3     3      3      2 2  2 2
+--R                            - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                          + 
+--R                                 2          3  3        2 2       2     4  4
+--R                            (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                       /
+--R                               7        6 2
+--R                          1024a c - 256a b
+--R                 + 
+--R                    2   2      2        2                    3  2
+--R                   a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R              /
+--R                    4      3 2
+--R                 32a c - 8a b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                            5         4 3          5 2      4 2       3 4
+--R                       ((64a b c - 16a b )e + (128a c  - 96a b c + 16a b )d)
+--R                    *
+--R                       ROOT
+--R                                 4 4     3     3      3      2 2  2 2
+--R                              - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                            + 
+--R                                   2          3  3        2 2       2     4  4
+--R                              (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                         /
+--R                                 7        6 2
+--R                            1024a c - 256a b
+--R                   + 
+--R                          4     3 2  3       3        2 3    2
+--R                     (- 4a c + a b )e  + (12a b c - 3a b )d e
+--R                   + 
+--R                        3 2      2 2        4  2         2   2       3     5  3
+--R                     (4a c  - 13a b c + 3a b )d e + (- 4a b c  + 5a b c - b )d
+--R                *
+--R                   ROOT
+--R                                  4       3 2
+--R                            (- 64a c + 16a b )
+--R                         *
+--R                            ROOT
+--R                                      4 4     3     3      3      2 2  2 2
+--R                                   - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                                 + 
+--R                                        2          3  3
+--R                                   (- 4a b c + 4a b )d e
+--R                                 + 
+--R                                       2 2       2     4  4
+--R                                   (- a c  + 2a b c - b )d
+--R                              /
+--R                                      7        6 2
+--R                                 1024a c - 256a b
+--R                        + 
+--R                           2   2      2        2                    3  2
+--R                          a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R                     /
+--R                           4      3 2
+--R                        32a c - 8a b
+--R               + 
+--R                      3   4     2       3       2   2 2           2    3   3
+--R                     a c e  - 3a b c d e  + 3a b c d e  + (- a b c  - b c)d e
+--R                   + 
+--R                           3    2 2  4
+--R                     (- a c  + b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                             +--------------------+
+--R               +-----------+ |   +-----------+
+--R           +-+ |          2  |   |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4       3 2
+--R                  (- 64a c + 16a b )
+--R               *
+--R                  ROOT
+--R                            4 4     3     3      3      2 2  2 2
+--R                         - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                       + 
+--R                              2          3  3        2 2       2     4  4
+--R                         (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                    /
+--R                            7        6 2
+--R                       1024a c - 256a b
+--R              + 
+--R                 2   2      2        2                    3  2
+--R                a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R           /
+--R                 4      3 2
+--R              32a c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                           5         4 3            5 2      4 2       3 4
+--R                    ((- 64a b c + 16a b )e + (- 128a c  + 96a b c - 16a b )d)
+--R                 *
+--R                    ROOT
+--R                              4 4     3     3      3      2 2  2 2
+--R                           - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                         + 
+--R                                2          3  3        2 2       2     4  4
+--R                           (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                      /
+--R                              7        6 2
+--R                         1024a c - 256a b
+--R                + 
+--R                     4     3 2  3         3        2 3    2
+--R                  (4a c - a b )e  + (- 12a b c + 3a b )d e
+--R                + 
+--R                       3 2      2 2        4  2       2   2       3     5  3
+--R                  (- 4a c  + 13a b c - 3a b )d e + (4a b c  - 5a b c + b )d
+--R             *
+--R                ROOT
+--R                               4       3 2
+--R                         (- 64a c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                   4 4     3     3      3      2 2  2 2
+--R                                - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                              + 
+--R                                   2          3  3        2 2       2     4  4
+--R                              (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                           /
+--R                                   7        6 2
+--R                              1024a c - 256a b
+--R                     + 
+--R                        2   2      2        2                    3  2
+--R                       a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R                  /
+--R                        4      3 2
+--R                     32a c - 8a b
+--R            + 
+--R                   3   4     2       3       2   2 2           2    3   3
+--R                  a c e  - 3a b c d e  + 3a b c d e  + (- a b c  - b c)d e
+--R                + 
+--R                        3    2 2  4
+--R                  (- a c  + b c )d
+--R             *
+--R                 2
+--R                x
+--R     + 
+--R       -
+--R                                +--------------------+
+--R                  +-----------+ |   +-----------+
+--R              +-+ |          2  |   |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                         4       3 2
+--R                     (64a c - 16a b )
+--R                  *
+--R                     ROOT
+--R                               4 4     3     3      3      2 2  2 2
+--R                            - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                          + 
+--R                                 2          3  3        2 2       2     4  4
+--R                            (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                       /
+--R                               7        6 2
+--R                          1024a c - 256a b
+--R                 + 
+--R                    2   2      2        2                    3  2
+--R                   a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R              /
+--R                    4      3 2
+--R                 32a c - 8a b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                              5         4 3            5 2      4 2       3 4
+--R                       ((- 64a b c + 16a b )e + (- 128a c  + 96a b c - 16a b )d)
+--R                    *
+--R                       ROOT
+--R                                 4 4     3     3      3      2 2  2 2
+--R                              - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                            + 
+--R                                   2          3  3        2 2       2     4  4
+--R                              (- 4a b c + 4a b )d e + (- a c  + 2a b c - b )d
+--R                         /
+--R                                 7        6 2
+--R                            1024a c - 256a b
+--R                   + 
+--R                          4     3 2  3       3        2 3    2
+--R                     (- 4a c + a b )e  + (12a b c - 3a b )d e
+--R                   + 
+--R                        3 2      2 2        4  2         2   2       3     5  3
+--R                     (4a c  - 13a b c + 3a b )d e + (- 4a b c  + 5a b c - b )d
+--R                *
+--R                   ROOT
+--R                                4       3 2
+--R                            (64a c - 16a b )
+--R                         *
+--R                            ROOT
+--R                                      4 4     3     3      3      2 2  2 2
+--R                                   - a e  + 4a b d e  + (2a c - 6a b )d e
+--R                                 + 
+--R                                        2          3  3
+--R                                   (- 4a b c + 4a b )d e
+--R                                 + 
+--R                                       2 2       2     4  4
+--R                                   (- a c  + 2a b c - b )d
+--R                              /
+--R                                      7        6 2
+--R                                 1024a c - 256a b
+--R                        + 
+--R                           2   2      2        2                    3  2
+--R                          a b e  + (4a c - 2a b )d e + (- 3a b c + b )d
+--R                     /
+--R                           4      3 2
+--R                        32a c - 8a b
+--R               + 
+--R                      3   4     2       3       2   2 2           2    3   3
+--R                     a c e  - 3a b c d e  + 3a b c d e  + (- a b c  - b c)d e
+--R                   + 
+--R                           3    2 2  4
+--R                     (- a c  + b c )d
+--R                *
+--R                    2
+--R                   x
+--R     + 
+--R                                            +------------------+
+--R            +-----------+                   | +-----------+
+--R            |          2                +-+ | |          2
+--R         (d\|- 4a c + b   - 2a e + b d)\|c \|\|- 4a c + b   + b
+--R      *
+--R                      2 +-+ +-+
+--R                     x \|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R            +-----------+                   |   +-----------+
+--R            |          2                +-+ |   |          2
+--R         (d\|- 4a c + b   + 2a e - b d)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                     2 +-+ +-+
+--R                    x \|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R     2a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 649
+t0:=(d+e*x^4)/(x^4*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 4
+--R              e x  + d
+--R   (1)  -------------------
+--R           12      8      4
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 241
+
+--S 242 of 649
+r0:=-1/3*d/(a*x^3)+1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))+1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(-b-sqrt(b^2-4*a*c))^(3/4))+1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(3/4))+1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                                       +------------------+3
+--R                +-----------+                          | +-----------+
+--R              3 |          2                  3 4+-+3 4| |          2
+--R         (3d x \|- 4a c + b   + (6a e - 3b d)x )\|c   \|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                         +--------------------+3
+--R                +-----------+                            |   +-----------+
+--R              3 |          2                    3 4+-+3 4|   |          2
+--R         (3d x \|- 4a c + b   + (- 6a e + 3b d)x )\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                                       +------------------+3
+--R                +-----------+                          | +-----------+
+--R              3 |          2                  3 4+-+3 4| |          2
+--R         (3d x \|- 4a c + b   + (6a e - 3b d)x )\|c   \|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                                         +--------------------+3
+--R                +-----------+                            |   +-----------+
+--R              3 |          2                    3 4+-+3 4|   |          2
+--R         (3d x \|- 4a c + b   + (- 6a e + 3b d)x )\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                              +--------------------+3  +------------------+3
+--R                +-----------+ |   +-----------+        | +-----------+
+--R           4+-+ |          2 4|   |          2        4| |          2
+--R       - 2d\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+3  +------------------+3
+--R                +-----------+ |   +-----------+        | +-----------+
+--R         3 4+-+ |          2 4|   |          2        4| |          2
+--R     6a x  \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3
+--R         3a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             9 2        8 2        7 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                        5       4 3  4      5 2      4 2      3 4    3
+--R                     (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                   + 
+--R                           4   2      3 3      2 5  2 2
+--R                     (- 30a b c  + 30a b c - 6a b )d e
+--R                   + 
+--R                          4 3      3 2 2      2 4        6  3
+--R                     (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                   + 
+--R                        3   3      2 3 2       5     7  4
+--R                     (7a b c  - 14a b c  + 7a b c - b )d
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                            10   2        9 3        8 5
+--R                      (4096a  b c  - 2048a b c + 256a b )e
+--R                    + 
+--R                            10 3        9 2 2        8 4        7 6
+--R                      (8192a  c  - 8192a b c  + 2560a b c - 256a b )d
+--R                 *
+--R                    ROOT
+--R                               10 2     9 2     8 4  8
+--R                           (- a  c  + 2a b c - a b )e
+--R                         + 
+--R                               9   2      8 3      7 5    7
+--R                           (16a b c  - 24a b c + 8a b )d e
+--R                         + 
+--R                               9 3       8 2 2       7 4       6 6  2 6
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                  8   3       7 3 2       6 5       5 7  3 5
+--R                           (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                         + 
+--R                                    8 4       7 2 3       6 4 2       5 6
+--R                               - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                             + 
+--R                                    4 8
+--R                               - 70a b
+--R                          *
+--R                              4 4
+--R                             d e
+--R                         + 
+--R                                   7   4       6 3 3       5 5 2       4 7
+--R                               160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                             + 
+--R                                  3 9
+--R                               56a b
+--R                          *
+--R                              5 3
+--R                             d e
+--R                         + 
+--R                                  7 5       6 2 4       5 4 3       4 6 2
+--R                               12a c  - 252a b c  + 672a b c  - 616a b c
+--R                             + 
+--R                                   3 8       2 10
+--R                               224a b c - 28a b
+--R                          *
+--R                              6 2
+--R                             d e
+--R                         + 
+--R                                    6   5       5 3 4       4 5 3       3 7 2
+--R                               - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                             + 
+--R                                    2 9        11
+--R                               - 72a b c + 8a b
+--R                          *
+--R                              7
+--R                             d e
+--R                         + 
+--R                                  6 6      5 2 5      4 4 4      3 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    2 8 2        10     12
+--R                               - 37a b c  + 10a b  c - b
+--R                          *
+--R                              8
+--R                             d
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                     7 2     6 2     5 4  5         6   2      5 3      4 5    4
+--R                  (4a c  - 5a b c + a b )e  + (- 36a b c  + 29a b c - 5a b )d e
+--R                + 
+--R                        6 3       5 2 2      4 4       3 6  2 3
+--R                  (- 24a c  + 110a b c  - 66a b c + 10a b )d e
+--R                + 
+--R                      5   3       4 3 2      3 5       2 7  3 2
+--R                  (72a b c  - 154a b c  + 74a b c - 10a b )d e
+--R                + 
+--R                     5 4      4 2 3       3 4 2      2 6        8  4
+--R                  (4a c  - 73a b c  + 102a b c  - 41a b c + 5a b )d e
+--R                + 
+--R                       4   4      3 3 3      2 5 2       7     9  5
+--R                  (- 4a b c  + 25a b c  - 26a b c  + 9a b c - b )d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    9 2        8 2        7 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                         10 2     9 2     8 4  8
+--R                                     (- a  c  + 2a b c - a b )e
+--R                                   + 
+--R                                         9   2      8 3      7 5    7
+--R                                     (16a b c  - 24a b c + 8a b )d e
+--R                                   + 
+--R                                           9 3       8 2 2       7 4       6 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                               8   3       7 3 2       6 5
+--R                                         - 120a b c  + 392a b c  - 280a b c
+--R                                       + 
+--R                                            5 7
+--R                                         56a b
+--R                                    *
+--R                                        3 5
+--R                                       d e
+--R                                   + 
+--R                                              8 4       7 2 3       6 4 2
+--R                                         - 38a c  + 422a b c  - 770a b c
+--R                                       + 
+--R                                             5 6       4 8
+--R                                         420a b c - 70a b
+--R                                    *
+--R                                        4 4
+--R                                       d e
+--R                                   + 
+--R                                             7   4       6 3 3       5 5 2
+--R                                         160a b c  - 728a b c  + 896a b c
+--R                                       + 
+--R                                               4 7       3 9
+--R                                         - 392a b c + 56a b
+--R                                    *
+--R                                        5 3
+--R                                       d e
+--R                                   + 
+--R                                            7 5       6 2 4       5 4 3
+--R                                         12a c  - 252a b c  + 672a b c
+--R                                       + 
+--R                                               4 6 2       3 8       2 10
+--R                                         - 616a b c  + 224a b c - 28a b
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                              6   5       5 3 4       4 5 3
+--R                                         - 24a b c  + 176a b c  - 320a b c
+--R                                       + 
+--R                                             3 7 2      2 9        11
+--R                                         232a b c  - 72a b c + 8a b
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                            6 6      5 2 5      4 4 4      3 6 3
+--R                                         - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                       + 
+--R                                              2 8 2        10     12
+--R                                         - 37a b c  + 10a b  c - b
+--R                                    *
+--R                                        8
+--R                                       d
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               5       4 3  4      5 2      4 2      3 4    3
+--R                            (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 30a b c  + 30a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (7a b c  - 14a b c  + 7a b c - b )d
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                    6 2    5 2   6        5   2     4 3     5
+--R                  (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                + 
+--R                       5 3      4 2 2      3 4   2 4
+--R                  (- 5a c  + 25a b c  - 10a b c)d e
+--R                + 
+--R                      4   3      3 3 2      2 5   3 3
+--R                  (10a b c  - 30a b c  + 10a b c)d e
+--R                + 
+--R                       4 4      2 4 2       6   4 2
+--R                  (- 5a c  + 15a b c  - 5a b c)d e
+--R                + 
+--R                      3   4      2 3 3      5 2    7   5
+--R                  (11a b c  - 10a b c  - a b c  + b c)d e
+--R                + 
+--R                    3 5     2 2 4       4 3    6 2  6
+--R                  (a c  - 6a b c  + 5a b c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                3
+--R            3a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  9 2        8 2        7 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                     10 2     9 2     8 4  8
+--R                                 (- a  c  + 2a b c - a b )e
+--R                               + 
+--R                                     9   2      8 3      7 5    7
+--R                                 (16a b c  - 24a b c + 8a b )d e
+--R                               + 
+--R                                     9 3       8 2 2       7 4       6 6  2 6
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                          8   3       7 3 2       6 5       5 7
+--R                                   (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                                *
+--R                                    3 5
+--R                                   d e
+--R                               + 
+--R                                          8 4       7 2 3       6 4 2       5 6
+--R                                     - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                   + 
+--R                                          4 8
+--R                                     - 70a b
+--R                                *
+--R                                    4 4
+--R                                   d e
+--R                               + 
+--R                                         7   4       6 3 3       5 5 2
+--R                                     160a b c  - 728a b c  + 896a b c
+--R                                   + 
+--R                                           4 7       3 9
+--R                                     - 392a b c + 56a b
+--R                                *
+--R                                    5 3
+--R                                   d e
+--R                               + 
+--R                                        7 5       6 2 4       5 4 3       4 6 2
+--R                                     12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                   + 
+--R                                         3 8       2 10
+--R                                     224a b c - 28a b
+--R                                *
+--R                                    6 2
+--R                                   d e
+--R                               + 
+--R                                          6   5       5 3 4       4 5 3
+--R                                     - 24a b c  + 176a b c  - 320a b c
+--R                                   + 
+--R                                         3 7 2      2 9        11
+--R                                     232a b c  - 72a b c + 8a b
+--R                                *
+--R                                    7
+--R                                   d e
+--R                               + 
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                *
+--R                                    8
+--R                                   d
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           5       4 3  4      5 2      4 2      3 4    3
+--R                        (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                      + 
+--R                              4   2      3 3      2 5  2 2
+--R                        (- 30a b c  + 30a b c - 6a b )d e
+--R                      + 
+--R                             4 3      3 2 2      2 4        6  3
+--R                        (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                      + 
+--R                           3   3      2 3 2       5     7  4
+--R                        (7a b c  - 14a b c  + 7a b c - b )d
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                               10   2        9 3        8 5
+--R                         (4096a  b c  - 2048a b c + 256a b )e
+--R                       + 
+--R                               10 3        9 2 2        8 4        7 6
+--R                         (8192a  c  - 8192a b c  + 2560a b c - 256a b )d
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                          7 2     6 2     5 4  5
+--R                     (- 4a c  + 5a b c - a b )e
+--R                   + 
+--R                         6   2      5 3      4 5    4
+--R                     (36a b c  - 29a b c + 5a b )d e
+--R                   + 
+--R                         6 3       5 2 2      4 4       3 6  2 3
+--R                     (24a c  - 110a b c  + 66a b c - 10a b )d e
+--R                   + 
+--R                           5   3       4 3 2      3 5       2 7  3 2
+--R                     (- 72a b c  + 154a b c  - 74a b c + 10a b )d e
+--R                   + 
+--R                          5 4      4 2 3       3 4 2      2 6        8  4
+--R                     (- 4a c  + 73a b c  - 102a b c  + 41a b c - 5a b )d e
+--R                   + 
+--R                        4   4      3 3 3      2 5 2       7     9  5
+--R                     (4a b c  - 25a b c  + 26a b c  - 9a b c + b )d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         9 2        8 2        7 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                            10 2     9 2     8 4  8
+--R                                        (- a  c  + 2a b c - a b )e
+--R                                      + 
+--R                                            9   2      8 3      7 5    7
+--R                                        (16a b c  - 24a b c + 8a b )d e
+--R                                      + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                                  8   3       7 3 2       6 5
+--R                                            - 120a b c  + 392a b c  - 280a b c
+--R                                          + 
+--R                                               5 7
+--R                                            56a b
+--R                                       *
+--R                                           3 5
+--R                                          d e
+--R                                      + 
+--R                                                 8 4       7 2 3       6 4 2
+--R                                            - 38a c  + 422a b c  - 770a b c
+--R                                          + 
+--R                                                5 6       4 8
+--R                                            420a b c - 70a b
+--R                                       *
+--R                                           4 4
+--R                                          d e
+--R                                      + 
+--R                                                7   4       6 3 3       5 5 2
+--R                                            160a b c  - 728a b c  + 896a b c
+--R                                          + 
+--R                                                  4 7       3 9
+--R                                            - 392a b c + 56a b
+--R                                       *
+--R                                           5 3
+--R                                          d e
+--R                                      + 
+--R                                               7 5       6 2 4       5 4 3
+--R                                            12a c  - 252a b c  + 672a b c
+--R                                          + 
+--R                                                  4 6 2       3 8       2 10
+--R                                            - 616a b c  + 224a b c - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 6   5       5 3 4       4 5 3
+--R                                            - 24a b c  + 176a b c  - 320a b c
+--R                                          + 
+--R                                                3 7 2      2 9        11
+--R                                            232a b c  - 72a b c + 8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               6 6      5 2 5      4 4 4
+--R                                            - a c  + 12a b c  - 46a b c
+--R                                          + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  5       4 3  4      5 2      4 2      3 4    3
+--R                               (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                     4   2      3 3      2 5  2 2
+--R                               (- 30a b c  + 30a b c - 6a b )d e
+--R                             + 
+--R                                    4 3      3 2 2      2 4        6  3
+--R                               (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                             + 
+--R                                  3   3      2 3 2       5     7  4
+--R                               (7a b c  - 14a b c  + 7a b c - b )d
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                       6 2    5 2   6        5   2     4 3     5
+--R                     (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                   + 
+--R                          5 3      4 2 2      3 4   2 4
+--R                     (- 5a c  + 25a b c  - 10a b c)d e
+--R                   + 
+--R                         4   3      3 3 2      2 5   3 3
+--R                     (10a b c  - 30a b c  + 10a b c)d e
+--R                   + 
+--R                          4 4      2 4 2       6   4 2
+--R                     (- 5a c  + 15a b c  - 5a b c)d e
+--R                   + 
+--R                         3   4      2 3 3      5 2    7   5
+--R                     (11a b c  - 10a b c  - a b c  + b c)d e
+--R                   + 
+--R                       3 5     2 2 4       4 3    6 2  6
+--R                     (a c  - 6a b c  + 5a b c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R             3
+--R         3a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               9 2        8 2        7 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                        5       4 3  4      5 2      4 2      3 4    3
+--R                     (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                   + 
+--R                           4   2      3 3      2 5  2 2
+--R                     (- 30a b c  + 30a b c - 6a b )d e
+--R                   + 
+--R                          4 3      3 2 2      2 4        6  3
+--R                     (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                   + 
+--R                        3   3      2 3 2       5     7  4
+--R                     (7a b c  - 14a b c  + 7a b c - b )d
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                              10   2        9 3        8 5
+--R                      (- 4096a  b c  + 2048a b c - 256a b )e
+--R                    + 
+--R                              10 3        9 2 2        8 4        7 6
+--R                      (- 8192a  c  + 8192a b c  - 2560a b c + 256a b )d
+--R                 *
+--R                    ROOT
+--R                               10 2     9 2     8 4  8
+--R                           (- a  c  + 2a b c - a b )e
+--R                         + 
+--R                               9   2      8 3      7 5    7
+--R                           (16a b c  - 24a b c + 8a b )d e
+--R                         + 
+--R                               9 3       8 2 2       7 4       6 6  2 6
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                  8   3       7 3 2       6 5       5 7  3 5
+--R                           (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                         + 
+--R                                    8 4       7 2 3       6 4 2       5 6
+--R                               - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                             + 
+--R                                    4 8
+--R                               - 70a b
+--R                          *
+--R                              4 4
+--R                             d e
+--R                         + 
+--R                                   7   4       6 3 3       5 5 2       4 7
+--R                               160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                             + 
+--R                                  3 9
+--R                               56a b
+--R                          *
+--R                              5 3
+--R                             d e
+--R                         + 
+--R                                  7 5       6 2 4       5 4 3       4 6 2
+--R                               12a c  - 252a b c  + 672a b c  - 616a b c
+--R                             + 
+--R                                   3 8       2 10
+--R                               224a b c - 28a b
+--R                          *
+--R                              6 2
+--R                             d e
+--R                         + 
+--R                                    6   5       5 3 4       4 5 3       3 7 2
+--R                               - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                             + 
+--R                                    2 9        11
+--R                               - 72a b c + 8a b
+--R                          *
+--R                              7
+--R                             d e
+--R                         + 
+--R                                  6 6      5 2 5      4 4 4      3 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    2 8 2        10     12
+--R                               - 37a b c  + 10a b  c - b
+--R                          *
+--R                              8
+--R                             d
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                     7 2     6 2     5 4  5         6   2      5 3      4 5    4
+--R                  (4a c  - 5a b c + a b )e  + (- 36a b c  + 29a b c - 5a b )d e
+--R                + 
+--R                        6 3       5 2 2      4 4       3 6  2 3
+--R                  (- 24a c  + 110a b c  - 66a b c + 10a b )d e
+--R                + 
+--R                      5   3       4 3 2      3 5       2 7  3 2
+--R                  (72a b c  - 154a b c  + 74a b c - 10a b )d e
+--R                + 
+--R                     5 4      4 2 3       3 4 2      2 6        8  4
+--R                  (4a c  - 73a b c  + 102a b c  - 41a b c + 5a b )d e
+--R                + 
+--R                       4   4      3 3 3      2 5 2       7     9  5
+--R                  (- 4a b c  + 25a b c  - 26a b c  + 9a b c - b )d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      9 2        8 2        7 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                         10 2     9 2     8 4  8
+--R                                     (- a  c  + 2a b c - a b )e
+--R                                   + 
+--R                                         9   2      8 3      7 5    7
+--R                                     (16a b c  - 24a b c + 8a b )d e
+--R                                   + 
+--R                                           9 3       8 2 2       7 4       6 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                               8   3       7 3 2       6 5
+--R                                         - 120a b c  + 392a b c  - 280a b c
+--R                                       + 
+--R                                            5 7
+--R                                         56a b
+--R                                    *
+--R                                        3 5
+--R                                       d e
+--R                                   + 
+--R                                              8 4       7 2 3       6 4 2
+--R                                         - 38a c  + 422a b c  - 770a b c
+--R                                       + 
+--R                                             5 6       4 8
+--R                                         420a b c - 70a b
+--R                                    *
+--R                                        4 4
+--R                                       d e
+--R                                   + 
+--R                                             7   4       6 3 3       5 5 2
+--R                                         160a b c  - 728a b c  + 896a b c
+--R                                       + 
+--R                                               4 7       3 9
+--R                                         - 392a b c + 56a b
+--R                                    *
+--R                                        5 3
+--R                                       d e
+--R                                   + 
+--R                                            7 5       6 2 4       5 4 3
+--R                                         12a c  - 252a b c  + 672a b c
+--R                                       + 
+--R                                               4 6 2       3 8       2 10
+--R                                         - 616a b c  + 224a b c - 28a b
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                              6   5       5 3 4       4 5 3
+--R                                         - 24a b c  + 176a b c  - 320a b c
+--R                                       + 
+--R                                             3 7 2      2 9        11
+--R                                         232a b c  - 72a b c + 8a b
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                            6 6      5 2 5      4 4 4      3 6 3
+--R                                         - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                       + 
+--R                                              2 8 2        10     12
+--R                                         - 37a b c  + 10a b  c - b
+--R                                    *
+--R                                        8
+--R                                       d
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               5       4 3  4      5 2      4 2      3 4    3
+--R                            (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 30a b c  + 30a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (7a b c  - 14a b c  + 7a b c - b )d
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                    6 2    5 2   6        5   2     4 3     5
+--R                  (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                + 
+--R                       5 3      4 2 2      3 4   2 4
+--R                  (- 5a c  + 25a b c  - 10a b c)d e
+--R                + 
+--R                      4   3      3 3 2      2 5   3 3
+--R                  (10a b c  - 30a b c  + 10a b c)d e
+--R                + 
+--R                       4 4      2 4 2       6   4 2
+--R                  (- 5a c  + 15a b c  - 5a b c)d e
+--R                + 
+--R                      3   4      2 3 3      5 2    7   5
+--R                  (11a b c  - 10a b c  - a b c  + b c)d e
+--R                + 
+--R                    3 5     2 2 4       4 3    6 2  6
+--R                  (a c  - 6a b c  + 5a b c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                3
+--R            3a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                9 2        8 2        7 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                     10 2     9 2     8 4  8
+--R                                 (- a  c  + 2a b c - a b )e
+--R                               + 
+--R                                     9   2      8 3      7 5    7
+--R                                 (16a b c  - 24a b c + 8a b )d e
+--R                               + 
+--R                                     9 3       8 2 2       7 4       6 6  2 6
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                          8   3       7 3 2       6 5       5 7
+--R                                   (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                                *
+--R                                    3 5
+--R                                   d e
+--R                               + 
+--R                                          8 4       7 2 3       6 4 2       5 6
+--R                                     - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                   + 
+--R                                          4 8
+--R                                     - 70a b
+--R                                *
+--R                                    4 4
+--R                                   d e
+--R                               + 
+--R                                         7   4       6 3 3       5 5 2
+--R                                     160a b c  - 728a b c  + 896a b c
+--R                                   + 
+--R                                           4 7       3 9
+--R                                     - 392a b c + 56a b
+--R                                *
+--R                                    5 3
+--R                                   d e
+--R                               + 
+--R                                        7 5       6 2 4       5 4 3       4 6 2
+--R                                     12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                   + 
+--R                                         3 8       2 10
+--R                                     224a b c - 28a b
+--R                                *
+--R                                    6 2
+--R                                   d e
+--R                               + 
+--R                                          6   5       5 3 4       4 5 3
+--R                                     - 24a b c  + 176a b c  - 320a b c
+--R                                   + 
+--R                                         3 7 2      2 9        11
+--R                                     232a b c  - 72a b c + 8a b
+--R                                *
+--R                                    7
+--R                                   d e
+--R                               + 
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                *
+--R                                    8
+--R                                   d
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           5       4 3  4      5 2      4 2      3 4    3
+--R                        (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                      + 
+--R                              4   2      3 3      2 5  2 2
+--R                        (- 30a b c  + 30a b c - 6a b )d e
+--R                      + 
+--R                             4 3      3 2 2      2 4        6  3
+--R                        (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                      + 
+--R                           3   3      2 3 2       5     7  4
+--R                        (7a b c  - 14a b c  + 7a b c - b )d
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                                 10   2        9 3        8 5
+--R                         (- 4096a  b c  + 2048a b c - 256a b )e
+--R                       + 
+--R                                 10 3        9 2 2        8 4        7 6
+--R                         (- 8192a  c  + 8192a b c  - 2560a b c + 256a b )d
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                          7 2     6 2     5 4  5
+--R                     (- 4a c  + 5a b c - a b )e
+--R                   + 
+--R                         6   2      5 3      4 5    4
+--R                     (36a b c  - 29a b c + 5a b )d e
+--R                   + 
+--R                         6 3       5 2 2      4 4       3 6  2 3
+--R                     (24a c  - 110a b c  + 66a b c - 10a b )d e
+--R                   + 
+--R                           5   3       4 3 2      3 5       2 7  3 2
+--R                     (- 72a b c  + 154a b c  - 74a b c + 10a b )d e
+--R                   + 
+--R                          5 4      4 2 3       3 4 2      2 6        8  4
+--R                     (- 4a c  + 73a b c  - 102a b c  + 41a b c - 5a b )d e
+--R                   + 
+--R                        4   4      3 3 3      2 5 2       7     9  5
+--R                     (4a b c  - 25a b c  + 26a b c  - 9a b c + b )d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       9 2        8 2        7 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                            10 2     9 2     8 4  8
+--R                                        (- a  c  + 2a b c - a b )e
+--R                                      + 
+--R                                            9   2      8 3      7 5    7
+--R                                        (16a b c  - 24a b c + 8a b )d e
+--R                                      + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                                  8   3       7 3 2       6 5
+--R                                            - 120a b c  + 392a b c  - 280a b c
+--R                                          + 
+--R                                               5 7
+--R                                            56a b
+--R                                       *
+--R                                           3 5
+--R                                          d e
+--R                                      + 
+--R                                                 8 4       7 2 3       6 4 2
+--R                                            - 38a c  + 422a b c  - 770a b c
+--R                                          + 
+--R                                                5 6       4 8
+--R                                            420a b c - 70a b
+--R                                       *
+--R                                           4 4
+--R                                          d e
+--R                                      + 
+--R                                                7   4       6 3 3       5 5 2
+--R                                            160a b c  - 728a b c  + 896a b c
+--R                                          + 
+--R                                                  4 7       3 9
+--R                                            - 392a b c + 56a b
+--R                                       *
+--R                                           5 3
+--R                                          d e
+--R                                      + 
+--R                                               7 5       6 2 4       5 4 3
+--R                                            12a c  - 252a b c  + 672a b c
+--R                                          + 
+--R                                                  4 6 2       3 8       2 10
+--R                                            - 616a b c  + 224a b c - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 6   5       5 3 4       4 5 3
+--R                                            - 24a b c  + 176a b c  - 320a b c
+--R                                          + 
+--R                                                3 7 2      2 9        11
+--R                                            232a b c  - 72a b c + 8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               6 6      5 2 5      4 4 4
+--R                                            - a c  + 12a b c  - 46a b c
+--R                                          + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  5       4 3  4      5 2      4 2      3 4    3
+--R                               (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                     4   2      3 3      2 5  2 2
+--R                               (- 30a b c  + 30a b c - 6a b )d e
+--R                             + 
+--R                                    4 3      3 2 2      2 4        6  3
+--R                               (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                             + 
+--R                                  3   3      2 3 2       5     7  4
+--R                               (7a b c  - 14a b c  + 7a b c - b )d
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                       6 2    5 2   6        5   2     4 3     5
+--R                     (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                   + 
+--R                          5 3      4 2 2      3 4   2 4
+--R                     (- 5a c  + 25a b c  - 10a b c)d e
+--R                   + 
+--R                         4   3      3 3 2      2 5   3 3
+--R                     (10a b c  - 30a b c  + 10a b c)d e
+--R                   + 
+--R                          4 4      2 4 2       6   4 2
+--R                     (- 5a c  + 15a b c  - 5a b c)d e
+--R                   + 
+--R                         3   4      2 3 3      5 2    7   5
+--R                     (11a b c  - 10a b c  - a b c  + b c)d e
+--R                   + 
+--R                       3 5     2 2 4       4 3    6 2  6
+--R                     (a c  - 6a b c  + 5a b c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R             3
+--R         3a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             9 2        8 2        7 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                        5       4 3  4      5 2      4 2      3 4    3
+--R                     (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                   + 
+--R                           4   2      3 3      2 5  2 2
+--R                     (- 30a b c  + 30a b c - 6a b )d e
+--R                   + 
+--R                          4 3      3 2 2      2 4        6  3
+--R                     (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                   + 
+--R                        3   3      2 3 2       5     7  4
+--R                     (7a b c  - 14a b c  + 7a b c - b )d
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                         10 3
+--R                    8192a  c d
+--R                 *
+--R                    ROOT
+--R                               10 2     9 2     8 4  8
+--R                           (- a  c  + 2a b c - a b )e
+--R                         + 
+--R                               9   2      8 3      7 5    7
+--R                           (16a b c  - 24a b c + 8a b )d e
+--R                         + 
+--R                               9 3       8 2 2       7 4       6 6  2 6
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                  8   3       7 3 2       6 5       5 7  3 5
+--R                           (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                         + 
+--R                                    8 4       7 2 3       6 4 2       5 6
+--R                               - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                             + 
+--R                                    4 8
+--R                               - 70a b
+--R                          *
+--R                              4 4
+--R                             d e
+--R                         + 
+--R                                   7   4       6 3 3       5 5 2       4 7
+--R                               160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                             + 
+--R                                  3 9
+--R                               56a b
+--R                          *
+--R                              5 3
+--R                             d e
+--R                         + 
+--R                                  7 5       6 2 4       5 4 3       4 6 2
+--R                               12a c  - 252a b c  + 672a b c  - 616a b c
+--R                             + 
+--R                                   3 8       2 10
+--R                               224a b c - 28a b
+--R                          *
+--R                              6 2
+--R                             d e
+--R                         + 
+--R                                    6   5       5 3 4       4 5 3       3 7 2
+--R                               - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                             + 
+--R                                    2 9        11
+--R                               - 72a b c + 8a b
+--R                          *
+--R                              7
+--R                             d e
+--R                         + 
+--R                                  6 6      5 2 5      4 4 4      3 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    2 8 2        10     12
+--R                               - 37a b c  + 10a b  c - b
+--R                          *
+--R                              8
+--R                             d
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                     7 2     6     5  5
+--R                  (4a c  + 5a c + a )e
+--R                + 
+--R                        6 3       5 2      4       3  2 3
+--R                  (- 24a c  - 110a c  - 66a c - 10a )d e
+--R                + 
+--R                     5 4      4 3       3 2      2        4
+--R                  (4a c  + 73a c  + 102a c  + 41a c + 5a)d e
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    9 2        8 2        7 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                         10 2     9 2     8 4  8
+--R                                     (- a  c  + 2a b c - a b )e
+--R                                   + 
+--R                                         9   2      8 3      7 5    7
+--R                                     (16a b c  - 24a b c + 8a b )d e
+--R                                   + 
+--R                                           9 3       8 2 2       7 4       6 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                               8   3       7 3 2       6 5
+--R                                         - 120a b c  + 392a b c  - 280a b c
+--R                                       + 
+--R                                            5 7
+--R                                         56a b
+--R                                    *
+--R                                        3 5
+--R                                       d e
+--R                                   + 
+--R                                              8 4       7 2 3       6 4 2
+--R                                         - 38a c  + 422a b c  - 770a b c
+--R                                       + 
+--R                                             5 6       4 8
+--R                                         420a b c - 70a b
+--R                                    *
+--R                                        4 4
+--R                                       d e
+--R                                   + 
+--R                                             7   4       6 3 3       5 5 2
+--R                                         160a b c  - 728a b c  + 896a b c
+--R                                       + 
+--R                                               4 7       3 9
+--R                                         - 392a b c + 56a b
+--R                                    *
+--R                                        5 3
+--R                                       d e
+--R                                   + 
+--R                                            7 5       6 2 4       5 4 3
+--R                                         12a c  - 252a b c  + 672a b c
+--R                                       + 
+--R                                               4 6 2       3 8       2 10
+--R                                         - 616a b c  + 224a b c - 28a b
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                              6   5       5 3 4       4 5 3
+--R                                         - 24a b c  + 176a b c  - 320a b c
+--R                                       + 
+--R                                             3 7 2      2 9        11
+--R                                         232a b c  - 72a b c + 8a b
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                            6 6      5 2 5      4 4 4      3 6 3
+--R                                         - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                       + 
+--R                                              2 8 2        10     12
+--R                                         - 37a b c  + 10a b  c - b
+--R                                    *
+--R                                        8
+--R                                       d
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               5       4 3  4      5 2      4 2      3 4    3
+--R                            (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 30a b c  + 30a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (7a b c  - 14a b c  + 7a b c - b )d
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                              10 2 2        9 4        8 6
+--R                        (4096a  b c  - 2048a b c + 256a b )e
+--R                      + 
+--R                                9 3 2        8 5        7 7
+--R                        (- 8192a b c  + 2560a b c - 256a b )d
+--R                   *
+--R                      ROOT
+--R                                 10 2     9 2     8 4  8
+--R                             (- a  c  + 2a b c - a b )e
+--R                           + 
+--R                                 9   2      8 3      7 5    7
+--R                             (16a b c  - 24a b c + 8a b )d e
+--R                           + 
+--R                                 9 3       8 2 2       7 4       6 6  2 6
+--R                             (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                           + 
+--R                                    8   3       7 3 2       6 5       5 7  3 5
+--R                             (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                           + 
+--R                                      8 4       7 2 3       6 4 2       5 6
+--R                                 - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                               + 
+--R                                      4 8
+--R                                 - 70a b
+--R                            *
+--R                                4 4
+--R                               d e
+--R                           + 
+--R                                     7   4       6 3 3       5 5 2       4 7
+--R                                 160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                               + 
+--R                                    3 9
+--R                                 56a b
+--R                            *
+--R                                5 3
+--R                               d e
+--R                           + 
+--R                                    7 5       6 2 4       5 4 3       4 6 2
+--R                                 12a c  - 252a b c  + 672a b c  - 616a b c
+--R                               + 
+--R                                     3 8       2 10
+--R                                 224a b c - 28a b
+--R                            *
+--R                                6 2
+--R                               d e
+--R                           + 
+--R                                      6   5       5 3 4       4 5 3       3 7 2
+--R                                 - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                               + 
+--R                                      2 9        11
+--R                                 - 72a b c + 8a b
+--R                            *
+--R                                7
+--R                               d e
+--R                           + 
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            *
+--R                                8
+--R                               d
+--R                        /
+--R                                     17 3           16 2 2          15 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     14 6
+--R                             - 65536a  b
+--R                  + 
+--R                        6 2      5      4    4
+--R                    (36a c  + 29a c + 5a )d e
+--R                  + 
+--R                          5 3       4 2      3       2  3 2
+--R                    (- 72a c  - 154a c  - 74a c - 10a )d e
+--R                  + 
+--R                         4 2 4      3 4 3      2 6 2       8     10  5
+--R                    (- 4a b c  + 25a b c  - 26a b c  + 9a b c - b  )d
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      9 2        8 2        7 4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                           10 2     9 2     8 4  8
+--R                                       (- a  c  + 2a b c - a b )e
+--R                                     + 
+--R                                           9   2      8 3      7 5    7
+--R                                       (16a b c  - 24a b c + 8a b )d e
+--R                                     + 
+--R                                                9 3       8 2 2       7 4
+--R                                             12a c  - 112a b c  + 112a b c
+--R                                           + 
+--R                                                  6 6
+--R                                             - 28a b
+--R                                      *
+--R                                          2 6
+--R                                         d e
+--R                                     + 
+--R                                                 8   3       7 3 2       6 5
+--R                                           - 120a b c  + 392a b c  - 280a b c
+--R                                         + 
+--R                                              5 7
+--R                                           56a b
+--R                                      *
+--R                                          3 5
+--R                                         d e
+--R                                     + 
+--R                                                8 4       7 2 3       6 4 2
+--R                                           - 38a c  + 422a b c  - 770a b c
+--R                                         + 
+--R                                               5 6       4 8
+--R                                           420a b c - 70a b
+--R                                      *
+--R                                          4 4
+--R                                         d e
+--R                                     + 
+--R                                               7   4       6 3 3       5 5 2
+--R                                           160a b c  - 728a b c  + 896a b c
+--R                                         + 
+--R                                                 4 7       3 9
+--R                                           - 392a b c + 56a b
+--R                                      *
+--R                                          5 3
+--R                                         d e
+--R                                     + 
+--R                                              7 5       6 2 4       5 4 3
+--R                                           12a c  - 252a b c  + 672a b c
+--R                                         + 
+--R                                                 4 6 2       3 8       2 10
+--R                                           - 616a b c  + 224a b c - 28a b
+--R                                      *
+--R                                          6 2
+--R                                         d e
+--R                                     + 
+--R                                                6   5       5 3 4       4 5 3
+--R                                           - 24a b c  + 176a b c  - 320a b c
+--R                                         + 
+--R                                               3 7 2      2 9        11
+--R                                           232a b c  - 72a b c + 8a b
+--R                                      *
+--R                                          7
+--R                                         d e
+--R                                     + 
+--R                                              6 6      5 2 5      4 4 4
+--R                                           - a c  + 12a b c  - 46a b c
+--R                                         + 
+--R                                              3 6 3      2 8 2        10     12
+--R                                           62a b c  - 37a b c  + 10a b  c - b
+--R                                      *
+--R                                          8
+--R                                         d
+--R                                  /
+--R                                               17 3           16 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              15 4          14 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                 5       4 3  4      5 2      4 2      3 4    3
+--R                              (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                            + 
+--R                                    4   2      3 3      2 5  2 2
+--R                              (- 30a b c  + 30a b c - 6a b )d e
+--R                            + 
+--R                                   4 3      3 2 2      2 4        6  3
+--R                              (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                            + 
+--R                                 3   3      2 3 2       5     7  4
+--R                              (7a b c  - 14a b c  + 7a b c - b )d
+--R                         /
+--R                                 9 2        8 2        7 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                        6 2    5 2   6      5   2     4 3     5
+--R                    (- a c  + a b c)e  + (9a b c  - 5a b c)d e
+--R                  + 
+--R                       5 3      4 2 2      3 4   2 4
+--R                    (5a c  - 25a b c  + 10a b c)d e
+--R                  + 
+--R                          4   3      3 3 2      2 5   3 3
+--R                    (- 10a b c  + 30a b c  - 10a b c)d e
+--R                  + 
+--R                       4 4      2 4 2       6   4 2
+--R                    (5a c  - 15a b c  + 5a b c)d e
+--R                  + 
+--R                          3   4      2 3 3      5 2    7   5
+--R                    (- 11a b c  + 10a b c  + a b c  - b c)d e
+--R                  + 
+--R                        3 5     2 2 4       4 3    6 2  6
+--R                    (- a c  + 6a b c  - 5a b c  + b c )d
+--R               *
+--R                  x
+--R     + 
+--R       -
+--R                3
+--R            3a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                9 2        8 2        7 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                     10 2     9 2     8 4  8
+--R                                 (- a  c  + 2a b c - a b )e
+--R                               + 
+--R                                     9   2      8 3      7 5    7
+--R                                 (16a b c  - 24a b c + 8a b )d e
+--R                               + 
+--R                                     9 3       8 2 2       7 4       6 6  2 6
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                          8   3       7 3 2       6 5       5 7
+--R                                   (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                                *
+--R                                    3 5
+--R                                   d e
+--R                               + 
+--R                                          8 4       7 2 3       6 4 2       5 6
+--R                                     - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                   + 
+--R                                          4 8
+--R                                     - 70a b
+--R                                *
+--R                                    4 4
+--R                                   d e
+--R                               + 
+--R                                         7   4       6 3 3       5 5 2
+--R                                     160a b c  - 728a b c  + 896a b c
+--R                                   + 
+--R                                           4 7       3 9
+--R                                     - 392a b c + 56a b
+--R                                *
+--R                                    5 3
+--R                                   d e
+--R                               + 
+--R                                        7 5       6 2 4       5 4 3       4 6 2
+--R                                     12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                   + 
+--R                                         3 8       2 10
+--R                                     224a b c - 28a b
+--R                                *
+--R                                    6 2
+--R                                   d e
+--R                               + 
+--R                                          6   5       5 3 4       4 5 3
+--R                                     - 24a b c  + 176a b c  - 320a b c
+--R                                   + 
+--R                                         3 7 2      2 9        11
+--R                                     232a b c  - 72a b c + 8a b
+--R                                *
+--R                                    7
+--R                                   d e
+--R                               + 
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                *
+--R                                    8
+--R                                   d
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           5       4 3  4      5 2      4 2      3 4    3
+--R                        (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                      + 
+--R                              4   2      3 3      2 5  2 2
+--R                        (- 30a b c  + 30a b c - 6a b )d e
+--R                      + 
+--R                             4 3      3 2 2      2 4        6  3
+--R                        (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                      + 
+--R                           3   3      2 3 2       5     7  4
+--R                        (7a b c  - 14a b c  + 7a b c - b )d
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                            10 3
+--R                       8192a  c d
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                        7 2     6     5  5
+--R                     (4a c  + 5a c + a )e
+--R                   + 
+--R                           6 3       5 2      4       3  2 3
+--R                     (- 24a c  - 110a c  - 66a c - 10a )d e
+--R                   + 
+--R                        5 4      4 3       3 2      2        4
+--R                     (4a c  + 73a c  + 102a c  + 41a c + 5a)d e
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       9 2        8 2        7 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                            10 2     9 2     8 4  8
+--R                                        (- a  c  + 2a b c - a b )e
+--R                                      + 
+--R                                            9   2      8 3      7 5    7
+--R                                        (16a b c  - 24a b c + 8a b )d e
+--R                                      + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                                  8   3       7 3 2       6 5
+--R                                            - 120a b c  + 392a b c  - 280a b c
+--R                                          + 
+--R                                               5 7
+--R                                            56a b
+--R                                       *
+--R                                           3 5
+--R                                          d e
+--R                                      + 
+--R                                                 8 4       7 2 3       6 4 2
+--R                                            - 38a c  + 422a b c  - 770a b c
+--R                                          + 
+--R                                                5 6       4 8
+--R                                            420a b c - 70a b
+--R                                       *
+--R                                           4 4
+--R                                          d e
+--R                                      + 
+--R                                                7   4       6 3 3       5 5 2
+--R                                            160a b c  - 728a b c  + 896a b c
+--R                                          + 
+--R                                                  4 7       3 9
+--R                                            - 392a b c + 56a b
+--R                                       *
+--R                                           5 3
+--R                                          d e
+--R                                      + 
+--R                                               7 5       6 2 4       5 4 3
+--R                                            12a c  - 252a b c  + 672a b c
+--R                                          + 
+--R                                                  4 6 2       3 8       2 10
+--R                                            - 616a b c  + 224a b c - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 6   5       5 3 4       4 5 3
+--R                                            - 24a b c  + 176a b c  - 320a b c
+--R                                          + 
+--R                                                3 7 2      2 9        11
+--R                                            232a b c  - 72a b c + 8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               6 6      5 2 5      4 4 4
+--R                                            - a c  + 12a b c  - 46a b c
+--R                                          + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  5       4 3  4      5 2      4 2      3 4    3
+--R                               (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                     4   2      3 3      2 5  2 2
+--R                               (- 30a b c  + 30a b c - 6a b )d e
+--R                             + 
+--R                                    4 3      3 2 2      2 4        6  3
+--R                               (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                             + 
+--R                                  3   3      2 3 2       5     7  4
+--R                               (7a b c  - 14a b c  + 7a b c - b )d
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                 10 2 2        9 4        8 6
+--R                           (4096a  b c  - 2048a b c + 256a b )e
+--R                         + 
+--R                                   9 3 2        8 5        7 7
+--R                           (- 8192a b c  + 2560a b c - 256a b )d
+--R                      *
+--R                         ROOT
+--R                                    10 2     9 2     8 4  8
+--R                                (- a  c  + 2a b c - a b )e
+--R                              + 
+--R                                    9   2      8 3      7 5    7
+--R                                (16a b c  - 24a b c + 8a b )d e
+--R                              + 
+--R                                    9 3       8 2 2       7 4       6 6  2 6
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                         8   3       7 3 2       6 5       5 7
+--R                                  (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                               *
+--R                                   3 5
+--R                                  d e
+--R                              + 
+--R                                         8 4       7 2 3       6 4 2       5 6
+--R                                    - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                  + 
+--R                                         4 8
+--R                                    - 70a b
+--R                               *
+--R                                   4 4
+--R                                  d e
+--R                              + 
+--R                                        7   4       6 3 3       5 5 2       4 7
+--R                                    160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                  + 
+--R                                       3 9
+--R                                    56a b
+--R                               *
+--R                                   5 3
+--R                                  d e
+--R                              + 
+--R                                       7 5       6 2 4       5 4 3       4 6 2
+--R                                    12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                  + 
+--R                                        3 8       2 10
+--R                                    224a b c - 28a b
+--R                               *
+--R                                   6 2
+--R                                  d e
+--R                              + 
+--R                                         6   5       5 3 4       4 5 3
+--R                                    - 24a b c  + 176a b c  - 320a b c
+--R                                  + 
+--R                                        3 7 2      2 9        11
+--R                                    232a b c  - 72a b c + 8a b
+--R                               *
+--R                                   7
+--R                                  d e
+--R                              + 
+--R                                       6 6      5 2 5      4 4 4      3 6 3
+--R                                    - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                  + 
+--R                                         2 8 2        10     12
+--R                                    - 37a b c  + 10a b  c - b
+--R                               *
+--R                                   8
+--R                                  d
+--R                           /
+--R                                        17 3           16 2 2          15 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        14 6
+--R                                - 65536a  b
+--R                     + 
+--R                           6 2      5      4    4
+--R                       (36a c  + 29a c + 5a )d e
+--R                     + 
+--R                             5 3       4 2      3       2  3 2
+--R                       (- 72a c  - 154a c  - 74a c - 10a )d e
+--R                     + 
+--R                            4 2 4      3 4 3      2 6 2       8     10  5
+--R                       (- 4a b c  + 25a b c  - 26a b c  + 9a b c - b  )d
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         9 2        8 2        7 4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                              10 2     9 2     8 4  8
+--R                                          (- a  c  + 2a b c - a b )e
+--R                                        + 
+--R                                              9   2      8 3      7 5    7
+--R                                          (16a b c  - 24a b c + 8a b )d e
+--R                                        + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                         *
+--R                                             2 6
+--R                                            d e
+--R                                        + 
+--R                                                    8   3       7 3 2       6 5
+--R                                              - 120a b c  + 392a b c  - 280a b c
+--R                                            + 
+--R                                                 5 7
+--R                                              56a b
+--R                                         *
+--R                                             3 5
+--R                                            d e
+--R                                        + 
+--R                                                   8 4       7 2 3       6 4 2
+--R                                              - 38a c  + 422a b c  - 770a b c
+--R                                            + 
+--R                                                  5 6       4 8
+--R                                              420a b c - 70a b
+--R                                         *
+--R                                             4 4
+--R                                            d e
+--R                                        + 
+--R                                                  7   4       6 3 3       5 5 2
+--R                                              160a b c  - 728a b c  + 896a b c
+--R                                            + 
+--R                                                    4 7       3 9
+--R                                              - 392a b c + 56a b
+--R                                         *
+--R                                             5 3
+--R                                            d e
+--R                                        + 
+--R                                                 7 5       6 2 4       5 4 3
+--R                                              12a c  - 252a b c  + 672a b c
+--R                                            + 
+--R                                                    4 6 2       3 8       2 10
+--R                                              - 616a b c  + 224a b c - 28a b
+--R                                         *
+--R                                             6 2
+--R                                            d e
+--R                                        + 
+--R                                                   6   5       5 3 4       4 5 3
+--R                                              - 24a b c  + 176a b c  - 320a b c
+--R                                            + 
+--R                                                  3 7 2      2 9        11
+--R                                              232a b c  - 72a b c + 8a b
+--R                                         *
+--R                                             7
+--R                                            d e
+--R                                        + 
+--R                                                 6 6      5 2 5      4 4 4
+--R                                              - a c  + 12a b c  - 46a b c
+--R                                            + 
+--R                                               3 6 3      2 8 2        10     12
+--R                                            62a b c  - 37a b c  + 10a b  c - b
+--R                                         *
+--R                                             8
+--R                                            d
+--R                                     /
+--R                                                  17 3           16 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 15 4          14 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                    5       4 3  4
+--R                                 (3a b c - a b )e
+--R                               + 
+--R                                    5 2      4 2      3 4    3
+--R                                 (8a c  - 16a b c + 4a b )d e
+--R                               + 
+--R                                       4   2      3 3      2 5  2 2
+--R                                 (- 30a b c  + 30a b c - 6a b )d e
+--R                               + 
+--R                                      4 3      3 2 2      2 4        6  3
+--R                                 (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                               + 
+--R                                    3   3      2 3 2       5     7  4
+--R                                 (7a b c  - 14a b c  + 7a b c - b )d
+--R                            /
+--R                                    9 2        8 2        7 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                         6 2    5 2   6        5   2     4 3     5
+--R                       (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                     + 
+--R                            5 3      4 2 2      3 4   2 4
+--R                       (- 5a c  + 25a b c  - 10a b c)d e
+--R                     + 
+--R                           4   3      3 3 2      2 5   3 3
+--R                       (10a b c  - 30a b c  + 10a b c)d e
+--R                     + 
+--R                            4 4      2 4 2       6   4 2
+--R                       (- 5a c  + 15a b c  - 5a b c)d e
+--R                     + 
+--R                           3   4      2 3 3      5 2    7   5
+--R                       (11a b c  - 10a b c  - a b c  + b c)d e
+--R                     + 
+--R                         3 5     2 2 4       4 3    6 2  6
+--R                       (a c  - 6a b c  + 5a b c  - b c )d
+--R                  *
+--R                     x
+--R     + 
+--R       -
+--R                3
+--R            3a x
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  9 2        8 2        7 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                     10 2     9 2     8 4  8
+--R                                 (- a  c  + 2a b c - a b )e
+--R                               + 
+--R                                     9   2      8 3      7 5    7
+--R                                 (16a b c  - 24a b c + 8a b )d e
+--R                               + 
+--R                                     9 3       8 2 2       7 4       6 6  2 6
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                          8   3       7 3 2       6 5       5 7
+--R                                   (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                                *
+--R                                    3 5
+--R                                   d e
+--R                               + 
+--R                                          8 4       7 2 3       6 4 2       5 6
+--R                                     - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                   + 
+--R                                          4 8
+--R                                     - 70a b
+--R                                *
+--R                                    4 4
+--R                                   d e
+--R                               + 
+--R                                         7   4       6 3 3       5 5 2
+--R                                     160a b c  - 728a b c  + 896a b c
+--R                                   + 
+--R                                           4 7       3 9
+--R                                     - 392a b c + 56a b
+--R                                *
+--R                                    5 3
+--R                                   d e
+--R                               + 
+--R                                        7 5       6 2 4       5 4 3       4 6 2
+--R                                     12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                   + 
+--R                                         3 8       2 10
+--R                                     224a b c - 28a b
+--R                                *
+--R                                    6 2
+--R                                   d e
+--R                               + 
+--R                                          6   5       5 3 4       4 5 3
+--R                                     - 24a b c  + 176a b c  - 320a b c
+--R                                   + 
+--R                                         3 7 2      2 9        11
+--R                                     232a b c  - 72a b c + 8a b
+--R                                *
+--R                                    7
+--R                                   d e
+--R                               + 
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                *
+--R                                    8
+--R                                   d
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           5       4 3  4      5 2      4 2      3 4    3
+--R                        (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                      + 
+--R                              4   2      3 3      2 5  2 2
+--R                        (- 30a b c  + 30a b c - 6a b )d e
+--R                      + 
+--R                             4 3      3 2 2      2 4        6  3
+--R                        (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                      + 
+--R                           3   3      2 3 2       5     7  4
+--R                        (7a b c  - 14a b c  + 7a b c - b )d
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                            10 3
+--R                       8192a  c d
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                          7 2     6     5  5
+--R                     (- 4a c  - 5a c - a )e
+--R                   + 
+--R                         6 3       5 2      4       3  2 3
+--R                     (24a c  + 110a c  + 66a c + 10a )d e
+--R                   + 
+--R                          5 4      4 3       3 2      2        4
+--R                     (- 4a c  - 73a c  - 102a c  - 41a c - 5a)d e
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         9 2        8 2        7 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                            10 2     9 2     8 4  8
+--R                                        (- a  c  + 2a b c - a b )e
+--R                                      + 
+--R                                            9   2      8 3      7 5    7
+--R                                        (16a b c  - 24a b c + 8a b )d e
+--R                                      + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                                  8   3       7 3 2       6 5
+--R                                            - 120a b c  + 392a b c  - 280a b c
+--R                                          + 
+--R                                               5 7
+--R                                            56a b
+--R                                       *
+--R                                           3 5
+--R                                          d e
+--R                                      + 
+--R                                                 8 4       7 2 3       6 4 2
+--R                                            - 38a c  + 422a b c  - 770a b c
+--R                                          + 
+--R                                                5 6       4 8
+--R                                            420a b c - 70a b
+--R                                       *
+--R                                           4 4
+--R                                          d e
+--R                                      + 
+--R                                                7   4       6 3 3       5 5 2
+--R                                            160a b c  - 728a b c  + 896a b c
+--R                                          + 
+--R                                                  4 7       3 9
+--R                                            - 392a b c + 56a b
+--R                                       *
+--R                                           5 3
+--R                                          d e
+--R                                      + 
+--R                                               7 5       6 2 4       5 4 3
+--R                                            12a c  - 252a b c  + 672a b c
+--R                                          + 
+--R                                                  4 6 2       3 8       2 10
+--R                                            - 616a b c  + 224a b c - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 6   5       5 3 4       4 5 3
+--R                                            - 24a b c  + 176a b c  - 320a b c
+--R                                          + 
+--R                                                3 7 2      2 9        11
+--R                                            232a b c  - 72a b c + 8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               6 6      5 2 5      4 4 4
+--R                                            - a c  + 12a b c  - 46a b c
+--R                                          + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  5       4 3  4      5 2      4 2      3 4    3
+--R                               (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                     4   2      3 3      2 5  2 2
+--R                               (- 30a b c  + 30a b c - 6a b )d e
+--R                             + 
+--R                                    4 3      3 2 2      2 4        6  3
+--R                               (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                             + 
+--R                                  3   3      2 3 2       5     7  4
+--R                               (7a b c  - 14a b c  + 7a b c - b )d
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                 10 2 2        9 4        8 6
+--R                           (4096a  b c  - 2048a b c + 256a b )e
+--R                         + 
+--R                                   9 3 2        8 5        7 7
+--R                           (- 8192a b c  + 2560a b c - 256a b )d
+--R                      *
+--R                         ROOT
+--R                                    10 2     9 2     8 4  8
+--R                                (- a  c  + 2a b c - a b )e
+--R                              + 
+--R                                    9   2      8 3      7 5    7
+--R                                (16a b c  - 24a b c + 8a b )d e
+--R                              + 
+--R                                    9 3       8 2 2       7 4       6 6  2 6
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                         8   3       7 3 2       6 5       5 7
+--R                                  (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                               *
+--R                                   3 5
+--R                                  d e
+--R                              + 
+--R                                         8 4       7 2 3       6 4 2       5 6
+--R                                    - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                  + 
+--R                                         4 8
+--R                                    - 70a b
+--R                               *
+--R                                   4 4
+--R                                  d e
+--R                              + 
+--R                                        7   4       6 3 3       5 5 2       4 7
+--R                                    160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                  + 
+--R                                       3 9
+--R                                    56a b
+--R                               *
+--R                                   5 3
+--R                                  d e
+--R                              + 
+--R                                       7 5       6 2 4       5 4 3       4 6 2
+--R                                    12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                  + 
+--R                                        3 8       2 10
+--R                                    224a b c - 28a b
+--R                               *
+--R                                   6 2
+--R                                  d e
+--R                              + 
+--R                                         6   5       5 3 4       4 5 3
+--R                                    - 24a b c  + 176a b c  - 320a b c
+--R                                  + 
+--R                                        3 7 2      2 9        11
+--R                                    232a b c  - 72a b c + 8a b
+--R                               *
+--R                                   7
+--R                                  d e
+--R                              + 
+--R                                       6 6      5 2 5      4 4 4      3 6 3
+--R                                    - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                  + 
+--R                                         2 8 2        10     12
+--R                                    - 37a b c  + 10a b  c - b
+--R                               *
+--R                                   8
+--R                                  d
+--R                           /
+--R                                        17 3           16 2 2          15 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        14 6
+--R                                - 65536a  b
+--R                     + 
+--R                             6 2      5      4    4
+--R                       (- 36a c  - 29a c - 5a )d e
+--R                     + 
+--R                           5 3       4 2      3       2  3 2
+--R                       (72a c  + 154a c  + 74a c + 10a )d e
+--R                     + 
+--R                          4 2 4      3 4 3      2 6 2       8     10  5
+--R                       (4a b c  - 25a b c  + 26a b c  - 9a b c + b  )d
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                           9 2        8 2        7 4
+--R                                   (- 4096a c  + 2048a b c - 256a b )
+--R                                *
+--R                                   ROOT
+--R                                              10 2     9 2     8 4  8
+--R                                          (- a  c  + 2a b c - a b )e
+--R                                        + 
+--R                                              9   2      8 3      7 5    7
+--R                                          (16a b c  - 24a b c + 8a b )d e
+--R                                        + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                         *
+--R                                             2 6
+--R                                            d e
+--R                                        + 
+--R                                                    8   3       7 3 2       6 5
+--R                                              - 120a b c  + 392a b c  - 280a b c
+--R                                            + 
+--R                                                 5 7
+--R                                              56a b
+--R                                         *
+--R                                             3 5
+--R                                            d e
+--R                                        + 
+--R                                                   8 4       7 2 3       6 4 2
+--R                                              - 38a c  + 422a b c  - 770a b c
+--R                                            + 
+--R                                                  5 6       4 8
+--R                                              420a b c - 70a b
+--R                                         *
+--R                                             4 4
+--R                                            d e
+--R                                        + 
+--R                                                  7   4       6 3 3       5 5 2
+--R                                              160a b c  - 728a b c  + 896a b c
+--R                                            + 
+--R                                                    4 7       3 9
+--R                                              - 392a b c + 56a b
+--R                                         *
+--R                                             5 3
+--R                                            d e
+--R                                        + 
+--R                                                 7 5       6 2 4       5 4 3
+--R                                              12a c  - 252a b c  + 672a b c
+--R                                            + 
+--R                                                    4 6 2       3 8       2 10
+--R                                              - 616a b c  + 224a b c - 28a b
+--R                                         *
+--R                                             6 2
+--R                                            d e
+--R                                        + 
+--R                                                   6   5       5 3 4       4 5 3
+--R                                              - 24a b c  + 176a b c  - 320a b c
+--R                                            + 
+--R                                                  3 7 2      2 9        11
+--R                                              232a b c  - 72a b c + 8a b
+--R                                         *
+--R                                             7
+--R                                            d e
+--R                                        + 
+--R                                                 6 6      5 2 5      4 4 4
+--R                                              - a c  + 12a b c  - 46a b c
+--R                                            + 
+--R                                               3 6 3      2 8 2        10     12
+--R                                            62a b c  - 37a b c  + 10a b  c - b
+--R                                         *
+--R                                             8
+--R                                            d
+--R                                     /
+--R                                                  17 3           16 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 15 4          14 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                    5       4 3  4
+--R                                 (3a b c - a b )e
+--R                               + 
+--R                                    5 2      4 2      3 4    3
+--R                                 (8a c  - 16a b c + 4a b )d e
+--R                               + 
+--R                                       4   2      3 3      2 5  2 2
+--R                                 (- 30a b c  + 30a b c - 6a b )d e
+--R                               + 
+--R                                      4 3      3 2 2      2 4        6  3
+--R                                 (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                               + 
+--R                                    3   3      2 3 2       5     7  4
+--R                                 (7a b c  - 14a b c  + 7a b c - b )d
+--R                            /
+--R                                    9 2        8 2        7 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                           6 2    5 2   6      5   2     4 3     5
+--R                       (- a c  + a b c)e  + (9a b c  - 5a b c)d e
+--R                     + 
+--R                          5 3      4 2 2      3 4   2 4
+--R                       (5a c  - 25a b c  + 10a b c)d e
+--R                     + 
+--R                             4   3      3 3 2      2 5   3 3
+--R                       (- 10a b c  + 30a b c  - 10a b c)d e
+--R                     + 
+--R                          4 4      2 4 2       6   4 2
+--R                       (5a c  - 15a b c  + 5a b c)d e
+--R                     + 
+--R                             3   4      2 3 3      5 2    7   5
+--R                       (- 11a b c  + 10a b c  + a b c  - b c)d e
+--R                     + 
+--R                           3 5     2 2 4       4 3    6 2  6
+--R                       (- a c  + 6a b c  - 5a b c  + b c )d
+--R                  *
+--R                     x
+--R     + 
+--R             3
+--R         3a x
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               9 2        8 2        7 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                        5       4 3  4      5 2      4 2      3 4    3
+--R                     (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                   + 
+--R                           4   2      3 3      2 5  2 2
+--R                     (- 30a b c  + 30a b c - 6a b )d e
+--R                   + 
+--R                          4 3      3 2 2      2 4        6  3
+--R                     (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                   + 
+--R                        3   3      2 3 2       5     7  4
+--R                     (7a b c  - 14a b c  + 7a b c - b )d
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                         10 3
+--R                    8192a  c d
+--R                 *
+--R                    ROOT
+--R                               10 2     9 2     8 4  8
+--R                           (- a  c  + 2a b c - a b )e
+--R                         + 
+--R                               9   2      8 3      7 5    7
+--R                           (16a b c  - 24a b c + 8a b )d e
+--R                         + 
+--R                               9 3       8 2 2       7 4       6 6  2 6
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                  8   3       7 3 2       6 5       5 7  3 5
+--R                           (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                         + 
+--R                                    8 4       7 2 3       6 4 2       5 6
+--R                               - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                             + 
+--R                                    4 8
+--R                               - 70a b
+--R                          *
+--R                              4 4
+--R                             d e
+--R                         + 
+--R                                   7   4       6 3 3       5 5 2       4 7
+--R                               160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                             + 
+--R                                  3 9
+--R                               56a b
+--R                          *
+--R                              5 3
+--R                             d e
+--R                         + 
+--R                                  7 5       6 2 4       5 4 3       4 6 2
+--R                               12a c  - 252a b c  + 672a b c  - 616a b c
+--R                             + 
+--R                                   3 8       2 10
+--R                               224a b c - 28a b
+--R                          *
+--R                              6 2
+--R                             d e
+--R                         + 
+--R                                    6   5       5 3 4       4 5 3       3 7 2
+--R                               - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                             + 
+--R                                    2 9        11
+--R                               - 72a b c + 8a b
+--R                          *
+--R                              7
+--R                             d e
+--R                         + 
+--R                                  6 6      5 2 5      4 4 4      3 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    2 8 2        10     12
+--R                               - 37a b c  + 10a b  c - b
+--R                          *
+--R                              8
+--R                             d
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                       7 2     6     5  5
+--R                  (- 4a c  - 5a c - a )e
+--R                + 
+--R                      6 3       5 2      4       3  2 3
+--R                  (24a c  + 110a c  + 66a c + 10a )d e
+--R                + 
+--R                       5 4      4 3       3 2      2        4
+--R                  (- 4a c  - 73a c  - 102a c  - 41a c - 5a)d e
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      9 2        8 2        7 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                         10 2     9 2     8 4  8
+--R                                     (- a  c  + 2a b c - a b )e
+--R                                   + 
+--R                                         9   2      8 3      7 5    7
+--R                                     (16a b c  - 24a b c + 8a b )d e
+--R                                   + 
+--R                                           9 3       8 2 2       7 4       6 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                               8   3       7 3 2       6 5
+--R                                         - 120a b c  + 392a b c  - 280a b c
+--R                                       + 
+--R                                            5 7
+--R                                         56a b
+--R                                    *
+--R                                        3 5
+--R                                       d e
+--R                                   + 
+--R                                              8 4       7 2 3       6 4 2
+--R                                         - 38a c  + 422a b c  - 770a b c
+--R                                       + 
+--R                                             5 6       4 8
+--R                                         420a b c - 70a b
+--R                                    *
+--R                                        4 4
+--R                                       d e
+--R                                   + 
+--R                                             7   4       6 3 3       5 5 2
+--R                                         160a b c  - 728a b c  + 896a b c
+--R                                       + 
+--R                                               4 7       3 9
+--R                                         - 392a b c + 56a b
+--R                                    *
+--R                                        5 3
+--R                                       d e
+--R                                   + 
+--R                                            7 5       6 2 4       5 4 3
+--R                                         12a c  - 252a b c  + 672a b c
+--R                                       + 
+--R                                               4 6 2       3 8       2 10
+--R                                         - 616a b c  + 224a b c - 28a b
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                              6   5       5 3 4       4 5 3
+--R                                         - 24a b c  + 176a b c  - 320a b c
+--R                                       + 
+--R                                             3 7 2      2 9        11
+--R                                         232a b c  - 72a b c + 8a b
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                            6 6      5 2 5      4 4 4      3 6 3
+--R                                         - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                       + 
+--R                                              2 8 2        10     12
+--R                                         - 37a b c  + 10a b  c - b
+--R                                    *
+--R                                        8
+--R                                       d
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               5       4 3  4      5 2      4 2      3 4    3
+--R                            (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 30a b c  + 30a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (7a b c  - 14a b c  + 7a b c - b )d
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                              10 2 2        9 4        8 6
+--R                        (4096a  b c  - 2048a b c + 256a b )e
+--R                      + 
+--R                                9 3 2        8 5        7 7
+--R                        (- 8192a b c  + 2560a b c - 256a b )d
+--R                   *
+--R                      ROOT
+--R                                 10 2     9 2     8 4  8
+--R                             (- a  c  + 2a b c - a b )e
+--R                           + 
+--R                                 9   2      8 3      7 5    7
+--R                             (16a b c  - 24a b c + 8a b )d e
+--R                           + 
+--R                                 9 3       8 2 2       7 4       6 6  2 6
+--R                             (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                           + 
+--R                                    8   3       7 3 2       6 5       5 7  3 5
+--R                             (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                           + 
+--R                                      8 4       7 2 3       6 4 2       5 6
+--R                                 - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                               + 
+--R                                      4 8
+--R                                 - 70a b
+--R                            *
+--R                                4 4
+--R                               d e
+--R                           + 
+--R                                     7   4       6 3 3       5 5 2       4 7
+--R                                 160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                               + 
+--R                                    3 9
+--R                                 56a b
+--R                            *
+--R                                5 3
+--R                               d e
+--R                           + 
+--R                                    7 5       6 2 4       5 4 3       4 6 2
+--R                                 12a c  - 252a b c  + 672a b c  - 616a b c
+--R                               + 
+--R                                     3 8       2 10
+--R                                 224a b c - 28a b
+--R                            *
+--R                                6 2
+--R                               d e
+--R                           + 
+--R                                      6   5       5 3 4       4 5 3       3 7 2
+--R                                 - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                               + 
+--R                                      2 9        11
+--R                                 - 72a b c + 8a b
+--R                            *
+--R                                7
+--R                               d e
+--R                           + 
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            *
+--R                                8
+--R                               d
+--R                        /
+--R                                     17 3           16 2 2          15 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     14 6
+--R                             - 65536a  b
+--R                  + 
+--R                          6 2      5      4    4
+--R                    (- 36a c  - 29a c - 5a )d e
+--R                  + 
+--R                        5 3       4 2      3       2  3 2
+--R                    (72a c  + 154a c  + 74a c + 10a )d e
+--R                  + 
+--R                       4 2 4      3 4 3      2 6 2       8     10  5
+--R                    (4a b c  - 25a b c  + 26a b c  - 9a b c + b  )d
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                        9 2        8 2        7 4
+--R                                (- 4096a c  + 2048a b c - 256a b )
+--R                             *
+--R                                ROOT
+--R                                           10 2     9 2     8 4  8
+--R                                       (- a  c  + 2a b c - a b )e
+--R                                     + 
+--R                                           9   2      8 3      7 5    7
+--R                                       (16a b c  - 24a b c + 8a b )d e
+--R                                     + 
+--R                                                9 3       8 2 2       7 4
+--R                                             12a c  - 112a b c  + 112a b c
+--R                                           + 
+--R                                                  6 6
+--R                                             - 28a b
+--R                                      *
+--R                                          2 6
+--R                                         d e
+--R                                     + 
+--R                                                 8   3       7 3 2       6 5
+--R                                           - 120a b c  + 392a b c  - 280a b c
+--R                                         + 
+--R                                              5 7
+--R                                           56a b
+--R                                      *
+--R                                          3 5
+--R                                         d e
+--R                                     + 
+--R                                                8 4       7 2 3       6 4 2
+--R                                           - 38a c  + 422a b c  - 770a b c
+--R                                         + 
+--R                                               5 6       4 8
+--R                                           420a b c - 70a b
+--R                                      *
+--R                                          4 4
+--R                                         d e
+--R                                     + 
+--R                                               7   4       6 3 3       5 5 2
+--R                                           160a b c  - 728a b c  + 896a b c
+--R                                         + 
+--R                                                 4 7       3 9
+--R                                           - 392a b c + 56a b
+--R                                      *
+--R                                          5 3
+--R                                         d e
+--R                                     + 
+--R                                              7 5       6 2 4       5 4 3
+--R                                           12a c  - 252a b c  + 672a b c
+--R                                         + 
+--R                                                 4 6 2       3 8       2 10
+--R                                           - 616a b c  + 224a b c - 28a b
+--R                                      *
+--R                                          6 2
+--R                                         d e
+--R                                     + 
+--R                                                6   5       5 3 4       4 5 3
+--R                                           - 24a b c  + 176a b c  - 320a b c
+--R                                         + 
+--R                                               3 7 2      2 9        11
+--R                                           232a b c  - 72a b c + 8a b
+--R                                      *
+--R                                          7
+--R                                         d e
+--R                                     + 
+--R                                              6 6      5 2 5      4 4 4
+--R                                           - a c  + 12a b c  - 46a b c
+--R                                         + 
+--R                                              3 6 3      2 8 2        10     12
+--R                                           62a b c  - 37a b c  + 10a b  c - b
+--R                                      *
+--R                                          8
+--R                                         d
+--R                                  /
+--R                                               17 3           16 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              15 4          14 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                 5       4 3  4      5 2      4 2      3 4    3
+--R                              (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                            + 
+--R                                    4   2      3 3      2 5  2 2
+--R                              (- 30a b c  + 30a b c - 6a b )d e
+--R                            + 
+--R                                   4 3      3 2 2      2 4        6  3
+--R                              (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                            + 
+--R                                 3   3      2 3 2       5     7  4
+--R                              (7a b c  - 14a b c  + 7a b c - b )d
+--R                         /
+--R                                 9 2        8 2        7 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                      6 2    5 2   6        5   2     4 3     5
+--R                    (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                  + 
+--R                         5 3      4 2 2      3 4   2 4
+--R                    (- 5a c  + 25a b c  - 10a b c)d e
+--R                  + 
+--R                        4   3      3 3 2      2 5   3 3
+--R                    (10a b c  - 30a b c  + 10a b c)d e
+--R                  + 
+--R                         4 4      2 4 2       6   4 2
+--R                    (- 5a c  + 15a b c  - 5a b c)d e
+--R                  + 
+--R                        3   4      2 3 3      5 2    7   5
+--R                    (11a b c  - 10a b c  - a b c  + b c)d e
+--R                  + 
+--R                      3 5     2 2 4       4 3    6 2  6
+--R                    (a c  - 6a b c  + 5a b c  - b c )d
+--R               *
+--R                  x
+--R     + 
+--R       - 2d
+--R  /
+--R         3
+--R     6a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 243
+
+--S 244 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             9 2        8 2        7 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                        5       4 3  4      5 2      4 2      3 4    3
+--R                     (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                   + 
+--R                           4   2      3 3      2 5  2 2
+--R                     (- 30a b c  + 30a b c - 6a b )d e
+--R                   + 
+--R                          4 3      3 2 2      2 4        6  3
+--R                     (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                   + 
+--R                        3   3      2 3 2       5     7  4
+--R                     (7a b c  - 14a b c  + 7a b c - b )d
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                            10   2        9 3        8 5
+--R                      (4096a  b c  - 2048a b c + 256a b )e
+--R                    + 
+--R                            10 3        9 2 2        8 4        7 6
+--R                      (8192a  c  - 8192a b c  + 2560a b c - 256a b )d
+--R                 *
+--R                    ROOT
+--R                               10 2     9 2     8 4  8
+--R                           (- a  c  + 2a b c - a b )e
+--R                         + 
+--R                               9   2      8 3      7 5    7
+--R                           (16a b c  - 24a b c + 8a b )d e
+--R                         + 
+--R                               9 3       8 2 2       7 4       6 6  2 6
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                  8   3       7 3 2       6 5       5 7  3 5
+--R                           (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                         + 
+--R                                    8 4       7 2 3       6 4 2       5 6
+--R                               - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                             + 
+--R                                    4 8
+--R                               - 70a b
+--R                          *
+--R                              4 4
+--R                             d e
+--R                         + 
+--R                                   7   4       6 3 3       5 5 2       4 7
+--R                               160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                             + 
+--R                                  3 9
+--R                               56a b
+--R                          *
+--R                              5 3
+--R                             d e
+--R                         + 
+--R                                  7 5       6 2 4       5 4 3       4 6 2
+--R                               12a c  - 252a b c  + 672a b c  - 616a b c
+--R                             + 
+--R                                   3 8       2 10
+--R                               224a b c - 28a b
+--R                          *
+--R                              6 2
+--R                             d e
+--R                         + 
+--R                                    6   5       5 3 4       4 5 3       3 7 2
+--R                               - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                             + 
+--R                                    2 9        11
+--R                               - 72a b c + 8a b
+--R                          *
+--R                              7
+--R                             d e
+--R                         + 
+--R                                  6 6      5 2 5      4 4 4      3 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    2 8 2        10     12
+--R                               - 37a b c  + 10a b  c - b
+--R                          *
+--R                              8
+--R                             d
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                     7 2     6 2     5 4  5         6   2      5 3      4 5    4
+--R                  (4a c  - 5a b c + a b )e  + (- 36a b c  + 29a b c - 5a b )d e
+--R                + 
+--R                        6 3       5 2 2      4 4       3 6  2 3
+--R                  (- 24a c  + 110a b c  - 66a b c + 10a b )d e
+--R                + 
+--R                      5   3       4 3 2      3 5       2 7  3 2
+--R                  (72a b c  - 154a b c  + 74a b c - 10a b )d e
+--R                + 
+--R                     5 4      4 2 3       3 4 2      2 6        8  4
+--R                  (4a c  - 73a b c  + 102a b c  - 41a b c + 5a b )d e
+--R                + 
+--R                       4   4      3 3 3      2 5 2       7     9  5
+--R                  (- 4a b c  + 25a b c  - 26a b c  + 9a b c - b )d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    9 2        8 2        7 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                         10 2     9 2     8 4  8
+--R                                     (- a  c  + 2a b c - a b )e
+--R                                   + 
+--R                                         9   2      8 3      7 5    7
+--R                                     (16a b c  - 24a b c + 8a b )d e
+--R                                   + 
+--R                                           9 3       8 2 2       7 4       6 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                               8   3       7 3 2       6 5
+--R                                         - 120a b c  + 392a b c  - 280a b c
+--R                                       + 
+--R                                            5 7
+--R                                         56a b
+--R                                    *
+--R                                        3 5
+--R                                       d e
+--R                                   + 
+--R                                              8 4       7 2 3       6 4 2
+--R                                         - 38a c  + 422a b c  - 770a b c
+--R                                       + 
+--R                                             5 6       4 8
+--R                                         420a b c - 70a b
+--R                                    *
+--R                                        4 4
+--R                                       d e
+--R                                   + 
+--R                                             7   4       6 3 3       5 5 2
+--R                                         160a b c  - 728a b c  + 896a b c
+--R                                       + 
+--R                                               4 7       3 9
+--R                                         - 392a b c + 56a b
+--R                                    *
+--R                                        5 3
+--R                                       d e
+--R                                   + 
+--R                                            7 5       6 2 4       5 4 3
+--R                                         12a c  - 252a b c  + 672a b c
+--R                                       + 
+--R                                               4 6 2       3 8       2 10
+--R                                         - 616a b c  + 224a b c - 28a b
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                              6   5       5 3 4       4 5 3
+--R                                         - 24a b c  + 176a b c  - 320a b c
+--R                                       + 
+--R                                             3 7 2      2 9        11
+--R                                         232a b c  - 72a b c + 8a b
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                            6 6      5 2 5      4 4 4      3 6 3
+--R                                         - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                       + 
+--R                                              2 8 2        10     12
+--R                                         - 37a b c  + 10a b  c - b
+--R                                    *
+--R                                        8
+--R                                       d
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               5       4 3  4      5 2      4 2      3 4    3
+--R                            (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 30a b c  + 30a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (7a b c  - 14a b c  + 7a b c - b )d
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                    6 2    5 2   6        5   2     4 3     5
+--R                  (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                + 
+--R                       5 3      4 2 2      3 4   2 4
+--R                  (- 5a c  + 25a b c  - 10a b c)d e
+--R                + 
+--R                      4   3      3 3 2      2 5   3 3
+--R                  (10a b c  - 30a b c  + 10a b c)d e
+--R                + 
+--R                       4 4      2 4 2       6   4 2
+--R                  (- 5a c  + 15a b c  - 5a b c)d e
+--R                + 
+--R                      3   4      2 3 3      5 2    7   5
+--R                  (11a b c  - 10a b c  - a b c  + b c)d e
+--R                + 
+--R                    3 5     2 2 4       4 3    6 2  6
+--R                  (a c  - 6a b c  + 5a b c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                +--------------------+3  +------------------+3
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             4+-+ |          2 4|   |          2        4| |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  9 2        8 2        7 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                     10 2     9 2     8 4  8
+--R                                 (- a  c  + 2a b c - a b )e
+--R                               + 
+--R                                     9   2      8 3      7 5    7
+--R                                 (16a b c  - 24a b c + 8a b )d e
+--R                               + 
+--R                                     9 3       8 2 2       7 4       6 6  2 6
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                          8   3       7 3 2       6 5       5 7
+--R                                   (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                                *
+--R                                    3 5
+--R                                   d e
+--R                               + 
+--R                                          8 4       7 2 3       6 4 2       5 6
+--R                                     - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                   + 
+--R                                          4 8
+--R                                     - 70a b
+--R                                *
+--R                                    4 4
+--R                                   d e
+--R                               + 
+--R                                         7   4       6 3 3       5 5 2
+--R                                     160a b c  - 728a b c  + 896a b c
+--R                                   + 
+--R                                           4 7       3 9
+--R                                     - 392a b c + 56a b
+--R                                *
+--R                                    5 3
+--R                                   d e
+--R                               + 
+--R                                        7 5       6 2 4       5 4 3       4 6 2
+--R                                     12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                   + 
+--R                                         3 8       2 10
+--R                                     224a b c - 28a b
+--R                                *
+--R                                    6 2
+--R                                   d e
+--R                               + 
+--R                                          6   5       5 3 4       4 5 3
+--R                                     - 24a b c  + 176a b c  - 320a b c
+--R                                   + 
+--R                                         3 7 2      2 9        11
+--R                                     232a b c  - 72a b c + 8a b
+--R                                *
+--R                                    7
+--R                                   d e
+--R                               + 
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                *
+--R                                    8
+--R                                   d
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           5       4 3  4      5 2      4 2      3 4    3
+--R                        (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                      + 
+--R                              4   2      3 3      2 5  2 2
+--R                        (- 30a b c  + 30a b c - 6a b )d e
+--R                      + 
+--R                             4 3      3 2 2      2 4        6  3
+--R                        (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                      + 
+--R                           3   3      2 3 2       5     7  4
+--R                        (7a b c  - 14a b c  + 7a b c - b )d
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                               10   2        9 3        8 5
+--R                         (4096a  b c  - 2048a b c + 256a b )e
+--R                       + 
+--R                               10 3        9 2 2        8 4        7 6
+--R                         (8192a  c  - 8192a b c  + 2560a b c - 256a b )d
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                          7 2     6 2     5 4  5
+--R                     (- 4a c  + 5a b c - a b )e
+--R                   + 
+--R                         6   2      5 3      4 5    4
+--R                     (36a b c  - 29a b c + 5a b )d e
+--R                   + 
+--R                         6 3       5 2 2      4 4       3 6  2 3
+--R                     (24a c  - 110a b c  + 66a b c - 10a b )d e
+--R                   + 
+--R                           5   3       4 3 2      3 5       2 7  3 2
+--R                     (- 72a b c  + 154a b c  - 74a b c + 10a b )d e
+--R                   + 
+--R                          5 4      4 2 3       3 4 2      2 6        8  4
+--R                     (- 4a c  + 73a b c  - 102a b c  + 41a b c - 5a b )d e
+--R                   + 
+--R                        4   4      3 3 3      2 5 2       7     9  5
+--R                     (4a b c  - 25a b c  + 26a b c  - 9a b c + b )d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         9 2        8 2        7 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                            10 2     9 2     8 4  8
+--R                                        (- a  c  + 2a b c - a b )e
+--R                                      + 
+--R                                            9   2      8 3      7 5    7
+--R                                        (16a b c  - 24a b c + 8a b )d e
+--R                                      + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                                  8   3       7 3 2       6 5
+--R                                            - 120a b c  + 392a b c  - 280a b c
+--R                                          + 
+--R                                               5 7
+--R                                            56a b
+--R                                       *
+--R                                           3 5
+--R                                          d e
+--R                                      + 
+--R                                                 8 4       7 2 3       6 4 2
+--R                                            - 38a c  + 422a b c  - 770a b c
+--R                                          + 
+--R                                                5 6       4 8
+--R                                            420a b c - 70a b
+--R                                       *
+--R                                           4 4
+--R                                          d e
+--R                                      + 
+--R                                                7   4       6 3 3       5 5 2
+--R                                            160a b c  - 728a b c  + 896a b c
+--R                                          + 
+--R                                                  4 7       3 9
+--R                                            - 392a b c + 56a b
+--R                                       *
+--R                                           5 3
+--R                                          d e
+--R                                      + 
+--R                                               7 5       6 2 4       5 4 3
+--R                                            12a c  - 252a b c  + 672a b c
+--R                                          + 
+--R                                                  4 6 2       3 8       2 10
+--R                                            - 616a b c  + 224a b c - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 6   5       5 3 4       4 5 3
+--R                                            - 24a b c  + 176a b c  - 320a b c
+--R                                          + 
+--R                                                3 7 2      2 9        11
+--R                                            232a b c  - 72a b c + 8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               6 6      5 2 5      4 4 4
+--R                                            - a c  + 12a b c  - 46a b c
+--R                                          + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  5       4 3  4      5 2      4 2      3 4    3
+--R                               (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                     4   2      3 3      2 5  2 2
+--R                               (- 30a b c  + 30a b c - 6a b )d e
+--R                             + 
+--R                                    4 3      3 2 2      2 4        6  3
+--R                               (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                             + 
+--R                                  3   3      2 3 2       5     7  4
+--R                               (7a b c  - 14a b c  + 7a b c - b )d
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                       6 2    5 2   6        5   2     4 3     5
+--R                     (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                   + 
+--R                          5 3      4 2 2      3 4   2 4
+--R                     (- 5a c  + 25a b c  - 10a b c)d e
+--R                   + 
+--R                         4   3      3 3 2      2 5   3 3
+--R                     (10a b c  - 30a b c  + 10a b c)d e
+--R                   + 
+--R                          4 4      2 4 2       6   4 2
+--R                     (- 5a c  + 15a b c  - 5a b c)d e
+--R                   + 
+--R                         3   4      2 3 3      5 2    7   5
+--R                     (11a b c  - 10a b c  - a b c  + b c)d e
+--R                   + 
+--R                       3 5     2 2 4       4 3    6 2  6
+--R                     (a c  - 6a b c  + 5a b c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               9 2        8 2        7 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                        5       4 3  4      5 2      4 2      3 4    3
+--R                     (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                   + 
+--R                           4   2      3 3      2 5  2 2
+--R                     (- 30a b c  + 30a b c - 6a b )d e
+--R                   + 
+--R                          4 3      3 2 2      2 4        6  3
+--R                     (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                   + 
+--R                        3   3      2 3 2       5     7  4
+--R                     (7a b c  - 14a b c  + 7a b c - b )d
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         log
+--R                              10   2        9 3        8 5
+--R                      (- 4096a  b c  + 2048a b c - 256a b )e
+--R                    + 
+--R                              10 3        9 2 2        8 4        7 6
+--R                      (- 8192a  c  + 8192a b c  - 2560a b c + 256a b )d
+--R                 *
+--R                    ROOT
+--R                               10 2     9 2     8 4  8
+--R                           (- a  c  + 2a b c - a b )e
+--R                         + 
+--R                               9   2      8 3      7 5    7
+--R                           (16a b c  - 24a b c + 8a b )d e
+--R                         + 
+--R                               9 3       8 2 2       7 4       6 6  2 6
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                  8   3       7 3 2       6 5       5 7  3 5
+--R                           (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                         + 
+--R                                    8 4       7 2 3       6 4 2       5 6
+--R                               - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                             + 
+--R                                    4 8
+--R                               - 70a b
+--R                          *
+--R                              4 4
+--R                             d e
+--R                         + 
+--R                                   7   4       6 3 3       5 5 2       4 7
+--R                               160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                             + 
+--R                                  3 9
+--R                               56a b
+--R                          *
+--R                              5 3
+--R                             d e
+--R                         + 
+--R                                  7 5       6 2 4       5 4 3       4 6 2
+--R                               12a c  - 252a b c  + 672a b c  - 616a b c
+--R                             + 
+--R                                   3 8       2 10
+--R                               224a b c - 28a b
+--R                          *
+--R                              6 2
+--R                             d e
+--R                         + 
+--R                                    6   5       5 3 4       4 5 3       3 7 2
+--R                               - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                             + 
+--R                                    2 9        11
+--R                               - 72a b c + 8a b
+--R                          *
+--R                              7
+--R                             d e
+--R                         + 
+--R                                  6 6      5 2 5      4 4 4      3 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    2 8 2        10     12
+--R                               - 37a b c  + 10a b  c - b
+--R                          *
+--R                              8
+--R                             d
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                     7 2     6 2     5 4  5         6   2      5 3      4 5    4
+--R                  (4a c  - 5a b c + a b )e  + (- 36a b c  + 29a b c - 5a b )d e
+--R                + 
+--R                        6 3       5 2 2      4 4       3 6  2 3
+--R                  (- 24a c  + 110a b c  - 66a b c + 10a b )d e
+--R                + 
+--R                      5   3       4 3 2      3 5       2 7  3 2
+--R                  (72a b c  - 154a b c  + 74a b c - 10a b )d e
+--R                + 
+--R                     5 4      4 2 3       3 4 2      2 6        8  4
+--R                  (4a c  - 73a b c  + 102a b c  - 41a b c + 5a b )d e
+--R                + 
+--R                       4   4      3 3 3      2 5 2       7     9  5
+--R                  (- 4a b c  + 25a b c  - 26a b c  + 9a b c - b )d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      9 2        8 2        7 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                         10 2     9 2     8 4  8
+--R                                     (- a  c  + 2a b c - a b )e
+--R                                   + 
+--R                                         9   2      8 3      7 5    7
+--R                                     (16a b c  - 24a b c + 8a b )d e
+--R                                   + 
+--R                                           9 3       8 2 2       7 4       6 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                               8   3       7 3 2       6 5
+--R                                         - 120a b c  + 392a b c  - 280a b c
+--R                                       + 
+--R                                            5 7
+--R                                         56a b
+--R                                    *
+--R                                        3 5
+--R                                       d e
+--R                                   + 
+--R                                              8 4       7 2 3       6 4 2
+--R                                         - 38a c  + 422a b c  - 770a b c
+--R                                       + 
+--R                                             5 6       4 8
+--R                                         420a b c - 70a b
+--R                                    *
+--R                                        4 4
+--R                                       d e
+--R                                   + 
+--R                                             7   4       6 3 3       5 5 2
+--R                                         160a b c  - 728a b c  + 896a b c
+--R                                       + 
+--R                                               4 7       3 9
+--R                                         - 392a b c + 56a b
+--R                                    *
+--R                                        5 3
+--R                                       d e
+--R                                   + 
+--R                                            7 5       6 2 4       5 4 3
+--R                                         12a c  - 252a b c  + 672a b c
+--R                                       + 
+--R                                               4 6 2       3 8       2 10
+--R                                         - 616a b c  + 224a b c - 28a b
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                              6   5       5 3 4       4 5 3
+--R                                         - 24a b c  + 176a b c  - 320a b c
+--R                                       + 
+--R                                             3 7 2      2 9        11
+--R                                         232a b c  - 72a b c + 8a b
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                            6 6      5 2 5      4 4 4      3 6 3
+--R                                         - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                       + 
+--R                                              2 8 2        10     12
+--R                                         - 37a b c  + 10a b  c - b
+--R                                    *
+--R                                        8
+--R                                       d
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               5       4 3  4      5 2      4 2      3 4    3
+--R                            (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 30a b c  + 30a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (7a b c  - 14a b c  + 7a b c - b )d
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R            + 
+--R                    6 2    5 2   6        5   2     4 3     5
+--R                  (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                + 
+--R                       5 3      4 2 2      3 4   2 4
+--R                  (- 5a c  + 25a b c  - 10a b c)d e
+--R                + 
+--R                      4   3      3 3 2      2 5   3 3
+--R                  (10a b c  - 30a b c  + 10a b c)d e
+--R                + 
+--R                       4 4      2 4 2       6   4 2
+--R                  (- 5a c  + 15a b c  - 5a b c)d e
+--R                + 
+--R                      3   4      2 3 3      5 2    7   5
+--R                  (11a b c  - 10a b c  - a b c  + b c)d e
+--R                + 
+--R                    3 5     2 2 4       4 3    6 2  6
+--R                  (a c  - 6a b c  + 5a b c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                +--------------------+3  +------------------+3
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             4+-+ |          2 4|   |          2        4| |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                9 2        8 2        7 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                     10 2     9 2     8 4  8
+--R                                 (- a  c  + 2a b c - a b )e
+--R                               + 
+--R                                     9   2      8 3      7 5    7
+--R                                 (16a b c  - 24a b c + 8a b )d e
+--R                               + 
+--R                                     9 3       8 2 2       7 4       6 6  2 6
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                          8   3       7 3 2       6 5       5 7
+--R                                   (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                                *
+--R                                    3 5
+--R                                   d e
+--R                               + 
+--R                                          8 4       7 2 3       6 4 2       5 6
+--R                                     - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                   + 
+--R                                          4 8
+--R                                     - 70a b
+--R                                *
+--R                                    4 4
+--R                                   d e
+--R                               + 
+--R                                         7   4       6 3 3       5 5 2
+--R                                     160a b c  - 728a b c  + 896a b c
+--R                                   + 
+--R                                           4 7       3 9
+--R                                     - 392a b c + 56a b
+--R                                *
+--R                                    5 3
+--R                                   d e
+--R                               + 
+--R                                        7 5       6 2 4       5 4 3       4 6 2
+--R                                     12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                   + 
+--R                                         3 8       2 10
+--R                                     224a b c - 28a b
+--R                                *
+--R                                    6 2
+--R                                   d e
+--R                               + 
+--R                                          6   5       5 3 4       4 5 3
+--R                                     - 24a b c  + 176a b c  - 320a b c
+--R                                   + 
+--R                                         3 7 2      2 9        11
+--R                                     232a b c  - 72a b c + 8a b
+--R                                *
+--R                                    7
+--R                                   d e
+--R                               + 
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                *
+--R                                    8
+--R                                   d
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           5       4 3  4      5 2      4 2      3 4    3
+--R                        (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                      + 
+--R                              4   2      3 3      2 5  2 2
+--R                        (- 30a b c  + 30a b c - 6a b )d e
+--R                      + 
+--R                             4 3      3 2 2      2 4        6  3
+--R                        (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                      + 
+--R                           3   3      2 3 2       5     7  4
+--R                        (7a b c  - 14a b c  + 7a b c - b )d
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            log
+--R                                 10   2        9 3        8 5
+--R                         (- 4096a  b c  + 2048a b c - 256a b )e
+--R                       + 
+--R                                 10 3        9 2 2        8 4        7 6
+--R                         (- 8192a  c  + 8192a b c  - 2560a b c + 256a b )d
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                          7 2     6 2     5 4  5
+--R                     (- 4a c  + 5a b c - a b )e
+--R                   + 
+--R                         6   2      5 3      4 5    4
+--R                     (36a b c  - 29a b c + 5a b )d e
+--R                   + 
+--R                         6 3       5 2 2      4 4       3 6  2 3
+--R                     (24a c  - 110a b c  + 66a b c - 10a b )d e
+--R                   + 
+--R                           5   3       4 3 2      3 5       2 7  3 2
+--R                     (- 72a b c  + 154a b c  - 74a b c + 10a b )d e
+--R                   + 
+--R                          5 4      4 2 3       3 4 2      2 6        8  4
+--R                     (- 4a c  + 73a b c  - 102a b c  + 41a b c - 5a b )d e
+--R                   + 
+--R                        4   4      3 3 3      2 5 2       7     9  5
+--R                     (4a b c  - 25a b c  + 26a b c  - 9a b c + b )d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       9 2        8 2        7 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                            10 2     9 2     8 4  8
+--R                                        (- a  c  + 2a b c - a b )e
+--R                                      + 
+--R                                            9   2      8 3      7 5    7
+--R                                        (16a b c  - 24a b c + 8a b )d e
+--R                                      + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                                  8   3       7 3 2       6 5
+--R                                            - 120a b c  + 392a b c  - 280a b c
+--R                                          + 
+--R                                               5 7
+--R                                            56a b
+--R                                       *
+--R                                           3 5
+--R                                          d e
+--R                                      + 
+--R                                                 8 4       7 2 3       6 4 2
+--R                                            - 38a c  + 422a b c  - 770a b c
+--R                                          + 
+--R                                                5 6       4 8
+--R                                            420a b c - 70a b
+--R                                       *
+--R                                           4 4
+--R                                          d e
+--R                                      + 
+--R                                                7   4       6 3 3       5 5 2
+--R                                            160a b c  - 728a b c  + 896a b c
+--R                                          + 
+--R                                                  4 7       3 9
+--R                                            - 392a b c + 56a b
+--R                                       *
+--R                                           5 3
+--R                                          d e
+--R                                      + 
+--R                                               7 5       6 2 4       5 4 3
+--R                                            12a c  - 252a b c  + 672a b c
+--R                                          + 
+--R                                                  4 6 2       3 8       2 10
+--R                                            - 616a b c  + 224a b c - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 6   5       5 3 4       4 5 3
+--R                                            - 24a b c  + 176a b c  - 320a b c
+--R                                          + 
+--R                                                3 7 2      2 9        11
+--R                                            232a b c  - 72a b c + 8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               6 6      5 2 5      4 4 4
+--R                                            - a c  + 12a b c  - 46a b c
+--R                                          + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  5       4 3  4      5 2      4 2      3 4    3
+--R                               (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                     4   2      3 3      2 5  2 2
+--R                               (- 30a b c  + 30a b c - 6a b )d e
+--R                             + 
+--R                                    4 3      3 2 2      2 4        6  3
+--R                               (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                             + 
+--R                                  3   3      2 3 2       5     7  4
+--R                               (7a b c  - 14a b c  + 7a b c - b )d
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R               + 
+--R                       6 2    5 2   6        5   2     4 3     5
+--R                     (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                   + 
+--R                          5 3      4 2 2      3 4   2 4
+--R                     (- 5a c  + 25a b c  - 10a b c)d e
+--R                   + 
+--R                         4   3      3 3 2      2 5   3 3
+--R                     (10a b c  - 30a b c  + 10a b c)d e
+--R                   + 
+--R                          4 4      2 4 2       6   4 2
+--R                     (- 5a c  + 15a b c  - 5a b c)d e
+--R                   + 
+--R                         3   4      2 3 3      5 2    7   5
+--R                     (11a b c  - 10a b c  - a b c  + b c)d e
+--R                   + 
+--R                       3 5     2 2 4       4 3    6 2  6
+--R                     (a c  - 6a b c  + 5a b c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             9 2        8 2        7 4
+--R                       (4096a c  - 2048a b c + 256a b )
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                        5       4 3  4      5 2      4 2      3 4    3
+--R                     (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                   + 
+--R                           4   2      3 3      2 5  2 2
+--R                     (- 30a b c  + 30a b c - 6a b )d e
+--R                   + 
+--R                          4 3      3 2 2      2 4        6  3
+--R                     (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                   + 
+--R                        3   3      2 3 2       5     7  4
+--R                     (7a b c  - 14a b c  + 7a b c - b )d
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                         10 3
+--R                    8192a  c d
+--R                 *
+--R                    ROOT
+--R                               10 2     9 2     8 4  8
+--R                           (- a  c  + 2a b c - a b )e
+--R                         + 
+--R                               9   2      8 3      7 5    7
+--R                           (16a b c  - 24a b c + 8a b )d e
+--R                         + 
+--R                               9 3       8 2 2       7 4       6 6  2 6
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                  8   3       7 3 2       6 5       5 7  3 5
+--R                           (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                         + 
+--R                                    8 4       7 2 3       6 4 2       5 6
+--R                               - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                             + 
+--R                                    4 8
+--R                               - 70a b
+--R                          *
+--R                              4 4
+--R                             d e
+--R                         + 
+--R                                   7   4       6 3 3       5 5 2       4 7
+--R                               160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                             + 
+--R                                  3 9
+--R                               56a b
+--R                          *
+--R                              5 3
+--R                             d e
+--R                         + 
+--R                                  7 5       6 2 4       5 4 3       4 6 2
+--R                               12a c  - 252a b c  + 672a b c  - 616a b c
+--R                             + 
+--R                                   3 8       2 10
+--R                               224a b c - 28a b
+--R                          *
+--R                              6 2
+--R                             d e
+--R                         + 
+--R                                    6   5       5 3 4       4 5 3       3 7 2
+--R                               - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                             + 
+--R                                    2 9        11
+--R                               - 72a b c + 8a b
+--R                          *
+--R                              7
+--R                             d e
+--R                         + 
+--R                                  6 6      5 2 5      4 4 4      3 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    2 8 2        10     12
+--R                               - 37a b c  + 10a b  c - b
+--R                          *
+--R                              8
+--R                             d
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                     7 2     6     5  5
+--R                  (4a c  + 5a c + a )e
+--R                + 
+--R                        6 3       5 2      4       3  2 3
+--R                  (- 24a c  - 110a c  - 66a c - 10a )d e
+--R                + 
+--R                     5 4      4 3       3 2      2        4
+--R                  (4a c  + 73a c  + 102a c  + 41a c + 5a)d e
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    9 2        8 2        7 4
+--R                              (4096a c  - 2048a b c + 256a b )
+--R                           *
+--R                              ROOT
+--R                                         10 2     9 2     8 4  8
+--R                                     (- a  c  + 2a b c - a b )e
+--R                                   + 
+--R                                         9   2      8 3      7 5    7
+--R                                     (16a b c  - 24a b c + 8a b )d e
+--R                                   + 
+--R                                           9 3       8 2 2       7 4       6 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                               8   3       7 3 2       6 5
+--R                                         - 120a b c  + 392a b c  - 280a b c
+--R                                       + 
+--R                                            5 7
+--R                                         56a b
+--R                                    *
+--R                                        3 5
+--R                                       d e
+--R                                   + 
+--R                                              8 4       7 2 3       6 4 2
+--R                                         - 38a c  + 422a b c  - 770a b c
+--R                                       + 
+--R                                             5 6       4 8
+--R                                         420a b c - 70a b
+--R                                    *
+--R                                        4 4
+--R                                       d e
+--R                                   + 
+--R                                             7   4       6 3 3       5 5 2
+--R                                         160a b c  - 728a b c  + 896a b c
+--R                                       + 
+--R                                               4 7       3 9
+--R                                         - 392a b c + 56a b
+--R                                    *
+--R                                        5 3
+--R                                       d e
+--R                                   + 
+--R                                            7 5       6 2 4       5 4 3
+--R                                         12a c  - 252a b c  + 672a b c
+--R                                       + 
+--R                                               4 6 2       3 8       2 10
+--R                                         - 616a b c  + 224a b c - 28a b
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                              6   5       5 3 4       4 5 3
+--R                                         - 24a b c  + 176a b c  - 320a b c
+--R                                       + 
+--R                                             3 7 2      2 9        11
+--R                                         232a b c  - 72a b c + 8a b
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                            6 6      5 2 5      4 4 4      3 6 3
+--R                                         - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                       + 
+--R                                              2 8 2        10     12
+--R                                         - 37a b c  + 10a b  c - b
+--R                                    *
+--R                                        8
+--R                                       d
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               5       4 3  4      5 2      4 2      3 4    3
+--R                            (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 30a b c  + 30a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (7a b c  - 14a b c  + 7a b c - b )d
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                              10 2 2        9 4        8 6
+--R                        (4096a  b c  - 2048a b c + 256a b )e
+--R                      + 
+--R                                9 3 2        8 5        7 7
+--R                        (- 8192a b c  + 2560a b c - 256a b )d
+--R                   *
+--R                      ROOT
+--R                                 10 2     9 2     8 4  8
+--R                             (- a  c  + 2a b c - a b )e
+--R                           + 
+--R                                 9   2      8 3      7 5    7
+--R                             (16a b c  - 24a b c + 8a b )d e
+--R                           + 
+--R                                 9 3       8 2 2       7 4       6 6  2 6
+--R                             (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                           + 
+--R                                    8   3       7 3 2       6 5       5 7  3 5
+--R                             (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                           + 
+--R                                      8 4       7 2 3       6 4 2       5 6
+--R                                 - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                               + 
+--R                                      4 8
+--R                                 - 70a b
+--R                            *
+--R                                4 4
+--R                               d e
+--R                           + 
+--R                                     7   4       6 3 3       5 5 2       4 7
+--R                                 160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                               + 
+--R                                    3 9
+--R                                 56a b
+--R                            *
+--R                                5 3
+--R                               d e
+--R                           + 
+--R                                    7 5       6 2 4       5 4 3       4 6 2
+--R                                 12a c  - 252a b c  + 672a b c  - 616a b c
+--R                               + 
+--R                                     3 8       2 10
+--R                                 224a b c - 28a b
+--R                            *
+--R                                6 2
+--R                               d e
+--R                           + 
+--R                                      6   5       5 3 4       4 5 3       3 7 2
+--R                                 - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                               + 
+--R                                      2 9        11
+--R                                 - 72a b c + 8a b
+--R                            *
+--R                                7
+--R                               d e
+--R                           + 
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            *
+--R                                8
+--R                               d
+--R                        /
+--R                                     17 3           16 2 2          15 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     14 6
+--R                             - 65536a  b
+--R                  + 
+--R                        6 2      5      4    4
+--R                    (36a c  + 29a c + 5a )d e
+--R                  + 
+--R                          5 3       4 2      3       2  3 2
+--R                    (- 72a c  - 154a c  - 74a c - 10a )d e
+--R                  + 
+--R                         4 2 4      3 4 3      2 6 2       8     10  5
+--R                    (- 4a b c  + 25a b c  - 26a b c  + 9a b c - b  )d
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                      9 2        8 2        7 4
+--R                                (4096a c  - 2048a b c + 256a b )
+--R                             *
+--R                                ROOT
+--R                                           10 2     9 2     8 4  8
+--R                                       (- a  c  + 2a b c - a b )e
+--R                                     + 
+--R                                           9   2      8 3      7 5    7
+--R                                       (16a b c  - 24a b c + 8a b )d e
+--R                                     + 
+--R                                                9 3       8 2 2       7 4
+--R                                             12a c  - 112a b c  + 112a b c
+--R                                           + 
+--R                                                  6 6
+--R                                             - 28a b
+--R                                      *
+--R                                          2 6
+--R                                         d e
+--R                                     + 
+--R                                                 8   3       7 3 2       6 5
+--R                                           - 120a b c  + 392a b c  - 280a b c
+--R                                         + 
+--R                                              5 7
+--R                                           56a b
+--R                                      *
+--R                                          3 5
+--R                                         d e
+--R                                     + 
+--R                                                8 4       7 2 3       6 4 2
+--R                                           - 38a c  + 422a b c  - 770a b c
+--R                                         + 
+--R                                               5 6       4 8
+--R                                           420a b c - 70a b
+--R                                      *
+--R                                          4 4
+--R                                         d e
+--R                                     + 
+--R                                               7   4       6 3 3       5 5 2
+--R                                           160a b c  - 728a b c  + 896a b c
+--R                                         + 
+--R                                                 4 7       3 9
+--R                                           - 392a b c + 56a b
+--R                                      *
+--R                                          5 3
+--R                                         d e
+--R                                     + 
+--R                                              7 5       6 2 4       5 4 3
+--R                                           12a c  - 252a b c  + 672a b c
+--R                                         + 
+--R                                                 4 6 2       3 8       2 10
+--R                                           - 616a b c  + 224a b c - 28a b
+--R                                      *
+--R                                          6 2
+--R                                         d e
+--R                                     + 
+--R                                                6   5       5 3 4       4 5 3
+--R                                           - 24a b c  + 176a b c  - 320a b c
+--R                                         + 
+--R                                               3 7 2      2 9        11
+--R                                           232a b c  - 72a b c + 8a b
+--R                                      *
+--R                                          7
+--R                                         d e
+--R                                     + 
+--R                                              6 6      5 2 5      4 4 4
+--R                                           - a c  + 12a b c  - 46a b c
+--R                                         + 
+--R                                              3 6 3      2 8 2        10     12
+--R                                           62a b c  - 37a b c  + 10a b  c - b
+--R                                      *
+--R                                          8
+--R                                         d
+--R                                  /
+--R                                               17 3           16 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              15 4          14 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                 5       4 3  4      5 2      4 2      3 4    3
+--R                              (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                            + 
+--R                                    4   2      3 3      2 5  2 2
+--R                              (- 30a b c  + 30a b c - 6a b )d e
+--R                            + 
+--R                                   4 3      3 2 2      2 4        6  3
+--R                              (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                            + 
+--R                                 3   3      2 3 2       5     7  4
+--R                              (7a b c  - 14a b c  + 7a b c - b )d
+--R                         /
+--R                                 9 2        8 2        7 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                        6 2    5 2   6      5   2     4 3     5
+--R                    (- a c  + a b c)e  + (9a b c  - 5a b c)d e
+--R                  + 
+--R                       5 3      4 2 2      3 4   2 4
+--R                    (5a c  - 25a b c  + 10a b c)d e
+--R                  + 
+--R                          4   3      3 3 2      2 5   3 3
+--R                    (- 10a b c  + 30a b c  - 10a b c)d e
+--R                  + 
+--R                       4 4      2 4 2       6   4 2
+--R                    (5a c  - 15a b c  + 5a b c)d e
+--R                  + 
+--R                          3   4      2 3 3      5 2    7   5
+--R                    (- 11a b c  + 10a b c  + a b c  - b c)d e
+--R                  + 
+--R                        3 5     2 2 4       4 3    6 2  6
+--R                    (- a c  + 6a b c  - 5a b c  + b c )d
+--R               *
+--R                  x
+--R     + 
+--R       -
+--R                                +--------------------+3  +------------------+3
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             4+-+ |          2 4|   |          2        4| |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                9 2        8 2        7 4
+--R                          (4096a c  - 2048a b c + 256a b )
+--R                       *
+--R                          ROOT
+--R                                     10 2     9 2     8 4  8
+--R                                 (- a  c  + 2a b c - a b )e
+--R                               + 
+--R                                     9   2      8 3      7 5    7
+--R                                 (16a b c  - 24a b c + 8a b )d e
+--R                               + 
+--R                                     9 3       8 2 2       7 4       6 6  2 6
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                          8   3       7 3 2       6 5       5 7
+--R                                   (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                                *
+--R                                    3 5
+--R                                   d e
+--R                               + 
+--R                                          8 4       7 2 3       6 4 2       5 6
+--R                                     - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                   + 
+--R                                          4 8
+--R                                     - 70a b
+--R                                *
+--R                                    4 4
+--R                                   d e
+--R                               + 
+--R                                         7   4       6 3 3       5 5 2
+--R                                     160a b c  - 728a b c  + 896a b c
+--R                                   + 
+--R                                           4 7       3 9
+--R                                     - 392a b c + 56a b
+--R                                *
+--R                                    5 3
+--R                                   d e
+--R                               + 
+--R                                        7 5       6 2 4       5 4 3       4 6 2
+--R                                     12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                   + 
+--R                                         3 8       2 10
+--R                                     224a b c - 28a b
+--R                                *
+--R                                    6 2
+--R                                   d e
+--R                               + 
+--R                                          6   5       5 3 4       4 5 3
+--R                                     - 24a b c  + 176a b c  - 320a b c
+--R                                   + 
+--R                                         3 7 2      2 9        11
+--R                                     232a b c  - 72a b c + 8a b
+--R                                *
+--R                                    7
+--R                                   d e
+--R                               + 
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                *
+--R                                    8
+--R                                   d
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           5       4 3  4      5 2      4 2      3 4    3
+--R                        (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                      + 
+--R                              4   2      3 3      2 5  2 2
+--R                        (- 30a b c  + 30a b c - 6a b )d e
+--R                      + 
+--R                             4 3      3 2 2      2 4        6  3
+--R                        (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                      + 
+--R                           3   3      2 3 2       5     7  4
+--R                        (7a b c  - 14a b c  + 7a b c - b )d
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                            10 3
+--R                       8192a  c d
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                        7 2     6     5  5
+--R                     (4a c  + 5a c + a )e
+--R                   + 
+--R                           6 3       5 2      4       3  2 3
+--R                     (- 24a c  - 110a c  - 66a c - 10a )d e
+--R                   + 
+--R                        5 4      4 3       3 2      2        4
+--R                     (4a c  + 73a c  + 102a c  + 41a c + 5a)d e
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       9 2        8 2        7 4
+--R                                 (4096a c  - 2048a b c + 256a b )
+--R                              *
+--R                                 ROOT
+--R                                            10 2     9 2     8 4  8
+--R                                        (- a  c  + 2a b c - a b )e
+--R                                      + 
+--R                                            9   2      8 3      7 5    7
+--R                                        (16a b c  - 24a b c + 8a b )d e
+--R                                      + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                                  8   3       7 3 2       6 5
+--R                                            - 120a b c  + 392a b c  - 280a b c
+--R                                          + 
+--R                                               5 7
+--R                                            56a b
+--R                                       *
+--R                                           3 5
+--R                                          d e
+--R                                      + 
+--R                                                 8 4       7 2 3       6 4 2
+--R                                            - 38a c  + 422a b c  - 770a b c
+--R                                          + 
+--R                                                5 6       4 8
+--R                                            420a b c - 70a b
+--R                                       *
+--R                                           4 4
+--R                                          d e
+--R                                      + 
+--R                                                7   4       6 3 3       5 5 2
+--R                                            160a b c  - 728a b c  + 896a b c
+--R                                          + 
+--R                                                  4 7       3 9
+--R                                            - 392a b c + 56a b
+--R                                       *
+--R                                           5 3
+--R                                          d e
+--R                                      + 
+--R                                               7 5       6 2 4       5 4 3
+--R                                            12a c  - 252a b c  + 672a b c
+--R                                          + 
+--R                                                  4 6 2       3 8       2 10
+--R                                            - 616a b c  + 224a b c - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 6   5       5 3 4       4 5 3
+--R                                            - 24a b c  + 176a b c  - 320a b c
+--R                                          + 
+--R                                                3 7 2      2 9        11
+--R                                            232a b c  - 72a b c + 8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               6 6      5 2 5      4 4 4
+--R                                            - a c  + 12a b c  - 46a b c
+--R                                          + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  5       4 3  4      5 2      4 2      3 4    3
+--R                               (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                     4   2      3 3      2 5  2 2
+--R                               (- 30a b c  + 30a b c - 6a b )d e
+--R                             + 
+--R                                    4 3      3 2 2      2 4        6  3
+--R                               (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                             + 
+--R                                  3   3      2 3 2       5     7  4
+--R                               (7a b c  - 14a b c  + 7a b c - b )d
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                 10 2 2        9 4        8 6
+--R                           (4096a  b c  - 2048a b c + 256a b )e
+--R                         + 
+--R                                   9 3 2        8 5        7 7
+--R                           (- 8192a b c  + 2560a b c - 256a b )d
+--R                      *
+--R                         ROOT
+--R                                    10 2     9 2     8 4  8
+--R                                (- a  c  + 2a b c - a b )e
+--R                              + 
+--R                                    9   2      8 3      7 5    7
+--R                                (16a b c  - 24a b c + 8a b )d e
+--R                              + 
+--R                                    9 3       8 2 2       7 4       6 6  2 6
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                         8   3       7 3 2       6 5       5 7
+--R                                  (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                               *
+--R                                   3 5
+--R                                  d e
+--R                              + 
+--R                                         8 4       7 2 3       6 4 2       5 6
+--R                                    - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                  + 
+--R                                         4 8
+--R                                    - 70a b
+--R                               *
+--R                                   4 4
+--R                                  d e
+--R                              + 
+--R                                        7   4       6 3 3       5 5 2       4 7
+--R                                    160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                  + 
+--R                                       3 9
+--R                                    56a b
+--R                               *
+--R                                   5 3
+--R                                  d e
+--R                              + 
+--R                                       7 5       6 2 4       5 4 3       4 6 2
+--R                                    12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                  + 
+--R                                        3 8       2 10
+--R                                    224a b c - 28a b
+--R                               *
+--R                                   6 2
+--R                                  d e
+--R                              + 
+--R                                         6   5       5 3 4       4 5 3
+--R                                    - 24a b c  + 176a b c  - 320a b c
+--R                                  + 
+--R                                        3 7 2      2 9        11
+--R                                    232a b c  - 72a b c + 8a b
+--R                               *
+--R                                   7
+--R                                  d e
+--R                              + 
+--R                                       6 6      5 2 5      4 4 4      3 6 3
+--R                                    - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                  + 
+--R                                         2 8 2        10     12
+--R                                    - 37a b c  + 10a b  c - b
+--R                               *
+--R                                   8
+--R                                  d
+--R                           /
+--R                                        17 3           16 2 2          15 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        14 6
+--R                                - 65536a  b
+--R                     + 
+--R                           6 2      5      4    4
+--R                       (36a c  + 29a c + 5a )d e
+--R                     + 
+--R                             5 3       4 2      3       2  3 2
+--R                       (- 72a c  - 154a c  - 74a c - 10a )d e
+--R                     + 
+--R                            4 2 4      3 4 3      2 6 2       8     10  5
+--R                       (- 4a b c  + 25a b c  - 26a b c  + 9a b c - b  )d
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                         9 2        8 2        7 4
+--R                                   (4096a c  - 2048a b c + 256a b )
+--R                                *
+--R                                   ROOT
+--R                                              10 2     9 2     8 4  8
+--R                                          (- a  c  + 2a b c - a b )e
+--R                                        + 
+--R                                              9   2      8 3      7 5    7
+--R                                          (16a b c  - 24a b c + 8a b )d e
+--R                                        + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                         *
+--R                                             2 6
+--R                                            d e
+--R                                        + 
+--R                                                    8   3       7 3 2       6 5
+--R                                              - 120a b c  + 392a b c  - 280a b c
+--R                                            + 
+--R                                                 5 7
+--R                                              56a b
+--R                                         *
+--R                                             3 5
+--R                                            d e
+--R                                        + 
+--R                                                   8 4       7 2 3       6 4 2
+--R                                              - 38a c  + 422a b c  - 770a b c
+--R                                            + 
+--R                                                  5 6       4 8
+--R                                              420a b c - 70a b
+--R                                         *
+--R                                             4 4
+--R                                            d e
+--R                                        + 
+--R                                                  7   4       6 3 3       5 5 2
+--R                                              160a b c  - 728a b c  + 896a b c
+--R                                            + 
+--R                                                    4 7       3 9
+--R                                              - 392a b c + 56a b
+--R                                         *
+--R                                             5 3
+--R                                            d e
+--R                                        + 
+--R                                                 7 5       6 2 4       5 4 3
+--R                                              12a c  - 252a b c  + 672a b c
+--R                                            + 
+--R                                                    4 6 2       3 8       2 10
+--R                                              - 616a b c  + 224a b c - 28a b
+--R                                         *
+--R                                             6 2
+--R                                            d e
+--R                                        + 
+--R                                                   6   5       5 3 4       4 5 3
+--R                                              - 24a b c  + 176a b c  - 320a b c
+--R                                            + 
+--R                                                  3 7 2      2 9        11
+--R                                              232a b c  - 72a b c + 8a b
+--R                                         *
+--R                                             7
+--R                                            d e
+--R                                        + 
+--R                                                 6 6      5 2 5      4 4 4
+--R                                              - a c  + 12a b c  - 46a b c
+--R                                            + 
+--R                                               3 6 3      2 8 2        10     12
+--R                                            62a b c  - 37a b c  + 10a b  c - b
+--R                                         *
+--R                                             8
+--R                                            d
+--R                                     /
+--R                                                  17 3           16 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 15 4          14 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                    5       4 3  4
+--R                                 (3a b c - a b )e
+--R                               + 
+--R                                    5 2      4 2      3 4    3
+--R                                 (8a c  - 16a b c + 4a b )d e
+--R                               + 
+--R                                       4   2      3 3      2 5  2 2
+--R                                 (- 30a b c  + 30a b c - 6a b )d e
+--R                               + 
+--R                                      4 3      3 2 2      2 4        6  3
+--R                                 (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                               + 
+--R                                    3   3      2 3 2       5     7  4
+--R                                 (7a b c  - 14a b c  + 7a b c - b )d
+--R                            /
+--R                                    9 2        8 2        7 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                         6 2    5 2   6        5   2     4 3     5
+--R                       (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                     + 
+--R                            5 3      4 2 2      3 4   2 4
+--R                       (- 5a c  + 25a b c  - 10a b c)d e
+--R                     + 
+--R                           4   3      3 3 2      2 5   3 3
+--R                       (10a b c  - 30a b c  + 10a b c)d e
+--R                     + 
+--R                            4 4      2 4 2       6   4 2
+--R                       (- 5a c  + 15a b c  - 5a b c)d e
+--R                     + 
+--R                           3   4      2 3 3      5 2    7   5
+--R                       (11a b c  - 10a b c  - a b c  + b c)d e
+--R                     + 
+--R                         3 5     2 2 4       4 3    6 2  6
+--R                       (a c  - 6a b c  + 5a b c  - b c )d
+--R                  *
+--R                     x
+--R     + 
+--R       -
+--R                                +--------------------+3  +------------------+3
+--R                  +-----------+ |   +-----------+        | +-----------+
+--R             4+-+ |          2 4|   |          2        4| |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  9 2        8 2        7 4
+--R                          (- 4096a c  + 2048a b c - 256a b )
+--R                       *
+--R                          ROOT
+--R                                     10 2     9 2     8 4  8
+--R                                 (- a  c  + 2a b c - a b )e
+--R                               + 
+--R                                     9   2      8 3      7 5    7
+--R                                 (16a b c  - 24a b c + 8a b )d e
+--R                               + 
+--R                                     9 3       8 2 2       7 4       6 6  2 6
+--R                                 (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                               + 
+--R                                          8   3       7 3 2       6 5       5 7
+--R                                   (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                                *
+--R                                    3 5
+--R                                   d e
+--R                               + 
+--R                                          8 4       7 2 3       6 4 2       5 6
+--R                                     - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                   + 
+--R                                          4 8
+--R                                     - 70a b
+--R                                *
+--R                                    4 4
+--R                                   d e
+--R                               + 
+--R                                         7   4       6 3 3       5 5 2
+--R                                     160a b c  - 728a b c  + 896a b c
+--R                                   + 
+--R                                           4 7       3 9
+--R                                     - 392a b c + 56a b
+--R                                *
+--R                                    5 3
+--R                                   d e
+--R                               + 
+--R                                        7 5       6 2 4       5 4 3       4 6 2
+--R                                     12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                   + 
+--R                                         3 8       2 10
+--R                                     224a b c - 28a b
+--R                                *
+--R                                    6 2
+--R                                   d e
+--R                               + 
+--R                                          6   5       5 3 4       4 5 3
+--R                                     - 24a b c  + 176a b c  - 320a b c
+--R                                   + 
+--R                                         3 7 2      2 9        11
+--R                                     232a b c  - 72a b c + 8a b
+--R                                *
+--R                                    7
+--R                                   d e
+--R                               + 
+--R                                        6 6      5 2 5      4 4 4      3 6 3
+--R                                     - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                   + 
+--R                                          2 8 2        10     12
+--R                                     - 37a b c  + 10a b  c - b
+--R                                *
+--R                                    8
+--R                                   d
+--R                            /
+--R                                         17 3           16 2 2          15 4
+--R                                 4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                               + 
+--R                                         14 6
+--R                                 - 65536a  b
+--R                      + 
+--R                           5       4 3  4      5 2      4 2      3 4    3
+--R                        (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                      + 
+--R                              4   2      3 3      2 5  2 2
+--R                        (- 30a b c  + 30a b c - 6a b )d e
+--R                      + 
+--R                             4 3      3 2 2      2 4        6  3
+--R                        (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                      + 
+--R                           3   3      2 3 2       5     7  4
+--R                        (7a b c  - 14a b c  + 7a b c - b )d
+--R                   /
+--R                           9 2        8 2        7 4
+--R                      2048a c  - 1024a b c + 128a b
+--R         *
+--R            atan
+--R                            10 3
+--R                       8192a  c d
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                          7 2     6     5  5
+--R                     (- 4a c  - 5a c - a )e
+--R                   + 
+--R                         6 3       5 2      4       3  2 3
+--R                     (24a c  + 110a c  + 66a c + 10a )d e
+--R                   + 
+--R                          5 4      4 3       3 2      2        4
+--R                     (- 4a c  - 73a c  - 102a c  - 41a c - 5a)d e
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         9 2        8 2        7 4
+--R                                 (- 4096a c  + 2048a b c - 256a b )
+--R                              *
+--R                                 ROOT
+--R                                            10 2     9 2     8 4  8
+--R                                        (- a  c  + 2a b c - a b )e
+--R                                      + 
+--R                                            9   2      8 3      7 5    7
+--R                                        (16a b c  - 24a b c + 8a b )d e
+--R                                      + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                       *
+--R                                           2 6
+--R                                          d e
+--R                                      + 
+--R                                                  8   3       7 3 2       6 5
+--R                                            - 120a b c  + 392a b c  - 280a b c
+--R                                          + 
+--R                                               5 7
+--R                                            56a b
+--R                                       *
+--R                                           3 5
+--R                                          d e
+--R                                      + 
+--R                                                 8 4       7 2 3       6 4 2
+--R                                            - 38a c  + 422a b c  - 770a b c
+--R                                          + 
+--R                                                5 6       4 8
+--R                                            420a b c - 70a b
+--R                                       *
+--R                                           4 4
+--R                                          d e
+--R                                      + 
+--R                                                7   4       6 3 3       5 5 2
+--R                                            160a b c  - 728a b c  + 896a b c
+--R                                          + 
+--R                                                  4 7       3 9
+--R                                            - 392a b c + 56a b
+--R                                       *
+--R                                           5 3
+--R                                          d e
+--R                                      + 
+--R                                               7 5       6 2 4       5 4 3
+--R                                            12a c  - 252a b c  + 672a b c
+--R                                          + 
+--R                                                  4 6 2       3 8       2 10
+--R                                            - 616a b c  + 224a b c - 28a b
+--R                                       *
+--R                                           6 2
+--R                                          d e
+--R                                      + 
+--R                                                 6   5       5 3 4       4 5 3
+--R                                            - 24a b c  + 176a b c  - 320a b c
+--R                                          + 
+--R                                                3 7 2      2 9        11
+--R                                            232a b c  - 72a b c + 8a b
+--R                                       *
+--R                                           7
+--R                                          d e
+--R                                      + 
+--R                                               6 6      5 2 5      4 4 4
+--R                                            - a c  + 12a b c  - 46a b c
+--R                                          + 
+--R                                             3 6 3      2 8 2        10     12
+--R                                          62a b c  - 37a b c  + 10a b  c - b
+--R                                       *
+--R                                           8
+--R                                          d
+--R                                   /
+--R                                                17 3           16 2 2
+--R                                        4194304a  c  - 3145728a  b c
+--R                                      + 
+--R                                               15 4          14 6
+--R                                        786432a  b c - 65536a  b
+--R                             + 
+--R                                  5       4 3  4      5 2      4 2      3 4    3
+--R                               (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                             + 
+--R                                     4   2      3 3      2 5  2 2
+--R                               (- 30a b c  + 30a b c - 6a b )d e
+--R                             + 
+--R                                    4 3      3 2 2      2 4        6  3
+--R                               (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                             + 
+--R                                  3   3      2 3 2       5     7  4
+--R                               (7a b c  - 14a b c  + 7a b c - b )d
+--R                          /
+--R                                  9 2        8 2        7 4
+--R                             2048a c  - 1024a b c + 128a b
+--R              /
+--R                                 10 2 2        9 4        8 6
+--R                           (4096a  b c  - 2048a b c + 256a b )e
+--R                         + 
+--R                                   9 3 2        8 5        7 7
+--R                           (- 8192a b c  + 2560a b c - 256a b )d
+--R                      *
+--R                         ROOT
+--R                                    10 2     9 2     8 4  8
+--R                                (- a  c  + 2a b c - a b )e
+--R                              + 
+--R                                    9   2      8 3      7 5    7
+--R                                (16a b c  - 24a b c + 8a b )d e
+--R                              + 
+--R                                    9 3       8 2 2       7 4       6 6  2 6
+--R                                (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                              + 
+--R                                         8   3       7 3 2       6 5       5 7
+--R                                  (- 120a b c  + 392a b c  - 280a b c + 56a b )
+--R                               *
+--R                                   3 5
+--R                                  d e
+--R                              + 
+--R                                         8 4       7 2 3       6 4 2       5 6
+--R                                    - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                  + 
+--R                                         4 8
+--R                                    - 70a b
+--R                               *
+--R                                   4 4
+--R                                  d e
+--R                              + 
+--R                                        7   4       6 3 3       5 5 2       4 7
+--R                                    160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                  + 
+--R                                       3 9
+--R                                    56a b
+--R                               *
+--R                                   5 3
+--R                                  d e
+--R                              + 
+--R                                       7 5       6 2 4       5 4 3       4 6 2
+--R                                    12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                  + 
+--R                                        3 8       2 10
+--R                                    224a b c - 28a b
+--R                               *
+--R                                   6 2
+--R                                  d e
+--R                              + 
+--R                                         6   5       5 3 4       4 5 3
+--R                                    - 24a b c  + 176a b c  - 320a b c
+--R                                  + 
+--R                                        3 7 2      2 9        11
+--R                                    232a b c  - 72a b c + 8a b
+--R                               *
+--R                                   7
+--R                                  d e
+--R                              + 
+--R                                       6 6      5 2 5      4 4 4      3 6 3
+--R                                    - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                  + 
+--R                                         2 8 2        10     12
+--R                                    - 37a b c  + 10a b  c - b
+--R                               *
+--R                                   8
+--R                                  d
+--R                           /
+--R                                        17 3           16 2 2          15 4
+--R                                4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                              + 
+--R                                        14 6
+--R                                - 65536a  b
+--R                     + 
+--R                             6 2      5      4    4
+--R                       (- 36a c  - 29a c - 5a )d e
+--R                     + 
+--R                           5 3       4 2      3       2  3 2
+--R                       (72a c  + 154a c  + 74a c + 10a )d e
+--R                     + 
+--R                          4 2 4      3 4 3      2 6 2       8     10  5
+--R                       (4a b c  - 25a b c  + 26a b c  - 9a b c + b  )d
+--R                  *
+--R                     ROOT
+--R                          2
+--R                       *
+--R                          ROOT
+--R                                           9 2        8 2        7 4
+--R                                   (- 4096a c  + 2048a b c - 256a b )
+--R                                *
+--R                                   ROOT
+--R                                              10 2     9 2     8 4  8
+--R                                          (- a  c  + 2a b c - a b )e
+--R                                        + 
+--R                                              9   2      8 3      7 5    7
+--R                                          (16a b c  - 24a b c + 8a b )d e
+--R                                        + 
+--R                                                 9 3       8 2 2       7 4
+--R                                              12a c  - 112a b c  + 112a b c
+--R                                            + 
+--R                                                   6 6
+--R                                              - 28a b
+--R                                         *
+--R                                             2 6
+--R                                            d e
+--R                                        + 
+--R                                                    8   3       7 3 2       6 5
+--R                                              - 120a b c  + 392a b c  - 280a b c
+--R                                            + 
+--R                                                 5 7
+--R                                              56a b
+--R                                         *
+--R                                             3 5
+--R                                            d e
+--R                                        + 
+--R                                                   8 4       7 2 3       6 4 2
+--R                                              - 38a c  + 422a b c  - 770a b c
+--R                                            + 
+--R                                                  5 6       4 8
+--R                                              420a b c - 70a b
+--R                                         *
+--R                                             4 4
+--R                                            d e
+--R                                        + 
+--R                                                  7   4       6 3 3       5 5 2
+--R                                              160a b c  - 728a b c  + 896a b c
+--R                                            + 
+--R                                                    4 7       3 9
+--R                                              - 392a b c + 56a b
+--R                                         *
+--R                                             5 3
+--R                                            d e
+--R                                        + 
+--R                                                 7 5       6 2 4       5 4 3
+--R                                              12a c  - 252a b c  + 672a b c
+--R                                            + 
+--R                                                    4 6 2       3 8       2 10
+--R                                              - 616a b c  + 224a b c - 28a b
+--R                                         *
+--R                                             6 2
+--R                                            d e
+--R                                        + 
+--R                                                   6   5       5 3 4       4 5 3
+--R                                              - 24a b c  + 176a b c  - 320a b c
+--R                                            + 
+--R                                                  3 7 2      2 9        11
+--R                                              232a b c  - 72a b c + 8a b
+--R                                         *
+--R                                             7
+--R                                            d e
+--R                                        + 
+--R                                                 6 6      5 2 5      4 4 4
+--R                                              - a c  + 12a b c  - 46a b c
+--R                                            + 
+--R                                               3 6 3      2 8 2        10     12
+--R                                            62a b c  - 37a b c  + 10a b  c - b
+--R                                         *
+--R                                             8
+--R                                            d
+--R                                     /
+--R                                                  17 3           16 2 2
+--R                                          4194304a  c  - 3145728a  b c
+--R                                        + 
+--R                                                 15 4          14 6
+--R                                          786432a  b c - 65536a  b
+--R                               + 
+--R                                    5       4 3  4
+--R                                 (3a b c - a b )e
+--R                               + 
+--R                                    5 2      4 2      3 4    3
+--R                                 (8a c  - 16a b c + 4a b )d e
+--R                               + 
+--R                                       4   2      3 3      2 5  2 2
+--R                                 (- 30a b c  + 30a b c - 6a b )d e
+--R                               + 
+--R                                      4 3      3 2 2      2 4        6  3
+--R                                 (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                               + 
+--R                                    3   3      2 3 2       5     7  4
+--R                                 (7a b c  - 14a b c  + 7a b c - b )d
+--R                            /
+--R                                    9 2        8 2        7 4
+--R                               2048a c  - 1024a b c + 128a b
+--R                 + 
+--R                           6 2    5 2   6      5   2     4 3     5
+--R                       (- a c  + a b c)e  + (9a b c  - 5a b c)d e
+--R                     + 
+--R                          5 3      4 2 2      3 4   2 4
+--R                       (5a c  - 25a b c  + 10a b c)d e
+--R                     + 
+--R                             4   3      3 3 2      2 5   3 3
+--R                       (- 10a b c  + 30a b c  - 10a b c)d e
+--R                     + 
+--R                          4 4      2 4 2       6   4 2
+--R                       (5a c  - 15a b c  + 5a b c)d e
+--R                     + 
+--R                             3   4      2 3 3      5 2    7   5
+--R                       (- 11a b c  + 10a b c  + a b c  - b c)d e
+--R                     + 
+--R                           3 5     2 2 4       4 3    6 2  6
+--R                       (- a c  + 6a b c  - 5a b c  + b c )d
+--R                  *
+--R                     x
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               9 2        8 2        7 4
+--R                       (- 4096a c  + 2048a b c - 256a b )
+--R                    *
+--R                       ROOT
+--R                                  10 2     9 2     8 4  8
+--R                              (- a  c  + 2a b c - a b )e
+--R                            + 
+--R                                  9   2      8 3      7 5    7
+--R                              (16a b c  - 24a b c + 8a b )d e
+--R                            + 
+--R                                  9 3       8 2 2       7 4       6 6  2 6
+--R                              (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                            + 
+--R                                     8   3       7 3 2       6 5       5 7  3 5
+--R                              (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                            + 
+--R                                       8 4       7 2 3       6 4 2       5 6
+--R                                  - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                                + 
+--R                                       4 8
+--R                                  - 70a b
+--R                             *
+--R                                 4 4
+--R                                d e
+--R                            + 
+--R                                      7   4       6 3 3       5 5 2       4 7
+--R                                  160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                                + 
+--R                                     3 9
+--R                                  56a b
+--R                             *
+--R                                 5 3
+--R                                d e
+--R                            + 
+--R                                     7 5       6 2 4       5 4 3       4 6 2
+--R                                  12a c  - 252a b c  + 672a b c  - 616a b c
+--R                                + 
+--R                                      3 8       2 10
+--R                                  224a b c - 28a b
+--R                             *
+--R                                 6 2
+--R                                d e
+--R                            + 
+--R                                       6   5       5 3 4       4 5 3       3 7 2
+--R                                  - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                                + 
+--R                                       2 9        11
+--R                                  - 72a b c + 8a b
+--R                             *
+--R                                 7
+--R                                d e
+--R                            + 
+--R                                     6 6      5 2 5      4 4 4      3 6 3
+--R                                  - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                + 
+--R                                       2 8 2        10     12
+--R                                  - 37a b c  + 10a b  c - b
+--R                             *
+--R                                 8
+--R                                d
+--R                         /
+--R                                      17 3           16 2 2          15 4
+--R                              4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                            + 
+--R                                      14 6
+--R                              - 65536a  b
+--R                   + 
+--R                        5       4 3  4      5 2      4 2      3 4    3
+--R                     (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                   + 
+--R                           4   2      3 3      2 5  2 2
+--R                     (- 30a b c  + 30a b c - 6a b )d e
+--R                   + 
+--R                          4 3      3 2 2      2 4        6  3
+--R                     (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                   + 
+--R                        3   3      2 3 2       5     7  4
+--R                     (7a b c  - 14a b c  + 7a b c - b )d
+--R                /
+--R                        9 2        8 2        7 4
+--R                   2048a c  - 1024a b c + 128a b
+--R      *
+--R         atan
+--R                         10 3
+--R                    8192a  c d
+--R                 *
+--R                    ROOT
+--R                               10 2     9 2     8 4  8
+--R                           (- a  c  + 2a b c - a b )e
+--R                         + 
+--R                               9   2      8 3      7 5    7
+--R                           (16a b c  - 24a b c + 8a b )d e
+--R                         + 
+--R                               9 3       8 2 2       7 4       6 6  2 6
+--R                           (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                         + 
+--R                                  8   3       7 3 2       6 5       5 7  3 5
+--R                           (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                         + 
+--R                                    8 4       7 2 3       6 4 2       5 6
+--R                               - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                             + 
+--R                                    4 8
+--R                               - 70a b
+--R                          *
+--R                              4 4
+--R                             d e
+--R                         + 
+--R                                   7   4       6 3 3       5 5 2       4 7
+--R                               160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                             + 
+--R                                  3 9
+--R                               56a b
+--R                          *
+--R                              5 3
+--R                             d e
+--R                         + 
+--R                                  7 5       6 2 4       5 4 3       4 6 2
+--R                               12a c  - 252a b c  + 672a b c  - 616a b c
+--R                             + 
+--R                                   3 8       2 10
+--R                               224a b c - 28a b
+--R                          *
+--R                              6 2
+--R                             d e
+--R                         + 
+--R                                    6   5       5 3 4       4 5 3       3 7 2
+--R                               - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                             + 
+--R                                    2 9        11
+--R                               - 72a b c + 8a b
+--R                          *
+--R                              7
+--R                             d e
+--R                         + 
+--R                                  6 6      5 2 5      4 4 4      3 6 3
+--R                               - a c  + 12a b c  - 46a b c  + 62a b c
+--R                             + 
+--R                                    2 8 2        10     12
+--R                               - 37a b c  + 10a b  c - b
+--R                          *
+--R                              8
+--R                             d
+--R                      /
+--R                                   17 3           16 2 2          15 4
+--R                           4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                         + 
+--R                                   14 6
+--R                           - 65536a  b
+--R                + 
+--R                       7 2     6     5  5
+--R                  (- 4a c  - 5a c - a )e
+--R                + 
+--R                      6 3       5 2      4       3  2 3
+--R                  (24a c  + 110a c  + 66a c + 10a )d e
+--R                + 
+--R                       5 4      4 3       3 2      2        4
+--R                  (- 4a c  - 73a c  - 102a c  - 41a c - 5a)d e
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      9 2        8 2        7 4
+--R                              (- 4096a c  + 2048a b c - 256a b )
+--R                           *
+--R                              ROOT
+--R                                         10 2     9 2     8 4  8
+--R                                     (- a  c  + 2a b c - a b )e
+--R                                   + 
+--R                                         9   2      8 3      7 5    7
+--R                                     (16a b c  - 24a b c + 8a b )d e
+--R                                   + 
+--R                                           9 3       8 2 2       7 4       6 6
+--R                                       (12a c  - 112a b c  + 112a b c - 28a b )
+--R                                    *
+--R                                        2 6
+--R                                       d e
+--R                                   + 
+--R                                               8   3       7 3 2       6 5
+--R                                         - 120a b c  + 392a b c  - 280a b c
+--R                                       + 
+--R                                            5 7
+--R                                         56a b
+--R                                    *
+--R                                        3 5
+--R                                       d e
+--R                                   + 
+--R                                              8 4       7 2 3       6 4 2
+--R                                         - 38a c  + 422a b c  - 770a b c
+--R                                       + 
+--R                                             5 6       4 8
+--R                                         420a b c - 70a b
+--R                                    *
+--R                                        4 4
+--R                                       d e
+--R                                   + 
+--R                                             7   4       6 3 3       5 5 2
+--R                                         160a b c  - 728a b c  + 896a b c
+--R                                       + 
+--R                                               4 7       3 9
+--R                                         - 392a b c + 56a b
+--R                                    *
+--R                                        5 3
+--R                                       d e
+--R                                   + 
+--R                                            7 5       6 2 4       5 4 3
+--R                                         12a c  - 252a b c  + 672a b c
+--R                                       + 
+--R                                               4 6 2       3 8       2 10
+--R                                         - 616a b c  + 224a b c - 28a b
+--R                                    *
+--R                                        6 2
+--R                                       d e
+--R                                   + 
+--R                                              6   5       5 3 4       4 5 3
+--R                                         - 24a b c  + 176a b c  - 320a b c
+--R                                       + 
+--R                                             3 7 2      2 9        11
+--R                                         232a b c  - 72a b c + 8a b
+--R                                    *
+--R                                        7
+--R                                       d e
+--R                                   + 
+--R                                            6 6      5 2 5      4 4 4      3 6 3
+--R                                         - a c  + 12a b c  - 46a b c  + 62a b c
+--R                                       + 
+--R                                              2 8 2        10     12
+--R                                         - 37a b c  + 10a b  c - b
+--R                                    *
+--R                                        8
+--R                                       d
+--R                                /
+--R                                             17 3           16 2 2
+--R                                     4194304a  c  - 3145728a  b c
+--R                                   + 
+--R                                            15 4          14 6
+--R                                     786432a  b c - 65536a  b
+--R                          + 
+--R                               5       4 3  4      5 2      4 2      3 4    3
+--R                            (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                          + 
+--R                                  4   2      3 3      2 5  2 2
+--R                            (- 30a b c  + 30a b c - 6a b )d e
+--R                          + 
+--R                                 4 3      3 2 2      2 4        6  3
+--R                            (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                          + 
+--R                               3   3      2 3 2       5     7  4
+--R                            (7a b c  - 14a b c  + 7a b c - b )d
+--R                       /
+--R                               9 2        8 2        7 4
+--R                          2048a c  - 1024a b c + 128a b
+--R           /
+--R                              10 2 2        9 4        8 6
+--R                        (4096a  b c  - 2048a b c + 256a b )e
+--R                      + 
+--R                                9 3 2        8 5        7 7
+--R                        (- 8192a b c  + 2560a b c - 256a b )d
+--R                   *
+--R                      ROOT
+--R                                 10 2     9 2     8 4  8
+--R                             (- a  c  + 2a b c - a b )e
+--R                           + 
+--R                                 9   2      8 3      7 5    7
+--R                             (16a b c  - 24a b c + 8a b )d e
+--R                           + 
+--R                                 9 3       8 2 2       7 4       6 6  2 6
+--R                             (12a c  - 112a b c  + 112a b c - 28a b )d e
+--R                           + 
+--R                                    8   3       7 3 2       6 5       5 7  3 5
+--R                             (- 120a b c  + 392a b c  - 280a b c + 56a b )d e
+--R                           + 
+--R                                      8 4       7 2 3       6 4 2       5 6
+--R                                 - 38a c  + 422a b c  - 770a b c  + 420a b c
+--R                               + 
+--R                                      4 8
+--R                                 - 70a b
+--R                            *
+--R                                4 4
+--R                               d e
+--R                           + 
+--R                                     7   4       6 3 3       5 5 2       4 7
+--R                                 160a b c  - 728a b c  + 896a b c  - 392a b c
+--R                               + 
+--R                                    3 9
+--R                                 56a b
+--R                            *
+--R                                5 3
+--R                               d e
+--R                           + 
+--R                                    7 5       6 2 4       5 4 3       4 6 2
+--R                                 12a c  - 252a b c  + 672a b c  - 616a b c
+--R                               + 
+--R                                     3 8       2 10
+--R                                 224a b c - 28a b
+--R                            *
+--R                                6 2
+--R                               d e
+--R                           + 
+--R                                      6   5       5 3 4       4 5 3       3 7 2
+--R                                 - 24a b c  + 176a b c  - 320a b c  + 232a b c
+--R                               + 
+--R                                      2 9        11
+--R                                 - 72a b c + 8a b
+--R                            *
+--R                                7
+--R                               d e
+--R                           + 
+--R                                    6 6      5 2 5      4 4 4      3 6 3
+--R                                 - a c  + 12a b c  - 46a b c  + 62a b c
+--R                               + 
+--R                                      2 8 2        10     12
+--R                                 - 37a b c  + 10a b  c - b
+--R                            *
+--R                                8
+--R                               d
+--R                        /
+--R                                     17 3           16 2 2          15 4
+--R                             4194304a  c  - 3145728a  b c  + 786432a  b c
+--R                           + 
+--R                                     14 6
+--R                             - 65536a  b
+--R                  + 
+--R                          6 2      5      4    4
+--R                    (- 36a c  - 29a c - 5a )d e
+--R                  + 
+--R                        5 3       4 2      3       2  3 2
+--R                    (72a c  + 154a c  + 74a c + 10a )d e
+--R                  + 
+--R                       4 2 4      3 4 3      2 6 2       8     10  5
+--R                    (4a b c  - 25a b c  + 26a b c  - 9a b c + b  )d
+--R               *
+--R                  ROOT
+--R                       2
+--R                    *
+--R                       ROOT
+--R                                        9 2        8 2        7 4
+--R                                (- 4096a c  + 2048a b c - 256a b )
+--R                             *
+--R                                ROOT
+--R                                           10 2     9 2     8 4  8
+--R                                       (- a  c  + 2a b c - a b )e
+--R                                     + 
+--R                                           9   2      8 3      7 5    7
+--R                                       (16a b c  - 24a b c + 8a b )d e
+--R                                     + 
+--R                                                9 3       8 2 2       7 4
+--R                                             12a c  - 112a b c  + 112a b c
+--R                                           + 
+--R                                                  6 6
+--R                                             - 28a b
+--R                                      *
+--R                                          2 6
+--R                                         d e
+--R                                     + 
+--R                                                 8   3       7 3 2       6 5
+--R                                           - 120a b c  + 392a b c  - 280a b c
+--R                                         + 
+--R                                              5 7
+--R                                           56a b
+--R                                      *
+--R                                          3 5
+--R                                         d e
+--R                                     + 
+--R                                                8 4       7 2 3       6 4 2
+--R                                           - 38a c  + 422a b c  - 770a b c
+--R                                         + 
+--R                                               5 6       4 8
+--R                                           420a b c - 70a b
+--R                                      *
+--R                                          4 4
+--R                                         d e
+--R                                     + 
+--R                                               7   4       6 3 3       5 5 2
+--R                                           160a b c  - 728a b c  + 896a b c
+--R                                         + 
+--R                                                 4 7       3 9
+--R                                           - 392a b c + 56a b
+--R                                      *
+--R                                          5 3
+--R                                         d e
+--R                                     + 
+--R                                              7 5       6 2 4       5 4 3
+--R                                           12a c  - 252a b c  + 672a b c
+--R                                         + 
+--R                                                 4 6 2       3 8       2 10
+--R                                           - 616a b c  + 224a b c - 28a b
+--R                                      *
+--R                                          6 2
+--R                                         d e
+--R                                     + 
+--R                                                6   5       5 3 4       4 5 3
+--R                                           - 24a b c  + 176a b c  - 320a b c
+--R                                         + 
+--R                                               3 7 2      2 9        11
+--R                                           232a b c  - 72a b c + 8a b
+--R                                      *
+--R                                          7
+--R                                         d e
+--R                                     + 
+--R                                              6 6      5 2 5      4 4 4
+--R                                           - a c  + 12a b c  - 46a b c
+--R                                         + 
+--R                                              3 6 3      2 8 2        10     12
+--R                                           62a b c  - 37a b c  + 10a b  c - b
+--R                                      *
+--R                                          8
+--R                                         d
+--R                                  /
+--R                                               17 3           16 2 2
+--R                                       4194304a  c  - 3145728a  b c
+--R                                     + 
+--R                                              15 4          14 6
+--R                                       786432a  b c - 65536a  b
+--R                            + 
+--R                                 5       4 3  4      5 2      4 2      3 4    3
+--R                              (3a b c - a b )e  + (8a c  - 16a b c + 4a b )d e
+--R                            + 
+--R                                    4   2      3 3      2 5  2 2
+--R                              (- 30a b c  + 30a b c - 6a b )d e
+--R                            + 
+--R                                   4 3      3 2 2      2 4        6  3
+--R                              (- 8a c  + 36a b c  - 24a b c + 4a b )d e
+--R                            + 
+--R                                 3   3      2 3 2       5     7  4
+--R                              (7a b c  - 14a b c  + 7a b c - b )d
+--R                         /
+--R                                 9 2        8 2        7 4
+--R                            2048a c  - 1024a b c + 128a b
+--R              + 
+--R                      6 2    5 2   6        5   2     4 3     5
+--R                    (a c  - a b c)e  + (- 9a b c  + 5a b c)d e
+--R                  + 
+--R                         5 3      4 2 2      3 4   2 4
+--R                    (- 5a c  + 25a b c  - 10a b c)d e
+--R                  + 
+--R                        4   3      3 3 2      2 5   3 3
+--R                    (10a b c  - 30a b c  + 10a b c)d e
+--R                  + 
+--R                         4 4      2 4 2       6   4 2
+--R                    (- 5a c  + 15a b c  - 5a b c)d e
+--R                  + 
+--R                        3   4      2 3 3      5 2    7   5
+--R                    (11a b c  - 10a b c  - a b c  + b c)d e
+--R                  + 
+--R                      3 5     2 2 4       4 3    6 2  6
+--R                    (a c  - 6a b c  + 5a b c  - b c )d
+--R               *
+--R                  x
+--R     + 
+--R                                                +------------------+3
+--R              +-----------+                     | +-----------+
+--R              |          2               4+-+3 4| |          2
+--R         (- d\|- 4a c + b   - 2a e + b d)\|c   \|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                +--------------------+3
+--R              +-----------+                     |   +-----------+
+--R              |          2               4+-+3 4|   |          2
+--R         (- d\|- 4a c + b   + 2a e - b d)\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                                +------------------+3
+--R              +-----------+                     | +-----------+
+--R              |          2               4+-+3 4| |          2
+--R         (- d\|- 4a c + b   - 2a e + b d)\|c   \|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                                +--------------------+3
+--R              +-----------+                     |   +-----------+
+--R              |          2               4+-+3 4|   |          2
+--R         (- d\|- 4a c + b   + 2a e - b d)\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                          +--------------------+3  +------------------+3
+--R            +-----------+ |   +-----------+        | +-----------+
+--R       4+-+ |          2 4|   |          2        4| |          2
+--R     2a\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 649
+--d0:=D(m0,x)
+--E 245
+
+)clear all
+
+--S 246 of 649
+t0:=x^4*(1-x^4)/(1-x^4+x^8)
+--R 
+--R
+--R            8    4
+--R         - x  + x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 246
+
+--S 247 of 649
+r0:=-x-1/2*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)-_
+   1/2*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/4*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(6)+1/4*log(1+x^2+_
+   x*sqrt(2-sqrt(3)))/sqrt(6)-1/4*log(1+x^2-x*sqrt(2+sqrt(3)))/_
+   sqrt(6)+1/4*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R             +--------+                   +----------+
+--R             | +-+         2              |   +-+         2
+--R       log(x\|\|3  + 2  + x  + 1) + log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                 +----------+                     +--------+
+--R                 |   +-+         2                | +-+         2
+--R       - log(- x\|- \|3  + 2  + x  + 1) - log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R                        +----------+ +--------+                 +----------+
+--R               +-+      |   +-+      | +-+            +-+       |   +-+
+--R       2atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R                           +----------+                +--------+
+--R                  +-+      |   +-+           +-+       | +-+
+--R       - 2atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                         +----------+                +--------+
+--R                +-+      |   +-+           +-+       | +-+            +-+
+--R       2atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 ) - 4x\|6
+--R  /
+--R       +-+
+--R     4\|6
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        +-+ +-+      3      +-+ +-+    4     2
+--R       \|2 \|3 log((x  + x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R          +-+ +-+        3      +-+ +-+    4     2
+--R       - \|2 \|3 log((- x  - x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R                        +-+ +-+                          +-+ +-+
+--R         +-+ +-+      x\|2 \|3  - 2       +-+ +-+      x\|2 \|3  + 2
+--R       2\|2 \|3 atan(---------------) - 2\|2 \|3 atan(---------------) - 24x
+--R                       +-+ +-+     2                    +-+ +-+     2
+--R                     x\|2 \|3  - 2x                   x\|2 \|3  + 2x
+--R  /
+--R     24
+--R                                         Type: Union(Expression(Integer),...)
+--E 248
+
+--S 249 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +--------+                    +----------+
+--R                | +-+         2               |   +-+         2
+--R       - 6log(x\|\|3  + 2  + x  + 1) - 6log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                +----------+                      +--------+
+--R                |   +-+         2                 | +-+         2
+--R       6log(- x\|- \|3  + 2  + x  + 1) + 6log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R                           +----------+ +--------+                 +----------+
+--R                  +-+      |   +-+      | +-+            +-+       |   +-+
+--R       - 12atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R                         +----------+ +--------+                   +----------+
+--R                +-+      |   +-+      | +-+              +-+       |   +-+
+--R       12atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R                          +----------+                +--------+
+--R                 +-+      |   +-+           +-+       | +-+
+--R       12atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                            +----------+                +--------+
+--R                   +-+      |   +-+           +-+       | +-+
+--R       - 12atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R        +-+ +-+ +-+      3      +-+ +-+    4     2
+--R       \|2 \|3 \|6 log((x  + x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R          +-+ +-+ +-+        3      +-+ +-+    4     2
+--R       - \|2 \|3 \|6 log((- x  - x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R                            +-+ +-+                              +-+ +-+
+--R         +-+ +-+ +-+      x\|2 \|3  - 2       +-+ +-+ +-+      x\|2 \|3  + 2
+--R       2\|2 \|3 \|6 atan(---------------) - 2\|2 \|3 \|6 atan(---------------)
+--R                           +-+ +-+     2                        +-+ +-+     2
+--R                         x\|2 \|3  - 2x                       x\|2 \|3  + 2x
+--R  /
+--R        +-+
+--R     24\|6
+--R                                                    Type: Expression(Integer)
+--E 249
+
+--S 250 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                         +--------+                           +----------+
+--R     4 +-+    4      +-+ | +-+            4 +-+    4      +-+ |   +-+
+--R   (x \|3  - x  - 1)\|6 \|\|3  + 2  + (- x \|3  - x  - 1)\|6 \|- \|3  + 2  + 6
+--R   ---------------------------------------------------------------------------
+--R                                    8     4
+--R                                  6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 250
+
+)clear all
+
+--S 251 of 649
+t0:=x^3*(1-x^4)/(1-x^4+x^8)
+--R 
+--R
+--R            7    3
+--R         - x  + x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 251
+
+--S 252 of 649
+r0:=-1/8*log(1-x^4+x^8)-1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                          4      +-+
+--R           +-+     8    4              (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                             3
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            8\|3
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                          4      +-+
+--R           +-+     8    4              (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                             3
+--R   (3)  ---------------------------------------------
+--R                              +-+
+--R                            8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 253
+
+--S 254 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 649
+t0:=x^2*(1-x^4)/(1-x^4+x^8)
+--R 
+--R
+--R            6    2
+--R         - x  + x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 256
+
+--S 257 of 649
+r0:=-1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))+_
+   1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))+_
+   1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))-_
+   1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))+_
+   1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))-_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))-_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+_
+   1/8*log(1+x^2+x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R        +--------+      +--------+
+--R        | +-+           | +-+         2
+--R       \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R          +----------+      +----------+
+--R          |   +-+           |   +-+         2
+--R       - \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +----------+        +----------+
+--R        |   +-+             |   +-+         2
+--R       \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +--------+        +--------+
+--R          | +-+             | +-+         2
+--R       - \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R           +----------+
+--R           |   +-+
+--R         2\|- \|3  + 2
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R              +----------+
+--R              |   +-+
+--R            2\|- \|3  + 2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R         +--------+                 +----------+                +--------+
+--R         | +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R           +--------+                 +----------+                +--------+
+--R           | +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  0
+--R                                         Type: Union(Expression(Integer),...)
+--E 258
+
+--S 259 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +--------+      +--------+
+--R          | +-+           | +-+         2
+--R       - \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R        +----------+      +----------+
+--R        |   +-+           |   +-+         2
+--R       \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +----------+        +----------+
+--R          |   +-+             |   +-+         2
+--R       - \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +--------+        +--------+
+--R        | +-+             | +-+         2
+--R       \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R              +----------+
+--R              |   +-+
+--R            2\|- \|3  + 2
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R           +----------+
+--R           |   +-+
+--R         2\|- \|3  + 2
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R           +--------+                 +----------+                +--------+
+--R           | +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R         +--------+                 +----------+                +--------+
+--R         | +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R           6    2
+--R          x  - x
+--R   (5)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 260
+
+)clear all
+
+--S 261 of 649
+t0:=x*(1-x^4)/(1-x^4+x^8)
+--R 
+--R
+--R             5
+--R          - x  + x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 261
+
+--S 262 of 649
+r0:=-1/4*log(1+x^4-x^2*sqrt(3))/sqrt(3)+1/4*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R             2 +-+    4               2 +-+    4
+--R        log(x \|3  + x  + 1) - log(- x \|3  + x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            4\|3
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R              8     4      +-+     6     2
+--R            (x  + 5x  + 1)\|3  + 6x  + 6x
+--R        log(------------------------------)
+--R                       8    4
+--R                      x  - x  + 1
+--R   (3)  -----------------------------------
+--R                         +-+
+--R                       4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 263
+
+--S 264 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      8     4      +-+     6     2
+--R              2 +-+    4            (x  + 5x  + 1)\|3  + 6x  + 6x
+--R       - log(x \|3  + x  + 1) + log(------------------------------)
+--R                                               8    4
+--R                                              x  - x  + 1
+--R     + 
+--R              2 +-+    4
+--R       log(- x \|3  + x  + 1)
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 265
+
+)clear all
+
+--S 266 of 649
+t0:=(1-x^4)/(1-x^4+x^8)
+--R 
+--R
+--R             4
+--R          - x  + 1
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 266
+
+--S 267 of 649
+r0:=1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))-_
+   1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))+_
+   1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))-_
+   1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))-_
+   1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))-_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+_
+   1/8*log(1+x^2+x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R        +--------+      +--------+
+--R        | +-+           | +-+         2
+--R       \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R          +----------+      +----------+
+--R          |   +-+           |   +-+         2
+--R       - \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +----------+        +----------+
+--R        |   +-+             |   +-+         2
+--R       \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +--------+        +--------+
+--R          | +-+             | +-+         2
+--R       - \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R              +----------+
+--R              |   +-+
+--R            2\|- \|3  + 2
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R           +----------+
+--R           |   +-+
+--R         2\|- \|3  + 2
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R           +--------+                 +----------+                +--------+
+--R           | +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R         +--------+                 +----------+                +--------+
+--R         | +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                   3
+--R                                                            atan(----)
+--R                                                                  +-+
+--R                                                                 \|3
+--R                                                        sin(----------)
+--R                                                                 2
+--R                                                   atan(---------------)
+--R                                                                   3
+--R          +-----------------------------------+             atan(----)
+--R          |           3   2              3   2                    +-+
+--R          |    atan(----)         atan(----)                     \|3
+--R          |          +-+                +-+             cos(----------)
+--R          |         \|3                \|3                       2
+--R         4|sin(----------)  + cos(----------)  cos(---------------------)
+--R         \|         2                  2                     2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                  +-+4+-+  |         \|3                \|3
+--R                x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R             *
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                  4+-+  |         \|3                \|3
+--R                3x\|9  4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R             *
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R       -
+--R                                                                      3
+--R                                                               atan(----)
+--R                                                                     +-+
+--R                                                                    \|3
+--R                                                           sin(----------)
+--R                                                                    2
+--R                                                      atan(---------------)
+--R                                                                      3
+--R             +-----------------------------------+             atan(----)
+--R             |           3   2              3   2                    +-+
+--R             |    atan(----)         atan(----)                     \|3
+--R             |          +-+                +-+             cos(----------)
+--R             |         \|3                \|3                       2
+--R            4|sin(----------)  + cos(----------)  cos(---------------------)
+--R            \|         2                  2                     2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                                 +-----------------------------------+
+--R                                 |           3   2              3   2
+--R                                 |    atan(----)         atan(----)
+--R                                 |          +-+                +-+
+--R                        +-+4+-+  |         \|3                \|3
+--R                      x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                                \|         2                  2
+--R                   *
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               cos(----------)
+--R                                        2
+--R                      sin(---------------------)
+--R                                    2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                              +-----------------------------------+
+--R                              |           3   2              3   2
+--R                              |    atan(----)         atan(----)
+--R                              |          +-+                +-+
+--R                        4+-+  |         \|3                \|3
+--R                      3x\|9  4|sin(----------)  + cos(----------)
+--R                             \|         2                  2
+--R                   *
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               cos(----------)
+--R                                        2
+--R                      cos(---------------------)
+--R                                    2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R                                                                     3
+--R                                                              atan(----)
+--R                                                                    +-+
+--R                                                                   \|3
+--R                                                          sin(----------)
+--R                                                                   2
+--R                                                     atan(---------------)
+--R                                                                     3
+--R            +-----------------------------------+             atan(----)
+--R            |           3   2              3   2                    +-+
+--R            |    atan(----)         atan(----)                     \|3
+--R            |          +-+                +-+             cos(----------)
+--R            |         \|3                \|3                       2
+--R         2 4|sin(----------)  + cos(----------)  sin(---------------------)
+--R           \|         2                  2                     2
+--R      *
+--R         atan
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                -
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  cos(---------------------)
+--R                                2
+--R              + 
+--R                     +-+4+-+
+--R                - 2x\|3 \|9
+--R     + 
+--R       -
+--R                                                                        3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R               +-----------------------------------+             atan(----)
+--R               |           3   2              3   2                    +-+
+--R               |    atan(----)         atan(----)                     \|3
+--R               |          +-+                +-+             cos(----------)
+--R               |         \|3                \|3                       2
+--R            2 4|sin(----------)  + cos(----------)  sin(---------------------)
+--R              \|         2                  2                     2
+--R         *
+--R            atan
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                   -
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                           |         \|3                \|3
+--R                        3 4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                     *
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 sin(----------)
+--R                                          2
+--R                            atan(---------------)
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 cos(----------)
+--R                                          2
+--R                        cos(---------------------)
+--R                                      2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R                 + 
+--R                      +-+4+-+
+--R                   2x\|3 \|9
+--R  /
+--R      4+-+
+--R     2\|9
+--R                                         Type: Union(Expression(Integer),...)
+--E 268
+
+--S 269 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                         3
+--R                                                                  atan(----)
+--R                                                                        +-+
+--R                                                                       \|3
+--R                                                              sin(----------)
+--R                                                                       2
+--R                                                         atan(---------------)
+--R                                                                         3
+--R                +-----------------------------------+             atan(----)
+--R                |           3   2              3   2                    +-+
+--R                |    atan(----)         atan(----)                     \|3
+--R                |          +-+                +-+             cos(----------)
+--R           +-+  |         \|3                \|3                       2
+--R         4\|3  4|sin(----------)  + cos(----------)  cos(---------------------)
+--R               \|         2                  2                     2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                  +-+4+-+  |         \|3                \|3
+--R                x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R             *
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                  4+-+  |         \|3                \|3
+--R                3x\|9  4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R             *
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R       -
+--R                   +-----------------------------------+
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R              +-+  |         \|3                \|3
+--R            4\|3  4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            cos(---------------------)
+--R                          2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                                 +-----------------------------------+
+--R                                 |           3   2              3   2
+--R                                 |    atan(----)         atan(----)
+--R                                 |          +-+                +-+
+--R                        +-+4+-+  |         \|3                \|3
+--R                      x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                                \|         2                  2
+--R                   *
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               cos(----------)
+--R                                        2
+--R                      sin(---------------------)
+--R                                    2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                              +-----------------------------------+
+--R                              |           3   2              3   2
+--R                              |    atan(----)         atan(----)
+--R                              |          +-+                +-+
+--R                        4+-+  |         \|3                \|3
+--R                      3x\|9  4|sin(----------)  + cos(----------)
+--R                             \|         2                  2
+--R                   *
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                          3
+--R                                   atan(----)
+--R                                         +-+
+--R                                        \|3
+--R                               cos(----------)
+--R                                        2
+--R                      cos(---------------------)
+--R                                    2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R                                                                         3
+--R                                                                  atan(----)
+--R                                                                        +-+
+--R                                                                       \|3
+--R                                                              sin(----------)
+--R                                                                       2
+--R                                                         atan(---------------)
+--R                                                                         3
+--R                +-----------------------------------+             atan(----)
+--R                |           3   2              3   2                    +-+
+--R                |    atan(----)         atan(----)                     \|3
+--R                |          +-+                +-+             cos(----------)
+--R           +-+  |         \|3                \|3                       2
+--R         8\|3  4|sin(----------)  + cos(----------)  sin(---------------------)
+--R               \|         2                  2                     2
+--R      *
+--R         atan
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                -
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                         +-----------------------------------+
+--R                         |           3   2              3   2
+--R                         |    atan(----)         atan(----)
+--R                         |          +-+                +-+
+--R                    +-+  |         \|3                \|3
+--R                  3\|3  4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  cos(---------------------)
+--R                                2
+--R              + 
+--R                     +-+4+-+
+--R                - 2x\|3 \|9
+--R     + 
+--R       -
+--R                   +-----------------------------------+
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R              +-+  |         \|3                \|3
+--R            8\|3  4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            sin(---------------------)
+--R                          2
+--R         *
+--R            atan
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                   -
+--R                           +-----------------------------------+
+--R                           |           3   2              3   2
+--R                           |    atan(----)         atan(----)
+--R                           |          +-+                +-+
+--R                           |         \|3                \|3
+--R                        3 4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                     *
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 sin(----------)
+--R                                          2
+--R                            atan(---------------)
+--R                                            3
+--R                                     atan(----)
+--R                                           +-+
+--R                                          \|3
+--R                                 cos(----------)
+--R                                          2
+--R                        cos(---------------------)
+--R                                      2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                            +-----------------------------------+
+--R                            |           3   2              3   2
+--R                            |    atan(----)         atan(----)
+--R                            |          +-+                +-+
+--R                       +-+  |         \|3                \|3
+--R                     3\|3  4|sin(----------)  + cos(----------)
+--R                           \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R                 + 
+--R                      +-+4+-+
+--R                   2x\|3 \|9
+--R     + 
+--R              +--------+      +--------+
+--R         4+-+ | +-+           | +-+         2
+--R       - \|9 \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R            +----------+      +----------+
+--R       4+-+ |   +-+           |   +-+         2
+--R       \|9 \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R              +----------+        +----------+
+--R         4+-+ |   +-+             |   +-+         2
+--R       - \|9 \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R            +--------+        +--------+
+--R       4+-+ | +-+             | +-+         2
+--R       \|9 \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R               +----------+
+--R          4+-+ |   +-+
+--R         2\|9 \|- \|3  + 2
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R                  +----------+
+--R             4+-+ |   +-+
+--R            2\|9 \|- \|3  + 2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R             +--------+                 +----------+                +--------+
+--R        4+-+ | +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|9 \|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R             +--------+                 +----------+                +--------+
+--R        4+-+ | +-+             +-+      |   +-+           +-+       | +-+
+--R     - 2\|9 \|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+4+-+
+--R     8\|3 \|9
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                               3   4                      3   2           3   2
+--R                        atan(----)                 atan(----)      atan(----)
+--R                              +-+                        +-+             +-+
+--R             8 4+-+2         \|3        8 4+-+2         \|3             \|3
+--R           3x  \|9  sin(----------) + 6x  \|9  cos(----------) sin(----------)
+--R                             2                          2               2
+--R         + 
+--R                               3   4
+--R                        atan(----)
+--R                              +-+
+--R             8 4+-+2         \|3
+--R           3x  \|9  cos(----------)
+--R                             2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               12x  \|9  sin(----------)
+--R                                  2
+--R             + 
+--R                                    3   2           3   2
+--R                             atan(----)      atan(----)
+--R                                   +-+             +-+
+--R                  8 4+-+2         \|3             \|3
+--R               24x  \|9  cos(----------) sin(----------)
+--R                                  2               2
+--R             + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               12x  \|9  cos(----------)
+--R                                  2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                              3   2                   3   2
+--R                       atan(----)              atan(----)
+--R                             +-+                     +-+
+--R                 10         \|3          10         \|3
+--R             (18x  sin(----------)  + 18x  cos(----------) )
+--R                            2                       2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 24x   - 12x  + 12x )\|3 sin(----------)
+--R                                               2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 24x   - 12x  + 12x )\|3 cos(----------)
+--R                                               2
+--R      *
+--R                                                                    3
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                             3     5
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               18x  \|9  sin(----------)
+--R                                  2
+--R             + 
+--R                                    3   2           3   2
+--R                             atan(----)      atan(----)
+--R                                   +-+             +-+
+--R                  8 4+-+2         \|3             \|3
+--R               36x  \|9  cos(----------) sin(----------)
+--R                                  2               2
+--R             + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               18x  \|9  cos(----------)
+--R                                  2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                              3   2                   3   2
+--R                       atan(----)              atan(----)
+--R                             +-+                     +-+
+--R                 10         \|3          10         \|3
+--R             (18x  sin(----------)  + 18x  cos(----------) )
+--R                            2                       2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (6x   + 3x  - 3x )\|9  sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (6x   + 3x  - 3x )\|9  cos(----------)
+--R                                           2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 48x   - 24x  + 24x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 48x   - 24x  + 24x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                       3   2
+--R                                                atan(----)
+--R                                                      +-+
+--R                    12     8     4  +-+4+-+2         \|3
+--R               (- 8x   - 4x  + 4x )\|3 \|9  sin(----------)
+--R                                                     2
+--R             + 
+--R                                                       3   2
+--R                                                atan(----)
+--R                                                      +-+
+--R                    12     8     4  +-+4+-+2         \|3
+--R               (- 8x   - 4x  + 4x )\|3 \|9  cos(----------)
+--R                                                     2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3     3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               12x  \|9  sin(----------)
+--R                                  2
+--R             + 
+--R                                    3   2           3   2
+--R                             atan(----)      atan(----)
+--R                                   +-+             +-+
+--R                  8 4+-+2         \|3             \|3
+--R               24x  \|9  cos(----------) sin(----------)
+--R                                  2               2
+--R             + 
+--R                                    3   4
+--R                             atan(----)
+--R                                   +-+
+--R                  8 4+-+2         \|3
+--R               12x  \|9  cos(----------)
+--R                                  2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                3   2                   3   2
+--R                         atan(----)              atan(----)
+--R                               +-+                     +-+
+--R                   10         \|3          10         \|3
+--R             (- 18x  sin(----------)  - 18x  cos(----------) )
+--R                              2                       2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                    3   2
+--R                                             atan(----)
+--R                                                   +-+
+--R                   12      8      4 4+-+2         \|3
+--R               (12x   + 30x  - 30x )\|9  sin(----------)
+--R                                                  2
+--R             + 
+--R                                                    3   2
+--R                                             atan(----)
+--R                                                   +-+
+--R                   12      8      4 4+-+2         \|3
+--R               (12x   + 30x  - 30x )\|9  cos(----------)
+--R                                                  2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                +-----------------------------------+2
+--R                                |           3   2              3   2
+--R                                |    atan(----)         atan(----)
+--R                                |          +-+                +-+
+--R              14     10     6   |         \|3                \|3
+--R           (9x   + 9x   - 9x ) 4|sin(----------)  + cos(----------)
+--R                               \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 24x   - 12x  + 12x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 24x   - 12x  + 12x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     5
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                  12     8     4  +-+4+-+2         \|3
+--R               (8x   + 4x  - 4x )\|3 \|9  sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                  12     8     4  +-+4+-+2         \|3
+--R               (8x   + 4x  - 4x )\|3 \|9  cos(----------)
+--R                                                   2
+--R          *
+--R                                 3     3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                          +-----------------------------------+2
+--R                                          |           3   2              3   2
+--R                                          |    atan(----)         atan(----)
+--R                                          |          +-+                +-+
+--R                  14      10      6  +-+  |         \|3                \|3
+--R             (- 6x   - 30x   + 30x )\|3  4|sin(----------)  + cos(----------)
+--R                                         \|         2                  2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                               3   4                      3   2           3   2
+--R                        atan(----)                 atan(----)      atan(----)
+--R                              +-+                        +-+             +-+
+--R             8 4+-+2         \|3        8 4+-+2         \|3             \|3
+--R           3x  \|9  sin(----------) + 6x  \|9  cos(----------) sin(----------)
+--R                             2                          2               2
+--R         + 
+--R                               3   4
+--R                        atan(----)
+--R                              +-+
+--R             8 4+-+2         \|3
+--R           3x  \|9  cos(----------)
+--R                             2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                            3   2                   3   2
+--R                     atan(----)              atan(----)
+--R                           +-+                     +-+
+--R               10         \|3          10         \|3
+--R         (- 18x  sin(----------)  - 18x  cos(----------) )
+--R                          2                       2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (6x   + 3x  - 3x )\|9  sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (6x   + 3x  - 3x )\|9  cos(----------)
+--R                                           2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                +-----------------------------------+2
+--R                                |           3   2              3   2
+--R                                |    atan(----)         atan(----)
+--R                                |          +-+                +-+
+--R              14     10     6   |         \|3                \|3
+--R         (- 9x   - 9x   + 9x ) 4|sin(----------)  + cos(----------)
+--R                               \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R          12     8 4+-+2
+--R       (3x   - 3x )\|9
+--R  /
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                          3   2           3   2
+--R                                   atan(----)      atan(----)
+--R                                         +-+             +-+
+--R              8     4     4+-+2         \|3             \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------) sin(----------)
+--R                                        2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )sin(----------)
+--R                                             2
+--R             + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )cos(----------)
+--R                                             2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 36x   + 36x  - 36x )\|3 sin(----------)
+--R                                               2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                 10      6      2  +-+         \|3
+--R           (- 36x   + 36x  - 36x )\|3 cos(----------)
+--R                                               2
+--R      *
+--R                                                                    3
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                             3     5
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (18x  - 18x  + 18)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (36x  - 36x  + 36)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (18x  - 18x  + 18)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )sin(----------)
+--R                                             2
+--R             + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (18x   - 18x  + 18x )cos(----------)
+--R                                             2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  cos(----------)
+--R                                           2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 72x   + 72x  - 72x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 72x   + 72x  - 72x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 12x   + 12x  - 12x )\|3 \|9  sin(----------)
+--R                                                        2
+--R             + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 12x   + 12x  - 12x )\|3 \|9  cos(----------)
+--R                                                        2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3     3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (12x  - 12x  + 12)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 18x   + 18x  - 18x )sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 18x   + 18x  - 18x )cos(----------)
+--R                                               2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                    3   2
+--R                                             atan(----)
+--R                                                   +-+
+--R                   12      8      4 4+-+2         \|3
+--R               (42x   - 42x  + 42x )\|9  sin(----------)
+--R                                                  2
+--R             + 
+--R                                                    3   2
+--R                                             atan(----)
+--R                                                   +-+
+--R                   12      8      4 4+-+2         \|3
+--R               (42x   - 42x  + 42x )\|9  cos(----------)
+--R                                                  2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                   +-----------------------------------+2
+--R                                   |           3   2              3   2
+--R                                   |    atan(----)         atan(----)
+--R                                   |          +-+                +-+
+--R               14      10      6   |         \|3                \|3
+--R           (18x   - 18x   + 18x ) 4|sin(----------)  + cos(----------)
+--R                                  \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 36x   + 36x  - 36x )\|3 sin(----------)
+--R                                                   2
+--R             + 
+--R                                                     3   2
+--R                                              atan(----)
+--R                                                    +-+
+--R                     10      6      2  +-+         \|3
+--R               (- 36x   + 36x  - 36x )\|3 cos(----------)
+--R                                                   2
+--R          *
+--R                                                                        3     5
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (12x   - 12x  + 12x )\|3 \|9  sin(----------)
+--R                                                      2
+--R             + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (12x   - 12x  + 12x )\|3 \|9  cos(----------)
+--R                                                      2
+--R          *
+--R                                 3     3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                           +-----------------------------------+2
+--R                                           |           3   2              3   2
+--R                                           |    atan(----)         atan(----)
+--R                                           |          +-+                +-+
+--R                   14      10      6  +-+  |         \|3                \|3
+--R             (- 36x   + 36x   - 36x )\|3  4|sin(----------)  + cos(----------)
+--R                                          \|         2                  2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                          3   2           3   2
+--R                                   atan(----)      atan(----)
+--R                                         +-+             +-+
+--R              8     4     4+-+2         \|3             \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------) sin(----------)
+--R                                        2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (3x  - 3x  + 3)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R                 10      6      2          \|3
+--R           (- 18x   + 18x  - 18x )sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R                 10      6      2          \|3
+--R           (- 18x   + 18x  - 18x )cos(----------)
+--R                                           2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  sin(----------)
+--R                                           2
+--R         + 
+--R                                             3   2
+--R                                      atan(----)
+--R                                            +-+
+--R              12     8     4 4+-+2         \|3
+--R           (9x   - 9x  + 9x )\|9  cos(----------)
+--R                                           2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                   +-----------------------------------+2
+--R                                   |           3   2              3   2
+--R                                   |    atan(----)         atan(----)
+--R                                   |          +-+                +-+
+--R               14      10      6   |         \|3                \|3
+--R         (- 18x   + 18x   - 18x ) 4|sin(----------)  + cos(----------)
+--R                                  \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R          16     12     8 4+-+2
+--R       (3x   - 3x   + 3x )\|9
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 649
+t0:=(1-x^4)/(x*(1-x^4+x^8))
+--R 
+--R
+--R             4
+--R          - x  + 1
+--R   (1)  -----------
+--R         9    5
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 271
+
+--S 272 of 649
+r0:=log(x)-1/8*log(1-x^4+x^8)+1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                        4      +-+
+--R           +-+     8    4          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 8\|3 log(x) - 2atan(-------------)
+--R                                                           3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   8\|3
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        4      +-+
+--R           +-+     8    4          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 8\|3 log(x) - 2atan(-------------)
+--R                                                           3
+--R   (3)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 273
+
+--S 274 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 275
+
+)clear all
+
+--S 276 of 649
+t0:=(1-x^4)/(x^2*(1-x^4+x^8))
+--R 
+--R
+--R              4
+--R           - x  + 1
+--R   (1)  -------------
+--R         10    6    2
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 276
+
+--S 277 of 649
+r0:=(-1)/x+1/2*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)-_
+   1/2*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/2*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/2*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/4*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(6)+1/4*log(1+x^2+_
+   x*sqrt(2-sqrt(3)))/sqrt(6)-1/4*log(1+x^2-x*sqrt(2+sqrt(3)))/_
+   sqrt(6)+1/4*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R               +--------+                     +----------+
+--R               | +-+         2                |   +-+         2
+--R       x log(x\|\|3  + 2  + x  + 1) + x log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                   +----------+                       +--------+
+--R                   |   +-+         2                  | +-+         2
+--R       - x log(- x\|- \|3  + 2  + x  + 1) - x log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R            2x
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R         2x
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R                           +----------+                +--------+
+--R                  +-+      |   +-+           +-+       | +-+
+--R       2x atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                             +----------+                +--------+
+--R                    +-+      |   +-+           +-+       | +-+           +-+
+--R       - 2x atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 ) - 4\|6
+--R  /
+--R        +-+
+--R     4x\|6
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         +-+ +-+      3      +-+ +-+    4     2
+--R       x\|2 \|3 log((x  + x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R           +-+ +-+        3      +-+ +-+    4     2
+--R       - x\|2 \|3 log((- x  - x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R                        +-+ +-+                           +-+ +-+
+--R          +-+ +-+      \|2 \|3  + 3x        +-+ +-+      \|2 \|3  - 3x
+--R       2x\|2 \|3 atan(---------------) - 2x\|2 \|3 atan(---------------) - 24
+--R                       2 +-+ +-+                         2 +-+ +-+
+--R                      x \|2 \|3  + 3x                   x \|2 \|3  - 3x
+--R  /
+--R     24x
+--R                                         Type: Union(Expression(Integer),...)
+--E 278
+
+--S 279 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +--------+                    +----------+
+--R                | +-+         2               |   +-+         2
+--R       - 6log(x\|\|3  + 2  + x  + 1) - 6log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                +----------+                      +--------+
+--R                |   +-+         2                 | +-+         2
+--R       6log(- x\|- \|3  + 2  + x  + 1) + 6log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R       12atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R            12
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R                            +----------+                +--------+
+--R                   +-+      |   +-+           +-+       | +-+
+--R       - 12atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                          +----------+                +--------+
+--R                 +-+      |   +-+           +-+       | +-+
+--R       12atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R        +-+ +-+ +-+      3      +-+ +-+    4     2
+--R       \|2 \|3 \|6 log((x  + x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R          +-+ +-+ +-+        3      +-+ +-+    4     2
+--R       - \|2 \|3 \|6 log((- x  - x)\|2 \|3  + x  + 3x  + 1)
+--R     + 
+--R                           +-+ +-+                              +-+ +-+
+--R         +-+ +-+ +-+      \|2 \|3  + 3x       +-+ +-+ +-+      \|2 \|3  - 3x
+--R       2\|2 \|3 \|6 atan(---------------) - 2\|2 \|3 \|6 atan(---------------)
+--R                          2 +-+ +-+                            2 +-+ +-+
+--R                         x \|2 \|3  + 3x                      x \|2 \|3  - 3x
+--R  /
+--R        +-+
+--R     24\|6
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                +--------+                          +----------+
+--R           2 +-+    6    2  +-+ | +-+          2 +-+    6    2  +-+ |   +-+
+--R       (- x \|3  + x  + x )\|6 \|\|3  + 2  + (x \|3  + x  + x )\|6 \|- \|3  + 2
+--R     + 
+--R           6
+--R       - 6x
+--R  /
+--R       8     4
+--R     6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 649
+t0:=(1-x^4)/(x^3*(1-x^4+x^8))
+--R 
+--R
+--R              4
+--R           - x  + 1
+--R   (1)  -------------
+--R         11    7    3
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 281
+
+--S 282 of 649
+r0:=(-1/2)/x^2+1/4*atan(-2*x^2+sqrt(3))-1/4*atan(2*x^2+sqrt(3))-_
+   1/8*log(1+x^4-x^2*sqrt(3))/sqrt(3)+1/8*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R        2     2 +-+    4         2       2 +-+    4
+--R       x log(x \|3  + x  + 1) - x log(- x \|3  + x  + 1)
+--R     + 
+--R           2 +-+      +-+     2      2 +-+      +-+     2      +-+
+--R       - 2x \|3 atan(\|3  + 2x ) + 2x \|3 atan(\|3  - 2x ) - 4\|3
+--R  /
+--R       2 +-+
+--R     8x \|3
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                         3
+--R                  atan(----)
+--R                        +-+
+--R             2         \|3
+--R            x cos(----------)
+--R                       2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3         2         \|3               \|3        4
+--R            log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                      3
+--R               atan(----)
+--R                     +-+
+--R          2         \|3
+--R         x cos(----------)
+--R                    2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3         2         \|3               \|3        4
+--R         log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R                                            3
+--R                                     atan(----)
+--R                     3                     +-+
+--R              atan(----)                  \|3
+--R                    +-+          cos(----------)
+--R         2         \|3                    2
+--R       2x sin(----------)atan(--------------------)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3       2
+--R                              sin(----------) - x
+--R                                       2
+--R     + 
+--R                                              3
+--R                                       atan(----)
+--R                       3                     +-+
+--R                atan(----)                  \|3
+--R                      +-+          cos(----------)
+--R           2         \|3                    2             +-+
+--R       - 2x sin(----------)atan(--------------------) - 2\|3
+--R                     2                     3
+--R                                    atan(----)
+--R                                          +-+
+--R                                         \|3       2
+--R                                sin(----------) + x
+--R                                         2
+--R  /
+--R       2 +-+
+--R     4x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 283
+
+--S 284 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R                           3   2                 3                 3   2
+--R                    atan(----)            atan(----)        atan(----)
+--R                          +-+                   +-+               +-+
+--R                         \|3         2         \|3               \|3        4
+--R            log(sin(----------)  + 2x sin(----------) + cos(----------)  + x )
+--R                         2                     2                 2
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R                        3   2                 3                 3   2
+--R                 atan(----)            atan(----)        atan(----)
+--R                       +-+                   +-+               +-+
+--R                      \|3         2         \|3               \|3        4
+--R         log(sin(----------)  - 2x sin(----------) + cos(----------)  + x )
+--R                      2                     2                 2
+--R     + 
+--R                                          3
+--R                                   atan(----)
+--R                   3                     +-+
+--R            atan(----)                  \|3
+--R                  +-+          cos(----------)
+--R                 \|3                    2
+--R       4sin(----------)atan(--------------------)
+--R                 2                     3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3       2
+--R                            sin(----------) - x
+--R                                     2
+--R     + 
+--R                                            3
+--R                                     atan(----)
+--R                     3                     +-+
+--R              atan(----)                  \|3
+--R                    +-+          cos(----------)
+--R                   \|3                    2                2 +-+    4
+--R       - 4sin(----------)atan(--------------------) - log(x \|3  + x  + 1)
+--R                   2                     3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3       2
+--R                              sin(----------) + x
+--R                                       2
+--R     + 
+--R              2 +-+    4          +-+      +-+     2      +-+      +-+     2
+--R       log(- x \|3  + x  + 1) + 2\|3 atan(\|3  + 2x ) - 2\|3 atan(\|3  - 2x )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     3   4                  3   2                  3   2
+--R              atan(----)             atan(----)             atan(----)
+--R                    +-+                    +-+                    +-+
+--R         5         \|3          5         \|3         9          \|3
+--R       3x sin(----------)  + (6x cos(----------)  - 6x )sin(----------)
+--R                   2                      2                      2
+--R     + 
+--R                                        3              3
+--R                                 atan(----)     atan(----)
+--R                                       +-+            +-+
+--R          13     9     5  +-+         \|3            \|3
+--R       (4x   - 4x  + 4x )\|3 cos(----------)sin(----------)
+--R                                      2              2
+--R     + 
+--R                     3   4                 3   2
+--R              atan(----)            atan(----)
+--R                    +-+                   +-+
+--R         5         \|3         9         \|3         13
+--R       3x cos(----------)  + 6x cos(----------)  + 3x
+--R                   2                     2
+--R  /
+--R                                 3   4
+--R                          atan(----)
+--R                                +-+
+--R          8     4              \|3
+--R       (3x  - 3x  + 3)sin(----------)
+--R                               2
+--R     + 
+--R                                  3   2                               3   2
+--R                           atan(----)                          atan(----)
+--R                                 +-+                                 +-+
+--R           8     4              \|3         12     8     4          \|3
+--R       ((6x  - 6x  + 6)cos(----------)  - 6x   + 6x  - 6x )sin(----------)
+--R                                2                                   2
+--R     + 
+--R                                 3   4                                3   2
+--R                          atan(----)                           atan(----)
+--R                                +-+                                  +-+
+--R          8     4              \|3          12     8     4          \|3
+--R       (3x  - 3x  + 3)cos(----------)  + (6x   - 6x  + 6x )cos(----------)
+--R                               2                                    2
+--R     + 
+--R         16     12     8
+--R       3x   - 3x   + 3x
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 649
+t0:=(1-x^4)/(x^4*(1-x^4+x^8))
+--R 
+--R
+--R              4
+--R           - x  + 1
+--R   (1)  -------------
+--R         12    8    4
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 286
+
+--S 287 of 649
+r0:=(-1/3)/x^3+1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/_
+   sqrt(3*(2-sqrt(3)))-1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/_
+   sqrt(3*(2-sqrt(3)))+1/8*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(3*(2-_
+   sqrt(3)))-1/8*log(1+x^2+x*sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))-_
+   1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))+_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))-_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))+1/8*log(1+x^2+_
+   x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R           +-----------+      +--------+
+--R         3 |    +-+           | +-+         2
+--R       3x \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R             +---------+      +----------+
+--R           3 |  +-+           |   +-+         2
+--R       - 3x \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R           +---------+        +----------+
+--R         3 |  +-+             |   +-+         2
+--R       3x \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R             +-----------+        +--------+
+--R           3 |    +-+             | +-+         2
+--R       - 3x \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R                +---------+
+--R              3 |  +-+
+--R            6x \|3\|3  + 6
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R             +---------+
+--R           3 |  +-+
+--R         6x \|3\|3  + 6
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R                +-----------+
+--R              3 |    +-+
+--R            6x \|- 3\|3  + 6
+--R         *
+--R                             +----------+                +--------+
+--R                    +-+      |   +-+           +-+       | +-+
+--R            atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R           +-----------+                 +----------+                +--------+
+--R         3 |    +-+             +-+      |   +-+           +-+       | +-+
+--R       6x \|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R           +-----------+ +---------+
+--R           |    +-+      |  +-+
+--R       - 8\|- 3\|3  + 6 \|3\|3  + 6
+--R  /
+--R          +-----------+ +---------+
+--R        3 |    +-+      |  +-+
+--R     24x \|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                                                                          3
+--R                                                                   atan(----)
+--R                                                                         +-+
+--R                                                                        \|3
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                          3
+--R                 +-----------------------------------+             atan(----)
+--R                 |           3   2              3   2                    +-+
+--R                 |    atan(----)         atan(----)                     \|3
+--R                 |          +-+                +-+             cos(----------)
+--R              3  |         \|3                \|3                       2
+--R            3x  4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                \|         2                  2                     2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                               +-----------------------------------+
+--R                               |           3   2              3   2
+--R                               |    atan(----)         atan(----)
+--R                               |          +-+                +-+
+--R                      +-+4+-+  |         \|3                \|3
+--R                   2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                              \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R                                                                       3
+--R                                                                atan(----)
+--R                                                                      +-+
+--R                                                                     \|3
+--R                                                            sin(----------)
+--R                                                                     2
+--R                                                       atan(---------------)
+--R                                                                       3
+--R              +-----------------------------------+             atan(----)
+--R              |           3   2              3   2                    +-+
+--R              |    atan(----)         atan(----)                     \|3
+--R              |          +-+                +-+             cos(----------)
+--R           3  |         \|3                \|3                       2
+--R         3x  4|sin(----------)  + cos(----------)  cos(---------------------)
+--R             \|         2                  2                     2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R              -
+--R                               +-----------------------------------+
+--R                               |           3   2              3   2
+--R                               |    atan(----)         atan(----)
+--R                               |          +-+                +-+
+--R                      +-+4+-+  |         \|3                \|3
+--R                   2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                              \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R                                                                       3
+--R                                                                atan(----)
+--R                                                                      +-+
+--R                                                                     \|3
+--R                                                            sin(----------)
+--R                                                                     2
+--R                                                       atan(---------------)
+--R                                                                       3
+--R              +-----------------------------------+             atan(----)
+--R              |           3   2              3   2                    +-+
+--R              |    atan(----)         atan(----)                     \|3
+--R              |          +-+                +-+             cos(----------)
+--R           3  |         \|3                \|3                       2
+--R         6x  4|sin(----------)  + cos(----------)  sin(---------------------)
+--R             \|         2                  2                     2
+--R      *
+--R         atan
+--R                                                                          3
+--R                                                                   atan(----)
+--R                                                                         +-+
+--R                                                                        \|3
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                          3
+--R                 +-----------------------------------+             atan(----)
+--R                 |           3   2              3   2                    +-+
+--R                 |    atan(----)         atan(----)                     \|3
+--R                 |          +-+                +-+             cos(----------)
+--R                 |         \|3                \|3                       2
+--R              3 4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                \|         2                  2                     2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                    +-+4+-+
+--R                - x\|3 \|9
+--R     + 
+--R       -
+--R                                                                          3
+--R                                                                   atan(----)
+--R                                                                         +-+
+--R                                                                        \|3
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                          3
+--R                 +-----------------------------------+             atan(----)
+--R                 |           3   2              3   2                    +-+
+--R                 |    atan(----)         atan(----)                     \|3
+--R                 |          +-+                +-+             cos(----------)
+--R              3  |         \|3                \|3                       2
+--R            6x  4|sin(----------)  + cos(----------)  sin(---------------------)
+--R                \|         2                  2                     2
+--R         *
+--R            atan
+--R                      +-----------------------------------+
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                     +-+4+-+
+--R                   x\|3 \|9
+--R     + 
+--R          4+-+
+--R       - 2\|9
+--R  /
+--R       3 4+-+
+--R     6x  \|9
+--R                                         Type: Union(Expression(Integer),...)
+--E 288
+
+--S 289 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                         +-----------------------------------+
+--R                                         |           3   2              3   2
+--R                                         |    atan(----)         atan(----)
+--R              +-----------+ +---------+  |          +-+                +-+
+--R              |    +-+      |  +-+       |         \|3                \|3
+--R            4\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                        \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            cos(---------------------)
+--R                          2
+--R         *
+--R            log
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                               +-----------------------------------+
+--R                               |           3   2              3   2
+--R                               |    atan(----)         atan(----)
+--R                               |          +-+                +-+
+--R                      +-+4+-+  |         \|3                \|3
+--R                   2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                              \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                      +-----------------------------------+2
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3     2
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                  2 4+-+2
+--R                 x  \|9
+--R     + 
+--R                                      +-----------------------------------+
+--R                                      |           3   2              3   2
+--R                                      |    atan(----)         atan(----)
+--R           +-----------+ +---------+  |          +-+                +-+
+--R           |    +-+      |  +-+       |         \|3                \|3
+--R         4\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                     \|         2                  2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R      *
+--R         log
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                sin(---------------------)
+--R                              2
+--R            + 
+--R              -
+--R                               +-----------------------------------+
+--R                               |           3   2              3   2
+--R                               |    atan(----)         atan(----)
+--R                               |          +-+                +-+
+--R                      +-+4+-+  |         \|3                \|3
+--R                   2x\|3 \|9  4|sin(----------)  + cos(----------)
+--R                              \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R            + 
+--R                   +-----------------------------------+2
+--R                   |           3   2              3   2
+--R                   |    atan(----)         atan(----)
+--R                   |          +-+                +-+
+--R                   |         \|3                \|3
+--R                3 4|sin(----------)  + cos(----------)
+--R                  \|         2                  2
+--R             *
+--R                                    3     2
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         sin(----------)
+--R                                  2
+--R                    atan(---------------)
+--R                                    3
+--R                             atan(----)
+--R                                   +-+
+--R                                  \|3
+--R                         cos(----------)
+--R                                  2
+--R                cos(---------------------)
+--R                              2
+--R            + 
+--R               2 4+-+2
+--R              x  \|9
+--R     + 
+--R                                      +-----------------------------------+
+--R                                      |           3   2              3   2
+--R                                      |    atan(----)         atan(----)
+--R           +-----------+ +---------+  |          +-+                +-+
+--R           |    +-+      |  +-+       |         \|3                \|3
+--R         8\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                     \|         2                  2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R      *
+--R         atan
+--R                                                                          3
+--R                                                                   atan(----)
+--R                                                                         +-+
+--R                                                                        \|3
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                          3
+--R                 +-----------------------------------+             atan(----)
+--R                 |           3   2              3   2                    +-+
+--R                 |    atan(----)         atan(----)                     \|3
+--R                 |          +-+                +-+             cos(----------)
+--R                 |         \|3                \|3                       2
+--R              3 4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                \|         2                  2                     2
+--R           /
+--R                     +-----------------------------------+
+--R                     |           3   2              3   2
+--R                     |    atan(----)         atan(----)
+--R                     |          +-+                +-+
+--R                     |         \|3                \|3
+--R                  3 4|sin(----------)  + cos(----------)
+--R                    \|         2                  2
+--R               *
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                      3
+--R                               atan(----)
+--R                                     +-+
+--R                                    \|3
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                    +-+4+-+
+--R                - x\|3 \|9
+--R     + 
+--R       -
+--R                                         +-----------------------------------+
+--R                                         |           3   2              3   2
+--R                                         |    atan(----)         atan(----)
+--R              +-----------+ +---------+  |          +-+                +-+
+--R              |    +-+      |  +-+       |         \|3                \|3
+--R            8\|- 3\|3  + 6 \|3\|3  + 6  4|sin(----------)  + cos(----------)
+--R                                        \|         2                  2
+--R         *
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     sin(----------)
+--R                              2
+--R                atan(---------------)
+--R                                3
+--R                         atan(----)
+--R                               +-+
+--R                              \|3
+--R                     cos(----------)
+--R                              2
+--R            sin(---------------------)
+--R                          2
+--R         *
+--R            atan
+--R                      +-----------------------------------+
+--R                      |           3   2              3   2
+--R                      |    atan(----)         atan(----)
+--R                      |          +-+                +-+
+--R                      |         \|3                \|3
+--R                   3 4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                *
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                       3
+--R                                atan(----)
+--R                                      +-+
+--R                                     \|3
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R              /
+--R                        +-----------------------------------+
+--R                        |           3   2              3   2
+--R                        |    atan(----)         atan(----)
+--R                        |          +-+                +-+
+--R                        |         \|3                \|3
+--R                     3 4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R                  *
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                         3
+--R                                  atan(----)
+--R                                        +-+
+--R                                       \|3
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                     +-+4+-+
+--R                   x\|3 \|9
+--R     + 
+--R              +-----------+      +--------+
+--R         4+-+ |    +-+           | +-+         2
+--R       - \|9 \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R            +---------+      +----------+
+--R       4+-+ |  +-+           |   +-+         2
+--R       \|9 \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R              +---------+        +----------+
+--R         4+-+ |  +-+             |   +-+         2
+--R       - \|9 \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R            +-----------+        +--------+
+--R       4+-+ |    +-+             | +-+         2
+--R       \|9 \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R               +---------+
+--R          4+-+ |  +-+
+--R         2\|9 \|3\|3  + 6
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R                  +---------+
+--R             4+-+ |  +-+
+--R            2\|9 \|3\|3  + 6
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R               +-----------+
+--R          4+-+ |    +-+
+--R         2\|9 \|- 3\|3  + 6
+--R      *
+--R                          +----------+                +--------+
+--R                 +-+      |   +-+           +-+       | +-+
+--R         atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R       -
+--R                  +-----------+
+--R             4+-+ |    +-+
+--R            2\|9 \|- 3\|3  + 6
+--R         *
+--R                             +----------+                +--------+
+--R                    +-+      |   +-+           +-+       | +-+
+--R            atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R           +-----------+ +---------+
+--R      4+-+ |    +-+      |  +-+
+--R     8\|9 \|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                              +--------+ +---------+
+--R                   4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((3x  + 1)\|3  - 5x  - 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                              +-----------+ +----------+
+--R                   4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((3x  + 1)\|3  + 5x  + 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                               +--------+ +---------+
+--R                   4      +-+      4     4+-+2 | +-+      |  +-+
+--R               ((6x  + 2)\|3  - 10x  - 4)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                               +-----------+ +----------+
+--R                   4      +-+      4     4+-+2 |    +-+      |   +-+
+--R               ((6x  + 2)\|3  + 10x  + 4)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2           3   2
+--R                 atan(----)      atan(----)
+--R                       +-+             +-+
+--R                      \|3             \|3
+--R             cos(----------) sin(----------)
+--R                      2               2
+--R         + 
+--R                                              +--------+ +---------+
+--R                   4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((3x  + 1)\|3  - 5x  - 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                              +-----------+ +----------+
+--R                   4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((3x  + 1)\|3  + 5x  + 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                    +--------+ +---------+
+--R                        4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((12x  + 4)\|3  - 20x  - 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                   ((12x  + 4)\|3  + 20x  + 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                     +--------+ +---------+
+--R                        4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((24x  + 8)\|3  - 40x  - 16)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                   ((24x  + 8)\|3  + 40x  + 16)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2           3   2
+--R                     atan(----)      atan(----)
+--R                           +-+             +-+
+--R                          \|3             \|3
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                                                    +--------+ +---------+
+--R                        4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((12x  + 4)\|3  - 20x  - 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                   ((12x  + 4)\|3  + 20x  + 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                       +--------+ +---------+
+--R                          6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                 ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                       +--------+ +---------+
+--R                          6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                 ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R               10      6      2  +-+         \|3
+--R           (24x   - 24x  + 24x )\|3 sin(----------)
+--R                                             2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R               10      6      2  +-+         \|3
+--R           (24x   - 24x  + 24x )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                                                                    3
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                             3     5
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                     +--------+ +---------+
+--R                        4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((18x  + 6)\|3  - 30x  - 12)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                   ((18x  + 6)\|3  + 30x  + 12)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                      +--------+ +---------+
+--R                        4       +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((36x  + 12)\|3  - 60x  - 24)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                      4       +-+      4      4+-+2 |    +-+      |   +-+
+--R                 ((36x  + 12)\|3  + 60x  + 24)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2           3   2
+--R                     atan(----)      atan(----)
+--R                           +-+             +-+
+--R                          \|3             \|3
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                                                     +--------+ +---------+
+--R                        4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((18x  + 6)\|3  - 30x  - 12)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                   ((18x  + 6)\|3  + 30x  + 12)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                       +--------+ +---------+
+--R                          6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                 ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                       +--------+ +---------+
+--R                          6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((- 36x  - 12x )\|3  + 60x  + 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                 ((- 36x  - 12x )\|3  - 60x  - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                    8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((18x  + 6x )\|3  - 30x  - 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R               ((18x  + 6x )\|3  + 30x  + 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                    8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((18x  + 6x )\|3  - 30x  - 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R               ((18x  + 6x )\|3  + 30x  + 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (48x   - 48x  + 48x )\|3 sin(----------)
+--R                                                 2
+--R             + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (48x   - 48x  + 48x )\|3 cos(----------)
+--R                                                 2
+--R          *
+--R                                                                        3     3
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 16x   + 16x  - 16x )\|3 \|9  sin(----------)
+--R                                                        2
+--R             + 
+--R                                                          3   2
+--R                                                   atan(----)
+--R                                                         +-+
+--R                     12      8      4  +-+4+-+2         \|3
+--R               (- 16x   + 16x  - 16x )\|3 \|9  cos(----------)
+--R                                                        2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3     3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                    +--------+ +---------+
+--R                        4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((12x  + 4)\|3  - 20x  - 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                   ((12x  + 4)\|3  + 20x  + 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                     +--------+ +---------+
+--R                        4      +-+      4      4+-+2 | +-+      |  +-+
+--R                   ((24x  + 8)\|3  - 40x  - 16)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        4      +-+      4      4+-+2 |    +-+      |   +-+
+--R                   ((24x  + 8)\|3  + 40x  + 16)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2           3   2
+--R                     atan(----)      atan(----)
+--R                           +-+             +-+
+--R                          \|3             \|3
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                                                    +--------+ +---------+
+--R                        4      +-+      4     4+-+2 | +-+      |  +-+
+--R                   ((12x  + 4)\|3  - 20x  - 8)\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                    +-----------+ +----------+
+--R                        4      +-+      4     4+-+2 |    +-+      |   +-+
+--R                   ((12x  + 4)\|3  + 20x  + 8)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   4
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                        6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                   ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                     +--------+ +---------+
+--R                        6      2  +-+      6      2  | +-+      |  +-+
+--R                   ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                     +-----------+ +----------+
+--R                        6      2  +-+      6      2  |    +-+      |   +-+
+--R                   ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                          +--------+ +---------+
+--R                          8     4  +-+      8     4 4+-+2 | +-+      |  +-+
+--R                   ((- 12x  - 4x )\|3  + 20x  + 8x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                            +-----------+
+--R                            8     4  +-+      8     4 4+-+2 |    +-+
+--R                     ((- 12x  - 4x )\|3  - 20x  - 8x )\|9  \|- 3\|3  + 6
+--R                  *
+--R                      +----------+
+--R                      |   +-+
+--R                     \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                                          +--------+ +---------+
+--R                          8     4  +-+      8     4 4+-+2 | +-+      |  +-+
+--R                   ((- 12x  - 4x )\|3  + 20x  + 8x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R                 + 
+--R                                                            +-----------+
+--R                            8     4  +-+      8     4 4+-+2 |    +-+
+--R                     ((- 12x  - 4x )\|3  - 20x  - 8x )\|9  \|- 3\|3  + 6
+--R                  *
+--R                      +----------+
+--R                      |   +-+
+--R                     \|- \|3  + 2
+--R              *
+--R                            3   2
+--R                     atan(----)
+--R                           +-+
+--R                          \|3
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                      10      6  +-+      10      6  | +-+      |  +-+
+--R               ((- 36x   - 12x )\|3  + 60x   + 24x )\|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                      10      6  +-+      10      6  |    +-+      |   +-+
+--R               ((- 36x   - 12x )\|3  - 60x   - 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (24x   - 24x  + 24x )\|3 sin(----------)
+--R                                                 2
+--R             + 
+--R                                                   3   2
+--R                                            atan(----)
+--R                                                  +-+
+--R                   10      6      2  +-+         \|3
+--R               (24x   - 24x  + 24x )\|3 cos(----------)
+--R                                                 2
+--R          *
+--R                                                                        3     5
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (16x   - 16x  + 16x )\|3 \|9  sin(----------)
+--R                                                      2
+--R             + 
+--R                                                        3   2
+--R                                                 atan(----)
+--R                                                       +-+
+--R                   12      8      4  +-+4+-+2         \|3
+--R               (16x   - 16x  + 16x )\|3 \|9  cos(----------)
+--R                                                      2
+--R          *
+--R                                 3     3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                         +-----------------------------------+2
+--R                                         |           3   2              3   2
+--R                                         |    atan(----)         atan(----)
+--R                                         |          +-+                +-+
+--R                 14      10      6  +-+  |         \|3                \|3
+--R             (24x   - 24x   + 24x )\|3  4|sin(----------)  + cos(----------)
+--R                                        \|         2                  2
+--R          *
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                              +--------+ +---------+
+--R                   4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((3x  + 1)\|3  - 5x  - 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                              +-----------+ +----------+
+--R                   4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((3x  + 1)\|3  + 5x  + 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                               +--------+ +---------+
+--R                   4      +-+      4     4+-+2 | +-+      |  +-+
+--R               ((6x  + 2)\|3  - 10x  - 4)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                               +-----------+ +----------+
+--R                   4      +-+      4     4+-+2 |    +-+      |   +-+
+--R               ((6x  + 2)\|3  + 10x  + 4)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2           3   2
+--R                 atan(----)      atan(----)
+--R                       +-+             +-+
+--R                      \|3             \|3
+--R             cos(----------) sin(----------)
+--R                      2               2
+--R         + 
+--R                                              +--------+ +---------+
+--R                   4      +-+     4     4+-+2 | +-+      |  +-+
+--R               ((3x  + 1)\|3  - 5x  - 2)\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                              +-----------+ +----------+
+--R                   4      +-+     4     4+-+2 |    +-+      |   +-+
+--R               ((3x  + 1)\|3  + 5x  + 2)\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   4
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                                 +--------+ +---------+
+--R                    6      2  +-+      6      2  | +-+      |  +-+
+--R               ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                 +-----------+ +----------+
+--R                    6      2  +-+      6      2  |    +-+      |   +-+
+--R               ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                 +--------+ +---------+
+--R                    6      2  +-+      6      2  | +-+      |  +-+
+--R               ((36x  + 12x )\|3  - 60x  - 24x )\|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                 +-----------+ +----------+
+--R                    6      2  +-+      6      2  |    +-+      |   +-+
+--R               ((36x  + 12x )\|3  + 60x  + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                                     +--------+ +---------+
+--R                    8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((18x  + 6x )\|3  - 30x  - 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R               ((18x  + 6x )\|3  + 30x  + 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                                     +--------+ +---------+
+--R                    8     4  +-+      8      4 4+-+2 | +-+      |  +-+
+--R               ((18x  + 6x )\|3  - 30x  - 12x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R             + 
+--R                                                     +-----------+ +----------+
+--R                    8     4  +-+      8      4 4+-+2 |    +-+      |   +-+
+--R               ((18x  + 6x )\|3  + 30x  + 12x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R          *
+--R                        3   2
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R             cos(----------)
+--R                      2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                               +--------+ +---------+
+--R                10      6  +-+      10      6  | +-+      |  +-+
+--R           ((36x   + 12x )\|3  - 60x   - 24x )\|\|3  + 2 \|3\|3  + 6
+--R         + 
+--R                                               +-----------+ +----------+
+--R                10      6  +-+      10      6  |    +-+      |   +-+
+--R           ((36x   + 12x )\|3  + 60x   + 24x )\|- 3\|3  + 6 \|- \|3  + 2
+--R      *
+--R                                                                    3     2
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                           +--------+ +---------+
+--R           12    8  +-+     12     8 4+-+2 | +-+      |  +-+
+--R       ((3x   + x )\|3  - 5x   - 2x )\|9  \|\|3  + 2 \|3\|3  + 6
+--R     + 
+--R                                           +-----------+ +----------+
+--R           12    8  +-+     12     8 4+-+2 |    +-+      |   +-+
+--R       ((3x   + x )\|3  + 5x   + 2x )\|9  \|- 3\|3  + 6 \|- \|3  + 2
+--R  /
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                             3   2           3   2
+--R                                      atan(----)      atan(----)
+--R                                            +-+             +-+
+--R               8      4      4+-+2         \|3             \|3
+--R           (12x  - 12x  + 12)\|9  cos(----------) sin(----------)
+--R                                           2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (48x  - 48x  + 48)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )cos(----------)
+--R                                               2
+--R          *
+--R              +-----------------------------------+2
+--R              |           3   2              3   2
+--R              |    atan(----)         atan(----)
+--R              |          +-+                +-+
+--R              |         \|3                \|3
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                             3     6
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (36x  - 36x  + 36)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (72x  - 72x  + 72)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (36x  - 36x  + 36)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     4
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2
+--R                                          atan(----)
+--R                                                +-+
+--R                     10      6      2          \|3
+--R               (- 72x   + 72x  - 72x )cos(----------)
+--R                                               2
+--R          *
+--R                                                                        3     2
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  sin(----------)
+--R                                              2
+--R         + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  cos(----------)
+--R                                              2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  sin(----------)
+--R                                               2
+--R             + 
+--R                                                 3   2           3   2
+--R                                          atan(----)      atan(----)
+--R                                                +-+             +-+
+--R                   8      4      4+-+2         \|3             \|3
+--R               (48x  - 48x  + 48)\|9  cos(----------) sin(----------)
+--R                                               2               2
+--R             + 
+--R                                                 3   4
+--R                                          atan(----)
+--R                                                +-+
+--R                   8      4      4+-+2         \|3
+--R               (24x  - 24x  + 24)\|9  cos(----------)
+--R                                               2
+--R          *
+--R                                 3     6
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (72x   - 72x  + 72x )sin(----------)
+--R                                             2
+--R             + 
+--R                                               3   2
+--R                                        atan(----)
+--R                                              +-+
+--R                   10      6      2          \|3
+--R               (72x   - 72x  + 72x )cos(----------)
+--R                                             2
+--R          *
+--R                                                                        3     4
+--R                                                                 atan(----)
+--R                                                                       +-+
+--R                                                                      \|3
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                        3
+--R              +-----------------------------------+2             atan(----)
+--R              |           3   2              3   2                     +-+
+--R              |    atan(----)         atan(----)                      \|3
+--R              |          +-+                +-+              cos(----------)
+--R              |         \|3                \|3                        2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                      3   2
+--R                                               atan(----)
+--R                                                     +-+
+--R                     12      8      4 4+-+2         \|3
+--R               (- 24x   + 24x  - 24x )\|9  sin(----------)
+--R                                                    2
+--R             + 
+--R                                                      3   2
+--R                                               atan(----)
+--R                                                     +-+
+--R                     12      8      4 4+-+2         \|3
+--R               (- 24x   + 24x  - 24x )\|9  cos(----------)
+--R                                                    2
+--R          *
+--R                                 3     2
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                 3
+--R                          atan(----)
+--R                                +-+
+--R                               \|3
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                     +-----------------------------------+2
+--R                                     |           3   2              3   2
+--R                                     |    atan(----)         atan(----)
+--R                                     |          +-+                +-+
+--R                 14      10      6   |         \|3                \|3
+--R           (- 72x   + 72x   - 72x ) 4|sin(----------)  + cos(----------)
+--R                                    \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  sin(----------)
+--R                                        2
+--R         + 
+--R                                             3   2           3   2
+--R                                      atan(----)      atan(----)
+--R                                            +-+             +-+
+--R               8      4      4+-+2         \|3             \|3
+--R           (12x  - 12x  + 12)\|9  cos(----------) sin(----------)
+--R                                           2               2
+--R         + 
+--R                                          3   4
+--R                                   atan(----)
+--R                                         +-+
+--R              8     4     4+-+2         \|3
+--R           (6x  - 6x  + 6)\|9  cos(----------)
+--R                                        2
+--R      *
+--R                             3     8
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                           3   2
+--R                                    atan(----)
+--R                                          +-+
+--R               10      6      2          \|3
+--R           (72x   - 72x  + 72x )sin(----------)
+--R                                         2
+--R         + 
+--R                                           3   2
+--R                                    atan(----)
+--R                                          +-+
+--R               10      6      2          \|3
+--R           (72x   - 72x  + 72x )cos(----------)
+--R                                         2
+--R      *
+--R                                                                    3     6
+--R                                                             atan(----)
+--R                                                                   +-+
+--R                                                                  \|3
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                    3
+--R          +-----------------------------------+2             atan(----)
+--R          |           3   2              3   2                     +-+
+--R          |    atan(----)         atan(----)                      \|3
+--R          |          +-+                +-+              cos(----------)
+--R          |         \|3                \|3                        2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  sin(----------)
+--R                                              2
+--R         + 
+--R                                                3   2
+--R                                         atan(----)
+--R                                               +-+
+--R               12      8      4 4+-+2         \|3
+--R           (36x   - 36x  + 36x )\|9  cos(----------)
+--R                                              2
+--R      *
+--R                             3     4
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                 +-----------------------------------+2
+--R                                 |           3   2              3   2
+--R                                 |    atan(----)         atan(----)
+--R                                 |          +-+                +-+
+--R             14      10      6   |         \|3                \|3
+--R         (72x   - 72x   + 72x ) 4|sin(----------)  + cos(----------)
+--R                                \|         2                  2
+--R      *
+--R                             3     2
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                             3
+--R                      atan(----)
+--R                            +-+
+--R                           \|3
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R          16     12     8 4+-+2
+--R       (6x   - 6x   + 6x )\|9
+--R                                                    Type: Expression(Integer)
+--E 290
+
+)clear all
+
+--S 291 of 649
+t0:=(1+x^4)/(1+x^4+x^8)
+--R 
+--R
+--R            4
+--R           x  + 1
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 291
+
+--S 292 of 649
+r0:=-1/4*atan(-2*x+sqrt(3))+1/4*atan(2*x+sqrt(3))-1/8*log(1-x+x^2)+_
+   1/8*log(1+x+x^2)-1/4*atan((1-2*x)/sqrt(3))/sqrt(3)+1/4*atan((1+2*x)/_
+   sqrt(3))/sqrt(3)-1/8*log(1+x^2-x*sqrt(3))/sqrt(3)+1/8*log(1+x^2+_
+   x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R             +-+    2         +-+     2             +-+     2
+--R       log(x\|3  + x  + 1) + \|3 log(x  + x + 1) - \|3 log(x  - x + 1)
+--R     + 
+--R                                                +-+                   +-+
+--R                 +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       - log(- x\|3  + x  + 1) + 2atan(------------) + 2atan(------------)
+--R                                             3                     3
+--R     + 
+--R         +-+      +-+           +-+      +-+
+--R       2\|3 atan(\|3  + 2x) - 2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3                  \|3               \|3
+--R                 sin(----------)  + x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                   3
+--R                            atan(----)
+--R                                  +-+
+--R                     +-+         \|3       2
+--R                 - x\|3 cos(----------) + x
+--R                                 2
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                              3
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            2
+--R     + 
+--R                                             3                     3
+--R                                      atan(----)            atan(----)
+--R                   3                        +-+                   +-+
+--R            atan(----)                     \|3       +-+         \|3
+--R                  +-+            3sin(----------) + \|3 cos(----------)
+--R                 \|3                       2                     2
+--R       4sin(----------)atan(-----------------------------------------------)
+--R                 2                         3                  3
+--R                                    atan(----)         atan(----)
+--R                                          +-+                +-+
+--R                             +-+         \|3                \|3         +-+
+--R                            \|3 sin(----------) - 3cos(----------) - 2x\|3
+--R                                         2                  2
+--R     + 
+--R                                               3                     3
+--R                                        atan(----)            atan(----)
+--R                     3                        +-+                   +-+
+--R              atan(----)                     \|3       +-+         \|3
+--R                    +-+            3sin(----------) + \|3 cos(----------)
+--R                   \|3                       2                     2
+--R       - 4sin(----------)atan(-----------------------------------------------)
+--R                   2                         3                  3
+--R                                      atan(----)         atan(----)
+--R                                            +-+                +-+
+--R                               +-+         \|3                \|3         +-+
+--R                              \|3 sin(----------) - 3cos(----------) + 2x\|3
+--R                                           2                  2
+--R     + 
+--R                                                                 +-+
+--R        +-+     2             +-+     2                 (2x - 1)\|3
+--R       \|3 log(x  + x + 1) - \|3 log(x  - x + 1) - atan(------------)
+--R                                                          2
+--R                                                        2x  - 2x - 1
+--R     + 
+--R                       +-+
+--R              (2x + 1)\|3
+--R       - atan(------------)
+--R                2
+--R              2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 293
+
+--S 294 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                        3
+--R                 atan(----)
+--R                       +-+
+--R                      \|3
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                            3   2                3                 3   2
+--R                     atan(----)           atan(----)        atan(----)
+--R                           +-+                  +-+               +-+
+--R                          \|3                  \|3               \|3
+--R                 sin(----------)  + x sin(----------) + cos(----------)
+--R                          2                    2                 2
+--R               + 
+--R                                   3
+--R                            atan(----)
+--R                                  +-+
+--R                     +-+         \|3       2
+--R                 - x\|3 cos(----------) + x
+--R                                 2
+--R     + 
+--R                     3
+--R              atan(----)
+--R                    +-+
+--R                   \|3
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                         3   2                3                 3   2
+--R                  atan(----)           atan(----)        atan(----)
+--R                        +-+                  +-+               +-+
+--R                       \|3                  \|3               \|3
+--R              sin(----------)  - x sin(----------) + cos(----------)
+--R                       2                    2                 2
+--R            + 
+--R                              3
+--R                       atan(----)
+--R                             +-+
+--R                +-+         \|3       2
+--R              x\|3 cos(----------) + x
+--R                            2
+--R     + 
+--R                                             3                     3
+--R                                      atan(----)            atan(----)
+--R                   3                        +-+                   +-+
+--R            atan(----)                     \|3       +-+         \|3
+--R                  +-+            3sin(----------) + \|3 cos(----------)
+--R                 \|3                       2                     2
+--R       4sin(----------)atan(-----------------------------------------------)
+--R                 2                         3                  3
+--R                                    atan(----)         atan(----)
+--R                                          +-+                +-+
+--R                             +-+         \|3                \|3         +-+
+--R                            \|3 sin(----------) - 3cos(----------) - 2x\|3
+--R                                         2                  2
+--R     + 
+--R                                               3                     3
+--R                                        atan(----)            atan(----)
+--R                     3                        +-+                   +-+
+--R              atan(----)                     \|3       +-+         \|3
+--R                    +-+            3sin(----------) + \|3 cos(----------)
+--R                   \|3                       2                     2
+--R       - 4sin(----------)atan(-----------------------------------------------)
+--R                   2                         3                  3
+--R                                      atan(----)         atan(----)
+--R                                            +-+                +-+
+--R                               +-+         \|3                \|3         +-+
+--R                              \|3 sin(----------) - 3cos(----------) + 2x\|3
+--R                                           2                  2
+--R     + 
+--R                                                                      +-+
+--R               +-+    2                +-+    2              (2x + 1)\|3
+--R       - log(x\|3  + x  + 1) + log(- x\|3  + x  + 1) - 2atan(------------)
+--R                                                                   3
+--R     + 
+--R                        +-+
+--R               (2x - 1)\|3       +-+      +-+           +-+      +-+
+--R       - 2atan(------------) - 2\|3 atan(\|3  + 2x) + 2\|3 atan(\|3  - 2x)
+--R                     3
+--R     + 
+--R                       +-+                  +-+
+--R              (2x - 1)\|3          (2x + 1)\|3
+--R       - atan(------------) - atan(------------)
+--R                2                    2
+--R              2x  - 2x - 1         2x  + 2x - 1
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 294
+
+--S 295 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                             3   8
+--R                      atan(----)
+--R                            +-+
+--R          4     2          \|3
+--R       (3x  - 3x )sin(----------)
+--R                           2
+--R     + 
+--R                                3   2                        3   6
+--R                         atan(----)                   atan(----)
+--R                               +-+                          +-+
+--R            4      2          \|3         6     4          \|3
+--R       ((12x  - 12x )cos(----------)  + 6x  - 6x )sin(----------)
+--R                              2                            2
+--R     + 
+--R                                       3              3   5
+--R                                atan(----)     atan(----)
+--R                                      +-+            +-+
+--R          6     4     2  +-+         \|3            \|3
+--R       (8x  - 8x  - 4x )\|3 cos(----------)sin(----------)
+--R                                     2              2
+--R     + 
+--R                                   3   4                         3   2
+--R                            atan(----)                    atan(----)
+--R                                  +-+                           +-+
+--R               4      2          \|3          6     4          \|3         8
+--R           (18x  - 18x )cos(----------)  + (6x  - 6x )cos(----------)  + 6x
+--R                                 2                             2
+--R         + 
+--R               6     4
+--R           - 6x  - 3x
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                             3   3
+--R                                      atan(----)
+--R                                            +-+
+--R               6      4     2  +-+         \|3
+--R           (16x  - 16x  - 8x )\|3 cos(----------)
+--R                                           2
+--R         + 
+--R                                           3
+--R                                    atan(----)
+--R                                          +-+
+--R              8     6     4  +-+         \|3
+--R           (8x  - 8x  - 4x )\|3 cos(----------)
+--R                                         2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                   3   6                           3   4
+--R                            atan(----)                      atan(----)
+--R                                  +-+                             +-+
+--R               4      2          \|3            6     4          \|3
+--R           (12x  - 12x )cos(----------)  + (- 6x  + 6x )cos(----------)
+--R                                 2                               2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               8      6      4          \|3         10     8     6
+--R           (12x  - 12x  - 30x )cos(----------)  + 3x   - 3x  - 3x
+--R                                        2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                           3   5
+--R                                    atan(----)
+--R                                          +-+
+--R              6     4     2  +-+         \|3
+--R           (8x  - 8x  - 4x )\|3 cos(----------)
+--R                                         2
+--R         + 
+--R                                             3   3
+--R                                      atan(----)
+--R                                            +-+
+--R                8     6     4  +-+         \|3
+--R           (- 8x  + 8x  + 4x )\|3 cos(----------)
+--R                                           2
+--R         + 
+--R                                             3
+--R                                      atan(----)
+--R                                            +-+
+--R              10     8      6  +-+         \|3
+--R           (2x   - 2x  - 10x )\|3 cos(----------)
+--R                                           2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                             3   8                           3   6
+--R                      atan(----)                      atan(----)
+--R                            +-+                             +-+
+--R          4     2          \|3            6     4          \|3
+--R       (3x  - 3x )cos(----------)  + (- 6x  + 6x )cos(----------)
+--R                           2                               2
+--R     + 
+--R                                   3   4                                  3   2
+--R                            atan(----)                             atan(----)
+--R                                  +-+                                    +-+
+--R          8     6     4          \|3            10     8     6          \|3
+--R       (6x  - 6x  - 3x )cos(----------)  + (- 3x   + 3x  + 3x )cos(----------)
+--R                                 2                                      2
+--R     + 
+--R           8
+--R       - 3x
+--R  /
+--R                                 3   8
+--R                          atan(----)
+--R                                +-+
+--R          4     2              \|3
+--R       (6x  - 6x  + 6)sin(----------)
+--R                               2
+--R     + 
+--R                                     3   2                                 3   6
+--R                              atan(----)                            atan(----)
+--R                                    +-+                                   +-+
+--R            4      2               \|3          6      4      2          \|3
+--R       ((24x  - 24x  + 24)cos(----------)  + 12x  - 12x  + 12x )sin(----------)
+--R                                   2                                     2
+--R     + 
+--R                                          3              3   5
+--R                                   atan(----)     atan(----)
+--R                                         +-+            +-+
+--R           6      4      2  +-+         \|3            \|3
+--R       (24x  - 24x  + 24x )\|3 cos(----------)sin(----------)
+--R                                        2              2
+--R     + 
+--R                                        3   4
+--R                                 atan(----)
+--R                                       +-+
+--R               4      2               \|3
+--R           (36x  - 36x  + 36)cos(----------)
+--R                                      2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               6      4      2          \|3          8      6      4
+--R           (12x  - 12x  + 12x )cos(----------)  + 18x  - 18x  + 18x
+--R                                        2
+--R      *
+--R                    3   4
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   3
+--R                                       atan(----)
+--R                                             +-+
+--R               6      4      2  +-+         \|3
+--R           (48x  - 48x  + 48x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                              3
+--R                                       atan(----)
+--R                                             +-+
+--R               8      6      4  +-+         \|3
+--R           (24x  - 24x  + 24x )\|3 cos(----------)
+--R                                            2
+--R      *
+--R                    3   3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                        3   6
+--R                                 atan(----)
+--R                                       +-+
+--R               4      2               \|3
+--R           (24x  - 24x  + 24)cos(----------)
+--R                                      2
+--R         + 
+--R                                            3   4
+--R                                     atan(----)
+--R                                           +-+
+--R                 6      4      2          \|3
+--R           (- 12x  + 12x  - 12x )cos(----------)
+--R                                          2
+--R         + 
+--R                                          3   2
+--R                                   atan(----)
+--R                                         +-+
+--R               8      6      4          \|3          10      8      6
+--R           (84x  - 84x  + 84x )cos(----------)  + 12x   - 12x  + 12x
+--R                                        2
+--R      *
+--R                    3   2
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                              3   5
+--R                                       atan(----)
+--R                                             +-+
+--R               6      4      2  +-+         \|3
+--R           (24x  - 24x  + 24x )\|3 cos(----------)
+--R                                            2
+--R         + 
+--R                                                3   3
+--R                                         atan(----)
+--R                                               +-+
+--R                 8      6      4  +-+         \|3
+--R           (- 24x  + 24x  - 24x )\|3 cos(----------)
+--R                                              2
+--R         + 
+--R                                               3
+--R                                        atan(----)
+--R                                              +-+
+--R               10      8      6  +-+         \|3
+--R           (24x   - 24x  + 24x )\|3 cos(----------)
+--R                                             2
+--R      *
+--R                    3
+--R             atan(----)
+--R                   +-+
+--R                  \|3
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                 3   8                                    3   6
+--R                          atan(----)                               atan(----)
+--R                                +-+                                      +-+
+--R          4     2              \|3             6      4      2          \|3
+--R       (6x  - 6x  + 6)cos(----------)  + (- 12x  + 12x  - 12x )cos(----------)
+--R                               2                                        2
+--R     + 
+--R                                      3   4
+--R                               atan(----)
+--R                                     +-+
+--R           8      6      4          \|3
+--R       (18x  - 18x  + 18x )cos(----------)
+--R                                    2
+--R     + 
+--R                                         3   2
+--R                                  atan(----)
+--R                                        +-+
+--R             10      8      6          \|3         12     10     8
+--R       (- 12x   + 12x  - 12x )cos(----------)  + 6x   - 6x   + 6x
+--R                                       2
+--R                                                    Type: Expression(Integer)
+--E 295
+
+)clear all
+
+--S 296 of 649
+t0:=(1-x^4)/(1+x^4+x^8)
+--R 
+--R
+--R             4
+--R          - x  + 1
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 296
+
+--S 297 of 649
+r0:=1/4*atan(-2*x+sqrt(3))-1/4*atan(2*x+sqrt(3))+1/8*log(1-x+x^2)-_
+   1/8*log(1+x+x^2)-1/4*atan((1-2*x)/sqrt(3))*sqrt(3)+1/4*atan((1+2*x)/_
+   sqrt(3))*sqrt(3)-1/8*log(1+x^2-x*sqrt(3))*sqrt(3)+1/8*log(1+x^2+_
+   x*sqrt(3))*sqrt(3)
+--R 
+--R
+--R   (2)
+--R        +-+      +-+    2             2                 2
+--R       \|3 log(x\|3  + x  + 1) - log(x  + x + 1) + log(x  - x + 1)
+--R     + 
+--R                                                        +-+
+--R          +-+        +-+    2          +-+     (2x + 1)\|3
+--R       - \|3 log(- x\|3  + x  + 1) + 2\|3 atan(------------)
+--R                                                     3
+--R     + 
+--R                          +-+
+--R         +-+     (2x - 1)\|3            +-+                +-+
+--R       2\|3 atan(------------) - 2atan(\|3  + 2x) + 2atan(\|3  - 2x)
+--R                       3
+--R  /
+--R     8
+--R                                                    Type: Expression(Integer)
+--E 297
+
+--S 298 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +-+
+--R              atan(\|3 )
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                        +-+  2                  +-+               +-+  2
+--R                  atan(\|3 )       +-+    atan(\|3 )        atan(\|3 )
+--R              sin(----------)  + x\|3 sin(----------) + cos(----------)
+--R                       2                       2                 2
+--R            + 
+--R                          +-+
+--R                    atan(\|3 )     2
+--R              x cos(----------) + x
+--R                         2
+--R     + 
+--R       -
+--R                       +-+
+--R                 atan(\|3 )
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                           +-+  2                  +-+               +-+  2
+--R                     atan(\|3 )       +-+    atan(\|3 )        atan(\|3 )
+--R                 sin(----------)  - x\|3 sin(----------) + cos(----------)
+--R                          2                       2                 2
+--R               + 
+--R                               +-+
+--R                         atan(\|3 )     2
+--R                 - x cos(----------) + x
+--R                              2
+--R     + 
+--R                                         +-+                   +-+
+--R                                   atan(\|3 )     +-+    atan(\|3 )
+--R                  +-+          sin(----------) - \|3 cos(----------)
+--R            atan(\|3 )                  2                     2
+--R       4sin(----------)atan(------------------------------------------)
+--R                 2                        +-+               +-+
+--R                             +-+    atan(\|3 )        atan(\|3 )
+--R                            \|3 sin(----------) + cos(----------) - 2x
+--R                                         2                 2
+--R     + 
+--R                                           +-+                   +-+
+--R                                     atan(\|3 )     +-+    atan(\|3 )
+--R                    +-+          sin(----------) - \|3 cos(----------)
+--R              atan(\|3 )                  2                     2
+--R       - 4sin(----------)atan(------------------------------------------)
+--R                   2                        +-+               +-+
+--R                               +-+    atan(\|3 )        atan(\|3 )
+--R                              \|3 sin(----------) + cos(----------) + 2x
+--R                                           2                 2
+--R     + 
+--R                                                               +-+
+--R              2                 2             +-+     (2x - 1)\|3
+--R       - log(x  + x + 1) + log(x  - x + 1) - \|3 atan(------------)
+--R                                                        2
+--R                                                      2x  - 2x - 1
+--R     + 
+--R                           +-+
+--R          +-+     (2x + 1)\|3
+--R       - \|3 atan(------------)
+--R                    2
+--R                  2x  + 2x - 1
+--R  /
+--R     8
+--R                                         Type: Union(Expression(Integer),...)
+--E 298
+
+--S 299 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    +-+
+--R              atan(\|3 )
+--R         2cos(----------)
+--R                   2
+--R      *
+--R         log
+--R                        +-+  2                  +-+               +-+  2
+--R                  atan(\|3 )       +-+    atan(\|3 )        atan(\|3 )
+--R              sin(----------)  + x\|3 sin(----------) + cos(----------)
+--R                       2                       2                 2
+--R            + 
+--R                          +-+
+--R                    atan(\|3 )     2
+--R              x cos(----------) + x
+--R                         2
+--R     + 
+--R       -
+--R                       +-+
+--R                 atan(\|3 )
+--R            2cos(----------)
+--R                      2
+--R         *
+--R            log
+--R                           +-+  2                  +-+               +-+  2
+--R                     atan(\|3 )       +-+    atan(\|3 )        atan(\|3 )
+--R                 sin(----------)  - x\|3 sin(----------) + cos(----------)
+--R                          2                       2                 2
+--R               + 
+--R                               +-+
+--R                         atan(\|3 )     2
+--R                 - x cos(----------) + x
+--R                              2
+--R     + 
+--R                                         +-+                   +-+
+--R                                   atan(\|3 )     +-+    atan(\|3 )
+--R                  +-+          sin(----------) - \|3 cos(----------)
+--R            atan(\|3 )                  2                     2
+--R       4sin(----------)atan(------------------------------------------)
+--R                 2                        +-+               +-+
+--R                             +-+    atan(\|3 )        atan(\|3 )
+--R                            \|3 sin(----------) + cos(----------) - 2x
+--R                                         2                 2
+--R     + 
+--R                                           +-+                   +-+
+--R                                     atan(\|3 )     +-+    atan(\|3 )
+--R                    +-+          sin(----------) - \|3 cos(----------)
+--R              atan(\|3 )                  2                     2
+--R       - 4sin(----------)atan(------------------------------------------)
+--R                   2                        +-+               +-+
+--R                               +-+    atan(\|3 )        atan(\|3 )
+--R                              \|3 sin(----------) + cos(----------) + 2x
+--R                                           2                 2
+--R     + 
+--R          +-+      +-+    2         +-+        +-+    2
+--R       - \|3 log(x\|3  + x  + 1) + \|3 log(- x\|3  + x  + 1)
+--R     + 
+--R                            +-+                       +-+
+--R           +-+     (2x + 1)\|3       +-+     (2x - 1)\|3            +-+
+--R       - 2\|3 atan(------------) - 2\|3 atan(------------) + 2atan(\|3  + 2x)
+--R                         3                         3
+--R     + 
+--R                                              +-+                      +-+
+--R                +-+          +-+     (2x - 1)\|3      +-+     (2x + 1)\|3
+--R       - 2atan(\|3  - 2x) - \|3 atan(------------) - \|3 atan(------------)
+--R                                       2                        2
+--R                                     2x  - 2x - 1             2x  + 2x - 1
+--R  /
+--R     8
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                          +-+  8
+--R         4    2     atan(\|3 )
+--R       (x  + x )sin(----------)
+--R                         2
+--R     + 
+--R                             +-+  2                       +-+  6
+--R           4     2     atan(\|3 )       4     2     atan(\|3 )
+--R       ((4x  + 4x )cos(----------)  - 4x  + 2x )sin(----------)
+--R                            2                            2
+--R     + 
+--R                                  +-+            +-+  5
+--R            6     4  +-+    atan(\|3 )     atan(\|3 )
+--R       (- 4x  - 4x )\|3 cos(----------)sin(----------)
+--R                                 2              2
+--R     + 
+--R                                  +-+  4                          +-+  2
+--R                4     2     atan(\|3 )          4     2     atan(\|3 )       6
+--R             (6x  + 6x )cos(----------)  + (- 4x  + 2x )cos(----------)  + 6x
+--R                                 2                               2
+--R           + 
+--R                 4
+--R             - 3x
+--R      *
+--R                   +-+  4
+--R             atan(\|3 )
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                     +-+  3                            +-+
+--R               6     4  +-+    atan(\|3 )        6     4  +-+    atan(\|3 )
+--R         ((- 8x  - 8x )\|3 cos(----------)  + (8x  - 4x )\|3 cos(----------))
+--R                                    2                                 2
+--R      *
+--R                   +-+  3
+--R             atan(\|3 )
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                +-+  6                        +-+  4
+--R              4     2     atan(\|3 )        4     2     atan(\|3 )
+--R           (4x  + 4x )cos(----------)  + (4x  - 2x )cos(----------)
+--R                               2                             2
+--R         + 
+--R                                        +-+  2
+--R               8      6     4     atan(\|3 )      10     8     6
+--R           (16x  + 12x  + 2x )cos(----------)  + x   - 5x  + 3x
+--R                                       2
+--R      *
+--R                   +-+  2
+--R             atan(\|3 )
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                      +-+  5                              +-+  3
+--R                6     4  +-+    atan(\|3 )          6     4  +-+    atan(\|3 )
+--R           (- 4x  - 4x )\|3 cos(----------)  + (- 8x  + 4x )\|3 cos(----------)
+--R                                     2                                   2
+--R         + 
+--R                                             +-+
+--R                10     8     6  +-+    atan(\|3 )
+--R           (- 2x   - 6x  + 2x )\|3 cos(----------)
+--R                                            2
+--R      *
+--R                   +-+
+--R             atan(\|3 )
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                          +-+  8                        +-+  6
+--R         4    2     atan(\|3 )        4     2     atan(\|3 )
+--R       (x  + x )cos(----------)  + (4x  - 2x )cos(----------)
+--R                         2                             2
+--R     + 
+--R                            +-+  4                                +-+  2
+--R          6     4     atan(\|3 )         10     8     6     atan(\|3 )       10
+--R       (6x  - 3x )cos(----------)  + (- x   + 5x  - 3x )cos(----------)  + 2x
+--R                           2                                     2
+--R     + 
+--R          8
+--R       - x
+--R  /
+--R                                +-+  8
+--R          4     2         atan(\|3 )
+--R       (2x  - 2x  + 2)sin(----------)
+--R                               2
+--R     + 
+--R                                 +-+  2                             +-+  6
+--R           4     2         atan(\|3 )       6     4     2     atan(\|3 )
+--R       ((8x  - 8x  + 8)cos(----------)  - 4x  + 4x  - 4x )sin(----------)
+--R                                2                                  2
+--R     + 
+--R                                        +-+            +-+  5
+--R            6     4     2  +-+    atan(\|3 )     atan(\|3 )
+--R       (- 8x  + 8x  - 8x )\|3 cos(----------)sin(----------)
+--R                                       2              2
+--R     + 
+--R                                       +-+  4
+--R               4      2          atan(\|3 )
+--R           (12x  - 12x  + 12)cos(----------)
+--R                                      2
+--R         + 
+--R                                        +-+  2
+--R                6     4     2     atan(\|3 )       8     6     4
+--R           (- 4x  + 4x  - 4x )cos(----------)  + 6x  - 6x  + 6x
+--R                                       2
+--R      *
+--R                   +-+  4
+--R             atan(\|3 )
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                               +-+  3
+--R                 6      4      2  +-+    atan(\|3 )
+--R           (- 16x  + 16x  - 16x )\|3 cos(----------)
+--R                                              2
+--R         + 
+--R                                          +-+
+--R              8     6     4  +-+    atan(\|3 )
+--R           (8x  - 8x  + 8x )\|3 cos(----------)
+--R                                         2
+--R      *
+--R                   +-+  3
+--R             atan(\|3 )
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                    +-+  6                              +-+  4
+--R              4     2         atan(\|3 )        6     4     2     atan(\|3 )
+--R           (8x  - 8x  + 8)cos(----------)  + (4x  - 4x  + 4x )cos(----------)
+--R                                   2                                   2
+--R         + 
+--R                                         +-+  2
+--R               8      6      4     atan(\|3 )       10     8     6
+--R           (28x  - 28x  + 28x )cos(----------)  - 4x   + 4x  - 4x
+--R                                        2
+--R      *
+--R                   +-+  2
+--R             atan(\|3 )
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                            +-+  5
+--R                6     4     2  +-+    atan(\|3 )
+--R           (- 8x  + 8x  - 8x )\|3 cos(----------)
+--R                                           2
+--R         + 
+--R                                            +-+  3
+--R                8     6     4  +-+    atan(\|3 )
+--R           (- 8x  + 8x  - 8x )\|3 cos(----------)
+--R                                           2
+--R         + 
+--R                                             +-+
+--R                10     8     6  +-+    atan(\|3 )
+--R           (- 8x   + 8x  - 8x )\|3 cos(----------)
+--R                                            2
+--R      *
+--R                   +-+
+--R             atan(\|3 )
+--R         sin(----------)
+--R                  2
+--R     + 
+--R                                +-+  8                              +-+  6
+--R          4     2         atan(\|3 )        6     4     2     atan(\|3 )
+--R       (2x  - 2x  + 2)cos(----------)  + (4x  - 4x  + 4x )cos(----------)
+--R                               2                                   2
+--R     + 
+--R                                  +-+  4                               +-+  2
+--R          8     6     4     atan(\|3 )        10     8     6     atan(\|3 )
+--R       (6x  - 6x  + 6x )cos(----------)  + (4x   - 4x  + 4x )cos(----------)
+--R                                 2                                    2
+--R     + 
+--R         12     10     8
+--R       2x   - 2x   + 2x
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 649
+t0:=(1+x^4)/(1-x^4+x^8)
+--R 
+--R
+--R            4
+--R           x  + 1
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 301
+
+--S 302 of 649
+r0:=-1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(2-sqrt(3))+_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(2-sqrt(3))-_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))*sqrt(2-sqrt(3))+1/8*log(1+x^2+_
+   x*sqrt(2+sqrt(3)))*sqrt(2-sqrt(3))-1/4*atan((-2*x+sqrt(2+sqrt(3)))/_
+   sqrt(2-sqrt(3)))*sqrt(2+sqrt(3))+1/4*atan((2*x+sqrt(2+sqrt(3)))/_
+   sqrt(2-sqrt(3)))*sqrt(2+sqrt(3))-1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*_
+   sqrt(2+sqrt(3))+1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*sqrt(2+sqrt(3))
+--R 
+--R
+--R   (2)
+--R        +----------+      +--------+
+--R        |   +-+           | +-+         2
+--R       \|- \|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R        +--------+      +----------+
+--R        | +-+           |   +-+         2
+--R       \|\|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +--------+        +----------+
+--R          | +-+             |   +-+         2
+--R       - \|\|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +----------+        +--------+
+--R          |   +-+             | +-+         2
+--R       - \|- \|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R           +--------+
+--R           | +-+
+--R         2\|\|3  + 2
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R              +--------+
+--R              | +-+
+--R            2\|\|3  + 2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R           +----------+                 +----------+                +--------+
+--R           |   +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2\|- \|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R         +----------+                 +----------+                +--------+
+--R         |   +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|- \|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R     8
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                                                                     +-+
+--R                                                               atan(\|3 )
+--R                                                           sin(----------)
+--R                                                                    2
+--R                                                      atan(---------------)
+--R                                                                     +-+
+--R             +-----------------------------------+             atan(\|3 )
+--R             |          +-+  2             +-+  2          cos(----------)
+--R             |    atan(\|3 )         atan(\|3 )                     2
+--R            4|sin(----------)  + cos(----------)  cos(---------------------)
+--R            \|         2                  2                     2
+--R         *
+--R            log
+--R                    +-----------------------------------+2
+--R                    |          +-+  2             +-+  2
+--R                    |    atan(\|3 )         atan(\|3 )
+--R                   4|sin(----------)  + cos(----------)
+--R                   \|         2                  2
+--R                *
+--R                                      +-+    2
+--R                                atan(\|3 )
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                          +-----------------------------------+
+--R                          |          +-+  2             +-+  2
+--R                     +-+  |    atan(\|3 )         atan(\|3 )
+--R                   x\|3  4|sin(----------)  + cos(----------)
+--R                         \|         2                  2
+--R                *
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                    +-----------------------------------+2
+--R                    |          +-+  2             +-+  2
+--R                    |    atan(\|3 )         atan(\|3 )
+--R                   4|sin(----------)  + cos(----------)
+--R                   \|         2                  2
+--R                *
+--R                                      +-+    2
+--R                                atan(\|3 )
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                         +-----------------------------------+
+--R                         |          +-+  2             +-+  2
+--R                         |    atan(\|3 )         atan(\|3 )
+--R                      x 4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R                   *
+--R                                         +-+
+--R                                   atan(\|3 )
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                         +-+
+--R                                   atan(\|3 )
+--R                               cos(----------)
+--R                                        2
+--R                      cos(---------------------)
+--R                                    2
+--R               + 
+--R                  2
+--R                 x
+--R     + 
+--R                                                                  +-+
+--R                                                            atan(\|3 )
+--R                                                        sin(----------)
+--R                                                                 2
+--R                                                   atan(---------------)
+--R                                                                  +-+
+--R          +-----------------------------------+             atan(\|3 )
+--R          |          +-+  2             +-+  2          cos(----------)
+--R          |    atan(\|3 )         atan(\|3 )                     2
+--R         4|sin(----------)  + cos(----------)  cos(---------------------)
+--R         \|         2                  2                     2
+--R      *
+--R         log
+--R                                                                        +-+    2
+--R                                                                  atan(\|3 )
+--R                                                              sin(----------)
+--R                                                                       2
+--R                                                         atan(---------------)
+--R                                                                        +-+
+--R               +-----------------------------------+2             atan(\|3 )
+--R               |          +-+  2             +-+  2           cos(----------)
+--R               |    atan(\|3 )         atan(\|3 )                      2
+--R              4|sin(----------)  + cos(----------)   sin(---------------------)
+--R              \|         2                  2                      2
+--R            + 
+--R              -
+--R                          +-----------------------------------+
+--R                          |          +-+  2             +-+  2
+--R                     +-+  |    atan(\|3 )         atan(\|3 )
+--R                   x\|3  4|sin(----------)  + cos(----------)
+--R                         \|         2                  2
+--R                *
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R            + 
+--R                                                                        +-+    2
+--R                                                                  atan(\|3 )
+--R                                                              sin(----------)
+--R                                                                       2
+--R                                                         atan(---------------)
+--R                                                                        +-+
+--R               +-----------------------------------+2             atan(\|3 )
+--R               |          +-+  2             +-+  2           cos(----------)
+--R               |    atan(\|3 )         atan(\|3 )                      2
+--R              4|sin(----------)  + cos(----------)   cos(---------------------)
+--R              \|         2                  2                      2
+--R            + 
+--R                                                                         +-+
+--R                                                                   atan(\|3 )
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                         +-+
+--R                 +-----------------------------------+             atan(\|3 )
+--R                 |          +-+  2             +-+  2          cos(----------)
+--R                 |    atan(\|3 )         atan(\|3 )                     2
+--R              x 4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                \|         2                  2                     2
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R                                                                    +-+
+--R                                                              atan(\|3 )
+--R                                                          sin(----------)
+--R                                                                   2
+--R                                                     atan(---------------)
+--R                                                                    +-+
+--R            +-----------------------------------+             atan(\|3 )
+--R            |          +-+  2             +-+  2          cos(----------)
+--R            |    atan(\|3 )         atan(\|3 )                     2
+--R         2 4|sin(----------)  + cos(----------)  sin(---------------------)
+--R           \|         2                  2                     2
+--R      *
+--R         atan
+--R                                                                         +-+
+--R                                                                   atan(\|3 )
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                         +-+
+--R                 +-----------------------------------+             atan(\|3 )
+--R                 |          +-+  2             +-+  2          cos(----------)
+--R                 |    atan(\|3 )         atan(\|3 )                     2
+--R                4|sin(----------)  + cos(----------)  sin(---------------------)
+--R                \|         2                  2                     2
+--R              + 
+--R                        +-----------------------------------+
+--R                        |          +-+  2             +-+  2
+--R                   +-+  |    atan(\|3 )         atan(\|3 )
+--R                  \|3  4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R               *
+--R                                     +-+
+--R                               atan(\|3 )
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                     +-+
+--R                               atan(\|3 )
+--R                           cos(----------)
+--R                                    2
+--R                  cos(---------------------)
+--R                                2
+--R           /
+--R                        +-----------------------------------+
+--R                        |          +-+  2             +-+  2
+--R                   +-+  |    atan(\|3 )         atan(\|3 )
+--R                  \|3  4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R               *
+--R                                     +-+
+--R                               atan(\|3 )
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                     +-+
+--R                               atan(\|3 )
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                -
+--R                      +-----------------------------------+
+--R                      |          +-+  2             +-+  2
+--R                      |    atan(\|3 )         atan(\|3 )
+--R                     4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                  *
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R              + 
+--R                - 2x
+--R     + 
+--R       -
+--R                                                                       +-+
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R               +-----------------------------------+             atan(\|3 )
+--R               |          +-+  2             +-+  2          cos(----------)
+--R               |    atan(\|3 )         atan(\|3 )                     2
+--R            2 4|sin(----------)  + cos(----------)  sin(---------------------)
+--R              \|         2                  2                     2
+--R         *
+--R            atan
+--R                      +-----------------------------------+
+--R                      |          +-+  2             +-+  2
+--R                      |    atan(\|3 )         atan(\|3 )
+--R                     4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                  *
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                           +-----------------------------------+
+--R                           |          +-+  2             +-+  2
+--R                      +-+  |    atan(\|3 )         atan(\|3 )
+--R                     \|3  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                  *
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R              /
+--R                           +-----------------------------------+
+--R                           |          +-+  2             +-+  2
+--R                      +-+  |    atan(\|3 )         atan(\|3 )
+--R                     \|3  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                  *
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                   -
+--R                         +-----------------------------------+
+--R                         |          +-+  2             +-+  2
+--R                         |    atan(\|3 )         atan(\|3 )
+--R                        4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R                     *
+--R                                           +-+
+--R                                     atan(\|3 )
+--R                                 sin(----------)
+--R                                          2
+--R                            atan(---------------)
+--R                                           +-+
+--R                                     atan(\|3 )
+--R                                 cos(----------)
+--R                                          2
+--R                        cos(---------------------)
+--R                                      2
+--R                 + 
+--R                   2x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 303
+
+--S 304 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                                                       +-+
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R               +-----------------------------------+             atan(\|3 )
+--R               |          +-+  2             +-+  2          cos(----------)
+--R               |    atan(\|3 )         atan(\|3 )                     2
+--R            4 4|sin(----------)  + cos(----------)  cos(---------------------)
+--R              \|         2                  2                     2
+--R         *
+--R            log
+--R                    +-----------------------------------+2
+--R                    |          +-+  2             +-+  2
+--R                    |    atan(\|3 )         atan(\|3 )
+--R                   4|sin(----------)  + cos(----------)
+--R                   \|         2                  2
+--R                *
+--R                                      +-+    2
+--R                                atan(\|3 )
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                          +-----------------------------------+
+--R                          |          +-+  2             +-+  2
+--R                     +-+  |    atan(\|3 )         atan(\|3 )
+--R                   x\|3  4|sin(----------)  + cos(----------)
+--R                         \|         2                  2
+--R                *
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R               + 
+--R                    +-----------------------------------+2
+--R                    |          +-+  2             +-+  2
+--R                    |    atan(\|3 )         atan(\|3 )
+--R                   4|sin(----------)  + cos(----------)
+--R                   \|         2                  2
+--R                *
+--R                                      +-+    2
+--R                                atan(\|3 )
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            cos(----------)
+--R                                     2
+--R                   cos(---------------------)
+--R                                 2
+--R               + 
+--R                 -
+--R                         +-----------------------------------+
+--R                         |          +-+  2             +-+  2
+--R                         |    atan(\|3 )         atan(\|3 )
+--R                      x 4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R                   *
+--R                                         +-+
+--R                                   atan(\|3 )
+--R                               sin(----------)
+--R                                        2
+--R                          atan(---------------)
+--R                                         +-+
+--R                                   atan(\|3 )
+--R                               cos(----------)
+--R                                        2
+--R                      cos(---------------------)
+--R                                    2
+--R               + 
+--R                  2
+--R                 x
+--R     + 
+--R                                                                    +-+
+--R                                                              atan(\|3 )
+--R                                                          sin(----------)
+--R                                                                   2
+--R                                                     atan(---------------)
+--R                                                                    +-+
+--R            +-----------------------------------+             atan(\|3 )
+--R            |          +-+  2             +-+  2          cos(----------)
+--R            |    atan(\|3 )         atan(\|3 )                     2
+--R         4 4|sin(----------)  + cos(----------)  cos(---------------------)
+--R           \|         2                  2                     2
+--R      *
+--R         log
+--R                                                                        +-+    2
+--R                                                                  atan(\|3 )
+--R                                                              sin(----------)
+--R                                                                       2
+--R                                                         atan(---------------)
+--R                                                                        +-+
+--R               +-----------------------------------+2             atan(\|3 )
+--R               |          +-+  2             +-+  2           cos(----------)
+--R               |    atan(\|3 )         atan(\|3 )                      2
+--R              4|sin(----------)  + cos(----------)   sin(---------------------)
+--R              \|         2                  2                      2
+--R            + 
+--R              -
+--R                          +-----------------------------------+
+--R                          |          +-+  2             +-+  2
+--R                     +-+  |    atan(\|3 )         atan(\|3 )
+--R                   x\|3  4|sin(----------)  + cos(----------)
+--R                         \|         2                  2
+--R                *
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            sin(----------)
+--R                                     2
+--R                       atan(---------------)
+--R                                      +-+
+--R                                atan(\|3 )
+--R                            cos(----------)
+--R                                     2
+--R                   sin(---------------------)
+--R                                 2
+--R            + 
+--R                                                                        +-+    2
+--R                                                                  atan(\|3 )
+--R                                                              sin(----------)
+--R                                                                       2
+--R                                                         atan(---------------)
+--R                                                                        +-+
+--R               +-----------------------------------+2             atan(\|3 )
+--R               |          +-+  2             +-+  2           cos(----------)
+--R               |    atan(\|3 )         atan(\|3 )                      2
+--R              4|sin(----------)  + cos(----------)   cos(---------------------)
+--R              \|         2                  2                      2
+--R            + 
+--R                                                                         +-+
+--R                                                                   atan(\|3 )
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                         +-+
+--R                 +-----------------------------------+             atan(\|3 )
+--R                 |          +-+  2             +-+  2          cos(----------)
+--R                 |    atan(\|3 )         atan(\|3 )                     2
+--R              x 4|sin(----------)  + cos(----------)  cos(---------------------)
+--R                \|         2                  2                     2
+--R            + 
+--R               2
+--R              x
+--R     + 
+--R                                                                    +-+
+--R                                                              atan(\|3 )
+--R                                                          sin(----------)
+--R                                                                   2
+--R                                                     atan(---------------)
+--R                                                                    +-+
+--R            +-----------------------------------+             atan(\|3 )
+--R            |          +-+  2             +-+  2          cos(----------)
+--R            |    atan(\|3 )         atan(\|3 )                     2
+--R         8 4|sin(----------)  + cos(----------)  sin(---------------------)
+--R           \|         2                  2                     2
+--R      *
+--R         atan
+--R                                                                         +-+
+--R                                                                   atan(\|3 )
+--R                                                               sin(----------)
+--R                                                                        2
+--R                                                          atan(---------------)
+--R                                                                         +-+
+--R                 +-----------------------------------+             atan(\|3 )
+--R                 |          +-+  2             +-+  2          cos(----------)
+--R                 |    atan(\|3 )         atan(\|3 )                     2
+--R                4|sin(----------)  + cos(----------)  sin(---------------------)
+--R                \|         2                  2                     2
+--R              + 
+--R                        +-----------------------------------+
+--R                        |          +-+  2             +-+  2
+--R                   +-+  |    atan(\|3 )         atan(\|3 )
+--R                  \|3  4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R               *
+--R                                     +-+
+--R                               atan(\|3 )
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                     +-+
+--R                               atan(\|3 )
+--R                           cos(----------)
+--R                                    2
+--R                  cos(---------------------)
+--R                                2
+--R           /
+--R                        +-----------------------------------+
+--R                        |          +-+  2             +-+  2
+--R                   +-+  |    atan(\|3 )         atan(\|3 )
+--R                  \|3  4|sin(----------)  + cos(----------)
+--R                       \|         2                  2
+--R               *
+--R                                     +-+
+--R                               atan(\|3 )
+--R                           sin(----------)
+--R                                    2
+--R                      atan(---------------)
+--R                                     +-+
+--R                               atan(\|3 )
+--R                           cos(----------)
+--R                                    2
+--R                  sin(---------------------)
+--R                                2
+--R              + 
+--R                -
+--R                      +-----------------------------------+
+--R                      |          +-+  2             +-+  2
+--R                      |    atan(\|3 )         atan(\|3 )
+--R                     4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                  *
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R              + 
+--R                - 2x
+--R     + 
+--R       -
+--R                                                                       +-+
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R               +-----------------------------------+             atan(\|3 )
+--R               |          +-+  2             +-+  2          cos(----------)
+--R               |    atan(\|3 )         atan(\|3 )                     2
+--R            8 4|sin(----------)  + cos(----------)  sin(---------------------)
+--R              \|         2                  2                     2
+--R         *
+--R            atan
+--R                      +-----------------------------------+
+--R                      |          +-+  2             +-+  2
+--R                      |    atan(\|3 )         atan(\|3 )
+--R                     4|sin(----------)  + cos(----------)
+--R                     \|         2                  2
+--R                  *
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                           +-----------------------------------+
+--R                           |          +-+  2             +-+  2
+--R                      +-+  |    atan(\|3 )         atan(\|3 )
+--R                     \|3  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                  *
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              cos(----------)
+--R                                       2
+--R                     cos(---------------------)
+--R                                   2
+--R              /
+--R                           +-----------------------------------+
+--R                           |          +-+  2             +-+  2
+--R                      +-+  |    atan(\|3 )         atan(\|3 )
+--R                     \|3  4|sin(----------)  + cos(----------)
+--R                          \|         2                  2
+--R                  *
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              sin(----------)
+--R                                       2
+--R                         atan(---------------)
+--R                                        +-+
+--R                                  atan(\|3 )
+--R                              cos(----------)
+--R                                       2
+--R                     sin(---------------------)
+--R                                   2
+--R                 + 
+--R                   -
+--R                         +-----------------------------------+
+--R                         |          +-+  2             +-+  2
+--R                         |    atan(\|3 )         atan(\|3 )
+--R                        4|sin(----------)  + cos(----------)
+--R                        \|         2                  2
+--R                     *
+--R                                           +-+
+--R                                     atan(\|3 )
+--R                                 sin(----------)
+--R                                          2
+--R                            atan(---------------)
+--R                                           +-+
+--R                                     atan(\|3 )
+--R                                 cos(----------)
+--R                                          2
+--R                        cos(---------------------)
+--R                                      2
+--R                 + 
+--R                   2x
+--R     + 
+--R          +----------+      +--------+
+--R          |   +-+           | +-+         2
+--R       - \|- \|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R          +--------+      +----------+
+--R          | +-+           |   +-+         2
+--R       - \|\|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +--------+        +----------+
+--R        | +-+             |   +-+         2
+--R       \|\|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +----------+        +--------+
+--R        |   +-+             | +-+         2
+--R       \|- \|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R              +--------+
+--R              | +-+
+--R            2\|\|3  + 2
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R           +--------+
+--R           | +-+
+--R         2\|\|3  + 2
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R         +----------+                 +----------+                +--------+
+--R         |   +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|- \|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R           +----------+                 +----------+                +--------+
+--R           |   +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2\|- \|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R     8
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       +----------+ +--------+                         +-+  4
+--R                4      |   +-+      | +-+         8    4         atan(\|3 )
+--R           ((- x  - 1)\|- \|3  + 2 \|\|3  + 2  + x  - x  + 1)sin(----------)
+--R                                                                      2
+--R         + 
+--R                          +----------+ +--------+
+--R                   4      |   +-+      | +-+          8     4
+--R             ((- 2x  - 2)\|- \|3  + 2 \|\|3  + 2  + 2x  - 2x  + 2)
+--R          *
+--R                       +-+  2          +-+  2
+--R                 atan(\|3 )      atan(\|3 )
+--R             cos(----------) sin(----------)
+--R                      2               2
+--R         + 
+--R                       +----------+ +--------+                         +-+  4
+--R                4      |   +-+      | +-+         8    4         atan(\|3 )
+--R           ((- x  - 1)\|- \|3  + 2 \|\|3  + 2  + x  - x  + 1)cos(----------)
+--R                                                                      2
+--R      *
+--R                            +-+    8
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                              +----------+ +--------+
+--R                       4      |   +-+      | +-+          8     4
+--R                 ((- 4x  - 4)\|- \|3  + 2 \|\|3  + 2  + 4x  - 4x  + 4)
+--R              *
+--R                           +-+  4
+--R                     atan(\|3 )
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                              +----------+ +--------+
+--R                       4      |   +-+      | +-+          8     4
+--R                 ((- 8x  - 8)\|- \|3  + 2 \|\|3  + 2  + 8x  - 8x  + 8)
+--R              *
+--R                           +-+  2          +-+  2
+--R                     atan(\|3 )      atan(\|3 )
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                              +----------+ +--------+
+--R                       4      |   +-+      | +-+          8     4
+--R                 ((- 4x  - 4)\|- \|3  + 2 \|\|3  + 2  + 4x  - 4x  + 4)
+--R              *
+--R                           +-+  4
+--R                     atan(\|3 )
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                +-+    2
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                           +----------+ +--------+          +-+  2
+--R                  6     2  |   +-+      | +-+         atan(\|3 )
+--R               (2x  + 2x )\|- \|3  + 2 \|\|3  + 2 sin(----------)
+--R                                                           2
+--R             + 
+--R                           +----------+ +--------+          +-+  2
+--R                  6     2  |   +-+      | +-+         atan(\|3 )
+--R               (2x  + 2x )\|- \|3  + 2 \|\|3  + 2 cos(----------)
+--R                                                           2
+--R          *
+--R              +-----------------------------------+2
+--R              |          +-+  2             +-+  2
+--R              |    atan(\|3 )         atan(\|3 )
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                            +-+    6
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                   +----------+ +--------+
+--R                      6     2  +-+ |   +-+      | +-+
+--R                 (- 4x  - 4x )\|3 \|- \|3  + 2 \|\|3  + 2
+--R               + 
+--R                    10     6     2  +-+
+--R                 (4x   - 4x  + 4x )\|3
+--R          *
+--R                       +-+  2
+--R                 atan(\|3 )
+--R             sin(----------)
+--R                      2
+--R         + 
+--R                                   +----------+ +--------+
+--R                      6     2  +-+ |   +-+      | +-+
+--R                 (- 4x  - 4x )\|3 \|- \|3  + 2 \|\|3  + 2
+--R               + 
+--R                    10     6     2  +-+
+--R                 (4x   - 4x  + 4x )\|3
+--R          *
+--R                       +-+  2
+--R                 atan(\|3 )
+--R             cos(----------)
+--R                      2
+--R      *
+--R                                                                   +-+
+--R                                                             atan(\|3 )
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                   +-+
+--R          +-----------------------------------+2             atan(\|3 )
+--R          |          +-+  2             +-+  2           cos(----------)
+--R          |    atan(\|3 )         atan(\|3 )                      2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                            +-+    5
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                              +----------+ +--------+
+--R                       4      |   +-+      | +-+          8     4
+--R                 ((- 6x  - 6)\|- \|3  + 2 \|\|3  + 2  + 6x  - 6x  + 6)
+--R              *
+--R                           +-+  4
+--R                     atan(\|3 )
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                +----------+ +--------+
+--R                        4       |   +-+      | +-+           8      4
+--R                 ((- 12x  - 12)\|- \|3  + 2 \|\|3  + 2  + 12x  - 12x  + 12)
+--R              *
+--R                           +-+  2          +-+  2
+--R                     atan(\|3 )      atan(\|3 )
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                              +----------+ +--------+
+--R                       4      |   +-+      | +-+          8     4
+--R                 ((- 6x  - 6)\|- \|3  + 2 \|\|3  + 2  + 6x  - 6x  + 6)
+--R              *
+--R                           +-+  4
+--R                     atan(\|3 )
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                +-+    4
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                           +----------+ +--------+          +-+  2
+--R                  6     2  |   +-+      | +-+         atan(\|3 )
+--R               (2x  + 2x )\|- \|3  + 2 \|\|3  + 2 sin(----------)
+--R                                                           2
+--R             + 
+--R                           +----------+ +--------+          +-+  2
+--R                  6     2  |   +-+      | +-+         atan(\|3 )
+--R               (2x  + 2x )\|- \|3  + 2 \|\|3  + 2 cos(----------)
+--R                                                           2
+--R          *
+--R                                                                       +-+    2
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R              +-----------------------------------+2             atan(\|3 )
+--R              |          +-+  2             +-+  2           cos(----------)
+--R              |    atan(\|3 )         atan(\|3 )                      2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                         +----------+ +--------+          +-+  2
+--R                8     4  |   +-+      | +-+         atan(\|3 )
+--R           (- 3x  - 3x )\|- \|3  + 2 \|\|3  + 2 sin(----------)
+--R                                                         2
+--R         + 
+--R                         +----------+ +--------+          +-+  2
+--R                8     4  |   +-+      | +-+         atan(\|3 )
+--R           (- 3x  - 3x )\|- \|3  + 2 \|\|3  + 2 cos(----------)
+--R                                                         2
+--R      *
+--R                            +-+    4
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                     +----------+ +--------+
+--R                        6     2  +-+ |   +-+      | +-+
+--R                   (- 8x  - 8x )\|3 \|- \|3  + 2 \|\|3  + 2
+--R                 + 
+--R                      10     6     2  +-+
+--R                   (8x   - 8x  + 8x )\|3
+--R              *
+--R                           +-+  2
+--R                     atan(\|3 )
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                     +----------+ +--------+
+--R                        6     2  +-+ |   +-+      | +-+
+--R                   (- 8x  - 8x )\|3 \|- \|3  + 2 \|\|3  + 2
+--R                 + 
+--R                      10     6     2  +-+
+--R                   (8x   - 8x  + 8x )\|3
+--R              *
+--R                           +-+  2
+--R                     atan(\|3 )
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                                                       +-+    3
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R              +-----------------------------------+2             atan(\|3 )
+--R              |          +-+  2             +-+  2           cos(----------)
+--R              |    atan(\|3 )         atan(\|3 )                      2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                               +----------+ +--------+          +-+  2
+--R                  8     4  +-+ |   +-+      | +-+         atan(\|3 )
+--R               (4x  + 4x )\|3 \|- \|3  + 2 \|\|3  + 2 sin(----------)
+--R                                                               2
+--R             + 
+--R                               +----------+ +--------+          +-+  2
+--R                  8     4  +-+ |   +-+      | +-+         atan(\|3 )
+--R               (4x  + 4x )\|3 \|- \|3  + 2 \|\|3  + 2 cos(----------)
+--R                                                               2
+--R          *
+--R                                +-+
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                            +-+    3
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                              +----------+ +--------+
+--R                       4      |   +-+      | +-+          8     4
+--R                 ((- 4x  - 4)\|- \|3  + 2 \|\|3  + 2  + 4x  - 4x  + 4)
+--R              *
+--R                           +-+  4
+--R                     atan(\|3 )
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                              +----------+ +--------+
+--R                       4      |   +-+      | +-+          8     4
+--R                 ((- 8x  - 8)\|- \|3  + 2 \|\|3  + 2  + 8x  - 8x  + 8)
+--R              *
+--R                           +-+  2          +-+  2
+--R                     atan(\|3 )      atan(\|3 )
+--R                 cos(----------) sin(----------)
+--R                          2               2
+--R             + 
+--R                              +----------+ +--------+
+--R                       4      |   +-+      | +-+          8     4
+--R                 ((- 4x  - 4)\|- \|3  + 2 \|\|3  + 2  + 4x  - 4x  + 4)
+--R              *
+--R                           +-+  4
+--R                     atan(\|3 )
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                +-+    6
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                             +----------+ +--------+          +-+  2
+--R                    6     2  |   +-+      | +-+         atan(\|3 )
+--R               (- 2x  - 2x )\|- \|3  + 2 \|\|3  + 2 sin(----------)
+--R                                                             2
+--R             + 
+--R                             +----------+ +--------+          +-+  2
+--R                    6     2  |   +-+      | +-+         atan(\|3 )
+--R               (- 2x  - 2x )\|- \|3  + 2 \|\|3  + 2 cos(----------)
+--R                                                             2
+--R          *
+--R                                                                       +-+    4
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R              +-----------------------------------+2             atan(\|3 )
+--R              |          +-+  2             +-+  2           cos(----------)
+--R              |    atan(\|3 )         atan(\|3 )                      2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                  +----------+ +--------+
+--R                        8      4  |   +-+      | +-+           12      8      4
+--R                 ((- 14x  - 14x )\|- \|3  + 2 \|\|3  + 2  + 16x   - 16x  + 16x )
+--R              *
+--R                           +-+  2
+--R                     atan(\|3 )
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                  +----------+ +--------+
+--R                        8      4  |   +-+      | +-+           12      8      4
+--R                 ((- 14x  - 14x )\|- \|3  + 2 \|\|3  + 2  + 16x   - 16x  + 16x )
+--R              *
+--R                           +-+  2
+--R                     atan(\|3 )
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                +-+    2
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                           +----------+ +--------+
+--R                 10     6  |   +-+      | +-+         14    10    6
+--R             ((2x   + 2x )\|- \|3  + 2 \|\|3  + 2  + x   - x   + x )
+--R          *
+--R              +-----------------------------------+2
+--R              |          +-+  2             +-+  2
+--R              |    atan(\|3 )         atan(\|3 )
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                            +-+    2
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                     +----------+ +--------+
+--R                        6     2  +-+ |   +-+      | +-+
+--R                   (- 4x  - 4x )\|3 \|- \|3  + 2 \|\|3  + 2
+--R                 + 
+--R                      10     6     2  +-+
+--R                   (4x   - 4x  + 4x )\|3
+--R              *
+--R                           +-+  2
+--R                     atan(\|3 )
+--R                 sin(----------)
+--R                          2
+--R             + 
+--R                                     +----------+ +--------+
+--R                        6     2  +-+ |   +-+      | +-+
+--R                   (- 4x  - 4x )\|3 \|- \|3  + 2 \|\|3  + 2
+--R                 + 
+--R                      10     6     2  +-+
+--R                   (4x   - 4x  + 4x )\|3
+--R              *
+--R                           +-+  2
+--R                     atan(\|3 )
+--R                 cos(----------)
+--R                          2
+--R          *
+--R                                                                       +-+    5
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R              +-----------------------------------+2             atan(\|3 )
+--R              |          +-+  2             +-+  2           cos(----------)
+--R              |    atan(\|3 )         atan(\|3 )                      2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                 +----------+ +--------+          +-+  2
+--R                    8     4  +-+ |   +-+      | +-+         atan(\|3 )
+--R               (- 4x  - 4x )\|3 \|- \|3  + 2 \|\|3  + 2 sin(----------)
+--R                                                                 2
+--R             + 
+--R                                 +----------+ +--------+          +-+  2
+--R                    8     4  +-+ |   +-+      | +-+         atan(\|3 )
+--R               (- 4x  - 4x )\|3 \|- \|3  + 2 \|\|3  + 2 cos(----------)
+--R                                                                 2
+--R          *
+--R                                +-+    3
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                  +----------+ +--------+
+--R                    10     6  +-+ |   +-+      | +-+
+--R               (- 4x   - 4x )\|3 \|- \|3  + 2 \|\|3  + 2
+--R             + 
+--R                  14     10     6  +-+
+--R               (2x   - 2x   + 2x )\|3
+--R          *
+--R                                                                       +-+
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R              +-----------------------------------+2             atan(\|3 )
+--R              |          +-+  2             +-+  2           cos(----------)
+--R              |    atan(\|3 )         atan(\|3 )                      2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R      *
+--R                            +-+
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                       +----------+ +--------+                         +-+  4
+--R                4      |   +-+      | +-+         8    4         atan(\|3 )
+--R           ((- x  - 1)\|- \|3  + 2 \|\|3  + 2  + x  - x  + 1)sin(----------)
+--R                                                                      2
+--R         + 
+--R                          +----------+ +--------+
+--R                   4      |   +-+      | +-+          8     4
+--R             ((- 2x  - 2)\|- \|3  + 2 \|\|3  + 2  + 2x  - 2x  + 2)
+--R          *
+--R                       +-+  2          +-+  2
+--R                 atan(\|3 )      atan(\|3 )
+--R             cos(----------) sin(----------)
+--R                      2               2
+--R         + 
+--R                       +----------+ +--------+                         +-+  4
+--R                4      |   +-+      | +-+         8    4         atan(\|3 )
+--R           ((- x  - 1)\|- \|3  + 2 \|\|3  + 2  + x  - x  + 1)cos(----------)
+--R                                                                      2
+--R      *
+--R                            +-+    8
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                         +----------+ +--------+          +-+  2
+--R                6     2  |   +-+      | +-+         atan(\|3 )
+--R           (- 2x  - 2x )\|- \|3  + 2 \|\|3  + 2 sin(----------)
+--R                                                         2
+--R         + 
+--R                         +----------+ +--------+          +-+  2
+--R                6     2  |   +-+      | +-+         atan(\|3 )
+--R           (- 2x  - 2x )\|- \|3  + 2 \|\|3  + 2 cos(----------)
+--R                                                         2
+--R      *
+--R                                                                   +-+    6
+--R                                                             atan(\|3 )
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                   +-+
+--R          +-----------------------------------+2             atan(\|3 )
+--R          |          +-+  2             +-+  2           cos(----------)
+--R          |    atan(\|3 )         atan(\|3 )                      2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                         +----------+ +--------+          +-+  2
+--R                8     4  |   +-+      | +-+         atan(\|3 )
+--R           (- 3x  - 3x )\|- \|3  + 2 \|\|3  + 2 sin(----------)
+--R                                                         2
+--R         + 
+--R                         +----------+ +--------+          +-+  2
+--R                8     4  |   +-+      | +-+         atan(\|3 )
+--R           (- 3x  - 3x )\|- \|3  + 2 \|\|3  + 2 cos(----------)
+--R                                                         2
+--R      *
+--R                            +-+    4
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                         +----------+ +--------+
+--R               10     6  |   +-+      | +-+         14    10    6
+--R         ((- 2x   - 2x )\|- \|3  + 2 \|\|3  + 2  - x   + x   - x )
+--R      *
+--R                                                                   +-+    2
+--R                                                             atan(\|3 )
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                   +-+
+--R          +-----------------------------------+2             atan(\|3 )
+--R          |          +-+  2             +-+  2           cos(----------)
+--R          |    atan(\|3 )         atan(\|3 )                      2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                    +----------+ +--------+
+--R           12    8  |   +-+      | +-+
+--R       (- x   - x )\|- \|3  + 2 \|\|3  + 2
+--R  /
+--R                                  +-+  4
+--R             8    4         atan(\|3 )
+--R           (x  - x  + 1)sin(----------)
+--R                                 2
+--R         + 
+--R                                    +-+  2          +-+  2
+--R              8     4         atan(\|3 )      atan(\|3 )
+--R           (2x  - 2x  + 2)cos(----------) sin(----------)
+--R                                   2               2
+--R         + 
+--R                                  +-+  4
+--R             8    4         atan(\|3 )
+--R           (x  - x  + 1)cos(----------)
+--R                                 2
+--R      *
+--R                            +-+    8
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                        +-+  4
+--R                  8     4         atan(\|3 )
+--R               (4x  - 4x  + 4)sin(----------)
+--R                                       2
+--R             + 
+--R                                        +-+  2          +-+  2
+--R                  8     4         atan(\|3 )      atan(\|3 )
+--R               (8x  - 8x  + 8)cos(----------) sin(----------)
+--R                                       2               2
+--R             + 
+--R                                        +-+  4
+--R                  8     4         atan(\|3 )
+--R               (4x  - 4x  + 4)cos(----------)
+--R                                       2
+--R          *
+--R                                +-+    2
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                             +-+  2
+--R                    10     6     2     atan(\|3 )
+--R               (- 2x   + 2x  - 2x )sin(----------)
+--R                                            2
+--R             + 
+--R                                             +-+  2
+--R                    10     6     2     atan(\|3 )
+--R               (- 2x   + 2x  - 2x )cos(----------)
+--R                                            2
+--R          *
+--R              +-----------------------------------+2
+--R              |          +-+  2             +-+  2
+--R              |    atan(\|3 )         atan(\|3 )
+--R             4|sin(----------)  + cos(----------)
+--R             \|         2                  2
+--R      *
+--R                            +-+    6
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                           +-+  2
+--R              10     6     2  +-+    atan(\|3 )
+--R           (4x   - 4x  + 4x )\|3 sin(----------)
+--R                                          2
+--R         + 
+--R                                           +-+  2
+--R              10     6     2  +-+    atan(\|3 )
+--R           (4x   - 4x  + 4x )\|3 cos(----------)
+--R                                          2
+--R      *
+--R                                                                   +-+
+--R                                                             atan(\|3 )
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                   +-+
+--R          +-----------------------------------+2             atan(\|3 )
+--R          |          +-+  2             +-+  2           cos(----------)
+--R          |    atan(\|3 )         atan(\|3 )                      2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R      *
+--R                            +-+    5
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                        +-+  4
+--R                  8     4         atan(\|3 )
+--R               (6x  - 6x  + 6)sin(----------)
+--R                                       2
+--R             + 
+--R                                           +-+  2          +-+  2
+--R                   8      4          atan(\|3 )      atan(\|3 )
+--R               (12x  - 12x  + 12)cos(----------) sin(----------)
+--R                                          2               2
+--R             + 
+--R                                        +-+  4
+--R                  8     4         atan(\|3 )
+--R               (6x  - 6x  + 6)cos(----------)
+--R                                       2
+--R          *
+--R                                +-+    4
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                             +-+  2
+--R                    10     6     2     atan(\|3 )
+--R               (- 2x   + 2x  - 2x )sin(----------)
+--R                                            2
+--R             + 
+--R                                             +-+  2
+--R                    10     6     2     atan(\|3 )
+--R               (- 2x   + 2x  - 2x )cos(----------)
+--R                                            2
+--R          *
+--R                                                                       +-+    2
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R              +-----------------------------------+2             atan(\|3 )
+--R              |          +-+  2             +-+  2           cos(----------)
+--R              |    atan(\|3 )         atan(\|3 )                      2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                     +-+  2                               +-+  2
+--R            12     8     4     atan(\|3 )        12     8     4     atan(\|3 )
+--R         (3x   - 3x  + 3x )sin(----------)  + (3x   - 3x  + 3x )cos(----------)
+--R                                    2                                    2
+--R      *
+--R                            +-+    4
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                               +-+  2
+--R                  10     6     2  +-+    atan(\|3 )
+--R               (8x   - 8x  + 8x )\|3 sin(----------)
+--R                                              2
+--R             + 
+--R                                               +-+  2
+--R                  10     6     2  +-+    atan(\|3 )
+--R               (8x   - 8x  + 8x )\|3 cos(----------)
+--R                                              2
+--R          *
+--R                                                                       +-+    3
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R              +-----------------------------------+2             atan(\|3 )
+--R              |          +-+  2             +-+  2           cos(----------)
+--R              |    atan(\|3 )         atan(\|3 )                      2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                                 +-+  2
+--R                    12     8     4  +-+    atan(\|3 )
+--R               (- 4x   + 4x  - 4x )\|3 sin(----------)
+--R                                                2
+--R             + 
+--R                                                 +-+  2
+--R                    12     8     4  +-+    atan(\|3 )
+--R               (- 4x   + 4x  - 4x )\|3 cos(----------)
+--R                                                2
+--R          *
+--R                                +-+
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                            +-+    3
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                        +-+  4
+--R                  8     4         atan(\|3 )
+--R               (4x  - 4x  + 4)sin(----------)
+--R                                       2
+--R             + 
+--R                                        +-+  2          +-+  2
+--R                  8     4         atan(\|3 )      atan(\|3 )
+--R               (8x  - 8x  + 8)cos(----------) sin(----------)
+--R                                       2               2
+--R             + 
+--R                                        +-+  4
+--R                  8     4         atan(\|3 )
+--R               (4x  - 4x  + 4)cos(----------)
+--R                                       2
+--R          *
+--R                                +-+    6
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                           +-+  2
+--R                  10     6     2     atan(\|3 )
+--R               (2x   - 2x  + 2x )sin(----------)
+--R                                          2
+--R             + 
+--R                                           +-+  2
+--R                  10     6     2     atan(\|3 )
+--R               (2x   - 2x  + 2x )cos(----------)
+--R                                          2
+--R          *
+--R                                                                       +-+    4
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R              +-----------------------------------+2             atan(\|3 )
+--R              |          +-+  2             +-+  2           cos(----------)
+--R              |    atan(\|3 )         atan(\|3 )                      2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                              +-+  2
+--R                   12      8      4     atan(\|3 )
+--R               (14x   - 14x  + 14x )sin(----------)
+--R                                             2
+--R             + 
+--R                                              +-+  2
+--R                   12      8      4     atan(\|3 )
+--R               (14x   - 14x  + 14x )cos(----------)
+--R                                             2
+--R          *
+--R                                +-+    2
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                  +-----------------------------------+2
+--R                                  |          +-+  2             +-+  2
+--R                14     10     6   |    atan(\|3 )         atan(\|3 )
+--R           (- 2x   + 2x   - 2x ) 4|sin(----------)  + cos(----------)
+--R                                 \|         2                  2
+--R      *
+--R                            +-+    2
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                               +-+  2
+--R                  10     6     2  +-+    atan(\|3 )
+--R               (4x   - 4x  + 4x )\|3 sin(----------)
+--R                                              2
+--R             + 
+--R                                               +-+  2
+--R                  10     6     2  +-+    atan(\|3 )
+--R               (4x   - 4x  + 4x )\|3 cos(----------)
+--R                                              2
+--R          *
+--R                                                                       +-+    5
+--R                                                                 atan(\|3 )
+--R                                                             sin(----------)
+--R                                                                      2
+--R                                                        atan(---------------)
+--R                                                                       +-+
+--R              +-----------------------------------+2             atan(\|3 )
+--R              |          +-+  2             +-+  2           cos(----------)
+--R              |    atan(\|3 )         atan(\|3 )                      2
+--R             4|sin(----------)  + cos(----------)   cos(---------------------)
+--R             \|         2                  2                      2
+--R         + 
+--R                                               +-+  2
+--R                  12     8     4  +-+    atan(\|3 )
+--R               (4x   - 4x  + 4x )\|3 sin(----------)
+--R                                              2
+--R             + 
+--R                                               +-+  2
+--R                  12     8     4  +-+    atan(\|3 )
+--R               (4x   - 4x  + 4x )\|3 cos(----------)
+--R                                              2
+--R          *
+--R                                +-+    3
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R         + 
+--R                                      +-----------------------------------+2
+--R                                      |          +-+  2             +-+  2
+--R                14     10     6  +-+  |    atan(\|3 )         atan(\|3 )
+--R             (4x   - 4x   + 4x )\|3  4|sin(----------)  + cos(----------)
+--R                                     \|         2                  2
+--R          *
+--R                                +-+
+--R                          atan(\|3 )
+--R                      sin(----------)
+--R                               2
+--R                 atan(---------------)
+--R                                +-+
+--R                          atan(\|3 )
+--R                      cos(----------)
+--R                               2
+--R             cos(---------------------)
+--R                           2
+--R      *
+--R                            +-+
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         sin(---------------------)
+--R                       2
+--R     + 
+--R                                  +-+  4
+--R             8    4         atan(\|3 )
+--R           (x  - x  + 1)sin(----------)
+--R                                 2
+--R         + 
+--R                                    +-+  2          +-+  2
+--R              8     4         atan(\|3 )      atan(\|3 )
+--R           (2x  - 2x  + 2)cos(----------) sin(----------)
+--R                                   2               2
+--R         + 
+--R                                  +-+  4
+--R             8    4         atan(\|3 )
+--R           (x  - x  + 1)cos(----------)
+--R                                 2
+--R      *
+--R                            +-+    8
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                                         +-+  2
+--R                10     6     2     atan(\|3 )
+--R             (2x   - 2x  + 2x )sin(----------)
+--R                                        2
+--R           + 
+--R                                         +-+  2
+--R                10     6     2     atan(\|3 )
+--R             (2x   - 2x  + 2x )cos(----------)
+--R                                        2
+--R      *
+--R                                                                   +-+    6
+--R                                                             atan(\|3 )
+--R                                                         sin(----------)
+--R                                                                  2
+--R                                                    atan(---------------)
+--R                                                                   +-+
+--R          +-----------------------------------+2             atan(\|3 )
+--R          |          +-+  2             +-+  2           cos(----------)
+--R          |    atan(\|3 )         atan(\|3 )                      2
+--R         4|sin(----------)  + cos(----------)   cos(---------------------)
+--R         \|         2                  2                      2
+--R     + 
+--R                                         +-+  2
+--R                12     8     4     atan(\|3 )
+--R             (3x   - 3x  + 3x )sin(----------)
+--R                                        2
+--R           + 
+--R                                         +-+  2
+--R                12     8     4     atan(\|3 )
+--R             (3x   - 3x  + 3x )cos(----------)
+--R                                        2
+--R      *
+--R                            +-+    4
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R                              +-----------------------------------+2
+--R                              |          +-+  2             +-+  2
+--R            14     10     6   |    atan(\|3 )         atan(\|3 )
+--R         (2x   - 2x   + 2x ) 4|sin(----------)  + cos(----------)
+--R                             \|         2                  2
+--R      *
+--R                            +-+    2
+--R                      atan(\|3 )
+--R                  sin(----------)
+--R                           2
+--R             atan(---------------)
+--R                            +-+
+--R                      atan(\|3 )
+--R                  cos(----------)
+--R                           2
+--R         cos(---------------------)
+--R                       2
+--R     + 
+--R        16    12    8
+--R       x   - x   + x
+--R                                                    Type: Expression(Integer)
+--E 305
+
+)clear all
+
+--S 306 of 649
+t0:=(1-x^4)/(1-3*x^4+x^8)
+--R 
+--R
+--R             4
+--R          - x  + 1
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 306
+
+--S 307 of 649
+r0:=1/2*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*(3-sqrt(5))^(1/4)/(2^(1/4)*_
+   sqrt(5))+1/2*atanh(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*(3-sqrt(5))^(1/4)/_
+   (2^(1/4)*sqrt(5))+1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))+1/2*atanh(x*(3+sqrt(5))^(1/4)/_
+   2^(1/4))*(3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                 +--------+
+--R        +--------+        4+-+3 4| +-+
+--R       4| +-+           x \|2   \|\|5  + 3
+--R       \|\|5  + 3 atanh(------------------)
+--R                                 2
+--R     + 
+--R                                +----------+
+--R        +----------+       4+-+4|   +-+
+--R       4|   +-+           x\|2 \|- \|5  + 3
+--R       \|- \|5  + 3 atanh(------------------)
+--R                                  +-+
+--R                                 \|2
+--R     + 
+--R                              +--------+                           +----------+
+--R      +--------+       4+-+3 4| +-+         +----------+      4+-+4|   +-+
+--R     4| +-+          x \|2   \|\|5  + 3    4|   +-+          x\|2 \|- \|5  + 3
+--R     \|\|5  + 3 atan(------------------) + \|- \|5  + 3 atan(------------------)
+--R                              2                                      +-+
+--R                                                                    \|2
+--R  /
+--R      4+-+ +-+
+--R     2\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +--------+               +--------+
+--R          | +-+                    | +-+
+--R          |\|5  + 5       +-+      |\|5  + 5
+--R       -  |-------- log((\|5  - 5) |--------  + x)
+--R          |    +-+                 |    +-+
+--R         \| 40\|5                 \| 40\|5
+--R     + 
+--R        +----------+               +----------+
+--R        |   +-+                    |   +-+
+--R        |- \|5  + 5       +-+      |- \|5  + 5
+--R        |---------- log((\|5  + 5) |----------  + x)
+--R        |     +-+                  |     +-+
+--R       \|  40\|5                  \|  40\|5
+--R     + 
+--R          +----------+                 +----------+
+--R          |   +-+                      |   +-+
+--R          |- \|5  + 5         +-+      |- \|5  + 5
+--R       -  |---------- log((- \|5  - 5) |----------  + x)
+--R          |     +-+                    |     +-+
+--R         \|  40\|5                    \|  40\|5
+--R     + 
+--R        +--------+                 +--------+
+--R        | +-+                      | +-+
+--R        |\|5  + 5         +-+      |\|5  + 5
+--R        |-------- log((- \|5  + 5) |--------  + x)
+--R        |    +-+                   |    +-+
+--R       \| 40\|5                   \| 40\|5
+--R     + 
+--R                                   +--------+
+--R                                   | +-+
+--R                          +-+      |\|5  + 5
+--R         +--------+     (\|5  - 5) |--------
+--R         | +-+                     |    +-+
+--R         |\|5  + 5                \| 40\|5
+--R       2 |-------- atan(---------------------)
+--R         |    +-+                 x
+--R        \| 40\|5
+--R     + 
+--R                                       +----------+
+--R                                       |   +-+
+--R                              +-+      |- \|5  + 5
+--R           +----------+     (\|5  + 5) |----------
+--R           |   +-+                     |     +-+
+--R           |- \|5  + 5                \|  40\|5
+--R       - 2 |---------- atan(-----------------------)
+--R           |     +-+                   x
+--R          \|  40\|5
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 308
+
+--S 309 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +--------+               +--------+
+--R                  | +-+                    | +-+
+--R         4+-+ +-+ |\|5  + 5       +-+      |\|5  + 5
+--R       - \|2 \|5  |-------- log((\|5  - 5) |--------  + x)
+--R                  |    +-+                 |    +-+
+--R                 \| 40\|5                 \| 40\|5
+--R     + 
+--R                +----------+               +----------+
+--R                |   +-+                    |   +-+
+--R       4+-+ +-+ |- \|5  + 5       +-+      |- \|5  + 5
+--R       \|2 \|5  |---------- log((\|5  + 5) |----------  + x)
+--R                |     +-+                  |     +-+
+--R               \|  40\|5                  \|  40\|5
+--R     + 
+--R                  +----------+                 +----------+
+--R                  |   +-+                      |   +-+
+--R         4+-+ +-+ |- \|5  + 5         +-+      |- \|5  + 5
+--R       - \|2 \|5  |---------- log((- \|5  - 5) |----------  + x)
+--R                  |     +-+                    |     +-+
+--R                 \|  40\|5                    \|  40\|5
+--R     + 
+--R                +--------+                 +--------+
+--R                | +-+                      | +-+
+--R       4+-+ +-+ |\|5  + 5         +-+      |\|5  + 5
+--R       \|2 \|5  |-------- log((- \|5  + 5) |--------  + x)
+--R                |    +-+                   |    +-+
+--R               \| 40\|5                   \| 40\|5
+--R     + 
+--R                                   +--------+
+--R          +--------+        4+-+3 4| +-+
+--R         4| +-+           x \|2   \|\|5  + 3
+--R       - \|\|5  + 3 atanh(------------------)
+--R                                   2
+--R     + 
+--R                                  +----------+
+--R          +----------+       4+-+4|   +-+
+--R         4|   +-+           x\|2 \|- \|5  + 3
+--R       - \|- \|5  + 3 atanh(------------------)
+--R                                    +-+
+--R                                   \|2
+--R     + 
+--R                                  +--------+
+--R          +--------+       4+-+3 4| +-+
+--R         4| +-+          x \|2   \|\|5  + 3
+--R       - \|\|5  + 3 atan(------------------)
+--R                                  2
+--R     + 
+--R                                           +--------+
+--R                                           | +-+
+--R                                  +-+      |\|5  + 5
+--R                 +--------+     (\|5  - 5) |--------
+--R                 | +-+                     |    +-+
+--R        4+-+ +-+ |\|5  + 5                \| 40\|5
+--R       2\|2 \|5  |-------- atan(---------------------)
+--R                 |    +-+                 x
+--R                \| 40\|5
+--R     + 
+--R                                               +----------+
+--R                                               |   +-+
+--R                                      +-+      |- \|5  + 5
+--R                   +----------+     (\|5  + 5) |----------
+--R                   |   +-+                     |     +-+
+--R          4+-+ +-+ |- \|5  + 5                \|  40\|5
+--R       - 2\|2 \|5  |---------- atan(-----------------------)
+--R                   |     +-+                   x
+--R                  \|  40\|5
+--R     + 
+--R                                 +----------+
+--R          +----------+      4+-+4|   +-+
+--R         4|   +-+          x\|2 \|- \|5  + 3
+--R       - \|- \|5  + 3 atan(------------------)
+--R                                   +-+
+--R                                  \|2
+--R  /
+--R      4+-+ +-+
+--R     2\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                              +--------+2
+--R           4      +-+      4 4| +-+
+--R       ((6x  - 4)\|5  - 10x )\|\|5  + 3
+--R     + 
+--R                                             +----------+2
+--R         4      +-+4+-+2 +-+     4 +-+4+-+2 4|   +-+               4      4+-+2
+--R     ((3x  - 2)\|2 \|2  \|5  + 5x \|2 \|2  )\|- \|5  + 3   + (- 20x  + 20)\|2
+--R  /
+--R         8      4      4+-+2
+--R     (20x  - 60x  + 20)\|2
+--R                                                    Type: Expression(Integer)
+--E 310
+
+)clear all
+
+--S 311 of 649
+t0:=(-1+2*x^4+sqrt(3))/(1-x^4+x^8)
+--R 
+--R
+--R          4    +-+
+--R        2x  + \|3  - 1
+--R   (1)  --------------
+--R           8    4
+--R          x  - x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 311
+
+--S 312 of 649
+r0:=-atan((-2*x*(3-sqrt(3))+sqrt(6))/sqrt(6*(7-4*sqrt(3))))/sqrt(2)+_
+   atan((2*x*(3-sqrt(3))+sqrt(6))/sqrt(6*(7-4*sqrt(3))))/sqrt(2)+_
+   1/2*log(3+x^2*(3-sqrt(3))-sqrt(3)-x*sqrt(6*(7-4*sqrt(3))))/sqrt(2)-_
+   1/2*log(3+x^2*(3-sqrt(3))-sqrt(3)+x*sqrt(6*(7-4*sqrt(3))))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R               +-------------+
+--R               |     +-+             2      +-+     2
+--R       - log(x\|- 24\|3  + 42  + (- x  - 1)\|3  + 3x  + 3)
+--R     + 
+--R               +-------------+
+--R               |     +-+             2      +-+     2
+--R       log(- x\|- 24\|3  + 42  + (- x  - 1)\|3  + 3x  + 3)
+--R     + 
+--R                                               +-------------+
+--R                 +-+      +-+       +-+        |     +-+
+--R             ((4\|3  + 7)\|6  + 10x\|3  + 18x)\|- 24\|3  + 42
+--R       2atan(-------------------------------------------------)
+--R                                     6
+--R     + 
+--R                                                 +-------------+
+--R                   +-+      +-+       +-+        |     +-+
+--R               ((4\|3  + 7)\|6  - 10x\|3  - 18x)\|- 24\|3  + 42
+--R       - 2atan(-------------------------------------------------)
+--R                                       6
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +-+ +-+    +-+
+--R                 2   \|2 \|3  - \|2
+--R                x  + --------------- x + 1
+--R       1                    2
+--R     ----- log(----------------------------)
+--R       +-+             +-+ +-+    +-+
+--R     2\|2       2   - \|2 \|3  + \|2
+--R               x  + ----------------- x + 1
+--R                            2
+--R   + 
+--R                +-+ +-+    +-+                           +-+ +-+    +-+
+--R       1       \|2 \|3  + \|2   3     2         1       \|2 \|3  + \|2
+--R     ---- atan(--------------- x  - ---- x) + ---- atan(--------------- x)
+--R      +-+             2              +-+       +-+             2
+--R     \|2                            \|2       \|2
+--R                                 Type: Union(Expression(AlgebraicNumber),...)
+--E 313
+
+--S 314 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +-+ +-+    +-+
+--R                 2   \|2 \|3  - \|2
+--R                x  + --------------- x + 1
+--R       1                    2
+--R     ----- log(----------------------------)
+--R       +-+             +-+ +-+    +-+
+--R     2\|2       2   - \|2 \|3  + \|2
+--R               x  + ----------------- x + 1
+--R                            2
+--R   + 
+--R      +-+                       +-------------+
+--R     \|2          +-+      2    |     +-+           +-+
+--R     ---- log((- \|3  + 3)x  + \|- 24\|3  + 42 x - \|3  + 3)
+--R       4
+--R   + 
+--R        +-+                       +-------------+
+--R       \|2          +-+      2    |     +-+           +-+
+--R     - ---- log((- \|3  + 3)x  - \|- 24\|3  + 42 x - \|3  + 3)
+--R         4
+--R   + 
+--R                +-+ +-+    +-+
+--R       1       \|2 \|3  + \|2   3     2
+--R     ---- atan(--------------- x  - ---- x)
+--R      +-+             2              +-+
+--R     \|2                            \|2
+--R   + 
+--R     -
+--R           +-+
+--R          \|2
+--R          ----
+--R            2
+--R       *
+--R                           +-------------+                     +-------------+
+--R                  +-+      |     +-+              +-+      +-+ |     +-+
+--R               (5\|3  + 9)\|- 24\|3  + 42      (4\|3  + 7)\|6 \|- 24\|3  + 42
+--R          atan(--------------------------- x + -------------------------------)
+--R                            3                                 6
+--R   + 
+--R     -
+--R           +-+
+--R          \|2
+--R          ----
+--R            2
+--R       *
+--R                         +-------------+                       +-------------+
+--R                +-+      |     +-+                +-+      +-+ |     +-+
+--R             (5\|3  + 9)\|- 24\|3  + 42      (- 4\|3  - 7)\|6 \|- 24\|3  + 42
+--R        atan(--------------------------- x + ---------------------------------)
+--R                          3                                  6
+--R   + 
+--R                +-+ +-+    +-+
+--R       1       \|2 \|3  + \|2
+--R     ---- atan(--------------- x)
+--R      +-+             2
+--R     \|2
+--R                                            Type: Expression(AlgebraicNumber)
+--E 314
+
+--S 315 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                            Type: Expression(AlgebraicNumber)
+--E 315
+
+)clear all
+
+--S 316 of 649
+t0:=(1+x^4*(1+sqrt(3)))/(1-x^4+x^8)
+--R 
+--R
+--R          +-+      4
+--R        (\|3  + 1)x  + 1
+--R   (1)  ----------------
+--R            8    4
+--R           x  - x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 316
+
+--S 317 of 649
+r0:=-1/2*atan((-2*x*sqrt(3)+sqrt(3*(2+sqrt(3))))/sqrt(3*(2-sqrt(3))))*_
+   sqrt(2+sqrt(3))+1/2*atan((2*x*sqrt(3)+sqrt(3*(2+sqrt(3))))/sqrt(3*_
+   (2-sqrt(3))))*sqrt(2+sqrt(3))-1/4*log(sqrt(3)+x^2*sqrt(3)-x*sqrt(3*_
+   (2-sqrt(3))))*sqrt(2+sqrt(3))+1/4*log(sqrt(3)+x^2*sqrt(3)+_
+   x*sqrt(3*(2-sqrt(3))))*sqrt(2+sqrt(3))
+--R 
+--R
+--R   (2)
+--R        +--------+      +-----------+
+--R        | +-+           |    +-+          2      +-+
+--R       \|\|3  + 2 log(x\|- 3\|3  + 6  + (x  + 1)\|3 )
+--R     + 
+--R          +--------+        +-----------+
+--R          | +-+             |    +-+          2      +-+
+--R       - \|\|3  + 2 log(- x\|- 3\|3  + 6  + (x  + 1)\|3 )
+--R     + 
+--R           +--------+
+--R           | +-+
+--R         2\|\|3  + 2
+--R      *
+--R                       +-----------+ +---------+                 +-----------+
+--R              +-+      |    +-+      |  +-+            +-+       |    +-+
+--R            (\|3  + 2)\|- 3\|3  + 6 \|3\|3  + 6  + (4x\|3  + 6x)\|- 3\|3  + 6
+--R       atan(------------------------------------------------------------------)
+--R                                             3
+--R     + 
+--R       -
+--R              +--------+
+--R              | +-+
+--R            2\|\|3  + 2
+--R         *
+--R            atan
+--R                              +-----------+ +---------+
+--R                     +-+      |    +-+      |  +-+
+--R                   (\|3  + 2)\|- 3\|3  + 6 \|3\|3  + 6
+--R                 + 
+--R                                   +-----------+
+--R                         +-+       |    +-+
+--R                   (- 4x\|3  - 6x)\|- 3\|3  + 6
+--R              /
+--R                 3
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      +--------+                       +--------+
+--R      | +-+           2       +-+      | +-+
+--R     \|\|3  + 2      x  + (- \|3  + 2)\|\|3  + 2 x + 1
+--R     ----------- log(---------------------------------)
+--R          4                           +--------+
+--R                       2     +-+      | +-+
+--R                      x  + (\|3  - 2)\|\|3  + 2 x + 1
+--R   + 
+--R      +--------+
+--R      | +-+            +--------+                  +--------+
+--R     \|\|3  + 2        | +-+      3       +-+      | +-+
+--R     ----------- atan(\|\|3  + 2 x  + (- \|3  + 1)\|\|3  + 2 x)
+--R          2
+--R   + 
+--R      +--------+
+--R      | +-+            +--------+
+--R     \|\|3  + 2        | +-+
+--R     ----------- atan(\|\|3  + 2 x)
+--R          2
+--R                                 Type: Union(Expression(AlgebraicNumber),...)
+--E 318
+
+--S 319 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        +--------+
+--R        | +-+                    +-----------+
+--R       \|\|3  + 2       +-+ 2    |    +-+          +-+
+--R     - ----------- log(\|3 x  + \|- 3\|3  + 6 x + \|3 )
+--R            4
+--R   + 
+--R      +--------+
+--R      | +-+                    +-----------+
+--R     \|\|3  + 2       +-+ 2    |    +-+          +-+
+--R     ----------- log(\|3 x  - \|- 3\|3  + 6 x + \|3 )
+--R          4
+--R   + 
+--R      +--------+                       +--------+
+--R      | +-+           2       +-+      | +-+
+--R     \|\|3  + 2      x  + (- \|3  + 2)\|\|3  + 2 x + 1
+--R     ----------- log(---------------------------------)
+--R          4                           +--------+
+--R                       2     +-+      | +-+
+--R                      x  + (\|3  - 2)\|\|3  + 2 x + 1
+--R   + 
+--R      +--------+
+--R      | +-+            +--------+                  +--------+
+--R     \|\|3  + 2        | +-+      3       +-+      | +-+
+--R     ----------- atan(\|\|3  + 2 x  + (- \|3  + 1)\|\|3  + 2 x)
+--R          2
+--R   + 
+--R      +--------+
+--R      | +-+            +--------+
+--R     \|\|3  + 2        | +-+
+--R     ----------- atan(\|\|3  + 2 x)
+--R          2
+--R   + 
+--R     -
+--R           +--------+
+--R           | +-+
+--R          \|\|3  + 2
+--R          -----------
+--R               2
+--R       *
+--R                         +-----------+                +-----------+ +---------+
+--R                +-+      |    +-+            +-+      |    +-+      |  +-+
+--R             (4\|3  + 6)\|- 3\|3  + 6      (\|3  + 2)\|- 3\|3  + 6 \|3\|3  + 6
+--R        atan(------------------------- x + ------------------------------------)
+--R                         3                                   3
+--R   + 
+--R     -
+--R           +--------+
+--R           | +-+
+--R          \|\|3  + 2
+--R          -----------
+--R               2
+--R       *
+--R          atan
+--R                           +-----------+
+--R                  +-+      |    +-+
+--R               (4\|3  + 6)\|- 3\|3  + 6
+--R               ------------------------- x
+--R                           3
+--R             + 
+--R                            +-----------+ +---------+
+--R                   +-+      |    +-+      |  +-+
+--R               (- \|3  - 2)\|- 3\|3  + 6 \|3\|3  + 6
+--R               --------------------------------------
+--R                                  3
+--R                                            Type: Expression(AlgebraicNumber)
+--E 319
+
+--gcd not gcd in QF cancelGcd (numerator)
+--S 320 of 649
+--d0:=D(m0,x)
+--E 320
+
+)clear all
+
+--S 321 of 649
+t0:=(3+x^4*(-3+sqrt(3))-2*sqrt(3))/(1-x^4+x^8)
+--R 
+--R
+--R          +-+      4     +-+
+--R        (\|3  - 3)x  - 2\|3  + 3
+--R   (1)  ------------------------
+--R                8    4
+--R               x  - x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 321
+
+--S 322 of 649
+r0:=1/2*atan((-2*x*(2-sqrt(3))+sqrt(2-sqrt(3)))/sqrt(26-15*sqrt(3)))*_
+   sqrt(3*(2-sqrt(3)))-1/2*atan((2*x*(2-sqrt(3))+sqrt(2-sqrt(3)))/_
+   sqrt(26-15*sqrt(3)))*sqrt(3*(2-sqrt(3)))+1/4*log(-3-x^2*(3-_
+   2*sqrt(3))+2*sqrt(3)-x*sqrt(3*(26-15*sqrt(3))))*sqrt(3*(2-sqrt(3)))-_
+   1/4*log(-3-x^2*(3-2*sqrt(3))+2*sqrt(3)+x*sqrt(3*(26-15*sqrt(3))))*_
+   sqrt(3*(2-sqrt(3)))
+--R 
+--R
+--R   (2)
+--R          +-----------+      +-------------+
+--R          |    +-+           |     +-+            2      +-+     2
+--R       - \|- 3\|3  + 6 log(x\|- 45\|3  + 78  + (2x  + 2)\|3  - 3x  - 3)
+--R     + 
+--R        +-----------+        +-------------+
+--R        |    +-+             |     +-+            2      +-+     2
+--R       \|- 3\|3  + 6 log(- x\|- 45\|3  + 78  + (2x  + 2)\|3  - 3x  - 3)
+--R     + 
+--R       -
+--R              +-----------+
+--R              |    +-+
+--R            2\|- 3\|3  + 6
+--R         *
+--R            atan
+--R                               +-------------+ +----------+
+--R                     +-+       |     +-+       |   +-+
+--R                 (15\|3  + 26)\|- 15\|3  + 26 \|- \|3  + 2
+--R               + 
+--R                                +-------------+
+--R                     +-+        |     +-+
+--R                 (8x\|3  + 14x)\|- 15\|3  + 26
+--R     + 
+--R           +-----------+
+--R           |    +-+
+--R         2\|- 3\|3  + 6
+--R      *
+--R         atan
+--R                            +-------------+ +----------+
+--R                  +-+       |     +-+       |   +-+
+--R              (15\|3  + 26)\|- 15\|3  + 26 \|- \|3  + 2
+--R            + 
+--R                               +-------------+
+--R                    +-+        |     +-+
+--R              (- 8x\|3  - 14x)\|- 15\|3  + 26
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                  +-----------+
+--R                              +-+ |    +-+
+--R      +-----------+      2   \|3 \|- 3\|3  + 6
+--R      |    +-+          x  - ------------------ x + 1
+--R     \|- 3\|3  + 6                    3
+--R     -------------- log(-----------------------------)
+--R            4                     +-----------+
+--R                              +-+ |    +-+
+--R                         2   \|3 \|- 3\|3  + 6
+--R                        x  + ------------------ x + 1
+--R                                      3
+--R   + 
+--R     -
+--R           +-----------+
+--R           |    +-+
+--R          \|- 3\|3  + 6
+--R          --------------
+--R                 2
+--R       *
+--R                           +-----------+                   +-----------+
+--R                  +-+      |    +-+               +-+      |    +-+
+--R               (2\|3  + 3)\|- 3\|3  + 6   3   (- \|3  - 3)\|- 3\|3  + 6
+--R          atan(------------------------- x  + -------------------------- x)
+--R                           3                               3
+--R   + 
+--R        +-----------+                  +-----------+
+--R        |    +-+              +-+      |    +-+
+--R       \|- 3\|3  + 6       (2\|3  + 3)\|- 3\|3  + 6
+--R     - -------------- atan(------------------------- x)
+--R              2                        3
+--R                                 Type: Union(Expression(AlgebraicNumber),...)
+--E 323
+
+--S 324 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R      +-----------+
+--R      |    +-+                           +-------------+
+--R     \|- 3\|3  + 6         +-+      2    |     +-+            +-+
+--R     -------------- log((2\|3  - 3)x  + \|- 45\|3  + 78 x + 2\|3  - 3)
+--R            4
+--R   + 
+--R        +-----------+
+--R        |    +-+                           +-------------+
+--R       \|- 3\|3  + 6         +-+      2    |     +-+            +-+
+--R     - -------------- log((2\|3  - 3)x  - \|- 45\|3  + 78 x + 2\|3  - 3)
+--R              4
+--R   + 
+--R                                  +-----------+
+--R                              +-+ |    +-+
+--R      +-----------+      2   \|3 \|- 3\|3  + 6
+--R      |    +-+          x  - ------------------ x + 1
+--R     \|- 3\|3  + 6                    3
+--R     -------------- log(-----------------------------)
+--R            4                     +-----------+
+--R                              +-+ |    +-+
+--R                         2   \|3 \|- 3\|3  + 6
+--R                        x  + ------------------ x + 1
+--R                                      3
+--R   + 
+--R     -
+--R           +-----------+
+--R           |    +-+
+--R          \|- 3\|3  + 6
+--R          --------------
+--R                 2
+--R       *
+--R                           +-----------+                   +-----------+
+--R                  +-+      |    +-+               +-+      |    +-+
+--R               (2\|3  + 3)\|- 3\|3  + 6   3   (- \|3  - 3)\|- 3\|3  + 6
+--R          atan(------------------------- x  + -------------------------- x)
+--R                           3                               3
+--R   + 
+--R        +-----------+                  +-----------+
+--R        |    +-+              +-+      |    +-+
+--R       \|- 3\|3  + 6       (2\|3  + 3)\|- 3\|3  + 6
+--R     - -------------- atan(------------------------- x)
+--R              2                        3
+--R   + 
+--R        +-----------+
+--R        |    +-+
+--R       \|- 3\|3  + 6
+--R       --------------
+--R              2
+--R    *
+--R       atan
+--R                         +-------------+
+--R               +-+       |     +-+
+--R            (8\|3  + 14)\|- 15\|3  + 26 x
+--R          + 
+--R                          +-------------+ +----------+
+--R                +-+       |     +-+       |   +-+
+--R            (15\|3  + 26)\|- 15\|3  + 26 \|- \|3  + 2
+--R   + 
+--R        +-----------+
+--R        |    +-+
+--R       \|- 3\|3  + 6
+--R       --------------
+--R              2
+--R    *
+--R       atan
+--R                         +-------------+
+--R               +-+       |     +-+
+--R            (8\|3  + 14)\|- 15\|3  + 26 x
+--R          + 
+--R                            +-------------+ +----------+
+--R                  +-+       |     +-+       |   +-+
+--R            (- 15\|3  - 26)\|- 15\|3  + 26 \|- \|3  + 2
+--R                                            Type: Expression(AlgebraicNumber)
+--E 324
+
+--S 325 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                            Type: Expression(AlgebraicNumber)
+--E 325
+
+)clear all
+
+--S 326 of 649
+t0:=(d+e*x^n)/(a+c*x^(2*n))
+--R 
+--R
+--R            n
+--R         e x  + d
+--R   (1)  ---------
+--R           2n
+--R        c x   + a
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 649
+--r0:=1/2*x*hypergeometric(1,1/n,1+1/n,-x^n*sqrt(c)/sqrt(-a))*_
+--  (d-e*sqrt(-a)/sqrt(c))/a+1/2*x*hypergeometric(1,1/n,1+1/n,x^n*_
+--  sqrt(c)/sqrt(-a))*(d+e*sqrt(-a)/sqrt(c))/a
+--E 327
+
+--S 328 of 649
+--a0:=integrate(t0,x)
+--E 328
+
+--S 329 of 649
+--m0:=a0-r0
+--E 329
+
+--S 330 of 649
+--d0:=D(m0,x)
+--E 330
+
+)clear all
+
+--S 331 of 649
+t0:=(d+e*x)/(a+c*x^2)
+--R 
+--R
+--R         e x + d
+--R   (1)  --------
+--R           2
+--R        c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 331
+
+--S 332 of 649
+r0:=1/2*e*log(a+c*x^2)/c+d*atan(x*sqrt(c)/sqrt(a))/(sqrt(a)*sqrt(c))
+--R 
+--R
+--R                    +-+
+--R                  x\|c              2      +-+ +-+
+--R        2c d atan(-----) + e log(c x  + a)\|a \|c
+--R                    +-+
+--R                   \|a
+--R   (2)  ------------------------------------------
+--R                           +-+ +-+
+--R                        2c\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2      +-----+
+--R            (c x  - a)\|- a c  + 2a c x             2      +-----+
+--R    c d log(---------------------------) + e log(c x  + a)\|- a c
+--R                         2
+--R                      c x  + a
+--R   [--------------------------------------------------------------,
+--R                                 +-----+
+--R                              2c\|- a c
+--R                +---+
+--R              x\|a c              2      +---+
+--R    2c d atan(-------) + e log(c x  + a)\|a c
+--R                 a
+--R    ------------------------------------------]
+--R                        +---+
+--R                     2c\|a c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 333
+
+--S 334 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R                         2      +-----+                              +-+
+--R          +-+ +-+    (c x  - a)\|- a c  + 2a c x       +-----+     x\|c
+--R        d\|a \|c log(---------------------------) - 2d\|- a c atan(-----)
+--R                                  2                                  +-+
+--R                               c x  + a                             \|a
+--R   (4)  -----------------------------------------------------------------
+--R                                  +-----+ +-+ +-+
+--R                                2\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+                  +-+
+--R          +-+ +-+     x\|a c       +---+     x\|c
+--R        d\|a \|c atan(-------) - d\|a c atan(-----)
+--R                         a                     +-+
+--R                                              \|a
+--R   (6)  -------------------------------------------
+--R                        +-+ +-+ +---+
+--R                       \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 337
+
+)clear all
+
+--S 338 of 649
+t0:=(d+e*x^2)/(a+c*x^4)
+--R 
+--R
+--R           2
+--R        e x  + d
+--R   (1)  --------
+--R           4
+--R        c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 338
+
+--S 339 of 649
+r0:=-1/4*log(-a^(1/4)*c^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(c))*(-e*sqrt(a)+_
+   d*sqrt(c))/(a^(3/4)*c^(3/4)*sqrt(2))+1/4*log(a^(1/4)*c^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(c))*(-e*sqrt(a)+d*sqrt(c))/(a^(3/4)*c^(3/4)*sqrt(2))-_
+   1/2*atan(1-c^(1/4)*x*sqrt(2)/a^(1/4))*(e*sqrt(a)+d*sqrt(c))/(a^(3/4)*_
+   c^(3/4)*sqrt(2))+1/2*atan(1+c^(1/4)*x*sqrt(2)/a^(1/4))*(e*sqrt(a)+_
+   d*sqrt(c))/(a^(3/4)*c^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R          +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (d\|c  - e\|a )log(x\|2 \|a \|c  + x \|c  + \|a )
+--R     + 
+--R            +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- d\|c  + e\|a )log(- x\|2 \|a \|c  + x \|c  + \|a )
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|c  + \|a
+--R       (2d\|c  + 2e\|a )atan(----------------)
+--R                                   4+-+
+--R                                   \|a
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|c  - \|a
+--R       (2d\|c  + 2e\|a )atan(----------------)
+--R                                   4+-+
+--R                                   \|a
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|a   \|c
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +--------------------------------------+
+--R          |     +-------------------------+
+--R          |     |   2 4         2 2    2 4
+--R          |     |- a e  + 2a c d e  - c d
+--R          |4a c |-------------------------  - d e
+--R          |     |             3 3
+--R          |    \|          64a c
+--R          |--------------------------------------
+--R         \|                 2a c
+--R      *
+--R         log
+--R                         +-------------------------+
+--R                         |   2 4         2 2    2 4
+--R                    3 2  |- a e  + 2a c d e  - c d       2     2       2 3
+--R                (16a c e |-------------------------  + 2a c d e  - 2a c d )
+--R                         |             3 3
+--R                        \|          64a c
+--R             *
+--R                 +--------------------------------------+
+--R                 |     +-------------------------+
+--R                 |     |   2 4         2 2    2 4
+--R                 |     |- a e  + 2a c d e  - c d
+--R                 |4a c |-------------------------  - d e
+--R                 |     |             3 3
+--R                 |    \|          64a c
+--R                 |--------------------------------------
+--R                \|                 2a c
+--R            + 
+--R                2 4    2 4
+--R              (a e  - c d )x
+--R     + 
+--R       -
+--R             +----------------------------------------+
+--R             |       +-------------------------+
+--R             |       |   2 4         2 2    2 4
+--R             |       |- a e  + 2a c d e  - c d
+--R             |- 4a c |-------------------------  - d e
+--R             |       |             3 3
+--R             |      \|          64a c
+--R             |----------------------------------------
+--R            \|                  2a c
+--R         *
+--R            log
+--R                            +-------------------------+
+--R                            |   2 4         2 2    2 4
+--R                       3 2  |- a e  + 2a c d e  - c d       2     2       2 3
+--R                   (16a c e |-------------------------  - 2a c d e  + 2a c d )
+--R                            |             3 3
+--R                           \|          64a c
+--R                *
+--R                    +----------------------------------------+
+--R                    |       +-------------------------+
+--R                    |       |   2 4         2 2    2 4
+--R                    |       |- a e  + 2a c d e  - c d
+--R                    |- 4a c |-------------------------  - d e
+--R                    |       |             3 3
+--R                    |      \|          64a c
+--R                    |----------------------------------------
+--R                   \|                  2a c
+--R               + 
+--R                   2 4    2 4
+--R                 (a e  - c d )x
+--R     + 
+--R          +----------------------------------------+
+--R          |       +-------------------------+
+--R          |       |   2 4         2 2    2 4
+--R          |       |- a e  + 2a c d e  - c d
+--R          |- 4a c |-------------------------  - d e
+--R          |       |             3 3
+--R          |      \|          64a c
+--R          |----------------------------------------
+--R         \|                  2a c
+--R      *
+--R         log
+--R                           +-------------------------+
+--R                           |   2 4         2 2    2 4
+--R                      3 2  |- a e  + 2a c d e  - c d       2     2       2 3
+--R                (- 16a c e |-------------------------  + 2a c d e  - 2a c d )
+--R                           |             3 3
+--R                          \|          64a c
+--R             *
+--R                 +----------------------------------------+
+--R                 |       +-------------------------+
+--R                 |       |   2 4         2 2    2 4
+--R                 |       |- a e  + 2a c d e  - c d
+--R                 |- 4a c |-------------------------  - d e
+--R                 |       |             3 3
+--R                 |      \|          64a c
+--R                 |----------------------------------------
+--R                \|                  2a c
+--R            + 
+--R                2 4    2 4
+--R              (a e  - c d )x
+--R     + 
+--R       -
+--R             +--------------------------------------+
+--R             |     +-------------------------+
+--R             |     |   2 4         2 2    2 4
+--R             |     |- a e  + 2a c d e  - c d
+--R             |4a c |-------------------------  - d e
+--R             |     |             3 3
+--R             |    \|          64a c
+--R             |--------------------------------------
+--R            \|                 2a c
+--R         *
+--R            log
+--R                              +-------------------------+
+--R                              |   2 4         2 2    2 4
+--R                         3 2  |- a e  + 2a c d e  - c d       2     2       2 3
+--R                   (- 16a c e |-------------------------  - 2a c d e  + 2a c d )
+--R                              |             3 3
+--R                             \|          64a c
+--R                *
+--R                    +--------------------------------------+
+--R                    |     +-------------------------+
+--R                    |     |   2 4         2 2    2 4
+--R                    |     |- a e  + 2a c d e  - c d
+--R                    |4a c |-------------------------  - d e
+--R                    |     |             3 3
+--R                    |    \|          64a c
+--R                    |--------------------------------------
+--R                   \|                 2a c
+--R               + 
+--R                   2 4    2 4
+--R                 (a e  - c d )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 340
+
+--S 341 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +--------------------------------------+
+--R                          |     +-------------------------+
+--R                          |     |   2 4         2 2    2 4
+--R                          |     |- a e  + 2a c d e  - c d
+--R                          |4a c |-------------------------  - d e
+--R                          |     |             3 3
+--R           +-+4+-+3 4+-+3 |    \|          64a c
+--R         2\|2 \|a   \|c   |--------------------------------------
+--R                         \|                 2a c
+--R      *
+--R         log
+--R                         +-------------------------+
+--R                         |   2 4         2 2    2 4
+--R                    3 2  |- a e  + 2a c d e  - c d       2     2       2 3
+--R                (16a c e |-------------------------  + 2a c d e  - 2a c d )
+--R                         |             3 3
+--R                        \|          64a c
+--R             *
+--R                 +--------------------------------------+
+--R                 |     +-------------------------+
+--R                 |     |   2 4         2 2    2 4
+--R                 |     |- a e  + 2a c d e  - c d
+--R                 |4a c |-------------------------  - d e
+--R                 |     |             3 3
+--R                 |    \|          64a c
+--R                 |--------------------------------------
+--R                \|                 2a c
+--R            + 
+--R                2 4    2 4
+--R              (a e  - c d )x
+--R     + 
+--R       -
+--R                             +----------------------------------------+
+--R                             |       +-------------------------+
+--R                             |       |   2 4         2 2    2 4
+--R                             |       |- a e  + 2a c d e  - c d
+--R                             |- 4a c |-------------------------  - d e
+--R                             |       |             3 3
+--R              +-+4+-+3 4+-+3 |      \|          64a c
+--R            2\|2 \|a   \|c   |----------------------------------------
+--R                            \|                  2a c
+--R         *
+--R            log
+--R                            +-------------------------+
+--R                            |   2 4         2 2    2 4
+--R                       3 2  |- a e  + 2a c d e  - c d       2     2       2 3
+--R                   (16a c e |-------------------------  - 2a c d e  + 2a c d )
+--R                            |             3 3
+--R                           \|          64a c
+--R                *
+--R                    +----------------------------------------+
+--R                    |       +-------------------------+
+--R                    |       |   2 4         2 2    2 4
+--R                    |       |- a e  + 2a c d e  - c d
+--R                    |- 4a c |-------------------------  - d e
+--R                    |       |             3 3
+--R                    |      \|          64a c
+--R                    |----------------------------------------
+--R                   \|                  2a c
+--R               + 
+--R                   2 4    2 4
+--R                 (a e  - c d )x
+--R     + 
+--R                          +----------------------------------------+
+--R                          |       +-------------------------+
+--R                          |       |   2 4         2 2    2 4
+--R                          |       |- a e  + 2a c d e  - c d
+--R                          |- 4a c |-------------------------  - d e
+--R                          |       |             3 3
+--R           +-+4+-+3 4+-+3 |      \|          64a c
+--R         2\|2 \|a   \|c   |----------------------------------------
+--R                         \|                  2a c
+--R      *
+--R         log
+--R                           +-------------------------+
+--R                           |   2 4         2 2    2 4
+--R                      3 2  |- a e  + 2a c d e  - c d       2     2       2 3
+--R                (- 16a c e |-------------------------  + 2a c d e  - 2a c d )
+--R                           |             3 3
+--R                          \|          64a c
+--R             *
+--R                 +----------------------------------------+
+--R                 |       +-------------------------+
+--R                 |       |   2 4         2 2    2 4
+--R                 |       |- a e  + 2a c d e  - c d
+--R                 |- 4a c |-------------------------  - d e
+--R                 |       |             3 3
+--R                 |      \|          64a c
+--R                 |----------------------------------------
+--R                \|                  2a c
+--R            + 
+--R                2 4    2 4
+--R              (a e  - c d )x
+--R     + 
+--R       -
+--R                             +--------------------------------------+
+--R                             |     +-------------------------+
+--R                             |     |   2 4         2 2    2 4
+--R                             |     |- a e  + 2a c d e  - c d
+--R                             |4a c |-------------------------  - d e
+--R                             |     |             3 3
+--R              +-+4+-+3 4+-+3 |    \|          64a c
+--R            2\|2 \|a   \|c   |--------------------------------------
+--R                            \|                 2a c
+--R         *
+--R            log
+--R                              +-------------------------+
+--R                              |   2 4         2 2    2 4
+--R                         3 2  |- a e  + 2a c d e  - c d       2     2       2 3
+--R                   (- 16a c e |-------------------------  - 2a c d e  + 2a c d )
+--R                              |             3 3
+--R                             \|          64a c
+--R                *
+--R                    +--------------------------------------+
+--R                    |     +-------------------------+
+--R                    |     |   2 4         2 2    2 4
+--R                    |     |- a e  + 2a c d e  - c d
+--R                    |4a c |-------------------------  - d e
+--R                    |     |             3 3
+--R                    |    \|          64a c
+--R                    |--------------------------------------
+--R                   \|                 2a c
+--R               + 
+--R                   2 4    2 4
+--R                 (a e  - c d )x
+--R     + 
+--R            +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- d\|c  + e\|a )log(x\|2 \|a \|c  + x \|c  + \|a )
+--R     + 
+--R          +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (d\|c  - e\|a )log(- x\|2 \|a \|c  + x \|c  + \|a )
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|c  + \|a
+--R       (- 2d\|c  - 2e\|a )atan(----------------)
+--R                                     4+-+
+--R                                     \|a
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|c  - \|a
+--R       (- 2d\|c  - 2e\|a )atan(----------------)
+--R                                     4+-+
+--R                                     \|a
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|a   \|c
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4       2  +-+4+-+2        6         4        2  +-+
+--R           ((4e x  + 4d x )\|a \|a   - c d x  - 2a e x  + a d x )\|c
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2c e x  + 2c d x  + 2a e x  + 2a d)\|a
+--R         + 
+--R                   6         4        2  +-+
+--R           (- c e x  - 2c d x  + a e x )\|a
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                   4         2       4+-+2
+--R             (c d x  - 2a e x  - a d)\|a
+--R           + 
+--R                     6        4        2        +-+
+--R             (- c e x  - c d x  - a e x  - a d)\|a
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R             4         2        +-+4+-+2    2   6           4           2    2
+--R       (c e x  - 2c d x  - a e)\|a \|a   + c d x  - 3a c e x  - 3a c d x  + a e
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4c x  + 4a x )\|a \|a  \|c  + (2c x  + 4a c x  + 2a )\|a  )\|c
+--R     + 
+--R             2 6     2   2
+--R       - 4a c x  - 4a c x
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 649
+t0:=(d+e*x^3)/(a+c*x^6)
+--R 
+--R
+--R           3
+--R        e x  + d
+--R   (1)  --------
+--R           6
+--R        c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 343
+
+--S 344 of 649
+r0:=-1/6*log((-a)^(1/6)+c^(1/6)*x)*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*_
+   c^(2/3))+1/12*log((-a)^(1/3)-(-a)^(1/6)*c^(1/6)*x+c^(1/3)*x^2)*_
+   (-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))+1/2*atan(((-a)^(1/6)-_
+   2*c^(1/6)*x)/((-a)^(1/6)*sqrt(3)))*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*_
+   c^(2/3)*sqrt(3))+1/6*log((-a)^(1/6)-c^(1/6)*x)*(e*sqrt(-a)+d*sqrt(c))/_
+   ((-a)^(5/6)*c^(2/3))-1/12*log((-a)^(1/3)+(-a)^(1/6)*c^(1/6)*x+_
+   c^(1/3)*x^2)*(e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))-_
+   1/2*atan(((-a)^(1/6)+2*c^(1/6)*x)/((-a)^(1/6)*sqrt(3)))*(e*_
+   sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3)*sqrt(3)),-1/6*log((-a)^(1/6)+_
+   c^(1/6)*x)*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))-1/6*(-1)^(2/3)*_
+   log((-a)^(1/6)-(-1)^(1/3)*c^(1/6)*x)*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*_
+   c^(2/3))+1/6*(-1)^(1/3)*log((-a)^(1/6)+(-1)^(2/3)*c^(1/6)*x)*_
+   (-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))+1/6*log((-a)^(1/6)-_
+   c^(1/6)*x)*(e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))+1/6*(-1)^(2/3)*_
+   log((-a)^(1/6)+(-1)^(1/3)*c^(1/6)*x)*(e*sqrt(-a)+d*sqrt(c))/_
+   ((-a)^(5/6)*c^(2/3))-1/6*(-1)^(1/3)*log((-a)^(1/6)-(-1)^(2/3)*_
+   c^(1/6)*x)*(e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))
+--R 
+--R
+--R   (2)
+--R   [
+--R              +-+ +-+     +-+ +---+      6+---+6+-+    2 3+-+  3+---+
+--R         (- d\|3 \|c  - e\|3 \|- a )log(x\|- a \|c  + x  \|c + \|- a )
+--R       + 
+--R               +-+ +-+      +-+ +---+      6+-+   6+---+
+--R         (- 2d\|3 \|c  + 2e\|3 \|- a )log(x\|c  + \|- a )
+--R       + 
+--R             +-+ +-+      +-+ +---+        6+-+   6+---+
+--R         (2d\|3 \|c  + 2e\|3 \|- a )log(- x\|c  + \|- a )
+--R       + 
+--R            +-+ +-+     +-+ +---+        6+---+6+-+    2 3+-+  3+---+
+--R         (d\|3 \|c  - e\|3 \|- a )log(- x\|- a \|c  + x  \|c + \|- a )
+--R       + 
+--R                                     6+-+   6+---+
+--R               +-+      +---+      2x\|c  + \|- a
+--R         (- 6d\|c  - 6e\|- a )atan(---------------)
+--R                                       +-+6+---+
+--R                                      \|3 \|- a
+--R       + 
+--R                                     6+-+   6+---+
+--R               +-+      +---+      2x\|c  - \|- a
+--R         (- 6d\|c  + 6e\|- a )atan(---------------)
+--R                                       +-+6+---+
+--R                                      \|3 \|- a
+--R    /
+--R          +-+6+---+5 3+-+2
+--R       12\|3 \|- a   \|c
+--R     ,
+--R
+--R           3+---+ +-+    3+---+ +---+       3+---+2 6+-+  6+---+
+--R         (d\|- 1 \|c  - e\|- 1 \|- a )log(x \|- 1   \|c + \|- a )
+--R       + 
+--R            3+---+2 +-+     3+---+2 +---+      3+---+6+-+   6+---+
+--R         (d \|- 1  \|c  + e \|- 1  \|- a )log(x\|- 1 \|c  + \|- a )
+--R       + 
+--R              +-+     +---+      6+-+   6+---+
+--R         (- d\|c  + e\|- a )log(x\|c  + \|- a )
+--R       + 
+--R            +-+     +---+        6+-+   6+---+
+--R         (d\|c  + e\|- a )log(- x\|c  + \|- a )
+--R       + 
+--R              3+---+2 +-+     3+---+2 +---+        3+---+6+-+   6+---+
+--R         (- d \|- 1  \|c  + e \|- 1  \|- a )log(- x\|- 1 \|c  + \|- a )
+--R       + 
+--R             3+---+ +-+    3+---+ +---+         3+---+2 6+-+  6+---+
+--R         (- d\|- 1 \|c  - e\|- 1 \|- a )log(- x \|- 1   \|c + \|- a )
+--R    /
+--R        6+---+5 3+-+2
+--R       6\|- a   \|c
+--R     ]
+--R                                             Type: Tuple(Expression(Integer))
+--E 344
+
+--S 345 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +--------------------------------------------------------+
+--R             |          +----------------------------+
+--R             |          |    2 2 4         4 2    2 6
+--R             |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R             |- 108a c  |----------------------------  - a e  + 3c d e
+--R             |          |                5 3
+--R             |         \|          11664a c
+--R             |--------------------------------------------------------
+--R            3|                             2 2
+--R            \|                         216a c
+--R         *
+--R            log
+--R                                 +----------------------------+
+--R                                 |    2 2 4         4 2    2 6
+--R                          5 3    |- 9a d e  + 6a c d e  - c d         4     4
+--R                     7776a c d e |----------------------------  - 108a c d e
+--R                                 |                5 3
+--R                                \|          11664a c
+--R                   + 
+--R                         3 2 3 2      2 3 5
+--R                     144a c d e  - 36a c d
+--R                *
+--R                    +--------------------------------------------------------+2
+--R                    |          +----------------------------+
+--R                    |          |    2 2 4         4 2    2 6
+--R                    |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                    |- 108a c  |----------------------------  - a e  + 3c d e
+--R                    |          |                5 3
+--R                    |         \|          11664a c
+--R                    |--------------------------------------------------------
+--R                   3|                             2 2
+--R                   \|                         216a c
+--R               + 
+--R                                                 +----------------------------+
+--R                                                 |    2 2 4         4 2    2 6
+--R                            5 2 3       4 3 2    |- 9a d e  + 6a c d e  - c d
+--R                     (- 648a c e  - 648a c d e)x |----------------------------
+--R                                                 |                5 3
+--R                                                \|          11664a c
+--R                   + 
+--R                           3   2 4      2 2 4 2       3 6
+--R                     (- 18a c d e  - 12a c d e  + 6a c d )x
+--R                *
+--R                    +--------------------------------------------------------+
+--R                    |          +----------------------------+
+--R                    |          |    2 2 4         4 2    2 6
+--R                    |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                    |- 108a c  |----------------------------  - a e  + 3c d e
+--R                    |          |                5 3
+--R                    |         \|          11664a c
+--R                    |--------------------------------------------------------
+--R                   3|                             2 2
+--R                   \|                         216a c
+--R               + 
+--R                    3   6     2   3 4      2 5 2    3 7  2
+--R                 (3a d e  + 5a c d e  + a c d e  - c d )x
+--R     + 
+--R            +--------------------------------------------------------+
+--R            |          +----------------------------+
+--R            |          |    2 2 4         4 2    2 6
+--R            |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R            |- 108a c  |----------------------------  - a e  + 3c d e
+--R            |          |                5 3
+--R            |         \|          11664a c
+--R         2  |--------------------------------------------------------
+--R           3|                             2 2
+--R           \|                         216a c
+--R      *
+--R         log
+--R                          +----------------------------+
+--R                          |    2 2 4         4 2    2 6
+--R                     4 2  |- 9a d e  + 6a c d e  - c d        2   2 2       2 4
+--R                (648a c e |----------------------------  + 18a c d e  - 6a c d )
+--R                          |                5 3
+--R                         \|          11664a c
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |          +----------------------------+
+--R                 |          |    2 2 4         4 2    2 6
+--R                 |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                 |- 108a c  |----------------------------  - a e  + 3c d e
+--R                 |          |                5 3
+--R                 |         \|          11664a c
+--R                 |--------------------------------------------------------
+--R                3|                             2 2
+--R                \|                         216a c
+--R            + 
+--R                 2   4         3 2    2 5
+--R              (3a d e  + 2a c d e  - c d )x
+--R     + 
+--R            +------------------------------------------------------+
+--R            |        +----------------------------+
+--R            |        |    2 2 4         4 2    2 6
+--R            |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R            |108a c  |----------------------------  - a e  + 3c d e
+--R            |        |                5 3
+--R            |       \|          11664a c
+--R         2  |------------------------------------------------------
+--R           3|                            2 2
+--R           \|                        216a c
+--R      *
+--R         log
+--R                               +----------------------------+
+--R                               |    2 2 4         4 2    2 6
+--R                          4 2  |- 9a d e  + 6a c d e  - c d        2   2 2
+--R                    - 648a c e |----------------------------  + 18a c d e
+--R                               |                5 3
+--R                              \|          11664a c
+--R                  + 
+--R                          2 4
+--R                    - 6a c d
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        +----------------------------+
+--R                 |        |    2 2 4         4 2    2 6
+--R                 |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                 |108a c  |----------------------------  - a e  + 3c d e
+--R                 |        |                5 3
+--R                 |       \|          11664a c
+--R                 |------------------------------------------------------
+--R                3|                            2 2
+--R                \|                        216a c
+--R            + 
+--R                 2   4         3 2    2 5
+--R              (3a d e  + 2a c d e  - c d )x
+--R     + 
+--R       -
+--R             +------------------------------------------------------+
+--R             |        +----------------------------+
+--R             |        |    2 2 4         4 2    2 6
+--R             |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R             |108a c  |----------------------------  - a e  + 3c d e
+--R             |        |                5 3
+--R             |       \|          11664a c
+--R             |------------------------------------------------------
+--R            3|                            2 2
+--R            \|                        216a c
+--R         *
+--R            log
+--R                                   +----------------------------+
+--R                                   |    2 2 4         4 2    2 6
+--R                            5 3    |- 9a d e  + 6a c d e  - c d         4     4
+--R                     - 7776a c d e |----------------------------  - 108a c d e
+--R                                   |                5 3
+--R                                  \|          11664a c
+--R                   + 
+--R                         3 2 3 2      2 3 5
+--R                     144a c d e  - 36a c d
+--R                *
+--R                    +------------------------------------------------------+2
+--R                    |        +----------------------------+
+--R                    |        |    2 2 4         4 2    2 6
+--R                    |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                    |108a c  |----------------------------  - a e  + 3c d e
+--R                    |        |                5 3
+--R                    |       \|          11664a c
+--R                    |------------------------------------------------------
+--R                   3|                            2 2
+--R                   \|                        216a c
+--R               + 
+--R                                               +----------------------------+
+--R                                               |    2 2 4         4 2    2 6
+--R                          5 2 3       4 3 2    |- 9a d e  + 6a c d e  - c d
+--R                     (648a c e  + 648a c d e)x |----------------------------
+--R                                               |                5 3
+--R                                              \|          11664a c
+--R                   + 
+--R                           3   2 4      2 2 4 2       3 6
+--R                     (- 18a c d e  - 12a c d e  + 6a c d )x
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |        +----------------------------+
+--R                    |        |    2 2 4         4 2    2 6
+--R                    |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                    |108a c  |----------------------------  - a e  + 3c d e
+--R                    |        |                5 3
+--R                    |       \|          11664a c
+--R                    |------------------------------------------------------
+--R                   3|                            2 2
+--R                   \|                        216a c
+--R               + 
+--R                    3   6     2   3 4      2 5 2    3 7  2
+--R                 (3a d e  + 5a c d e  + a c d e  - c d )x
+--R     + 
+--R                +--------------------------------------------------------+
+--R                |          +----------------------------+
+--R                |          |    2 2 4         4 2    2 6
+--R                |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                |- 108a c  |----------------------------  - a e  + 3c d e
+--R                |          |                5 3
+--R           +-+  |         \|          11664a c
+--R         2\|3   |--------------------------------------------------------
+--R               3|                             2 2
+--R               \|                         216a c
+--R      *
+--R         atan
+--R                               +----------------------------+
+--R                               |    2 2 4         4 2    2 6
+--R                      4 2  +-+ |- 9a d e  + 6a c d e  - c d
+--R                  324a c e\|3  |----------------------------
+--R                               |                5 3
+--R                              \|          11664a c
+--R                + 
+--R                     2   2 2       2 4  +-+
+--R                  (9a c d e  - 3a c d )\|3
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |          +----------------------------+
+--R                 |          |    2 2 4         4 2    2 6
+--R                 |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                 |- 108a c  |----------------------------  - a e  + 3c d e
+--R                 |          |                5 3
+--R                 |         \|          11664a c
+--R                 |--------------------------------------------------------
+--R                3|                             2 2
+--R                \|                         216a c
+--R           /
+--R                               +----------------------------+
+--R                               |    2 2 4         4 2    2 6
+--R                          4 2  |- 9a d e  + 6a c d e  - c d       2   2 2
+--R                      324a c e |----------------------------  + 9a c d e
+--R                               |                5 3
+--R                              \|          11664a c
+--R                    + 
+--R                            2 4
+--R                      - 3a c d
+--R               *
+--R                   +--------------------------------------------------------+
+--R                   |          +----------------------------+
+--R                   |          |    2 2 4         4 2    2 6
+--R                   |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                   |- 108a c  |----------------------------  - a e  + 3c d e
+--R                   |          |                5 3
+--R                   |         \|          11664a c
+--R                   |--------------------------------------------------------
+--R                  3|                             2 2
+--R                  \|                         216a c
+--R              + 
+--R                     2   4         3 2    2 5
+--R                (- 3a d e  - 2a c d e  + c d )x
+--R     + 
+--R                +------------------------------------------------------+
+--R                |        +----------------------------+
+--R                |        |    2 2 4         4 2    2 6
+--R                |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                |108a c  |----------------------------  - a e  + 3c d e
+--R                |        |                5 3
+--R           +-+  |       \|          11664a c
+--R         2\|3   |------------------------------------------------------
+--R               3|                            2 2
+--R               \|                        216a c
+--R      *
+--R         atan
+--R                               +----------------------------+
+--R                               |    2 2 4         4 2    2 6
+--R                      4 2  +-+ |- 9a d e  + 6a c d e  - c d
+--R                  324a c e\|3  |----------------------------
+--R                               |                5 3
+--R                              \|          11664a c
+--R                + 
+--R                       2   2 2       2 4  +-+
+--R                  (- 9a c d e  + 3a c d )\|3
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        +----------------------------+
+--R                 |        |    2 2 4         4 2    2 6
+--R                 |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                 |108a c  |----------------------------  - a e  + 3c d e
+--R                 |        |                5 3
+--R                 |       \|          11664a c
+--R                 |------------------------------------------------------
+--R                3|                            2 2
+--R                \|                        216a c
+--R           /
+--R                               +----------------------------+
+--R                               |    2 2 4         4 2    2 6
+--R                          4 2  |- 9a d e  + 6a c d e  - c d       2   2 2
+--R                      324a c e |----------------------------  - 9a c d e
+--R                               |                5 3
+--R                              \|          11664a c
+--R                    + 
+--R                          2 4
+--R                      3a c d
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |        +----------------------------+
+--R                   |        |    2 2 4         4 2    2 6
+--R                   |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                   |108a c  |----------------------------  - a e  + 3c d e
+--R                   |        |                5 3
+--R                   |       \|          11664a c
+--R                   |------------------------------------------------------
+--R                  3|                            2 2
+--R                  \|                        216a c
+--R              + 
+--R                   2   4         3 2    2 5
+--R                (3a d e  + 2a c d e  - c d )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 345
+
+--S 346 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R              +-+6+---+5 3+-+2
+--R            6\|3 \|- a   \|c
+--R         *
+--R             +--------------------------------------------------------+
+--R             |          +----------------------------+
+--R             |          |    2 2 4         4 2    2 6
+--R             |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R             |- 108a c  |----------------------------  - a e  + 3c d e
+--R             |          |                5 3
+--R             |         \|          11664a c
+--R             |--------------------------------------------------------
+--R            3|                             2 2
+--R            \|                         216a c
+--R         *
+--R            log
+--R                                 +----------------------------+
+--R                                 |    2 2 4         4 2    2 6
+--R                          5 3    |- 9a d e  + 6a c d e  - c d         4     4
+--R                     7776a c d e |----------------------------  - 108a c d e
+--R                                 |                5 3
+--R                                \|          11664a c
+--R                   + 
+--R                         3 2 3 2      2 3 5
+--R                     144a c d e  - 36a c d
+--R                *
+--R                    +--------------------------------------------------------+2
+--R                    |          +----------------------------+
+--R                    |          |    2 2 4         4 2    2 6
+--R                    |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                    |- 108a c  |----------------------------  - a e  + 3c d e
+--R                    |          |                5 3
+--R                    |         \|          11664a c
+--R                    |--------------------------------------------------------
+--R                   3|                             2 2
+--R                   \|                         216a c
+--R               + 
+--R                                                 +----------------------------+
+--R                                                 |    2 2 4         4 2    2 6
+--R                            5 2 3       4 3 2    |- 9a d e  + 6a c d e  - c d
+--R                     (- 648a c e  - 648a c d e)x |----------------------------
+--R                                                 |                5 3
+--R                                                \|          11664a c
+--R                   + 
+--R                           3   2 4      2 2 4 2       3 6
+--R                     (- 18a c d e  - 12a c d e  + 6a c d )x
+--R                *
+--R                    +--------------------------------------------------------+
+--R                    |          +----------------------------+
+--R                    |          |    2 2 4         4 2    2 6
+--R                    |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                    |- 108a c  |----------------------------  - a e  + 3c d e
+--R                    |          |                5 3
+--R                    |         \|          11664a c
+--R                    |--------------------------------------------------------
+--R                   3|                             2 2
+--R                   \|                         216a c
+--R               + 
+--R                    3   6     2   3 4      2 5 2    3 7  2
+--R                 (3a d e  + 5a c d e  + a c d e  - c d )x
+--R     + 
+--R            +-+6+---+5 3+-+2
+--R         12\|3 \|- a   \|c
+--R      *
+--R          +--------------------------------------------------------+
+--R          |          +----------------------------+
+--R          |          |    2 2 4         4 2    2 6
+--R          |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R          |- 108a c  |----------------------------  - a e  + 3c d e
+--R          |          |                5 3
+--R          |         \|          11664a c
+--R          |--------------------------------------------------------
+--R         3|                             2 2
+--R         \|                         216a c
+--R      *
+--R         log
+--R                          +----------------------------+
+--R                          |    2 2 4         4 2    2 6
+--R                     4 2  |- 9a d e  + 6a c d e  - c d        2   2 2       2 4
+--R                (648a c e |----------------------------  + 18a c d e  - 6a c d )
+--R                          |                5 3
+--R                         \|          11664a c
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |          +----------------------------+
+--R                 |          |    2 2 4         4 2    2 6
+--R                 |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                 |- 108a c  |----------------------------  - a e  + 3c d e
+--R                 |          |                5 3
+--R                 |         \|          11664a c
+--R                 |--------------------------------------------------------
+--R                3|                             2 2
+--R                \|                         216a c
+--R            + 
+--R                 2   4         3 2    2 5
+--R              (3a d e  + 2a c d e  - c d )x
+--R     + 
+--R            +-+6+---+5 3+-+2
+--R         12\|3 \|- a   \|c
+--R      *
+--R          +------------------------------------------------------+
+--R          |        +----------------------------+
+--R          |        |    2 2 4         4 2    2 6
+--R          |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R          |108a c  |----------------------------  - a e  + 3c d e
+--R          |        |                5 3
+--R          |       \|          11664a c
+--R          |------------------------------------------------------
+--R         3|                            2 2
+--R         \|                        216a c
+--R      *
+--R         log
+--R                               +----------------------------+
+--R                               |    2 2 4         4 2    2 6
+--R                          4 2  |- 9a d e  + 6a c d e  - c d        2   2 2
+--R                    - 648a c e |----------------------------  + 18a c d e
+--R                               |                5 3
+--R                              \|          11664a c
+--R                  + 
+--R                          2 4
+--R                    - 6a c d
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        +----------------------------+
+--R                 |        |    2 2 4         4 2    2 6
+--R                 |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                 |108a c  |----------------------------  - a e  + 3c d e
+--R                 |        |                5 3
+--R                 |       \|          11664a c
+--R                 |------------------------------------------------------
+--R                3|                            2 2
+--R                \|                        216a c
+--R            + 
+--R                 2   4         3 2    2 5
+--R              (3a d e  + 2a c d e  - c d )x
+--R     + 
+--R       -
+--R              +-+6+---+5 3+-+2
+--R            6\|3 \|- a   \|c
+--R         *
+--R             +------------------------------------------------------+
+--R             |        +----------------------------+
+--R             |        |    2 2 4         4 2    2 6
+--R             |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R             |108a c  |----------------------------  - a e  + 3c d e
+--R             |        |                5 3
+--R             |       \|          11664a c
+--R             |------------------------------------------------------
+--R            3|                            2 2
+--R            \|                        216a c
+--R         *
+--R            log
+--R                                   +----------------------------+
+--R                                   |    2 2 4         4 2    2 6
+--R                            5 3    |- 9a d e  + 6a c d e  - c d         4     4
+--R                     - 7776a c d e |----------------------------  - 108a c d e
+--R                                   |                5 3
+--R                                  \|          11664a c
+--R                   + 
+--R                         3 2 3 2      2 3 5
+--R                     144a c d e  - 36a c d
+--R                *
+--R                    +------------------------------------------------------+2
+--R                    |        +----------------------------+
+--R                    |        |    2 2 4         4 2    2 6
+--R                    |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                    |108a c  |----------------------------  - a e  + 3c d e
+--R                    |        |                5 3
+--R                    |       \|          11664a c
+--R                    |------------------------------------------------------
+--R                   3|                            2 2
+--R                   \|                        216a c
+--R               + 
+--R                                               +----------------------------+
+--R                                               |    2 2 4         4 2    2 6
+--R                          5 2 3       4 3 2    |- 9a d e  + 6a c d e  - c d
+--R                     (648a c e  + 648a c d e)x |----------------------------
+--R                                               |                5 3
+--R                                              \|          11664a c
+--R                   + 
+--R                           3   2 4      2 2 4 2       3 6
+--R                     (- 18a c d e  - 12a c d e  + 6a c d )x
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |        +----------------------------+
+--R                    |        |    2 2 4         4 2    2 6
+--R                    |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                    |108a c  |----------------------------  - a e  + 3c d e
+--R                    |        |                5 3
+--R                    |       \|          11664a c
+--R                    |------------------------------------------------------
+--R                   3|                            2 2
+--R                   \|                        216a c
+--R               + 
+--R                    3   6     2   3 4      2 5 2    3 7  2
+--R                 (3a d e  + 5a c d e  + a c d e  - c d )x
+--R     + 
+--R           6+---+5 3+-+2
+--R         36\|- a   \|c
+--R      *
+--R          +--------------------------------------------------------+
+--R          |          +----------------------------+
+--R          |          |    2 2 4         4 2    2 6
+--R          |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R          |- 108a c  |----------------------------  - a e  + 3c d e
+--R          |          |                5 3
+--R          |         \|          11664a c
+--R          |--------------------------------------------------------
+--R         3|                             2 2
+--R         \|                         216a c
+--R      *
+--R         atan
+--R                               +----------------------------+
+--R                               |    2 2 4         4 2    2 6
+--R                      4 2  +-+ |- 9a d e  + 6a c d e  - c d
+--R                  324a c e\|3  |----------------------------
+--R                               |                5 3
+--R                              \|          11664a c
+--R                + 
+--R                     2   2 2       2 4  +-+
+--R                  (9a c d e  - 3a c d )\|3
+--R             *
+--R                 +--------------------------------------------------------+
+--R                 |          +----------------------------+
+--R                 |          |    2 2 4         4 2    2 6
+--R                 |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                 |- 108a c  |----------------------------  - a e  + 3c d e
+--R                 |          |                5 3
+--R                 |         \|          11664a c
+--R                 |--------------------------------------------------------
+--R                3|                             2 2
+--R                \|                         216a c
+--R           /
+--R                               +----------------------------+
+--R                               |    2 2 4         4 2    2 6
+--R                          4 2  |- 9a d e  + 6a c d e  - c d       2   2 2
+--R                      324a c e |----------------------------  + 9a c d e
+--R                               |                5 3
+--R                              \|          11664a c
+--R                    + 
+--R                            2 4
+--R                      - 3a c d
+--R               *
+--R                   +--------------------------------------------------------+
+--R                   |          +----------------------------+
+--R                   |          |    2 2 4         4 2    2 6
+--R                   |      2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                   |- 108a c  |----------------------------  - a e  + 3c d e
+--R                   |          |                5 3
+--R                   |         \|          11664a c
+--R                   |--------------------------------------------------------
+--R                  3|                             2 2
+--R                  \|                         216a c
+--R              + 
+--R                     2   4         3 2    2 5
+--R                (- 3a d e  - 2a c d e  + c d )x
+--R     + 
+--R                          +------------------------------------------------------+
+--R                          |        +----------------------------+
+--R                          |        |    2 2 4         4 2    2 6
+--R                          |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                          |108a c  |----------------------------  - a e  + 3c d e
+--R                          |        |                5 3
+--R           6+---+5 3+-+2  |       \|          11664a c
+--R         36\|- a   \|c    |------------------------------------------------------
+--R                         3|                            2 2
+--R                         \|                        216a c
+--R      *
+--R         atan
+--R                               +----------------------------+
+--R                               |    2 2 4         4 2    2 6
+--R                      4 2  +-+ |- 9a d e  + 6a c d e  - c d
+--R                  324a c e\|3  |----------------------------
+--R                               |                5 3
+--R                              \|          11664a c
+--R                + 
+--R                       2   2 2       2 4  +-+
+--R                  (- 9a c d e  + 3a c d )\|3
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        +----------------------------+
+--R                 |        |    2 2 4         4 2    2 6
+--R                 |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                 |108a c  |----------------------------  - a e  + 3c d e
+--R                 |        |                5 3
+--R                 |       \|          11664a c
+--R                 |------------------------------------------------------
+--R                3|                            2 2
+--R                \|                        216a c
+--R           /
+--R                               +----------------------------+
+--R                               |    2 2 4         4 2    2 6
+--R                          4 2  |- 9a d e  + 6a c d e  - c d       2   2 2
+--R                      324a c e |----------------------------  - 9a c d e
+--R                               |                5 3
+--R                              \|          11664a c
+--R                    + 
+--R                          2 4
+--R                      3a c d
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |        +----------------------------+
+--R                   |        |    2 2 4         4 2    2 6
+--R                   |    2 2 |- 9a d e  + 6a c d e  - c d        3       2
+--R                   |108a c  |----------------------------  - a e  + 3c d e
+--R                   |        |                5 3
+--R                   |       \|          11664a c
+--R                   |------------------------------------------------------
+--R                  3|                            2 2
+--R                  \|                        216a c
+--R              + 
+--R                   2   4         3 2    2 5
+--R                (3a d e  + 2a c d e  - c d )x
+--R     + 
+--R          +-+ +-+     +-+ +---+      6+---+6+-+    2 3+-+  3+---+
+--R       (d\|3 \|c  + e\|3 \|- a )log(x\|- a \|c  + x  \|c + \|- a )
+--R     + 
+--R           +-+ +-+      +-+ +---+      6+-+   6+---+
+--R       (2d\|3 \|c  - 2e\|3 \|- a )log(x\|c  + \|- a )
+--R     + 
+--R             +-+ +-+      +-+ +---+        6+-+   6+---+
+--R       (- 2d\|3 \|c  - 2e\|3 \|- a )log(- x\|c  + \|- a )
+--R     + 
+--R            +-+ +-+     +-+ +---+        6+---+6+-+    2 3+-+  3+---+
+--R       (- d\|3 \|c  + e\|3 \|- a )log(- x\|- a \|c  + x  \|c + \|- a )
+--R     + 
+--R                                 6+-+   6+---+
+--R           +-+      +---+      2x\|c  + \|- a
+--R       (6d\|c  + 6e\|- a )atan(---------------)
+--R                                   +-+6+---+
+--R                                  \|3 \|- a
+--R     + 
+--R                                 6+-+   6+---+
+--R           +-+      +---+      2x\|c  - \|- a
+--R       (6d\|c  - 6e\|- a )atan(---------------)
+--R                                   +-+6+---+
+--R                                  \|3 \|- a
+--R  /
+--R        +-+6+---+5 3+-+2
+--R     12\|3 \|- a   \|c
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  4 6+---+4       4 3+---+2 +-+3+-+2          8 +-+3+-+
+--R           (2a d x  \|- a  + a d x  \|- a )\|c \|c   + a c d x \|c \|c
+--R         + 
+--R                   6 3+---+ +-+
+--R           2a c d x  \|- a \|c
+--R      *
+--R         6+-+5
+--R         \|c
+--R     + 
+--R                   3 +---+6+---+5         3 +---+3+---+2 6+---+3+-+2
+--R           (- a e x \|- a \|- a   - 5a e x \|- a \|- a   \|- a)\|c
+--R         + 
+--R                     7 +---+6+---+3+-+            5 +---+3+---+6+---+
+--R           - 5a c e x \|- a \|- a \|c  - 10a c e x \|- a \|- a \|- a
+--R      *
+--R         6+-+4
+--R         \|c
+--R     + 
+--R                    2 3+---+2 6+---+2   2   2  +-+3+-+2
+--R           (- 2a d x  \|- a   \|- a - 5a d x )\|c \|c
+--R         + 
+--R                     6 6+---+2 +-+3+-+          4 3+---+6+---+2 +-+
+--R           - 2a c d x  \|- a  \|c \|c - 4a c d x  \|- a \|- a  \|c
+--R      *
+--R         6+-+3
+--R         \|c
+--R     + 
+--R                  +---+3+---+2 6+---+3          7    2     +---+6+---+ 3+-+2
+--R           (a e x\|- a \|- a   \|- a  + (a c e x  - a e x)\|- a \|- a )\|c
+--R         + 
+--R                   5 +---+6+---+3     2     5     2     2 3+-+
+--R           (a c e x \|- a \|- a   + 6a c e x  + 6a c d x )\|c
+--R         + 
+--R                   3 +---+3+---+6+---+3
+--R           2a c e x \|- a \|- a \|- a
+--R      *
+--R         6+-+2
+--R         \|c
+--R     + 
+--R                     3+---+2 6+---+4         6 6+---+2          6    2  3+---+
+--R             (- 5a d \|- a   \|- a  - a c d x  \|- a  + (a c d x  + a d)\|- a )
+--R          *
+--R              +-+3+-+2
+--R             \|c \|c
+--R         + 
+--R                     4 6+---+4 +-+3+-+
+--R           - 5a c d x  \|- a  \|c \|c
+--R         + 
+--R                       2 3+---+6+---+4     2   8    2     2  +-+
+--R           (- 10a c d x  \|- a \|- a  - a c d x  - a c d x )\|c
+--R      *
+--R         6+-+
+--R         \|c
+--R     + 
+--R                 5 +---+3+---+2 6+---+5            5            2 3+---+6+---+4
+--R           2c e x \|- a \|- a   \|- a  + (12a c e x  + 12a c d x )\|- a \|- a
+--R         + 
+--R                   5 +---+6+---+3
+--R           5a c e x \|- a \|- a
+--R      *
+--R         3+-+2
+--R         \|c
+--R     + 
+--R                  3 +---+6+---+5            3          3+---+2 6+---+43+-+
+--R       (- 2a c e x \|- a \|- a   + (6a c e x  + 6a c d)\|- a   \|- a )\|c
+--R     + 
+--R          2   7             +---+3+---+6+---+5        2   7       2   4 6+---+4
+--R       (2c e x  - 2a c e x)\|- a \|- a \|- a   + (6a c e x  + 6a c d x )\|- a
+--R  /
+--R          2 2 8     3   2 3+-+6+-+2         2 8      2   2 3+---+6+---+4 3+-+2
+--R       (6a c x  + 6a c x )\|c \|c   + (12a c x  + 12a c x )\|- a \|- a   \|c
+--R     + 
+--R            2 6     2  3+---+2 6+---+4 3+-+      3 10     2 2 4 6+---+4
+--R       (6a c x  + 6a c)\|- a   \|- a   \| + (6a c x   + 6a c x )\|- a
+--R                                                    Type: Expression(Integer)
+--E 347
+
+)clear all
+
+--S 348 of 649
+t0:=(d+e*x^4)/(a+c*x^8)
+--R 
+--R
+--R           4
+--R        e x  + d
+--R   (1)  --------
+--R           8
+--R        c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 348
+
+--S 349 of 649
+r0a:=-1/4*atan(2^(1/4)*c^(1/8)*x/sqrt(-a^(1/4)+sqrt(-sqrt(a))))*_
+   (-e*sqrt(a)+d*sqrt(c)+a^(1/4)*(e*sqrt(a)+d*sqrt(c))/sqrt(-sqrt(a)))/_
+   (2^(1/4)*a^(3/4)*c^(5/8)*sqrt(-a^(1/4)+sqrt(-sqrt(a))))-_
+   1/4*atanh(2^(1/4)*c^(1/8)*x/sqrt(-a^(1/4)+sqrt(-sqrt(a))))*_
+   (-e*sqrt(a)+d*sqrt(c)+a^(1/4)*(e*sqrt(a)+d*sqrt(c))/sqrt(-sqrt(a)))/_
+   (2^(1/4)*a^(3/4)*c^(5/8)*sqrt(-a^(1/4)+sqrt(-sqrt(a))))+_
+   1/4*atan(2^(1/4)*c^(1/8)*x/sqrt(a^(1/4)+sqrt(-sqrt(a))))*_
+   (-e*sqrt(a)+d*sqrt(c)-a^(1/4)*(e*sqrt(a)+d*sqrt(c))/sqrt(-sqrt(a)))/_
+   (2^(1/4)*a^(3/4)*c^(5/8)*sqrt(a^(1/4)+sqrt(-sqrt(a))))+_
+   1/4*atanh(2^(1/4)*c^(1/8)*x/sqrt(a^(1/4)+sqrt(-sqrt(a))))*_
+   (-e*sqrt(a)+d*sqrt(c)-a^(1/4)*(e*sqrt(a)+d*sqrt(c))/sqrt(-sqrt(a)))/_
+   (2^(1/4)*a^(3/4)*c^(5/8)*sqrt(a^(1/4)+sqrt(-sqrt(a))))
+--R 
+--R
+--R   (2)
+--R                                                              +----------------+
+--R                            +------+                          | +------+
+--R               +-+     +-+  |   +-+     4+-+ +-+     +-+4+-+  | |   +-+    4+-+
+--R         ((- d\|c  + e\|a )\|- \|a   - d\|a \|c  - e\|a \|a )\|\|- \|a   + \|a
+--R      *
+--R                     4+-+8+-+
+--R                    x\|2 \|c
+--R         atanh(-------------------)
+--R                +----------------+
+--R                | +------+
+--R                | |   +-+    4+-+
+--R               \|\|- \|a   - \|a
+--R     + 
+--R                                                            +----------------+
+--R                          +------+                          | +------+
+--R             +-+     +-+  |   +-+     4+-+ +-+     +-+4+-+  | |   +-+    4+-+
+--R         ((d\|c  - e\|a )\|- \|a   - d\|a \|c  - e\|a \|a )\|\|- \|a   - \|a
+--R      *
+--R                     4+-+8+-+
+--R                    x\|2 \|c
+--R         atanh(-------------------)
+--R                +----------------+
+--R                | +------+
+--R                | |   +-+    4+-+
+--R               \|\|- \|a   + \|a
+--R     + 
+--R                                                              +----------------+
+--R                            +------+                          | +------+
+--R               +-+     +-+  |   +-+     4+-+ +-+     +-+4+-+  | |   +-+    4+-+
+--R         ((- d\|c  + e\|a )\|- \|a   - d\|a \|c  - e\|a \|a )\|\|- \|a   + \|a
+--R      *
+--R                    4+-+8+-+
+--R                   x\|2 \|c
+--R         atan(-------------------)
+--R               +----------------+
+--R               | +------+
+--R               | |   +-+    4+-+
+--R              \|\|- \|a   - \|a
+--R     + 
+--R                                                            +----------------+
+--R                          +------+                          | +------+
+--R             +-+     +-+  |   +-+     4+-+ +-+     +-+4+-+  | |   +-+    4+-+
+--R         ((d\|c  - e\|a )\|- \|a   - d\|a \|c  - e\|a \|a )\|\|- \|a   - \|a
+--R      *
+--R                    4+-+8+-+
+--R                   x\|2 \|c
+--R         atan(-------------------)
+--R               +----------------+
+--R               | +------+
+--R               | |   +-+    4+-+
+--R              \|\|- \|a   + \|a
+--R  /
+--R                               +----------------+ +----------------+
+--R                      +------+ | +------+         | +------+
+--R      4+-+4+-+3 8+-+5 |   +-+  | |   +-+    4+-+  | |   +-+    4+-+
+--R     4\|2 \|a   \|c  \|- \|a  \|\|- \|a   - \|a  \|\|- \|a   + \|a
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 649
+r0b:=-1/8*(-1)^(3/4)*log((-a)^(1/8)-(-1)^(1/4)*c^(1/8)*x)*(-e*sqrt(-a)+_
+   d*sqrt(c))/((-a)^(7/8)*c^(5/8))+1/8*(-1)^(3/4)*log((-a)^(1/8)+_
+   (-1)^(1/4)*c^(1/8)*x)*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(7/8)*c^(5/8))-_
+   1/8*(-1)^(1/4)*log((-a)^(1/8)-(-1)^(3/4)*c^(1/8)*x)*(-e*sqrt(-a)+_
+   d*sqrt(c))/((-a)^(7/8)*c^(5/8))+1/8*(-1)^(1/4)*log((-a)^(1/8)+_
+   (-1)^(3/4)*c^(1/8)*x)*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(7/8)*c^(5/8))+_
+   1/8*log((-a)^(1/8)-c^(1/8)*x)*(e*sqrt(-a)+d*sqrt(c))/((-a)^(7/8)*_
+   c^(5/8))-1/8*%i*log((-a)^(1/8)-%i*c^(1/8)*x)*(e*sqrt(-a)+d*sqrt(c))/_
+   ((-a)^(7/8)*c^(5/8))+1/8*%i*log((-a)^(1/8)+%i*c^(1/8)*x)*(e*sqrt(-a)+_
+   d*sqrt(c))/((-a)^(7/8)*c^(5/8))-1/8*log((-a)^(1/8)+c^(1/8)*x)*_
+   (e*sqrt(-a)+d*sqrt(c))/((-a)^(7/8)*c^(5/8))
+--R 
+--R
+--R   (3)
+--R          1   +-+ +-+   1   +-+ +---+      8+-+   8+---+
+--R       (- - d\|2 \|c  - - e\|2 \|- a )log(x\|c  + \|- a )
+--R          8             8
+--R     + 
+--R        1      +-+ +-+   1      +-+ +---+         8+-+   8+---+
+--R       (- %i d\|2 \|c  + - %i e\|2 \|- a )log(%i x\|c  + \|- a )
+--R        8                8
+--R     + 
+--R                                                           8+-+    +-+8+---+
+--R           1   1      +-+    1   1      +---+     (1 + %i)x\|c  + \|2 \|- a
+--R       ((- - + - %i)d\|c  + (- - - %i)e\|- a )log(--------------------------)
+--R           8   8             8   8                            +-+
+--R                                                             \|2
+--R     + 
+--R                                                           8+-+    +-+8+---+
+--R           1   1      +-+    1   1      +---+     (1 - %i)x\|c  + \|2 \|- a
+--R       ((- - - - %i)d\|c  + (- + - %i)e\|- a )log(--------------------------)
+--R           8   8             8   8                            +-+
+--R                                                             \|2
+--R     + 
+--R                                                             8+-+    +-+8+---+
+--R         1   1      +-+      1   1      +---+     (- 1 + %i)x\|c  + \|2 \|- a
+--R       ((- + - %i)d\|c  + (- - - - %i)e\|- a )log(----------------------------)
+--R         8   8               8   8                             +-+
+--R                                                              \|2
+--R     + 
+--R                                                             8+-+    +-+8+---+
+--R         1   1      +-+      1   1      +---+     (- 1 - %i)x\|c  + \|2 \|- a
+--R       ((- - - %i)d\|c  + (- - + - %i)e\|- a )log(----------------------------)
+--R         8   8               8   8                             +-+
+--R                                                              \|2
+--R     + 
+--R          1      +-+ +-+   1      +-+ +---+           8+-+   8+---+
+--R       (- - %i d\|2 \|c  - - %i e\|2 \|- a )log(- %i x\|c  + \|- a )
+--R          8                8
+--R     + 
+--R        1   +-+ +-+   1   +-+ +---+        8+-+   8+---+
+--R       (- d\|2 \|c  + - e\|2 \|- a )log(- x\|c  + \|- a )
+--R        8             8
+--R  /
+--R      +-+8+---+7 8+-+5
+--R     \|2 \|- a   \|c
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 350
+
+--S 351 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                              3 2
+--R                          512a c
+--R                       *
+--R                         +----------------------------------------------------+
+--R                         |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                         |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                         |----------------------------------------------------
+--R                         |                             7 5
+--R                        \|                     4194304a c
+--R                      + 
+--R                             3      3
+--R                        a d e  - c d e
+--R                   /
+--R                          3 2
+--R                      256a c
+--R         *
+--R            log
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                        +----------------------------------------------------+
+--R                        |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                        |----------------------------------------------------
+--R                        |                             7 5
+--R                       \|                     4194304a c
+--R                   + 
+--R                         3     4      2 2 3 2       3 5
+--R                     - 4a c d e  + 24a c d e  - 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                     3 2
+--R                                 512a c
+--R                              *
+--R                                 ROOT
+--R                                           4 8      3   2 6      2 2 4 4
+--R                                        - a e  + 12a c d e  - 38a c d e
+--R                                      + 
+--R                                             3 6 2    4 8
+--R                                        12a c d e  - c d
+--R                                   /
+--R                                              7 5
+--R                                      4194304a c
+--R                             + 
+--R                                    3      3
+--R                               a d e  - c d e
+--R                          /
+--R                                 3 2
+--R                             256a c
+--R               + 
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                     -
+--R                              3 2
+--R                          512a c
+--R                       *
+--R                         +----------------------------------------------------+
+--R                         |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                         |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                         |----------------------------------------------------
+--R                         |                             7 5
+--R                        \|                     4194304a c
+--R                   + 
+--R                          3      3
+--R                     a d e  - c d e
+--R                /
+--R                       3 2
+--R                   256a c
+--R      *
+--R         log
+--R                         5 3
+--R                    8192a c e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                     |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                     |----------------------------------------------------
+--R                     |                             7 5
+--R                    \|                     4194304a c
+--R                + 
+--R                    3     4      2 2 3 2       3 5
+--R                  4a c d e  - 24a c d e  + 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                            -
+--R                                     3 2
+--R                                 512a c
+--R                              *
+--R                                 ROOT
+--R                                           4 8      3   2 6      2 2 4 4
+--R                                        - a e  + 12a c d e  - 38a c d e
+--R                                      + 
+--R                                             3 6 2    4 8
+--R                                        12a c d e  - c d
+--R                                   /
+--R                                              7 5
+--R                                      4194304a c
+--R                          + 
+--R                                 3      3
+--R                            a d e  - c d e
+--R                       /
+--R                              3 2
+--R                          256a c
+--R            + 
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                        -
+--R                                 3 2
+--R                             512a c
+--R                          *
+--R                             ROOT
+--R                                       4 8      3   2 6      2 2 4 4
+--R                                    - a e  + 12a c d e  - 38a c d e
+--R                                  + 
+--R                                         3 6 2    4 8
+--R                                    12a c d e  - c d
+--R                               /
+--R                                          7 5
+--R                                  4194304a c
+--R                      + 
+--R                             3      3
+--R                        a d e  - c d e
+--R                   /
+--R                          3 2
+--R                      256a c
+--R         *
+--R            log
+--R                     -
+--R                               5 3
+--R                          8192a c e
+--R                       *
+--R                         +----------------------------------------------------+
+--R                         |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                         |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                         |----------------------------------------------------
+--R                         |                             7 5
+--R                        \|                     4194304a c
+--R                   + 
+--R                         3     4      2 2 3 2       3 5
+--R                     - 4a c d e  + 24a c d e  - 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                               -
+--R                                        3 2
+--R                                    512a c
+--R                                 *
+--R                                    ROOT
+--R                                              4 8      3   2 6      2 2 4 4
+--R                                           - a e  + 12a c d e  - 38a c d e
+--R                                         + 
+--R                                                3 6 2    4 8
+--R                                           12a c d e  - c d
+--R                                      /
+--R                                                 7 5
+--R                                         4194304a c
+--R                             + 
+--R                                    3      3
+--R                               a d e  - c d e
+--R                          /
+--R                                 3 2
+--R                             256a c
+--R               + 
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           3 2
+--R                       512a c
+--R                    *
+--R                        +----------------------------------------------------+
+--R                        |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                        |----------------------------------------------------
+--R                        |                             7 5
+--R                       \|                     4194304a c
+--R                   + 
+--R                          3      3
+--R                     a d e  - c d e
+--R                /
+--R                       3 2
+--R                   256a c
+--R      *
+--R         log
+--R                  -
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                        +----------------------------------------------------+
+--R                        |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                        |----------------------------------------------------
+--R                        |                             7 5
+--R                       \|                     4194304a c
+--R                + 
+--R                    3     4      2 2 3 2       3 5
+--R                  4a c d e  - 24a c d e  + 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                  3 2
+--R                              512a c
+--R                           *
+--R                              ROOT
+--R                                        4 8      3   2 6      2 2 4 4
+--R                                     - a e  + 12a c d e  - 38a c d e
+--R                                   + 
+--R                                          3 6 2    4 8
+--R                                     12a c d e  - c d
+--R                                /
+--R                                           7 5
+--R                                   4194304a c
+--R                          + 
+--R                                 3      3
+--R                            a d e  - c d e
+--R                       /
+--R                              3 2
+--R                          256a c
+--R            + 
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           3 2
+--R                       512a c
+--R                    *
+--R                        +----------------------------------------------------+
+--R                        |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                        |----------------------------------------------------
+--R                        |                             7 5
+--R                       \|                     4194304a c
+--R                   + 
+--R                          3      3
+--R                     a d e  - c d e
+--R                /
+--R                       3 2
+--R                   256a c
+--R      *
+--R         atan
+--R                         5 3
+--R                    8192a c e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                     |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                     |----------------------------------------------------
+--R                     |                             7 5
+--R                    \|                     4194304a c
+--R                + 
+--R                      3     4      2 2 3 2       3 5
+--R                  - 4a c d e  + 24a c d e  - 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                  3 2
+--R                              512a c
+--R                           *
+--R                              ROOT
+--R                                        4 8      3   2 6      2 2 4 4
+--R                                     - a e  + 12a c d e  - 38a c d e
+--R                                   + 
+--R                                          3 6 2    4 8
+--R                                     12a c d e  - c d
+--R                                /
+--R                                           7 5
+--R                                   4194304a c
+--R                          + 
+--R                                 3      3
+--R                            a d e  - c d e
+--R                       /
+--R                              3 2
+--R                          256a c
+--R           /
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                        -
+--R                                 3 2
+--R                             512a c
+--R                          *
+--R                             ROOT
+--R                                       4 8      3   2 6      2 2 4 4
+--R                                    - a e  + 12a c d e  - 38a c d e
+--R                                  + 
+--R                                         3 6 2    4 8
+--R                                    12a c d e  - c d
+--R                               /
+--R                                          7 5
+--R                                  4194304a c
+--R                      + 
+--R                             3      3
+--R                        a d e  - c d e
+--R                   /
+--R                          3 2
+--R                      256a c
+--R         *
+--R            atan
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                        +----------------------------------------------------+
+--R                        |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                        |----------------------------------------------------
+--R                        |                             7 5
+--R                       \|                     4194304a c
+--R                   + 
+--R                       3     4      2 2 3 2       3 5
+--R                     4a c d e  - 24a c d e  + 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                               -
+--R                                        3 2
+--R                                    512a c
+--R                                 *
+--R                                    ROOT
+--R                                              4 8      3   2 6      2 2 4 4
+--R                                           - a e  + 12a c d e  - 38a c d e
+--R                                         + 
+--R                                                3 6 2    4 8
+--R                                           12a c d e  - c d
+--R                                      /
+--R                                                 7 5
+--R                                         4194304a c
+--R                             + 
+--R                                    3      3
+--R                               a d e  - c d e
+--R                          /
+--R                                 3 2
+--R                             256a c
+--R              /
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  - 5a c d e  - 5a c d e  + c d )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 351
+
+--S 352 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R       -
+--R                                      +----------------+ +----------------+
+--R                             +------+ | +------+         | +------+
+--R             4+-+4+-+3 8+-+5 |   +-+  | |   +-+    4+-+  | |   +-+    4+-+
+--R            2\|2 \|a   \|c  \|- \|a  \|\|- \|a   - \|a  \|\|- \|a   + \|a
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                              3 2
+--R                          512a c
+--R                       *
+--R                         +----------------------------------------------------+
+--R                         |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                         |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                         |----------------------------------------------------
+--R                         |                             7 5
+--R                        \|                     4194304a c
+--R                      + 
+--R                             3      3
+--R                        a d e  - c d e
+--R                   /
+--R                          3 2
+--R                      256a c
+--R         *
+--R            log
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                        +----------------------------------------------------+
+--R                        |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                        |----------------------------------------------------
+--R                        |                             7 5
+--R                       \|                     4194304a c
+--R                   + 
+--R                         3     4      2 2 3 2       3 5
+--R                     - 4a c d e  + 24a c d e  - 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                     3 2
+--R                                 512a c
+--R                              *
+--R                                 ROOT
+--R                                           4 8      3   2 6      2 2 4 4
+--R                                        - a e  + 12a c d e  - 38a c d e
+--R                                      + 
+--R                                             3 6 2    4 8
+--R                                        12a c d e  - c d
+--R                                   /
+--R                                              7 5
+--R                                      4194304a c
+--R                             + 
+--R                                    3      3
+--R                               a d e  - c d e
+--R                          /
+--R                                 3 2
+--R                             256a c
+--R               + 
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R                                   +----------------+ +----------------+
+--R                          +------+ | +------+         | +------+
+--R          4+-+4+-+3 8+-+5 |   +-+  | |   +-+    4+-+  | |   +-+    4+-+
+--R         2\|2 \|a   \|c  \|- \|a  \|\|- \|a   - \|a  \|\|- \|a   + \|a
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                     -
+--R                              3 2
+--R                          512a c
+--R                       *
+--R                         +----------------------------------------------------+
+--R                         |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                         |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                         |----------------------------------------------------
+--R                         |                             7 5
+--R                        \|                     4194304a c
+--R                   + 
+--R                          3      3
+--R                     a d e  - c d e
+--R                /
+--R                       3 2
+--R                   256a c
+--R      *
+--R         log
+--R                         5 3
+--R                    8192a c e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                     |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                     |----------------------------------------------------
+--R                     |                             7 5
+--R                    \|                     4194304a c
+--R                + 
+--R                    3     4      2 2 3 2       3 5
+--R                  4a c d e  - 24a c d e  + 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                            -
+--R                                     3 2
+--R                                 512a c
+--R                              *
+--R                                 ROOT
+--R                                           4 8      3   2 6      2 2 4 4
+--R                                        - a e  + 12a c d e  - 38a c d e
+--R                                      + 
+--R                                             3 6 2    4 8
+--R                                        12a c d e  - c d
+--R                                   /
+--R                                              7 5
+--R                                      4194304a c
+--R                          + 
+--R                                 3      3
+--R                            a d e  - c d e
+--R                       /
+--R                              3 2
+--R                          256a c
+--R            + 
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R       -
+--R                                      +----------------+ +----------------+
+--R                             +------+ | +------+         | +------+
+--R             4+-+4+-+3 8+-+5 |   +-+  | |   +-+    4+-+  | |   +-+    4+-+
+--R            2\|2 \|a   \|c  \|- \|a  \|\|- \|a   - \|a  \|\|- \|a   + \|a
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                        -
+--R                                 3 2
+--R                             512a c
+--R                          *
+--R                             ROOT
+--R                                       4 8      3   2 6      2 2 4 4
+--R                                    - a e  + 12a c d e  - 38a c d e
+--R                                  + 
+--R                                         3 6 2    4 8
+--R                                    12a c d e  - c d
+--R                               /
+--R                                          7 5
+--R                                  4194304a c
+--R                      + 
+--R                             3      3
+--R                        a d e  - c d e
+--R                   /
+--R                          3 2
+--R                      256a c
+--R         *
+--R            log
+--R                     -
+--R                               5 3
+--R                          8192a c e
+--R                       *
+--R                         +----------------------------------------------------+
+--R                         |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                         |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                         |----------------------------------------------------
+--R                         |                             7 5
+--R                        \|                     4194304a c
+--R                   + 
+--R                         3     4      2 2 3 2       3 5
+--R                     - 4a c d e  + 24a c d e  - 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                               -
+--R                                        3 2
+--R                                    512a c
+--R                                 *
+--R                                    ROOT
+--R                                              4 8      3   2 6      2 2 4 4
+--R                                           - a e  + 12a c d e  - 38a c d e
+--R                                         + 
+--R                                                3 6 2    4 8
+--R                                           12a c d e  - c d
+--R                                      /
+--R                                                 7 5
+--R                                         4194304a c
+--R                             + 
+--R                                    3      3
+--R                               a d e  - c d e
+--R                          /
+--R                                 3 2
+--R                             256a c
+--R               + 
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R                                   +----------------+ +----------------+
+--R                          +------+ | +------+         | +------+
+--R          4+-+4+-+3 8+-+5 |   +-+  | |   +-+    4+-+  | |   +-+    4+-+
+--R         2\|2 \|a   \|c  \|- \|a  \|\|- \|a   - \|a  \|\|- \|a   + \|a
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           3 2
+--R                       512a c
+--R                    *
+--R                        +----------------------------------------------------+
+--R                        |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                        |----------------------------------------------------
+--R                        |                             7 5
+--R                       \|                     4194304a c
+--R                   + 
+--R                          3      3
+--R                     a d e  - c d e
+--R                /
+--R                       3 2
+--R                   256a c
+--R      *
+--R         log
+--R                  -
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                        +----------------------------------------------------+
+--R                        |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                        |----------------------------------------------------
+--R                        |                             7 5
+--R                       \|                     4194304a c
+--R                + 
+--R                    3     4      2 2 3 2       3 5
+--R                  4a c d e  - 24a c d e  + 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                  3 2
+--R                              512a c
+--R                           *
+--R                              ROOT
+--R                                        4 8      3   2 6      2 2 4 4
+--R                                     - a e  + 12a c d e  - 38a c d e
+--R                                   + 
+--R                                          3 6 2    4 8
+--R                                     12a c d e  - c d
+--R                                /
+--R                                           7 5
+--R                                   4194304a c
+--R                          + 
+--R                                 3      3
+--R                            a d e  - c d e
+--R                       /
+--R                              3 2
+--R                          256a c
+--R            + 
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R                                                            +----------------+
+--R                          +------+                          | +------+
+--R             +-+     +-+  |   +-+     4+-+ +-+     +-+4+-+  | |   +-+    4+-+
+--R         ((d\|c  - e\|a )\|- \|a   + d\|a \|c  + e\|a \|a )\|\|- \|a   + \|a
+--R      *
+--R                     4+-+8+-+
+--R                    x\|2 \|c
+--R         atanh(-------------------)
+--R                +----------------+
+--R                | +------+
+--R                | |   +-+    4+-+
+--R               \|\|- \|a   - \|a
+--R     + 
+--R                                                              +----------------+
+--R                            +------+                          | +------+
+--R               +-+     +-+  |   +-+     4+-+ +-+     +-+4+-+  | |   +-+    4+-+
+--R         ((- d\|c  + e\|a )\|- \|a   + d\|a \|c  + e\|a \|a )\|\|- \|a   - \|a
+--R      *
+--R                     4+-+8+-+
+--R                    x\|2 \|c
+--R         atanh(-------------------)
+--R                +----------------+
+--R                | +------+
+--R                | |   +-+    4+-+
+--R               \|\|- \|a   + \|a
+--R     + 
+--R                                   +----------------+ +----------------+
+--R                          +------+ | +------+         | +------+
+--R          4+-+4+-+3 8+-+5 |   +-+  | |   +-+    4+-+  | |   +-+    4+-+
+--R         4\|2 \|a   \|c  \|- \|a  \|\|- \|a   - \|a  \|\|- \|a   + \|a
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           3 2
+--R                       512a c
+--R                    *
+--R                        +----------------------------------------------------+
+--R                        |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                        |----------------------------------------------------
+--R                        |                             7 5
+--R                       \|                     4194304a c
+--R                   + 
+--R                          3      3
+--R                     a d e  - c d e
+--R                /
+--R                       3 2
+--R                   256a c
+--R      *
+--R         atan
+--R                         5 3
+--R                    8192a c e
+--R                 *
+--R                     +----------------------------------------------------+
+--R                     |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                     |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                     |----------------------------------------------------
+--R                     |                             7 5
+--R                    \|                     4194304a c
+--R                + 
+--R                      3     4      2 2 3 2       3 5
+--R                  - 4a c d e  + 24a c d e  - 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                  3 2
+--R                              512a c
+--R                           *
+--R                              ROOT
+--R                                        4 8      3   2 6      2 2 4 4
+--R                                     - a e  + 12a c d e  - 38a c d e
+--R                                   + 
+--R                                          3 6 2    4 8
+--R                                     12a c d e  - c d
+--R                                /
+--R                                           7 5
+--R                                   4194304a c
+--R                          + 
+--R                                 3      3
+--R                            a d e  - c d e
+--R                       /
+--R                              3 2
+--R                          256a c
+--R           /
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R       -
+--R                                      +----------------+ +----------------+
+--R                             +------+ | +------+         | +------+
+--R             4+-+4+-+3 8+-+5 |   +-+  | |   +-+    4+-+  | |   +-+    4+-+
+--R            4\|2 \|a   \|c  \|- \|a  \|\|- \|a   - \|a  \|\|- \|a   + \|a
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                        -
+--R                                 3 2
+--R                             512a c
+--R                          *
+--R                             ROOT
+--R                                       4 8      3   2 6      2 2 4 4
+--R                                    - a e  + 12a c d e  - 38a c d e
+--R                                  + 
+--R                                         3 6 2    4 8
+--R                                    12a c d e  - c d
+--R                               /
+--R                                          7 5
+--R                                  4194304a c
+--R                      + 
+--R                             3      3
+--R                        a d e  - c d e
+--R                   /
+--R                          3 2
+--R                      256a c
+--R         *
+--R            atan
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                        +----------------------------------------------------+
+--R                        |   4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |- a e  + 12a c d e  - 38a c d e  + 12a c d e  - c d
+--R                        |----------------------------------------------------
+--R                        |                             7 5
+--R                       \|                     4194304a c
+--R                   + 
+--R                       3     4      2 2 3 2       3 5
+--R                     4a c d e  - 24a c d e  + 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                               -
+--R                                        3 2
+--R                                    512a c
+--R                                 *
+--R                                    ROOT
+--R                                              4 8      3   2 6      2 2 4 4
+--R                                           - a e  + 12a c d e  - 38a c d e
+--R                                         + 
+--R                                                3 6 2    4 8
+--R                                           12a c d e  - c d
+--R                                      /
+--R                                                 7 5
+--R                                         4194304a c
+--R                             + 
+--R                                    3      3
+--R                               a d e  - c d e
+--R                          /
+--R                                 3 2
+--R                             256a c
+--R              /
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R                                                            +----------------+
+--R                          +------+                          | +------+
+--R             +-+     +-+  |   +-+     4+-+ +-+     +-+4+-+  | |   +-+    4+-+
+--R         ((d\|c  - e\|a )\|- \|a   + d\|a \|c  + e\|a \|a )\|\|- \|a   + \|a
+--R      *
+--R                    4+-+8+-+
+--R                   x\|2 \|c
+--R         atan(-------------------)
+--R               +----------------+
+--R               | +------+
+--R               | |   +-+    4+-+
+--R              \|\|- \|a   - \|a
+--R     + 
+--R                                                              +----------------+
+--R                            +------+                          | +------+
+--R               +-+     +-+  |   +-+     4+-+ +-+     +-+4+-+  | |   +-+    4+-+
+--R         ((- d\|c  + e\|a )\|- \|a   + d\|a \|c  + e\|a \|a )\|\|- \|a   - \|a
+--R      *
+--R                    4+-+8+-+
+--R                   x\|2 \|c
+--R         atan(-------------------)
+--R               +----------------+
+--R               | +------+
+--R               | |   +-+    4+-+
+--R              \|\|- \|a   + \|a
+--R  /
+--R                               +----------------+ +----------------+
+--R                      +------+ | +------+         | +------+
+--R      4+-+4+-+3 8+-+5 |   +-+  | |   +-+    4+-+  | |   +-+    4+-+
+--R     4\|2 \|a   \|c  \|- \|a  \|\|- \|a   - \|a  \|\|- \|a   + \|a
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R                              +-+8+-+4
+--R                           2d\|c \|c   - 2c d
+--R   (6)  --------------------------------------------------------
+--R             4 4+-+2      4 +-+ 8+-+4     +-+4+-+2     2 8
+--R        (2c x  \|a  - 2c x \|a )\|c   - c\|a \|a   - 2c x  - a c
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 649
+m0b:=a0-r0b 
+--R 
+--R
+--R   (7)
+--R       -
+--R            1  +-+8+---+7 8+-+5
+--R            - \|2 \|- a   \|c
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                            3 2
+--R                          2a c
+--R                       *
+--R                          ROOT
+--R                                      1     4 8      3     3   2 6
+--R                                 - ------- a e  + ------- a c d e
+--R                                   4194304        1048576
+--R                               + 
+--R                                      19    2 2 4 4      3       3 6 2
+--R                                 - ------- a c d e  + ------- a c d e
+--R                                   2097152            1048576
+--R                               + 
+--R                                      1     4 8
+--R                                 - ------- c d
+--R                                   4194304
+--R                            /
+--R                                7 5
+--R                               a c
+--R                      + 
+--R                         1       3    1     3
+--R                        --- a d e  - --- c d e
+--R                        256          256
+--R                   /
+--R                       3 2
+--R                      a c
+--R         *
+--R            log
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                       ROOT
+--R                                   1     4 8      3     3   2 6
+--R                              - ------- a e  + ------- a c d e
+--R                                4194304        1048576
+--R                            + 
+--R                                 19    2 2 4 4      3       3 6 2      1     4 8
+--R                            - ------- a c d e  + ------- a c d e  - ------- c d
+--R                              2097152            1048576            4194304
+--R                         /
+--R                             7 5
+--R                            a c
+--R                   + 
+--R                         3     4      2 2 3 2       3 5
+--R                     - 4a c d e  + 24a c d e  - 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                   3 2
+--R                                 2a c
+--R                              *
+--R                                 ROOT
+--R                                             1     4 8      3     3   2 6
+--R                                        - ------- a e  + ------- a c d e
+--R                                          4194304        1048576
+--R                                      + 
+--R                                             19    2 2 4 4      3       3 6 2
+--R                                        - ------- a c d e  + ------- a c d e
+--R                                          2097152            1048576
+--R                                      + 
+--R                                             1     4 8
+--R                                        - ------- c d
+--R                                          4194304
+--R                                   /
+--R                                       7 5
+--R                                      a c
+--R                             + 
+--R                                1       3    1     3
+--R                               --- a d e  - --- c d e
+--R                               256          256
+--R                          /
+--R                              3 2
+--R                             a c
+--R               + 
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R         1  +-+8+---+7 8+-+5
+--R         - \|2 \|- a   \|c
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                     -
+--R                            3 2
+--R                          2a c
+--R                       *
+--R                          ROOT
+--R                                      1     4 8      3     3   2 6
+--R                                 - ------- a e  + ------- a c d e
+--R                                   4194304        1048576
+--R                               + 
+--R                                      19    2 2 4 4      3       3 6 2
+--R                                 - ------- a c d e  + ------- a c d e
+--R                                   2097152            1048576
+--R                               + 
+--R                                      1     4 8
+--R                                 - ------- c d
+--R                                   4194304
+--R                            /
+--R                                7 5
+--R                               a c
+--R                   + 
+--R                      1       3    1     3
+--R                     --- a d e  - --- c d e
+--R                     256          256
+--R                /
+--R                    3 2
+--R                   a c
+--R      *
+--R         log
+--R                         5 3
+--R                    8192a c e
+--R                 *
+--R                    ROOT
+--R                                1     4 8      3     3   2 6      19    2 2 4 4
+--R                           - ------- a e  + ------- a c d e  - ------- a c d e
+--R                             4194304        1048576            2097152
+--R                         + 
+--R                              3       3 6 2      1     4 8
+--R                           ------- a c d e  - ------- c d
+--R                           1048576            4194304
+--R                      /
+--R                          7 5
+--R                         a c
+--R                + 
+--R                    3     4      2 2 3 2       3 5
+--R                  4a c d e  - 24a c d e  + 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                            -
+--R                                   3 2
+--R                                 2a c
+--R                              *
+--R                                 ROOT
+--R                                             1     4 8      3     3   2 6
+--R                                        - ------- a e  + ------- a c d e
+--R                                          4194304        1048576
+--R                                      + 
+--R                                             19    2 2 4 4      3       3 6 2
+--R                                        - ------- a c d e  + ------- a c d e
+--R                                          2097152            1048576
+--R                                      + 
+--R                                             1     4 8
+--R                                        - ------- c d
+--R                                          4194304
+--R                                   /
+--R                                       7 5
+--R                                      a c
+--R                          + 
+--R                             1       3    1     3
+--R                            --- a d e  - --- c d e
+--R                            256          256
+--R                       /
+--R                           3 2
+--R                          a c
+--R            + 
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R       -
+--R            1  +-+8+---+7 8+-+5
+--R            - \|2 \|- a   \|c
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                        -
+--R                               3 2
+--R                             2a c
+--R                          *
+--R                             ROOT
+--R                                         1     4 8      3     3   2 6
+--R                                    - ------- a e  + ------- a c d e
+--R                                      4194304        1048576
+--R                                  + 
+--R                                         19    2 2 4 4      3       3 6 2
+--R                                    - ------- a c d e  + ------- a c d e
+--R                                      2097152            1048576
+--R                                  + 
+--R                                         1     4 8
+--R                                    - ------- c d
+--R                                      4194304
+--R                               /
+--R                                   7 5
+--R                                  a c
+--R                      + 
+--R                         1       3    1     3
+--R                        --- a d e  - --- c d e
+--R                        256          256
+--R                   /
+--R                       3 2
+--R                      a c
+--R         *
+--R            log
+--R                     -
+--R                               5 3
+--R                          8192a c e
+--R                       *
+--R                          ROOT
+--R                                      1     4 8      3     3   2 6
+--R                                 - ------- a e  + ------- a c d e
+--R                                   4194304        1048576
+--R                               + 
+--R                                      19    2 2 4 4      3       3 6 2
+--R                                 - ------- a c d e  + ------- a c d e
+--R                                   2097152            1048576
+--R                               + 
+--R                                      1     4 8
+--R                                 - ------- c d
+--R                                   4194304
+--R                            /
+--R                                7 5
+--R                               a c
+--R                   + 
+--R                         3     4      2 2 3 2       3 5
+--R                     - 4a c d e  + 24a c d e  - 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                               -
+--R                                      3 2
+--R                                    2a c
+--R                                 *
+--R                                    ROOT
+--R                                                1     4 8      3     3   2 6
+--R                                           - ------- a e  + ------- a c d e
+--R                                             4194304        1048576
+--R                                         + 
+--R                                                19    2 2 4 4      3       3 6 2
+--R                                           - ------- a c d e  + ------- a c d e
+--R                                             2097152            1048576
+--R                                         + 
+--R                                                1     4 8
+--R                                           - ------- c d
+--R                                             4194304
+--R                                      /
+--R                                          7 5
+--R                                         a c
+--R                             + 
+--R                                1       3    1     3
+--R                               --- a d e  - --- c d e
+--R                               256          256
+--R                          /
+--R                              3 2
+--R                             a c
+--R               + 
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R         1  +-+8+---+7 8+-+5
+--R         - \|2 \|- a   \|c
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                         3 2
+--R                       2a c
+--R                    *
+--R                       ROOT
+--R                                   1     4 8      3     3   2 6
+--R                              - ------- a e  + ------- a c d e
+--R                                4194304        1048576
+--R                            + 
+--R                                 19    2 2 4 4      3       3 6 2      1     4 8
+--R                            - ------- a c d e  + ------- a c d e  - ------- c d
+--R                              2097152            1048576            4194304
+--R                         /
+--R                             7 5
+--R                            a c
+--R                   + 
+--R                      1       3    1     3
+--R                     --- a d e  - --- c d e
+--R                     256          256
+--R                /
+--R                    3 2
+--R                   a c
+--R      *
+--R         log
+--R                  -
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                       ROOT
+--R                                   1     4 8      3     3   2 6
+--R                              - ------- a e  + ------- a c d e
+--R                                4194304        1048576
+--R                            + 
+--R                                 19    2 2 4 4      3       3 6 2      1     4 8
+--R                            - ------- a c d e  + ------- a c d e  - ------- c d
+--R                              2097152            1048576            4194304
+--R                         /
+--R                             7 5
+--R                            a c
+--R                + 
+--R                    3     4      2 2 3 2       3 5
+--R                  4a c d e  - 24a c d e  + 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                3 2
+--R                              2a c
+--R                           *
+--R                              ROOT
+--R                                          1     4 8      3     3   2 6
+--R                                     - ------- a e  + ------- a c d e
+--R                                       4194304        1048576
+--R                                   + 
+--R                                          19    2 2 4 4      3       3 6 2
+--R                                     - ------- a c d e  + ------- a c d e
+--R                                       2097152            1048576
+--R                                   + 
+--R                                          1     4 8
+--R                                     - ------- c d
+--R                                       4194304
+--R                                /
+--R                                    7 5
+--R                                   a c
+--R                          + 
+--R                             1       3    1     3
+--R                            --- a d e  - --- c d e
+--R                            256          256
+--R                       /
+--R                           3 2
+--R                          a c
+--R            + 
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R          +-+8+---+7 8+-+5
+--R         \|2 \|- a   \|c
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                         3 2
+--R                       2a c
+--R                    *
+--R                       ROOT
+--R                                   1     4 8      3     3   2 6
+--R                              - ------- a e  + ------- a c d e
+--R                                4194304        1048576
+--R                            + 
+--R                                 19    2 2 4 4      3       3 6 2      1     4 8
+--R                            - ------- a c d e  + ------- a c d e  - ------- c d
+--R                              2097152            1048576            4194304
+--R                         /
+--R                             7 5
+--R                            a c
+--R                   + 
+--R                      1       3    1     3
+--R                     --- a d e  - --- c d e
+--R                     256          256
+--R                /
+--R                    3 2
+--R                   a c
+--R      *
+--R         atan
+--R                         5 3
+--R                    8192a c e
+--R                 *
+--R                    ROOT
+--R                                1     4 8      3     3   2 6      19    2 2 4 4
+--R                           - ------- a e  + ------- a c d e  - ------- a c d e
+--R                             4194304        1048576            2097152
+--R                         + 
+--R                              3       3 6 2      1     4 8
+--R                           ------- a c d e  - ------- c d
+--R                           1048576            4194304
+--R                      /
+--R                          7 5
+--R                         a c
+--R                + 
+--R                      3     4      2 2 3 2       3 5
+--R                  - 4a c d e  + 24a c d e  - 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                3 2
+--R                              2a c
+--R                           *
+--R                              ROOT
+--R                                          1     4 8      3     3   2 6
+--R                                     - ------- a e  + ------- a c d e
+--R                                       4194304        1048576
+--R                                   + 
+--R                                          19    2 2 4 4      3       3 6 2
+--R                                     - ------- a c d e  + ------- a c d e
+--R                                       2097152            1048576
+--R                                   + 
+--R                                          1     4 8
+--R                                     - ------- c d
+--R                                       4194304
+--R                                /
+--R                                    7 5
+--R                                   a c
+--R                          + 
+--R                             1       3    1     3
+--R                            --- a d e  - --- c d e
+--R                            256          256
+--R                       /
+--R                           3 2
+--R                          a c
+--R           /
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R       -
+--R             +-+8+---+7 8+-+5
+--R            \|2 \|- a   \|c
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                        -
+--R                               3 2
+--R                             2a c
+--R                          *
+--R                             ROOT
+--R                                         1     4 8      3     3   2 6
+--R                                    - ------- a e  + ------- a c d e
+--R                                      4194304        1048576
+--R                                  + 
+--R                                         19    2 2 4 4      3       3 6 2
+--R                                    - ------- a c d e  + ------- a c d e
+--R                                      2097152            1048576
+--R                                  + 
+--R                                         1     4 8
+--R                                    - ------- c d
+--R                                      4194304
+--R                               /
+--R                                   7 5
+--R                                  a c
+--R                      + 
+--R                         1       3    1     3
+--R                        --- a d e  - --- c d e
+--R                        256          256
+--R                   /
+--R                       3 2
+--R                      a c
+--R         *
+--R            atan
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                       ROOT
+--R                                   1     4 8      3     3   2 6
+--R                              - ------- a e  + ------- a c d e
+--R                                4194304        1048576
+--R                            + 
+--R                                 19    2 2 4 4      3       3 6 2      1     4 8
+--R                            - ------- a c d e  + ------- a c d e  - ------- c d
+--R                              2097152            1048576            4194304
+--R                         /
+--R                             7 5
+--R                            a c
+--R                   + 
+--R                       3     4      2 2 3 2       3 5
+--R                     4a c d e  - 24a c d e  + 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                               -
+--R                                      3 2
+--R                                    2a c
+--R                                 *
+--R                                    ROOT
+--R                                                1     4 8      3     3   2 6
+--R                                           - ------- a e  + ------- a c d e
+--R                                             4194304        1048576
+--R                                         + 
+--R                                                19    2 2 4 4      3       3 6 2
+--R                                           - ------- a c d e  + ------- a c d e
+--R                                             2097152            1048576
+--R                                         + 
+--R                                                1     4 8
+--R                                           - ------- c d
+--R                                             4194304
+--R                                      /
+--R                                          7 5
+--R                                         a c
+--R                             + 
+--R                                1       3    1     3
+--R                               --- a d e  - --- c d e
+--R                               256          256
+--R                          /
+--R                              3 2
+--R                             a c
+--R              /
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  - 5a c d e  - 5a c d e  + c d )x
+--R     + 
+--R        1   +-+ +-+   1   +-+ +---+      8+-+   8+---+
+--R       (- d\|2 \|c  + - e\|2 \|- a )log(x\|c  + \|- a )
+--R        8             8
+--R     + 
+--R          1      +-+ +-+   1      +-+ +---+         8+-+   8+---+
+--R       (- - %i d\|2 \|c  - - %i e\|2 \|- a )log(%i x\|c  + \|- a )
+--R          8                8
+--R     + 
+--R                                                           8+-+    +-+8+---+
+--R         1   1      +-+      1   1      +---+     (1 + %i)x\|c  + \|2 \|- a
+--R       ((- - - %i)d\|c  + (- - + - %i)e\|- a )log(--------------------------)
+--R         8   8               8   8                            +-+
+--R                                                             \|2
+--R     + 
+--R                                                           8+-+    +-+8+---+
+--R         1   1      +-+      1   1      +---+     (1 - %i)x\|c  + \|2 \|- a
+--R       ((- + - %i)d\|c  + (- - - - %i)e\|- a )log(--------------------------)
+--R         8   8               8   8                            +-+
+--R                                                             \|2
+--R     + 
+--R                                                             8+-+    +-+8+---+
+--R           1   1      +-+    1   1      +---+     (- 1 + %i)x\|c  + \|2 \|- a
+--R       ((- - - - %i)d\|c  + (- + - %i)e\|- a )log(----------------------------)
+--R           8   8             8   8                             +-+
+--R                                                              \|2
+--R     + 
+--R                                                             8+-+    +-+8+---+
+--R           1   1      +-+    1   1      +---+     (- 1 - %i)x\|c  + \|2 \|- a
+--R       ((- - + - %i)d\|c  + (- - - %i)e\|- a )log(----------------------------)
+--R           8   8             8   8                             +-+
+--R                                                              \|2
+--R     + 
+--R        1      +-+ +-+   1      +-+ +---+           8+-+   8+---+
+--R       (- %i d\|2 \|c  + - %i e\|2 \|- a )log(- %i x\|c  + \|- a )
+--R        8                8
+--R     + 
+--R          1   +-+ +-+   1   +-+ +---+        8+-+   8+---+
+--R       (- - d\|2 \|c  - - e\|2 \|- a )log(- x\|c  + \|- a )
+--R          8             8
+--R  /
+--R      +-+8+---+7 8+-+5
+--R     \|2 \|- a   \|c
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 354
+
+--S 355 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R            8+---+4 +-+8+-+4         4       8+---+4        4 +---+
+--R        - d \|- a  \|c \|c   + (c e x  + c d)\|- a   - c e x \|- a
+--R   (8)  -----------------------------------------------------------
+--R                              2 8       8+---+4
+--R                            (c x  + a c)\|- a
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 355
+
+)clear all
+
+--S 356 of 649
+t0:=(d+e*x^n)/(a-c*x^(2*n))
+--R 
+--R
+--R             n
+--R        - e x  - d
+--R   (1)  ----------
+--R            2n
+--R         c x   - a
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 649
+--r0:=1/2*x*hypergeometric(1,1/n,1+1/n,-x^n*sqrt(c)/sqrt(a))*_
+--  (d-e*sqrt(a)/sqrt(c))/a+1/2*x*hypergeometric(1,1/n,1+1/n,x^n*_
+--  sqrt(c)/sqrt(a))*(d+e*sqrt(a)/sqrt(c))/a
+--E 357
+
+--S 358 of 649
+--a0:=integrate(t0,x)
+--E 358
+
+--S 359 of 649
+--m0:=a0-r0
+--E 359
+
+--S 360 of 649
+--d0:=D(m0,x)
+--E 360
+
+)clear all
+
+--S 361 of 649
+t0:=(d+e*x)/(a-c*x^2)
+--R 
+--R
+--R        - e x - d
+--R   (1)  ---------
+--R            2
+--R         c x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 361
+
+--S 362 of 649
+r0:=-1/2*e*log(a-c*x^2)/c+d*atanh(x*sqrt(c)/sqrt(a))/(sqrt(a)*sqrt(c))
+--R 
+--R
+--R                     +-+
+--R                   x\|c                2      +-+ +-+
+--R        2c d atanh(-----) - e log(- c x  + a)\|a \|c
+--R                     +-+
+--R                    \|a
+--R   (2)  ---------------------------------------------
+--R                             +-+ +-+
+--R                          2c\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2      +---+
+--R            (c x  + a)\|a c  + 2a c x             2      +---+
+--R    c d log(-------------------------) - e log(c x  - a)\|a c
+--R                        2
+--R                     c x  - a
+--R   [----------------------------------------------------------,
+--R                                +---+
+--R                             2c\|a c
+--R                +-----+
+--R              x\|- a c              2      +-----+
+--R    2c d atan(---------) - e log(c x  - a)\|- a c
+--R                  a
+--R    ----------------------------------------------]
+--R                         +-----+
+--R                      2c\|- a c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 363
+
+--S 364 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          2      +---+                               +-+
+--R           +-+ +-+    (c x  + a)\|a c  + 2a c x         +---+      x\|c
+--R       c d\|a \|c log(-------------------------) - 2c d\|a c atanh(-----)
+--R                                  2                                  +-+
+--R                               c x  - a                             \|a
+--R     + 
+--R                   2                   2       +-+ +-+ +---+
+--R       (- e log(c x  - a) + e log(- c x  + a))\|a \|c \|a c
+--R  /
+--R        +-+ +-+ +---+
+--R     2c\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             +-+                       +-----+
+--R              +-----+      x\|c          +-+ +-+     x\|- a c
+--R       - 2c d\|- a c atanh(-----) + 2c d\|a \|c atan(---------)
+--R                             +-+                         a
+--R                            \|a
+--R     + 
+--R                   2                   2       +-----+ +-+ +-+
+--R       (- e log(c x  - a) + e log(- c x  + a))\|- a c \|a \|c
+--R  /
+--R        +-----+ +-+ +-+
+--R     2c\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 367
+
+)clear all
+
+--S 368 of 649
+t0:=(d+e*x^2)/(a-c*x^4)
+--R 
+--R
+--R             2
+--R        - e x  - d
+--R   (1)  ----------
+--R            4
+--R         c x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 368
+
+--S 369 of 649
+r0:=1/2*atan(c^(1/4)*x/a^(1/4))*(-e*sqrt(a)+d*sqrt(c))/(a^(3/4)*c^(3/4))+_
+   1/2*atanh(c^(1/4)*x/a^(1/4))*(e*sqrt(a)+d*sqrt(c))/(a^(3/4)*c^(3/4))
+--R 
+--R
+--R                              4+-+                         4+-+
+--R           +-+     +-+       x\|c        +-+     +-+      x\|c
+--R        (d\|c  + e\|a )atanh(-----) + (d\|c  - e\|a )atan(-----)
+--R                              4+-+                         4+-+
+--R                              \|a                          \|a
+--R   (2)  --------------------------------------------------------
+--R                                4+-+3 4+-+3
+--R                               2\|a   \|c
+--R                                                    Type: Expression(Integer)
+--E 369
+
+--S 370 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +------------------------------------+
+--R          |     +-----------------------+
+--R          |     | 2 4         2 2    2 4
+--R          |     |a e  + 2a c d e  + c d
+--R          |4a c |-----------------------  + d e
+--R          |     |            3 3
+--R          |    \|         64a c
+--R          |------------------------------------
+--R         \|                2a c
+--R      *
+--R         log
+--R                         +-----------------------+
+--R                         | 2 4         2 2    2 4
+--R                    3 2  |a e  + 2a c d e  + c d       2     2       2 3
+--R                (16a c e |-----------------------  - 2a c d e  - 2a c d )
+--R                         |            3 3
+--R                        \|         64a c
+--R             *
+--R                 +------------------------------------+
+--R                 |     +-----------------------+
+--R                 |     | 2 4         2 2    2 4
+--R                 |     |a e  + 2a c d e  + c d
+--R                 |4a c |-----------------------  + d e
+--R                 |     |            3 3
+--R                 |    \|         64a c
+--R                 |------------------------------------
+--R                \|                2a c
+--R            + 
+--R                2 4    2 4
+--R              (a e  - c d )x
+--R     + 
+--R       -
+--R             +--------------------------------------+
+--R             |       +-----------------------+
+--R             |       | 2 4         2 2    2 4
+--R             |       |a e  + 2a c d e  + c d
+--R             |- 4a c |-----------------------  + d e
+--R             |       |            3 3
+--R             |      \|         64a c
+--R             |--------------------------------------
+--R            \|                 2a c
+--R         *
+--R            log
+--R                            +-----------------------+
+--R                            | 2 4         2 2    2 4
+--R                       3 2  |a e  + 2a c d e  + c d       2     2       2 3
+--R                   (16a c e |-----------------------  + 2a c d e  + 2a c d )
+--R                            |            3 3
+--R                           \|         64a c
+--R                *
+--R                    +--------------------------------------+
+--R                    |       +-----------------------+
+--R                    |       | 2 4         2 2    2 4
+--R                    |       |a e  + 2a c d e  + c d
+--R                    |- 4a c |-----------------------  + d e
+--R                    |       |            3 3
+--R                    |      \|         64a c
+--R                    |--------------------------------------
+--R                   \|                 2a c
+--R               + 
+--R                   2 4    2 4
+--R                 (a e  - c d )x
+--R     + 
+--R          +--------------------------------------+
+--R          |       +-----------------------+
+--R          |       | 2 4         2 2    2 4
+--R          |       |a e  + 2a c d e  + c d
+--R          |- 4a c |-----------------------  + d e
+--R          |       |            3 3
+--R          |      \|         64a c
+--R          |--------------------------------------
+--R         \|                 2a c
+--R      *
+--R         log
+--R                           +-----------------------+
+--R                           | 2 4         2 2    2 4
+--R                      3 2  |a e  + 2a c d e  + c d       2     2       2 3
+--R                (- 16a c e |-----------------------  - 2a c d e  - 2a c d )
+--R                           |            3 3
+--R                          \|         64a c
+--R             *
+--R                 +--------------------------------------+
+--R                 |       +-----------------------+
+--R                 |       | 2 4         2 2    2 4
+--R                 |       |a e  + 2a c d e  + c d
+--R                 |- 4a c |-----------------------  + d e
+--R                 |       |            3 3
+--R                 |      \|         64a c
+--R                 |--------------------------------------
+--R                \|                 2a c
+--R            + 
+--R                2 4    2 4
+--R              (a e  - c d )x
+--R     + 
+--R       -
+--R             +------------------------------------+
+--R             |     +-----------------------+
+--R             |     | 2 4         2 2    2 4
+--R             |     |a e  + 2a c d e  + c d
+--R             |4a c |-----------------------  + d e
+--R             |     |            3 3
+--R             |    \|         64a c
+--R             |------------------------------------
+--R            \|                2a c
+--R         *
+--R            log
+--R                              +-----------------------+
+--R                              | 2 4         2 2    2 4
+--R                         3 2  |a e  + 2a c d e  + c d       2     2       2 3
+--R                   (- 16a c e |-----------------------  + 2a c d e  + 2a c d )
+--R                              |            3 3
+--R                             \|         64a c
+--R                *
+--R                    +------------------------------------+
+--R                    |     +-----------------------+
+--R                    |     | 2 4         2 2    2 4
+--R                    |     |a e  + 2a c d e  + c d
+--R                    |4a c |-----------------------  + d e
+--R                    |     |            3 3
+--R                    |    \|         64a c
+--R                    |------------------------------------
+--R                   \|                2a c
+--R               + 
+--R                   2 4    2 4
+--R                 (a e  - c d )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 370
+
+--S 371 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +------------------------------------+
+--R                     |     +-----------------------+
+--R                     |     | 2 4         2 2    2 4
+--R                     |     |a e  + 2a c d e  + c d
+--R                     |4a c |-----------------------  + d e
+--R                     |     |            3 3
+--R         4+-+3 4+-+3 |    \|         64a c
+--R         \|a   \|c   |------------------------------------
+--R                    \|                2a c
+--R      *
+--R         log
+--R                         +-----------------------+
+--R                         | 2 4         2 2    2 4
+--R                    3 2  |a e  + 2a c d e  + c d       2     2       2 3
+--R                (16a c e |-----------------------  - 2a c d e  - 2a c d )
+--R                         |            3 3
+--R                        \|         64a c
+--R             *
+--R                 +------------------------------------+
+--R                 |     +-----------------------+
+--R                 |     | 2 4         2 2    2 4
+--R                 |     |a e  + 2a c d e  + c d
+--R                 |4a c |-----------------------  + d e
+--R                 |     |            3 3
+--R                 |    \|         64a c
+--R                 |------------------------------------
+--R                \|                2a c
+--R            + 
+--R                2 4    2 4
+--R              (a e  - c d )x
+--R     + 
+--R       -
+--R                        +--------------------------------------+
+--R                        |       +-----------------------+
+--R                        |       | 2 4         2 2    2 4
+--R                        |       |a e  + 2a c d e  + c d
+--R                        |- 4a c |-----------------------  + d e
+--R                        |       |            3 3
+--R            4+-+3 4+-+3 |      \|         64a c
+--R            \|a   \|c   |--------------------------------------
+--R                       \|                 2a c
+--R         *
+--R            log
+--R                            +-----------------------+
+--R                            | 2 4         2 2    2 4
+--R                       3 2  |a e  + 2a c d e  + c d       2     2       2 3
+--R                   (16a c e |-----------------------  + 2a c d e  + 2a c d )
+--R                            |            3 3
+--R                           \|         64a c
+--R                *
+--R                    +--------------------------------------+
+--R                    |       +-----------------------+
+--R                    |       | 2 4         2 2    2 4
+--R                    |       |a e  + 2a c d e  + c d
+--R                    |- 4a c |-----------------------  + d e
+--R                    |       |            3 3
+--R                    |      \|         64a c
+--R                    |--------------------------------------
+--R                   \|                 2a c
+--R               + 
+--R                   2 4    2 4
+--R                 (a e  - c d )x
+--R     + 
+--R                     +--------------------------------------+
+--R                     |       +-----------------------+
+--R                     |       | 2 4         2 2    2 4
+--R                     |       |a e  + 2a c d e  + c d
+--R                     |- 4a c |-----------------------  + d e
+--R                     |       |            3 3
+--R         4+-+3 4+-+3 |      \|         64a c
+--R         \|a   \|c   |--------------------------------------
+--R                    \|                 2a c
+--R      *
+--R         log
+--R                           +-----------------------+
+--R                           | 2 4         2 2    2 4
+--R                      3 2  |a e  + 2a c d e  + c d       2     2       2 3
+--R                (- 16a c e |-----------------------  - 2a c d e  - 2a c d )
+--R                           |            3 3
+--R                          \|         64a c
+--R             *
+--R                 +--------------------------------------+
+--R                 |       +-----------------------+
+--R                 |       | 2 4         2 2    2 4
+--R                 |       |a e  + 2a c d e  + c d
+--R                 |- 4a c |-----------------------  + d e
+--R                 |       |            3 3
+--R                 |      \|         64a c
+--R                 |--------------------------------------
+--R                \|                 2a c
+--R            + 
+--R                2 4    2 4
+--R              (a e  - c d )x
+--R     + 
+--R       -
+--R                        +------------------------------------+
+--R                        |     +-----------------------+
+--R                        |     | 2 4         2 2    2 4
+--R                        |     |a e  + 2a c d e  + c d
+--R                        |4a c |-----------------------  + d e
+--R                        |     |            3 3
+--R            4+-+3 4+-+3 |    \|         64a c
+--R            \|a   \|c   |------------------------------------
+--R                       \|                2a c
+--R         *
+--R            log
+--R                              +-----------------------+
+--R                              | 2 4         2 2    2 4
+--R                         3 2  |a e  + 2a c d e  + c d       2     2       2 3
+--R                   (- 16a c e |-----------------------  + 2a c d e  + 2a c d )
+--R                              |            3 3
+--R                             \|         64a c
+--R                *
+--R                    +------------------------------------+
+--R                    |     +-----------------------+
+--R                    |     | 2 4         2 2    2 4
+--R                    |     |a e  + 2a c d e  + c d
+--R                    |4a c |-----------------------  + d e
+--R                    |     |            3 3
+--R                    |    \|         64a c
+--R                    |------------------------------------
+--R                   \|                2a c
+--R               + 
+--R                   2 4    2 4
+--R                 (a e  - c d )x
+--R     + 
+--R                               4+-+                           4+-+
+--R            +-+     +-+       x\|c          +-+     +-+      x\|c
+--R       (- d\|c  - e\|a )atanh(-----) + (- d\|c  + e\|a )atan(-----)
+--R                               4+-+                           4+-+
+--R                               \|a                            \|a
+--R  /
+--R      4+-+3 4+-+3
+--R     2\|a   \|c
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R               2     4+-+2      2 +-+ 4+-+2     4+-+2 +-+
+--R        ((- e x  - d)\|a   + e x \|a )\|c   + d \|a  \|c
+--R   (5)  -------------------------------------------------
+--R                           4     4+-+2 4+-+2
+--R                       (c x  - a)\|a   \|c
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 649
+t0:=(d+e*x^3)/(a-c*x^6)
+--R 
+--R
+--R             3
+--R        - e x  - d
+--R   (1)  ----------
+--R            6
+--R         c x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 373
+
+--S 374 of 649
+r0:=1/6*log(a^(1/6)+c^(1/6)*x)*(d-e*sqrt(a)/sqrt(c))/(a^(5/6)*c^(1/6))+_
+   1/6*(-1)^(2/3)*log(a^(1/6)-(-1)^(1/3)*c^(1/6)*x)*(d-e*sqrt(a)/sqrt(c))/_
+   (a^(5/6)*c^(1/6))-1/6*(-1)^(1/3)*log(a^(1/6)+(-1)^(2/3)*c^(1/6)*x)*_
+   (d-e*sqrt(a)/sqrt(c))/(a^(5/6)*c^(1/6))-1/6*log(a^(1/6)-c^(1/6)*x)*_
+   (e*sqrt(a)+d*sqrt(c))/(a^(5/6)*c^(2/3))-1/6*(-1)^(2/3)*log(a^(1/6)+_
+   (-1)^(1/3)*c^(1/6)*x)*(e*sqrt(a)+d*sqrt(c))/(a^(5/6)*c^(2/3))+_
+   1/6*(-1)^(1/3)*log(a^(1/6)-(-1)^(2/3)*c^(1/6)*x)*(e*sqrt(a)+d*_
+   sqrt(c))/(a^(5/6)*c^(2/3))
+--R 
+--R
+--R   (2)
+--R           3+---+ +-+    3+---+ +-+ 3+-+2      3+---+2 6+-+  6+-+
+--R       (- d\|- 1 \|c  + e\|- 1 \|a )\|c  log(x \|- 1   \|c + \|a )
+--R     + 
+--R            3+---+2 +-+ +-+       3+---+2 6+-+     3+---+6+-+   6+-+
+--R       (- e \|- 1  \|a \|c  - c d \|- 1  )\|c log(x\|- 1 \|c  + \|a )
+--R     + 
+--R          +-+     +-+ 3+-+2     6+-+   6+-+
+--R       (d\|c  - e\|a )\|c  log(x\|c  + \|a )
+--R     + 
+--R            +-+ +-+       6+-+       6+-+   6+-+
+--R       (- e\|a \|c  - c d)\|c log(- x\|c  + \|a )
+--R     + 
+--R          3+---+2 +-+     3+---+2 +-+ 3+-+2       3+---+6+-+   6+-+
+--R       (d \|- 1  \|c  - e \|- 1  \|a )\|c  log(- x\|- 1 \|c  + \|a )
+--R     + 
+--R         3+---+ +-+ +-+      3+---+ 6+-+        3+---+2 6+-+  6+-+
+--R       (e\|- 1 \|a \|c  + c d\|- 1 )\|c log(- x \|- 1   \|c + \|a )
+--R  /
+--R      6+-+5 +-+3+-+2 6+-+
+--R     6\|a  \|c \|c   \|c
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +----------------------------------------------------+
+--R             |        +--------------------------+
+--R             |        |  2 2 4         4 2    2 6
+--R             |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R             |108a c  |--------------------------  - a e  - 3c d e
+--R             |        |               5 3
+--R             |       \|         11664a c
+--R             |----------------------------------------------------
+--R            3|                           2 2
+--R            \|                       216a c
+--R         *
+--R            log
+--R                                 +--------------------------+
+--R                                 |  2 2 4         4 2    2 6
+--R                          5 3    |9a d e  + 6a c d e  + c d         4     4
+--R                     7776a c d e |--------------------------  + 108a c d e
+--R                                 |               5 3
+--R                                \|         11664a c
+--R                   + 
+--R                         3 2 3 2      2 3 5
+--R                     144a c d e  + 36a c d
+--R                *
+--R                    +----------------------------------------------------+2
+--R                    |        +--------------------------+
+--R                    |        |  2 2 4         4 2    2 6
+--R                    |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                    |108a c  |--------------------------  - a e  - 3c d e
+--R                    |        |               5 3
+--R                    |       \|         11664a c
+--R                    |----------------------------------------------------
+--R                   3|                           2 2
+--R                   \|                       216a c
+--R               + 
+--R                                               +--------------------------+
+--R                                               |  2 2 4         4 2    2 6
+--R                          5 2 3       4 3 2    |9a d e  + 6a c d e  + c d
+--R                     (648a c e  - 648a c d e)x |--------------------------
+--R                                               |               5 3
+--R                                              \|         11664a c
+--R                   + 
+--R                         3   2 4      2 2 4 2       3 6
+--R                     (18a c d e  - 12a c d e  - 6a c d )x
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |        +--------------------------+
+--R                    |        |  2 2 4         4 2    2 6
+--R                    |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                    |108a c  |--------------------------  - a e  - 3c d e
+--R                    |        |               5 3
+--R                    |       \|         11664a c
+--R                    |----------------------------------------------------
+--R                   3|                           2 2
+--R                   \|                       216a c
+--R               + 
+--R                    3   6     2   3 4      2 5 2    3 7  2
+--R                 (3a d e  - 5a c d e  + a c d e  + c d )x
+--R     + 
+--R            +------------------------------------------------------+
+--R            |          +--------------------------+
+--R            |          |  2 2 4         4 2    2 6
+--R            |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R            |- 108a c  |--------------------------  - a e  - 3c d e
+--R            |          |               5 3
+--R            |         \|         11664a c
+--R         2  |------------------------------------------------------
+--R           3|                            2 2
+--R           \|                        216a c
+--R      *
+--R         log
+--R                          +--------------------------+
+--R                          |  2 2 4         4 2    2 6
+--R                     4 2  |9a d e  + 6a c d e  + c d        2   2 2       2 4
+--R                (648a c e |--------------------------  - 18a c d e  - 6a c d )
+--R                          |               5 3
+--R                         \|         11664a c
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |          +--------------------------+
+--R                 |          |  2 2 4         4 2    2 6
+--R                 |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                 |- 108a c  |--------------------------  - a e  - 3c d e
+--R                 |          |               5 3
+--R                 |         \|         11664a c
+--R                 |------------------------------------------------------
+--R                3|                            2 2
+--R                \|                        216a c
+--R            + 
+--R                 2   4         3 2    2 5
+--R              (3a d e  - 2a c d e  - c d )x
+--R     + 
+--R       -
+--R             +------------------------------------------------------+
+--R             |          +--------------------------+
+--R             |          |  2 2 4         4 2    2 6
+--R             |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R             |- 108a c  |--------------------------  - a e  - 3c d e
+--R             |          |               5 3
+--R             |         \|         11664a c
+--R             |------------------------------------------------------
+--R            3|                            2 2
+--R            \|                        216a c
+--R         *
+--R            log
+--R                                   +--------------------------+
+--R                                   |  2 2 4         4 2    2 6
+--R                            5 3    |9a d e  + 6a c d e  + c d         4     4
+--R                     - 7776a c d e |--------------------------  + 108a c d e
+--R                                   |               5 3
+--R                                  \|         11664a c
+--R                   + 
+--R                         3 2 3 2      2 3 5
+--R                     144a c d e  + 36a c d
+--R                *
+--R                    +------------------------------------------------------+2
+--R                    |          +--------------------------+
+--R                    |          |  2 2 4         4 2    2 6
+--R                    |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                    |- 108a c  |--------------------------  - a e  - 3c d e
+--R                    |          |               5 3
+--R                    |         \|         11664a c
+--R                    |------------------------------------------------------
+--R                   3|                            2 2
+--R                   \|                        216a c
+--R               + 
+--R                                                 +--------------------------+
+--R                                                 |  2 2 4         4 2    2 6
+--R                            5 2 3       4 3 2    |9a d e  + 6a c d e  + c d
+--R                     (- 648a c e  + 648a c d e)x |--------------------------
+--R                                                 |               5 3
+--R                                                \|         11664a c
+--R                   + 
+--R                         3   2 4      2 2 4 2       3 6
+--R                     (18a c d e  - 12a c d e  - 6a c d )x
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |          +--------------------------+
+--R                    |          |  2 2 4         4 2    2 6
+--R                    |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                    |- 108a c  |--------------------------  - a e  - 3c d e
+--R                    |          |               5 3
+--R                    |         \|         11664a c
+--R                    |------------------------------------------------------
+--R                   3|                            2 2
+--R                   \|                        216a c
+--R               + 
+--R                    3   6     2   3 4      2 5 2    3 7  2
+--R                 (3a d e  - 5a c d e  + a c d e  + c d )x
+--R     + 
+--R            +----------------------------------------------------+
+--R            |        +--------------------------+
+--R            |        |  2 2 4         4 2    2 6
+--R            |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R            |108a c  |--------------------------  - a e  - 3c d e
+--R            |        |               5 3
+--R            |       \|         11664a c
+--R         2  |----------------------------------------------------
+--R           3|                           2 2
+--R           \|                       216a c
+--R      *
+--R         log
+--R                            +--------------------------+
+--R                            |  2 2 4         4 2    2 6
+--R                       4 2  |9a d e  + 6a c d e  + c d        2   2 2       2 4
+--R                (- 648a c e |--------------------------  - 18a c d e  - 6a c d )
+--R                            |               5 3
+--R                           \|         11664a c
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |        +--------------------------+
+--R                 |        |  2 2 4         4 2    2 6
+--R                 |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                 |108a c  |--------------------------  - a e  - 3c d e
+--R                 |        |               5 3
+--R                 |       \|         11664a c
+--R                 |----------------------------------------------------
+--R                3|                           2 2
+--R                \|                       216a c
+--R            + 
+--R                 2   4         3 2    2 5
+--R              (3a d e  - 2a c d e  - c d )x
+--R     + 
+--R                +------------------------------------------------------+
+--R                |          +--------------------------+
+--R                |          |  2 2 4         4 2    2 6
+--R                |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                |- 108a c  |--------------------------  - a e  - 3c d e
+--R                |          |               5 3
+--R           +-+  |         \|         11664a c
+--R         2\|3   |------------------------------------------------------
+--R               3|                            2 2
+--R               \|                        216a c
+--R      *
+--R         atan
+--R                               +--------------------------+
+--R                               |  2 2 4         4 2    2 6
+--R                      4 2  +-+ |9a d e  + 6a c d e  + c d
+--R                  324a c e\|3  |--------------------------
+--R                               |               5 3
+--R                              \|         11664a c
+--R                + 
+--R                       2   2 2       2 4  +-+
+--R                  (- 9a c d e  - 3a c d )\|3
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |          +--------------------------+
+--R                 |          |  2 2 4         4 2    2 6
+--R                 |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                 |- 108a c  |--------------------------  - a e  - 3c d e
+--R                 |          |               5 3
+--R                 |         \|         11664a c
+--R                 |------------------------------------------------------
+--R                3|                            2 2
+--R                \|                        216a c
+--R           /
+--R                            +--------------------------+
+--R                            |  2 2 4         4 2    2 6
+--R                       4 2  |9a d e  + 6a c d e  + c d       2   2 2       2 4
+--R                  (324a c e |--------------------------  - 9a c d e  - 3a c d )
+--R                            |               5 3
+--R                           \|         11664a c
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |          +--------------------------+
+--R                   |          |  2 2 4         4 2    2 6
+--R                   |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                   |- 108a c  |--------------------------  - a e  - 3c d e
+--R                   |          |               5 3
+--R                   |         \|         11664a c
+--R                   |------------------------------------------------------
+--R                  3|                            2 2
+--R                  \|                        216a c
+--R              + 
+--R                     2   4         3 2    2 5
+--R                (- 3a d e  + 2a c d e  + c d )x
+--R     + 
+--R                +----------------------------------------------------+
+--R                |        +--------------------------+
+--R                |        |  2 2 4         4 2    2 6
+--R                |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                |108a c  |--------------------------  - a e  - 3c d e
+--R                |        |               5 3
+--R           +-+  |       \|         11664a c
+--R         2\|3   |----------------------------------------------------
+--R               3|                           2 2
+--R               \|                       216a c
+--R      *
+--R         atan
+--R                               +--------------------------+
+--R                               |  2 2 4         4 2    2 6
+--R                      4 2  +-+ |9a d e  + 6a c d e  + c d
+--R                  324a c e\|3  |--------------------------
+--R                               |               5 3
+--R                              \|         11664a c
+--R                + 
+--R                     2   2 2       2 4  +-+
+--R                  (9a c d e  + 3a c d )\|3
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |        +--------------------------+
+--R                 |        |  2 2 4         4 2    2 6
+--R                 |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                 |108a c  |--------------------------  - a e  - 3c d e
+--R                 |        |               5 3
+--R                 |       \|         11664a c
+--R                 |----------------------------------------------------
+--R                3|                           2 2
+--R                \|                       216a c
+--R           /
+--R                            +--------------------------+
+--R                            |  2 2 4         4 2    2 6
+--R                       4 2  |9a d e  + 6a c d e  + c d       2   2 2       2 4
+--R                  (324a c e |--------------------------  + 9a c d e  + 3a c d )
+--R                            |               5 3
+--R                           \|         11664a c
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |        +--------------------------+
+--R                   |        |  2 2 4         4 2    2 6
+--R                   |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                   |108a c  |--------------------------  - a e  - 3c d e
+--R                   |        |               5 3
+--R                   |       \|         11664a c
+--R                   |----------------------------------------------------
+--R                  3|                           2 2
+--R                  \|                       216a c
+--R              + 
+--R                   2   4         3 2    2 5
+--R                (3a d e  - 2a c d e  - c d )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 375
+
+--S 376 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R             6+-+5 +-+3+-+2 6+-+
+--R            3\|a  \|c \|c   \|c
+--R         *
+--R             +----------------------------------------------------+
+--R             |        +--------------------------+
+--R             |        |  2 2 4         4 2    2 6
+--R             |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R             |108a c  |--------------------------  - a e  - 3c d e
+--R             |        |               5 3
+--R             |       \|         11664a c
+--R             |----------------------------------------------------
+--R            3|                           2 2
+--R            \|                       216a c
+--R         *
+--R            log
+--R                                 +--------------------------+
+--R                                 |  2 2 4         4 2    2 6
+--R                          5 3    |9a d e  + 6a c d e  + c d         4     4
+--R                     7776a c d e |--------------------------  + 108a c d e
+--R                                 |               5 3
+--R                                \|         11664a c
+--R                   + 
+--R                         3 2 3 2      2 3 5
+--R                     144a c d e  + 36a c d
+--R                *
+--R                    +----------------------------------------------------+2
+--R                    |        +--------------------------+
+--R                    |        |  2 2 4         4 2    2 6
+--R                    |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                    |108a c  |--------------------------  - a e  - 3c d e
+--R                    |        |               5 3
+--R                    |       \|         11664a c
+--R                    |----------------------------------------------------
+--R                   3|                           2 2
+--R                   \|                       216a c
+--R               + 
+--R                                               +--------------------------+
+--R                                               |  2 2 4         4 2    2 6
+--R                          5 2 3       4 3 2    |9a d e  + 6a c d e  + c d
+--R                     (648a c e  - 648a c d e)x |--------------------------
+--R                                               |               5 3
+--R                                              \|         11664a c
+--R                   + 
+--R                         3   2 4      2 2 4 2       3 6
+--R                     (18a c d e  - 12a c d e  - 6a c d )x
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |        +--------------------------+
+--R                    |        |  2 2 4         4 2    2 6
+--R                    |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                    |108a c  |--------------------------  - a e  - 3c d e
+--R                    |        |               5 3
+--R                    |       \|         11664a c
+--R                    |----------------------------------------------------
+--R                   3|                           2 2
+--R                   \|                       216a c
+--R               + 
+--R                    3   6     2   3 4      2 5 2    3 7  2
+--R                 (3a d e  - 5a c d e  + a c d e  + c d )x
+--R     + 
+--R          6+-+5 +-+3+-+2 6+-+
+--R         6\|a  \|c \|c   \|c
+--R      *
+--R          +------------------------------------------------------+
+--R          |          +--------------------------+
+--R          |          |  2 2 4         4 2    2 6
+--R          |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R          |- 108a c  |--------------------------  - a e  - 3c d e
+--R          |          |               5 3
+--R          |         \|         11664a c
+--R          |------------------------------------------------------
+--R         3|                            2 2
+--R         \|                        216a c
+--R      *
+--R         log
+--R                          +--------------------------+
+--R                          |  2 2 4         4 2    2 6
+--R                     4 2  |9a d e  + 6a c d e  + c d        2   2 2       2 4
+--R                (648a c e |--------------------------  - 18a c d e  - 6a c d )
+--R                          |               5 3
+--R                         \|         11664a c
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |          +--------------------------+
+--R                 |          |  2 2 4         4 2    2 6
+--R                 |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                 |- 108a c  |--------------------------  - a e  - 3c d e
+--R                 |          |               5 3
+--R                 |         \|         11664a c
+--R                 |------------------------------------------------------
+--R                3|                            2 2
+--R                \|                        216a c
+--R            + 
+--R                 2   4         3 2    2 5
+--R              (3a d e  - 2a c d e  - c d )x
+--R     + 
+--R       -
+--R             6+-+5 +-+3+-+2 6+-+
+--R            3\|a  \|c \|c   \|c
+--R         *
+--R             +------------------------------------------------------+
+--R             |          +--------------------------+
+--R             |          |  2 2 4         4 2    2 6
+--R             |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R             |- 108a c  |--------------------------  - a e  - 3c d e
+--R             |          |               5 3
+--R             |         \|         11664a c
+--R             |------------------------------------------------------
+--R            3|                            2 2
+--R            \|                        216a c
+--R         *
+--R            log
+--R                                   +--------------------------+
+--R                                   |  2 2 4         4 2    2 6
+--R                            5 3    |9a d e  + 6a c d e  + c d         4     4
+--R                     - 7776a c d e |--------------------------  + 108a c d e
+--R                                   |               5 3
+--R                                  \|         11664a c
+--R                   + 
+--R                         3 2 3 2      2 3 5
+--R                     144a c d e  + 36a c d
+--R                *
+--R                    +------------------------------------------------------+2
+--R                    |          +--------------------------+
+--R                    |          |  2 2 4         4 2    2 6
+--R                    |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                    |- 108a c  |--------------------------  - a e  - 3c d e
+--R                    |          |               5 3
+--R                    |         \|         11664a c
+--R                    |------------------------------------------------------
+--R                   3|                            2 2
+--R                   \|                        216a c
+--R               + 
+--R                                                 +--------------------------+
+--R                                                 |  2 2 4         4 2    2 6
+--R                            5 2 3       4 3 2    |9a d e  + 6a c d e  + c d
+--R                     (- 648a c e  + 648a c d e)x |--------------------------
+--R                                                 |               5 3
+--R                                                \|         11664a c
+--R                   + 
+--R                         3   2 4      2 2 4 2       3 6
+--R                     (18a c d e  - 12a c d e  - 6a c d )x
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |          +--------------------------+
+--R                    |          |  2 2 4         4 2    2 6
+--R                    |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                    |- 108a c  |--------------------------  - a e  - 3c d e
+--R                    |          |               5 3
+--R                    |         \|         11664a c
+--R                    |------------------------------------------------------
+--R                   3|                            2 2
+--R                   \|                        216a c
+--R               + 
+--R                    3   6     2   3 4      2 5 2    3 7  2
+--R                 (3a d e  - 5a c d e  + a c d e  + c d )x
+--R     + 
+--R          6+-+5 +-+3+-+2 6+-+
+--R         6\|a  \|c \|c   \|c
+--R      *
+--R          +----------------------------------------------------+
+--R          |        +--------------------------+
+--R          |        |  2 2 4         4 2    2 6
+--R          |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R          |108a c  |--------------------------  - a e  - 3c d e
+--R          |        |               5 3
+--R          |       \|         11664a c
+--R          |----------------------------------------------------
+--R         3|                           2 2
+--R         \|                       216a c
+--R      *
+--R         log
+--R                            +--------------------------+
+--R                            |  2 2 4         4 2    2 6
+--R                       4 2  |9a d e  + 6a c d e  + c d        2   2 2       2 4
+--R                (- 648a c e |--------------------------  - 18a c d e  - 6a c d )
+--R                            |               5 3
+--R                           \|         11664a c
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |        +--------------------------+
+--R                 |        |  2 2 4         4 2    2 6
+--R                 |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                 |108a c  |--------------------------  - a e  - 3c d e
+--R                 |        |               5 3
+--R                 |       \|         11664a c
+--R                 |----------------------------------------------------
+--R                3|                           2 2
+--R                \|                       216a c
+--R            + 
+--R                 2   4         3 2    2 5
+--R              (3a d e  - 2a c d e  - c d )x
+--R     + 
+--R           +-+6+-+5 +-+3+-+2 6+-+
+--R         6\|3 \|a  \|c \|c   \|c
+--R      *
+--R          +------------------------------------------------------+
+--R          |          +--------------------------+
+--R          |          |  2 2 4         4 2    2 6
+--R          |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R          |- 108a c  |--------------------------  - a e  - 3c d e
+--R          |          |               5 3
+--R          |         \|         11664a c
+--R          |------------------------------------------------------
+--R         3|                            2 2
+--R         \|                        216a c
+--R      *
+--R         atan
+--R                               +--------------------------+
+--R                               |  2 2 4         4 2    2 6
+--R                      4 2  +-+ |9a d e  + 6a c d e  + c d
+--R                  324a c e\|3  |--------------------------
+--R                               |               5 3
+--R                              \|         11664a c
+--R                + 
+--R                       2   2 2       2 4  +-+
+--R                  (- 9a c d e  - 3a c d )\|3
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |          +--------------------------+
+--R                 |          |  2 2 4         4 2    2 6
+--R                 |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                 |- 108a c  |--------------------------  - a e  - 3c d e
+--R                 |          |               5 3
+--R                 |         \|         11664a c
+--R                 |------------------------------------------------------
+--R                3|                            2 2
+--R                \|                        216a c
+--R           /
+--R                            +--------------------------+
+--R                            |  2 2 4         4 2    2 6
+--R                       4 2  |9a d e  + 6a c d e  + c d       2   2 2       2 4
+--R                  (324a c e |--------------------------  - 9a c d e  - 3a c d )
+--R                            |               5 3
+--R                           \|         11664a c
+--R               *
+--R                   +------------------------------------------------------+
+--R                   |          +--------------------------+
+--R                   |          |  2 2 4         4 2    2 6
+--R                   |      2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                   |- 108a c  |--------------------------  - a e  - 3c d e
+--R                   |          |               5 3
+--R                   |         \|         11664a c
+--R                   |------------------------------------------------------
+--R                  3|                            2 2
+--R                  \|                        216a c
+--R              + 
+--R                     2   4         3 2    2 5
+--R                (- 3a d e  + 2a c d e  + c d )x
+--R     + 
+--R           +-+6+-+5 +-+3+-+2 6+-+
+--R         6\|3 \|a  \|c \|c   \|c
+--R      *
+--R          +----------------------------------------------------+
+--R          |        +--------------------------+
+--R          |        |  2 2 4         4 2    2 6
+--R          |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R          |108a c  |--------------------------  - a e  - 3c d e
+--R          |        |               5 3
+--R          |       \|         11664a c
+--R          |----------------------------------------------------
+--R         3|                           2 2
+--R         \|                       216a c
+--R      *
+--R         atan
+--R                               +--------------------------+
+--R                               |  2 2 4         4 2    2 6
+--R                      4 2  +-+ |9a d e  + 6a c d e  + c d
+--R                  324a c e\|3  |--------------------------
+--R                               |               5 3
+--R                              \|         11664a c
+--R                + 
+--R                     2   2 2       2 4  +-+
+--R                  (9a c d e  + 3a c d )\|3
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |        +--------------------------+
+--R                 |        |  2 2 4         4 2    2 6
+--R                 |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                 |108a c  |--------------------------  - a e  - 3c d e
+--R                 |        |               5 3
+--R                 |       \|         11664a c
+--R                 |----------------------------------------------------
+--R                3|                           2 2
+--R                \|                       216a c
+--R           /
+--R                            +--------------------------+
+--R                            |  2 2 4         4 2    2 6
+--R                       4 2  |9a d e  + 6a c d e  + c d       2   2 2       2 4
+--R                  (324a c e |--------------------------  + 9a c d e  + 3a c d )
+--R                            |               5 3
+--R                           \|         11664a c
+--R               *
+--R                   +----------------------------------------------------+
+--R                   |        +--------------------------+
+--R                   |        |  2 2 4         4 2    2 6
+--R                   |    2 2 |9a d e  + 6a c d e  + c d        3       2
+--R                   |108a c  |--------------------------  - a e  - 3c d e
+--R                   |        |               5 3
+--R                   |       \|         11664a c
+--R                   |----------------------------------------------------
+--R                  3|                           2 2
+--R                  \|                       216a c
+--R              + 
+--R                   2   4         3 2    2 5
+--R                (3a d e  - 2a c d e  - c d )x
+--R     + 
+--R         3+---+ +-+    3+---+ +-+ 3+-+2      3+---+2 6+-+  6+-+
+--R       (d\|- 1 \|c  - e\|- 1 \|a )\|c  log(x \|- 1   \|c + \|a )
+--R     + 
+--R          3+---+2 +-+ +-+       3+---+2 6+-+     3+---+6+-+   6+-+
+--R       (e \|- 1  \|a \|c  + c d \|- 1  )\|c log(x\|- 1 \|c  + \|a )
+--R     + 
+--R            +-+     +-+ 3+-+2     6+-+   6+-+
+--R       (- d\|c  + e\|a )\|c  log(x\|c  + \|a )
+--R     + 
+--R          +-+ +-+       6+-+       6+-+   6+-+
+--R       (e\|a \|c  + c d)\|c log(- x\|c  + \|a )
+--R     + 
+--R            3+---+2 +-+     3+---+2 +-+ 3+-+2       3+---+6+-+   6+-+
+--R       (- d \|- 1  \|c  + e \|- 1  \|a )\|c  log(- x\|- 1 \|c  + \|a )
+--R     + 
+--R           3+---+ +-+ +-+      3+---+ 6+-+        3+---+2 6+-+  6+-+
+--R       (- e\|- 1 \|a \|c  - c d\|- 1 )\|c log(- x \|- 1   \|c + \|a )
+--R  /
+--R      6+-+5 +-+3+-+2 6+-+
+--R     6\|a  \|c \|c   \|c
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                              8     2   2 3+---+2            8     2   2 3+---+
+--R                   (- 2a c d x  + 2a d x )\|- 1   + (2a c d x  - 2a d x )\|- 1
+--R                 + 
+--R                             8     2   2
+--R                   - 2a c d x  + 2a d x
+--R              *
+--R                 6+-+2 +-+
+--R                 \|a  \|c
+--R             + 
+--R                              8     2   2 3+---+2            8     2   2 3+---+
+--R                   (- 2a c e x  + 2a e x )\|- 1   + (2a c e x  - 2a e x )\|- 1
+--R                 + 
+--R                             8     2   2
+--R                   - 2a c e x  + 2a e x
+--R              *
+--R                  +-+6+-+2
+--R                 \|a \|a
+--R          *
+--R             3+-+
+--R             \|c
+--R         + 
+--R                         9     2   3 3+---+2            9     2   3 3+---+  +-+
+--R             ((- 3a c e x  + 3a e x )\|- 1   + (3a c e x  - 3a e x )\|- 1 )\|a
+--R          *
+--R             6+-+ +-+
+--R             \|a \|c
+--R         + 
+--R               2   9     2     3 3+---+2          2   9     2     3 3+---+ 6+-+
+--R         ((3a c d x  - 3a c d x )\|- 1   + (- 3a c d x  + 3a c d x )\|- 1 )\|a
+--R      *
+--R         6+-+5
+--R         \|c
+--R     + 
+--R                           7    2    3+---+2             7    2    3+---+
+--R                   (a c d x  - a d x)\|- 1   + (- a c d x  + a d x)\|- 1
+--R                 + 
+--R                          7    2
+--R                   a c d x  - a d x
+--R              *
+--R                 6+-+3 +-+
+--R                 \|a  \|c
+--R             + 
+--R                           7    2    3+---+2             7    2    3+---+
+--R                   (a c e x  - a e x)\|- 1   + (- a c e x  + a e x)\|- 1
+--R                 + 
+--R                          7    2
+--R                   a c e x  - a e x
+--R              *
+--R                  +-+6+-+3
+--R                 \|a \|a
+--R          *
+--R             3+-+
+--R             \|c
+--R         + 
+--R                        8     2   2 3+---+2              8     2   2 3+---+
+--R               (2a c e x  - 2a e x )\|- 1   + (- 2a c e x  + 2a e x )\|- 1
+--R             + 
+--R                       8     2   2
+--R               2a c e x  - 2a e x
+--R          *
+--R              +-+6+-+2 +-+
+--R             \|a \|a  \|c
+--R         + 
+--R                      2   8     2     5     2     2 3+---+2
+--R               (- 2a c d x  - 6a c e x  - 4a c d x )\|- 1
+--R             + 
+--R                    2   8     2     5     2     2 3+---+       2   8     2     5
+--R               (2a c d x  + 6a c e x  + 4a c d x )\|- 1  - 2a c d x  - 6a c e x
+--R             + 
+--R                   2     2
+--R               - 4a c d x
+--R          *
+--R             6+-+2
+--R             \|a
+--R      *
+--R         6+-+4
+--R         \|c
+--R     + 
+--R                     6     2  6+-+4 +-+            6     2   +-+6+-+4 3+-+
+--R           ((3a c d x  - 3a d)\|a  \|c  + (3a c e x  - 3a e)\|a \|a  )\|c
+--R         + 
+--R                       7    2    3+---+2             7    2    3+---+          7
+--R               (a c e x  - a e x)\|- 1   + (- a c e x  + a e x)\|- 1  + a c e x
+--R             + 
+--R                  2
+--R               - a e x
+--R          *
+--R              +-+6+-+3 +-+
+--R             \|a \|a  \|c
+--R         + 
+--R                     2   7    2      3+---+2       2   7    2      3+---+
+--R               (- a c d x  + a c d x)\|- 1   + (a c d x  - a c d x)\|- 1
+--R             + 
+--R                    2   7    2
+--R               - a c d x  + a c d x
+--R          *
+--R             6+-+3
+--R             \|a
+--R      *
+--R         6+-+3
+--R         \|c
+--R     + 
+--R                     2   11          5 3+---+2       2   11          5 3+---+
+--R                   (c d x   - a c d x )\|- 1   + (- c d x   + a c d x )\|- 1
+--R                 + 
+--R                    2   11          5
+--R                   c d x   - a c d x
+--R              *
+--R                 6+-+5 +-+
+--R                 \|a  \|c
+--R             + 
+--R                     2   11          5 3+---+2       2   11          5 3+---+
+--R                   (c e x   - a c e x )\|- 1   + (- c e x   + a c e x )\|- 1
+--R                 + 
+--R                    2   11          5
+--R                   c e x   - a c e x
+--R              *
+--R                  +-+6+-+5
+--R                 \|a \|a
+--R          *
+--R             3+-+
+--R             \|c
+--R         + 
+--R                      6     2   +-+6+-+4 +-+
+--R           (- 3a c e x  + 3a e)\|a \|a  \|c
+--R         + 
+--R                  2   9       2   6     2     3     2    6+-+4
+--R           (- 6a c e x  - 3a c d x  + 6a c e x  + 3a c d)\|a
+--R      *
+--R         6+-+2
+--R         \|c
+--R     + 
+--R                       2   10    2     4 3+---+2
+--R                   (a c d x   - a c d x )\|- 1
+--R                 + 
+--R                         2   10    2     4 3+---+      2   10    2     4
+--R                   (- a c d x   + a c d x )\|- 1  + a c d x   - a c d x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                       2   10    2     4 3+---+2
+--R                   (a c e x   - a c e x )\|- 1
+--R                 + 
+--R                         2   10    2     4 3+---+      2   10    2     4
+--R                   (- a c e x   + a c e x )\|- 1  + a c e x   - a c e x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R             3+-+
+--R             \|c
+--R         + 
+--R                 2   11          5 3+---+2       2   11          5 3+---+
+--R               (c e x   - a c e x )\|- 1   + (- c e x   + a c e x )\|- 1
+--R             + 
+--R                2   11          5
+--R               c e x   - a c e x
+--R          *
+--R              +-+6+-+5 +-+
+--R             \|a \|a  \|c
+--R         + 
+--R                   3   11      2   5 3+---+2     3   11      2   5 3+---+
+--R               (- c d x   + a c d x )\|- 1   + (c d x   - a c d x )\|- 1
+--R             + 
+--R                  3   11      2   5
+--R               - c d x   + a c d x
+--R          *
+--R             6+-+5
+--R             \|a
+--R      *
+--R         6+-+
+--R         \|c
+--R     + 
+--R                     2   9     2     3 3+---+2        2   9     2     3 3+---+
+--R             ((- 3a c d x  + 3a c d x )\|- 1   + (3a c d x  - 3a c d x )\|- 1 )
+--R          *
+--R             6+-+ +-+
+--R             \|a \|c
+--R         + 
+--R                     2   9     2     3 3+---+2        2   9     2     3 3+---+
+--R             ((- 3a c e x  + 3a c e x )\|- 1   + (3a c e x  - 3a c e x )\|- 1 )
+--R          *
+--R              +-+6+-+
+--R             \|a \|a
+--R      *
+--R         3+-+
+--R         \|c
+--R     + 
+--R                 2   10    2     4 3+---+2       2   10    2     4 3+---+
+--R           (- a c e x   + a c e x )\|- 1   + (a c e x   - a c e x )\|- 1
+--R         + 
+--R                2   10    2     4
+--R           - a c e x   + a c e x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R     + 
+--R           3   10     2 2   7     2 2   4 3+---+2
+--R       (a c d x   + 6a c e x  + 5a c d x )\|- 1
+--R     + 
+--R             3   10     2 2   7     2 2   4 3+---+      3   10     2 2   7
+--R       (- a c d x   - 6a c e x  - 5a c d x )\|- 1  + a c d x   + 6a c e x
+--R     + 
+--R         2 2   4
+--R       5a c d x
+--R  /
+--R              2 2 8     3   2 3+---+2        2 2 8     3   2 3+---+     2 2 8
+--R           (6a c x  - 6a c x )\|- 1   + (- 6a c x  + 6a c x )\|- 1  + 6a c x
+--R         + 
+--R               3   2
+--R           - 6a c x
+--R      *
+--R         6+-+2 6+-+4
+--R         \|a   \|c
+--R     + 
+--R            3 12      2 2 6     3  6+-+4 6+-+2       2 3 10     3 2 4 3+---+2
+--R       (6a c x   - 12a c x  + 6a c)\|a   \|c  + (- 6a c x   + 6a c x )\|- 1
+--R     + 
+--R          2 3 10     3 2 4 3+---+     2 3 10     3 2 4
+--R       (6a c x   - 6a c x )\|- 1  - 6a c x   + 6a c x
+--R                                                    Type: Expression(Integer)
+--E 377
+
+)clear all
+
+--S 378 of 649
+t0:=(d+e*x^4)/(a-c*x^8)
+--R 
+--R
+--R             4
+--R        - e x  - d
+--R   (1)  ----------
+--R            8
+--R         c x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 378
+
+--S 379 of 649
+r0:=1/8*(-1)^(3/4)*log(a^(1/8)-(-1)^(1/4)*c^(1/8)*x)*(d-e*sqrt(a)/sqrt(c))/_
+   (a^(7/8)*c^(1/8))-1/8*(-1)^(3/4)*log(a^(1/8)+(-1)^(1/4)*c^(1/8)*x)*_
+   (d-e*sqrt(a)/sqrt(c))/(a^(7/8)*c^(1/8))+1/8*(-1)^(1/4)*log(a^(1/8)-_
+   (-1)^(3/4)*c^(1/8)*x)*(d-e*sqrt(a)/sqrt(c))/(a^(7/8)*c^(1/8))-_
+   1/8*(-1)^(1/4)*log(a^(1/8)+(-1)^(3/4)*c^(1/8)*x)*(d-e*sqrt(a)/_
+   sqrt(c))/(a^(7/8)*c^(1/8))-1/8*log(a^(1/8)-c^(1/8)*x)*(e*sqrt(a)+_
+   d*sqrt(c))/(a^(7/8)*c^(5/8))+1/8*%i*log(a^(1/8)-%i*c^(1/8)*x)*(e*_
+   sqrt(a)+d*sqrt(c))/(a^(7/8)*c^(5/8))-1/8*%i*log(a^(1/8)+%i*c^(1/8)*x)*_
+   (e*sqrt(a)+d*sqrt(c))/(a^(7/8)*c^(5/8))+1/8*log(a^(1/8)+c^(1/8)*x)*_
+   (e*sqrt(a)+d*sqrt(c))/(a^(7/8)*c^(5/8))
+--R 
+--R
+--R   (2)
+--R        1   +-+ +-+ +-+   1     +-+      8+-+   8+-+
+--R       (- e\|2 \|a \|c  + - c d\|2 )log(x\|c  + \|a )
+--R        8                 8
+--R     + 
+--R          1      +-+ +-+ +-+   1        +-+         8+-+   8+-+
+--R       (- - %i e\|2 \|a \|c  - - %i c d\|2 )log(%i x\|c  + \|a )
+--R          8                    8
+--R     + 
+--R                                                              8+-+    +-+8+-+
+--R         1   1      +-+      1   1      +-+ 8+-+4    (1 + %i)x\|c  + \|2 \|a
+--R       ((- - - %i)d\|c  + (- - + - %i)e\|a )\|c  log(------------------------)
+--R         8   8               8   8                              +-+
+--R                                                               \|2
+--R     + 
+--R                                                              8+-+    +-+8+-+
+--R         1   1      +-+      1   1      +-+ 8+-+4    (1 - %i)x\|c  + \|2 \|a
+--R       ((- + - %i)d\|c  + (- - - - %i)e\|a )\|c  log(------------------------)
+--R         8   8               8   8                              +-+
+--R                                                               \|2
+--R     + 
+--R                                                                8+-+    +-+8+-+
+--R           1   1      +-+    1   1      +-+ 8+-+4    (- 1 + %i)x\|c  + \|2 \|a
+--R       ((- - - - %i)d\|c  + (- + - %i)e\|a )\|c  log(--------------------------)
+--R           8   8             8   8                               +-+
+--R                                                                \|2
+--R     + 
+--R                                                                8+-+    +-+8+-+
+--R           1   1      +-+    1   1      +-+ 8+-+4    (- 1 - %i)x\|c  + \|2 \|a
+--R       ((- - + - %i)d\|c  + (- - - %i)e\|a )\|c  log(--------------------------)
+--R           8   8             8   8                               +-+
+--R                                                                \|2
+--R     + 
+--R        1      +-+ +-+ +-+   1        +-+           8+-+   8+-+
+--R       (- %i e\|2 \|a \|c  + - %i c d\|2 )log(- %i x\|c  + \|a )
+--R        8                    8
+--R     + 
+--R          1   +-+ +-+ +-+   1     +-+        8+-+   8+-+
+--R       (- - e\|2 \|a \|c  - - c d\|2 )log(- x\|c  + \|a )
+--R          8                 8
+--R  /
+--R      +-+8+-+7 +-+8+-+5
+--R     \|2 \|a  \|c \|c
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 379
+
+--S 380 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                           3 2
+--R                       512a c
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        | 4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |a e  + 12a c d e  + 38a c d e  + 12a c d e  + c d
+--R                        |--------------------------------------------------
+--R                        |                            7 5
+--R                       \|                    4194304a c
+--R                   + 
+--R                          3      3
+--R                     a d e  + c d e
+--R                /
+--R                       3 2
+--R                   256a c
+--R      *
+--R         log
+--R                            +--------------------------------------------------+
+--R                            | 4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                       5 3  |a e  + 12a c d e  + 38a c d e  + 12a c d e  + c d
+--R                  8192a c e |--------------------------------------------------
+--R                            |                            7 5
+--R                           \|                    4194304a c
+--R                + 
+--R                      3     4      2 2 3 2       3 5
+--R                  - 4a c d e  - 24a c d e  - 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                  3 2
+--R                              512a c
+--R                           *
+--R                              ROOT
+--R                                      4 8      3   2 6      2 2 4 4        3 6 2
+--R                                     a e  + 12a c d e  + 38a c d e  + 12a c d e
+--R                                   + 
+--R                                      4 8
+--R                                     c d
+--R                                /
+--R                                           7 5
+--R                                   4194304a c
+--R                          + 
+--R                                 3      3
+--R                            a d e  + c d e
+--R                       /
+--R                              3 2
+--R                          256a c
+--R            + 
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  + 5a c d e  - 5a c d e  - c d )x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                        -
+--R                                 3 2
+--R                             512a c
+--R                          *
+--R                            +--------------------------------------------------+
+--R                            | 4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                            |a e  + 12a c d e  + 38a c d e  + 12a c d e  + c d
+--R                            |--------------------------------------------------
+--R                            |                            7 5
+--R                           \|                    4194304a c
+--R                      + 
+--R                             3      3
+--R                        a d e  + c d e
+--R                   /
+--R                          3 2
+--R                      256a c
+--R         *
+--R            log
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        | 4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |a e  + 12a c d e  + 38a c d e  + 12a c d e  + c d
+--R                        |--------------------------------------------------
+--R                        |                            7 5
+--R                       \|                    4194304a c
+--R                   + 
+--R                       3     4      2 2 3 2       3 5
+--R                     4a c d e  + 24a c d e  + 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                               -
+--R                                        3 2
+--R                                    512a c
+--R                                 *
+--R                                    ROOT
+--R                                            4 8      3   2 6      2 2 4 4
+--R                                           a e  + 12a c d e  + 38a c d e
+--R                                         + 
+--R                                                3 6 2    4 8
+--R                                           12a c d e  + c d
+--R                                      /
+--R                                                 7 5
+--R                                         4194304a c
+--R                             + 
+--R                                    3      3
+--R                               a d e  + c d e
+--R                          /
+--R                                 3 2
+--R                             256a c
+--R               + 
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  + 5a c d e  - 5a c d e  - c d )x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                     -
+--R                              3 2
+--R                          512a c
+--R                       *
+--R                           +--------------------------------------------------+
+--R                           | 4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                           |a e  + 12a c d e  + 38a c d e  + 12a c d e  + c d
+--R                           |--------------------------------------------------
+--R                           |                            7 5
+--R                          \|                    4194304a c
+--R                   + 
+--R                          3      3
+--R                     a d e  + c d e
+--R                /
+--R                       3 2
+--R                   256a c
+--R      *
+--R         log
+--R                  -
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                        +--------------------------------------------------+
+--R                        | 4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                        |a e  + 12a c d e  + 38a c d e  + 12a c d e  + c d
+--R                        |--------------------------------------------------
+--R                        |                            7 5
+--R                       \|                    4194304a c
+--R                + 
+--R                      3     4      2 2 3 2       3 5
+--R                  - 4a c d e  - 24a c d e  - 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                            -
+--R                                     3 2
+--R                                 512a c
+--R                              *
+--R                                 ROOT
+--R                                         4 8      3   2 6      2 2 4 4
+--R                                        a e  + 12a c d e  + 38a c d e
+--R                                      + 
+--R                                             3 6 2    4 8
+--R                                        12a c d e  + c d
+--R                                   /
+--R                                              7 5
+--R                                      4194304a c
+--R                          + 
+--R                                 3      3
+--R                            a d e  + c d e
+--R                       /
+--R                              3 2
+--R                          256a c
+--R            + 
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  + 5a c d e  - 5a c d e  - c d )x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                              3 2
+--R                          512a c
+--R                       *
+--R                           +--------------------------------------------------+
+--R                           | 4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                           |a e  + 12a c d e  + 38a c d e  + 12a c d e  + c d
+--R                           |--------------------------------------------------
+--R                           |                            7 5
+--R                          \|                    4194304a c
+--R                      + 
+--R                             3      3
+--R                        a d e  + c d e
+--R                   /
+--R                          3 2
+--R                      256a c
+--R         *
+--R            log
+--R                     -
+--R                               5 3
+--R                          8192a c e
+--R                       *
+--R                           +--------------------------------------------------+
+--R                           | 4 8      3   2 6      2 2 4 4        3 6 2    4 8
+--R                           |a e  + 12a c d e  + 38a c d e  + 12a c d e  + c d
+--R                           |--------------------------------------------------
+--R                           |                            7 5
+--R                          \|                    4194304a c
+--R                   + 
+--R                       3     4      2 2 3 2       3 5
+--R                     4a c d e  + 24a c d e  + 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                     3 2
+--R                                 512a c
+--R                              *
+--R                                 ROOT
+--R                                         4 8      3   2 6      2 2 4 4
+--R                                        a e  + 12a c d e  + 38a c d e
+--R                                      + 
+--R                                             3 6 2    4 8
+--R                                        12a c d e  + c d
+--R                                   /
+--R                                              7 5
+--R                                      4194304a c
+--R                             + 
+--R                                    3      3
+--R                               a d e  + c d e
+--R                          /
+--R                                 3 2
+--R                             256a c
+--R               + 
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  + 5a c d e  - 5a c d e  - c d )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 380
+
+--S 381 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         1  +-+8+-+7 +-+8+-+5
+--R         - \|2 \|a  \|c \|c
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                         3 2
+--R                       2a c
+--R                    *
+--R                       ROOT
+--R                                 1     4 8      3     3   2 6      19    2 2 4 4
+--R                              ------- a e  + ------- a c d e  + ------- a c d e
+--R                              4194304        1048576            2097152
+--R                            + 
+--R                                 3       3 6 2      1     4 8
+--R                              ------- a c d e  + ------- c d
+--R                              1048576            4194304
+--R                         /
+--R                             7 5
+--R                            a c
+--R                   + 
+--R                      1       3    1     3
+--R                     --- a d e  + --- c d e
+--R                     256          256
+--R                /
+--R                    3 2
+--R                   a c
+--R      *
+--R         log
+--R                         5 3
+--R                    8192a c e
+--R                 *
+--R                    ROOT
+--R                              1     4 8      3     3   2 6      19    2 2 4 4
+--R                           ------- a e  + ------- a c d e  + ------- a c d e
+--R                           4194304        1048576            2097152
+--R                         + 
+--R                              3       3 6 2      1     4 8
+--R                           ------- a c d e  + ------- c d
+--R                           1048576            4194304
+--R                      /
+--R                          7 5
+--R                         a c
+--R                + 
+--R                      3     4      2 2 3 2       3 5
+--R                  - 4a c d e  - 24a c d e  - 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                3 2
+--R                              2a c
+--R                           *
+--R                              ROOT
+--R                                        1     4 8      3     3   2 6
+--R                                     ------- a e  + ------- a c d e
+--R                                     4194304        1048576
+--R                                   + 
+--R                                        19    2 2 4 4      3       3 6 2
+--R                                     ------- a c d e  + ------- a c d e
+--R                                     2097152            1048576
+--R                                   + 
+--R                                        1     4 8
+--R                                     ------- c d
+--R                                     4194304
+--R                                /
+--R                                    7 5
+--R                                   a c
+--R                          + 
+--R                             1       3    1     3
+--R                            --- a d e  + --- c d e
+--R                            256          256
+--R                       /
+--R                           3 2
+--R                          a c
+--R            + 
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  + 5a c d e  - 5a c d e  - c d )x
+--R     + 
+--R       -
+--R            1  +-+8+-+7 +-+8+-+5
+--R            - \|2 \|a  \|c \|c
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                        -
+--R                               3 2
+--R                             2a c
+--R                          *
+--R                             ROOT
+--R                                       1     4 8      3     3   2 6
+--R                                    ------- a e  + ------- a c d e
+--R                                    4194304        1048576
+--R                                  + 
+--R                                       19    2 2 4 4      3       3 6 2
+--R                                    ------- a c d e  + ------- a c d e
+--R                                    2097152            1048576
+--R                                  + 
+--R                                       1     4 8
+--R                                    ------- c d
+--R                                    4194304
+--R                               /
+--R                                   7 5
+--R                                  a c
+--R                      + 
+--R                         1       3    1     3
+--R                        --- a d e  + --- c d e
+--R                        256          256
+--R                   /
+--R                       3 2
+--R                      a c
+--R         *
+--R            log
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                       ROOT
+--R                                 1     4 8      3     3   2 6      19    2 2 4 4
+--R                              ------- a e  + ------- a c d e  + ------- a c d e
+--R                              4194304        1048576            2097152
+--R                            + 
+--R                                 3       3 6 2      1     4 8
+--R                              ------- a c d e  + ------- c d
+--R                              1048576            4194304
+--R                         /
+--R                             7 5
+--R                            a c
+--R                   + 
+--R                       3     4      2 2 3 2       3 5
+--R                     4a c d e  + 24a c d e  + 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                               -
+--R                                      3 2
+--R                                    2a c
+--R                                 *
+--R                                    ROOT
+--R                                              1     4 8      3     3   2 6
+--R                                           ------- a e  + ------- a c d e
+--R                                           4194304        1048576
+--R                                         + 
+--R                                              19    2 2 4 4      3       3 6 2
+--R                                           ------- a c d e  + ------- a c d e
+--R                                           2097152            1048576
+--R                                         + 
+--R                                              1     4 8
+--R                                           ------- c d
+--R                                           4194304
+--R                                      /
+--R                                          7 5
+--R                                         a c
+--R                             + 
+--R                                1       3    1     3
+--R                               --- a d e  + --- c d e
+--R                               256          256
+--R                          /
+--R                              3 2
+--R                             a c
+--R               + 
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  + 5a c d e  - 5a c d e  - c d )x
+--R     + 
+--R         1  +-+8+-+7 +-+8+-+5
+--R         - \|2 \|a  \|c \|c
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                     -
+--R                            3 2
+--R                          2a c
+--R                       *
+--R                          ROOT
+--R                                    1     4 8      3     3   2 6
+--R                                 ------- a e  + ------- a c d e
+--R                                 4194304        1048576
+--R                               + 
+--R                                    19    2 2 4 4      3       3 6 2
+--R                                 ------- a c d e  + ------- a c d e
+--R                                 2097152            1048576
+--R                               + 
+--R                                    1     4 8
+--R                                 ------- c d
+--R                                 4194304
+--R                            /
+--R                                7 5
+--R                               a c
+--R                   + 
+--R                      1       3    1     3
+--R                     --- a d e  + --- c d e
+--R                     256          256
+--R                /
+--R                    3 2
+--R                   a c
+--R      *
+--R         log
+--R                  -
+--R                            5 3
+--R                       8192a c e
+--R                    *
+--R                       ROOT
+--R                                 1     4 8      3     3   2 6      19    2 2 4 4
+--R                              ------- a e  + ------- a c d e  + ------- a c d e
+--R                              4194304        1048576            2097152
+--R                            + 
+--R                                 3       3 6 2      1     4 8
+--R                              ------- a c d e  + ------- c d
+--R                              1048576            4194304
+--R                         /
+--R                             7 5
+--R                            a c
+--R                + 
+--R                      3     4      2 2 3 2       3 5
+--R                  - 4a c d e  - 24a c d e  - 4a c d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                            -
+--R                                   3 2
+--R                                 2a c
+--R                              *
+--R                                 ROOT
+--R                                           1     4 8      3     3   2 6
+--R                                        ------- a e  + ------- a c d e
+--R                                        4194304        1048576
+--R                                      + 
+--R                                           19    2 2 4 4      3       3 6 2
+--R                                        ------- a c d e  + ------- a c d e
+--R                                        2097152            1048576
+--R                                      + 
+--R                                           1     4 8
+--R                                        ------- c d
+--R                                        4194304
+--R                                   /
+--R                                       7 5
+--R                                      a c
+--R                          + 
+--R                             1       3    1     3
+--R                            --- a d e  + --- c d e
+--R                            256          256
+--R                       /
+--R                           3 2
+--R                          a c
+--R            + 
+--R                3 6     2   2 4       2 4 2    3 6
+--R              (a e  + 5a c d e  - 5a c d e  - c d )x
+--R     + 
+--R       -
+--R            1  +-+8+-+7 +-+8+-+5
+--R            - \|2 \|a  \|c \|c
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                            3 2
+--R                          2a c
+--R                       *
+--R                          ROOT
+--R                                    1     4 8      3     3   2 6
+--R                                 ------- a e  + ------- a c d e
+--R                                 4194304        1048576
+--R                               + 
+--R                                    19    2 2 4 4      3       3 6 2
+--R                                 ------- a c d e  + ------- a c d e
+--R                                 2097152            1048576
+--R                               + 
+--R                                    1     4 8
+--R                                 ------- c d
+--R                                 4194304
+--R                            /
+--R                                7 5
+--R                               a c
+--R                      + 
+--R                         1       3    1     3
+--R                        --- a d e  + --- c d e
+--R                        256          256
+--R                   /
+--R                       3 2
+--R                      a c
+--R         *
+--R            log
+--R                     -
+--R                               5 3
+--R                          8192a c e
+--R                       *
+--R                          ROOT
+--R                                    1     4 8      3     3   2 6
+--R                                 ------- a e  + ------- a c d e
+--R                                 4194304        1048576
+--R                               + 
+--R                                    19    2 2 4 4      3       3 6 2
+--R                                 ------- a c d e  + ------- a c d e
+--R                                 2097152            1048576
+--R                               + 
+--R                                    1     4 8
+--R                                 ------- c d
+--R                                 4194304
+--R                            /
+--R                                7 5
+--R                               a c
+--R                   + 
+--R                       3     4      2 2 3 2       3 5
+--R                     4a c d e  + 24a c d e  + 4a c d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                   3 2
+--R                                 2a c
+--R                              *
+--R                                 ROOT
+--R                                           1     4 8      3     3   2 6
+--R                                        ------- a e  + ------- a c d e
+--R                                        4194304        1048576
+--R                                      + 
+--R                                           19    2 2 4 4      3       3 6 2
+--R                                        ------- a c d e  + ------- a c d e
+--R                                        2097152            1048576
+--R                                      + 
+--R                                           1     4 8
+--R                                        ------- c d
+--R                                        4194304
+--R                                   /
+--R                                       7 5
+--R                                      a c
+--R                             + 
+--R                                1       3    1     3
+--R                               --- a d e  + --- c d e
+--R                               256          256
+--R                          /
+--R                              3 2
+--R                             a c
+--R               + 
+--R                   3 6     2   2 4       2 4 2    3 6
+--R                 (a e  + 5a c d e  - 5a c d e  - c d )x
+--R     + 
+--R          1   +-+ +-+ +-+   1     +-+      8+-+   8+-+
+--R       (- - e\|2 \|a \|c  - - c d\|2 )log(x\|c  + \|a )
+--R          8                 8
+--R     + 
+--R        1      +-+ +-+ +-+   1        +-+         8+-+   8+-+
+--R       (- %i e\|2 \|a \|c  + - %i c d\|2 )log(%i x\|c  + \|a )
+--R        8                    8
+--R     + 
+--R                                                              8+-+    +-+8+-+
+--R           1   1      +-+    1   1      +-+ 8+-+4    (1 + %i)x\|c  + \|2 \|a
+--R       ((- - + - %i)d\|c  + (- - - %i)e\|a )\|c  log(------------------------)
+--R           8   8             8   8                              +-+
+--R                                                               \|2
+--R     + 
+--R                                                              8+-+    +-+8+-+
+--R           1   1      +-+    1   1      +-+ 8+-+4    (1 - %i)x\|c  + \|2 \|a
+--R       ((- - - - %i)d\|c  + (- + - %i)e\|a )\|c  log(------------------------)
+--R           8   8             8   8                              +-+
+--R                                                               \|2
+--R     + 
+--R                                                                8+-+    +-+8+-+
+--R         1   1      +-+      1   1      +-+ 8+-+4    (- 1 + %i)x\|c  + \|2 \|a
+--R       ((- + - %i)d\|c  + (- - - - %i)e\|a )\|c  log(--------------------------)
+--R         8   8               8   8                               +-+
+--R                                                                \|2
+--R     + 
+--R                                                                8+-+    +-+8+-+
+--R         1   1      +-+      1   1      +-+ 8+-+4    (- 1 - %i)x\|c  + \|2 \|a
+--R       ((- - - %i)d\|c  + (- - + - %i)e\|a )\|c  log(--------------------------)
+--R         8   8               8   8                               +-+
+--R                                                                \|2
+--R     + 
+--R          1      +-+ +-+ +-+   1        +-+           8+-+   8+-+
+--R       (- - %i e\|2 \|a \|c  - - %i c d\|2 )log(- %i x\|c  + \|a )
+--R          8                    8
+--R     + 
+--R        1   +-+ +-+ +-+   1     +-+        8+-+   8+-+
+--R       (- e\|2 \|a \|c  + - c d\|2 )log(- x\|c  + \|a )
+--R        8                 8
+--R  /
+--R      +-+8+-+7 +-+8+-+5
+--R     \|2 \|a  \|c \|c
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 381
+
+--S 382 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                        1  6 2   4     5 3 3 2   1  4 4 5 8+-+4
+--R                       (- a c d e  + 3a c d e  + - a c d )\|a
+--R                        2                        2
+--R                     + 
+--R                        1  6 2 5     5 3 2 3   1  4 4 4   4 +-+
+--R                       (- a c e  + 3a c d e  + - a c d e)x \|a
+--R                        2                      2
+--R                  *
+--R                      +-+
+--R                     \|c
+--R                 + 
+--R                    1  6 2 5     5 3 2 3   1  4 4 4   +-+8+-+4
+--R                   (- a c e  + 3a c d e  + - a c d e)\|a \|a
+--R                    2                      2
+--R                 + 
+--R                      1  6 3   4     5 4 3 2   1  4 5 5  4
+--R                   (- - a c d e  - 3a c d e  - - a c d )x
+--R                      2                        2
+--R              *
+--R                 8+-+4
+--R                 \|c
+--R             + 
+--R                      1  6 2 5     5 3 2 3   1  4 4 4   +-+8+-+4
+--R                   (- - a c e  - 3a c d e  - - a c d e)\|a \|a
+--R                      2                      2
+--R                 + 
+--R                    1  6 3   4     5 4 3 2   1  4 5 5  4
+--R                   (- a c d e  + 3a c d e  + - a c d )x
+--R                    2                        2
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                1  5 4   4     4 5 3 2   1  3 6 5  8 8+-+4
+--R               (- a c d e  + 3a c d e  + - a c d )x  \|a
+--R                2                        2
+--R             + 
+--R                1  6 3 5     5 4 2 3   1  4 5 4   4 +-+
+--R               (- a c e  + 3a c d e  + - a c d e)x \|a
+--R                2                      2
+--R          *
+--R             ROOT
+--R                    -
+--R                           3 2
+--R                         2a c
+--R                      *
+--R                         ROOT
+--R                                   1     4 8      3     3   2 6
+--R                                ------- a e  + ------- a c d e
+--R                                4194304        1048576
+--R                              + 
+--R                                 19    2 2 4 4      3       3 6 2      1     4 8
+--R                              ------- a c d e  + ------- a c d e  + ------- c d
+--R                              2097152            1048576            4194304
+--R                           /
+--R                               7 5
+--R                              a c
+--R                  + 
+--R                     1       3    1     3
+--R                    --- a d e  + --- c d e
+--R                    256          256
+--R               /
+--R                   3 2
+--R                  a c
+--R         + 
+--R                       6 4 2   2 8+-+4     6 4   2 6 +-+  +-+
+--R                   (64a c d e x  \|a  + 64a c d e x \|a )\|c
+--R                 + 
+--R                      6 4   2 2 +-+8+-+4      6 5 2   6
+--R                   64a c d e x \|a \|a   - 64a c d e x
+--R              *
+--R                 8+-+4
+--R                 \|c
+--R             + 
+--R                     6 4   2 2 +-+8+-+4      6 5 2   6  +-+
+--R               (- 64a c d e x \|a \|a   + 64a c d e x )\|c
+--R             + 
+--R                      6 5 3      5 6 2   10       7 4 3      6 5 2   2 8+-+4
+--R               ((- 16a c e  + 16a c d e)x   + (16a c e  + 48a c d e)x )\|a
+--R             + 
+--R                  6 5   2 6 +-+
+--R               64a c d e x \|a
+--R          *
+--R             ROOT
+--R                       1     4 8      3     3   2 6      19    2 2 4 4
+--R                    ------- a e  + ------- a c d e  + ------- a c d e
+--R                    4194304        1048576            2097152
+--R                  + 
+--R                       3       3 6 2      1     4 8
+--R                    ------- a c d e  + ------- c d
+--R                    1048576            4194304
+--R               /
+--R                   7 5
+--R                  a c
+--R         + 
+--R                         1  5     6    7  4 2 3 4    7  3 3 5 2    1  2 4 7  2
+--R                     (- -- a c d e  - -- a c d e  - -- a c d e  - -- a c d )x
+--R                        64            64            64            64
+--R                  *
+--R                     8+-+4
+--R                     \|a
+--R                 + 
+--R                       1  5   7    7  4 2 2 5    7  3 3 4 3    1  2 4 6   6 +-+
+--R                   (- -- a c e  - -- a c d e  - -- a c d e  - -- a c d e)x \|a
+--R                      64          64            64            64
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                   1  5   7    7  4 2 2 5    7  3 3 4 3    1  2 4 6   2 +-+8+-+4
+--R               (- -- a c e  - -- a c d e  - -- a c d e  - -- a c d e)x \|a \|a
+--R                  64          64            64            64
+--R             + 
+--R                 1  5 2   6    7  4 3 3 4    7  3 4 5 2    1  2 5 7  6
+--R               (-- a c d e  + -- a c d e  + -- a c d e  + -- a c d )x
+--R                64            64            64            64
+--R          *
+--R             8+-+4
+--R             \|c
+--R         + 
+--R                 1  5   7    7  4 2 2 5    7  3 3 4 3    1  2 4 6   2 +-+8+-+4
+--R               (-- a c e  + -- a c d e  + -- a c d e  + -- a c d e)x \|a \|a
+--R                64          64            64            64
+--R             + 
+--R                   1  5 2   6    7  4 3 3 4    7  3 4 5 2    1  2 5 7  6
+--R               (- -- a c d e  - -- a c d e  - -- a c d e  - -- a c d )x
+--R                  64            64            64            64
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                 1   4 3   6    5   3 4 3 4    5   2 5 5 2    1     6 7  10
+--R               (--- a c d e  + --- a c d e  - --- a c d e  - --- a c d )x
+--R                128            128            128            128
+--R             + 
+--R                   3   5 2   6    19  4 3 3 4    9   3 4 5 2    1   2 5 7  2
+--R               (- --- a c d e  - --- a c d e  - --- a c d e  - --- a c d )x
+--R                  128            128            128            128
+--R          *
+--R             8+-+4
+--R             \|a
+--R         + 
+--R               1  5 2 7    7  4 3 2 5    7  3 4 4 3    1  2 5 6   6 +-+
+--R           (- -- a c e  - -- a c d e  - -- a c d e  - -- a c d e)x \|a
+--R              64          64            64            64
+--R      *
+--R         ROOT
+--R                    3 2
+--R                  2a c
+--R               *
+--R                  ROOT
+--R                            1     4 8      3     3   2 6      19    2 2 4 4
+--R                         ------- a e  + ------- a c d e  + ------- a c d e
+--R                         4194304        1048576            2097152
+--R                       + 
+--R                            3       3 6 2      1     4 8
+--R                         ------- a c d e  + ------- c d
+--R                         1048576            4194304
+--R                    /
+--R                        7 5
+--R                       a c
+--R              + 
+--R                 1       3    1     3
+--R                --- a d e  + --- c d e
+--R                256          256
+--R           /
+--R               3 2
+--R              a c
+--R     + 
+--R                         6 4 2   2 8+-+4     6 4   2 6 +-+  +-+
+--R                   (- 64a c d e x  \|a  - 64a c d e x \|a )\|c
+--R                 + 
+--R                        6 4   2 2 +-+8+-+4      6 5 2   6
+--R                   - 64a c d e x \|a \|a   + 64a c d e x
+--R              *
+--R                 8+-+4
+--R                 \|c
+--R             + 
+--R                   6 4   2 2 +-+8+-+4      6 5 2   6  +-+
+--R               (64a c d e x \|a \|a   - 64a c d e x )\|c
+--R             + 
+--R                    6 5 3      5 6 2   10         7 4 3      6 5 2   2 8+-+4
+--R               ((16a c e  - 16a c d e)x   + (- 16a c e  - 48a c d e)x )\|a
+--R             + 
+--R                    6 5   2 6 +-+
+--R               - 64a c d e x \|a
+--R          *
+--R             ROOT
+--R                       1     4 8      3     3   2 6      19    2 2 4 4
+--R                    ------- a e  + ------- a c d e  + ------- a c d e
+--R                    4194304        1048576            2097152
+--R                  + 
+--R                       3       3 6 2      1     4 8
+--R                    ------- a c d e  + ------- c d
+--R                    1048576            4194304
+--R               /
+--R                   7 5
+--R                  a c
+--R         + 
+--R                         1  5     6    7  4 2 3 4    7  3 3 5 2    1  2 4 7  2
+--R                     (- -- a c d e  - -- a c d e  - -- a c d e  - -- a c d )x
+--R                        64            64            64            64
+--R                  *
+--R                     8+-+4
+--R                     \|a
+--R                 + 
+--R                       1  5   7    7  4 2 2 5    7  3 3 4 3    1  2 4 6   6 +-+
+--R                   (- -- a c e  - -- a c d e  - -- a c d e  - -- a c d e)x \|a
+--R                      64          64            64            64
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                   1  5   7    7  4 2 2 5    7  3 3 4 3    1  2 4 6   2 +-+8+-+4
+--R               (- -- a c e  - -- a c d e  - -- a c d e  - -- a c d e)x \|a \|a
+--R                  64          64            64            64
+--R             + 
+--R                 1  5 2   6    7  4 3 3 4    7  3 4 5 2    1  2 5 7  6
+--R               (-- a c d e  + -- a c d e  + -- a c d e  + -- a c d )x
+--R                64            64            64            64
+--R          *
+--R             8+-+4
+--R             \|c
+--R         + 
+--R                 1  5   7    7  4 2 2 5    7  3 3 4 3    1  2 4 6   2 +-+8+-+4
+--R               (-- a c e  + -- a c d e  + -- a c d e  + -- a c d e)x \|a \|a
+--R                64          64            64            64
+--R             + 
+--R                   1  5 2   6    7  4 3 3 4    7  3 4 5 2    1  2 5 7  6
+--R               (- -- a c d e  - -- a c d e  - -- a c d e  - -- a c d )x
+--R                  64            64            64            64
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                 1   4 3   6    5   3 4 3 4    5   2 5 5 2    1     6 7  10
+--R               (--- a c d e  + --- a c d e  - --- a c d e  - --- a c d )x
+--R                128            128            128            128
+--R             + 
+--R                   3   5 2   6    19  4 3 3 4    9   3 4 5 2    1   2 5 7  2
+--R               (- --- a c d e  - --- a c d e  - --- a c d e  - --- a c d )x
+--R                  128            128            128            128
+--R          *
+--R             8+-+4
+--R             \|a
+--R         + 
+--R               1  5 2 7    7  4 3 2 5    7  3 4 4 3    1  2 5 6   6 +-+
+--R           (- -- a c e  - -- a c d e  - -- a c d e  - -- a c d e)x \|a
+--R              64          64            64            64
+--R      *
+--R         ROOT
+--R                -
+--R                       3 2
+--R                     2a c
+--R                  *
+--R                     ROOT
+--R                               1     4 8      3     3   2 6      19    2 2 4 4
+--R                            ------- a e  + ------- a c d e  + ------- a c d e
+--R                            4194304        1048576            2097152
+--R                          + 
+--R                               3       3 6 2      1     4 8
+--R                            ------- a c d e  + ------- c d
+--R                            1048576            4194304
+--R                       /
+--R                           7 5
+--R                          a c
+--R              + 
+--R                 1       3    1     3
+--R                --- a d e  + --- c d e
+--R                256          256
+--R           /
+--R               3 2
+--R              a c
+--R     + 
+--R                     1   4   8    1   3   3 6     5   2 2 5 4    1     3 7 2
+--R                   ---- a d e  + --- a c d e  - ---- a c d e  + --- a c d e
+--R                   2048          512            1024            512
+--R                 + 
+--R                     1   4 9
+--R                   ---- c d
+--R                   2048
+--R              *
+--R                  4 8+-+4
+--R                 x  \|a
+--R             + 
+--R                     1   4 9    1   3   2 7     5   2 2 4 5    1     3 6 3
+--R                   ---- a e  + --- a c d e  - ---- a c d e  + --- a c d e
+--R                   2048        512            1024            512
+--R                 + 
+--R                     1   4 8
+--R                   ---- c d e
+--R                   2048
+--R              *
+--R                  8 +-+
+--R                 x \|a
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                 1   4 9    1   3   2 7     5   2 2 4 5    1     3 6 3
+--R               ---- a e  + --- a c d e  - ---- a c d e  + --- a c d e
+--R               2048        512            1024            512
+--R             + 
+--R                 1   4 8
+--R               ---- c d e
+--R               2048
+--R          *
+--R              4 +-+8+-+4
+--R             x \|a \|a
+--R         + 
+--R                   1   4     8    1   3 2 3 6     5   2 3 5 4    1     4 7 2
+--R               - ---- a c d e  - --- a c d e  + ---- a c d e  - --- a c d e
+--R                 2048            512            1024            512
+--R             + 
+--R                   1   5 9
+--R               - ---- c d
+--R                 2048
+--R          *
+--R              8
+--R             x
+--R      *
+--R         8+-+4
+--R         \|c
+--R     + 
+--R                   1   4 9    1   3   2 7     5   2 2 4 5    1     3 6 3
+--R               - ---- a e  - --- a c d e  + ---- a c d e  - --- a c d e
+--R                 2048        512            1024            512
+--R             + 
+--R                   1   4 8
+--R               - ---- c d e
+--R                 2048
+--R          *
+--R              4 +-+8+-+4
+--R             x \|a \|a
+--R         + 
+--R                 1   4     8    1   3 2 3 6     5   2 3 5 4    1     4 7 2
+--R               ---- a c d e  + --- a c d e  - ---- a c d e  + --- a c d e
+--R               2048            512            1024            512
+--R             + 
+--R                 1   5 9
+--R               ---- c d
+--R               2048
+--R          *
+--R              8
+--R             x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R               1   4     8    1   3 2 3 6     5   2 3 5 4    1     4 7 2
+--R             ---- a c d e  + --- a c d e  - ---- a c d e  + --- a c d e
+--R             2048            512            1024            512
+--R           + 
+--R               1   5 9
+--R             ---- c d
+--R             2048
+--R      *
+--R          4 8+-+4
+--R         x  \|a
+--R     + 
+--R               1   4   9    1   3 2 2 7     5   2 3 4 5    1     4 6 3
+--R             ---- a c e  + --- a c d e  - ---- a c d e  + --- a c d e
+--R             2048          512            1024            512
+--R           + 
+--R               1   5 8
+--R             ---- c d e
+--R             2048
+--R      *
+--R          8 +-+
+--R         x \|a
+--R  /
+--R                6 4 4     5 5 2 2    4 6 4  8    7 3 4     6 4 2 2    5 5 4
+--R             ((a c e  + 6a c d e  + a c d )x  - a c e  - 6a c d e  - a c d )
+--R          *
+--R             8+-+4
+--R             \|a
+--R          *
+--R             ROOT
+--R                    -
+--R                           3 2
+--R                         2a c
+--R                      *
+--R                         ROOT
+--R                                   1     4 8      3     3   2 6
+--R                                ------- a e  + ------- a c d e
+--R                                4194304        1048576
+--R                              + 
+--R                                 19    2 2 4 4      3       3 6 2      1     4 8
+--R                              ------- a c d e  + ------- a c d e  + ------- c d
+--R                              2097152            1048576            4194304
+--R                           /
+--R                               7 5
+--R                              a c
+--R                  + 
+--R                     1       3    1     3
+--R                    --- a d e  + --- c d e
+--R                    256          256
+--R               /
+--R                   3 2
+--R                  a c
+--R         + 
+--R                  6 6     10       7 5     2 8+-+4
+--R             (128a c d e x   - 128a c d e x )\|a
+--R          *
+--R             ROOT
+--R                       1     4 8      3     3   2 6      19    2 2 4 4
+--R                    ------- a e  + ------- a c d e  + ------- a c d e
+--R                    4194304        1048576            2097152
+--R                  + 
+--R                       3       3 6 2      1     4 8
+--R                    ------- a c d e  + ------- c d
+--R                    1048576            4194304
+--R               /
+--R                   7 5
+--R                  a c
+--R         + 
+--R                   1  5 3 6    7  4 4 2 4    7  3 5 4 2    1  2 6 6  10
+--R               (- -- a c e  - -- a c d e  - -- a c d e  - -- a c d )x
+--R                  32          32            32            32
+--R             + 
+--R                 1  6 2 6    7  5 3 2 4    7  4 4 4 2    1  3 5 6  2
+--R               (-- a c e  + -- a c d e  + -- a c d e  + -- a c d )x
+--R                32          32            32            32
+--R          *
+--R             8+-+4
+--R             \|a
+--R      *
+--R         ROOT
+--R                    3 2
+--R                  2a c
+--R               *
+--R                  ROOT
+--R                            1     4 8      3     3   2 6      19    2 2 4 4
+--R                         ------- a e  + ------- a c d e  + ------- a c d e
+--R                         4194304        1048576            2097152
+--R                       + 
+--R                            3       3 6 2      1     4 8
+--R                         ------- a c d e  + ------- c d
+--R                         1048576            4194304
+--R                    /
+--R                        7 5
+--R                       a c
+--R              + 
+--R                 1       3    1     3
+--R                --- a d e  + --- c d e
+--R                256          256
+--R           /
+--R               3 2
+--R              a c
+--R     + 
+--R                    6 6     10       7 5     2 8+-+4
+--R             (- 128a c d e x   + 128a c d e x )\|a
+--R          *
+--R             ROOT
+--R                       1     4 8      3     3   2 6      19    2 2 4 4
+--R                    ------- a e  + ------- a c d e  + ------- a c d e
+--R                    4194304        1048576            2097152
+--R                  + 
+--R                       3       3 6 2      1     4 8
+--R                    ------- a c d e  + ------- c d
+--R                    1048576            4194304
+--R               /
+--R                   7 5
+--R                  a c
+--R         + 
+--R                   1  5 3 6    7  4 4 2 4    7  3 5 4 2    1  2 6 6  10
+--R               (- -- a c e  - -- a c d e  - -- a c d e  - -- a c d )x
+--R                  32          32            32            32
+--R             + 
+--R                 1  6 2 6    7  5 3 2 4    7  4 4 4 2    1  3 5 6  2
+--R               (-- a c e  + -- a c d e  + -- a c d e  + -- a c d )x
+--R                32          32            32            32
+--R          *
+--R             8+-+4
+--R             \|a
+--R      *
+--R         ROOT
+--R                -
+--R                       3 2
+--R                     2a c
+--R                  *
+--R                     ROOT
+--R                               1     4 8      3     3   2 6      19    2 2 4 4
+--R                            ------- a e  + ------- a c d e  + ------- a c d e
+--R                            4194304        1048576            2097152
+--R                          + 
+--R                               3       3 6 2      1     4 8
+--R                            ------- a c d e  + ------- c d
+--R                            1048576            4194304
+--R                       /
+--R                           7 5
+--R                          a c
+--R              + 
+--R                 1       3    1     3
+--R                --- a d e  + --- c d e
+--R                256          256
+--R           /
+--R               3 2
+--R              a c
+--R     + 
+--R                 1   4 2 8    1   3 3 2 6    5   2 4 4 4    1     5 6 2
+--R               ---- a c e  + --- a c d e  - --- a c d e  + --- a c d e
+--R               1024          256            512            256
+--R             + 
+--R                 1   6 8
+--R               ---- c d
+--R               1024
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                   1   5   8    1   4 2 2 6    5   3 3 4 4    1   2 4 6 2
+--R               - ---- a c e  - --- a c d e  + --- a c d e  - --- a c d e
+--R                 1024          256            512            256
+--R             + 
+--R                   1     5 8
+--R               - ---- a c d
+--R                 1024
+--R          *
+--R              4
+--R             x
+--R      *
+--R         8+-+4
+--R         \|a
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 382
+
+)clear all
+
+--S 383 of 649
+t0:=(b+2*c*x)*(a+b*x+c*x^2)^13
+--R 
+--R
+--R   (1)
+--R       14 27        13 26         13       2 12  25            12       3 11  24
+--R     2c  x   + 27b c  x   + (26a c   + 169b c  )x   + (325a b c   + 650b c  )x
+--R   + 
+--R          2 12          2 11        4 10  23
+--R     (156a c   + 1872a b c   + 1716b c  )x
+--R   + 
+--R           2   11          3 10        5 9  22
+--R     (1794a b c   + 6578a b c   + 3289b c )x
+--R   + 
+--R          3 11        2 2 10           4 9        6 8  21
+--R     (572a c   + 9438a b c   + 15730a b c  + 4719b c )x
+--R   + 
+--R           3   10         2 3 9           5 8        7 7  20
+--R     (6006a b c   + 30030a b c  + 27027a b c  + 5148b c )x
+--R   + 
+--R           4 10         3 2 9         2 4 8           6 7        8 6  19
+--R     (1430a c   + 28600a b c  + 64350a b c  + 34320a b c  + 4290b c )x
+--R   + 
+--R            4   9         3 3 8         2 5 7           7 6        9 5  18
+--R     (13585a b c  + 81510a b c  + 97812a b c  + 32604a b c  + 2717b c )x
+--R   + 
+--R              5 9         4 2 8          3 4 7          2 6 6           8 5
+--R         2574a c  + 57915a b c  + 154440a b c  + 108108a b c  + 23166a b c
+--R       + 
+--R              10 4
+--R         1287b  c
+--R    *
+--R        17
+--R       x
+--R   + 
+--R               5   8          4 3 7          3 5 6         2 7 5           9 4
+--R         21879a b c  + 145860a b c  + 204204a b c  + 87516a b c  + 12155a b c
+--R       + 
+--R             11 3
+--R         442b  c
+--R    *
+--R        16
+--R       x
+--R   + 
+--R              6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R         3432a c  + 82368a b c  + 240240a b c  + 192192a b c  + 51480a b c
+--R       + 
+--R                10 3       12 2
+--R         4576a b  c  + 104b  c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R               6   7          5 3 6          4 5 5          3 7 4         2 9 3
+--R         25740a b c  + 180180a b c  + 270270a b c  + 128700a b c  + 21450a b c
+--R       + 
+--R                11 2      13
+--R         1170a b  c  + 15b  c
+--R    *
+--R        14
+--R       x
+--R   + 
+--R              7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R         3432a c  + 84084a b c  + 252252a b c  + 210210a b c  + 60060a b c
+--R       + 
+--R              2 10 2         12     14
+--R         6006a b  c  + 182a b  c + b
+--R    *
+--R        13
+--R       x
+--R   + 
+--R               7   6          6 3 5          5 5 4          4 7 3         3 9 2
+--R         22308a b c  + 156156a b c  + 234234a b c  + 111540a b c  + 18590a b c
+--R       + 
+--R              2 11         13
+--R         1014a b  c + 13a b
+--R    *
+--R        12
+--R       x
+--R   + 
+--R              8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R         2574a c  + 61776a b c  + 180180a b c  + 144144a b c  + 38610a b c
+--R       + 
+--R              3 10       2 12
+--R         3432a b  c + 78a b
+--R    *
+--R        11
+--R       x
+--R   + 
+--R               8   5         7 3 4          6 5 3         5 7 2        4 9
+--R         14157a b c  + 94380a b c  + 132132a b c  + 56628a b c  + 7865a b c
+--R       + 
+--R             3 11
+--R         286a b
+--R    *
+--R        10
+--R       x
+--R   + 
+--R              9 5         8 2 4         7 4 3         6 6 2         5 8
+--R         1430a c  + 32175a b c  + 85800a b c  + 60060a b c  + 12870a b c
+--R       + 
+--R             4 10
+--R         715a b
+--R    *
+--R        9
+--R       x
+--R   + 
+--R           9   4         8 3 3         7 5 2         6 7         5 9  8
+--R     (6435a b c  + 38610a b c  + 46332a b c  + 15444a b c + 1287a b )x
+--R   + 
+--R          10 4         9 2 3         8 4 2         7 6         6 8  7
+--R     (572a  c  + 11440a b c  + 25740a b c  + 13728a b c + 1716a b )x
+--R   + 
+--R           10   3         9 3 2        8 5         7 7  6
+--R     (2002a  b c  + 10010a b c  + 9009a b c + 1716a b )x
+--R   + 
+--R          11 3        10 2 2        9 4         8 6  5
+--R     (156a  c  + 2574a  b c  + 4290a b c + 1287a b )x
+--R   + 
+--R          11   2        10 3        9 5  4       12 2       11 2        10 4  3
+--R     (390a  b c  + 1430a  b c + 715a b )x  + (26a  c  + 312a  b c + 286a  b )x
+--R   + 
+--R         12         11 3  2      13       12 2      13
+--R     (39a  b c + 78a  b )x  + (2a  c + 13a  b )x + a  b
+--R                                                    Type: Polynomial(Integer)
+--E 383
+
+--S 384 of 649
+r0:=1/14*(a+b*x+c*x^2)^14
+--R 
+--R
+--R   (2)
+--R      1  14 28      13 27       13   13  2 12  26           12      3 11  25
+--R     -- c  x   + b c  x   + (a c   + -- b c  )x   + (13a b c   + 26b c  )x
+--R     14                               2
+--R   + 
+--R      13  2 12        2 11   143  4 10  24
+--R     (-- a c   + 78a b c   + --- b c  )x
+--R       2                      2
+--R   + 
+--R         2   11         3 10       5 9  23
+--R     (78a b c   + 286a b c   + 143b c )x
+--R   + 
+--R         3 11       2 2 10         4 9   429  6 8  22
+--R     (26a c   + 429a b c   + 715a b c  + --- b c )x
+--R                                          2
+--R   + 
+--R          3   10        2 3 9          5 8   1716  7 7  21
+--R     (286a b c   + 1430a b c  + 1287a b c  + ---- b c )x
+--R                                               7
+--R   + 
+--R      143  4 10        3 2 9   6435  2 4 8          6 7   429  8 6  20
+--R     (--- a c   + 1430a b c  + ---- a b c  + 1716a b c  + --- b c )x
+--R       2                         2                         2
+--R   + 
+--R          4   9        3 3 8        2 5 7          7 6       9 5  19
+--R     (715a b c  + 4290a b c  + 5148a b c  + 1716a b c  + 143b c )x
+--R   + 
+--R               5 9   6435  4 2 8        3 4 7        2 6 6          8 5
+--R           143a c  + ---- a b c  + 8580a b c  + 6006a b c  + 1287a b c
+--R                       2
+--R         + 
+--R           143  10 4
+--R           --- b  c
+--R            2
+--R    *
+--R        18
+--R       x
+--R   + 
+--R                5   8        4 3 7         3 5 6        2 7 5         9 4
+--R           1287a b c  + 8580a b c  + 12012a b c  + 5148a b c  + 715a b c
+--R         + 
+--R              11 3
+--R           26b  c
+--R    *
+--R        17
+--R       x
+--R   + 
+--R         429  6 8        5 2 7         4 4 6         3 6 5   6435  2 8 4
+--R         --- a c  + 5148a b c  + 15015a b c  + 12012a b c  + ---- a b c
+--R          2                                                    2
+--R       + 
+--R               10 3   13  12 2
+--R         286a b  c  + -- b  c
+--R                       2
+--R    *
+--R        16
+--R       x
+--R   + 
+--R              6   7         5 3 6         4 5 5        3 7 4        2 9 3
+--R         1716a b c  + 12012a b c  + 18018a b c  + 8580a b c  + 1430a b c
+--R       + 
+--R              11 2    13
+--R         78a b  c  + b  c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R         1716  7 7        6 2 6         5 4 5         4 6 4        3 8 3
+--R         ---- a c  + 6006a b c  + 18018a b c  + 15015a b c  + 4290a b c
+--R           7
+--R       + 
+--R             2 10 2        12     1  14
+--R         429a b  c  + 13a b  c + -- b
+--R                                 14
+--R    *
+--R        14
+--R       x
+--R   + 
+--R              7   6         6 3 5         5 5 4        4 7 3        3 9 2
+--R         1716a b c  + 12012a b c  + 18018a b c  + 8580a b c  + 1430a b c
+--R       + 
+--R            2 11       13
+--R         78a b  c + a b
+--R    *
+--R        13
+--R       x
+--R   + 
+--R         429  8 6        7 2 5         6 4 4         5 6 3   6435  4 8 2
+--R         --- a c  + 5148a b c  + 15015a b c  + 12012a b c  + ---- a b c
+--R          2                                                    2
+--R       + 
+--R             3 10    13  2 12
+--R         286a b  c + -- a b
+--R                      2
+--R    *
+--R        12
+--R       x
+--R   + 
+--R             8   5        7 3 4         6 5 3        5 7 2       4 9       3 11
+--R       (1287a b c  + 8580a b c  + 12012a b c  + 5148a b c  + 715a b c + 26a b  )
+--R    *
+--R        11
+--R       x
+--R   + 
+--R            9 5   6435  8 2 4        7 4 3        6 6 2        5 8    143  4 10
+--R       (143a c  + ---- a b c  + 8580a b c  + 6006a b c  + 1287a b c + --- a b  )
+--R                    2                                                  2
+--R    *
+--R        10
+--R       x
+--R   + 
+--R          9   4        8 3 3        7 5 2        6 7        5 9  9
+--R     (715a b c  + 4290a b c  + 5148a b c  + 1716a b c + 143a b )x
+--R   + 
+--R      143  10 4        9 2 3   6435  8 4 2        7 6    429  6 8  8
+--R     (--- a  c  + 1430a b c  + ---- a b c  + 1716a b c + --- a b )x
+--R       2                         2                        2
+--R   + 
+--R          10   3        9 3 2        8 5    1716  7 7  7
+--R     (286a  b c  + 1430a b c  + 1287a b c + ---- a b )x
+--R                                              7
+--R   + 
+--R         11 3       10 2 2       9 4    429  8 6  6
+--R     (26a  c  + 429a  b c  + 715a b c + --- a b )x
+--R                                         2
+--R   + 
+--R         11   2       10 3        9 5  5    13  12 2      11 2    143  10 4  4
+--R     (78a  b c  + 286a  b c + 143a b )x  + (-- a  c  + 78a  b c + --- a  b )x
+--R                                             2                     2
+--R   + 
+--R         12         11 3  3     13    13  12 2  2    13       1  14
+--R     (13a  b c + 26a  b )x  + (a  c + -- a  b )x  + a  b x + -- a
+--R                                       2                     14
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 384
+
+--S 385 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 28      13 27       13   13  2 12  26           12      3 11  25
+--R     -- c  x   + b c  x   + (a c   + -- b c  )x   + (13a b c   + 26b c  )x
+--R     14                               2
+--R   + 
+--R      13  2 12        2 11   143  4 10  24
+--R     (-- a c   + 78a b c   + --- b c  )x
+--R       2                      2
+--R   + 
+--R         2   11         3 10       5 9  23
+--R     (78a b c   + 286a b c   + 143b c )x
+--R   + 
+--R         3 11       2 2 10         4 9   429  6 8  22
+--R     (26a c   + 429a b c   + 715a b c  + --- b c )x
+--R                                          2
+--R   + 
+--R          3   10        2 3 9          5 8   1716  7 7  21
+--R     (286a b c   + 1430a b c  + 1287a b c  + ---- b c )x
+--R                                               7
+--R   + 
+--R      143  4 10        3 2 9   6435  2 4 8          6 7   429  8 6  20
+--R     (--- a c   + 1430a b c  + ---- a b c  + 1716a b c  + --- b c )x
+--R       2                         2                         2
+--R   + 
+--R          4   9        3 3 8        2 5 7          7 6       9 5  19
+--R     (715a b c  + 4290a b c  + 5148a b c  + 1716a b c  + 143b c )x
+--R   + 
+--R               5 9   6435  4 2 8        3 4 7        2 6 6          8 5
+--R           143a c  + ---- a b c  + 8580a b c  + 6006a b c  + 1287a b c
+--R                       2
+--R         + 
+--R           143  10 4
+--R           --- b  c
+--R            2
+--R    *
+--R        18
+--R       x
+--R   + 
+--R                5   8        4 3 7         3 5 6        2 7 5         9 4
+--R           1287a b c  + 8580a b c  + 12012a b c  + 5148a b c  + 715a b c
+--R         + 
+--R              11 3
+--R           26b  c
+--R    *
+--R        17
+--R       x
+--R   + 
+--R         429  6 8        5 2 7         4 4 6         3 6 5   6435  2 8 4
+--R         --- a c  + 5148a b c  + 15015a b c  + 12012a b c  + ---- a b c
+--R          2                                                    2
+--R       + 
+--R               10 3   13  12 2
+--R         286a b  c  + -- b  c
+--R                       2
+--R    *
+--R        16
+--R       x
+--R   + 
+--R              6   7         5 3 6         4 5 5        3 7 4        2 9 3
+--R         1716a b c  + 12012a b c  + 18018a b c  + 8580a b c  + 1430a b c
+--R       + 
+--R              11 2    13
+--R         78a b  c  + b  c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R         1716  7 7        6 2 6         5 4 5         4 6 4        3 8 3
+--R         ---- a c  + 6006a b c  + 18018a b c  + 15015a b c  + 4290a b c
+--R           7
+--R       + 
+--R             2 10 2        12     1  14
+--R         429a b  c  + 13a b  c + -- b
+--R                                 14
+--R    *
+--R        14
+--R       x
+--R   + 
+--R              7   6         6 3 5         5 5 4        4 7 3        3 9 2
+--R         1716a b c  + 12012a b c  + 18018a b c  + 8580a b c  + 1430a b c
+--R       + 
+--R            2 11       13
+--R         78a b  c + a b
+--R    *
+--R        13
+--R       x
+--R   + 
+--R         429  8 6        7 2 5         6 4 4         5 6 3   6435  4 8 2
+--R         --- a c  + 5148a b c  + 15015a b c  + 12012a b c  + ---- a b c
+--R          2                                                    2
+--R       + 
+--R             3 10    13  2 12
+--R         286a b  c + -- a b
+--R                      2
+--R    *
+--R        12
+--R       x
+--R   + 
+--R             8   5        7 3 4         6 5 3        5 7 2       4 9       3 11
+--R       (1287a b c  + 8580a b c  + 12012a b c  + 5148a b c  + 715a b c + 26a b  )
+--R    *
+--R        11
+--R       x
+--R   + 
+--R            9 5   6435  8 2 4        7 4 3        6 6 2        5 8    143  4 10
+--R       (143a c  + ---- a b c  + 8580a b c  + 6006a b c  + 1287a b c + --- a b  )
+--R                    2                                                  2
+--R    *
+--R        10
+--R       x
+--R   + 
+--R          9   4        8 3 3        7 5 2        6 7        5 9  9
+--R     (715a b c  + 4290a b c  + 5148a b c  + 1716a b c + 143a b )x
+--R   + 
+--R      143  10 4        9 2 3   6435  8 4 2        7 6    429  6 8  8
+--R     (--- a  c  + 1430a b c  + ---- a b c  + 1716a b c + --- a b )x
+--R       2                         2                        2
+--R   + 
+--R          10   3        9 3 2        8 5    1716  7 7  7
+--R     (286a  b c  + 1430a b c  + 1287a b c + ---- a b )x
+--R                                              7
+--R   + 
+--R         11 3       10 2 2       9 4    429  8 6  6
+--R     (26a  c  + 429a  b c  + 715a b c + --- a b )x
+--R                                         2
+--R   + 
+--R         11   2       10 3        9 5  5    13  12 2      11 2    143  10 4  4
+--R     (78a  b c  + 286a  b c + 143a b )x  + (-- a  c  + 78a  b c + --- a  b )x
+--R                                             2                     2
+--R   + 
+--R         12         11 3  3     13    13  12 2  2    13
+--R     (13a  b c + 26a  b )x  + (a  c + -- a  b )x  + a  b x
+--R                                       2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 385
+
+--S 386 of 649
+m0:=a0-r0
+--R 
+--R
+--R           1  14
+--R   (4)  - -- a
+--R          14
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 386
+
+--S 387 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 387
+
+)clear all
+
+--S 388 of 649
+t0:=x*(b+2*c*x^2)*(a+b*x^2+c*x^4)^13
+--R 
+--R
+--R   (1)
+--R       14 55        13 53         13       2 12  51            12       3 11  49
+--R     2c  x   + 27b c  x   + (26a c   + 169b c  )x   + (325a b c   + 650b c  )x
+--R   + 
+--R          2 12          2 11        4 10  47
+--R     (156a c   + 1872a b c   + 1716b c  )x
+--R   + 
+--R           2   11          3 10        5 9  45
+--R     (1794a b c   + 6578a b c   + 3289b c )x
+--R   + 
+--R          3 11        2 2 10           4 9        6 8  43
+--R     (572a c   + 9438a b c   + 15730a b c  + 4719b c )x
+--R   + 
+--R           3   10         2 3 9           5 8        7 7  41
+--R     (6006a b c   + 30030a b c  + 27027a b c  + 5148b c )x
+--R   + 
+--R           4 10         3 2 9         2 4 8           6 7        8 6  39
+--R     (1430a c   + 28600a b c  + 64350a b c  + 34320a b c  + 4290b c )x
+--R   + 
+--R            4   9         3 3 8         2 5 7           7 6        9 5  37
+--R     (13585a b c  + 81510a b c  + 97812a b c  + 32604a b c  + 2717b c )x
+--R   + 
+--R              5 9         4 2 8          3 4 7          2 6 6           8 5
+--R         2574a c  + 57915a b c  + 154440a b c  + 108108a b c  + 23166a b c
+--R       + 
+--R              10 4
+--R         1287b  c
+--R    *
+--R        35
+--R       x
+--R   + 
+--R               5   8          4 3 7          3 5 6         2 7 5           9 4
+--R         21879a b c  + 145860a b c  + 204204a b c  + 87516a b c  + 12155a b c
+--R       + 
+--R             11 3
+--R         442b  c
+--R    *
+--R        33
+--R       x
+--R   + 
+--R              6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R         3432a c  + 82368a b c  + 240240a b c  + 192192a b c  + 51480a b c
+--R       + 
+--R                10 3       12 2
+--R         4576a b  c  + 104b  c
+--R    *
+--R        31
+--R       x
+--R   + 
+--R               6   7          5 3 6          4 5 5          3 7 4         2 9 3
+--R         25740a b c  + 180180a b c  + 270270a b c  + 128700a b c  + 21450a b c
+--R       + 
+--R                11 2      13
+--R         1170a b  c  + 15b  c
+--R    *
+--R        29
+--R       x
+--R   + 
+--R              7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R         3432a c  + 84084a b c  + 252252a b c  + 210210a b c  + 60060a b c
+--R       + 
+--R              2 10 2         12     14
+--R         6006a b  c  + 182a b  c + b
+--R    *
+--R        27
+--R       x
+--R   + 
+--R               7   6          6 3 5          5 5 4          4 7 3         3 9 2
+--R         22308a b c  + 156156a b c  + 234234a b c  + 111540a b c  + 18590a b c
+--R       + 
+--R              2 11         13
+--R         1014a b  c + 13a b
+--R    *
+--R        25
+--R       x
+--R   + 
+--R              8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R         2574a c  + 61776a b c  + 180180a b c  + 144144a b c  + 38610a b c
+--R       + 
+--R              3 10       2 12
+--R         3432a b  c + 78a b
+--R    *
+--R        23
+--R       x
+--R   + 
+--R               8   5         7 3 4          6 5 3         5 7 2        4 9
+--R         14157a b c  + 94380a b c  + 132132a b c  + 56628a b c  + 7865a b c
+--R       + 
+--R             3 11
+--R         286a b
+--R    *
+--R        21
+--R       x
+--R   + 
+--R              9 5         8 2 4         7 4 3         6 6 2         5 8
+--R         1430a c  + 32175a b c  + 85800a b c  + 60060a b c  + 12870a b c
+--R       + 
+--R             4 10
+--R         715a b
+--R    *
+--R        19
+--R       x
+--R   + 
+--R           9   4         8 3 3         7 5 2         6 7         5 9  17
+--R     (6435a b c  + 38610a b c  + 46332a b c  + 15444a b c + 1287a b )x
+--R   + 
+--R          10 4         9 2 3         8 4 2         7 6         6 8  15
+--R     (572a  c  + 11440a b c  + 25740a b c  + 13728a b c + 1716a b )x
+--R   + 
+--R           10   3         9 3 2        8 5         7 7  13
+--R     (2002a  b c  + 10010a b c  + 9009a b c + 1716a b )x
+--R   + 
+--R          11 3        10 2 2        9 4         8 6  11
+--R     (156a  c  + 2574a  b c  + 4290a b c + 1287a b )x
+--R   + 
+--R          11   2        10 3        9 5  9       12 2       11 2        10 4  7
+--R     (390a  b c  + 1430a  b c + 715a b )x  + (26a  c  + 312a  b c + 286a  b )x
+--R   + 
+--R         12         11 3  5      13       12 2  3    13
+--R     (39a  b c + 78a  b )x  + (2a  c + 13a  b )x  + a  b x
+--R                                                    Type: Polynomial(Integer)
+--E 388
+
+--S 389 of 649
+r0:=1/28*(a+b*x^2+c*x^4)^14
+--R 
+--R
+--R   (2)
+--R      1  14 56   1    13 54    1    13   13  2 12  52
+--R     -- c  x   + - b c  x   + (- a c   + -- b c  )x
+--R     28          2             2          4
+--R   + 
+--R      13      12      3 11  50    13  2 12        2 11   143  4 10  48
+--R     (-- a b c   + 13b c  )x   + (-- a c   + 39a b c   + --- b c  )x
+--R       2                           4                      4
+--R   + 
+--R         2   11         3 10   143  5 9  46
+--R     (39a b c   + 143a b c   + --- b c )x
+--R                                2
+--R   + 
+--R         3 11   429  2 2 10   715    4 9   429  6 8  44
+--R     (13a c   + --- a b c   + --- a b c  + --- b c )x
+--R                 2             2            4
+--R   + 
+--R          3   10       2 3 9   1287    5 8   858  7 7  42
+--R     (143a b c   + 715a b c  + ---- a b c  + --- b c )x
+--R                                 2            7
+--R   + 
+--R      143  4 10       3 2 9   6435  2 4 8         6 7   429  8 6  40
+--R     (--- a c   + 715a b c  + ---- a b c  + 858a b c  + --- b c )x
+--R       4                        4                        4
+--R   + 
+--R      715  4   9        3 3 8        2 5 7         7 6   143  9 5  38
+--R     (--- a b c  + 2145a b c  + 2574a b c  + 858a b c  + --- b c )x
+--R       2                                                  2
+--R   + 
+--R         143  5 9   6435  4 2 8        3 4 7        2 6 6   1287    8 5
+--R         --- a c  + ---- a b c  + 4290a b c  + 3003a b c  + ---- a b c
+--R          2           4                                       2
+--R       + 
+--R         143  10 4
+--R         --- b  c
+--R          4
+--R    *
+--R        36
+--R       x
+--R   + 
+--R           1287  5   8        4 3 7        3 5 6        2 7 5   715    9 4
+--R           ---- a b c  + 4290a b c  + 6006a b c  + 2574a b c  + --- a b c
+--R             2                                                   2
+--R         + 
+--R              11 3
+--R           13b  c
+--R    *
+--R        34
+--R       x
+--R   + 
+--R         429  6 8        5 2 7   15015  4 4 6        3 6 5   6435  2 8 4
+--R         --- a c  + 2574a b c  + ----- a b c  + 6006a b c  + ---- a b c
+--R          4                        2                           4
+--R       + 
+--R               10 3   13  12 2
+--R         143a b  c  + -- b  c
+--R                       4
+--R    *
+--R        32
+--R       x
+--R   + 
+--R             6   7        5 3 6        4 5 5        3 7 4       2 9 3
+--R         858a b c  + 6006a b c  + 9009a b c  + 4290a b c  + 715a b c
+--R       + 
+--R              11 2   1  13
+--R         39a b  c  + - b  c
+--R                     2
+--R    *
+--R        30
+--R       x
+--R   + 
+--R         858  7 7        6 2 6        5 4 5   15015  4 6 4        3 8 3
+--R         --- a c  + 3003a b c  + 9009a b c  + ----- a b c  + 2145a b c
+--R          7                                     2
+--R       + 
+--R         429  2 10 2   13    12     1  14
+--R         --- a b  c  + -- a b  c + -- b
+--R          2             2          28
+--R    *
+--R        28
+--R       x
+--R   + 
+--R             7   6        6 3 5        5 5 4        4 7 3       3 9 2      2 11
+--R         858a b c  + 6006a b c  + 9009a b c  + 4290a b c  + 715a b c  + 39a b  c
+--R       + 
+--R         1    13
+--R         - a b
+--R         2
+--R    *
+--R        26
+--R       x
+--R   + 
+--R         429  8 6        7 2 5   15015  6 4 4        5 6 3   6435  4 8 2
+--R         --- a c  + 2574a b c  + ----- a b c  + 6006a b c  + ---- a b c
+--R          4                        2                           4
+--R       + 
+--R             3 10    13  2 12
+--R         143a b  c + -- a b
+--R                      4
+--R    *
+--R        24
+--R       x
+--R   + 
+--R           1287  8   5        7 3 4        6 5 3        5 7 2   715  4 9
+--R           ---- a b c  + 4290a b c  + 6006a b c  + 2574a b c  + --- a b c
+--R             2                                                   2
+--R         + 
+--R              3 11
+--R           13a b
+--R    *
+--R        22
+--R       x
+--R   + 
+--R           143  9 5   6435  8 2 4        7 4 3        6 6 2   1287  5 8
+--R           --- a c  + ---- a b c  + 4290a b c  + 3003a b c  + ---- a b c
+--R            2           4                                       2
+--R         + 
+--R           143  4 10
+--R           --- a b
+--R            4
+--R    *
+--R        20
+--R       x
+--R   + 
+--R      715  9   4        8 3 3        7 5 2       6 7    143  5 9  18
+--R     (--- a b c  + 2145a b c  + 2574a b c  + 858a b c + --- a b )x
+--R       2                                                 2
+--R   + 
+--R      143  10 4       9 2 3   6435  8 4 2       7 6    429  6 8  16
+--R     (--- a  c  + 715a b c  + ---- a b c  + 858a b c + --- a b )x
+--R       4                        4                       4
+--R   + 
+--R          10   3       9 3 2   1287  8 5    858  7 7  14
+--R     (143a  b c  + 715a b c  + ---- a b c + --- a b )x
+--R                                 2           7
+--R   + 
+--R         11 3   429  10 2 2   715  9 4    429  8 6  12
+--R     (13a  c  + --- a  b c  + --- a b c + --- a b )x
+--R                 2             2           4
+--R   + 
+--R         11   2       10 3    143  9 5  10    13  12 2      11 2    143  10 4  8
+--R     (39a  b c  + 143a  b c + --- a b )x   + (-- a  c  + 39a  b c + --- a  b )x
+--R                               2               4                     4
+--R   + 
+--R      13  12         11 3  6    1  13    13  12 2  4   1  13   2    1  14
+--R     (-- a  b c + 13a  b )x  + (- a  c + -- a  b )x  + - a  b x  + -- a
+--R       2                        2         4            2           28
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 389
+
+--S 390 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 56   1    13 54    1    13   13  2 12  52
+--R     -- c  x   + - b c  x   + (- a c   + -- b c  )x
+--R     28          2             2          4
+--R   + 
+--R      13      12      3 11  50    13  2 12        2 11   143  4 10  48
+--R     (-- a b c   + 13b c  )x   + (-- a c   + 39a b c   + --- b c  )x
+--R       2                           4                      4
+--R   + 
+--R         2   11         3 10   143  5 9  46
+--R     (39a b c   + 143a b c   + --- b c )x
+--R                                2
+--R   + 
+--R         3 11   429  2 2 10   715    4 9   429  6 8  44
+--R     (13a c   + --- a b c   + --- a b c  + --- b c )x
+--R                 2             2            4
+--R   + 
+--R          3   10       2 3 9   1287    5 8   858  7 7  42
+--R     (143a b c   + 715a b c  + ---- a b c  + --- b c )x
+--R                                 2            7
+--R   + 
+--R      143  4 10       3 2 9   6435  2 4 8         6 7   429  8 6  40
+--R     (--- a c   + 715a b c  + ---- a b c  + 858a b c  + --- b c )x
+--R       4                        4                        4
+--R   + 
+--R      715  4   9        3 3 8        2 5 7         7 6   143  9 5  38
+--R     (--- a b c  + 2145a b c  + 2574a b c  + 858a b c  + --- b c )x
+--R       2                                                  2
+--R   + 
+--R         143  5 9   6435  4 2 8        3 4 7        2 6 6   1287    8 5
+--R         --- a c  + ---- a b c  + 4290a b c  + 3003a b c  + ---- a b c
+--R          2           4                                       2
+--R       + 
+--R         143  10 4
+--R         --- b  c
+--R          4
+--R    *
+--R        36
+--R       x
+--R   + 
+--R           1287  5   8        4 3 7        3 5 6        2 7 5   715    9 4
+--R           ---- a b c  + 4290a b c  + 6006a b c  + 2574a b c  + --- a b c
+--R             2                                                   2
+--R         + 
+--R              11 3
+--R           13b  c
+--R    *
+--R        34
+--R       x
+--R   + 
+--R         429  6 8        5 2 7   15015  4 4 6        3 6 5   6435  2 8 4
+--R         --- a c  + 2574a b c  + ----- a b c  + 6006a b c  + ---- a b c
+--R          4                        2                           4
+--R       + 
+--R               10 3   13  12 2
+--R         143a b  c  + -- b  c
+--R                       4
+--R    *
+--R        32
+--R       x
+--R   + 
+--R             6   7        5 3 6        4 5 5        3 7 4       2 9 3
+--R         858a b c  + 6006a b c  + 9009a b c  + 4290a b c  + 715a b c
+--R       + 
+--R              11 2   1  13
+--R         39a b  c  + - b  c
+--R                     2
+--R    *
+--R        30
+--R       x
+--R   + 
+--R         858  7 7        6 2 6        5 4 5   15015  4 6 4        3 8 3
+--R         --- a c  + 3003a b c  + 9009a b c  + ----- a b c  + 2145a b c
+--R          7                                     2
+--R       + 
+--R         429  2 10 2   13    12     1  14
+--R         --- a b  c  + -- a b  c + -- b
+--R          2             2          28
+--R    *
+--R        28
+--R       x
+--R   + 
+--R             7   6        6 3 5        5 5 4        4 7 3       3 9 2      2 11
+--R         858a b c  + 6006a b c  + 9009a b c  + 4290a b c  + 715a b c  + 39a b  c
+--R       + 
+--R         1    13
+--R         - a b
+--R         2
+--R    *
+--R        26
+--R       x
+--R   + 
+--R         429  8 6        7 2 5   15015  6 4 4        5 6 3   6435  4 8 2
+--R         --- a c  + 2574a b c  + ----- a b c  + 6006a b c  + ---- a b c
+--R          4                        2                           4
+--R       + 
+--R             3 10    13  2 12
+--R         143a b  c + -- a b
+--R                      4
+--R    *
+--R        24
+--R       x
+--R   + 
+--R           1287  8   5        7 3 4        6 5 3        5 7 2   715  4 9
+--R           ---- a b c  + 4290a b c  + 6006a b c  + 2574a b c  + --- a b c
+--R             2                                                   2
+--R         + 
+--R              3 11
+--R           13a b
+--R    *
+--R        22
+--R       x
+--R   + 
+--R           143  9 5   6435  8 2 4        7 4 3        6 6 2   1287  5 8
+--R           --- a c  + ---- a b c  + 4290a b c  + 3003a b c  + ---- a b c
+--R            2           4                                       2
+--R         + 
+--R           143  4 10
+--R           --- a b
+--R            4
+--R    *
+--R        20
+--R       x
+--R   + 
+--R      715  9   4        8 3 3        7 5 2       6 7    143  5 9  18
+--R     (--- a b c  + 2145a b c  + 2574a b c  + 858a b c + --- a b )x
+--R       2                                                 2
+--R   + 
+--R      143  10 4       9 2 3   6435  8 4 2       7 6    429  6 8  16
+--R     (--- a  c  + 715a b c  + ---- a b c  + 858a b c + --- a b )x
+--R       4                        4                       4
+--R   + 
+--R          10   3       9 3 2   1287  8 5    858  7 7  14
+--R     (143a  b c  + 715a b c  + ---- a b c + --- a b )x
+--R                                 2           7
+--R   + 
+--R         11 3   429  10 2 2   715  9 4    429  8 6  12
+--R     (13a  c  + --- a  b c  + --- a b c + --- a b )x
+--R                 2             2           4
+--R   + 
+--R         11   2       10 3    143  9 5  10    13  12 2      11 2    143  10 4  8
+--R     (39a  b c  + 143a  b c + --- a b )x   + (-- a  c  + 39a  b c + --- a  b )x
+--R                               2               4                     4
+--R   + 
+--R      13  12         11 3  6    1  13    13  12 2  4   1  13   2
+--R     (-- a  b c + 13a  b )x  + (- a  c + -- a  b )x  + - a  b x
+--R       2                        2         4            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 390
+
+--S 391 of 649
+m0:=a0-r0
+--R 
+--R
+--R           1  14
+--R   (4)  - -- a
+--R          28
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 391
+
+--S 392 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 392
+
+)clear all
+
+--S 393 of 649
+t0:=x^2*(b+2*c*x^3)*(a+b*x^3+c*x^6)^13
+--R 
+--R
+--R   (1)
+--R       14 83        13 80         13       2 12  77            12       3 11  74
+--R     2c  x   + 27b c  x   + (26a c   + 169b c  )x   + (325a b c   + 650b c  )x
+--R   + 
+--R          2 12          2 11        4 10  71
+--R     (156a c   + 1872a b c   + 1716b c  )x
+--R   + 
+--R           2   11          3 10        5 9  68
+--R     (1794a b c   + 6578a b c   + 3289b c )x
+--R   + 
+--R          3 11        2 2 10           4 9        6 8  65
+--R     (572a c   + 9438a b c   + 15730a b c  + 4719b c )x
+--R   + 
+--R           3   10         2 3 9           5 8        7 7  62
+--R     (6006a b c   + 30030a b c  + 27027a b c  + 5148b c )x
+--R   + 
+--R           4 10         3 2 9         2 4 8           6 7        8 6  59
+--R     (1430a c   + 28600a b c  + 64350a b c  + 34320a b c  + 4290b c )x
+--R   + 
+--R            4   9         3 3 8         2 5 7           7 6        9 5  56
+--R     (13585a b c  + 81510a b c  + 97812a b c  + 32604a b c  + 2717b c )x
+--R   + 
+--R              5 9         4 2 8          3 4 7          2 6 6           8 5
+--R         2574a c  + 57915a b c  + 154440a b c  + 108108a b c  + 23166a b c
+--R       + 
+--R              10 4
+--R         1287b  c
+--R    *
+--R        53
+--R       x
+--R   + 
+--R               5   8          4 3 7          3 5 6         2 7 5           9 4
+--R         21879a b c  + 145860a b c  + 204204a b c  + 87516a b c  + 12155a b c
+--R       + 
+--R             11 3
+--R         442b  c
+--R    *
+--R        50
+--R       x
+--R   + 
+--R              6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R         3432a c  + 82368a b c  + 240240a b c  + 192192a b c  + 51480a b c
+--R       + 
+--R                10 3       12 2
+--R         4576a b  c  + 104b  c
+--R    *
+--R        47
+--R       x
+--R   + 
+--R               6   7          5 3 6          4 5 5          3 7 4         2 9 3
+--R         25740a b c  + 180180a b c  + 270270a b c  + 128700a b c  + 21450a b c
+--R       + 
+--R                11 2      13
+--R         1170a b  c  + 15b  c
+--R    *
+--R        44
+--R       x
+--R   + 
+--R              7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R         3432a c  + 84084a b c  + 252252a b c  + 210210a b c  + 60060a b c
+--R       + 
+--R              2 10 2         12     14
+--R         6006a b  c  + 182a b  c + b
+--R    *
+--R        41
+--R       x
+--R   + 
+--R               7   6          6 3 5          5 5 4          4 7 3         3 9 2
+--R         22308a b c  + 156156a b c  + 234234a b c  + 111540a b c  + 18590a b c
+--R       + 
+--R              2 11         13
+--R         1014a b  c + 13a b
+--R    *
+--R        38
+--R       x
+--R   + 
+--R              8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R         2574a c  + 61776a b c  + 180180a b c  + 144144a b c  + 38610a b c
+--R       + 
+--R              3 10       2 12
+--R         3432a b  c + 78a b
+--R    *
+--R        35
+--R       x
+--R   + 
+--R               8   5         7 3 4          6 5 3         5 7 2        4 9
+--R         14157a b c  + 94380a b c  + 132132a b c  + 56628a b c  + 7865a b c
+--R       + 
+--R             3 11
+--R         286a b
+--R    *
+--R        32
+--R       x
+--R   + 
+--R              9 5         8 2 4         7 4 3         6 6 2         5 8
+--R         1430a c  + 32175a b c  + 85800a b c  + 60060a b c  + 12870a b c
+--R       + 
+--R             4 10
+--R         715a b
+--R    *
+--R        29
+--R       x
+--R   + 
+--R           9   4         8 3 3         7 5 2         6 7         5 9  26
+--R     (6435a b c  + 38610a b c  + 46332a b c  + 15444a b c + 1287a b )x
+--R   + 
+--R          10 4         9 2 3         8 4 2         7 6         6 8  23
+--R     (572a  c  + 11440a b c  + 25740a b c  + 13728a b c + 1716a b )x
+--R   + 
+--R           10   3         9 3 2        8 5         7 7  20
+--R     (2002a  b c  + 10010a b c  + 9009a b c + 1716a b )x
+--R   + 
+--R          11 3        10 2 2        9 4         8 6  17
+--R     (156a  c  + 2574a  b c  + 4290a b c + 1287a b )x
+--R   + 
+--R          11   2        10 3        9 5  14
+--R     (390a  b c  + 1430a  b c + 715a b )x
+--R   + 
+--R         12 2       11 2        10 4  11       12         11 3  8
+--R     (26a  c  + 312a  b c + 286a  b )x   + (39a  b c + 78a  b )x
+--R   + 
+--R        13       12 2  5    13   2
+--R     (2a  c + 13a  b )x  + a  b x
+--R                                                    Type: Polynomial(Integer)
+--E 393
+
+--S 394 of 649
+r0:=1/42*(a+b*x^3+c*x^6)^14
+--R 
+--R
+--R   (2)
+--R      1  14 84   1    13 81    1    13   13  2 12  78
+--R     -- c  x   + - b c  x   + (- a c   + -- b c  )x
+--R     42          3             3          6
+--R   + 
+--R      13      12   26  3 11  75    13  2 12        2 11   143  4 10  72
+--R     (-- a b c   + -- b c  )x   + (-- a c   + 26a b c   + --- b c  )x
+--R       3            3               6                      6
+--R   + 
+--R         2   11   286    3 10   143  5 9  69
+--R     (26a b c   + --- a b c   + --- b c )x
+--R                   3             3
+--R   + 
+--R      26  3 11       2 2 10   715    4 9   143  6 8  66
+--R     (-- a c   + 143a b c   + --- a b c  + --- b c )x
+--R       3                       3            2
+--R   + 
+--R      286  3   10   1430  2 3 9         5 8   572  7 7  63
+--R     (--- a b c   + ---- a b c  + 429a b c  + --- b c )x
+--R       3              3                        7
+--R   + 
+--R      143  4 10   1430  3 2 9   2145  2 4 8         6 7   143  8 6  60
+--R     (--- a c   + ---- a b c  + ---- a b c  + 572a b c  + --- b c )x
+--R       6            3             2                        2
+--R   + 
+--R      715  4   9        3 3 8        2 5 7         7 6   143  9 5  57
+--R     (--- a b c  + 1430a b c  + 1716a b c  + 572a b c  + --- b c )x
+--R       3                                                  3
+--R   + 
+--R           143  5 9   2145  4 2 8        3 4 7        2 6 6         8 5
+--R           --- a c  + ---- a b c  + 2860a b c  + 2002a b c  + 429a b c
+--R            3           2
+--R         + 
+--R           143  10 4
+--R           --- b  c
+--R            6
+--R    *
+--R        54
+--R       x
+--R   + 
+--R               5   8        4 3 7        3 5 6        2 7 5   715    9 4
+--R           429a b c  + 2860a b c  + 4004a b c  + 1716a b c  + --- a b c
+--R                                                               3
+--R         + 
+--R           26  11 3
+--R           -- b  c
+--R            3
+--R    *
+--R        51
+--R       x
+--R   + 
+--R         143  6 8        5 2 7        4 4 6        3 6 5   2145  2 8 4
+--R         --- a c  + 1716a b c  + 5005a b c  + 4004a b c  + ---- a b c
+--R          2                                                  2
+--R       + 
+--R         286    10 3   13  12 2
+--R         --- a b  c  + -- b  c
+--R          3             6
+--R    *
+--R        48
+--R       x
+--R   + 
+--R             6   7        5 3 6        4 5 5        3 7 4   1430  2 9 3
+--R         572a b c  + 4004a b c  + 6006a b c  + 2860a b c  + ---- a b c
+--R                                                              3
+--R       + 
+--R              11 2   1  13
+--R         26a b  c  + - b  c
+--R                     3
+--R    *
+--R        45
+--R       x
+--R   + 
+--R         572  7 7        6 2 6        5 4 5        4 6 4        3 8 3
+--R         --- a c  + 2002a b c  + 6006a b c  + 5005a b c  + 1430a b c
+--R          7
+--R       + 
+--R             2 10 2   13    12     1  14
+--R         143a b  c  + -- a b  c + -- b
+--R                       3          42
+--R    *
+--R        42
+--R       x
+--R   + 
+--R             7   6        6 3 5        5 5 4        4 7 3   1430  3 9 2
+--R         572a b c  + 4004a b c  + 6006a b c  + 2860a b c  + ---- a b c
+--R                                                              3
+--R       + 
+--R            2 11    1    13
+--R         26a b  c + - a b
+--R                    3
+--R    *
+--R        39
+--R       x
+--R   + 
+--R         143  8 6        7 2 5        6 4 4        5 6 3   2145  4 8 2
+--R         --- a c  + 1716a b c  + 5005a b c  + 4004a b c  + ---- a b c
+--R          2                                                  2
+--R       + 
+--R         286  3 10    13  2 12
+--R         --- a b  c + -- a b
+--R          3            6
+--R    *
+--R        36
+--R       x
+--R   + 
+--R            8   5        7 3 4        6 5 3        5 7 2   715  4 9    26  3 11
+--R       (429a b c  + 2860a b c  + 4004a b c  + 1716a b c  + --- a b c + -- a b  )
+--R                                                            3           3
+--R    *
+--R        33
+--R       x
+--R   + 
+--R        143  9 5   2145  8 2 4        7 4 3        6 6 2       5 8    143  4 10
+--R       (--- a c  + ---- a b c  + 2860a b c  + 2002a b c  + 429a b c + --- a b  )
+--R         3           2                                                 6
+--R    *
+--R        30
+--R       x
+--R   + 
+--R      715  9   4        8 3 3        7 5 2       6 7    143  5 9  27
+--R     (--- a b c  + 1430a b c  + 1716a b c  + 572a b c + --- a b )x
+--R       3                                                 3
+--R   + 
+--R      143  10 4   1430  9 2 3   2145  8 4 2       7 6    143  6 8  24
+--R     (--- a  c  + ---- a b c  + ---- a b c  + 572a b c + --- a b )x
+--R       6            3             2                       2
+--R   + 
+--R      286  10   3   1430  9 3 2       8 5    572  7 7  21
+--R     (--- a  b c  + ---- a b c  + 429a b c + --- a b )x
+--R       3              3                       7
+--R   + 
+--R      26  11 3       10 2 2   715  9 4    143  8 6  18
+--R     (-- a  c  + 143a  b c  + --- a b c + --- a b )x
+--R       3                       3           2
+--R   + 
+--R         11   2   286  10 3    143  9 5  15
+--R     (26a  b c  + --- a  b c + --- a b )x
+--R                   3            3
+--R   + 
+--R      13  12 2      11 2    143  10 4  12    13  12      26  11 3  9
+--R     (-- a  c  + 26a  b c + --- a  b )x   + (-- a  b c + -- a  b )x
+--R       6                     6                3           3
+--R   + 
+--R      1  13    13  12 2  6   1  13   3    1  14
+--R     (- a  c + -- a  b )x  + - a  b x  + -- a
+--R      3         6            3           42
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 394
+
+--S 395 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 84   1    13 81    1    13   13  2 12  78
+--R     -- c  x   + - b c  x   + (- a c   + -- b c  )x
+--R     42          3             3          6
+--R   + 
+--R      13      12   26  3 11  75    13  2 12        2 11   143  4 10  72
+--R     (-- a b c   + -- b c  )x   + (-- a c   + 26a b c   + --- b c  )x
+--R       3            3               6                      6
+--R   + 
+--R         2   11   286    3 10   143  5 9  69
+--R     (26a b c   + --- a b c   + --- b c )x
+--R                   3             3
+--R   + 
+--R      26  3 11       2 2 10   715    4 9   143  6 8  66
+--R     (-- a c   + 143a b c   + --- a b c  + --- b c )x
+--R       3                       3            2
+--R   + 
+--R      286  3   10   1430  2 3 9         5 8   572  7 7  63
+--R     (--- a b c   + ---- a b c  + 429a b c  + --- b c )x
+--R       3              3                        7
+--R   + 
+--R      143  4 10   1430  3 2 9   2145  2 4 8         6 7   143  8 6  60
+--R     (--- a c   + ---- a b c  + ---- a b c  + 572a b c  + --- b c )x
+--R       6            3             2                        2
+--R   + 
+--R      715  4   9        3 3 8        2 5 7         7 6   143  9 5  57
+--R     (--- a b c  + 1430a b c  + 1716a b c  + 572a b c  + --- b c )x
+--R       3                                                  3
+--R   + 
+--R           143  5 9   2145  4 2 8        3 4 7        2 6 6         8 5
+--R           --- a c  + ---- a b c  + 2860a b c  + 2002a b c  + 429a b c
+--R            3           2
+--R         + 
+--R           143  10 4
+--R           --- b  c
+--R            6
+--R    *
+--R        54
+--R       x
+--R   + 
+--R               5   8        4 3 7        3 5 6        2 7 5   715    9 4
+--R           429a b c  + 2860a b c  + 4004a b c  + 1716a b c  + --- a b c
+--R                                                               3
+--R         + 
+--R           26  11 3
+--R           -- b  c
+--R            3
+--R    *
+--R        51
+--R       x
+--R   + 
+--R         143  6 8        5 2 7        4 4 6        3 6 5   2145  2 8 4
+--R         --- a c  + 1716a b c  + 5005a b c  + 4004a b c  + ---- a b c
+--R          2                                                  2
+--R       + 
+--R         286    10 3   13  12 2
+--R         --- a b  c  + -- b  c
+--R          3             6
+--R    *
+--R        48
+--R       x
+--R   + 
+--R             6   7        5 3 6        4 5 5        3 7 4   1430  2 9 3
+--R         572a b c  + 4004a b c  + 6006a b c  + 2860a b c  + ---- a b c
+--R                                                              3
+--R       + 
+--R              11 2   1  13
+--R         26a b  c  + - b  c
+--R                     3
+--R    *
+--R        45
+--R       x
+--R   + 
+--R         572  7 7        6 2 6        5 4 5        4 6 4        3 8 3
+--R         --- a c  + 2002a b c  + 6006a b c  + 5005a b c  + 1430a b c
+--R          7
+--R       + 
+--R             2 10 2   13    12     1  14
+--R         143a b  c  + -- a b  c + -- b
+--R                       3          42
+--R    *
+--R        42
+--R       x
+--R   + 
+--R             7   6        6 3 5        5 5 4        4 7 3   1430  3 9 2
+--R         572a b c  + 4004a b c  + 6006a b c  + 2860a b c  + ---- a b c
+--R                                                              3
+--R       + 
+--R            2 11    1    13
+--R         26a b  c + - a b
+--R                    3
+--R    *
+--R        39
+--R       x
+--R   + 
+--R         143  8 6        7 2 5        6 4 4        5 6 3   2145  4 8 2
+--R         --- a c  + 1716a b c  + 5005a b c  + 4004a b c  + ---- a b c
+--R          2                                                  2
+--R       + 
+--R         286  3 10    13  2 12
+--R         --- a b  c + -- a b
+--R          3            6
+--R    *
+--R        36
+--R       x
+--R   + 
+--R            8   5        7 3 4        6 5 3        5 7 2   715  4 9    26  3 11
+--R       (429a b c  + 2860a b c  + 4004a b c  + 1716a b c  + --- a b c + -- a b  )
+--R                                                            3           3
+--R    *
+--R        33
+--R       x
+--R   + 
+--R        143  9 5   2145  8 2 4        7 4 3        6 6 2       5 8    143  4 10
+--R       (--- a c  + ---- a b c  + 2860a b c  + 2002a b c  + 429a b c + --- a b  )
+--R         3           2                                                 6
+--R    *
+--R        30
+--R       x
+--R   + 
+--R      715  9   4        8 3 3        7 5 2       6 7    143  5 9  27
+--R     (--- a b c  + 1430a b c  + 1716a b c  + 572a b c + --- a b )x
+--R       3                                                 3
+--R   + 
+--R      143  10 4   1430  9 2 3   2145  8 4 2       7 6    143  6 8  24
+--R     (--- a  c  + ---- a b c  + ---- a b c  + 572a b c + --- a b )x
+--R       6            3             2                       2
+--R   + 
+--R      286  10   3   1430  9 3 2       8 5    572  7 7  21
+--R     (--- a  b c  + ---- a b c  + 429a b c + --- a b )x
+--R       3              3                       7
+--R   + 
+--R      26  11 3       10 2 2   715  9 4    143  8 6  18
+--R     (-- a  c  + 143a  b c  + --- a b c + --- a b )x
+--R       3                       3           2
+--R   + 
+--R         11   2   286  10 3    143  9 5  15
+--R     (26a  b c  + --- a  b c + --- a b )x
+--R                   3            3
+--R   + 
+--R      13  12 2      11 2    143  10 4  12    13  12      26  11 3  9
+--R     (-- a  c  + 26a  b c + --- a  b )x   + (-- a  b c + -- a  b )x
+--R       6                     6                3           3
+--R   + 
+--R      1  13    13  12 2  6   1  13   3
+--R     (- a  c + -- a  b )x  + - a  b x
+--R      3         6            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 395
+
+--S 396 of 649
+m0:=a0-r0
+--R 
+--R
+--R           1  14
+--R   (4)  - -- a
+--R          42
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 396
+
+--S 397 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 397
+
+)clear all
+
+--S 398 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)*(a+b*x^n+c*x^(2*n))^13
+--R 
+--R
+--R   (1)
+--R        14 n - 1 n      13 n - 1   2n 13
+--R     (2c  x     x  + b c  x     )(x  )
+--R   + 
+--R           13 n - 1  n 2         13      2 12  n - 1 n          12 n - 1   2n 12
+--R     (26b c  x     (x )  + (26a c   + 13b c  )x     x  + 13a b c  x     )(x  )
+--R   + 
+--R             2 12 n - 1  n 3            12      3 11  n - 1  n 2
+--R         156b c  x     (x )  + (312a b c   + 78b c  )x     (x )
+--R       + 
+--R              2 12         2 11  n - 1 n      2   11 n - 1
+--R         (156a c   + 156a b c  )x     x  + 78a b c  x
+--R    *
+--R         2n 11
+--R       (x  )
+--R   + 
+--R             3 11 n - 1  n 4           2 11       4 10  n - 1  n 3
+--R         572b c  x     (x )  + (1716a b c   + 286b c  )x     (x )
+--R       + 
+--R               2   11         3 10  n - 1  n 2        3 11       2 2 10  n - 1 n
+--R         (1716a b c   + 858a b c  )x     (x )  + (572a c   + 858a b c  )x     x
+--R       + 
+--R             3   10 n - 1
+--R         286a b c  x
+--R    *
+--R         2n 10
+--R       (x  )
+--R   + 
+--R              4 10 n - 1  n 5           3 10       5 9  n - 1  n 4
+--R         1430b c  x     (x )  + (5720a b c   + 715b c )x     (x )
+--R       + 
+--R               2 2 10          4 9  n - 1  n 3
+--R         (8580a b c   + 2860a b c )x     (x )
+--R       + 
+--R               3   10        2 3 9  n - 1  n 2
+--R         (5720a b c   + 4290a b c )x     (x )
+--R       + 
+--R               4 10        3 2 9  n - 1 n       4   9 n - 1
+--R         (1430a c   + 2860a b c )x     x  + 715a b c x
+--R    *
+--R         2n 9
+--R       (x  )
+--R   + 
+--R              5 9 n - 1  n 6            4 9        6 8  n - 1  n 5
+--R         2574b c x     (x )  + (12870a b c  + 1287b c )x     (x )
+--R       + 
+--R                2 3 9          5 8  n - 1  n 4
+--R         (25740a b c  + 6435a b c )x     (x )
+--R       + 
+--R                3 2 9         2 4 8  n - 1  n 3
+--R         (25740a b c  + 12870a b c )x     (x )
+--R       + 
+--R                4   9         3 3 8  n - 1  n 2
+--R         (12870a b c  + 12870a b c )x     (x )
+--R       + 
+--R               5 9        4 2 8  n - 1 n        5   8 n - 1
+--R         (2574a c  + 6435a b c )x     x  + 1287a b c x
+--R    *
+--R         2n 8
+--R       (x  )
+--R   + 
+--R              6 8 n - 1  n 7            5 8        7 7  n - 1  n 6
+--R         3432b c x     (x )  + (20592a b c  + 1716b c )x     (x )
+--R       + 
+--R                2 4 8           6 7  n - 1  n 5
+--R         (51480a b c  + 10296a b c )x     (x )
+--R       + 
+--R                3 3 8         2 5 7  n - 1  n 4
+--R         (68640a b c  + 25740a b c )x     (x )
+--R       + 
+--R                4 2 8         3 4 7  n - 1  n 3
+--R         (51480a b c  + 34320a b c )x     (x )
+--R       + 
+--R                5   8         4 3 7  n - 1  n 2
+--R         (20592a b c  + 25740a b c )x     (x )
+--R       + 
+--R               6 8         5 2 7  n - 1 n        6   7 n - 1
+--R         (3432a c  + 10296a b c )x     x  + 1716a b c x
+--R    *
+--R         2n 7
+--R       (x  )
+--R   + 
+--R              7 7 n - 1  n 8            6 7        8 6  n - 1  n 7
+--R         3432b c x     (x )  + (24024a b c  + 1716b c )x     (x )
+--R       + 
+--R                2 5 7           7 6  n - 1  n 6
+--R         (72072a b c  + 12012a b c )x     (x )
+--R       + 
+--R                 3 4 7         2 6 6  n - 1  n 5
+--R         (120120a b c  + 36036a b c )x     (x )
+--R       + 
+--R                 4 3 7         3 5 6  n - 1  n 4
+--R         (120120a b c  + 60060a b c )x     (x )
+--R       + 
+--R                5 2 7         4 4 6  n - 1  n 3
+--R         (72072a b c  + 60060a b c )x     (x )
+--R       + 
+--R                6   7         5 3 6  n - 1  n 2
+--R         (24024a b c  + 36036a b c )x     (x )
+--R       + 
+--R               7 7         6 2 6  n - 1 n        7   6 n - 1
+--R         (3432a c  + 12012a b c )x     x  + 1716a b c x
+--R    *
+--R         2n 6
+--R       (x  )
+--R   + 
+--R              8 6 n - 1  n 9            7 6        9 5  n - 1  n 8
+--R         2574b c x     (x )  + (20592a b c  + 1287b c )x     (x )
+--R       + 
+--R                2 6 6           8 5  n - 1  n 7
+--R         (72072a b c  + 10296a b c )x     (x )
+--R       + 
+--R                 3 5 6         2 7 5  n - 1  n 6
+--R         (144144a b c  + 36036a b c )x     (x )
+--R       + 
+--R                 4 4 6         3 6 5  n - 1  n 5
+--R         (180180a b c  + 72072a b c )x     (x )
+--R       + 
+--R                 5 3 6         4 5 5  n - 1  n 4
+--R         (144144a b c  + 90090a b c )x     (x )
+--R       + 
+--R                6 2 6         5 4 5  n - 1  n 3
+--R         (72072a b c  + 72072a b c )x     (x )
+--R       + 
+--R                7   6         6 3 5  n - 1  n 2
+--R         (20592a b c  + 36036a b c )x     (x )
+--R       + 
+--R               8 6         7 2 5  n - 1 n        8   5 n - 1
+--R         (2574a c  + 10296a b c )x     x  + 1287a b c x
+--R    *
+--R         2n 5
+--R       (x  )
+--R   + 
+--R              9 5 n - 1  n 10            8 5       10 4  n - 1  n 9
+--R         1430b c x     (x )   + (12870a b c  + 715b  c )x     (x )
+--R       + 
+--R                2 7 5          9 4  n - 1  n 8
+--R         (51480a b c  + 6435a b c )x     (x )
+--R       + 
+--R                 3 6 5         2 8 4  n - 1  n 7
+--R         (120120a b c  + 25740a b c )x     (x )
+--R       + 
+--R                 4 5 5         3 7 4  n - 1  n 6
+--R         (180180a b c  + 60060a b c )x     (x )
+--R       + 
+--R                 5 4 5         4 6 4  n - 1  n 5
+--R         (180180a b c  + 90090a b c )x     (x )
+--R       + 
+--R                 6 3 5         5 5 4  n - 1  n 4
+--R         (120120a b c  + 90090a b c )x     (x )
+--R       + 
+--R                7 2 5         6 4 4  n - 1  n 3
+--R         (51480a b c  + 60060a b c )x     (x )
+--R       + 
+--R                8   5         7 3 4  n - 1  n 2
+--R         (12870a b c  + 25740a b c )x     (x )
+--R       + 
+--R               9 5        8 2 4  n - 1 n       9   4 n - 1
+--R         (1430a c  + 6435a b c )x     x  + 715a b c x
+--R    *
+--R         2n 4
+--R       (x  )
+--R   + 
+--R             10 4 n - 1  n 11           9 4       11 3  n - 1  n 10
+--R         572b  c x     (x )   + (5720a b c  + 286b  c )x     (x )
+--R       + 
+--R                2 8 4          10 3  n - 1  n 9
+--R         (25740a b c  + 2860a b  c )x     (x )
+--R       + 
+--R                3 7 4         2 9 3  n - 1  n 8
+--R         (68640a b c  + 12870a b c )x     (x )
+--R       + 
+--R                 4 6 4         3 8 3  n - 1  n 7
+--R         (120120a b c  + 34320a b c )x     (x )
+--R       + 
+--R                 5 5 4         4 7 3  n - 1  n 6
+--R         (144144a b c  + 60060a b c )x     (x )
+--R       + 
+--R                 6 4 4         5 6 3  n - 1  n 5
+--R         (120120a b c  + 72072a b c )x     (x )
+--R       + 
+--R                7 3 4         6 5 3  n - 1  n 4
+--R         (68640a b c  + 60060a b c )x     (x )
+--R       + 
+--R                8 2 4         7 4 3  n - 1  n 3
+--R         (25740a b c  + 34320a b c )x     (x )
+--R       + 
+--R               9   4         8 3 3  n - 1  n 2        10 4        9 2 3  n - 1 n
+--R         (5720a b c  + 12870a b c )x     (x )  + (572a  c  + 2860a b c )x     x
+--R       + 
+--R             10   3 n - 1
+--R         286a  b c x
+--R    *
+--R         2n 3
+--R       (x  )
+--R   + 
+--R             11 3 n - 1  n 12           10 3      12 2  n - 1  n 11
+--R         156b  c x     (x )   + (1716a b  c  + 78b  c )x     (x )
+--R       + 
+--R               2 9 3         11 2  n - 1  n 10
+--R         (8580a b c  + 858a b  c )x     (x )
+--R       + 
+--R                3 8 3        2 10 2  n - 1  n 9
+--R         (25740a b c  + 4290a b  c )x     (x )
+--R       + 
+--R                4 7 3         3 9 2  n - 1  n 8
+--R         (51480a b c  + 12870a b c )x     (x )
+--R       + 
+--R                5 6 3         4 8 2  n - 1  n 7
+--R         (72072a b c  + 25740a b c )x     (x )
+--R       + 
+--R                6 5 3         5 7 2  n - 1  n 6
+--R         (72072a b c  + 36036a b c )x     (x )
+--R       + 
+--R                7 4 3         6 6 2  n - 1  n 5
+--R         (51480a b c  + 36036a b c )x     (x )
+--R       + 
+--R                8 3 3         7 5 2  n - 1  n 4
+--R         (25740a b c  + 25740a b c )x     (x )
+--R       + 
+--R               9 2 3         8 4 2  n - 1  n 3
+--R         (8580a b c  + 12870a b c )x     (x )
+--R       + 
+--R               10   3        9 3 2  n - 1  n 2        11 3       10 2 2  n - 1 n
+--R         (1716a  b c  + 4290a b c )x     (x )  + (156a  c  + 858a  b c )x     x
+--R       + 
+--R            11   2 n - 1
+--R         78a  b c x
+--R    *
+--R         2n 2
+--R       (x  )
+--R   + 
+--R            12 2 n - 1  n 13          11 2      13   n - 1  n 12
+--R         26b  c x     (x )   + (312a b  c  + 13b  c)x     (x )
+--R       + 
+--R               2 10 2         12   n - 1  n 11
+--R         (1716a b  c  + 156a b  c)x     (x )
+--R       + 
+--R               3 9 2       2 11   n - 1  n 10
+--R         (5720a b c  + 858a b  c)x     (x )
+--R       + 
+--R                4 8 2        3 10   n - 1  n 9
+--R         (12870a b c  + 2860a b  c)x     (x )
+--R       + 
+--R                5 7 2        4 9   n - 1  n 8
+--R         (20592a b c  + 6435a b c)x     (x )
+--R       + 
+--R                6 6 2         5 8   n - 1  n 7
+--R         (24024a b c  + 10296a b c)x     (x )
+--R       + 
+--R                7 5 2         6 7   n - 1  n 6
+--R         (20592a b c  + 12012a b c)x     (x )
+--R       + 
+--R                8 4 2         7 6   n - 1  n 5
+--R         (12870a b c  + 10296a b c)x     (x )
+--R       + 
+--R               9 3 2        8 5   n - 1  n 4
+--R         (5720a b c  + 6435a b c)x     (x )
+--R       + 
+--R               10 2 2        9 4   n - 1  n 3
+--R         (1716a  b c  + 2860a b c)x     (x )
+--R       + 
+--R              11   2       10 3   n - 1  n 2       12 2       11 2   n - 1 n
+--R         (312a  b c  + 858a  b c)x     (x )  + (26a  c  + 156a  b c)x     x
+--R       + 
+--R            12     n - 1
+--R         13a  b c x
+--R    *
+--R        2n
+--R       x
+--R   + 
+--R       13   n - 1  n 14         12     14  n - 1  n 13
+--R     2b  c x     (x )   + (26a b  c + b  )x     (x )
+--R   + 
+--R          2 11         13  n - 1  n 12        3 10       2 12  n - 1  n 11
+--R     (156a b  c + 13a b  )x     (x )   + (572a b  c + 78a b  )x     (x )
+--R   + 
+--R           4 9        3 11  n - 1  n 10         5 8        4 10  n - 1  n 9
+--R     (1430a b c + 286a b  )x     (x )   + (2574a b c + 715a b  )x     (x )
+--R   + 
+--R           6 7         5 9  n - 1  n 8         7 6         6 8  n - 1  n 7
+--R     (3432a b c + 1287a b )x     (x )  + (3432a b c + 1716a b )x     (x )
+--R   + 
+--R           8 5         7 7  n - 1  n 6         9 4         8 6  n - 1  n 5
+--R     (2574a b c + 1716a b )x     (x )  + (1430a b c + 1287a b )x     (x )
+--R   + 
+--R          10 3        9 5  n - 1  n 4        11 2        10 4  n - 1  n 3
+--R     (572a  b c + 715a b )x     (x )  + (156a  b c + 286a  b )x     (x )
+--R   + 
+--R         12         11 3  n - 1  n 2      13       12 2  n - 1 n    13   n - 1
+--R     (26a  b c + 78a  b )x     (x )  + (2a  c + 13a  b )x     x  + a  b x
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 649
+r0:=1/14*(a+b*x^n+c*x^(2*n))^14/n
+--R 
+--R
+--R   (2)
+--R        14  2n 14         13 n        13   2n 13
+--R       c  (x  )   + (14b c  x  + 14a c  )(x  )
+--R     + 
+--R           2 12  n 2           12 n      2 12   2n 12
+--R       (91b c  (x )  + 182a b c  x  + 91a c  )(x  )
+--R     + 
+--R            3 11  n 3          2 11  n 2        2   11 n       3 11   2n 11
+--R       (364b c  (x )  + 1092a b c  (x )  + 1092a b c  x  + 364a c  )(x  )
+--R     + 
+--R                4 10  n 4          3 10  n 3        2 2 10  n 2        3   10 n
+--R           1001b c  (x )  + 4004a b c  (x )  + 6006a b c  (x )  + 4004a b c  x
+--R         + 
+--R                4 10
+--R           1001a c
+--R      *
+--R           2n 10
+--R         (x  )
+--R     + 
+--R                5 9  n 5           4 9  n 4         2 3 9  n 3
+--R           2002b c (x )  + 10010a b c (x )  + 20020a b c (x )
+--R         + 
+--R                 3 2 9  n 2         4   9 n        5 9
+--R           20020a b c (x )  + 10010a b c x  + 2002a c
+--R      *
+--R           2n 9
+--R         (x  )
+--R     + 
+--R                6 8  n 6           5 8  n 5         2 4 8  n 4
+--R           3003b c (x )  + 18018a b c (x )  + 45045a b c (x )
+--R         + 
+--R                 3 3 8  n 3         4 2 8  n 2         5   8 n        6 8
+--R           60060a b c (x )  + 45045a b c (x )  + 18018a b c x  + 3003a c
+--R      *
+--R           2n 8
+--R         (x  )
+--R     + 
+--R                7 7  n 7           6 7  n 6         2 5 7  n 5
+--R           3432b c (x )  + 24024a b c (x )  + 72072a b c (x )
+--R         + 
+--R                  3 4 7  n 4          4 3 7  n 3         5 2 7  n 2
+--R           120120a b c (x )  + 120120a b c (x )  + 72072a b c (x )
+--R         + 
+--R                 6   7 n        7 7
+--R           24024a b c x  + 3432a c
+--R      *
+--R           2n 7
+--R         (x  )
+--R     + 
+--R                8 6  n 8           7 6  n 7         2 6 6  n 6
+--R           3003b c (x )  + 24024a b c (x )  + 84084a b c (x )
+--R         + 
+--R                  3 5 6  n 5          4 4 6  n 4          5 3 6  n 3
+--R           168168a b c (x )  + 210210a b c (x )  + 168168a b c (x )
+--R         + 
+--R                 6 2 6  n 2         7   6 n        8 6
+--R           84084a b c (x )  + 24024a b c x  + 3003a c
+--R      *
+--R           2n 6
+--R         (x  )
+--R     + 
+--R                9 5  n 9           8 5  n 8         2 7 5  n 7
+--R           2002b c (x )  + 18018a b c (x )  + 72072a b c (x )
+--R         + 
+--R                  3 6 5  n 6          4 5 5  n 5          5 4 5  n 4
+--R           168168a b c (x )  + 252252a b c (x )  + 252252a b c (x )
+--R         + 
+--R                  6 3 5  n 3         7 2 5  n 2         8   5 n        9 5
+--R           168168a b c (x )  + 72072a b c (x )  + 18018a b c x  + 2002a c
+--R      *
+--R           2n 5
+--R         (x  )
+--R     + 
+--R                10 4  n 10           9 4  n 9         2 8 4  n 8
+--R           1001b  c (x )   + 10010a b c (x )  + 45045a b c (x )
+--R         + 
+--R                  3 7 4  n 7          4 6 4  n 6          5 5 4  n 5
+--R           120120a b c (x )  + 210210a b c (x )  + 252252a b c (x )
+--R         + 
+--R                  6 4 4  n 4          7 3 4  n 3         8 2 4  n 2
+--R           210210a b c (x )  + 120120a b c (x )  + 45045a b c (x )
+--R         + 
+--R                 9   4 n        10 4
+--R           10010a b c x  + 1001a  c
+--R      *
+--R           2n 4
+--R         (x  )
+--R     + 
+--R               11 3  n 11          10 3  n 10         2 9 3  n 9
+--R           364b  c (x )   + 4004a b  c (x )   + 20020a b c (x )
+--R         + 
+--R                 3 8 3  n 8          4 7 3  n 7          5 6 3  n 6
+--R           60060a b c (x )  + 120120a b c (x )  + 168168a b c (x )
+--R         + 
+--R                  6 5 3  n 5          7 4 3  n 4         8 3 3  n 3
+--R           168168a b c (x )  + 120120a b c (x )  + 60060a b c (x )
+--R         + 
+--R                 9 2 3  n 2        10   3 n       11 3
+--R           20020a b c (x )  + 4004a  b c x  + 364a  c
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R              12 2  n 12          11 2  n 11        2 10 2  n 10
+--R           91b  c (x )   + 1092a b  c (x )   + 6006a b  c (x )
+--R         + 
+--R                 3 9 2  n 9         4 8 2  n 8         5 7 2  n 7
+--R           20020a b c (x )  + 45045a b c (x )  + 72072a b c (x )
+--R         + 
+--R                 6 6 2  n 6         7 5 2  n 5         8 4 2  n 4
+--R           84084a b c (x )  + 72072a b c (x )  + 45045a b c (x )
+--R         + 
+--R                 9 3 2  n 3        10 2 2  n 2        11   2 n      12 2
+--R           20020a b c (x )  + 6006a  b c (x )  + 1092a  b c x  + 91a  c
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R              13    n 13         12    n 12        2 11    n 11
+--R           14b  c (x )   + 182a b  c (x )   + 1092a b  c (x )
+--R         + 
+--R                3 10    n 10         4 9    n 9         5 8    n 8
+--R           4004a b  c (x )   + 10010a b c (x )  + 18018a b c (x )
+--R         + 
+--R                 6 7    n 7         7 6    n 6         8 5    n 5
+--R           24024a b c (x )  + 24024a b c (x )  + 18018a b c (x )
+--R         + 
+--R                 9 4    n 4        10 3    n 3        11 2    n 2       12     n
+--R           10010a b c (x )  + 4004a  b c (x )  + 1092a  b c (x )  + 182a  b c x
+--R         + 
+--R              13
+--R           14a  c
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R        14  n 14        13  n 13      2 12  n 12       3 11  n 11
+--R       b  (x )   + 14a b  (x )   + 91a b  (x )   + 364a b  (x )
+--R     + 
+--R            4 10  n 10        5 9  n 9        6 8  n 8        7 7  n 7
+--R       1001a b  (x )   + 2002a b (x )  + 3003a b (x )  + 3432a b (x )
+--R     + 
+--R            8 6  n 6        9 5  n 5        10 4  n 4       11 3  n 3
+--R       3003a b (x )  + 2002a b (x )  + 1001a  b (x )  + 364a  b (x )
+--R     + 
+--R          12 2  n 2      13   n    14
+--R       91a  b (x )  + 14a  b x  + a
+--R  /
+--R     14n
+--R                                                    Type: Expression(Integer)
+--E 399
+
+--S 400 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        14   n log(x) 28        13   n log(x) 27
+--R       c  (%e        )   + 14b c  (%e        )
+--R     + 
+--R             13      2 12    n log(x) 26            12       3 11    n log(x) 25
+--R       (14a c   + 91b c  )(%e        )   + (182a b c   + 364b c  )(%e        )
+--R     + 
+--R           2 12          2 11        4 10    n log(x) 24
+--R       (91a c   + 1092a b c   + 1001b c  )(%e        )
+--R     + 
+--R             2   11          3 10        5 9    n log(x) 23
+--R       (1092a b c   + 4004a b c   + 2002b c )(%e        )
+--R     + 
+--R            3 11        2 2 10           4 9        6 8    n log(x) 22
+--R       (364a c   + 6006a b c   + 10010a b c  + 3003b c )(%e        )
+--R     + 
+--R             3   10         2 3 9           5 8        7 7    n log(x) 21
+--R       (4004a b c   + 20020a b c  + 18018a b c  + 3432b c )(%e        )
+--R     + 
+--R               4 10         3 2 9         2 4 8           6 7        8 6
+--R         (1001a c   + 20020a b c  + 45045a b c  + 24024a b c  + 3003b c )
+--R      *
+--R            n log(x) 20
+--R         (%e        )
+--R     + 
+--R                4   9         3 3 8         2 5 7           7 6        9 5
+--R         (10010a b c  + 60060a b c  + 72072a b c  + 24024a b c  + 2002b c )
+--R      *
+--R            n log(x) 19
+--R         (%e        )
+--R     + 
+--R                5 9         4 2 8          3 4 7         2 6 6           8 5
+--R           2002a c  + 45045a b c  + 120120a b c  + 84084a b c  + 18018a b c
+--R         + 
+--R                10 4
+--R           1001b  c
+--R      *
+--R            n log(x) 18
+--R         (%e        )
+--R     + 
+--R                 5   8          4 3 7          3 5 6         2 7 5           9 4
+--R           18018a b c  + 120120a b c  + 168168a b c  + 72072a b c  + 10010a b c
+--R         + 
+--R               11 3
+--R           364b  c
+--R      *
+--R            n log(x) 17
+--R         (%e        )
+--R     + 
+--R                6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R           3003a c  + 72072a b c  + 210210a b c  + 168168a b c  + 45045a b c
+--R         + 
+--R                  10 3      12 2
+--R           4004a b  c  + 91b  c
+--R      *
+--R            n log(x) 16
+--R         (%e        )
+--R     + 
+--R                 6   7          5 3 6          4 5 5          3 7 4
+--R           24024a b c  + 168168a b c  + 252252a b c  + 120120a b c
+--R         + 
+--R                 2 9 3          11 2      13
+--R           20020a b c  + 1092a b  c  + 14b  c
+--R      *
+--R            n log(x) 15
+--R         (%e        )
+--R     + 
+--R                7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R           3432a c  + 84084a b c  + 252252a b c  + 210210a b c  + 60060a b c
+--R         + 
+--R                2 10 2         12     14
+--R           6006a b  c  + 182a b  c + b
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                 7   6          6 3 5          5 5 4          4 7 3
+--R           24024a b c  + 168168a b c  + 252252a b c  + 120120a b c
+--R         + 
+--R                 3 9 2        2 11         13
+--R           20020a b c  + 1092a b  c + 14a b
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R                8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R           3003a c  + 72072a b c  + 210210a b c  + 168168a b c  + 45045a b c
+--R         + 
+--R                3 10       2 12
+--R           4004a b  c + 91a b
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                 8   5          7 3 4          6 5 3         5 7 2         4 9
+--R           18018a b c  + 120120a b c  + 168168a b c  + 72072a b c  + 10010a b c
+--R         + 
+--R               3 11
+--R           364a b
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                9 5         8 2 4          7 4 3         6 6 2         5 8
+--R           2002a c  + 45045a b c  + 120120a b c  + 84084a b c  + 18018a b c
+--R         + 
+--R                4 10
+--R           1001a b
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                9   4         8 3 3         7 5 2         6 7         5 9
+--R         (10010a b c  + 60060a b c  + 72072a b c  + 24024a b c + 2002a b )
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R               10 4         9 2 3         8 4 2         7 6         6 8
+--R         (1001a  c  + 20020a b c  + 45045a b c  + 24024a b c + 3003a b )
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R             10   3         9 3 2         8 5         7 7    n log(x) 7
+--R       (4004a  b c  + 20020a b c  + 18018a b c + 3432a b )(%e        )
+--R     + 
+--R            11 3        10 2 2         9 4         8 6    n log(x) 6
+--R       (364a  c  + 6006a  b c  + 10010a b c + 3003a b )(%e        )
+--R     + 
+--R             11   2        10 3         9 5    n log(x) 5
+--R       (1092a  b c  + 4004a  b c + 2002a b )(%e        )
+--R     + 
+--R           12 2        11 2         10 4    n log(x) 4
+--R       (91a  c  + 1092a  b c + 1001a  b )(%e        )
+--R     + 
+--R            12          11 3    n log(x) 3       13       12 2    n log(x) 2
+--R       (182a  b c + 364a  b )(%e        )  + (14a  c + 91a  b )(%e        )
+--R     + 
+--R          13    n log(x)
+--R       14a  b %e
+--R  /
+--R     14n
+--R                                         Type: Union(Expression(Integer),...)
+--E 400
+
+--S 401 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        14   n log(x) 28        13   n log(x) 27
+--R       c  (%e        )   + 14b c  (%e        )
+--R     + 
+--R             13      2 12    n log(x) 26            12       3 11    n log(x) 25
+--R       (14a c   + 91b c  )(%e        )   + (182a b c   + 364b c  )(%e        )
+--R     + 
+--R           2 12          2 11        4 10    n log(x) 24
+--R       (91a c   + 1092a b c   + 1001b c  )(%e        )
+--R     + 
+--R             2   11          3 10        5 9    n log(x) 23
+--R       (1092a b c   + 4004a b c   + 2002b c )(%e        )
+--R     + 
+--R            3 11        2 2 10           4 9        6 8    n log(x) 22
+--R       (364a c   + 6006a b c   + 10010a b c  + 3003b c )(%e        )
+--R     + 
+--R             3   10         2 3 9           5 8        7 7    n log(x) 21
+--R       (4004a b c   + 20020a b c  + 18018a b c  + 3432b c )(%e        )
+--R     + 
+--R               4 10         3 2 9         2 4 8           6 7        8 6
+--R         (1001a c   + 20020a b c  + 45045a b c  + 24024a b c  + 3003b c )
+--R      *
+--R            n log(x) 20
+--R         (%e        )
+--R     + 
+--R                4   9         3 3 8         2 5 7           7 6        9 5
+--R         (10010a b c  + 60060a b c  + 72072a b c  + 24024a b c  + 2002b c )
+--R      *
+--R            n log(x) 19
+--R         (%e        )
+--R     + 
+--R                5 9         4 2 8          3 4 7         2 6 6           8 5
+--R           2002a c  + 45045a b c  + 120120a b c  + 84084a b c  + 18018a b c
+--R         + 
+--R                10 4
+--R           1001b  c
+--R      *
+--R            n log(x) 18
+--R         (%e        )
+--R     + 
+--R                 5   8          4 3 7          3 5 6         2 7 5           9 4
+--R           18018a b c  + 120120a b c  + 168168a b c  + 72072a b c  + 10010a b c
+--R         + 
+--R               11 3
+--R           364b  c
+--R      *
+--R            n log(x) 17
+--R         (%e        )
+--R     + 
+--R                6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R           3003a c  + 72072a b c  + 210210a b c  + 168168a b c  + 45045a b c
+--R         + 
+--R                  10 3      12 2
+--R           4004a b  c  + 91b  c
+--R      *
+--R            n log(x) 16
+--R         (%e        )
+--R     + 
+--R                 6   7          5 3 6          4 5 5          3 7 4
+--R           24024a b c  + 168168a b c  + 252252a b c  + 120120a b c
+--R         + 
+--R                 2 9 3          11 2      13
+--R           20020a b c  + 1092a b  c  + 14b  c
+--R      *
+--R            n log(x) 15
+--R         (%e        )
+--R     + 
+--R                7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R           3432a c  + 84084a b c  + 252252a b c  + 210210a b c  + 60060a b c
+--R         + 
+--R                2 10 2         12     14
+--R           6006a b  c  + 182a b  c + b
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                 7   6          6 3 5          5 5 4          4 7 3
+--R           24024a b c  + 168168a b c  + 252252a b c  + 120120a b c
+--R         + 
+--R                 3 9 2        2 11         13
+--R           20020a b c  + 1092a b  c + 14a b
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R                8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R           3003a c  + 72072a b c  + 210210a b c  + 168168a b c  + 45045a b c
+--R         + 
+--R                3 10       2 12
+--R           4004a b  c + 91a b
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                 8   5          7 3 4          6 5 3         5 7 2         4 9
+--R           18018a b c  + 120120a b c  + 168168a b c  + 72072a b c  + 10010a b c
+--R         + 
+--R               3 11
+--R           364a b
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                9 5         8 2 4          7 4 3         6 6 2         5 8
+--R           2002a c  + 45045a b c  + 120120a b c  + 84084a b c  + 18018a b c
+--R         + 
+--R                4 10
+--R           1001a b
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                9   4         8 3 3         7 5 2         6 7         5 9
+--R         (10010a b c  + 60060a b c  + 72072a b c  + 24024a b c + 2002a b )
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R               10 4         9 2 3         8 4 2         7 6         6 8
+--R         (1001a  c  + 20020a b c  + 45045a b c  + 24024a b c + 3003a b )
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R             10   3         9 3 2         8 5         7 7    n log(x) 7
+--R       (4004a  b c  + 20020a b c  + 18018a b c + 3432a b )(%e        )
+--R     + 
+--R            11 3        10 2 2         9 4         8 6    n log(x) 6
+--R       (364a  c  + 6006a  b c  + 10010a b c + 3003a b )(%e        )
+--R     + 
+--R             11   2        10 3         9 5    n log(x) 5
+--R       (1092a  b c  + 4004a  b c + 2002a b )(%e        )
+--R     + 
+--R           12 2        11 2         10 4    n log(x) 4
+--R       (91a  c  + 1092a  b c + 1001a  b )(%e        )
+--R     + 
+--R            12          11 3    n log(x) 3       13       12 2    n log(x) 2
+--R       (182a  b c + 364a  b )(%e        )  + (14a  c + 91a  b )(%e        )
+--R     + 
+--R          13    n log(x)    14  2n 14           13 n        13   2n 13
+--R       14a  b %e         - c  (x  )   + (- 14b c  x  - 14a c  )(x  )
+--R     + 
+--R             2 12  n 2           12 n      2 12   2n 12
+--R       (- 91b c  (x )  - 182a b c  x  - 91a c  )(x  )
+--R     + 
+--R              3 11  n 3          2 11  n 2        2   11 n       3 11   2n 11
+--R       (- 364b c  (x )  - 1092a b c  (x )  - 1092a b c  x  - 364a c  )(x  )
+--R     + 
+--R                  4 10  n 4          3 10  n 3        2 2 10  n 2
+--R           - 1001b c  (x )  - 4004a b c  (x )  - 6006a b c  (x )
+--R         + 
+--R                  3   10 n        4 10
+--R           - 4004a b c  x  - 1001a c
+--R      *
+--R           2n 10
+--R         (x  )
+--R     + 
+--R                  5 9  n 5           4 9  n 4         2 3 9  n 3
+--R           - 2002b c (x )  - 10010a b c (x )  - 20020a b c (x )
+--R         + 
+--R                   3 2 9  n 2         4   9 n        5 9
+--R           - 20020a b c (x )  - 10010a b c x  - 2002a c
+--R      *
+--R           2n 9
+--R         (x  )
+--R     + 
+--R                  6 8  n 6           5 8  n 5         2 4 8  n 4
+--R           - 3003b c (x )  - 18018a b c (x )  - 45045a b c (x )
+--R         + 
+--R                   3 3 8  n 3         4 2 8  n 2         5   8 n        6 8
+--R           - 60060a b c (x )  - 45045a b c (x )  - 18018a b c x  - 3003a c
+--R      *
+--R           2n 8
+--R         (x  )
+--R     + 
+--R                  7 7  n 7           6 7  n 6         2 5 7  n 5
+--R           - 3432b c (x )  - 24024a b c (x )  - 72072a b c (x )
+--R         + 
+--R                    3 4 7  n 4          4 3 7  n 3         5 2 7  n 2
+--R           - 120120a b c (x )  - 120120a b c (x )  - 72072a b c (x )
+--R         + 
+--R                   6   7 n        7 7
+--R           - 24024a b c x  - 3432a c
+--R      *
+--R           2n 7
+--R         (x  )
+--R     + 
+--R                  8 6  n 8           7 6  n 7         2 6 6  n 6
+--R           - 3003b c (x )  - 24024a b c (x )  - 84084a b c (x )
+--R         + 
+--R                    3 5 6  n 5          4 4 6  n 4          5 3 6  n 3
+--R           - 168168a b c (x )  - 210210a b c (x )  - 168168a b c (x )
+--R         + 
+--R                   6 2 6  n 2         7   6 n        8 6
+--R           - 84084a b c (x )  - 24024a b c x  - 3003a c
+--R      *
+--R           2n 6
+--R         (x  )
+--R     + 
+--R                  9 5  n 9           8 5  n 8         2 7 5  n 7
+--R           - 2002b c (x )  - 18018a b c (x )  - 72072a b c (x )
+--R         + 
+--R                    3 6 5  n 6          4 5 5  n 5          5 4 5  n 4
+--R           - 168168a b c (x )  - 252252a b c (x )  - 252252a b c (x )
+--R         + 
+--R                    6 3 5  n 3         7 2 5  n 2         8   5 n        9 5
+--R           - 168168a b c (x )  - 72072a b c (x )  - 18018a b c x  - 2002a c
+--R      *
+--R           2n 5
+--R         (x  )
+--R     + 
+--R                  10 4  n 10           9 4  n 9         2 8 4  n 8
+--R           - 1001b  c (x )   - 10010a b c (x )  - 45045a b c (x )
+--R         + 
+--R                    3 7 4  n 7          4 6 4  n 6          5 5 4  n 5
+--R           - 120120a b c (x )  - 210210a b c (x )  - 252252a b c (x )
+--R         + 
+--R                    6 4 4  n 4          7 3 4  n 3         8 2 4  n 2
+--R           - 210210a b c (x )  - 120120a b c (x )  - 45045a b c (x )
+--R         + 
+--R                   9   4 n        10 4
+--R           - 10010a b c x  - 1001a  c
+--R      *
+--R           2n 4
+--R         (x  )
+--R     + 
+--R                 11 3  n 11          10 3  n 10         2 9 3  n 9
+--R           - 364b  c (x )   - 4004a b  c (x )   - 20020a b c (x )
+--R         + 
+--R                   3 8 3  n 8          4 7 3  n 7          5 6 3  n 6
+--R           - 60060a b c (x )  - 120120a b c (x )  - 168168a b c (x )
+--R         + 
+--R                    6 5 3  n 5          7 4 3  n 4         8 3 3  n 3
+--R           - 168168a b c (x )  - 120120a b c (x )  - 60060a b c (x )
+--R         + 
+--R                   9 2 3  n 2        10   3 n       11 3
+--R           - 20020a b c (x )  - 4004a  b c x  - 364a  c
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R                12 2  n 12          11 2  n 11        2 10 2  n 10
+--R           - 91b  c (x )   - 1092a b  c (x )   - 6006a b  c (x )
+--R         + 
+--R                   3 9 2  n 9         4 8 2  n 8         5 7 2  n 7
+--R           - 20020a b c (x )  - 45045a b c (x )  - 72072a b c (x )
+--R         + 
+--R                   6 6 2  n 6         7 5 2  n 5         8 4 2  n 4
+--R           - 84084a b c (x )  - 72072a b c (x )  - 45045a b c (x )
+--R         + 
+--R                   9 3 2  n 3        10 2 2  n 2        11   2 n      12 2
+--R           - 20020a b c (x )  - 6006a  b c (x )  - 1092a  b c x  - 91a  c
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R                13    n 13         12    n 12        2 11    n 11
+--R           - 14b  c (x )   - 182a b  c (x )   - 1092a b  c (x )
+--R         + 
+--R                  3 10    n 10         4 9    n 9         5 8    n 8
+--R           - 4004a b  c (x )   - 10010a b c (x )  - 18018a b c (x )
+--R         + 
+--R                   6 7    n 7         7 6    n 6         8 5    n 5
+--R           - 24024a b c (x )  - 24024a b c (x )  - 18018a b c (x )
+--R         + 
+--R                   9 4    n 4        10 3    n 3        11 2    n 2
+--R           - 10010a b c (x )  - 4004a  b c (x )  - 1092a  b c (x )
+--R         + 
+--R                 12     n      13
+--R           - 182a  b c x  - 14a  c
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R          14  n 14        13  n 13      2 12  n 12       3 11  n 11
+--R       - b  (x )   - 14a b  (x )   - 91a b  (x )   - 364a b  (x )
+--R     + 
+--R              4 10  n 10        5 9  n 9        6 8  n 8        7 7  n 7
+--R       - 1001a b  (x )   - 2002a b (x )  - 3003a b (x )  - 3432a b (x )
+--R     + 
+--R              8 6  n 6        9 5  n 5        10 4  n 4       11 3  n 3
+--R       - 3003a b (x )  - 2002a b (x )  - 1001a  b (x )  - 364a  b (x )
+--R     + 
+--R            12 2  n 2      13   n    14
+--R       - 91a  b (x )  - 14a  b x  - a
+--R  /
+--R     14n
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         14   n log(x) 28        13   n log(x) 27
+--R       2c  (%e        )   + 27b c  (%e        )
+--R     + 
+--R             13       2 12    n log(x) 26
+--R       (26a c   + 169b c  )(%e        )
+--R     + 
+--R                12       3 11    n log(x) 25
+--R       (325a b c   + 650b c  )(%e        )
+--R     + 
+--R            2 12          2 11        4 10    n log(x) 24
+--R       (156a c   + 1872a b c   + 1716b c  )(%e        )
+--R     + 
+--R             2   11          3 10        5 9    n log(x) 23
+--R       (1794a b c   + 6578a b c   + 3289b c )(%e        )
+--R     + 
+--R            3 11        2 2 10           4 9        6 8    n log(x) 22
+--R       (572a c   + 9438a b c   + 15730a b c  + 4719b c )(%e        )
+--R     + 
+--R             3   10         2 3 9           5 8        7 7    n log(x) 21
+--R       (6006a b c   + 30030a b c  + 27027a b c  + 5148b c )(%e        )
+--R     + 
+--R               4 10         3 2 9         2 4 8           6 7        8 6
+--R         (1430a c   + 28600a b c  + 64350a b c  + 34320a b c  + 4290b c )
+--R      *
+--R            n log(x) 20
+--R         (%e        )
+--R     + 
+--R                4   9         3 3 8         2 5 7           7 6        9 5
+--R         (13585a b c  + 81510a b c  + 97812a b c  + 32604a b c  + 2717b c )
+--R      *
+--R            n log(x) 19
+--R         (%e        )
+--R     + 
+--R                5 9         4 2 8          3 4 7          2 6 6           8 5
+--R           2574a c  + 57915a b c  + 154440a b c  + 108108a b c  + 23166a b c
+--R         + 
+--R                10 4
+--R           1287b  c
+--R      *
+--R            n log(x) 18
+--R         (%e        )
+--R     + 
+--R                 5   8          4 3 7          3 5 6         2 7 5           9 4
+--R           21879a b c  + 145860a b c  + 204204a b c  + 87516a b c  + 12155a b c
+--R         + 
+--R               11 3
+--R           442b  c
+--R      *
+--R            n log(x) 17
+--R         (%e        )
+--R     + 
+--R                6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R           3432a c  + 82368a b c  + 240240a b c  + 192192a b c  + 51480a b c
+--R         + 
+--R                  10 3       12 2
+--R           4576a b  c  + 104b  c
+--R      *
+--R            n log(x) 16
+--R         (%e        )
+--R     + 
+--R                 6   7          5 3 6          4 5 5          3 7 4
+--R           25740a b c  + 180180a b c  + 270270a b c  + 128700a b c
+--R         + 
+--R                 2 9 3          11 2      13
+--R           21450a b c  + 1170a b  c  + 15b  c
+--R      *
+--R            n log(x) 15
+--R         (%e        )
+--R     + 
+--R                7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R           3432a c  + 84084a b c  + 252252a b c  + 210210a b c  + 60060a b c
+--R         + 
+--R                2 10 2         12     14
+--R           6006a b  c  + 182a b  c + b
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                 7   6          6 3 5          5 5 4          4 7 3
+--R           22308a b c  + 156156a b c  + 234234a b c  + 111540a b c
+--R         + 
+--R                 3 9 2        2 11         13
+--R           18590a b c  + 1014a b  c + 13a b
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R                8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R           2574a c  + 61776a b c  + 180180a b c  + 144144a b c  + 38610a b c
+--R         + 
+--R                3 10       2 12
+--R           3432a b  c + 78a b
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                 8   5         7 3 4          6 5 3         5 7 2        4 9
+--R           14157a b c  + 94380a b c  + 132132a b c  + 56628a b c  + 7865a b c
+--R         + 
+--R               3 11
+--R           286a b
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                9 5         8 2 4         7 4 3         6 6 2         5 8
+--R           1430a c  + 32175a b c  + 85800a b c  + 60060a b c  + 12870a b c
+--R         + 
+--R               4 10
+--R           715a b
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R               9   4         8 3 3         7 5 2         6 7         5 9
+--R         (6435a b c  + 38610a b c  + 46332a b c  + 15444a b c + 1287a b )
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R              10 4         9 2 3         8 4 2         7 6         6 8
+--R         (572a  c  + 11440a b c  + 25740a b c  + 13728a b c + 1716a b )
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R             10   3         9 3 2        8 5         7 7    n log(x) 7
+--R       (2002a  b c  + 10010a b c  + 9009a b c + 1716a b )(%e        )
+--R     + 
+--R            11 3        10 2 2        9 4         8 6    n log(x) 6
+--R       (156a  c  + 2574a  b c  + 4290a b c + 1287a b )(%e        )
+--R     + 
+--R            11   2        10 3        9 5    n log(x) 5
+--R       (390a  b c  + 1430a  b c + 715a b )(%e        )
+--R     + 
+--R           12 2       11 2        10 4    n log(x) 4
+--R       (26a  c  + 312a  b c + 286a  b )(%e        )
+--R     + 
+--R           12         11 3    n log(x) 3      13       12 2    n log(x) 2
+--R       (39a  b c + 78a  b )(%e        )  + (2a  c + 13a  b )(%e        )
+--R     + 
+--R        13    n log(x)        14   2n - 1      13   n - 1   2n 13
+--R       a  b %e         + (- 2c  x x       - b c  x x     )(x  )
+--R     + 
+--R                   13   n        13   2n - 1      2 12   n - 1 n
+--R           (- 26b c  x x  - 26a c  x)x       - 13b c  x x     x
+--R         + 
+--R                    12   n - 1
+--R           - 13a b c  x x
+--R      *
+--R           2n 12
+--R         (x  )
+--R     + 
+--R                  2 12    n 2           12   n       2 12   2n - 1
+--R           (- 156b c  x (x )  - 312a b c  x x  - 156a c  x)x
+--R         + 
+--R                3 11   n - 1  n 2         2 11   n - 1 n      2   11   n - 1
+--R           - 78b c  x x     (x )  - 156a b c  x x     x  - 78a b c  x x
+--R      *
+--R           2n 11
+--R         (x  )
+--R     + 
+--R                     3 11    n 3          2 11    n 2        2   11   n
+--R               - 572b c  x (x )  - 1716a b c  x (x )  - 1716a b c  x x
+--R             + 
+--R                     3 11
+--R               - 572a c  x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                 4 10   n - 1  n 3         3 10   n - 1  n 2
+--R           - 286b c  x x     (x )  - 858a b c  x x     (x )
+--R         + 
+--R                 2 2 10   n - 1 n       3   10   n - 1
+--R           - 858a b c  x x     x  - 286a b c  x x
+--R      *
+--R           2n 10
+--R         (x  )
+--R     + 
+--R                      4 10    n 4          3 10    n 3        2 2 10    n 2
+--R               - 1430b c  x (x )  - 5720a b c  x (x )  - 8580a b c  x (x )
+--R             + 
+--R                      3   10   n        4 10
+--R               - 5720a b c  x x  - 1430a c  x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                 5 9   n - 1  n 4          4 9   n - 1  n 3
+--R           - 715b c x x     (x )  - 2860a b c x x     (x )
+--R         + 
+--R                  2 3 9   n - 1  n 2        3 2 9   n - 1 n       4   9   n - 1
+--R           - 4290a b c x x     (x )  - 2860a b c x x     x  - 715a b c x x
+--R      *
+--R           2n 9
+--R         (x  )
+--R     + 
+--R                      5 9    n 5           4 9    n 4         2 3 9    n 3
+--R               - 2574b c x (x )  - 12870a b c x (x )  - 25740a b c x (x )
+--R             + 
+--R                       3 2 9    n 2         4   9   n        5 9
+--R               - 25740a b c x (x )  - 12870a b c x x  - 2574a c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                  6 8   n - 1  n 5          5 8   n - 1  n 4
+--R           - 1287b c x x     (x )  - 6435a b c x x     (x )
+--R         + 
+--R                   2 4 8   n - 1  n 3         3 3 8   n - 1  n 2
+--R           - 12870a b c x x     (x )  - 12870a b c x x     (x )
+--R         + 
+--R                  4 2 8   n - 1 n        5   8   n - 1
+--R           - 6435a b c x x     x  - 1287a b c x x
+--R      *
+--R           2n 8
+--R         (x  )
+--R     + 
+--R                      6 8    n 6           5 8    n 5         2 4 8    n 4
+--R               - 3432b c x (x )  - 20592a b c x (x )  - 51480a b c x (x )
+--R             + 
+--R                       3 3 8    n 3         4 2 8    n 2         5   8   n
+--R               - 68640a b c x (x )  - 51480a b c x (x )  - 20592a b c x x
+--R             + 
+--R                      6 8
+--R               - 3432a c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                  7 7   n - 1  n 6           6 7   n - 1  n 5
+--R           - 1716b c x x     (x )  - 10296a b c x x     (x )
+--R         + 
+--R                   2 5 7   n - 1  n 4         3 4 7   n - 1  n 3
+--R           - 25740a b c x x     (x )  - 34320a b c x x     (x )
+--R         + 
+--R                 4 3 7   n - 1  n 2         5 2 7   n - 1 n        6   7   n - 1
+--R         - 25740a b c x x     (x )  - 10296a b c x x     x  - 1716a b c x x
+--R      *
+--R           2n 7
+--R         (x  )
+--R     + 
+--R                      7 7    n 7           6 7    n 6         2 5 7    n 5
+--R               - 3432b c x (x )  - 24024a b c x (x )  - 72072a b c x (x )
+--R             + 
+--R                        3 4 7    n 4          4 3 7    n 3         5 2 7    n 2
+--R               - 120120a b c x (x )  - 120120a b c x (x )  - 72072a b c x (x )
+--R             + 
+--R                       6   7   n        7 7
+--R               - 24024a b c x x  - 3432a c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                  8 6   n - 1  n 7           7 6   n - 1  n 6
+--R           - 1716b c x x     (x )  - 12012a b c x x     (x )
+--R         + 
+--R                   2 6 6   n - 1  n 5         3 5 6   n - 1  n 4
+--R           - 36036a b c x x     (x )  - 60060a b c x x     (x )
+--R         + 
+--R                   4 4 6   n - 1  n 3         5 3 6   n - 1  n 2
+--R           - 60060a b c x x     (x )  - 36036a b c x x     (x )
+--R         + 
+--R                   6 2 6   n - 1 n        7   6   n - 1
+--R           - 12012a b c x x     x  - 1716a b c x x
+--R      *
+--R           2n 6
+--R         (x  )
+--R     + 
+--R                      8 6    n 8           7 6    n 7         2 6 6    n 6
+--R               - 2574b c x (x )  - 20592a b c x (x )  - 72072a b c x (x )
+--R             + 
+--R                        3 5 6    n 5          4 4 6    n 4          5 3 6    n 3
+--R               - 144144a b c x (x )  - 180180a b c x (x )  - 144144a b c x (x )
+--R             + 
+--R                       6 2 6    n 2         7   6   n        8 6
+--R               - 72072a b c x (x )  - 20592a b c x x  - 2574a c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                  9 5   n - 1  n 8           8 5   n - 1  n 7
+--R           - 1287b c x x     (x )  - 10296a b c x x     (x )
+--R         + 
+--R                   2 7 5   n - 1  n 6         3 6 5   n - 1  n 5
+--R           - 36036a b c x x     (x )  - 72072a b c x x     (x )
+--R         + 
+--R                   4 5 5   n - 1  n 4         5 4 5   n - 1  n 3
+--R           - 90090a b c x x     (x )  - 72072a b c x x     (x )
+--R         + 
+--R                 6 3 5   n - 1  n 2         7 2 5   n - 1 n        8   5   n - 1
+--R         - 36036a b c x x     (x )  - 10296a b c x x     x  - 1287a b c x x
+--R      *
+--R           2n 5
+--R         (x  )
+--R     + 
+--R                      9 5    n 9           8 5    n 8         2 7 5    n 7
+--R               - 1430b c x (x )  - 12870a b c x (x )  - 51480a b c x (x )
+--R             + 
+--R                        3 6 5    n 6          4 5 5    n 5          5 4 5    n 4
+--R               - 120120a b c x (x )  - 180180a b c x (x )  - 180180a b c x (x )
+--R             + 
+--R                        6 3 5    n 3         7 2 5    n 2         8   5   n
+--R               - 120120a b c x (x )  - 51480a b c x (x )  - 12870a b c x x
+--R             + 
+--R                      9 5
+--R               - 1430a c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                 10 4   n - 1  n 9          9 4   n - 1  n 8
+--R           - 715b  c x x     (x )  - 6435a b c x x     (x )
+--R         + 
+--R                   2 8 4   n - 1  n 7         3 7 4   n - 1  n 6
+--R           - 25740a b c x x     (x )  - 60060a b c x x     (x )
+--R         + 
+--R                   4 6 4   n - 1  n 5         5 5 4   n - 1  n 4
+--R           - 90090a b c x x     (x )  - 90090a b c x x     (x )
+--R         + 
+--R                   6 4 4   n - 1  n 3         7 3 4   n - 1  n 2
+--R           - 60060a b c x x     (x )  - 25740a b c x x     (x )
+--R         + 
+--R                  8 2 4   n - 1 n       9   4   n - 1
+--R           - 6435a b c x x     x  - 715a b c x x
+--R      *
+--R           2n 4
+--R         (x  )
+--R     + 
+--R                     10 4    n 10          9 4    n 9         2 8 4    n 8
+--R               - 572b  c x (x )   - 5720a b c x (x )  - 25740a b c x (x )
+--R             + 
+--R                       3 7 4    n 7          4 6 4    n 6          5 5 4    n 5
+--R               - 68640a b c x (x )  - 120120a b c x (x )  - 144144a b c x (x )
+--R             + 
+--R                        6 4 4    n 4         7 3 4    n 3         8 2 4    n 2
+--R               - 120120a b c x (x )  - 68640a b c x (x )  - 25740a b c x (x )
+--R             + 
+--R                      9   4   n       10 4
+--R               - 5720a b c x x  - 572a  c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                 11 3   n - 1  n 10          10 3   n - 1  n 9
+--R           - 286b  c x x     (x )   - 2860a b  c x x     (x )
+--R         + 
+--R                   2 9 3   n - 1  n 8         3 8 3   n - 1  n 7
+--R           - 12870a b c x x     (x )  - 34320a b c x x     (x )
+--R         + 
+--R                   4 7 3   n - 1  n 6         5 6 3   n - 1  n 5
+--R           - 60060a b c x x     (x )  - 72072a b c x x     (x )
+--R         + 
+--R                   6 5 3   n - 1  n 4         7 4 3   n - 1  n 3
+--R           - 60060a b c x x     (x )  - 34320a b c x x     (x )
+--R         + 
+--R                 8 3 3   n - 1  n 2        9 2 3   n - 1 n       10   3   n - 1
+--R         - 12870a b c x x     (x )  - 2860a b c x x     x  - 286a  b c x x
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R                     11 3    n 11          10 3    n 10        2 9 3    n 9
+--R               - 156b  c x (x )   - 1716a b  c x (x )   - 8580a b c x (x )
+--R             + 
+--R                       3 8 3    n 8         4 7 3    n 7         5 6 3    n 6
+--R               - 25740a b c x (x )  - 51480a b c x (x )  - 72072a b c x (x )
+--R             + 
+--R                       6 5 3    n 5         7 4 3    n 4         8 3 3    n 3
+--R               - 72072a b c x (x )  - 51480a b c x (x )  - 25740a b c x (x )
+--R             + 
+--R                      9 2 3    n 2        10   3   n       11 3
+--R               - 8580a b c x (x )  - 1716a  b c x x  - 156a  c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                12 2   n - 1  n 11         11 2   n - 1  n 10
+--R           - 78b  c x x     (x )   - 858a b  c x x     (x )
+--R         + 
+--R                  2 10 2   n - 1  n 9         3 9 2   n - 1  n 8
+--R           - 4290a b  c x x     (x )  - 12870a b c x x     (x )
+--R         + 
+--R                   4 8 2   n - 1  n 7         5 7 2   n - 1  n 6
+--R           - 25740a b c x x     (x )  - 36036a b c x x     (x )
+--R         + 
+--R                   6 6 2   n - 1  n 5         7 5 2   n - 1  n 4
+--R           - 36036a b c x x     (x )  - 25740a b c x x     (x )
+--R         + 
+--R                   8 4 2   n - 1  n 3        9 3 2   n - 1  n 2
+--R           - 12870a b c x x     (x )  - 4290a b c x x     (x )
+--R         + 
+--R                 10 2 2   n - 1 n      11   2   n - 1
+--R           - 858a  b c x x     x  - 78a  b c x x
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R                    12 2    n 12         11 2    n 11        2 10 2    n 10
+--R               - 26b  c x (x )   - 312a b  c x (x )   - 1716a b  c x (x )
+--R             + 
+--R                      3 9 2    n 9         4 8 2    n 8         5 7 2    n 7
+--R               - 5720a b c x (x )  - 12870a b c x (x )  - 20592a b c x (x )
+--R             + 
+--R                       6 6 2    n 6         7 5 2    n 5         8 4 2    n 4
+--R               - 24024a b c x (x )  - 20592a b c x (x )  - 12870a b c x (x )
+--R             + 
+--R                      9 3 2    n 3        10 2 2    n 2       11   2   n
+--R               - 5720a b c x (x )  - 1716a  b c x (x )  - 312a  b c x x
+--R             + 
+--R                    12 2
+--R               - 26a  c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                13     n - 1  n 12         12     n - 1  n 11
+--R           - 13b  c x x     (x )   - 156a b  c x x     (x )
+--R         + 
+--R                 2 11     n - 1  n 10        3 10     n - 1  n 9
+--R           - 858a b  c x x     (x )   - 2860a b  c x x     (x )
+--R         + 
+--R                  4 9     n - 1  n 8         5 8     n - 1  n 7
+--R           - 6435a b c x x     (x )  - 10296a b c x x     (x )
+--R         + 
+--R                   6 7     n - 1  n 6         7 6     n - 1  n 5
+--R           - 12012a b c x x     (x )  - 10296a b c x x     (x )
+--R         + 
+--R                  8 5     n - 1  n 4        9 4     n - 1  n 3
+--R           - 6435a b c x x     (x )  - 2860a b c x x     (x )
+--R         + 
+--R                 10 3     n - 1  n 2       11 2     n - 1 n      12       n - 1
+--R           - 858a  b c x x     (x )  - 156a  b c x x     x  - 13a  b c x x
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R               13      n 13        12      n 12       2 11      n 11
+--R           - 2b  c x (x )   - 26a b  c x (x )   - 156a b  c x (x )
+--R         + 
+--R                 3 10      n 10        4 9      n 9        5 8      n 8
+--R           - 572a b  c x (x )   - 1430a b c x (x )  - 2574a b c x (x )
+--R         + 
+--R                  6 7      n 7        7 6      n 6        8 5      n 5
+--R           - 3432a b c x (x )  - 3432a b c x (x )  - 2574a b c x (x )
+--R         + 
+--R                  9 4      n 4       10 3      n 3       11 2      n 2
+--R           - 1430a b c x (x )  - 572a  b c x (x )  - 156a  b c x (x )
+--R         + 
+--R                12       n     13
+--R           - 26a  b c x x  - 2a  c x
+--R      *
+--R          2n - 1
+--R         x
+--R     + 
+--R          14   n - 1  n 13        13   n - 1  n 12      2 12   n - 1  n 11
+--R       - b  x x     (x )   - 13a b  x x     (x )   - 78a b  x x     (x )
+--R     + 
+--R             3 11   n - 1  n 10       4 10   n - 1  n 9        5 9   n - 1  n 8
+--R       - 286a b  x x     (x )   - 715a b  x x     (x )  - 1287a b x x     (x )
+--R     + 
+--R              6 8   n - 1  n 7        7 7   n - 1  n 6        8 6   n - 1  n 5
+--R       - 1716a b x x     (x )  - 1716a b x x     (x )  - 1287a b x x     (x )
+--R     + 
+--R             9 5   n - 1  n 4       10 4   n - 1  n 3      11 3   n - 1  n 2
+--R       - 715a b x x     (x )  - 286a  b x x     (x )  - 78a  b x x     (x )
+--R     + 
+--R            12 2   n - 1 n    13     n - 1
+--R       - 13a  b x x     x  - a  b x x
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 649
+t0:=(b+2*c*x)*(-a+b*x+c*x^2)^13
+--R 
+--R
+--R   (1)
+--R       14 27        13 26           13       2 12  25
+--R     2c  x   + 27b c  x   + (- 26a c   + 169b c  )x
+--R   + 
+--R                12       3 11  24        2 12          2 11        4 10  23
+--R     (- 325a b c   + 650b c  )x   + (156a c   - 1872a b c   + 1716b c  )x
+--R   + 
+--R           2   11          3 10        5 9  22
+--R     (1794a b c   - 6578a b c   + 3289b c )x
+--R   + 
+--R            3 11        2 2 10           4 9        6 8  21
+--R     (- 572a c   + 9438a b c   - 15730a b c  + 4719b c )x
+--R   + 
+--R             3   10         2 3 9           5 8        7 7  20
+--R     (- 6006a b c   + 30030a b c  - 27027a b c  + 5148b c )x
+--R   + 
+--R           4 10         3 2 9         2 4 8           6 7        8 6  19
+--R     (1430a c   - 28600a b c  + 64350a b c  - 34320a b c  + 4290b c )x
+--R   + 
+--R            4   9         3 3 8         2 5 7           7 6        9 5  18
+--R     (13585a b c  - 81510a b c  + 97812a b c  - 32604a b c  + 2717b c )x
+--R   + 
+--R                5 9         4 2 8          3 4 7          2 6 6           8 5
+--R         - 2574a c  + 57915a b c  - 154440a b c  + 108108a b c  - 23166a b c
+--R       + 
+--R              10 4
+--R         1287b  c
+--R    *
+--R        17
+--R       x
+--R   + 
+--R                 5   8          4 3 7          3 5 6         2 7 5           9 4
+--R         - 21879a b c  + 145860a b c  - 204204a b c  + 87516a b c  - 12155a b c
+--R       + 
+--R             11 3
+--R         442b  c
+--R    *
+--R        16
+--R       x
+--R   + 
+--R              6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R         3432a c  - 82368a b c  + 240240a b c  - 192192a b c  + 51480a b c
+--R       + 
+--R                  10 3       12 2
+--R         - 4576a b  c  + 104b  c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R               6   7          5 3 6          4 5 5          3 7 4         2 9 3
+--R         25740a b c  - 180180a b c  + 270270a b c  - 128700a b c  + 21450a b c
+--R       + 
+--R                  11 2      13
+--R         - 1170a b  c  + 15b  c
+--R    *
+--R        14
+--R       x
+--R   + 
+--R                7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R         - 3432a c  + 84084a b c  - 252252a b c  + 210210a b c  - 60060a b c
+--R       + 
+--R              2 10 2         12     14
+--R         6006a b  c  - 182a b  c + b
+--R    *
+--R        13
+--R       x
+--R   + 
+--R                 7   6          6 3 5          5 5 4          4 7 3
+--R         - 22308a b c  + 156156a b c  - 234234a b c  + 111540a b c
+--R       + 
+--R                 3 9 2        2 11         13
+--R         - 18590a b c  + 1014a b  c - 13a b
+--R    *
+--R        12
+--R       x
+--R   + 
+--R              8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R         2574a c  - 61776a b c  + 180180a b c  - 144144a b c  + 38610a b c
+--R       + 
+--R                3 10       2 12
+--R         - 3432a b  c + 78a b
+--R    *
+--R        11
+--R       x
+--R   + 
+--R               8   5         7 3 4          6 5 3         5 7 2        4 9
+--R         14157a b c  - 94380a b c  + 132132a b c  - 56628a b c  + 7865a b c
+--R       + 
+--R               3 11
+--R         - 286a b
+--R    *
+--R        10
+--R       x
+--R   + 
+--R                9 5         8 2 4         7 4 3         6 6 2         5 8
+--R         - 1430a c  + 32175a b c  - 85800a b c  + 60060a b c  - 12870a b c
+--R       + 
+--R             4 10
+--R         715a b
+--R    *
+--R        9
+--R       x
+--R   + 
+--R             9   4         8 3 3         7 5 2         6 7         5 9  8
+--R     (- 6435a b c  + 38610a b c  - 46332a b c  + 15444a b c - 1287a b )x
+--R   + 
+--R          10 4         9 2 3         8 4 2         7 6         6 8  7
+--R     (572a  c  - 11440a b c  + 25740a b c  - 13728a b c + 1716a b )x
+--R   + 
+--R           10   3         9 3 2        8 5         7 7  6
+--R     (2002a  b c  - 10010a b c  + 9009a b c - 1716a b )x
+--R   + 
+--R            11 3        10 2 2        9 4         8 6  5
+--R     (- 156a  c  + 2574a  b c  - 4290a b c + 1287a b )x
+--R   + 
+--R            11   2        10 3        9 5  4
+--R     (- 390a  b c  + 1430a  b c - 715a b )x
+--R   + 
+--R         12 2       11 2        10 4  3       12         11 3  2
+--R     (26a  c  - 312a  b c + 286a  b )x  + (39a  b c - 78a  b )x
+--R   + 
+--R          13       12 2      13
+--R     (- 2a  c + 13a  b )x - a  b
+--R                                                    Type: Polynomial(Integer)
+--E 403
+
+--S 404 of 649
+r0:=1/14*(a-b*x-c*x^2)^14
+--R 
+--R
+--R   (2)
+--R      1  14 28      13 27         13   13  2 12  26             12      3 11  25
+--R     -- c  x   + b c  x   + (- a c   + -- b c  )x   + (- 13a b c   + 26b c  )x
+--R     14                                 2
+--R   + 
+--R      13  2 12        2 11   143  4 10  24
+--R     (-- a c   - 78a b c   + --- b c  )x
+--R       2                      2
+--R   + 
+--R         2   11         3 10       5 9  23
+--R     (78a b c   - 286a b c   + 143b c )x
+--R   + 
+--R           3 11       2 2 10         4 9   429  6 8  22
+--R     (- 26a c   + 429a b c   - 715a b c  + --- b c )x
+--R                                            2
+--R   + 
+--R            3   10        2 3 9          5 8   1716  7 7  21
+--R     (- 286a b c   + 1430a b c  - 1287a b c  + ---- b c )x
+--R                                                 7
+--R   + 
+--R      143  4 10        3 2 9   6435  2 4 8          6 7   429  8 6  20
+--R     (--- a c   - 1430a b c  + ---- a b c  - 1716a b c  + --- b c )x
+--R       2                         2                         2
+--R   + 
+--R          4   9        3 3 8        2 5 7          7 6       9 5  19
+--R     (715a b c  - 4290a b c  + 5148a b c  - 1716a b c  + 143b c )x
+--R   + 
+--R               5 9   6435  4 2 8        3 4 7        2 6 6          8 5
+--R         - 143a c  + ---- a b c  - 8580a b c  + 6006a b c  - 1287a b c
+--R                       2
+--R       + 
+--R         143  10 4
+--R         --- b  c
+--R          2
+--R    *
+--R        18
+--R       x
+--R   + 
+--R                5   8        4 3 7         3 5 6        2 7 5         9 4
+--R         - 1287a b c  + 8580a b c  - 12012a b c  + 5148a b c  - 715a b c
+--R       + 
+--R            11 3
+--R         26b  c
+--R    *
+--R        17
+--R       x
+--R   + 
+--R         429  6 8        5 2 7         4 4 6         3 6 5   6435  2 8 4
+--R         --- a c  - 5148a b c  + 15015a b c  - 12012a b c  + ---- a b c
+--R          2                                                    2
+--R       + 
+--R                 10 3   13  12 2
+--R         - 286a b  c  + -- b  c
+--R                         2
+--R    *
+--R        16
+--R       x
+--R   + 
+--R              6   7         5 3 6         4 5 5        3 7 4        2 9 3
+--R         1716a b c  - 12012a b c  + 18018a b c  - 8580a b c  + 1430a b c
+--R       + 
+--R                11 2    13
+--R         - 78a b  c  + b  c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R           1716  7 7        6 2 6         5 4 5         4 6 4        3 8 3
+--R         - ---- a c  + 6006a b c  - 18018a b c  + 15015a b c  - 4290a b c
+--R             7
+--R       + 
+--R             2 10 2        12     1  14
+--R         429a b  c  - 13a b  c + -- b
+--R                                 14
+--R    *
+--R        14
+--R       x
+--R   + 
+--R                7   6         6 3 5         5 5 4        4 7 3        3 9 2
+--R         - 1716a b c  + 12012a b c  - 18018a b c  + 8580a b c  - 1430a b c
+--R       + 
+--R            2 11       13
+--R         78a b  c - a b
+--R    *
+--R        13
+--R       x
+--R   + 
+--R         429  8 6        7 2 5         6 4 4         5 6 3   6435  4 8 2
+--R         --- a c  - 5148a b c  + 15015a b c  - 12012a b c  + ---- a b c
+--R          2                                                    2
+--R       + 
+--R               3 10    13  2 12
+--R         - 286a b  c + -- a b
+--R                        2
+--R    *
+--R        12
+--R       x
+--R   + 
+--R             8   5        7 3 4         6 5 3        5 7 2       4 9       3 11
+--R       (1287a b c  - 8580a b c  + 12012a b c  - 5148a b c  + 715a b c - 26a b  )
+--R    *
+--R        11
+--R       x
+--R   + 
+--R                 9 5   6435  8 2 4        7 4 3        6 6 2        5 8
+--R           - 143a c  + ---- a b c  - 8580a b c  + 6006a b c  - 1287a b c
+--R                         2
+--R         + 
+--R           143  4 10
+--R           --- a b
+--R            2
+--R    *
+--R        10
+--R       x
+--R   + 
+--R            9   4        8 3 3        7 5 2        6 7        5 9  9
+--R     (- 715a b c  + 4290a b c  - 5148a b c  + 1716a b c - 143a b )x
+--R   + 
+--R      143  10 4        9 2 3   6435  8 4 2        7 6    429  6 8  8
+--R     (--- a  c  - 1430a b c  + ---- a b c  - 1716a b c + --- a b )x
+--R       2                         2                        2
+--R   + 
+--R          10   3        9 3 2        8 5    1716  7 7  7
+--R     (286a  b c  - 1430a b c  + 1287a b c - ---- a b )x
+--R                                              7
+--R   + 
+--R           11 3       10 2 2       9 4    429  8 6  6
+--R     (- 26a  c  + 429a  b c  - 715a b c + --- a b )x
+--R                                           2
+--R   + 
+--R           11   2       10 3        9 5  5    13  12 2      11 2    143  10 4  4
+--R     (- 78a  b c  + 286a  b c - 143a b )x  + (-- a  c  - 78a  b c + --- a  b )x
+--R                                               2                     2
+--R   + 
+--R         12         11 3  3       13    13  12 2  2    13       1  14
+--R     (13a  b c - 26a  b )x  + (- a  c + -- a  b )x  - a  b x + -- a
+--R                                         2                     14
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 404
+
+--S 405 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 28      13 27         13   13  2 12  26             12      3 11  25
+--R     -- c  x   + b c  x   + (- a c   + -- b c  )x   + (- 13a b c   + 26b c  )x
+--R     14                                 2
+--R   + 
+--R      13  2 12        2 11   143  4 10  24
+--R     (-- a c   - 78a b c   + --- b c  )x
+--R       2                      2
+--R   + 
+--R         2   11         3 10       5 9  23
+--R     (78a b c   - 286a b c   + 143b c )x
+--R   + 
+--R           3 11       2 2 10         4 9   429  6 8  22
+--R     (- 26a c   + 429a b c   - 715a b c  + --- b c )x
+--R                                            2
+--R   + 
+--R            3   10        2 3 9          5 8   1716  7 7  21
+--R     (- 286a b c   + 1430a b c  - 1287a b c  + ---- b c )x
+--R                                                 7
+--R   + 
+--R      143  4 10        3 2 9   6435  2 4 8          6 7   429  8 6  20
+--R     (--- a c   - 1430a b c  + ---- a b c  - 1716a b c  + --- b c )x
+--R       2                         2                         2
+--R   + 
+--R          4   9        3 3 8        2 5 7          7 6       9 5  19
+--R     (715a b c  - 4290a b c  + 5148a b c  - 1716a b c  + 143b c )x
+--R   + 
+--R               5 9   6435  4 2 8        3 4 7        2 6 6          8 5
+--R         - 143a c  + ---- a b c  - 8580a b c  + 6006a b c  - 1287a b c
+--R                       2
+--R       + 
+--R         143  10 4
+--R         --- b  c
+--R          2
+--R    *
+--R        18
+--R       x
+--R   + 
+--R                5   8        4 3 7         3 5 6        2 7 5         9 4
+--R         - 1287a b c  + 8580a b c  - 12012a b c  + 5148a b c  - 715a b c
+--R       + 
+--R            11 3
+--R         26b  c
+--R    *
+--R        17
+--R       x
+--R   + 
+--R         429  6 8        5 2 7         4 4 6         3 6 5   6435  2 8 4
+--R         --- a c  - 5148a b c  + 15015a b c  - 12012a b c  + ---- a b c
+--R          2                                                    2
+--R       + 
+--R                 10 3   13  12 2
+--R         - 286a b  c  + -- b  c
+--R                         2
+--R    *
+--R        16
+--R       x
+--R   + 
+--R              6   7         5 3 6         4 5 5        3 7 4        2 9 3
+--R         1716a b c  - 12012a b c  + 18018a b c  - 8580a b c  + 1430a b c
+--R       + 
+--R                11 2    13
+--R         - 78a b  c  + b  c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R           1716  7 7        6 2 6         5 4 5         4 6 4        3 8 3
+--R         - ---- a c  + 6006a b c  - 18018a b c  + 15015a b c  - 4290a b c
+--R             7
+--R       + 
+--R             2 10 2        12     1  14
+--R         429a b  c  - 13a b  c + -- b
+--R                                 14
+--R    *
+--R        14
+--R       x
+--R   + 
+--R                7   6         6 3 5         5 5 4        4 7 3        3 9 2
+--R         - 1716a b c  + 12012a b c  - 18018a b c  + 8580a b c  - 1430a b c
+--R       + 
+--R            2 11       13
+--R         78a b  c - a b
+--R    *
+--R        13
+--R       x
+--R   + 
+--R         429  8 6        7 2 5         6 4 4         5 6 3   6435  4 8 2
+--R         --- a c  - 5148a b c  + 15015a b c  - 12012a b c  + ---- a b c
+--R          2                                                    2
+--R       + 
+--R               3 10    13  2 12
+--R         - 286a b  c + -- a b
+--R                        2
+--R    *
+--R        12
+--R       x
+--R   + 
+--R             8   5        7 3 4         6 5 3        5 7 2       4 9       3 11
+--R       (1287a b c  - 8580a b c  + 12012a b c  - 5148a b c  + 715a b c - 26a b  )
+--R    *
+--R        11
+--R       x
+--R   + 
+--R                 9 5   6435  8 2 4        7 4 3        6 6 2        5 8
+--R           - 143a c  + ---- a b c  - 8580a b c  + 6006a b c  - 1287a b c
+--R                         2
+--R         + 
+--R           143  4 10
+--R           --- a b
+--R            2
+--R    *
+--R        10
+--R       x
+--R   + 
+--R            9   4        8 3 3        7 5 2        6 7        5 9  9
+--R     (- 715a b c  + 4290a b c  - 5148a b c  + 1716a b c - 143a b )x
+--R   + 
+--R      143  10 4        9 2 3   6435  8 4 2        7 6    429  6 8  8
+--R     (--- a  c  - 1430a b c  + ---- a b c  - 1716a b c + --- a b )x
+--R       2                         2                        2
+--R   + 
+--R          10   3        9 3 2        8 5    1716  7 7  7
+--R     (286a  b c  - 1430a b c  + 1287a b c - ---- a b )x
+--R                                              7
+--R   + 
+--R           11 3       10 2 2       9 4    429  8 6  6
+--R     (- 26a  c  + 429a  b c  - 715a b c + --- a b )x
+--R                                           2
+--R   + 
+--R           11   2       10 3        9 5  5    13  12 2      11 2    143  10 4  4
+--R     (- 78a  b c  + 286a  b c - 143a b )x  + (-- a  c  - 78a  b c + --- a  b )x
+--R                                               2                     2
+--R   + 
+--R         12         11 3  3       13    13  12 2  2    13
+--R     (13a  b c - 26a  b )x  + (- a  c + -- a  b )x  - a  b x
+--R                                         2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 405
+
+--S 406 of 649
+m0:=a0-r0
+--R 
+--R
+--R           1  14
+--R   (4)  - -- a
+--R          14
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 406
+
+--S 407 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 407
+
+)clear all
+
+--S 408 of 649
+t0:=x*(b+2*c*x^2)*(-a+b*x^2+c*x^4)^13
+--R 
+--R
+--R   (1)
+--R       14 55        13 53           13       2 12  51
+--R     2c  x   + 27b c  x   + (- 26a c   + 169b c  )x
+--R   + 
+--R                12       3 11  49        2 12          2 11        4 10  47
+--R     (- 325a b c   + 650b c  )x   + (156a c   - 1872a b c   + 1716b c  )x
+--R   + 
+--R           2   11          3 10        5 9  45
+--R     (1794a b c   - 6578a b c   + 3289b c )x
+--R   + 
+--R            3 11        2 2 10           4 9        6 8  43
+--R     (- 572a c   + 9438a b c   - 15730a b c  + 4719b c )x
+--R   + 
+--R             3   10         2 3 9           5 8        7 7  41
+--R     (- 6006a b c   + 30030a b c  - 27027a b c  + 5148b c )x
+--R   + 
+--R           4 10         3 2 9         2 4 8           6 7        8 6  39
+--R     (1430a c   - 28600a b c  + 64350a b c  - 34320a b c  + 4290b c )x
+--R   + 
+--R            4   9         3 3 8         2 5 7           7 6        9 5  37
+--R     (13585a b c  - 81510a b c  + 97812a b c  - 32604a b c  + 2717b c )x
+--R   + 
+--R                5 9         4 2 8          3 4 7          2 6 6           8 5
+--R         - 2574a c  + 57915a b c  - 154440a b c  + 108108a b c  - 23166a b c
+--R       + 
+--R              10 4
+--R         1287b  c
+--R    *
+--R        35
+--R       x
+--R   + 
+--R                 5   8          4 3 7          3 5 6         2 7 5           9 4
+--R         - 21879a b c  + 145860a b c  - 204204a b c  + 87516a b c  - 12155a b c
+--R       + 
+--R             11 3
+--R         442b  c
+--R    *
+--R        33
+--R       x
+--R   + 
+--R              6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R         3432a c  - 82368a b c  + 240240a b c  - 192192a b c  + 51480a b c
+--R       + 
+--R                  10 3       12 2
+--R         - 4576a b  c  + 104b  c
+--R    *
+--R        31
+--R       x
+--R   + 
+--R               6   7          5 3 6          4 5 5          3 7 4         2 9 3
+--R         25740a b c  - 180180a b c  + 270270a b c  - 128700a b c  + 21450a b c
+--R       + 
+--R                  11 2      13
+--R         - 1170a b  c  + 15b  c
+--R    *
+--R        29
+--R       x
+--R   + 
+--R                7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R         - 3432a c  + 84084a b c  - 252252a b c  + 210210a b c  - 60060a b c
+--R       + 
+--R              2 10 2         12     14
+--R         6006a b  c  - 182a b  c + b
+--R    *
+--R        27
+--R       x
+--R   + 
+--R                 7   6          6 3 5          5 5 4          4 7 3
+--R         - 22308a b c  + 156156a b c  - 234234a b c  + 111540a b c
+--R       + 
+--R                 3 9 2        2 11         13
+--R         - 18590a b c  + 1014a b  c - 13a b
+--R    *
+--R        25
+--R       x
+--R   + 
+--R              8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R         2574a c  - 61776a b c  + 180180a b c  - 144144a b c  + 38610a b c
+--R       + 
+--R                3 10       2 12
+--R         - 3432a b  c + 78a b
+--R    *
+--R        23
+--R       x
+--R   + 
+--R               8   5         7 3 4          6 5 3         5 7 2        4 9
+--R         14157a b c  - 94380a b c  + 132132a b c  - 56628a b c  + 7865a b c
+--R       + 
+--R               3 11
+--R         - 286a b
+--R    *
+--R        21
+--R       x
+--R   + 
+--R                9 5         8 2 4         7 4 3         6 6 2         5 8
+--R         - 1430a c  + 32175a b c  - 85800a b c  + 60060a b c  - 12870a b c
+--R       + 
+--R             4 10
+--R         715a b
+--R    *
+--R        19
+--R       x
+--R   + 
+--R             9   4         8 3 3         7 5 2         6 7         5 9  17
+--R     (- 6435a b c  + 38610a b c  - 46332a b c  + 15444a b c - 1287a b )x
+--R   + 
+--R          10 4         9 2 3         8 4 2         7 6         6 8  15
+--R     (572a  c  - 11440a b c  + 25740a b c  - 13728a b c + 1716a b )x
+--R   + 
+--R           10   3         9 3 2        8 5         7 7  13
+--R     (2002a  b c  - 10010a b c  + 9009a b c - 1716a b )x
+--R   + 
+--R            11 3        10 2 2        9 4         8 6  11
+--R     (- 156a  c  + 2574a  b c  - 4290a b c + 1287a b )x
+--R   + 
+--R            11   2        10 3        9 5  9
+--R     (- 390a  b c  + 1430a  b c - 715a b )x
+--R   + 
+--R         12 2       11 2        10 4  7       12         11 3  5
+--R     (26a  c  - 312a  b c + 286a  b )x  + (39a  b c - 78a  b )x
+--R   + 
+--R          13       12 2  3    13
+--R     (- 2a  c + 13a  b )x  - a  b x
+--R                                                    Type: Polynomial(Integer)
+--E 408
+
+--S 409 of 649
+r0:=1/28*(a-b*x^2-c*x^4)^14
+--R 
+--R
+--R   (2)
+--R      1  14 56   1    13 54      1    13   13  2 12  52
+--R     -- c  x   + - b c  x   + (- - a c   + -- b c  )x
+--R     28          2               2          4
+--R   + 
+--R        13      12      3 11  50    13  2 12        2 11   143  4 10  48
+--R     (- -- a b c   + 13b c  )x   + (-- a c   - 39a b c   + --- b c  )x
+--R         2                           4                      4
+--R   + 
+--R         2   11         3 10   143  5 9  46
+--R     (39a b c   - 143a b c   + --- b c )x
+--R                                2
+--R   + 
+--R           3 11   429  2 2 10   715    4 9   429  6 8  44
+--R     (- 13a c   + --- a b c   - --- a b c  + --- b c )x
+--R                   2             2            4
+--R   + 
+--R            3   10       2 3 9   1287    5 8   858  7 7  42
+--R     (- 143a b c   + 715a b c  - ---- a b c  + --- b c )x
+--R                                   2            7
+--R   + 
+--R      143  4 10       3 2 9   6435  2 4 8         6 7   429  8 6  40
+--R     (--- a c   - 715a b c  + ---- a b c  - 858a b c  + --- b c )x
+--R       4                        4                        4
+--R   + 
+--R      715  4   9        3 3 8        2 5 7         7 6   143  9 5  38
+--R     (--- a b c  - 2145a b c  + 2574a b c  - 858a b c  + --- b c )x
+--R       2                                                  2
+--R   + 
+--R           143  5 9   6435  4 2 8        3 4 7        2 6 6   1287    8 5
+--R         - --- a c  + ---- a b c  - 4290a b c  + 3003a b c  - ---- a b c
+--R            2           4                                       2
+--R       + 
+--R         143  10 4
+--R         --- b  c
+--R          4
+--R    *
+--R        36
+--R       x
+--R   + 
+--R           1287  5   8        4 3 7        3 5 6        2 7 5   715    9 4
+--R         - ---- a b c  + 4290a b c  - 6006a b c  + 2574a b c  - --- a b c
+--R             2                                                   2
+--R       + 
+--R            11 3
+--R         13b  c
+--R    *
+--R        34
+--R       x
+--R   + 
+--R         429  6 8        5 2 7   15015  4 4 6        3 6 5   6435  2 8 4
+--R         --- a c  - 2574a b c  + ----- a b c  - 6006a b c  + ---- a b c
+--R          4                        2                           4
+--R       + 
+--R                 10 3   13  12 2
+--R         - 143a b  c  + -- b  c
+--R                         4
+--R    *
+--R        32
+--R       x
+--R   + 
+--R             6   7        5 3 6        4 5 5        3 7 4       2 9 3
+--R         858a b c  - 6006a b c  + 9009a b c  - 4290a b c  + 715a b c
+--R       + 
+--R                11 2   1  13
+--R         - 39a b  c  + - b  c
+--R                       2
+--R    *
+--R        30
+--R       x
+--R   + 
+--R           858  7 7        6 2 6        5 4 5   15015  4 6 4        3 8 3
+--R         - --- a c  + 3003a b c  - 9009a b c  + ----- a b c  - 2145a b c
+--R            7                                     2
+--R       + 
+--R         429  2 10 2   13    12     1  14
+--R         --- a b  c  - -- a b  c + -- b
+--R          2             2          28
+--R    *
+--R        28
+--R       x
+--R   + 
+--R               7   6        6 3 5        5 5 4        4 7 3       3 9 2
+--R         - 858a b c  + 6006a b c  - 9009a b c  + 4290a b c  - 715a b c
+--R       + 
+--R            2 11    1    13
+--R         39a b  c - - a b
+--R                    2
+--R    *
+--R        26
+--R       x
+--R   + 
+--R         429  8 6        7 2 5   15015  6 4 4        5 6 3   6435  4 8 2
+--R         --- a c  - 2574a b c  + ----- a b c  - 6006a b c  + ---- a b c
+--R          4                        2                           4
+--R       + 
+--R               3 10    13  2 12
+--R         - 143a b  c + -- a b
+--R                        4
+--R    *
+--R        24
+--R       x
+--R   + 
+--R           1287  8   5        7 3 4        6 5 3        5 7 2   715  4 9
+--R           ---- a b c  - 4290a b c  + 6006a b c  - 2574a b c  + --- a b c
+--R             2                                                   2
+--R         + 
+--R                3 11
+--R           - 13a b
+--R    *
+--R        22
+--R       x
+--R   + 
+--R           143  9 5   6435  8 2 4        7 4 3        6 6 2   1287  5 8
+--R         - --- a c  + ---- a b c  - 4290a b c  + 3003a b c  - ---- a b c
+--R            2           4                                       2
+--R       + 
+--R         143  4 10
+--R         --- a b
+--R          4
+--R    *
+--R        20
+--R       x
+--R   + 
+--R        715  9   4        8 3 3        7 5 2       6 7    143  5 9  18
+--R     (- --- a b c  + 2145a b c  - 2574a b c  + 858a b c - --- a b )x
+--R         2                                                 2
+--R   + 
+--R      143  10 4       9 2 3   6435  8 4 2       7 6    429  6 8  16
+--R     (--- a  c  - 715a b c  + ---- a b c  - 858a b c + --- a b )x
+--R       4                        4                       4
+--R   + 
+--R          10   3       9 3 2   1287  8 5    858  7 7  14
+--R     (143a  b c  - 715a b c  + ---- a b c - --- a b )x
+--R                                 2           7
+--R   + 
+--R           11 3   429  10 2 2   715  9 4    429  8 6  12
+--R     (- 13a  c  + --- a  b c  - --- a b c + --- a b )x
+--R                   2             2           4
+--R   + 
+--R           11   2       10 3    143  9 5  10
+--R     (- 39a  b c  + 143a  b c - --- a b )x
+--R                                 2
+--R   + 
+--R      13  12 2      11 2    143  10 4  8    13  12         11 3  6
+--R     (-- a  c  - 39a  b c + --- a  b )x  + (-- a  b c - 13a  b )x
+--R       4                     4               2
+--R   + 
+--R        1  13    13  12 2  4   1  13   2    1  14
+--R     (- - a  c + -- a  b )x  - - a  b x  + -- a
+--R        2         4            2           28
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 409
+
+--S 410 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 56   1    13 54      1    13   13  2 12  52
+--R     -- c  x   + - b c  x   + (- - a c   + -- b c  )x
+--R     28          2               2          4
+--R   + 
+--R        13      12      3 11  50    13  2 12        2 11   143  4 10  48
+--R     (- -- a b c   + 13b c  )x   + (-- a c   - 39a b c   + --- b c  )x
+--R         2                           4                      4
+--R   + 
+--R         2   11         3 10   143  5 9  46
+--R     (39a b c   - 143a b c   + --- b c )x
+--R                                2
+--R   + 
+--R           3 11   429  2 2 10   715    4 9   429  6 8  44
+--R     (- 13a c   + --- a b c   - --- a b c  + --- b c )x
+--R                   2             2            4
+--R   + 
+--R            3   10       2 3 9   1287    5 8   858  7 7  42
+--R     (- 143a b c   + 715a b c  - ---- a b c  + --- b c )x
+--R                                   2            7
+--R   + 
+--R      143  4 10       3 2 9   6435  2 4 8         6 7   429  8 6  40
+--R     (--- a c   - 715a b c  + ---- a b c  - 858a b c  + --- b c )x
+--R       4                        4                        4
+--R   + 
+--R      715  4   9        3 3 8        2 5 7         7 6   143  9 5  38
+--R     (--- a b c  - 2145a b c  + 2574a b c  - 858a b c  + --- b c )x
+--R       2                                                  2
+--R   + 
+--R           143  5 9   6435  4 2 8        3 4 7        2 6 6   1287    8 5
+--R         - --- a c  + ---- a b c  - 4290a b c  + 3003a b c  - ---- a b c
+--R            2           4                                       2
+--R       + 
+--R         143  10 4
+--R         --- b  c
+--R          4
+--R    *
+--R        36
+--R       x
+--R   + 
+--R           1287  5   8        4 3 7        3 5 6        2 7 5   715    9 4
+--R         - ---- a b c  + 4290a b c  - 6006a b c  + 2574a b c  - --- a b c
+--R             2                                                   2
+--R       + 
+--R            11 3
+--R         13b  c
+--R    *
+--R        34
+--R       x
+--R   + 
+--R         429  6 8        5 2 7   15015  4 4 6        3 6 5   6435  2 8 4
+--R         --- a c  - 2574a b c  + ----- a b c  - 6006a b c  + ---- a b c
+--R          4                        2                           4
+--R       + 
+--R                 10 3   13  12 2
+--R         - 143a b  c  + -- b  c
+--R                         4
+--R    *
+--R        32
+--R       x
+--R   + 
+--R             6   7        5 3 6        4 5 5        3 7 4       2 9 3
+--R         858a b c  - 6006a b c  + 9009a b c  - 4290a b c  + 715a b c
+--R       + 
+--R                11 2   1  13
+--R         - 39a b  c  + - b  c
+--R                       2
+--R    *
+--R        30
+--R       x
+--R   + 
+--R           858  7 7        6 2 6        5 4 5   15015  4 6 4        3 8 3
+--R         - --- a c  + 3003a b c  - 9009a b c  + ----- a b c  - 2145a b c
+--R            7                                     2
+--R       + 
+--R         429  2 10 2   13    12     1  14
+--R         --- a b  c  - -- a b  c + -- b
+--R          2             2          28
+--R    *
+--R        28
+--R       x
+--R   + 
+--R               7   6        6 3 5        5 5 4        4 7 3       3 9 2
+--R         - 858a b c  + 6006a b c  - 9009a b c  + 4290a b c  - 715a b c
+--R       + 
+--R            2 11    1    13
+--R         39a b  c - - a b
+--R                    2
+--R    *
+--R        26
+--R       x
+--R   + 
+--R         429  8 6        7 2 5   15015  6 4 4        5 6 3   6435  4 8 2
+--R         --- a c  - 2574a b c  + ----- a b c  - 6006a b c  + ---- a b c
+--R          4                        2                           4
+--R       + 
+--R               3 10    13  2 12
+--R         - 143a b  c + -- a b
+--R                        4
+--R    *
+--R        24
+--R       x
+--R   + 
+--R           1287  8   5        7 3 4        6 5 3        5 7 2   715  4 9
+--R           ---- a b c  - 4290a b c  + 6006a b c  - 2574a b c  + --- a b c
+--R             2                                                   2
+--R         + 
+--R                3 11
+--R           - 13a b
+--R    *
+--R        22
+--R       x
+--R   + 
+--R           143  9 5   6435  8 2 4        7 4 3        6 6 2   1287  5 8
+--R         - --- a c  + ---- a b c  - 4290a b c  + 3003a b c  - ---- a b c
+--R            2           4                                       2
+--R       + 
+--R         143  4 10
+--R         --- a b
+--R          4
+--R    *
+--R        20
+--R       x
+--R   + 
+--R        715  9   4        8 3 3        7 5 2       6 7    143  5 9  18
+--R     (- --- a b c  + 2145a b c  - 2574a b c  + 858a b c - --- a b )x
+--R         2                                                 2
+--R   + 
+--R      143  10 4       9 2 3   6435  8 4 2       7 6    429  6 8  16
+--R     (--- a  c  - 715a b c  + ---- a b c  - 858a b c + --- a b )x
+--R       4                        4                       4
+--R   + 
+--R          10   3       9 3 2   1287  8 5    858  7 7  14
+--R     (143a  b c  - 715a b c  + ---- a b c - --- a b )x
+--R                                 2           7
+--R   + 
+--R           11 3   429  10 2 2   715  9 4    429  8 6  12
+--R     (- 13a  c  + --- a  b c  - --- a b c + --- a b )x
+--R                   2             2           4
+--R   + 
+--R           11   2       10 3    143  9 5  10
+--R     (- 39a  b c  + 143a  b c - --- a b )x
+--R                                 2
+--R   + 
+--R      13  12 2      11 2    143  10 4  8    13  12         11 3  6
+--R     (-- a  c  - 39a  b c + --- a  b )x  + (-- a  b c - 13a  b )x
+--R       4                     4               2
+--R   + 
+--R        1  13    13  12 2  4   1  13   2
+--R     (- - a  c + -- a  b )x  - - a  b x
+--R        2         4            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 410
+
+--S 411 of 649
+m0:=a0-r0
+--R 
+--R
+--R           1  14
+--R   (4)  - -- a
+--R          28
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 411
+
+--S 412 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 412
+
+)clear all
+
+--S 413 of 649
+t0:=x^2*(b+2*c*x^3)*(-a+b*x^3+c*x^6)^13
+--R 
+--R
+--R   (1)
+--R       14 83        13 80           13       2 12  77
+--R     2c  x   + 27b c  x   + (- 26a c   + 169b c  )x
+--R   + 
+--R                12       3 11  74        2 12          2 11        4 10  71
+--R     (- 325a b c   + 650b c  )x   + (156a c   - 1872a b c   + 1716b c  )x
+--R   + 
+--R           2   11          3 10        5 9  68
+--R     (1794a b c   - 6578a b c   + 3289b c )x
+--R   + 
+--R            3 11        2 2 10           4 9        6 8  65
+--R     (- 572a c   + 9438a b c   - 15730a b c  + 4719b c )x
+--R   + 
+--R             3   10         2 3 9           5 8        7 7  62
+--R     (- 6006a b c   + 30030a b c  - 27027a b c  + 5148b c )x
+--R   + 
+--R           4 10         3 2 9         2 4 8           6 7        8 6  59
+--R     (1430a c   - 28600a b c  + 64350a b c  - 34320a b c  + 4290b c )x
+--R   + 
+--R            4   9         3 3 8         2 5 7           7 6        9 5  56
+--R     (13585a b c  - 81510a b c  + 97812a b c  - 32604a b c  + 2717b c )x
+--R   + 
+--R                5 9         4 2 8          3 4 7          2 6 6           8 5
+--R         - 2574a c  + 57915a b c  - 154440a b c  + 108108a b c  - 23166a b c
+--R       + 
+--R              10 4
+--R         1287b  c
+--R    *
+--R        53
+--R       x
+--R   + 
+--R                 5   8          4 3 7          3 5 6         2 7 5           9 4
+--R         - 21879a b c  + 145860a b c  - 204204a b c  + 87516a b c  - 12155a b c
+--R       + 
+--R             11 3
+--R         442b  c
+--R    *
+--R        50
+--R       x
+--R   + 
+--R              6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R         3432a c  - 82368a b c  + 240240a b c  - 192192a b c  + 51480a b c
+--R       + 
+--R                  10 3       12 2
+--R         - 4576a b  c  + 104b  c
+--R    *
+--R        47
+--R       x
+--R   + 
+--R               6   7          5 3 6          4 5 5          3 7 4         2 9 3
+--R         25740a b c  - 180180a b c  + 270270a b c  - 128700a b c  + 21450a b c
+--R       + 
+--R                  11 2      13
+--R         - 1170a b  c  + 15b  c
+--R    *
+--R        44
+--R       x
+--R   + 
+--R                7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R         - 3432a c  + 84084a b c  - 252252a b c  + 210210a b c  - 60060a b c
+--R       + 
+--R              2 10 2         12     14
+--R         6006a b  c  - 182a b  c + b
+--R    *
+--R        41
+--R       x
+--R   + 
+--R                 7   6          6 3 5          5 5 4          4 7 3
+--R         - 22308a b c  + 156156a b c  - 234234a b c  + 111540a b c
+--R       + 
+--R                 3 9 2        2 11         13
+--R         - 18590a b c  + 1014a b  c - 13a b
+--R    *
+--R        38
+--R       x
+--R   + 
+--R              8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R         2574a c  - 61776a b c  + 180180a b c  - 144144a b c  + 38610a b c
+--R       + 
+--R                3 10       2 12
+--R         - 3432a b  c + 78a b
+--R    *
+--R        35
+--R       x
+--R   + 
+--R               8   5         7 3 4          6 5 3         5 7 2        4 9
+--R         14157a b c  - 94380a b c  + 132132a b c  - 56628a b c  + 7865a b c
+--R       + 
+--R               3 11
+--R         - 286a b
+--R    *
+--R        32
+--R       x
+--R   + 
+--R                9 5         8 2 4         7 4 3         6 6 2         5 8
+--R         - 1430a c  + 32175a b c  - 85800a b c  + 60060a b c  - 12870a b c
+--R       + 
+--R             4 10
+--R         715a b
+--R    *
+--R        29
+--R       x
+--R   + 
+--R             9   4         8 3 3         7 5 2         6 7         5 9  26
+--R     (- 6435a b c  + 38610a b c  - 46332a b c  + 15444a b c - 1287a b )x
+--R   + 
+--R          10 4         9 2 3         8 4 2         7 6         6 8  23
+--R     (572a  c  - 11440a b c  + 25740a b c  - 13728a b c + 1716a b )x
+--R   + 
+--R           10   3         9 3 2        8 5         7 7  20
+--R     (2002a  b c  - 10010a b c  + 9009a b c - 1716a b )x
+--R   + 
+--R            11 3        10 2 2        9 4         8 6  17
+--R     (- 156a  c  + 2574a  b c  - 4290a b c + 1287a b )x
+--R   + 
+--R            11   2        10 3        9 5  14
+--R     (- 390a  b c  + 1430a  b c - 715a b )x
+--R   + 
+--R         12 2       11 2        10 4  11       12         11 3  8
+--R     (26a  c  - 312a  b c + 286a  b )x   + (39a  b c - 78a  b )x
+--R   + 
+--R          13       12 2  5    13   2
+--R     (- 2a  c + 13a  b )x  - a  b x
+--R                                                    Type: Polynomial(Integer)
+--E 413
+
+--S 414 of 649
+r0:=1/42*(a-b*x^3-c*x^6)^14
+--R 
+--R
+--R   (2)
+--R      1  14 84   1    13 81      1    13   13  2 12  78
+--R     -- c  x   + - b c  x   + (- - a c   + -- b c  )x
+--R     42          3               3          6
+--R   + 
+--R        13      12   26  3 11  75    13  2 12        2 11   143  4 10  72
+--R     (- -- a b c   + -- b c  )x   + (-- a c   - 26a b c   + --- b c  )x
+--R         3            3               6                      6
+--R   + 
+--R         2   11   286    3 10   143  5 9  69
+--R     (26a b c   - --- a b c   + --- b c )x
+--R                   3             3
+--R   + 
+--R        26  3 11       2 2 10   715    4 9   143  6 8  66
+--R     (- -- a c   + 143a b c   - --- a b c  + --- b c )x
+--R         3                       3            2
+--R   + 
+--R        286  3   10   1430  2 3 9         5 8   572  7 7  63
+--R     (- --- a b c   + ---- a b c  - 429a b c  + --- b c )x
+--R         3              3                        7
+--R   + 
+--R      143  4 10   1430  3 2 9   2145  2 4 8         6 7   143  8 6  60
+--R     (--- a c   - ---- a b c  + ---- a b c  - 572a b c  + --- b c )x
+--R       6            3             2                        2
+--R   + 
+--R      715  4   9        3 3 8        2 5 7         7 6   143  9 5  57
+--R     (--- a b c  - 1430a b c  + 1716a b c  - 572a b c  + --- b c )x
+--R       3                                                  3
+--R   + 
+--R           143  5 9   2145  4 2 8        3 4 7        2 6 6         8 5
+--R         - --- a c  + ---- a b c  - 2860a b c  + 2002a b c  - 429a b c
+--R            3           2
+--R       + 
+--R         143  10 4
+--R         --- b  c
+--R          6
+--R    *
+--R        54
+--R       x
+--R   + 
+--R               5   8        4 3 7        3 5 6        2 7 5   715    9 4
+--R         - 429a b c  + 2860a b c  - 4004a b c  + 1716a b c  - --- a b c
+--R                                                               3
+--R       + 
+--R         26  11 3
+--R         -- b  c
+--R          3
+--R    *
+--R        51
+--R       x
+--R   + 
+--R         143  6 8        5 2 7        4 4 6        3 6 5   2145  2 8 4
+--R         --- a c  - 1716a b c  + 5005a b c  - 4004a b c  + ---- a b c
+--R          2                                                  2
+--R       + 
+--R           286    10 3   13  12 2
+--R         - --- a b  c  + -- b  c
+--R            3             6
+--R    *
+--R        48
+--R       x
+--R   + 
+--R             6   7        5 3 6        4 5 5        3 7 4   1430  2 9 3
+--R         572a b c  - 4004a b c  + 6006a b c  - 2860a b c  + ---- a b c
+--R                                                              3
+--R       + 
+--R                11 2   1  13
+--R         - 26a b  c  + - b  c
+--R                       3
+--R    *
+--R        45
+--R       x
+--R   + 
+--R           572  7 7        6 2 6        5 4 5        4 6 4        3 8 3
+--R         - --- a c  + 2002a b c  - 6006a b c  + 5005a b c  - 1430a b c
+--R            7
+--R       + 
+--R             2 10 2   13    12     1  14
+--R         143a b  c  - -- a b  c + -- b
+--R                       3          42
+--R    *
+--R        42
+--R       x
+--R   + 
+--R               7   6        6 3 5        5 5 4        4 7 3   1430  3 9 2
+--R         - 572a b c  + 4004a b c  - 6006a b c  + 2860a b c  - ---- a b c
+--R                                                                3
+--R       + 
+--R            2 11    1    13
+--R         26a b  c - - a b
+--R                    3
+--R    *
+--R        39
+--R       x
+--R   + 
+--R         143  8 6        7 2 5        6 4 4        5 6 3   2145  4 8 2
+--R         --- a c  - 1716a b c  + 5005a b c  - 4004a b c  + ---- a b c
+--R          2                                                  2
+--R       + 
+--R           286  3 10    13  2 12
+--R         - --- a b  c + -- a b
+--R            3            6
+--R    *
+--R        36
+--R       x
+--R   + 
+--R            8   5        7 3 4        6 5 3        5 7 2   715  4 9    26  3 11
+--R       (429a b c  - 2860a b c  + 4004a b c  - 1716a b c  + --- a b c - -- a b  )
+--R                                                            3           3
+--R    *
+--R        33
+--R       x
+--R   + 
+--R             143  9 5   2145  8 2 4        7 4 3        6 6 2       5 8
+--R           - --- a c  + ---- a b c  - 2860a b c  + 2002a b c  - 429a b c
+--R              3           2
+--R         + 
+--R           143  4 10
+--R           --- a b
+--R            6
+--R    *
+--R        30
+--R       x
+--R   + 
+--R        715  9   4        8 3 3        7 5 2       6 7    143  5 9  27
+--R     (- --- a b c  + 1430a b c  - 1716a b c  + 572a b c - --- a b )x
+--R         3                                                 3
+--R   + 
+--R      143  10 4   1430  9 2 3   2145  8 4 2       7 6    143  6 8  24
+--R     (--- a  c  - ---- a b c  + ---- a b c  - 572a b c + --- a b )x
+--R       6            3             2                       2
+--R   + 
+--R      286  10   3   1430  9 3 2       8 5    572  7 7  21
+--R     (--- a  b c  - ---- a b c  + 429a b c - --- a b )x
+--R       3              3                       7
+--R   + 
+--R        26  11 3       10 2 2   715  9 4    143  8 6  18
+--R     (- -- a  c  + 143a  b c  - --- a b c + --- a b )x
+--R         3                       3           2
+--R   + 
+--R           11   2   286  10 3    143  9 5  15
+--R     (- 26a  b c  + --- a  b c - --- a b )x
+--R                     3            3
+--R   + 
+--R      13  12 2      11 2    143  10 4  12    13  12      26  11 3  9
+--R     (-- a  c  - 26a  b c + --- a  b )x   + (-- a  b c - -- a  b )x
+--R       6                     6                3           3
+--R   + 
+--R        1  13    13  12 2  6   1  13   3    1  14
+--R     (- - a  c + -- a  b )x  - - a  b x  + -- a
+--R        3         6            3           42
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 414
+
+--S 415 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 84   1    13 81      1    13   13  2 12  78
+--R     -- c  x   + - b c  x   + (- - a c   + -- b c  )x
+--R     42          3               3          6
+--R   + 
+--R        13      12   26  3 11  75    13  2 12        2 11   143  4 10  72
+--R     (- -- a b c   + -- b c  )x   + (-- a c   - 26a b c   + --- b c  )x
+--R         3            3               6                      6
+--R   + 
+--R         2   11   286    3 10   143  5 9  69
+--R     (26a b c   - --- a b c   + --- b c )x
+--R                   3             3
+--R   + 
+--R        26  3 11       2 2 10   715    4 9   143  6 8  66
+--R     (- -- a c   + 143a b c   - --- a b c  + --- b c )x
+--R         3                       3            2
+--R   + 
+--R        286  3   10   1430  2 3 9         5 8   572  7 7  63
+--R     (- --- a b c   + ---- a b c  - 429a b c  + --- b c )x
+--R         3              3                        7
+--R   + 
+--R      143  4 10   1430  3 2 9   2145  2 4 8         6 7   143  8 6  60
+--R     (--- a c   - ---- a b c  + ---- a b c  - 572a b c  + --- b c )x
+--R       6            3             2                        2
+--R   + 
+--R      715  4   9        3 3 8        2 5 7         7 6   143  9 5  57
+--R     (--- a b c  - 1430a b c  + 1716a b c  - 572a b c  + --- b c )x
+--R       3                                                  3
+--R   + 
+--R           143  5 9   2145  4 2 8        3 4 7        2 6 6         8 5
+--R         - --- a c  + ---- a b c  - 2860a b c  + 2002a b c  - 429a b c
+--R            3           2
+--R       + 
+--R         143  10 4
+--R         --- b  c
+--R          6
+--R    *
+--R        54
+--R       x
+--R   + 
+--R               5   8        4 3 7        3 5 6        2 7 5   715    9 4
+--R         - 429a b c  + 2860a b c  - 4004a b c  + 1716a b c  - --- a b c
+--R                                                               3
+--R       + 
+--R         26  11 3
+--R         -- b  c
+--R          3
+--R    *
+--R        51
+--R       x
+--R   + 
+--R         143  6 8        5 2 7        4 4 6        3 6 5   2145  2 8 4
+--R         --- a c  - 1716a b c  + 5005a b c  - 4004a b c  + ---- a b c
+--R          2                                                  2
+--R       + 
+--R           286    10 3   13  12 2
+--R         - --- a b  c  + -- b  c
+--R            3             6
+--R    *
+--R        48
+--R       x
+--R   + 
+--R             6   7        5 3 6        4 5 5        3 7 4   1430  2 9 3
+--R         572a b c  - 4004a b c  + 6006a b c  - 2860a b c  + ---- a b c
+--R                                                              3
+--R       + 
+--R                11 2   1  13
+--R         - 26a b  c  + - b  c
+--R                       3
+--R    *
+--R        45
+--R       x
+--R   + 
+--R           572  7 7        6 2 6        5 4 5        4 6 4        3 8 3
+--R         - --- a c  + 2002a b c  - 6006a b c  + 5005a b c  - 1430a b c
+--R            7
+--R       + 
+--R             2 10 2   13    12     1  14
+--R         143a b  c  - -- a b  c + -- b
+--R                       3          42
+--R    *
+--R        42
+--R       x
+--R   + 
+--R               7   6        6 3 5        5 5 4        4 7 3   1430  3 9 2
+--R         - 572a b c  + 4004a b c  - 6006a b c  + 2860a b c  - ---- a b c
+--R                                                                3
+--R       + 
+--R            2 11    1    13
+--R         26a b  c - - a b
+--R                    3
+--R    *
+--R        39
+--R       x
+--R   + 
+--R         143  8 6        7 2 5        6 4 4        5 6 3   2145  4 8 2
+--R         --- a c  - 1716a b c  + 5005a b c  - 4004a b c  + ---- a b c
+--R          2                                                  2
+--R       + 
+--R           286  3 10    13  2 12
+--R         - --- a b  c + -- a b
+--R            3            6
+--R    *
+--R        36
+--R       x
+--R   + 
+--R            8   5        7 3 4        6 5 3        5 7 2   715  4 9    26  3 11
+--R       (429a b c  - 2860a b c  + 4004a b c  - 1716a b c  + --- a b c - -- a b  )
+--R                                                            3           3
+--R    *
+--R        33
+--R       x
+--R   + 
+--R             143  9 5   2145  8 2 4        7 4 3        6 6 2       5 8
+--R           - --- a c  + ---- a b c  - 2860a b c  + 2002a b c  - 429a b c
+--R              3           2
+--R         + 
+--R           143  4 10
+--R           --- a b
+--R            6
+--R    *
+--R        30
+--R       x
+--R   + 
+--R        715  9   4        8 3 3        7 5 2       6 7    143  5 9  27
+--R     (- --- a b c  + 1430a b c  - 1716a b c  + 572a b c - --- a b )x
+--R         3                                                 3
+--R   + 
+--R      143  10 4   1430  9 2 3   2145  8 4 2       7 6    143  6 8  24
+--R     (--- a  c  - ---- a b c  + ---- a b c  - 572a b c + --- a b )x
+--R       6            3             2                       2
+--R   + 
+--R      286  10   3   1430  9 3 2       8 5    572  7 7  21
+--R     (--- a  b c  - ---- a b c  + 429a b c - --- a b )x
+--R       3              3                       7
+--R   + 
+--R        26  11 3       10 2 2   715  9 4    143  8 6  18
+--R     (- -- a  c  + 143a  b c  - --- a b c + --- a b )x
+--R         3                       3           2
+--R   + 
+--R           11   2   286  10 3    143  9 5  15
+--R     (- 26a  b c  + --- a  b c - --- a b )x
+--R                     3            3
+--R   + 
+--R      13  12 2      11 2    143  10 4  12    13  12      26  11 3  9
+--R     (-- a  c  - 26a  b c + --- a  b )x   + (-- a  b c - -- a  b )x
+--R       6                     6                3           3
+--R   + 
+--R        1  13    13  12 2  6   1  13   3
+--R     (- - a  c + -- a  b )x  - - a  b x
+--R        3         6            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 415
+
+--S 416 of 649
+m0:=a0-r0
+--R 
+--R
+--R           1  14
+--R   (4)  - -- a
+--R          42
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 416
+
+--S 417 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 417
+
+)clear all
+
+--S 418 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)*(-a+b*x^n+c*x^(2*n))^13
+--R 
+--R
+--R   (1)
+--R        14 n - 1 n      13 n - 1   2n 13
+--R     (2c  x     x  + b c  x     )(x  )
+--R   + 
+--R             13 n - 1  n 2           13      2 12  n - 1 n          12 n - 1
+--R       (26b c  x     (x )  + (- 26a c   + 13b c  )x     x  - 13a b c  x     )
+--R    *
+--R         2n 12
+--R       (x  )
+--R   + 
+--R             2 12 n - 1  n 3              12      3 11  n - 1  n 2
+--R         156b c  x     (x )  + (- 312a b c   + 78b c  )x     (x )
+--R       + 
+--R              2 12         2 11  n - 1 n      2   11 n - 1
+--R         (156a c   - 156a b c  )x     x  + 78a b c  x
+--R    *
+--R         2n 11
+--R       (x  )
+--R   + 
+--R             3 11 n - 1  n 4             2 11       4 10  n - 1  n 3
+--R         572b c  x     (x )  + (- 1716a b c   + 286b c  )x     (x )
+--R       + 
+--R               2   11         3 10  n - 1  n 2
+--R         (1716a b c   - 858a b c  )x     (x )
+--R       + 
+--R                3 11       2 2 10  n - 1 n       3   10 n - 1
+--R         (- 572a c   + 858a b c  )x     x  - 286a b c  x
+--R    *
+--R         2n 10
+--R       (x  )
+--R   + 
+--R              4 10 n - 1  n 5             3 10       5 9  n - 1  n 4
+--R         1430b c  x     (x )  + (- 5720a b c   + 715b c )x     (x )
+--R       + 
+--R               2 2 10          4 9  n - 1  n 3
+--R         (8580a b c   - 2860a b c )x     (x )
+--R       + 
+--R                 3   10        2 3 9  n - 1  n 2
+--R         (- 5720a b c   + 4290a b c )x     (x )
+--R       + 
+--R               4 10        3 2 9  n - 1 n       4   9 n - 1
+--R         (1430a c   - 2860a b c )x     x  + 715a b c x
+--R    *
+--R         2n 9
+--R       (x  )
+--R   + 
+--R              5 9 n - 1  n 6              4 9        6 8  n - 1  n 5
+--R         2574b c x     (x )  + (- 12870a b c  + 1287b c )x     (x )
+--R       + 
+--R                2 3 9          5 8  n - 1  n 4
+--R         (25740a b c  - 6435a b c )x     (x )
+--R       + 
+--R                  3 2 9         2 4 8  n - 1  n 3
+--R         (- 25740a b c  + 12870a b c )x     (x )
+--R       + 
+--R                4   9         3 3 8  n - 1  n 2
+--R         (12870a b c  - 12870a b c )x     (x )
+--R       + 
+--R                 5 9        4 2 8  n - 1 n        5   8 n - 1
+--R         (- 2574a c  + 6435a b c )x     x  - 1287a b c x
+--R    *
+--R         2n 8
+--R       (x  )
+--R   + 
+--R              6 8 n - 1  n 7              5 8        7 7  n - 1  n 6
+--R         3432b c x     (x )  + (- 20592a b c  + 1716b c )x     (x )
+--R       + 
+--R                2 4 8           6 7  n - 1  n 5
+--R         (51480a b c  - 10296a b c )x     (x )
+--R       + 
+--R                  3 3 8         2 5 7  n - 1  n 4
+--R         (- 68640a b c  + 25740a b c )x     (x )
+--R       + 
+--R                4 2 8         3 4 7  n - 1  n 3
+--R         (51480a b c  - 34320a b c )x     (x )
+--R       + 
+--R                  5   8         4 3 7  n - 1  n 2
+--R         (- 20592a b c  + 25740a b c )x     (x )
+--R       + 
+--R               6 8         5 2 7  n - 1 n        6   7 n - 1
+--R         (3432a c  - 10296a b c )x     x  + 1716a b c x
+--R    *
+--R         2n 7
+--R       (x  )
+--R   + 
+--R              7 7 n - 1  n 8              6 7        8 6  n - 1  n 7
+--R         3432b c x     (x )  + (- 24024a b c  + 1716b c )x     (x )
+--R       + 
+--R                2 5 7           7 6  n - 1  n 6
+--R         (72072a b c  - 12012a b c )x     (x )
+--R       + 
+--R                   3 4 7         2 6 6  n - 1  n 5
+--R         (- 120120a b c  + 36036a b c )x     (x )
+--R       + 
+--R                 4 3 7         3 5 6  n - 1  n 4
+--R         (120120a b c  - 60060a b c )x     (x )
+--R       + 
+--R                  5 2 7         4 4 6  n - 1  n 3
+--R         (- 72072a b c  + 60060a b c )x     (x )
+--R       + 
+--R                6   7         5 3 6  n - 1  n 2
+--R         (24024a b c  - 36036a b c )x     (x )
+--R       + 
+--R                 7 7         6 2 6  n - 1 n        7   6 n - 1
+--R         (- 3432a c  + 12012a b c )x     x  - 1716a b c x
+--R    *
+--R         2n 6
+--R       (x  )
+--R   + 
+--R              8 6 n - 1  n 9              7 6        9 5  n - 1  n 8
+--R         2574b c x     (x )  + (- 20592a b c  + 1287b c )x     (x )
+--R       + 
+--R                2 6 6           8 5  n - 1  n 7
+--R         (72072a b c  - 10296a b c )x     (x )
+--R       + 
+--R                   3 5 6         2 7 5  n - 1  n 6
+--R         (- 144144a b c  + 36036a b c )x     (x )
+--R       + 
+--R                 4 4 6         3 6 5  n - 1  n 5
+--R         (180180a b c  - 72072a b c )x     (x )
+--R       + 
+--R                   5 3 6         4 5 5  n - 1  n 4
+--R         (- 144144a b c  + 90090a b c )x     (x )
+--R       + 
+--R                6 2 6         5 4 5  n - 1  n 3
+--R         (72072a b c  - 72072a b c )x     (x )
+--R       + 
+--R                  7   6         6 3 5  n - 1  n 2
+--R         (- 20592a b c  + 36036a b c )x     (x )
+--R       + 
+--R               8 6         7 2 5  n - 1 n        8   5 n - 1
+--R         (2574a c  - 10296a b c )x     x  + 1287a b c x
+--R    *
+--R         2n 5
+--R       (x  )
+--R   + 
+--R              9 5 n - 1  n 10              8 5       10 4  n - 1  n 9
+--R         1430b c x     (x )   + (- 12870a b c  + 715b  c )x     (x )
+--R       + 
+--R                2 7 5          9 4  n - 1  n 8
+--R         (51480a b c  - 6435a b c )x     (x )
+--R       + 
+--R                   3 6 5         2 8 4  n - 1  n 7
+--R         (- 120120a b c  + 25740a b c )x     (x )
+--R       + 
+--R                 4 5 5         3 7 4  n - 1  n 6
+--R         (180180a b c  - 60060a b c )x     (x )
+--R       + 
+--R                   5 4 5         4 6 4  n - 1  n 5
+--R         (- 180180a b c  + 90090a b c )x     (x )
+--R       + 
+--R                 6 3 5         5 5 4  n - 1  n 4
+--R         (120120a b c  - 90090a b c )x     (x )
+--R       + 
+--R                  7 2 5         6 4 4  n - 1  n 3
+--R         (- 51480a b c  + 60060a b c )x     (x )
+--R       + 
+--R                8   5         7 3 4  n - 1  n 2
+--R         (12870a b c  - 25740a b c )x     (x )
+--R       + 
+--R                 9 5        8 2 4  n - 1 n       9   4 n - 1
+--R         (- 1430a c  + 6435a b c )x     x  - 715a b c x
+--R    *
+--R         2n 4
+--R       (x  )
+--R   + 
+--R             10 4 n - 1  n 11             9 4       11 3  n - 1  n 10
+--R         572b  c x     (x )   + (- 5720a b c  + 286b  c )x     (x )
+--R       + 
+--R                2 8 4          10 3  n - 1  n 9
+--R         (25740a b c  - 2860a b  c )x     (x )
+--R       + 
+--R                  3 7 4         2 9 3  n - 1  n 8
+--R         (- 68640a b c  + 12870a b c )x     (x )
+--R       + 
+--R                 4 6 4         3 8 3  n - 1  n 7
+--R         (120120a b c  - 34320a b c )x     (x )
+--R       + 
+--R                   5 5 4         4 7 3  n - 1  n 6
+--R         (- 144144a b c  + 60060a b c )x     (x )
+--R       + 
+--R                 6 4 4         5 6 3  n - 1  n 5
+--R         (120120a b c  - 72072a b c )x     (x )
+--R       + 
+--R                  7 3 4         6 5 3  n - 1  n 4
+--R         (- 68640a b c  + 60060a b c )x     (x )
+--R       + 
+--R                8 2 4         7 4 3  n - 1  n 3
+--R         (25740a b c  - 34320a b c )x     (x )
+--R       + 
+--R                 9   4         8 3 3  n - 1  n 2
+--R         (- 5720a b c  + 12870a b c )x     (x )
+--R       + 
+--R              10 4        9 2 3  n - 1 n       10   3 n - 1
+--R         (572a  c  - 2860a b c )x     x  + 286a  b c x
+--R    *
+--R         2n 3
+--R       (x  )
+--R   + 
+--R             11 3 n - 1  n 12             10 3      12 2  n - 1  n 11
+--R         156b  c x     (x )   + (- 1716a b  c  + 78b  c )x     (x )
+--R       + 
+--R               2 9 3         11 2  n - 1  n 10
+--R         (8580a b c  - 858a b  c )x     (x )
+--R       + 
+--R                  3 8 3        2 10 2  n - 1  n 9
+--R         (- 25740a b c  + 4290a b  c )x     (x )
+--R       + 
+--R                4 7 3         3 9 2  n - 1  n 8
+--R         (51480a b c  - 12870a b c )x     (x )
+--R       + 
+--R                  5 6 3         4 8 2  n - 1  n 7
+--R         (- 72072a b c  + 25740a b c )x     (x )
+--R       + 
+--R                6 5 3         5 7 2  n - 1  n 6
+--R         (72072a b c  - 36036a b c )x     (x )
+--R       + 
+--R                  7 4 3         6 6 2  n - 1  n 5
+--R         (- 51480a b c  + 36036a b c )x     (x )
+--R       + 
+--R                8 3 3         7 5 2  n - 1  n 4
+--R         (25740a b c  - 25740a b c )x     (x )
+--R       + 
+--R                 9 2 3         8 4 2  n - 1  n 3
+--R         (- 8580a b c  + 12870a b c )x     (x )
+--R       + 
+--R               10   3        9 3 2  n - 1  n 2
+--R         (1716a  b c  - 4290a b c )x     (x )
+--R       + 
+--R                11 3       10 2 2  n - 1 n      11   2 n - 1
+--R         (- 156a  c  + 858a  b c )x     x  - 78a  b c x
+--R    *
+--R         2n 2
+--R       (x  )
+--R   + 
+--R            12 2 n - 1  n 13            11 2      13   n - 1  n 12
+--R         26b  c x     (x )   + (- 312a b  c  + 13b  c)x     (x )
+--R       + 
+--R               2 10 2         12   n - 1  n 11
+--R         (1716a b  c  - 156a b  c)x     (x )
+--R       + 
+--R                 3 9 2       2 11   n - 1  n 10
+--R         (- 5720a b c  + 858a b  c)x     (x )
+--R       + 
+--R                4 8 2        3 10   n - 1  n 9
+--R         (12870a b c  - 2860a b  c)x     (x )
+--R       + 
+--R                  5 7 2        4 9   n - 1  n 8
+--R         (- 20592a b c  + 6435a b c)x     (x )
+--R       + 
+--R                6 6 2         5 8   n - 1  n 7
+--R         (24024a b c  - 10296a b c)x     (x )
+--R       + 
+--R                  7 5 2         6 7   n - 1  n 6
+--R         (- 20592a b c  + 12012a b c)x     (x )
+--R       + 
+--R                8 4 2         7 6   n - 1  n 5
+--R         (12870a b c  - 10296a b c)x     (x )
+--R       + 
+--R                 9 3 2        8 5   n - 1  n 4
+--R         (- 5720a b c  + 6435a b c)x     (x )
+--R       + 
+--R               10 2 2        9 4   n - 1  n 3
+--R         (1716a  b c  - 2860a b c)x     (x )
+--R       + 
+--R                11   2       10 3   n - 1  n 2       12 2       11 2   n - 1 n
+--R         (- 312a  b c  + 858a  b c)x     (x )  + (26a  c  - 156a  b c)x     x
+--R       + 
+--R            12     n - 1
+--R         13a  b c x
+--R    *
+--R        2n
+--R       x
+--R   + 
+--R       13   n - 1  n 14           12     14  n - 1  n 13
+--R     2b  c x     (x )   + (- 26a b  c + b  )x     (x )
+--R   + 
+--R          2 11         13  n - 1  n 12          3 10       2 12  n - 1  n 11
+--R     (156a b  c - 13a b  )x     (x )   + (- 572a b  c + 78a b  )x     (x )
+--R   + 
+--R           4 9        3 11  n - 1  n 10           5 8        4 10  n - 1  n 9
+--R     (1430a b c - 286a b  )x     (x )   + (- 2574a b c + 715a b  )x     (x )
+--R   + 
+--R           6 7         5 9  n - 1  n 8           7 6         6 8  n - 1  n 7
+--R     (3432a b c - 1287a b )x     (x )  + (- 3432a b c + 1716a b )x     (x )
+--R   + 
+--R           8 5         7 7  n - 1  n 6           9 4         8 6  n - 1  n 5
+--R     (2574a b c - 1716a b )x     (x )  + (- 1430a b c + 1287a b )x     (x )
+--R   + 
+--R          10 3        9 5  n - 1  n 4          11 2        10 4  n - 1  n 3
+--R     (572a  b c - 715a b )x     (x )  + (- 156a  b c + 286a  b )x     (x )
+--R   + 
+--R       12         11 3  n - 1  n 2        13       12 2  n - 1 n    13   n - 1
+--R   (26a  b c - 78a  b )x     (x )  + (- 2a  c + 13a  b )x     x  - a  b x
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 649
+r0:=1/14*(a-b*x^n-c*x^(2*n))^14/n
+--R 
+--R
+--R   (2)
+--R        14  2n 14         13 n        13   2n 13
+--R       c  (x  )   + (14b c  x  - 14a c  )(x  )
+--R     + 
+--R           2 12  n 2           12 n      2 12   2n 12
+--R       (91b c  (x )  - 182a b c  x  + 91a c  )(x  )
+--R     + 
+--R            3 11  n 3          2 11  n 2        2   11 n       3 11   2n 11
+--R       (364b c  (x )  - 1092a b c  (x )  + 1092a b c  x  - 364a c  )(x  )
+--R     + 
+--R                4 10  n 4          3 10  n 3        2 2 10  n 2        3   10 n
+--R           1001b c  (x )  - 4004a b c  (x )  + 6006a b c  (x )  - 4004a b c  x
+--R         + 
+--R                4 10
+--R           1001a c
+--R      *
+--R           2n 10
+--R         (x  )
+--R     + 
+--R                5 9  n 5           4 9  n 4         2 3 9  n 3
+--R           2002b c (x )  - 10010a b c (x )  + 20020a b c (x )
+--R         + 
+--R                   3 2 9  n 2         4   9 n        5 9
+--R           - 20020a b c (x )  + 10010a b c x  - 2002a c
+--R      *
+--R           2n 9
+--R         (x  )
+--R     + 
+--R                6 8  n 6           5 8  n 5         2 4 8  n 4
+--R           3003b c (x )  - 18018a b c (x )  + 45045a b c (x )
+--R         + 
+--R                   3 3 8  n 3         4 2 8  n 2         5   8 n        6 8
+--R           - 60060a b c (x )  + 45045a b c (x )  - 18018a b c x  + 3003a c
+--R      *
+--R           2n 8
+--R         (x  )
+--R     + 
+--R                7 7  n 7           6 7  n 6         2 5 7  n 5
+--R           3432b c (x )  - 24024a b c (x )  + 72072a b c (x )
+--R         + 
+--R                    3 4 7  n 4          4 3 7  n 3         5 2 7  n 2
+--R           - 120120a b c (x )  + 120120a b c (x )  - 72072a b c (x )
+--R         + 
+--R                 6   7 n        7 7
+--R           24024a b c x  - 3432a c
+--R      *
+--R           2n 7
+--R         (x  )
+--R     + 
+--R                8 6  n 8           7 6  n 7         2 6 6  n 6
+--R           3003b c (x )  - 24024a b c (x )  + 84084a b c (x )
+--R         + 
+--R                    3 5 6  n 5          4 4 6  n 4          5 3 6  n 3
+--R           - 168168a b c (x )  + 210210a b c (x )  - 168168a b c (x )
+--R         + 
+--R                 6 2 6  n 2         7   6 n        8 6
+--R           84084a b c (x )  - 24024a b c x  + 3003a c
+--R      *
+--R           2n 6
+--R         (x  )
+--R     + 
+--R                9 5  n 9           8 5  n 8         2 7 5  n 7
+--R           2002b c (x )  - 18018a b c (x )  + 72072a b c (x )
+--R         + 
+--R                    3 6 5  n 6          4 5 5  n 5          5 4 5  n 4
+--R           - 168168a b c (x )  + 252252a b c (x )  - 252252a b c (x )
+--R         + 
+--R                  6 3 5  n 3         7 2 5  n 2         8   5 n        9 5
+--R           168168a b c (x )  - 72072a b c (x )  + 18018a b c x  - 2002a c
+--R      *
+--R           2n 5
+--R         (x  )
+--R     + 
+--R                10 4  n 10           9 4  n 9         2 8 4  n 8
+--R           1001b  c (x )   - 10010a b c (x )  + 45045a b c (x )
+--R         + 
+--R                    3 7 4  n 7          4 6 4  n 6          5 5 4  n 5
+--R           - 120120a b c (x )  + 210210a b c (x )  - 252252a b c (x )
+--R         + 
+--R                  6 4 4  n 4          7 3 4  n 3         8 2 4  n 2
+--R           210210a b c (x )  - 120120a b c (x )  + 45045a b c (x )
+--R         + 
+--R                   9   4 n        10 4
+--R           - 10010a b c x  + 1001a  c
+--R      *
+--R           2n 4
+--R         (x  )
+--R     + 
+--R               11 3  n 11          10 3  n 10         2 9 3  n 9
+--R           364b  c (x )   - 4004a b  c (x )   + 20020a b c (x )
+--R         + 
+--R                   3 8 3  n 8          4 7 3  n 7          5 6 3  n 6
+--R           - 60060a b c (x )  + 120120a b c (x )  - 168168a b c (x )
+--R         + 
+--R                  6 5 3  n 5          7 4 3  n 4         8 3 3  n 3
+--R           168168a b c (x )  - 120120a b c (x )  + 60060a b c (x )
+--R         + 
+--R                   9 2 3  n 2        10   3 n       11 3
+--R           - 20020a b c (x )  + 4004a  b c x  - 364a  c
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R              12 2  n 12          11 2  n 11        2 10 2  n 10
+--R           91b  c (x )   - 1092a b  c (x )   + 6006a b  c (x )
+--R         + 
+--R                   3 9 2  n 9         4 8 2  n 8         5 7 2  n 7
+--R           - 20020a b c (x )  + 45045a b c (x )  - 72072a b c (x )
+--R         + 
+--R                 6 6 2  n 6         7 5 2  n 5         8 4 2  n 4
+--R           84084a b c (x )  - 72072a b c (x )  + 45045a b c (x )
+--R         + 
+--R                   9 3 2  n 3        10 2 2  n 2        11   2 n      12 2
+--R           - 20020a b c (x )  + 6006a  b c (x )  - 1092a  b c x  + 91a  c
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R              13    n 13         12    n 12        2 11    n 11
+--R           14b  c (x )   - 182a b  c (x )   + 1092a b  c (x )
+--R         + 
+--R                  3 10    n 10         4 9    n 9         5 8    n 8
+--R           - 4004a b  c (x )   + 10010a b c (x )  - 18018a b c (x )
+--R         + 
+--R                 6 7    n 7         7 6    n 6         8 5    n 5
+--R           24024a b c (x )  - 24024a b c (x )  + 18018a b c (x )
+--R         + 
+--R                   9 4    n 4        10 3    n 3        11 2    n 2
+--R           - 10010a b c (x )  + 4004a  b c (x )  - 1092a  b c (x )
+--R         + 
+--R               12     n      13
+--R           182a  b c x  - 14a  c
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R        14  n 14        13  n 13      2 12  n 12       3 11  n 11
+--R       b  (x )   - 14a b  (x )   + 91a b  (x )   - 364a b  (x )
+--R     + 
+--R            4 10  n 10        5 9  n 9        6 8  n 8        7 7  n 7
+--R       1001a b  (x )   - 2002a b (x )  + 3003a b (x )  - 3432a b (x )
+--R     + 
+--R            8 6  n 6        9 5  n 5        10 4  n 4       11 3  n 3
+--R       3003a b (x )  - 2002a b (x )  + 1001a  b (x )  - 364a  b (x )
+--R     + 
+--R          12 2  n 2      13   n    14
+--R       91a  b (x )  - 14a  b x  + a
+--R  /
+--R     14n
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        14   n log(x) 28        13   n log(x) 27
+--R       c  (%e        )   + 14b c  (%e        )
+--R     + 
+--R               13      2 12    n log(x) 26
+--R       (- 14a c   + 91b c  )(%e        )
+--R     + 
+--R                  12       3 11    n log(x) 25
+--R       (- 182a b c   + 364b c  )(%e        )
+--R     + 
+--R           2 12          2 11        4 10    n log(x) 24
+--R       (91a c   - 1092a b c   + 1001b c  )(%e        )
+--R     + 
+--R             2   11          3 10        5 9    n log(x) 23
+--R       (1092a b c   - 4004a b c   + 2002b c )(%e        )
+--R     + 
+--R              3 11        2 2 10           4 9        6 8    n log(x) 22
+--R       (- 364a c   + 6006a b c   - 10010a b c  + 3003b c )(%e        )
+--R     + 
+--R               3   10         2 3 9           5 8        7 7    n log(x) 21
+--R       (- 4004a b c   + 20020a b c  - 18018a b c  + 3432b c )(%e        )
+--R     + 
+--R               4 10         3 2 9         2 4 8           6 7        8 6
+--R         (1001a c   - 20020a b c  + 45045a b c  - 24024a b c  + 3003b c )
+--R      *
+--R            n log(x) 20
+--R         (%e        )
+--R     + 
+--R                4   9         3 3 8         2 5 7           7 6        9 5
+--R         (10010a b c  - 60060a b c  + 72072a b c  - 24024a b c  + 2002b c )
+--R      *
+--R            n log(x) 19
+--R         (%e        )
+--R     + 
+--R                  5 9         4 2 8          3 4 7         2 6 6           8 5
+--R           - 2002a c  + 45045a b c  - 120120a b c  + 84084a b c  - 18018a b c
+--R         + 
+--R                10 4
+--R           1001b  c
+--R      *
+--R            n log(x) 18
+--R         (%e        )
+--R     + 
+--R                   5   8          4 3 7          3 5 6         2 7 5
+--R           - 18018a b c  + 120120a b c  - 168168a b c  + 72072a b c
+--R         + 
+--R                     9 4       11 3
+--R           - 10010a b c  + 364b  c
+--R      *
+--R            n log(x) 17
+--R         (%e        )
+--R     + 
+--R                6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R           3003a c  - 72072a b c  + 210210a b c  - 168168a b c  + 45045a b c
+--R         + 
+--R                    10 3      12 2
+--R           - 4004a b  c  + 91b  c
+--R      *
+--R            n log(x) 16
+--R         (%e        )
+--R     + 
+--R                 6   7          5 3 6          4 5 5          3 7 4
+--R           24024a b c  - 168168a b c  + 252252a b c  - 120120a b c
+--R         + 
+--R                 2 9 3          11 2      13
+--R           20020a b c  - 1092a b  c  + 14b  c
+--R      *
+--R            n log(x) 15
+--R         (%e        )
+--R     + 
+--R                  7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R           - 3432a c  + 84084a b c  - 252252a b c  + 210210a b c  - 60060a b c
+--R         + 
+--R                2 10 2         12     14
+--R           6006a b  c  - 182a b  c + b
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                   7   6          6 3 5          5 5 4          4 7 3
+--R           - 24024a b c  + 168168a b c  - 252252a b c  + 120120a b c
+--R         + 
+--R                   3 9 2        2 11         13
+--R           - 20020a b c  + 1092a b  c - 14a b
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R                8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R           3003a c  - 72072a b c  + 210210a b c  - 168168a b c  + 45045a b c
+--R         + 
+--R                  3 10       2 12
+--R           - 4004a b  c + 91a b
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                 8   5          7 3 4          6 5 3         5 7 2         4 9
+--R           18018a b c  - 120120a b c  + 168168a b c  - 72072a b c  + 10010a b c
+--R         + 
+--R                 3 11
+--R           - 364a b
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                  9 5         8 2 4          7 4 3         6 6 2         5 8
+--R           - 2002a c  + 45045a b c  - 120120a b c  + 84084a b c  - 18018a b c
+--R         + 
+--R                4 10
+--R           1001a b
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                  9   4         8 3 3         7 5 2         6 7         5 9
+--R         (- 10010a b c  + 60060a b c  - 72072a b c  + 24024a b c - 2002a b )
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R               10 4         9 2 3         8 4 2         7 6         6 8
+--R         (1001a  c  - 20020a b c  + 45045a b c  - 24024a b c + 3003a b )
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R             10   3         9 3 2         8 5         7 7    n log(x) 7
+--R       (4004a  b c  - 20020a b c  + 18018a b c - 3432a b )(%e        )
+--R     + 
+--R              11 3        10 2 2         9 4         8 6    n log(x) 6
+--R       (- 364a  c  + 6006a  b c  - 10010a b c + 3003a b )(%e        )
+--R     + 
+--R               11   2        10 3         9 5    n log(x) 5
+--R       (- 1092a  b c  + 4004a  b c - 2002a b )(%e        )
+--R     + 
+--R           12 2        11 2         10 4    n log(x) 4
+--R       (91a  c  - 1092a  b c + 1001a  b )(%e        )
+--R     + 
+--R            12          11 3    n log(x) 3         13       12 2    n log(x) 2
+--R       (182a  b c - 364a  b )(%e        )  + (- 14a  c + 91a  b )(%e        )
+--R     + 
+--R            13    n log(x)
+--R       - 14a  b %e
+--R  /
+--R     14n
+--R                                         Type: Union(Expression(Integer),...)
+--E 420
+
+--S 421 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        14   n log(x) 28        13   n log(x) 27
+--R       c  (%e        )   + 14b c  (%e        )
+--R     + 
+--R               13      2 12    n log(x) 26
+--R       (- 14a c   + 91b c  )(%e        )
+--R     + 
+--R                  12       3 11    n log(x) 25
+--R       (- 182a b c   + 364b c  )(%e        )
+--R     + 
+--R           2 12          2 11        4 10    n log(x) 24
+--R       (91a c   - 1092a b c   + 1001b c  )(%e        )
+--R     + 
+--R             2   11          3 10        5 9    n log(x) 23
+--R       (1092a b c   - 4004a b c   + 2002b c )(%e        )
+--R     + 
+--R              3 11        2 2 10           4 9        6 8    n log(x) 22
+--R       (- 364a c   + 6006a b c   - 10010a b c  + 3003b c )(%e        )
+--R     + 
+--R               3   10         2 3 9           5 8        7 7    n log(x) 21
+--R       (- 4004a b c   + 20020a b c  - 18018a b c  + 3432b c )(%e        )
+--R     + 
+--R               4 10         3 2 9         2 4 8           6 7        8 6
+--R         (1001a c   - 20020a b c  + 45045a b c  - 24024a b c  + 3003b c )
+--R      *
+--R            n log(x) 20
+--R         (%e        )
+--R     + 
+--R                4   9         3 3 8         2 5 7           7 6        9 5
+--R         (10010a b c  - 60060a b c  + 72072a b c  - 24024a b c  + 2002b c )
+--R      *
+--R            n log(x) 19
+--R         (%e        )
+--R     + 
+--R                  5 9         4 2 8          3 4 7         2 6 6           8 5
+--R           - 2002a c  + 45045a b c  - 120120a b c  + 84084a b c  - 18018a b c
+--R         + 
+--R                10 4
+--R           1001b  c
+--R      *
+--R            n log(x) 18
+--R         (%e        )
+--R     + 
+--R                   5   8          4 3 7          3 5 6         2 7 5
+--R           - 18018a b c  + 120120a b c  - 168168a b c  + 72072a b c
+--R         + 
+--R                     9 4       11 3
+--R           - 10010a b c  + 364b  c
+--R      *
+--R            n log(x) 17
+--R         (%e        )
+--R     + 
+--R                6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R           3003a c  - 72072a b c  + 210210a b c  - 168168a b c  + 45045a b c
+--R         + 
+--R                    10 3      12 2
+--R           - 4004a b  c  + 91b  c
+--R      *
+--R            n log(x) 16
+--R         (%e        )
+--R     + 
+--R                 6   7          5 3 6          4 5 5          3 7 4
+--R           24024a b c  - 168168a b c  + 252252a b c  - 120120a b c
+--R         + 
+--R                 2 9 3          11 2      13
+--R           20020a b c  - 1092a b  c  + 14b  c
+--R      *
+--R            n log(x) 15
+--R         (%e        )
+--R     + 
+--R                  7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R           - 3432a c  + 84084a b c  - 252252a b c  + 210210a b c  - 60060a b c
+--R         + 
+--R                2 10 2         12     14
+--R           6006a b  c  - 182a b  c + b
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                   7   6          6 3 5          5 5 4          4 7 3
+--R           - 24024a b c  + 168168a b c  - 252252a b c  + 120120a b c
+--R         + 
+--R                   3 9 2        2 11         13
+--R           - 20020a b c  + 1092a b  c - 14a b
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R                8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R           3003a c  - 72072a b c  + 210210a b c  - 168168a b c  + 45045a b c
+--R         + 
+--R                  3 10       2 12
+--R           - 4004a b  c + 91a b
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                 8   5          7 3 4          6 5 3         5 7 2         4 9
+--R           18018a b c  - 120120a b c  + 168168a b c  - 72072a b c  + 10010a b c
+--R         + 
+--R                 3 11
+--R           - 364a b
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                  9 5         8 2 4          7 4 3         6 6 2         5 8
+--R           - 2002a c  + 45045a b c  - 120120a b c  + 84084a b c  - 18018a b c
+--R         + 
+--R                4 10
+--R           1001a b
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                  9   4         8 3 3         7 5 2         6 7         5 9
+--R         (- 10010a b c  + 60060a b c  - 72072a b c  + 24024a b c - 2002a b )
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R               10 4         9 2 3         8 4 2         7 6         6 8
+--R         (1001a  c  - 20020a b c  + 45045a b c  - 24024a b c + 3003a b )
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R             10   3         9 3 2         8 5         7 7    n log(x) 7
+--R       (4004a  b c  - 20020a b c  + 18018a b c - 3432a b )(%e        )
+--R     + 
+--R              11 3        10 2 2         9 4         8 6    n log(x) 6
+--R       (- 364a  c  + 6006a  b c  - 10010a b c + 3003a b )(%e        )
+--R     + 
+--R               11   2        10 3         9 5    n log(x) 5
+--R       (- 1092a  b c  + 4004a  b c - 2002a b )(%e        )
+--R     + 
+--R           12 2        11 2         10 4    n log(x) 4
+--R       (91a  c  - 1092a  b c + 1001a  b )(%e        )
+--R     + 
+--R            12          11 3    n log(x) 3         13       12 2    n log(x) 2
+--R       (182a  b c - 364a  b )(%e        )  + (- 14a  c + 91a  b )(%e        )
+--R     + 
+--R            13    n log(x)    14  2n 14           13 n        13   2n 13
+--R       - 14a  b %e         - c  (x  )   + (- 14b c  x  + 14a c  )(x  )
+--R     + 
+--R             2 12  n 2           12 n      2 12   2n 12
+--R       (- 91b c  (x )  + 182a b c  x  - 91a c  )(x  )
+--R     + 
+--R              3 11  n 3          2 11  n 2        2   11 n       3 11   2n 11
+--R       (- 364b c  (x )  + 1092a b c  (x )  - 1092a b c  x  + 364a c  )(x  )
+--R     + 
+--R                  4 10  n 4          3 10  n 3        2 2 10  n 2
+--R           - 1001b c  (x )  + 4004a b c  (x )  - 6006a b c  (x )
+--R         + 
+--R                3   10 n        4 10
+--R           4004a b c  x  - 1001a c
+--R      *
+--R           2n 10
+--R         (x  )
+--R     + 
+--R                  5 9  n 5           4 9  n 4         2 3 9  n 3
+--R           - 2002b c (x )  + 10010a b c (x )  - 20020a b c (x )
+--R         + 
+--R                 3 2 9  n 2         4   9 n        5 9
+--R           20020a b c (x )  - 10010a b c x  + 2002a c
+--R      *
+--R           2n 9
+--R         (x  )
+--R     + 
+--R                  6 8  n 6           5 8  n 5         2 4 8  n 4
+--R           - 3003b c (x )  + 18018a b c (x )  - 45045a b c (x )
+--R         + 
+--R                 3 3 8  n 3         4 2 8  n 2         5   8 n        6 8
+--R           60060a b c (x )  - 45045a b c (x )  + 18018a b c x  - 3003a c
+--R      *
+--R           2n 8
+--R         (x  )
+--R     + 
+--R                  7 7  n 7           6 7  n 6         2 5 7  n 5
+--R           - 3432b c (x )  + 24024a b c (x )  - 72072a b c (x )
+--R         + 
+--R                  3 4 7  n 4          4 3 7  n 3         5 2 7  n 2
+--R           120120a b c (x )  - 120120a b c (x )  + 72072a b c (x )
+--R         + 
+--R                   6   7 n        7 7
+--R           - 24024a b c x  + 3432a c
+--R      *
+--R           2n 7
+--R         (x  )
+--R     + 
+--R                  8 6  n 8           7 6  n 7         2 6 6  n 6
+--R           - 3003b c (x )  + 24024a b c (x )  - 84084a b c (x )
+--R         + 
+--R                  3 5 6  n 5          4 4 6  n 4          5 3 6  n 3
+--R           168168a b c (x )  - 210210a b c (x )  + 168168a b c (x )
+--R         + 
+--R                   6 2 6  n 2         7   6 n        8 6
+--R           - 84084a b c (x )  + 24024a b c x  - 3003a c
+--R      *
+--R           2n 6
+--R         (x  )
+--R     + 
+--R                  9 5  n 9           8 5  n 8         2 7 5  n 7
+--R           - 2002b c (x )  + 18018a b c (x )  - 72072a b c (x )
+--R         + 
+--R                  3 6 5  n 6          4 5 5  n 5          5 4 5  n 4
+--R           168168a b c (x )  - 252252a b c (x )  + 252252a b c (x )
+--R         + 
+--R                    6 3 5  n 3         7 2 5  n 2         8   5 n        9 5
+--R           - 168168a b c (x )  + 72072a b c (x )  - 18018a b c x  + 2002a c
+--R      *
+--R           2n 5
+--R         (x  )
+--R     + 
+--R                  10 4  n 10           9 4  n 9         2 8 4  n 8
+--R           - 1001b  c (x )   + 10010a b c (x )  - 45045a b c (x )
+--R         + 
+--R                  3 7 4  n 7          4 6 4  n 6          5 5 4  n 5
+--R           120120a b c (x )  - 210210a b c (x )  + 252252a b c (x )
+--R         + 
+--R                    6 4 4  n 4          7 3 4  n 3         8 2 4  n 2
+--R           - 210210a b c (x )  + 120120a b c (x )  - 45045a b c (x )
+--R         + 
+--R                 9   4 n        10 4
+--R           10010a b c x  - 1001a  c
+--R      *
+--R           2n 4
+--R         (x  )
+--R     + 
+--R                 11 3  n 11          10 3  n 10         2 9 3  n 9
+--R           - 364b  c (x )   + 4004a b  c (x )   - 20020a b c (x )
+--R         + 
+--R                 3 8 3  n 8          4 7 3  n 7          5 6 3  n 6
+--R           60060a b c (x )  - 120120a b c (x )  + 168168a b c (x )
+--R         + 
+--R                    6 5 3  n 5          7 4 3  n 4         8 3 3  n 3
+--R           - 168168a b c (x )  + 120120a b c (x )  - 60060a b c (x )
+--R         + 
+--R                 9 2 3  n 2        10   3 n       11 3
+--R           20020a b c (x )  - 4004a  b c x  + 364a  c
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R                12 2  n 12          11 2  n 11        2 10 2  n 10
+--R           - 91b  c (x )   + 1092a b  c (x )   - 6006a b  c (x )
+--R         + 
+--R                 3 9 2  n 9         4 8 2  n 8         5 7 2  n 7
+--R           20020a b c (x )  - 45045a b c (x )  + 72072a b c (x )
+--R         + 
+--R                   6 6 2  n 6         7 5 2  n 5         8 4 2  n 4
+--R           - 84084a b c (x )  + 72072a b c (x )  - 45045a b c (x )
+--R         + 
+--R                 9 3 2  n 3        10 2 2  n 2        11   2 n      12 2
+--R           20020a b c (x )  - 6006a  b c (x )  + 1092a  b c x  - 91a  c
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R                13    n 13         12    n 12        2 11    n 11
+--R           - 14b  c (x )   + 182a b  c (x )   - 1092a b  c (x )
+--R         + 
+--R                3 10    n 10         4 9    n 9         5 8    n 8
+--R           4004a b  c (x )   - 10010a b c (x )  + 18018a b c (x )
+--R         + 
+--R                   6 7    n 7         7 6    n 6         8 5    n 5
+--R           - 24024a b c (x )  + 24024a b c (x )  - 18018a b c (x )
+--R         + 
+--R                 9 4    n 4        10 3    n 3        11 2    n 2       12     n
+--R           10010a b c (x )  - 4004a  b c (x )  + 1092a  b c (x )  - 182a  b c x
+--R         + 
+--R              13
+--R           14a  c
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R          14  n 14        13  n 13      2 12  n 12       3 11  n 11
+--R       - b  (x )   + 14a b  (x )   - 91a b  (x )   + 364a b  (x )
+--R     + 
+--R              4 10  n 10        5 9  n 9        6 8  n 8        7 7  n 7
+--R       - 1001a b  (x )   + 2002a b (x )  - 3003a b (x )  + 3432a b (x )
+--R     + 
+--R              8 6  n 6        9 5  n 5        10 4  n 4       11 3  n 3
+--R       - 3003a b (x )  + 2002a b (x )  - 1001a  b (x )  + 364a  b (x )
+--R     + 
+--R            12 2  n 2      13   n    14
+--R       - 91a  b (x )  + 14a  b x  - a
+--R  /
+--R     14n
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         14   n log(x) 28        13   n log(x) 27
+--R       2c  (%e        )   + 27b c  (%e        )
+--R     + 
+--R               13       2 12    n log(x) 26
+--R       (- 26a c   + 169b c  )(%e        )
+--R     + 
+--R                  12       3 11    n log(x) 25
+--R       (- 325a b c   + 650b c  )(%e        )
+--R     + 
+--R            2 12          2 11        4 10    n log(x) 24
+--R       (156a c   - 1872a b c   + 1716b c  )(%e        )
+--R     + 
+--R             2   11          3 10        5 9    n log(x) 23
+--R       (1794a b c   - 6578a b c   + 3289b c )(%e        )
+--R     + 
+--R              3 11        2 2 10           4 9        6 8    n log(x) 22
+--R       (- 572a c   + 9438a b c   - 15730a b c  + 4719b c )(%e        )
+--R     + 
+--R               3   10         2 3 9           5 8        7 7    n log(x) 21
+--R       (- 6006a b c   + 30030a b c  - 27027a b c  + 5148b c )(%e        )
+--R     + 
+--R               4 10         3 2 9         2 4 8           6 7        8 6
+--R         (1430a c   - 28600a b c  + 64350a b c  - 34320a b c  + 4290b c )
+--R      *
+--R            n log(x) 20
+--R         (%e        )
+--R     + 
+--R                4   9         3 3 8         2 5 7           7 6        9 5
+--R         (13585a b c  - 81510a b c  + 97812a b c  - 32604a b c  + 2717b c )
+--R      *
+--R            n log(x) 19
+--R         (%e        )
+--R     + 
+--R                  5 9         4 2 8          3 4 7          2 6 6           8 5
+--R           - 2574a c  + 57915a b c  - 154440a b c  + 108108a b c  - 23166a b c
+--R         + 
+--R                10 4
+--R           1287b  c
+--R      *
+--R            n log(x) 18
+--R         (%e        )
+--R     + 
+--R                   5   8          4 3 7          3 5 6         2 7 5
+--R           - 21879a b c  + 145860a b c  - 204204a b c  + 87516a b c
+--R         + 
+--R                     9 4       11 3
+--R           - 12155a b c  + 442b  c
+--R      *
+--R            n log(x) 17
+--R         (%e        )
+--R     + 
+--R                6 8         5 2 7          4 4 6          3 6 5         2 8 4
+--R           3432a c  - 82368a b c  + 240240a b c  - 192192a b c  + 51480a b c
+--R         + 
+--R                    10 3       12 2
+--R           - 4576a b  c  + 104b  c
+--R      *
+--R            n log(x) 16
+--R         (%e        )
+--R     + 
+--R                 6   7          5 3 6          4 5 5          3 7 4
+--R           25740a b c  - 180180a b c  + 270270a b c  - 128700a b c
+--R         + 
+--R                 2 9 3          11 2      13
+--R           21450a b c  - 1170a b  c  + 15b  c
+--R      *
+--R            n log(x) 15
+--R         (%e        )
+--R     + 
+--R                  7 7         6 2 6          5 4 5          4 6 4         3 8 3
+--R           - 3432a c  + 84084a b c  - 252252a b c  + 210210a b c  - 60060a b c
+--R         + 
+--R                2 10 2         12     14
+--R           6006a b  c  - 182a b  c + b
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                   7   6          6 3 5          5 5 4          4 7 3
+--R           - 22308a b c  + 156156a b c  - 234234a b c  + 111540a b c
+--R         + 
+--R                   3 9 2        2 11         13
+--R           - 18590a b c  + 1014a b  c - 13a b
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R                8 6         7 2 5          6 4 4          5 6 3         4 8 2
+--R           2574a c  - 61776a b c  + 180180a b c  - 144144a b c  + 38610a b c
+--R         + 
+--R                  3 10       2 12
+--R           - 3432a b  c + 78a b
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                 8   5         7 3 4          6 5 3         5 7 2        4 9
+--R           14157a b c  - 94380a b c  + 132132a b c  - 56628a b c  + 7865a b c
+--R         + 
+--R                 3 11
+--R           - 286a b
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                  9 5         8 2 4         7 4 3         6 6 2         5 8
+--R           - 1430a c  + 32175a b c  - 85800a b c  + 60060a b c  - 12870a b c
+--R         + 
+--R               4 10
+--R           715a b
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                 9   4         8 3 3         7 5 2         6 7         5 9
+--R         (- 6435a b c  + 38610a b c  - 46332a b c  + 15444a b c - 1287a b )
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R              10 4         9 2 3         8 4 2         7 6         6 8
+--R         (572a  c  - 11440a b c  + 25740a b c  - 13728a b c + 1716a b )
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R             10   3         9 3 2        8 5         7 7    n log(x) 7
+--R       (2002a  b c  - 10010a b c  + 9009a b c - 1716a b )(%e        )
+--R     + 
+--R              11 3        10 2 2        9 4         8 6    n log(x) 6
+--R       (- 156a  c  + 2574a  b c  - 4290a b c + 1287a b )(%e        )
+--R     + 
+--R              11   2        10 3        9 5    n log(x) 5
+--R       (- 390a  b c  + 1430a  b c - 715a b )(%e        )
+--R     + 
+--R           12 2       11 2        10 4    n log(x) 4
+--R       (26a  c  - 312a  b c + 286a  b )(%e        )
+--R     + 
+--R           12         11 3    n log(x) 3        13       12 2    n log(x) 2
+--R       (39a  b c - 78a  b )(%e        )  + (- 2a  c + 13a  b )(%e        )
+--R     + 
+--R          13    n log(x)        14   2n - 1      13   n - 1   2n 13
+--R       - a  b %e         + (- 2c  x x       - b c  x x     )(x  )
+--R     + 
+--R                   13   n        13   2n - 1      2 12   n - 1 n
+--R           (- 26b c  x x  + 26a c  x)x       - 13b c  x x     x
+--R         + 
+--R                  12   n - 1
+--R           13a b c  x x
+--R      *
+--R           2n 12
+--R         (x  )
+--R     + 
+--R                  2 12    n 2           12   n       2 12   2n - 1
+--R           (- 156b c  x (x )  + 312a b c  x x  - 156a c  x)x
+--R         + 
+--R                3 11   n - 1  n 2         2 11   n - 1 n      2   11   n - 1
+--R           - 78b c  x x     (x )  + 156a b c  x x     x  - 78a b c  x x
+--R      *
+--R           2n 11
+--R         (x  )
+--R     + 
+--R                     3 11    n 3          2 11    n 2        2   11   n
+--R               - 572b c  x (x )  + 1716a b c  x (x )  - 1716a b c  x x
+--R             + 
+--R                   3 11
+--R               572a c  x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                 4 10   n - 1  n 3         3 10   n - 1  n 2
+--R           - 286b c  x x     (x )  + 858a b c  x x     (x )
+--R         + 
+--R                 2 2 10   n - 1 n       3   10   n - 1
+--R           - 858a b c  x x     x  + 286a b c  x x
+--R      *
+--R           2n 10
+--R         (x  )
+--R     + 
+--R                      4 10    n 4          3 10    n 3        2 2 10    n 2
+--R               - 1430b c  x (x )  + 5720a b c  x (x )  - 8580a b c  x (x )
+--R             + 
+--R                    3   10   n        4 10
+--R               5720a b c  x x  - 1430a c  x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                 5 9   n - 1  n 4          4 9   n - 1  n 3
+--R           - 715b c x x     (x )  + 2860a b c x x     (x )
+--R         + 
+--R                  2 3 9   n - 1  n 2        3 2 9   n - 1 n       4   9   n - 1
+--R           - 4290a b c x x     (x )  + 2860a b c x x     x  - 715a b c x x
+--R      *
+--R           2n 9
+--R         (x  )
+--R     + 
+--R                      5 9    n 5           4 9    n 4         2 3 9    n 3
+--R               - 2574b c x (x )  + 12870a b c x (x )  - 25740a b c x (x )
+--R             + 
+--R                     3 2 9    n 2         4   9   n        5 9
+--R               25740a b c x (x )  - 12870a b c x x  + 2574a c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                  6 8   n - 1  n 5          5 8   n - 1  n 4
+--R           - 1287b c x x     (x )  + 6435a b c x x     (x )
+--R         + 
+--R                   2 4 8   n - 1  n 3         3 3 8   n - 1  n 2
+--R           - 12870a b c x x     (x )  + 12870a b c x x     (x )
+--R         + 
+--R                  4 2 8   n - 1 n        5   8   n - 1
+--R           - 6435a b c x x     x  + 1287a b c x x
+--R      *
+--R           2n 8
+--R         (x  )
+--R     + 
+--R                      6 8    n 6           5 8    n 5         2 4 8    n 4
+--R               - 3432b c x (x )  + 20592a b c x (x )  - 51480a b c x (x )
+--R             + 
+--R                     3 3 8    n 3         4 2 8    n 2         5   8   n
+--R               68640a b c x (x )  - 51480a b c x (x )  + 20592a b c x x
+--R             + 
+--R                      6 8
+--R               - 3432a c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                  7 7   n - 1  n 6           6 7   n - 1  n 5
+--R           - 1716b c x x     (x )  + 10296a b c x x     (x )
+--R         + 
+--R                   2 5 7   n - 1  n 4         3 4 7   n - 1  n 3
+--R           - 25740a b c x x     (x )  + 34320a b c x x     (x )
+--R         + 
+--R                 4 3 7   n - 1  n 2         5 2 7   n - 1 n        6   7   n - 1
+--R         - 25740a b c x x     (x )  + 10296a b c x x     x  - 1716a b c x x
+--R      *
+--R           2n 7
+--R         (x  )
+--R     + 
+--R                      7 7    n 7           6 7    n 6         2 5 7    n 5
+--R               - 3432b c x (x )  + 24024a b c x (x )  - 72072a b c x (x )
+--R             + 
+--R                      3 4 7    n 4          4 3 7    n 3         5 2 7    n 2
+--R               120120a b c x (x )  - 120120a b c x (x )  + 72072a b c x (x )
+--R             + 
+--R                       6   7   n        7 7
+--R               - 24024a b c x x  + 3432a c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                  8 6   n - 1  n 7           7 6   n - 1  n 6
+--R           - 1716b c x x     (x )  + 12012a b c x x     (x )
+--R         + 
+--R                   2 6 6   n - 1  n 5         3 5 6   n - 1  n 4
+--R           - 36036a b c x x     (x )  + 60060a b c x x     (x )
+--R         + 
+--R                   4 4 6   n - 1  n 3         5 3 6   n - 1  n 2
+--R           - 60060a b c x x     (x )  + 36036a b c x x     (x )
+--R         + 
+--R                   6 2 6   n - 1 n        7   6   n - 1
+--R           - 12012a b c x x     x  + 1716a b c x x
+--R      *
+--R           2n 6
+--R         (x  )
+--R     + 
+--R                      8 6    n 8           7 6    n 7         2 6 6    n 6
+--R               - 2574b c x (x )  + 20592a b c x (x )  - 72072a b c x (x )
+--R             + 
+--R                      3 5 6    n 5          4 4 6    n 4          5 3 6    n 3
+--R               144144a b c x (x )  - 180180a b c x (x )  + 144144a b c x (x )
+--R             + 
+--R                       6 2 6    n 2         7   6   n        8 6
+--R               - 72072a b c x (x )  + 20592a b c x x  - 2574a c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                  9 5   n - 1  n 8           8 5   n - 1  n 7
+--R           - 1287b c x x     (x )  + 10296a b c x x     (x )
+--R         + 
+--R                   2 7 5   n - 1  n 6         3 6 5   n - 1  n 5
+--R           - 36036a b c x x     (x )  + 72072a b c x x     (x )
+--R         + 
+--R                   4 5 5   n - 1  n 4         5 4 5   n - 1  n 3
+--R           - 90090a b c x x     (x )  + 72072a b c x x     (x )
+--R         + 
+--R                 6 3 5   n - 1  n 2         7 2 5   n - 1 n        8   5   n - 1
+--R         - 36036a b c x x     (x )  + 10296a b c x x     x  - 1287a b c x x
+--R      *
+--R           2n 5
+--R         (x  )
+--R     + 
+--R                      9 5    n 9           8 5    n 8         2 7 5    n 7
+--R               - 1430b c x (x )  + 12870a b c x (x )  - 51480a b c x (x )
+--R             + 
+--R                      3 6 5    n 6          4 5 5    n 5          5 4 5    n 4
+--R               120120a b c x (x )  - 180180a b c x (x )  + 180180a b c x (x )
+--R             + 
+--R                        6 3 5    n 3         7 2 5    n 2         8   5   n
+--R               - 120120a b c x (x )  + 51480a b c x (x )  - 12870a b c x x
+--R             + 
+--R                    9 5
+--R               1430a c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                 10 4   n - 1  n 9          9 4   n - 1  n 8
+--R           - 715b  c x x     (x )  + 6435a b c x x     (x )
+--R         + 
+--R                   2 8 4   n - 1  n 7         3 7 4   n - 1  n 6
+--R           - 25740a b c x x     (x )  + 60060a b c x x     (x )
+--R         + 
+--R                   4 6 4   n - 1  n 5         5 5 4   n - 1  n 4
+--R           - 90090a b c x x     (x )  + 90090a b c x x     (x )
+--R         + 
+--R                   6 4 4   n - 1  n 3         7 3 4   n - 1  n 2
+--R           - 60060a b c x x     (x )  + 25740a b c x x     (x )
+--R         + 
+--R                  8 2 4   n - 1 n       9   4   n - 1
+--R           - 6435a b c x x     x  + 715a b c x x
+--R      *
+--R           2n 4
+--R         (x  )
+--R     + 
+--R                     10 4    n 10          9 4    n 9         2 8 4    n 8
+--R               - 572b  c x (x )   + 5720a b c x (x )  - 25740a b c x (x )
+--R             + 
+--R                     3 7 4    n 7          4 6 4    n 6          5 5 4    n 5
+--R               68640a b c x (x )  - 120120a b c x (x )  + 144144a b c x (x )
+--R             + 
+--R                        6 4 4    n 4         7 3 4    n 3         8 2 4    n 2
+--R               - 120120a b c x (x )  + 68640a b c x (x )  - 25740a b c x (x )
+--R             + 
+--R                    9   4   n       10 4
+--R               5720a b c x x  - 572a  c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                 11 3   n - 1  n 10          10 3   n - 1  n 9
+--R           - 286b  c x x     (x )   + 2860a b  c x x     (x )
+--R         + 
+--R                   2 9 3   n - 1  n 8         3 8 3   n - 1  n 7
+--R           - 12870a b c x x     (x )  + 34320a b c x x     (x )
+--R         + 
+--R                   4 7 3   n - 1  n 6         5 6 3   n - 1  n 5
+--R           - 60060a b c x x     (x )  + 72072a b c x x     (x )
+--R         + 
+--R                   6 5 3   n - 1  n 4         7 4 3   n - 1  n 3
+--R           - 60060a b c x x     (x )  + 34320a b c x x     (x )
+--R         + 
+--R                 8 3 3   n - 1  n 2        9 2 3   n - 1 n       10   3   n - 1
+--R         - 12870a b c x x     (x )  + 2860a b c x x     x  - 286a  b c x x
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R                     11 3    n 11          10 3    n 10        2 9 3    n 9
+--R               - 156b  c x (x )   + 1716a b  c x (x )   - 8580a b c x (x )
+--R             + 
+--R                     3 8 3    n 8         4 7 3    n 7         5 6 3    n 6
+--R               25740a b c x (x )  - 51480a b c x (x )  + 72072a b c x (x )
+--R             + 
+--R                       6 5 3    n 5         7 4 3    n 4         8 3 3    n 3
+--R               - 72072a b c x (x )  + 51480a b c x (x )  - 25740a b c x (x )
+--R             + 
+--R                    9 2 3    n 2        10   3   n       11 3
+--R               8580a b c x (x )  - 1716a  b c x x  + 156a  c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                12 2   n - 1  n 11         11 2   n - 1  n 10
+--R           - 78b  c x x     (x )   + 858a b  c x x     (x )
+--R         + 
+--R                  2 10 2   n - 1  n 9         3 9 2   n - 1  n 8
+--R           - 4290a b  c x x     (x )  + 12870a b c x x     (x )
+--R         + 
+--R                   4 8 2   n - 1  n 7         5 7 2   n - 1  n 6
+--R           - 25740a b c x x     (x )  + 36036a b c x x     (x )
+--R         + 
+--R                   6 6 2   n - 1  n 5         7 5 2   n - 1  n 4
+--R           - 36036a b c x x     (x )  + 25740a b c x x     (x )
+--R         + 
+--R                   8 4 2   n - 1  n 3        9 3 2   n - 1  n 2
+--R           - 12870a b c x x     (x )  + 4290a b c x x     (x )
+--R         + 
+--R                 10 2 2   n - 1 n      11   2   n - 1
+--R           - 858a  b c x x     x  + 78a  b c x x
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R                    12 2    n 12         11 2    n 11        2 10 2    n 10
+--R               - 26b  c x (x )   + 312a b  c x (x )   - 1716a b  c x (x )
+--R             + 
+--R                    3 9 2    n 9         4 8 2    n 8         5 7 2    n 7
+--R               5720a b c x (x )  - 12870a b c x (x )  + 20592a b c x (x )
+--R             + 
+--R                       6 6 2    n 6         7 5 2    n 5         8 4 2    n 4
+--R               - 24024a b c x (x )  + 20592a b c x (x )  - 12870a b c x (x )
+--R             + 
+--R                  9 3 2    n 3        10 2 2    n 2       11   2   n      12 2
+--R             5720a b c x (x )  - 1716a  b c x (x )  + 312a  b c x x  - 26a  c x
+--R          *
+--R              2n - 1
+--R             x
+--R         + 
+--R                13     n - 1  n 12         12     n - 1  n 11
+--R           - 13b  c x x     (x )   + 156a b  c x x     (x )
+--R         + 
+--R                 2 11     n - 1  n 10        3 10     n - 1  n 9
+--R           - 858a b  c x x     (x )   + 2860a b  c x x     (x )
+--R         + 
+--R                  4 9     n - 1  n 8         5 8     n - 1  n 7
+--R           - 6435a b c x x     (x )  + 10296a b c x x     (x )
+--R         + 
+--R                   6 7     n - 1  n 6         7 6     n - 1  n 5
+--R           - 12012a b c x x     (x )  + 10296a b c x x     (x )
+--R         + 
+--R                  8 5     n - 1  n 4        9 4     n - 1  n 3
+--R           - 6435a b c x x     (x )  + 2860a b c x x     (x )
+--R         + 
+--R                 10 3     n - 1  n 2       11 2     n - 1 n      12       n - 1
+--R           - 858a  b c x x     (x )  + 156a  b c x x     x  - 13a  b c x x
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R               13      n 13        12      n 12       2 11      n 11
+--R           - 2b  c x (x )   + 26a b  c x (x )   - 156a b  c x (x )
+--R         + 
+--R               3 10      n 10        4 9      n 9        5 8      n 8
+--R           572a b  c x (x )   - 1430a b c x (x )  + 2574a b c x (x )
+--R         + 
+--R                  6 7      n 7        7 6      n 6        8 5      n 5
+--R           - 3432a b c x (x )  + 3432a b c x (x )  - 2574a b c x (x )
+--R         + 
+--R                9 4      n 4       10 3      n 3       11 2      n 2
+--R           1430a b c x (x )  - 572a  b c x (x )  + 156a  b c x (x )
+--R         + 
+--R                12       n     13
+--R           - 26a  b c x x  + 2a  c x
+--R      *
+--R          2n - 1
+--R         x
+--R     + 
+--R          14   n - 1  n 13        13   n - 1  n 12      2 12   n - 1  n 11
+--R       - b  x x     (x )   + 13a b  x x     (x )   - 78a b  x x     (x )
+--R     + 
+--R           3 11   n - 1  n 10       4 10   n - 1  n 9        5 9   n - 1  n 8
+--R       286a b  x x     (x )   - 715a b  x x     (x )  + 1287a b x x     (x )
+--R     + 
+--R              6 8   n - 1  n 7        7 7   n - 1  n 6        8 6   n - 1  n 5
+--R       - 1716a b x x     (x )  + 1716a b x x     (x )  - 1287a b x x     (x )
+--R     + 
+--R           9 5   n - 1  n 4       10 4   n - 1  n 3      11 3   n - 1  n 2
+--R       715a b x x     (x )  - 286a  b x x     (x )  + 78a  b x x     (x )
+--R     + 
+--R            12 2   n - 1 n    13     n - 1
+--R       - 13a  b x x     x  + a  b x x
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 422
+
+)clear all
+
+--S 423 of 649
+t0:=(b+2*c*x)*(b*x+c*x^2)^13
+--R 
+--R
+--R   (1)
+--R       14 27        13 26       2 12 25       3 11 24        4 10 23
+--R     2c  x   + 27b c  x   + 169b c  x   + 650b c  x   + 1716b c  x
+--R   + 
+--R          5 9 22        6 8 21        7 7 20        8 6 19        9 5 18
+--R     3289b c x   + 4719b c x   + 5148b c x   + 4290b c x   + 2717b c x
+--R   + 
+--R          10 4 17       11 3 16       12 2 15      13   14    14 13
+--R     1287b  c x   + 442b  c x   + 104b  c x   + 15b  c x   + b  x
+--R                                                    Type: Polynomial(Integer)
+--E 423
+
+--S 424 of 649
+r0:=1/14*x^14*(b+c*x)^14
+--R 
+--R
+--R   (2)
+--R      1  14 28      13 27   13  2 12 26      3 11 25   143  4 10 24       5 9 23
+--R     -- c  x   + b c  x   + -- b c  x   + 26b c  x   + --- b c  x   + 143b c x
+--R     14                      2                          2
+--R   + 
+--R     429  6 8 22   1716  7 7 21   429  8 6 20       9 5 19   143  10 4 18
+--R     --- b c x   + ---- b c x   + --- b c x   + 143b c x   + --- b  c x
+--R      2              7             2                          2
+--R   + 
+--R        11 3 17   13  12 2 16    13   15    1  14 14
+--R     26b  c x   + -- b  c x   + b  c x   + -- b  x
+--R                   2                       14
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 424
+
+--S 425 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 28      13 27   13  2 12 26      3 11 25   143  4 10 24       5 9 23
+--R     -- c  x   + b c  x   + -- b c  x   + 26b c  x   + --- b c  x   + 143b c x
+--R     14                      2                          2
+--R   + 
+--R     429  6 8 22   1716  7 7 21   429  8 6 20       9 5 19   143  10 4 18
+--R     --- b c x   + ---- b c x   + --- b c x   + 143b c x   + --- b  c x
+--R      2              7             2                          2
+--R   + 
+--R        11 3 17   13  12 2 16    13   15    1  14 14
+--R     26b  c x   + -- b  c x   + b  c x   + -- b  x
+--R                   2                       14
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 425
+
+--S 426 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 426
+
+--S 427 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 427
+
+)clear all
+
+--S 428 of 649
+t0:=x*(b+2*c*x^2)*(b*x^2+c*x^4)^13
+--R 
+--R
+--R   (1)
+--R       14 55        13 53       2 12 51       3 11 49        4 10 47
+--R     2c  x   + 27b c  x   + 169b c  x   + 650b c  x   + 1716b c  x
+--R   + 
+--R          5 9 45        6 8 43        7 7 41        8 6 39        9 5 37
+--R     3289b c x   + 4719b c x   + 5148b c x   + 4290b c x   + 2717b c x
+--R   + 
+--R          10 4 35       11 3 33       12 2 31      13   29    14 27
+--R     1287b  c x   + 442b  c x   + 104b  c x   + 15b  c x   + b  x
+--R                                                    Type: Polynomial(Integer)
+--E 428
+
+--S 429 of 649
+r0:=1/28*x^28*(b+c*x^2)^14
+--R 
+--R
+--R   (2)
+--R      1  14 56   1    13 54   13  2 12 52      3 11 50   143  4 10 48
+--R     -- c  x   + - b c  x   + -- b c  x   + 13b c  x   + --- b c  x
+--R     28          2             4                          4
+--R   + 
+--R     143  5 9 46   429  6 8 44   858  7 7 42   429  8 6 40   143  9 5 38
+--R     --- b c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R      2             4             7             4             2
+--R   + 
+--R     143  10 4 36      11 3 34   13  12 2 32   1  13   30    1  14 28
+--R     --- b  c x   + 13b  c x   + -- b  c x   + - b  c x   + -- b  x
+--R      4                           4            2            28
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 429
+
+--S 430 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 56   1    13 54   13  2 12 52      3 11 50   143  4 10 48
+--R     -- c  x   + - b c  x   + -- b c  x   + 13b c  x   + --- b c  x
+--R     28          2             4                          4
+--R   + 
+--R     143  5 9 46   429  6 8 44   858  7 7 42   429  8 6 40   143  9 5 38
+--R     --- b c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R      2             4             7             4             2
+--R   + 
+--R     143  10 4 36      11 3 34   13  12 2 32   1  13   30    1  14 28
+--R     --- b  c x   + 13b  c x   + -- b  c x   + - b  c x   + -- b  x
+--R      4                           4            2            28
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 430
+
+--S 431 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 431
+
+--S 432 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 432
+
+)clear all
+
+--S 433 of 649
+t0:=x^2*(b+2*c*x^3)*(b*x^3+c*x^6)^13
+--R 
+--R
+--R   (1)
+--R       14 83        13 80       2 12 77       3 11 74        4 10 71
+--R     2c  x   + 27b c  x   + 169b c  x   + 650b c  x   + 1716b c  x
+--R   + 
+--R          5 9 68        6 8 65        7 7 62        8 6 59        9 5 56
+--R     3289b c x   + 4719b c x   + 5148b c x   + 4290b c x   + 2717b c x
+--R   + 
+--R          10 4 53       11 3 50       12 2 47      13   44    14 41
+--R     1287b  c x   + 442b  c x   + 104b  c x   + 15b  c x   + b  x
+--R                                                    Type: Polynomial(Integer)
+--E 433
+
+--S 434 of 649
+r0:=1/42*x^42*(b+c*x^3)^14
+--R 
+--R
+--R   (2)
+--R      1  14 84   1    13 81   13  2 12 78   26  3 11 75   143  4 10 72
+--R     -- c  x   + - b c  x   + -- b c  x   + -- b c  x   + --- b c  x
+--R     42          3             6             3             6
+--R   + 
+--R     143  5 9 69   143  6 8 66   572  7 7 63   143  8 6 60   143  9 5 57
+--R     --- b c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R      3             2             7             2             3
+--R   + 
+--R     143  10 4 54   26  11 3 51   13  12 2 48   1  13   45    1  14 42
+--R     --- b  c x   + -- b  c x   + -- b  c x   + - b  c x   + -- b  x
+--R      6              3             6            3            42
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 434
+
+--S 435 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 84   1    13 81   13  2 12 78   26  3 11 75   143  4 10 72
+--R     -- c  x   + - b c  x   + -- b c  x   + -- b c  x   + --- b c  x
+--R     42          3             6             3             6
+--R   + 
+--R     143  5 9 69   143  6 8 66   572  7 7 63   143  8 6 60   143  9 5 57
+--R     --- b c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R      3             2             7             2             3
+--R   + 
+--R     143  10 4 54   26  11 3 51   13  12 2 48   1  13   45    1  14 42
+--R     --- b  c x   + -- b  c x   + -- b  c x   + - b  c x   + -- b  x
+--R      6              3             6            3            42
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 435
+
+--S 436 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 436
+
+--S 437 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 437
+
+)clear all
+
+--S 438 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)*(b*x^n+c*x^(2*n))^13
+--R 
+--R
+--R   (1)
+--R        14 n - 1 n      13 n - 1   2n 13
+--R     (2c  x     x  + b c  x     )(x  )
+--R   + 
+--R           13 n - 1  n 2      2 12 n - 1 n   2n 12
+--R     (26b c  x     (x )  + 13b c  x     x )(x  )
+--R   + 
+--R          2 12 n - 1  n 3      3 11 n - 1  n 2   2n 11
+--R     (156b c  x     (x )  + 78b c  x     (x ) )(x  )
+--R   + 
+--R          3 11 n - 1  n 4       4 10 n - 1  n 3   2n 10
+--R     (572b c  x     (x )  + 286b c  x     (x ) )(x  )
+--R   + 
+--R           4 10 n - 1  n 5       5 9 n - 1  n 4   2n 9
+--R     (1430b c  x     (x )  + 715b c x     (x ) )(x  )
+--R   + 
+--R           5 9 n - 1  n 6        6 8 n - 1  n 5   2n 8
+--R     (2574b c x     (x )  + 1287b c x     (x ) )(x  )
+--R   + 
+--R           6 8 n - 1  n 7        7 7 n - 1  n 6   2n 7
+--R     (3432b c x     (x )  + 1716b c x     (x ) )(x  )
+--R   + 
+--R           7 7 n - 1  n 8        8 6 n - 1  n 7   2n 6
+--R     (3432b c x     (x )  + 1716b c x     (x ) )(x  )
+--R   + 
+--R           8 6 n - 1  n 9        9 5 n - 1  n 8   2n 5
+--R     (2574b c x     (x )  + 1287b c x     (x ) )(x  )
+--R   + 
+--R           9 5 n - 1  n 10       10 4 n - 1  n 9   2n 4
+--R     (1430b c x     (x )   + 715b  c x     (x ) )(x  )
+--R   + 
+--R          10 4 n - 1  n 11       11 3 n - 1  n 10   2n 3
+--R     (572b  c x     (x )   + 286b  c x     (x )  )(x  )
+--R   + 
+--R          11 3 n - 1  n 12      12 2 n - 1  n 11   2n 2
+--R     (156b  c x     (x )   + 78b  c x     (x )  )(x  )
+--R   + 
+--R         12 2 n - 1  n 13      13   n - 1  n 12  2n     13   n - 1  n 14
+--R     (26b  c x     (x )   + 13b  c x     (x )  )x   + 2b  c x     (x )
+--R   + 
+--R      14 n - 1  n 13
+--R     b  x     (x )
+--R                                                    Type: Expression(Integer)
+--E 438
+
+--S 439 of 649
+r0:=1/14*x^(14*n)*(b+c*x^n)^14/n
+--R 
+--R
+--R   (2)
+--R          14  n 14        13  n 13      2 12  n 12       3 11  n 11
+--R         c  (x )   + 14b c  (x )   + 91b c  (x )   + 364b c  (x )
+--R       + 
+--R              4 10  n 10        5 9  n 9        6 8  n 8        7 7  n 7
+--R         1001b c  (x )   + 2002b c (x )  + 3003b c (x )  + 3432b c (x )
+--R       + 
+--R              8 6  n 6        9 5  n 5        10 4  n 4       11 3  n 3
+--R         3003b c (x )  + 2002b c (x )  + 1001b  c (x )  + 364b  c (x )
+--R       + 
+--R            12 2  n 2      13   n    14
+--R         91b  c (x )  + 14b  c x  + b
+--R    *
+--R        14n
+--R       x
+--R  /
+--R     14n
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        14   n log(x) 28        13   n log(x) 27      2 12   n log(x) 26
+--R       c  (%e        )   + 14b c  (%e        )   + 91b c  (%e        )
+--R     + 
+--R           3 11   n log(x) 25        4 10   n log(x) 24        5 9   n log(x) 23
+--R       364b c  (%e        )   + 1001b c  (%e        )   + 2002b c (%e        )
+--R     + 
+--R            6 8   n log(x) 22        7 7   n log(x) 21        8 6   n log(x) 20
+--R       3003b c (%e        )   + 3432b c (%e        )   + 3003b c (%e        )
+--R     + 
+--R            9 5   n log(x) 19        10 4   n log(x) 18       11 3   n log(x) 17
+--R       2002b c (%e        )   + 1001b  c (%e        )   + 364b  c (%e        )
+--R     + 
+--R          12 2   n log(x) 16      13     n log(x) 15    14   n log(x) 14
+--R       91b  c (%e        )   + 14b  c (%e        )   + b  (%e        )
+--R  /
+--R     14n
+--R                                         Type: Union(Expression(Integer),...)
+--E 440
+
+--S 441 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        14   n log(x) 28        13   n log(x) 27      2 12   n log(x) 26
+--R       c  (%e        )   + 14b c  (%e        )   + 91b c  (%e        )
+--R     + 
+--R           3 11   n log(x) 25        4 10   n log(x) 24        5 9   n log(x) 23
+--R       364b c  (%e        )   + 1001b c  (%e        )   + 2002b c (%e        )
+--R     + 
+--R            6 8   n log(x) 22        7 7   n log(x) 21        8 6   n log(x) 20
+--R       3003b c (%e        )   + 3432b c (%e        )   + 3003b c (%e        )
+--R     + 
+--R            9 5   n log(x) 19        10 4   n log(x) 18       11 3   n log(x) 17
+--R       2002b c (%e        )   + 1001b  c (%e        )   + 364b  c (%e        )
+--R     + 
+--R          12 2   n log(x) 16      13     n log(x) 15    14   n log(x) 14
+--R       91b  c (%e        )   + 14b  c (%e        )   + b  (%e        )
+--R     + 
+--R              14  n 14        13  n 13      2 12  n 12       3 11  n 11
+--R           - c  (x )   - 14b c  (x )   - 91b c  (x )   - 364b c  (x )
+--R         + 
+--R                  4 10  n 10        5 9  n 9        6 8  n 8        7 7  n 7
+--R           - 1001b c  (x )   - 2002b c (x )  - 3003b c (x )  - 3432b c (x )
+--R         + 
+--R                  8 6  n 6        9 5  n 5        10 4  n 4       11 3  n 3
+--R           - 3003b c (x )  - 2002b c (x )  - 1001b  c (x )  - 364b  c (x )
+--R         + 
+--R                12 2  n 2      13   n    14
+--R           - 91b  c (x )  - 14b  c x  - b
+--R      *
+--R          14n
+--R         x
+--R  /
+--R     14n
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         14   n log(x) 28        13   n log(x) 27       2 12   n log(x) 26
+--R       2c  (%e        )   + 27b c  (%e        )   + 169b c  (%e        )
+--R     + 
+--R           3 11   n log(x) 25        4 10   n log(x) 24        5 9   n log(x) 23
+--R       650b c  (%e        )   + 1716b c  (%e        )   + 3289b c (%e        )
+--R     + 
+--R            6 8   n log(x) 22        7 7   n log(x) 21        8 6   n log(x) 20
+--R       4719b c (%e        )   + 5148b c (%e        )   + 4290b c (%e        )
+--R     + 
+--R            9 5   n log(x) 19        10 4   n log(x) 18       11 3   n log(x) 17
+--R       2717b c (%e        )   + 1287b  c (%e        )   + 442b  c (%e        )
+--R     + 
+--R           12 2   n log(x) 16      13     n log(x) 15    14   n log(x) 14
+--R       104b  c (%e        )   + 15b  c (%e        )   + b  (%e        )
+--R     + 
+--R              14   n - 1  n 13        13   n - 1  n 12      2 12   n - 1  n 11
+--R           - c  x x     (x )   - 13b c  x x     (x )   - 78b c  x x     (x )
+--R         + 
+--R                 3 11   n - 1  n 10       4 10   n - 1  n 9
+--R           - 286b c  x x     (x )   - 715b c  x x     (x )
+--R         + 
+--R                  5 9   n - 1  n 8        6 8   n - 1  n 7
+--R           - 1287b c x x     (x )  - 1716b c x x     (x )
+--R         + 
+--R                  7 7   n - 1  n 6        8 6   n - 1  n 5
+--R           - 1716b c x x     (x )  - 1287b c x x     (x )
+--R         + 
+--R                 9 5   n - 1  n 4       10 4   n - 1  n 3      11 3   n - 1  n 2
+--R           - 715b c x x     (x )  - 286b  c x x     (x )  - 78b  c x x     (x )
+--R         + 
+--R                12 2   n - 1 n    13     n - 1
+--R           - 13b  c x x     x  - b  c x x
+--R      *
+--R          14n
+--R         x
+--R     + 
+--R              14    n 14        13    n 13      2 12    n 12       3 11    n 11
+--R           - c  x (x )   - 14b c  x (x )   - 91b c  x (x )   - 364b c  x (x )
+--R         + 
+--R                  4 10    n 10        5 9    n 9        6 8    n 8
+--R           - 1001b c  x (x )   - 2002b c x (x )  - 3003b c x (x )
+--R         + 
+--R                  7 7    n 7        8 6    n 6        9 5    n 5
+--R           - 3432b c x (x )  - 3003b c x (x )  - 2002b c x (x )
+--R         + 
+--R                  10 4    n 4       11 3    n 3      12 2    n 2      13     n
+--R           - 1001b  c x (x )  - 364b  c x (x )  - 91b  c x (x )  - 14b  c x x
+--R         + 
+--R              14
+--R           - b  x
+--R      *
+--R          14n - 1
+--R         x
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+)clear all
+
+--S 443 of 649
+t0:=(b+2*c*x)/(a+b*x+c*x^2)
+--R 
+--R
+--R           2c x + b
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 443
+
+--S 444 of 649
+r0:=log(a+b*x+c*x^2)
+--R 
+--R
+--R               2
+--R   (2)  log(c x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R   (3)  log(c x  + b x + a)
+--R                                         Type: Union(Expression(Integer),...)
+--E 445
+
+--S 446 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 649
+t0:=x*(b+2*c*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R              3
+--R          2c x  + b x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 448
+
+--S 449 of 649
+r0:=1/2*log(a+b*x^2+c*x^4)
+--R 
+--R
+--R               4      2
+--R        log(c x  + b x  + a)
+--R   (2)  --------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4      2
+--R        log(c x  + b x  + a)
+--R   (3)  --------------------
+--R                  2
+--R                                         Type: Union(Expression(Integer),...)
+--E 450
+
+--S 451 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 452
+
+)clear all
+
+--S 453 of 649
+t0:=x^2*(b+2*c*x^3)/(a+b*x^3+c*x^6)
+--R 
+--R
+--R              5      2
+--R          2c x  + b x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 453
+
+--S 454 of 649
+r0:=1/3*log(a+b*x^3+c*x^6)
+--R 
+--R
+--R               6      3
+--R        log(c x  + b x  + a)
+--R   (2)  --------------------
+--R                  3
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               6      3
+--R        log(c x  + b x  + a)
+--R   (3)  --------------------
+--R                  3
+--R                                         Type: Union(Expression(Integer),...)
+--E 455
+
+--S 456 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 457
+
+)clear all
+
+--S 458 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 1 n      n - 1
+--R        2c x     x  + b x
+--R   (1)  ----------------------
+--R              2n      n
+--R           c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 649
+r0:=log(a+b*x^n+c*x^(2*n))/n
+--R 
+--R
+--R               2n      n
+--R        log(c x   + b x  + a)
+--R   (2)  ---------------------
+--R                  n
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 n log(x) 2       n log(x)
+--R        log(c (%e        )  + b %e         + a)
+--R   (3)  ---------------------------------------
+--R                           n
+--R                                         Type: Union(Expression(Integer),...)
+--E 460
+
+--S 461 of 649
+m0:=a0-r0
+--R 
+--R
+--R                 n log(x) 2       n log(x)               2n      n
+--R        log(c (%e        )  + b %e         + a) - log(c x   + b x  + a)
+--R   (4)  ---------------------------------------------------------------
+--R                                       n
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R          2 2n     2   2n - 1         n          n - 1           n log(x) 2
+--R       (2c x   - 2c x x       + 2b c x  - b c x x      + 2a c)(%e        )
+--R     + 
+--R             2n           2n - 1    2 n    2   n - 1         n log(x)
+--R       (b c x   - 2b c x x       + b x  - b x x      + a b)%e
+--R     + 
+--R                 2n - 1          n - 1
+--R       - 2a c x x       - a b x x
+--R  /
+--R         2   2n          n            n log(x) 2
+--R       (c x x   + b c x x  + a c x)(%e        )
+--R     + 
+--R               2n    2   n           n log(x)          2n          n    2
+--R       (b c x x   + b x x  + a b x)%e         + a c x x   + a b x x  + a x
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 649
+t0:=(b+2*c*x)/(a+b*x+c*x^2)^8
+--R 
+--R
+--R   (1)
+--R     2c x + b
+--R  /
+--R        8 16       7 15        7      2 6  14           6      3 5  13
+--R       c x   + 8b c x   + (8a c  + 28b c )x   + (56a b c  + 56b c )x
+--R     + 
+--R           2 6         2 5      4 4  12        2   5         3 4      5 3  11
+--R       (28a c  + 168a b c  + 70b c )x   + (168a b c  + 280a b c  + 56b c )x
+--R     + 
+--R           3 5       2 2 4         4 3      6 2  10
+--R       (56a c  + 420a b c  + 280a b c  + 28b c )x
+--R     + 
+--R            3   4       2 3 3         5 2     7   9
+--R       (280a b c  + 560a b c  + 168a b c  + 8b c)x
+--R     + 
+--R           4 4       3 2 3       2 4 2        6     8  8
+--R       (70a c  + 560a b c  + 420a b c  + 56a b c + b )x
+--R     + 
+--R            4   3       3 3 2       2 5        7  7
+--R       (280a b c  + 560a b c  + 168a b c + 8a b )x
+--R     + 
+--R           5 3       4 2 2       3 4       2 6  6
+--R       (56a c  + 420a b c  + 280a b c + 28a b )x
+--R     + 
+--R            5   2       4 3       3 5  5       6 2       5 2       4 4  4
+--R       (168a b c  + 280a b c + 56a b )x  + (28a c  + 168a b c + 70a b )x
+--R     + 
+--R           6         5 3  3      7       6 2  2     7       8
+--R       (56a b c + 56a b )x  + (8a c + 28a b )x  + 8a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 463
+
+--S 464 of 649
+r0:=(-1/7)/(a+b*x+c*x^2)^7
+--R 
+--R
+--R   (2)
+--R   -
+--R        1
+--R        -
+--R        7
+--R     /
+--R           7 14       6 13        6      2 5  12           5      3 4  11
+--R          c x   + 7b c x   + (7a c  + 21b c )x   + (42a b c  + 35b c )x
+--R        + 
+--R              2 5         2 4      4 3  10        2   4         3 3      5 2  9
+--R          (21a c  + 105a b c  + 35b c )x   + (105a b c  + 140a b c  + 21b c )x
+--R        + 
+--R              3 4       2 2 3         4 2     6   8
+--R          (35a c  + 210a b c  + 105a b c  + 7b c)x
+--R        + 
+--R               3   3       2 3 2        5     7  7
+--R          (140a b c  + 210a b c  + 42a b c + b )x
+--R        + 
+--R              4 3       3 2 2       2 4        6  6
+--R          (35a c  + 210a b c  + 105a b c + 7a b )x
+--R        + 
+--R               4   2       3 3       2 5  5       5 2       4 2       3 4  4
+--R          (105a b c  + 140a b c + 21a b )x  + (21a c  + 105a b c + 35a b )x
+--R        + 
+--R              5         4 3  3      6       5 2  2     6       7
+--R          (42a b c + 35a b )x  + (7a c + 21a b )x  + 7a b x + a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 464
+
+--S 465 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R            7 14        6 13         6       2 5  12            5       3 4  11
+--R          7c x   + 49b c x   + (49a c  + 147b c )x   + (294a b c  + 245b c )x
+--R        + 
+--R               2 5         2 4       4 3  10
+--R          (147a c  + 735a b c  + 245b c )x
+--R        + 
+--R               2   4         3 3       5 2  9
+--R          (735a b c  + 980a b c  + 147b c )x
+--R        + 
+--R               3 4        2 2 3         4 2      6   8
+--R          (245a c  + 1470a b c  + 735a b c  + 49b c)x
+--R        + 
+--R               3   3        2 3 2         5      7  7
+--R          (980a b c  + 1470a b c  + 294a b c + 7b )x
+--R        + 
+--R               4 3        3 2 2       2 4         6  6
+--R          (245a c  + 1470a b c  + 735a b c + 49a b )x
+--R        + 
+--R               4   2       3 3        2 5  5        5 2       4 2        3 4  4
+--R          (735a b c  + 980a b c + 147a b )x  + (147a c  + 735a b c + 245a b )x
+--R        + 
+--R               5          4 3  3       6        5 2  2      6        7
+--R          (294a b c + 245a b )x  + (49a c + 147a b )x  + 49a b x + 7a
+--R                                         Type: Union(Expression(Integer),...)
+--E 465
+
+--S 466 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 467
+
+)clear all
+
+--S 468 of 649
+t0:=x*(b+2*c*x^2)/(a+b*x^2+c*x^4)^8
+--R 
+--R
+--R   (1)
+--R         3
+--R     2c x  + b x
+--R  /
+--R        8 32       7 30        7      2 6  28           6      3 5  26
+--R       c x   + 8b c x   + (8a c  + 28b c )x   + (56a b c  + 56b c )x
+--R     + 
+--R           2 6         2 5      4 4  24        2   5         3 4      5 3  22
+--R       (28a c  + 168a b c  + 70b c )x   + (168a b c  + 280a b c  + 56b c )x
+--R     + 
+--R           3 5       2 2 4         4 3      6 2  20
+--R       (56a c  + 420a b c  + 280a b c  + 28b c )x
+--R     + 
+--R            3   4       2 3 3         5 2     7   18
+--R       (280a b c  + 560a b c  + 168a b c  + 8b c)x
+--R     + 
+--R           4 4       3 2 3       2 4 2        6     8  16
+--R       (70a c  + 560a b c  + 420a b c  + 56a b c + b )x
+--R     + 
+--R            4   3       3 3 2       2 5        7  14
+--R       (280a b c  + 560a b c  + 168a b c + 8a b )x
+--R     + 
+--R           5 3       4 2 2       3 4       2 6  12
+--R       (56a c  + 420a b c  + 280a b c + 28a b )x
+--R     + 
+--R            5   2       4 3       3 5  10       6 2       5 2       4 4  8
+--R       (168a b c  + 280a b c + 56a b )x   + (28a c  + 168a b c + 70a b )x
+--R     + 
+--R           6         5 3  6      7       6 2  4     7   2    8
+--R       (56a b c + 56a b )x  + (8a c + 28a b )x  + 8a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 468
+
+--S 469 of 649
+r0:=(-1/14)/(a+b*x^2+c*x^4)^7
+--R 
+--R
+--R   (2)
+--R   -
+--R         1
+--R        --
+--R        14
+--R     /
+--R           7 28       6 26        6      2 5  24           5      3 4  22
+--R          c x   + 7b c x   + (7a c  + 21b c )x   + (42a b c  + 35b c )x
+--R        + 
+--R              2 5         2 4      4 3  20        2   4         3 3      5 2  18
+--R          (21a c  + 105a b c  + 35b c )x   + (105a b c  + 140a b c  + 21b c )x
+--R        + 
+--R              3 4       2 2 3         4 2     6   16
+--R          (35a c  + 210a b c  + 105a b c  + 7b c)x
+--R        + 
+--R               3   3       2 3 2        5     7  14
+--R          (140a b c  + 210a b c  + 42a b c + b )x
+--R        + 
+--R              4 3       3 2 2       2 4        6  12
+--R          (35a c  + 210a b c  + 105a b c + 7a b )x
+--R        + 
+--R               4   2       3 3       2 5  10       5 2       4 2       3 4  8
+--R          (105a b c  + 140a b c + 21a b )x   + (21a c  + 105a b c + 35a b )x
+--R        + 
+--R              5         4 3  6      6       5 2  4     6   2    7
+--R          (42a b c + 35a b )x  + (7a c + 21a b )x  + 7a b x  + a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 469
+
+--S 470 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R             7 28        6 26         6       2 5  24            5       3 4  22
+--R          14c x   + 98b c x   + (98a c  + 294b c )x   + (588a b c  + 490b c )x
+--R        + 
+--R               2 5          2 4       4 3  20
+--R          (294a c  + 1470a b c  + 490b c )x
+--R        + 
+--R                2   4          3 3       5 2  18
+--R          (1470a b c  + 1960a b c  + 294b c )x
+--R        + 
+--R               3 4        2 2 3          4 2      6   16
+--R          (490a c  + 2940a b c  + 1470a b c  + 98b c)x
+--R        + 
+--R                3   3        2 3 2         5       7  14
+--R          (1960a b c  + 2940a b c  + 588a b c + 14b )x
+--R        + 
+--R               4 3        3 2 2        2 4         6  12
+--R          (490a c  + 2940a b c  + 1470a b c + 98a b )x
+--R        + 
+--R                4   2        3 3        2 5  10
+--R          (1470a b c  + 1960a b c + 294a b )x
+--R        + 
+--R               5 2        4 2        3 4  8        5          4 3  6
+--R          (294a c  + 1470a b c + 490a b )x  + (588a b c + 490a b )x
+--R        + 
+--R              6        5 2  4      6   2      7
+--R          (98a c + 294a b )x  + 98a b x  + 14a
+--R                                         Type: Union(Expression(Integer),...)
+--E 470
+
+--S 471 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 472
+
+)clear all
+
+--S 473 of 649
+t0:=x^2*(b+2*c*x^3)/(a+b*x^3+c*x^6)^8
+--R 
+--R
+--R   (1)
+--R         5      2
+--R     2c x  + b x
+--R  /
+--R        8 48       7 45        7      2 6  42           6      3 5  39
+--R       c x   + 8b c x   + (8a c  + 28b c )x   + (56a b c  + 56b c )x
+--R     + 
+--R           2 6         2 5      4 4  36        2   5         3 4      5 3  33
+--R       (28a c  + 168a b c  + 70b c )x   + (168a b c  + 280a b c  + 56b c )x
+--R     + 
+--R           3 5       2 2 4         4 3      6 2  30
+--R       (56a c  + 420a b c  + 280a b c  + 28b c )x
+--R     + 
+--R            3   4       2 3 3         5 2     7   27
+--R       (280a b c  + 560a b c  + 168a b c  + 8b c)x
+--R     + 
+--R           4 4       3 2 3       2 4 2        6     8  24
+--R       (70a c  + 560a b c  + 420a b c  + 56a b c + b )x
+--R     + 
+--R            4   3       3 3 2       2 5        7  21
+--R       (280a b c  + 560a b c  + 168a b c + 8a b )x
+--R     + 
+--R           5 3       4 2 2       3 4       2 6  18
+--R       (56a c  + 420a b c  + 280a b c + 28a b )x
+--R     + 
+--R            5   2       4 3       3 5  15       6 2       5 2       4 4  12
+--R       (168a b c  + 280a b c + 56a b )x   + (28a c  + 168a b c + 70a b )x
+--R     + 
+--R           6         5 3  9      7       6 2  6     7   3    8
+--R       (56a b c + 56a b )x  + (8a c + 28a b )x  + 8a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 473
+
+--S 474 of 649
+r0:=(-1/21)/(a+b*x^3+c*x^6)^7
+--R 
+--R
+--R   (2)
+--R   -
+--R         1
+--R        --
+--R        21
+--R     /
+--R           7 42       6 39        6      2 5  36           5      3 4  33
+--R          c x   + 7b c x   + (7a c  + 21b c )x   + (42a b c  + 35b c )x
+--R        + 
+--R              2 5         2 4      4 3  30        2   4         3 3      5 2  27
+--R          (21a c  + 105a b c  + 35b c )x   + (105a b c  + 140a b c  + 21b c )x
+--R        + 
+--R              3 4       2 2 3         4 2     6   24
+--R          (35a c  + 210a b c  + 105a b c  + 7b c)x
+--R        + 
+--R               3   3       2 3 2        5     7  21
+--R          (140a b c  + 210a b c  + 42a b c + b )x
+--R        + 
+--R              4 3       3 2 2       2 4        6  18
+--R          (35a c  + 210a b c  + 105a b c + 7a b )x
+--R        + 
+--R               4   2       3 3       2 5  15       5 2       4 2       3 4  12
+--R          (105a b c  + 140a b c + 21a b )x   + (21a c  + 105a b c + 35a b )x
+--R        + 
+--R              5         4 3  9      6       5 2  6     6   3    7
+--R          (42a b c + 35a b )x  + (7a c + 21a b )x  + 7a b x  + a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 474
+
+--S 475 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R             7 42         6 39          6       2 5  36
+--R          21c x   + 147b c x   + (147a c  + 441b c )x
+--R        + 
+--R                   5       3 4  33        2 5          2 4       4 3  30
+--R          (882a b c  + 735b c )x   + (441a c  + 2205a b c  + 735b c )x
+--R        + 
+--R                2   4          3 3       5 2  27
+--R          (2205a b c  + 2940a b c  + 441b c )x
+--R        + 
+--R               3 4        2 2 3          4 2       6   24
+--R          (735a c  + 4410a b c  + 2205a b c  + 147b c)x
+--R        + 
+--R                3   3        2 3 2         5       7  21
+--R          (2940a b c  + 4410a b c  + 882a b c + 21b )x
+--R        + 
+--R               4 3        3 2 2        2 4          6  18
+--R          (735a c  + 4410a b c  + 2205a b c + 147a b )x
+--R        + 
+--R                4   2        3 3        2 5  15
+--R          (2205a b c  + 2940a b c + 441a b )x
+--R        + 
+--R               5 2        4 2        3 4  12        5          4 3  9
+--R          (441a c  + 2205a b c + 735a b )x   + (882a b c + 735a b )x
+--R        + 
+--R               6        5 2  6       6   3      7
+--R          (147a c + 441a b )x  + 147a b x  + 21a
+--R                                         Type: Union(Expression(Integer),...)
+--E 475
+
+--S 476 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)/(a+b*x^n+c*x^(2*n))^8
+--R 
+--R
+--R   (1)
+--R         n - 1 n      n - 1
+--R     2c x     x  + b x
+--R  /
+--R        8  2n 8        7 n       7   2n 7
+--R       c (x  )  + (8b c x  + 8a c )(x  )
+--R     + 
+--R           2 6  n 2          6 n      2 6   2n 6
+--R       (28b c (x )  + 56a b c x  + 28a c )(x  )
+--R     + 
+--R           3 5  n 3         2 5  n 2       2   5 n      3 5   2n 5
+--R       (56b c (x )  + 168a b c (x )  + 168a b c x  + 56a c )(x  )
+--R     + 
+--R             4 4  n 4         3 4  n 3       2 2 4  n 2       3   4 n      4 4
+--R         (70b c (x )  + 280a b c (x )  + 420a b c (x )  + 280a b c x  + 70a c )
+--R      *
+--R           2n 4
+--R         (x  )
+--R     + 
+--R              5 3  n 5         4 3  n 4       2 3 3  n 3       3 2 3  n 2
+--R           56b c (x )  + 280a b c (x )  + 560a b c (x )  + 560a b c (x )
+--R         + 
+--R               4   3 n      5 3
+--R           280a b c x  + 56a c
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R              6 2  n 6         5 2  n 5       2 4 2  n 4       3 3 2  n 3
+--R           28b c (x )  + 168a b c (x )  + 420a b c (x )  + 560a b c (x )
+--R         + 
+--R               4 2 2  n 2       5   2 n      6 2
+--R           420a b c (x )  + 168a b c x  + 28a c
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R             7    n 7        6    n 6       2 5    n 5       3 4    n 4
+--R           8b c (x )  + 56a b c (x )  + 168a b c (x )  + 280a b c (x )
+--R         + 
+--R               4 3    n 3       5 2    n 2      6     n     7
+--R           280a b c (x )  + 168a b c (x )  + 56a b c x  + 8a c
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R        8  n 8       7  n 7      2 6  n 6      3 5  n 5      4 4  n 4
+--R       b (x )  + 8a b (x )  + 28a b (x )  + 56a b (x )  + 70a b (x )
+--R     + 
+--R          5 3  n 3      6 2  n 2     7   n    8
+--R       56a b (x )  + 28a b (x )  + 8a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 649
+r0:=(-1/7)/(n*(a+b*x^n+c*x^(2*n))^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R        1
+--R     /
+--R            7    2n 7         6   n        6    2n 6
+--R          7c n (x  )  + (49b c n x  + 49a c n)(x  )
+--R        + 
+--R               2 5    n 2           5   n       2 5    2n 5
+--R          (147b c n (x )  + 294a b c n x  + 147a c n)(x  )
+--R        + 
+--R               3 4    n 3         2 4    n 2       2   4   n       3 4    2n 4
+--R          (245b c n (x )  + 735a b c n (x )  + 735a b c n x  + 245a c n)(x  )
+--R        + 
+--R                  4 3    n 4         3 3    n 3        2 2 3    n 2
+--R              245b c n (x )  + 980a b c n (x )  + 1470a b c n (x )
+--R            + 
+--R                  3   3   n       4 3
+--R              980a b c n x  + 245a c n
+--R         *
+--R              2n 3
+--R            (x  )
+--R        + 
+--R                  5 2    n 5         4 2    n 4        2 3 2    n 3
+--R              147b c n (x )  + 735a b c n (x )  + 1470a b c n (x )
+--R            + 
+--R                   3 2 2    n 2       4   2   n       5 2
+--R              1470a b c n (x )  + 735a b c n x  + 147a c n
+--R         *
+--R              2n 2
+--R            (x  )
+--R        + 
+--R                 6      n 6         5      n 5       2 4      n 4
+--R              49b c n (x )  + 294a b c n (x )  + 735a b c n (x )
+--R            + 
+--R                  3 3      n 3       4 2      n 2       5       n      6
+--R              980a b c n (x )  + 735a b c n (x )  + 294a b c n x  + 49a c n
+--R         *
+--R             2n
+--R            x
+--R        + 
+--R            7    n 7        6    n 6       2 5    n 5       3 4    n 4
+--R          7b n (x )  + 49a b n (x )  + 147a b n (x )  + 245a b n (x )
+--R        + 
+--R              4 3    n 3       5 2    n 2      6     n     7
+--R          245a b n (x )  + 147a b n (x )  + 49a b n x  + 7a n
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R            7     n log(x) 14        6     n log(x) 13
+--R          7c n (%e        )   + 49b c n (%e        )
+--R        + 
+--R                6       2 5      n log(x) 12
+--R          (49a c  + 147b c )n (%e        )
+--R        + 
+--R                   5       3 4      n log(x) 11
+--R          (294a b c  + 245b c )n (%e        )
+--R        + 
+--R               2 5         2 4       4 3      n log(x) 10
+--R          (147a c  + 735a b c  + 245b c )n (%e        )
+--R        + 
+--R               2   4         3 3       5 2      n log(x) 9
+--R          (735a b c  + 980a b c  + 147b c )n (%e        )
+--R        + 
+--R               3 4        2 2 3         4 2      6       n log(x) 8
+--R          (245a c  + 1470a b c  + 735a b c  + 49b c)n (%e        )
+--R        + 
+--R               3   3        2 3 2         5      7      n log(x) 7
+--R          (980a b c  + 1470a b c  + 294a b c + 7b )n (%e        )
+--R        + 
+--R               4 3        3 2 2       2 4         6      n log(x) 6
+--R          (245a c  + 1470a b c  + 735a b c + 49a b )n (%e        )
+--R        + 
+--R               4   2       3 3        2 5      n log(x) 5
+--R          (735a b c  + 980a b c + 147a b )n (%e        )
+--R        + 
+--R               5 2       4 2        3 4      n log(x) 4
+--R          (147a c  + 735a b c + 245a b )n (%e        )
+--R        + 
+--R               5          4 3      n log(x) 3       6        5 2      n log(x) 2
+--R          (294a b c + 245a b )n (%e        )  + (49a c + 147a b )n (%e        )
+--R        + 
+--R             6      n log(x)     7
+--R          49a b n %e         + 7a n
+--R                                         Type: Union(Expression(Integer),...)
+--E 480
+
+--S 481 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        7   n log(x) 14       6   n log(x) 13        6      2 5    n log(x) 12
+--R       c (%e        )   + 7b c (%e        )   + (7a c  + 21b c )(%e        )
+--R     + 
+--R               5      3 4    n log(x) 11
+--R       (42a b c  + 35b c )(%e        )
+--R     + 
+--R           2 5         2 4      4 3    n log(x) 10
+--R       (21a c  + 105a b c  + 35b c )(%e        )
+--R     + 
+--R            2   4         3 3      5 2    n log(x) 9
+--R       (105a b c  + 140a b c  + 21b c )(%e        )
+--R     + 
+--R           3 4       2 2 3         4 2     6     n log(x) 8
+--R       (35a c  + 210a b c  + 105a b c  + 7b c)(%e        )
+--R     + 
+--R            3   3       2 3 2        5     7    n log(x) 7
+--R       (140a b c  + 210a b c  + 42a b c + b )(%e        )
+--R     + 
+--R           4 3       3 2 2       2 4        6    n log(x) 6
+--R       (35a c  + 210a b c  + 105a b c + 7a b )(%e        )
+--R     + 
+--R            4   2       3 3       2 5    n log(x) 5
+--R       (105a b c  + 140a b c + 21a b )(%e        )
+--R     + 
+--R           5 2       4 2       3 4    n log(x) 4
+--R       (21a c  + 105a b c + 35a b )(%e        )
+--R     + 
+--R           5         4 3    n log(x) 3      6       5 2    n log(x) 2
+--R       (42a b c + 35a b )(%e        )  + (7a c + 21a b )(%e        )
+--R     + 
+--R         6    n log(x)    7  2n 7          6 n       6   2n 6
+--R       7a b %e         - c (x  )  + (- 7b c x  - 7a c )(x  )
+--R     + 
+--R             2 5  n 2          5 n      2 5   2n 5
+--R       (- 21b c (x )  - 42a b c x  - 21a c )(x  )
+--R     + 
+--R             3 4  n 3         2 4  n 2       2   4 n      3 4   2n 4
+--R       (- 35b c (x )  - 105a b c (x )  - 105a b c x  - 35a c )(x  )
+--R     + 
+--R                  4 3  n 4         3 3  n 3       2 2 3  n 2       3   3 n
+--R             - 35b c (x )  - 140a b c (x )  - 210a b c (x )  - 140a b c x
+--R           + 
+--R                  4 3
+--R             - 35a c
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R                5 2  n 5         4 2  n 4       2 3 2  n 3       3 2 2  n 2
+--R           - 21b c (x )  - 105a b c (x )  - 210a b c (x )  - 210a b c (x )
+--R         + 
+--R                 4   2 n      5 2
+--R           - 105a b c x  - 21a c
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R               6    n 6        5    n 5       2 4    n 4       3 3    n 3
+--R           - 7b c (x )  - 42a b c (x )  - 105a b c (x )  - 140a b c (x )
+--R         + 
+--R                 4 2    n 2      5     n     6
+--R           - 105a b c (x )  - 42a b c x  - 7a c
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R          7  n 7       6  n 6      2 5  n 5      3 4  n 4      4 3  n 3
+--R       - b (x )  - 7a b (x )  - 21a b (x )  - 35a b (x )  - 35a b (x )
+--R     + 
+--R            5 2  n 2     6   n
+--R       - 21a b (x )  - 7a b x
+--R  /
+--R             14    2n 7         13   n        13    2n 6
+--R           7c  n (x  )  + (49b c  n x  + 49a c  n)(x  )
+--R         + 
+--R                2 12    n 2           12   n       2 12    2n 5
+--R           (147b c  n (x )  + 294a b c  n x  + 147a c  n)(x  )
+--R         + 
+--R                  3 11    n 3         2 11    n 2       2   11   n       3 11
+--R             (245b c  n (x )  + 735a b c  n (x )  + 735a b c  n x  + 245a c  n)
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                   4 10    n 4         3 10    n 3        2 2 10    n 2
+--R               245b c  n (x )  + 980a b c  n (x )  + 1470a b c  n (x )
+--R             + 
+--R                   3   10   n       4 10
+--R               980a b c  n x  + 245a c  n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                   5 9    n 5         4 9    n 4        2 3 9    n 3
+--R               147b c n (x )  + 735a b c n (x )  + 1470a b c n (x )
+--R             + 
+--R                    3 2 9    n 2       4   9   n       5 9
+--R               1470a b c n (x )  + 735a b c n x  + 147a c n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                  6 8    n 6         5 8    n 5       2 4 8    n 4
+--R               49b c n (x )  + 294a b c n (x )  + 735a b c n (x )
+--R             + 
+--R                   3 3 8    n 3       4 2 8    n 2       5   8   n      6 8
+--R               980a b c n (x )  + 735a b c n (x )  + 294a b c n x  + 49a c n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R             7 7    n 7        6 7    n 6       2 5 7    n 5       3 4 7    n 4
+--R           7b c n (x )  + 49a b c n (x )  + 147a b c n (x )  + 245a b c n (x )
+--R         + 
+--R               4 3 7    n 3       5 2 7    n 2      6   7   n     7 7
+--R           245a b c n (x )  + 147a b c n (x )  + 49a b c n x  + 7a c n
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                13    2n 7        2 12   n           12    2n 6
+--R           49b c  n (x  )  + (343b c  n x  + 343a b c  n)(x  )
+--R         + 
+--R                 3 11    n 2          2 11   n        2   11    2n 5
+--R           (1029b c  n (x )  + 2058a b c  n x  + 1029a b c  n)(x  )
+--R         + 
+--R                    4 10    n 3          3 10    n 2        2 2 10   n
+--R               1715b c  n (x )  + 5145a b c  n (x )  + 5145a b c  n x
+--R             + 
+--R                    3   10
+--R               1715a b c  n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                    5 9    n 4          4 9    n 3         2 3 9    n 2
+--R               1715b c n (x )  + 6860a b c n (x )  + 10290a b c n (x )
+--R             + 
+--R                    3 2 9   n        4   9
+--R               6860a b c n x  + 1715a b c n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                    6 8    n 5          5 8    n 4         2 4 8    n 3
+--R               1029b c n (x )  + 5145a b c n (x )  + 10290a b c n (x )
+--R             + 
+--R                     3 3 8    n 2        4 2 8   n        5   8
+--R               10290a b c n (x )  + 5145a b c n x  + 1029a b c n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                   7 7    n 6          6 7    n 5        2 5 7    n 4
+--R               343b c n (x )  + 2058a b c n (x )  + 5145a b c n (x )
+--R             + 
+--R                  3 4 7    n 3        4 3 7    n 2        5 2 7   n       6   7
+--R             6860a b c n (x )  + 5145a b c n (x )  + 2058a b c n x  + 343a b c n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R              8 6    n 7         7 6    n 6        2 6 6    n 5
+--R           49b c n (x )  + 343a b c n (x )  + 1029a b c n (x )
+--R         + 
+--R                3 5 6    n 4        4 4 6    n 3        5 3 6    n 2
+--R           1715a b c n (x )  + 1715a b c n (x )  + 1029a b c n (x )
+--R         + 
+--R               6 2 6   n      7   6
+--R           343a b c n x  + 49a b c n
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R                 13       2 12     2n 7
+--R           (49a c   + 147b c  )n (x  )
+--R         + 
+--R                     12        3 11    n        2 12          2 11     2n 6
+--R           ((343a b c   + 1029b c  )n x  + (343a c   + 1029a b c  )n)(x  )
+--R         + 
+--R                       2 11        4 10     n 2
+--R               (1029a b c   + 3087b c  )n (x )
+--R             + 
+--R                     2   11          3 10    n         3 11        2 2 10
+--R               (2058a b c   + 6174a b c  )n x  + (1029a c   + 3087a b c  )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                       3 10        5 9     n 3
+--R               (1715a b c   + 5145b c )n (x )
+--R             + 
+--R                     2 2 10           4 9     n 2
+--R               (5145a b c   + 15435a b c )n (x )
+--R             + 
+--R                     3   10         2 3 9    n         4 10        3 2 9
+--R               (5145a b c   + 15435a b c )n x  + (1715a c   + 5145a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                       4 9        6 8     n 4
+--R               (1715a b c  + 5145b c )n (x )
+--R             + 
+--R                     2 3 9           5 8     n 3
+--R               (6860a b c  + 20580a b c )n (x )
+--R             + 
+--R                      3 2 9         2 4 8     n 2
+--R               (10290a b c  + 30870a b c )n (x )
+--R             + 
+--R                     4   9         3 3 8    n         5 9        4 2 8
+--R               (6860a b c  + 20580a b c )n x  + (1715a c  + 5145a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                       5 8        7 7     n 5
+--R               (1029a b c  + 3087b c )n (x )
+--R             + 
+--R                     2 4 8           6 7     n 4
+--R               (5145a b c  + 15435a b c )n (x )
+--R             + 
+--R                      3 3 8         2 5 7     n 3
+--R               (10290a b c  + 30870a b c )n (x )
+--R             + 
+--R                      4 2 8         3 4 7     n 2
+--R               (10290a b c  + 30870a b c )n (x )
+--R             + 
+--R                     5   8         4 3 7    n         6 8        5 2 7
+--R               (5145a b c  + 15435a b c )n x  + (1029a c  + 3087a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                      6 7        8 6     n 6         2 5 7          7 6     n 5
+--R               (343a b c  + 1029b c )n (x )  + (2058a b c  + 6174a b c )n (x )
+--R             + 
+--R                     3 4 7         2 6 6     n 4
+--R               (5145a b c  + 15435a b c )n (x )
+--R             + 
+--R                     4 3 7         3 5 6     n 3
+--R               (6860a b c  + 20580a b c )n (x )
+--R             + 
+--R                     5 2 7         4 4 6     n 2         6   7        5 3 6    n
+--R               (5145a b c  + 15435a b c )n (x )  + (2058a b c  + 6174a b c )n x
+--R             + 
+--R                    7 7        6 2 6
+--R               (343a c  + 1029a b c )n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                 7 6       9 5     n 7        2 6 6          8 5     n 6
+--R           (49a b c  + 147b c )n (x )  + (343a b c  + 1029a b c )n (x )
+--R         + 
+--R                 3 5 6        2 7 5     n 5         4 4 6        3 6 5     n 4
+--R           (1029a b c  + 3087a b c )n (x )  + (1715a b c  + 5145a b c )n (x )
+--R         + 
+--R                 5 3 6        4 5 5     n 3         6 2 6        5 4 5     n 2
+--R           (1715a b c  + 5145a b c )n (x )  + (1029a b c  + 3087a b c )n (x )
+--R         + 
+--R                7   6        6 3 5    n       8 6       7 2 5
+--R           (343a b c  + 1029a b c )n x  + (49a c  + 147a b c )n
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                    12       3 11     2n 7
+--R           (294a b c   + 245b c  )n (x  )
+--R         + 
+--R                    2 11        4 10    n         2   11          3 10     2n 6
+--R           ((2058a b c   + 1715b c  )n x  + (2058a b c   + 1715a b c  )n)(x  )
+--R         + 
+--R                       3 10        5 9     n 2
+--R               (6174a b c   + 5145b c )n (x )
+--R             + 
+--R                      2 2 10           4 9    n         3   10        2 3 9
+--R               (12348a b c   + 10290a b c )n x  + (6174a b c   + 5145a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                        4 9        6 8     n 3
+--R               (10290a b c  + 8575b c )n (x )
+--R             + 
+--R                      2 3 9           5 8     n 2
+--R               (30870a b c  + 25725a b c )n (x )
+--R             + 
+--R                      3 2 9         2 4 8    n          4   9        3 3 8
+--R               (30870a b c  + 25725a b c )n x  + (10290a b c  + 8575a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                        5 8        7 7     n 4
+--R               (10290a b c  + 8575b c )n (x )
+--R             + 
+--R                      2 4 8           6 7     n 3
+--R               (41160a b c  + 34300a b c )n (x )
+--R             + 
+--R                      3 3 8         2 5 7     n 2
+--R               (61740a b c  + 51450a b c )n (x )
+--R             + 
+--R                      4 2 8         3 4 7    n          5   8        4 3 7
+--R               (41160a b c  + 34300a b c )n x  + (10290a b c  + 8575a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                       6 7        8 6     n 5
+--R               (6174a b c  + 5145b c )n (x )
+--R             + 
+--R                      2 5 7           7 6     n 4
+--R               (30870a b c  + 25725a b c )n (x )
+--R             + 
+--R                      3 4 7         2 6 6     n 3
+--R               (61740a b c  + 51450a b c )n (x )
+--R             + 
+--R                      4 3 7         3 5 6     n 2
+--R               (61740a b c  + 51450a b c )n (x )
+--R             + 
+--R                      5 2 7         4 4 6    n         6   7        5 3 6
+--R               (30870a b c  + 25725a b c )n x  + (6174a b c  + 5145a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                       7 6        9 5     n 6
+--R               (2058a b c  + 1715b c )n (x )
+--R             + 
+--R                      2 6 6           8 5     n 5
+--R               (12348a b c  + 10290a b c )n (x )
+--R             + 
+--R                      3 5 6         2 7 5     n 4
+--R               (30870a b c  + 25725a b c )n (x )
+--R             + 
+--R                      4 4 6         3 6 5     n 3
+--R               (41160a b c  + 34300a b c )n (x )
+--R             + 
+--R                      5 3 6         4 5 5     n 2
+--R               (30870a b c  + 25725a b c )n (x )
+--R             + 
+--R                      6 2 6         5 4 5    n         7   6        6 3 5
+--R               (12348a b c  + 10290a b c )n x  + (2058a b c  + 1715a b c )n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                  8 5       10 4     n 7         2 7 5          9 4     n 6
+--R           (294a b c  + 245b  c )n (x )  + (2058a b c  + 1715a b c )n (x )
+--R         + 
+--R                 3 6 5        2 8 4     n 5          4 5 5        3 7 4     n 4
+--R           (6174a b c  + 5145a b c )n (x )  + (10290a b c  + 8575a b c )n (x )
+--R         + 
+--R                  5 4 5        4 6 4     n 3         6 3 5        5 5 4     n 2
+--R           (10290a b c  + 8575a b c )n (x )  + (6174a b c  + 5145a b c )n (x )
+--R         + 
+--R                 7 2 5        6 4 4    n        8   5       7 3 4
+--R           (2058a b c  + 1715a b c )n x  + (294a b c  + 245a b c )n
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                2 12         2 11       4 10     2n 7
+--R           (147a c   + 735a b c   + 245b c  )n (x  )
+--R         + 
+--R                     2   11          3 10        5 9    n
+--R               (1029a b c   + 5145a b c   + 1715b c )n x
+--R             + 
+--R                     3 11        2 2 10          4 9
+--R               (1029a c   + 5145a b c   + 1715a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     2 2 10           4 9        6 8     n 2
+--R               (3087a b c   + 15435a b c  + 5145b c )n (x )
+--R             + 
+--R                     3   10         2 3 9           5 8    n
+--R               (6174a b c   + 30870a b c  + 10290a b c )n x
+--R             + 
+--R                     4 10         3 2 9        2 4 8
+--R               (3087a c   + 15435a b c  + 5145a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     2 3 9           5 8        7 7     n 3
+--R               (5145a b c  + 25725a b c  + 8575b c )n (x )
+--R             + 
+--R                      3 2 9         2 4 8           6 7     n 2
+--R               (15435a b c  + 77175a b c  + 25725a b c )n (x )
+--R             + 
+--R                      4   9         3 3 8         2 5 7    n
+--R               (15435a b c  + 77175a b c  + 25725a b c )n x
+--R             + 
+--R                     5 9         4 2 8        3 4 7
+--R               (5145a c  + 25725a b c  + 8575a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     2 4 8           6 7        8 6     n 4
+--R               (5145a b c  + 25725a b c  + 8575b c )n (x )
+--R             + 
+--R                      3 3 8          2 5 7           7 6     n 3
+--R               (20580a b c  + 102900a b c  + 34300a b c )n (x )
+--R             + 
+--R                      4 2 8          3 4 7         2 6 6     n 2
+--R               (30870a b c  + 154350a b c  + 51450a b c )n (x )
+--R             + 
+--R                      5   8          4 3 7         3 5 6    n
+--R               (20580a b c  + 102900a b c  + 34300a b c )n x
+--R             + 
+--R                     6 8         5 2 7        4 4 6
+--R               (5145a c  + 25725a b c  + 8575a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     2 5 7           7 6        9 5     n 5
+--R               (3087a b c  + 15435a b c  + 5145b c )n (x )
+--R             + 
+--R                      3 4 7         2 6 6           8 5     n 4
+--R               (15435a b c  + 77175a b c  + 25725a b c )n (x )
+--R             + 
+--R                      4 3 7          3 5 6         2 7 5     n 3
+--R               (30870a b c  + 154350a b c  + 51450a b c )n (x )
+--R             + 
+--R                      5 2 7          4 4 6         3 6 5     n 2
+--R               (30870a b c  + 154350a b c  + 51450a b c )n (x )
+--R             + 
+--R                      6   7         5 3 6         4 5 5    n
+--R               (15435a b c  + 77175a b c  + 25725a b c )n x
+--R             + 
+--R                     7 7         6 2 6        5 4 5
+--R               (3087a c  + 15435a b c  + 5145a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     2 6 6          8 5        10 4     n 6
+--R               (1029a b c  + 5145a b c  + 1715b  c )n (x )
+--R             + 
+--R                     3 5 6         2 7 5           9 4     n 5
+--R               (6174a b c  + 30870a b c  + 10290a b c )n (x )
+--R             + 
+--R                      4 4 6         3 6 5         2 8 4     n 4
+--R               (15435a b c  + 77175a b c  + 25725a b c )n (x )
+--R             + 
+--R                      5 3 6          4 5 5         3 7 4     n 3
+--R               (20580a b c  + 102900a b c  + 34300a b c )n (x )
+--R             + 
+--R                      6 2 6         5 4 5         4 6 4     n 2
+--R               (15435a b c  + 77175a b c  + 25725a b c )n (x )
+--R             + 
+--R                     7   6         6 3 5         5 5 4    n
+--R               (6174a b c  + 30870a b c  + 10290a b c )n x
+--R             + 
+--R                     8 6        7 2 5        6 4 4
+--R               (1029a c  + 5145a b c  + 1715a b c )n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                2 7 5         9 4       11 3     n 7
+--R           (147a b c  + 735a b c  + 245b  c )n (x )
+--R         + 
+--R                 3 6 5        2 8 4          10 3     n 6
+--R           (1029a b c  + 5145a b c  + 1715a b  c )n (x )
+--R         + 
+--R                 4 5 5         3 7 4        2 9 3     n 5
+--R           (3087a b c  + 15435a b c  + 5145a b c )n (x )
+--R         + 
+--R                 5 4 5         4 6 4        3 8 3     n 4
+--R           (5145a b c  + 25725a b c  + 8575a b c )n (x )
+--R         + 
+--R                 6 3 5         5 5 4        4 7 3     n 3
+--R           (5145a b c  + 25725a b c  + 8575a b c )n (x )
+--R         + 
+--R                 7 2 5         6 4 4        5 6 3     n 2
+--R           (3087a b c  + 15435a b c  + 5145a b c )n (x )
+--R         + 
+--R                 8   5        7 3 4        6 5 3    n
+--R           (1029a b c  + 5145a b c  + 1715a b c )n x
+--R         + 
+--R                9 5       8 2 4       7 4 3
+--R           (147a c  + 735a b c  + 245a b c )n
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                2   11         3 10       5 9     2n 7
+--R           (735a b c   + 980a b c   + 147b c )n (x  )
+--R         + 
+--R                     2 2 10          4 9        6 8    n
+--R               (5145a b c   + 6860a b c  + 1029b c )n x
+--R             + 
+--R                     3   10        2 3 9          5 8
+--R               (5145a b c   + 6860a b c  + 1029a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                      2 3 9           5 8        7 7     n 2
+--R               (15435a b c  + 20580a b c  + 3087b c )n (x )
+--R             + 
+--R                      3 2 9         2 4 8          6 7    n
+--R               (30870a b c  + 41160a b c  + 6174a b c )n x
+--R             + 
+--R                      4   9         3 3 8        2 5 7
+--R               (15435a b c  + 20580a b c  + 3087a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      2 4 8           6 7        8 6     n 3
+--R               (25725a b c  + 34300a b c  + 5145b c )n (x )
+--R             + 
+--R                      3 3 8          2 5 7           7 6     n 2
+--R               (77175a b c  + 102900a b c  + 15435a b c )n (x )
+--R             + 
+--R                      4 2 8          3 4 7         2 6 6    n
+--R               (77175a b c  + 102900a b c  + 15435a b c )n x
+--R             + 
+--R                      5   8         4 3 7        3 5 6
+--R               (25725a b c  + 34300a b c  + 5145a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      2 5 7           7 6        9 5     n 4
+--R               (25725a b c  + 34300a b c  + 5145b c )n (x )
+--R             + 
+--R                       3 4 7          2 6 6           8 5     n 3
+--R               (102900a b c  + 137200a b c  + 20580a b c )n (x )
+--R             + 
+--R                       4 3 7          3 5 6         2 7 5     n 2
+--R               (154350a b c  + 205800a b c  + 30870a b c )n (x )
+--R             + 
+--R                       5 2 7          4 4 6         3 6 5    n
+--R               (102900a b c  + 137200a b c  + 20580a b c )n x
+--R             + 
+--R                      6   7         5 3 6        4 5 5
+--R               (25725a b c  + 34300a b c  + 5145a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                      2 6 6           8 5        10 4     n 5
+--R               (15435a b c  + 20580a b c  + 3087b  c )n (x )
+--R             + 
+--R                      3 5 6          2 7 5           9 4     n 4
+--R               (77175a b c  + 102900a b c  + 15435a b c )n (x )
+--R             + 
+--R                       4 4 6          3 6 5         2 8 4     n 3
+--R               (154350a b c  + 205800a b c  + 30870a b c )n (x )
+--R             + 
+--R                       5 3 6          4 5 5         3 7 4     n 2
+--R               (154350a b c  + 205800a b c  + 30870a b c )n (x )
+--R             + 
+--R                      6 2 6          5 4 5         4 6 4    n
+--R               (77175a b c  + 102900a b c  + 15435a b c )n x
+--R             + 
+--R                      7   6         6 3 5        5 5 4
+--R               (15435a b c  + 20580a b c  + 3087a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     2 7 5          9 4        11 3     n 6
+--R               (5145a b c  + 6860a b c  + 1029b  c )n (x )
+--R             + 
+--R                      3 6 5         2 8 4          10 3     n 5
+--R               (30870a b c  + 41160a b c  + 6174a b  c )n (x )
+--R             + 
+--R                      4 5 5          3 7 4         2 9 3     n 4
+--R               (77175a b c  + 102900a b c  + 15435a b c )n (x )
+--R             + 
+--R                       5 4 5          4 6 4         3 8 3     n 3
+--R               (102900a b c  + 137200a b c  + 20580a b c )n (x )
+--R             + 
+--R                      6 3 5          5 5 4         4 7 3     n 2
+--R               (77175a b c  + 102900a b c  + 15435a b c )n (x )
+--R             + 
+--R                      7 2 5         6 4 4        5 6 3    n
+--R               (30870a b c  + 41160a b c  + 6174a b c )n x
+--R             + 
+--R                     8   5        7 3 4        6 5 3
+--R               (5145a b c  + 6860a b c  + 1029a b c )n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                2 8 4         10 3       12 2     n 7
+--R           (735a b c  + 980a b  c  + 147b  c )n (x )
+--R         + 
+--R                 3 7 4        2 9 3          11 2     n 6
+--R           (5145a b c  + 6860a b c  + 1029a b  c )n (x )
+--R         + 
+--R                  4 6 4         3 8 3        2 10 2     n 5
+--R           (15435a b c  + 20580a b c  + 3087a b  c )n (x )
+--R         + 
+--R                  5 5 4         4 7 3        3 9 2     n 4
+--R           (25725a b c  + 34300a b c  + 5145a b c )n (x )
+--R         + 
+--R                  6 4 4         5 6 3        4 8 2     n 3
+--R           (25725a b c  + 34300a b c  + 5145a b c )n (x )
+--R         + 
+--R                  7 3 4         6 5 3        5 7 2     n 2
+--R           (15435a b c  + 20580a b c  + 3087a b c )n (x )
+--R         + 
+--R                 8 2 4        7 4 3        6 6 2    n
+--R           (5145a b c  + 6860a b c  + 1029a b c )n x
+--R         + 
+--R                9   4       8 3 3       7 5 2
+--R           (735a b c  + 980a b c  + 147a b c )n
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R                3 11        2 2 10         4 9      6 8     2n 7
+--R           (245a c   + 1470a b c   + 735a b c  + 49b c )n (x  )
+--R         + 
+--R                     3   10         2 3 9          5 8       7 7    n
+--R               (1715a b c   + 10290a b c  + 5145a b c  + 343b c )n x
+--R             + 
+--R                     4 10         3 2 9        2 4 8         6 7
+--R               (1715a c   + 10290a b c  + 5145a b c  + 343a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     3 2 9         2 4 8           6 7        8 6     n 2
+--R               (5145a b c  + 30870a b c  + 15435a b c  + 1029b c )n (x )
+--R             + 
+--R                      4   9         3 3 8         2 5 7          7 6    n
+--R               (10290a b c  + 61740a b c  + 30870a b c  + 2058a b c )n x
+--R             + 
+--R                     5 9         4 2 8         3 4 7        2 6 6
+--R               (5145a c  + 30870a b c  + 15435a b c  + 1029a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     3 3 8         2 5 7           7 6        9 5     n 3
+--R               (8575a b c  + 51450a b c  + 25725a b c  + 1715b c )n (x )
+--R             + 
+--R                      4 2 8          3 4 7         2 6 6          8 5     n 2
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b c )n (x )
+--R             + 
+--R                      5   8          4 3 7         3 5 6        2 7 5    n
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b c )n x
+--R             + 
+--R                     6 8         5 2 7         4 4 6        3 6 5
+--R               (8575a c  + 51450a b c  + 25725a b c  + 1715a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     3 4 7         2 6 6           8 5        10 4     n 4
+--R               (8575a b c  + 51450a b c  + 25725a b c  + 1715b  c )n (x )
+--R             + 
+--R                      4 3 7          3 5 6          2 7 5          9 4     n 3
+--R               (34300a b c  + 205800a b c  + 102900a b c  + 6860a b c )n (x )
+--R             + 
+--R                      5 2 7          4 4 6          3 6 5         2 8 4     n 2
+--R               (51450a b c  + 308700a b c  + 154350a b c  + 10290a b c )n (x )
+--R             + 
+--R                      6   7          5 3 6          4 5 5        3 7 4    n
+--R               (34300a b c  + 205800a b c  + 102900a b c  + 6860a b c )n x
+--R             + 
+--R                     7 7         6 2 6         5 4 5        4 6 4
+--R               (8575a c  + 51450a b c  + 25725a b c  + 1715a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     3 5 6         2 7 5           9 4        11 3     n 5
+--R               (5145a b c  + 30870a b c  + 15435a b c  + 1029b  c )n (x )
+--R             + 
+--R                      4 4 6          3 6 5         2 8 4          10 3     n 4
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b  c )n (x )
+--R             + 
+--R                      5 3 6          4 5 5          3 7 4         2 9 3     n 3
+--R               (51450a b c  + 308700a b c  + 154350a b c  + 10290a b c )n (x )
+--R             + 
+--R                      6 2 6          5 4 5          4 6 4         3 8 3     n 2
+--R               (51450a b c  + 308700a b c  + 154350a b c  + 10290a b c )n (x )
+--R             + 
+--R                      7   6          6 3 5         5 5 4        4 7 3    n
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b c )n x
+--R             + 
+--R                     8 6         7 2 5         6 4 4        5 6 3
+--R               (5145a c  + 30870a b c  + 15435a b c  + 1029a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     3 6 5         2 8 4          10 3       12 2     n 6
+--R               (1715a b c  + 10290a b c  + 5145a b  c  + 343b  c )n (x )
+--R             + 
+--R                      4 5 5         3 7 4         2 9 3          11 2     n 5
+--R               (10290a b c  + 61740a b c  + 30870a b c  + 2058a b  c )n (x )
+--R             + 
+--R                      5 4 5          4 6 4         3 8 3        2 10 2     n 4
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b  c )n (x )
+--R             + 
+--R                      6 3 5          5 5 4          4 7 3        3 9 2     n 3
+--R               (34300a b c  + 205800a b c  + 102900a b c  + 6860a b c )n (x )
+--R             + 
+--R                      7 2 5          6 4 4         5 6 3        4 8 2     n 2
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b c )n (x )
+--R             + 
+--R                      8   5         7 3 4         6 5 3        5 7 2    n
+--R               (10290a b c  + 61740a b c  + 30870a b c  + 2058a b c )n x
+--R             + 
+--R                     9 5         8 2 4        7 4 3       6 6 2
+--R               (1715a c  + 10290a b c  + 5145a b c  + 343a b c )n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                3 7 4        2 9 3         11 2      13      n 7
+--R           (245a b c  + 1470a b c  + 735a b  c  + 49b  c)n (x )
+--R         + 
+--R                 4 6 4         3 8 3        2 10 2         12      n 6
+--R           (1715a b c  + 10290a b c  + 5145a b  c  + 343a b  c)n (x )
+--R         + 
+--R                 5 5 4         4 7 3         3 9 2        2 11      n 5
+--R           (5145a b c  + 30870a b c  + 15435a b c  + 1029a b  c)n (x )
+--R         + 
+--R                 6 4 4         5 6 3         4 8 2        3 10      n 4
+--R           (8575a b c  + 51450a b c  + 25725a b c  + 1715a b  c)n (x )
+--R         + 
+--R                 7 3 4         6 5 3         5 7 2        4 9      n 3
+--R           (8575a b c  + 51450a b c  + 25725a b c  + 1715a b c)n (x )
+--R         + 
+--R                 8 2 4         7 4 3         6 6 2        5 8      n 2
+--R           (5145a b c  + 30870a b c  + 15435a b c  + 1029a b c)n (x )
+--R         + 
+--R                 9   4         8 3 3        7 5 2       6 7     n
+--R           (1715a b c  + 10290a b c  + 5145a b c  + 343a b c)n x
+--R         + 
+--R                10 4        9 2 3       8 4 2      7 6
+--R           (245a  c  + 1470a b c  + 735a b c  + 49a b c)n
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R                3   10        2 3 9         5 8     7 7     2n 7
+--R           (980a b c   + 1470a b c  + 294a b c  + 7b c )n (x  )
+--R         + 
+--R                     3 2 9         2 4 8          6 7      8 6    n
+--R               (6860a b c  + 10290a b c  + 2058a b c  + 49b c )n x
+--R             + 
+--R                     4   9         3 3 8        2 5 7        7 6
+--R               (6860a b c  + 10290a b c  + 2058a b c  + 49a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                      3 3 8         2 5 7          7 6       9 5     n 2
+--R               (20580a b c  + 30870a b c  + 6174a b c  + 147b c )n (x )
+--R             + 
+--R                      4 2 8         3 4 7         2 6 6         8 5    n
+--R               (41160a b c  + 61740a b c  + 12348a b c  + 294a b c )n x
+--R             + 
+--R                      5   8         4 3 7        3 5 6       2 7 5
+--R               (20580a b c  + 30870a b c  + 6174a b c  + 147a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      3 4 7         2 6 6           8 5       10 4     n 3
+--R               (34300a b c  + 51450a b c  + 10290a b c  + 245b  c )n (x )
+--R             + 
+--R                       4 3 7          3 5 6         2 7 5         9 4     n 2
+--R               (102900a b c  + 154350a b c  + 30870a b c  + 735a b c )n (x )
+--R             + 
+--R                       5 2 7          4 4 6         3 6 5       2 8 4    n
+--R               (102900a b c  + 154350a b c  + 30870a b c  + 735a b c )n x
+--R             + 
+--R                      6   7         5 3 6         4 5 5       3 7 4
+--R               (34300a b c  + 51450a b c  + 10290a b c  + 245a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      3 5 6         2 7 5           9 4       11 3     n 4
+--R               (34300a b c  + 51450a b c  + 10290a b c  + 245b  c )n (x )
+--R             + 
+--R                       4 4 6          3 6 5         2 8 4         10 3     n 3
+--R               (137200a b c  + 205800a b c  + 41160a b c  + 980a b  c )n (x )
+--R             + 
+--R                       5 3 6          4 5 5         3 7 4        2 9 3     n 2
+--R               (205800a b c  + 308700a b c  + 61740a b c  + 1470a b c )n (x )
+--R             + 
+--R                       6 2 6          5 4 5         4 6 4       3 8 3    n
+--R               (137200a b c  + 205800a b c  + 41160a b c  + 980a b c )n x
+--R             + 
+--R                      7   6         6 3 5         5 5 4       4 7 3
+--R               (34300a b c  + 51450a b c  + 10290a b c  + 245a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                      3 6 5         2 8 4          10 3       12 2     n 5
+--R               (20580a b c  + 30870a b c  + 6174a b  c  + 147b  c )n (x )
+--R             + 
+--R                       4 5 5          3 7 4         2 9 3         11 2     n 4
+--R               (102900a b c  + 154350a b c  + 30870a b c  + 735a b  c )n (x )
+--R             + 
+--R                       5 4 5          4 6 4         3 8 3        2 10 2     n 3
+--R               (205800a b c  + 308700a b c  + 61740a b c  + 1470a b  c )n (x )
+--R             + 
+--R                       6 3 5          5 5 4         4 7 3        3 9 2     n 2
+--R               (205800a b c  + 308700a b c  + 61740a b c  + 1470a b c )n (x )
+--R             + 
+--R                       7 2 5          6 4 4         5 6 3       4 8 2    n
+--R               (102900a b c  + 154350a b c  + 30870a b c  + 735a b c )n x
+--R             + 
+--R                      8   5         7 3 4        6 5 3       5 7 2
+--R               (20580a b c  + 30870a b c  + 6174a b c  + 147a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     3 7 4         2 9 3          11 2      13      n 6
+--R               (6860a b c  + 10290a b c  + 2058a b  c  + 49b  c)n (x )
+--R             + 
+--R                      4 6 4         3 8 3         2 10 2         12      n 5
+--R               (41160a b c  + 61740a b c  + 12348a b  c  + 294a b  c)n (x )
+--R             + 
+--R                       5 5 4          4 7 3         3 9 2       2 11      n 4
+--R               (102900a b c  + 154350a b c  + 30870a b c  + 735a b  c)n (x )
+--R             + 
+--R                       6 4 4          5 6 3         4 8 2       3 10      n 3
+--R               (137200a b c  + 205800a b c  + 41160a b c  + 980a b  c)n (x )
+--R             + 
+--R                       7 3 4          6 5 3         5 7 2       4 9      n 2
+--R               (102900a b c  + 154350a b c  + 30870a b c  + 735a b c)n (x )
+--R             + 
+--R                      8 2 4         7 4 3         6 6 2       5 8     n
+--R               (41160a b c  + 61740a b c  + 12348a b c  + 294a b c)n x
+--R             + 
+--R                     9   4         8 3 3        7 5 2      6 7
+--R               (6860a b c  + 10290a b c  + 2058a b c  + 49a b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                3 8 3        2 10 2         12      14     n 7
+--R           (980a b c  + 1470a b  c  + 294a b  c + 7b  )n (x )
+--R         + 
+--R                 4 7 3         3 9 2        2 11         13     n 6
+--R           (6860a b c  + 10290a b c  + 2058a b  c + 49a b  )n (x )
+--R         + 
+--R                  5 6 3         4 8 2        3 10        2 12     n 5
+--R           (20580a b c  + 30870a b c  + 6174a b  c + 147a b  )n (x )
+--R         + 
+--R                  6 5 3         5 7 2         4 9        3 11     n 4
+--R           (34300a b c  + 51450a b c  + 10290a b c + 245a b  )n (x )
+--R         + 
+--R                  7 4 3         6 6 2         5 8        4 10     n 3
+--R           (34300a b c  + 51450a b c  + 10290a b c + 245a b  )n (x )
+--R         + 
+--R                  8 3 3         7 5 2        6 7        5 9     n 2
+--R           (20580a b c  + 30870a b c  + 6174a b c + 147a b )n (x )
+--R         + 
+--R                 9 2 3         8 4 2        7 6       6 8    n
+--R           (6860a b c  + 10290a b c  + 2058a b c + 49a b )n x
+--R         + 
+--R                10   3        9 3 2       8 5      7 7
+--R           (980a  b c  + 1470a b c  + 294a b c + 7a b )n
+--R      *
+--R            n log(x) 7
+--R         (%e        )
+--R     + 
+--R                4 10        3 2 9       2 4 8        6 7     2n 7
+--R           (245a c   + 1470a b c  + 735a b c  + 49a b c )n (x  )
+--R         + 
+--R                     4   9         3 3 8        2 5 7         7 6    n
+--R               (1715a b c  + 10290a b c  + 5145a b c  + 343a b c )n x
+--R             + 
+--R                     5 9         4 2 8        3 4 7       2 6 6
+--R               (1715a c  + 10290a b c  + 5145a b c  + 343a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     4 2 8         3 4 7         2 6 6          8 5     n 2
+--R               (5145a b c  + 30870a b c  + 15435a b c  + 1029a b c )n (x )
+--R             + 
+--R                      5   8         4 3 7         3 5 6        2 7 5    n
+--R               (10290a b c  + 61740a b c  + 30870a b c  + 2058a b c )n x
+--R             + 
+--R                     6 8         5 2 7         4 4 6        3 6 5
+--R               (5145a c  + 30870a b c  + 15435a b c  + 1029a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     4 3 7         3 5 6         2 7 5          9 4     n 3
+--R               (8575a b c  + 51450a b c  + 25725a b c  + 1715a b c )n (x )
+--R             + 
+--R                      5 2 7          4 4 6         3 6 5        2 8 4     n 2
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b c )n (x )
+--R             + 
+--R                      6   7          5 3 6         4 5 5        3 7 4    n
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b c )n x
+--R             + 
+--R                     7 7         6 2 6         5 4 5        4 6 4
+--R               (8575a c  + 51450a b c  + 25725a b c  + 1715a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     4 4 6         3 6 5         2 8 4          10 3     n 4
+--R               (8575a b c  + 51450a b c  + 25725a b c  + 1715a b  c )n (x )
+--R             + 
+--R                      5 3 6          4 5 5          3 7 4        2 9 3     n 3
+--R               (34300a b c  + 205800a b c  + 102900a b c  + 6860a b c )n (x )
+--R             + 
+--R                      6 2 6          5 4 5          4 6 4         3 8 3     n 2
+--R               (51450a b c  + 308700a b c  + 154350a b c  + 10290a b c )n (x )
+--R             + 
+--R                      7   6          6 3 5          5 5 4        4 7 3    n
+--R               (34300a b c  + 205800a b c  + 102900a b c  + 6860a b c )n x
+--R             + 
+--R                     8 6         7 2 5         6 4 4        5 6 3
+--R               (8575a c  + 51450a b c  + 25725a b c  + 1715a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     4 5 5         3 7 4         2 9 3          11 2     n 5
+--R               (5145a b c  + 30870a b c  + 15435a b c  + 1029a b  c )n (x )
+--R             + 
+--R                      5 4 5          4 6 4         3 8 3        2 10 2     n 4
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b  c )n (x )
+--R             + 
+--R                      6 3 5          5 5 4          4 7 3         3 9 2     n 3
+--R               (51450a b c  + 308700a b c  + 154350a b c  + 10290a b c )n (x )
+--R             + 
+--R                      7 2 5          6 4 4          5 6 3         4 8 2     n 2
+--R               (51450a b c  + 308700a b c  + 154350a b c  + 10290a b c )n (x )
+--R             + 
+--R                      8   5          7 3 4         6 5 3        5 7 2    n
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b c )n x
+--R             + 
+--R                     9 5         8 2 4         7 4 3        6 6 2
+--R               (5145a c  + 30870a b c  + 15435a b c  + 1029a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     4 6 4         3 8 3        2 10 2         12      n 6
+--R               (1715a b c  + 10290a b c  + 5145a b  c  + 343a b  c)n (x )
+--R             + 
+--R                      5 5 4         4 7 3         3 9 2        2 11      n 5
+--R               (10290a b c  + 61740a b c  + 30870a b c  + 2058a b  c)n (x )
+--R             + 
+--R                      6 4 4          5 6 3         4 8 2        3 10      n 4
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b  c)n (x )
+--R             + 
+--R                      7 3 4          6 5 3          5 7 2        4 9      n 3
+--R               (34300a b c  + 205800a b c  + 102900a b c  + 6860a b c)n (x )
+--R             + 
+--R                      8 2 4          7 4 3         6 6 2        5 8      n 2
+--R               (25725a b c  + 154350a b c  + 77175a b c  + 5145a b c)n (x )
+--R             + 
+--R                      9   4         8 3 3         7 5 2        6 7     n
+--R               (10290a b c  + 61740a b c  + 30870a b c  + 2058a b c)n x
+--R             + 
+--R                     10 4         9 2 3        8 4 2       7 6
+--R               (1715a  c  + 10290a b c  + 5145a b c  + 343a b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                4 7 3        3 9 2       2 11         13     n 7
+--R           (245a b c  + 1470a b c  + 735a b  c + 49a b  )n (x )
+--R         + 
+--R                 5 6 3         4 8 2        3 10        2 12     n 6
+--R           (1715a b c  + 10290a b c  + 5145a b  c + 343a b  )n (x )
+--R         + 
+--R                 6 5 3         5 7 2         4 9         3 11     n 5
+--R           (5145a b c  + 30870a b c  + 15435a b c + 1029a b  )n (x )
+--R         + 
+--R                 7 4 3         6 6 2         5 8         4 10     n 4
+--R           (8575a b c  + 51450a b c  + 25725a b c + 1715a b  )n (x )
+--R         + 
+--R                 8 3 3         7 5 2         6 7         5 9     n 3
+--R           (8575a b c  + 51450a b c  + 25725a b c + 1715a b )n (x )
+--R         + 
+--R                 9 2 3         8 4 2         7 6         6 8     n 2
+--R           (5145a b c  + 30870a b c  + 15435a b c + 1029a b )n (x )
+--R         + 
+--R                 10   3         9 3 2        8 5        7 7    n
+--R           (1715a  b c  + 10290a b c  + 5145a b c + 343a b )n x
+--R         + 
+--R                11 3        10 2 2       9 4       8 6
+--R           (245a  c  + 1470a  b c  + 735a b c + 49a b )n
+--R      *
+--R            n log(x) 6
+--R         (%e        )
+--R     + 
+--R                4   9       3 3 8       2 5 7     2n 7
+--R           (735a b c  + 980a b c  + 147a b c )n (x  )
+--R         + 
+--R                     4 2 8        3 4 7        2 6 6    n
+--R               (5145a b c  + 6860a b c  + 1029a b c )n x
+--R             + 
+--R                     5   8        4 3 7        3 5 6
+--R               (5145a b c  + 6860a b c  + 1029a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                      4 3 7         3 5 6        2 7 5     n 2
+--R               (15435a b c  + 20580a b c  + 3087a b c )n (x )
+--R             + 
+--R                      5 2 7         4 4 6        3 6 5    n
+--R               (30870a b c  + 41160a b c  + 6174a b c )n x
+--R             + 
+--R                      6   7         5 3 6        4 5 5
+--R               (15435a b c  + 20580a b c  + 3087a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      4 4 6         3 6 5        2 8 4     n 3
+--R               (25725a b c  + 34300a b c  + 5145a b c )n (x )
+--R             + 
+--R                      5 3 6          4 5 5         3 7 4     n 2
+--R               (77175a b c  + 102900a b c  + 15435a b c )n (x )
+--R             + 
+--R                      6 2 6          5 4 5         4 6 4    n
+--R               (77175a b c  + 102900a b c  + 15435a b c )n x
+--R             + 
+--R                      7   6         6 3 5        5 5 4
+--R               (25725a b c  + 34300a b c  + 5145a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      4 5 5         3 7 4        2 9 3     n 4
+--R               (25725a b c  + 34300a b c  + 5145a b c )n (x )
+--R             + 
+--R                       5 4 5          4 6 4         3 8 3     n 3
+--R               (102900a b c  + 137200a b c  + 20580a b c )n (x )
+--R             + 
+--R                       6 3 5          5 5 4         4 7 3     n 2
+--R               (154350a b c  + 205800a b c  + 30870a b c )n (x )
+--R             + 
+--R                       7 2 5          6 4 4         5 6 3    n
+--R               (102900a b c  + 137200a b c  + 20580a b c )n x
+--R             + 
+--R                      8   5         7 3 4        6 5 3
+--R               (25725a b c  + 34300a b c  + 5145a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                      4 6 4         3 8 3        2 10 2     n 5
+--R               (15435a b c  + 20580a b c  + 3087a b  c )n (x )
+--R             + 
+--R                      5 5 4          4 7 3         3 9 2     n 4
+--R               (77175a b c  + 102900a b c  + 15435a b c )n (x )
+--R             + 
+--R                       6 4 4          5 6 3         4 8 2     n 3
+--R               (154350a b c  + 205800a b c  + 30870a b c )n (x )
+--R             + 
+--R                       7 3 4          6 5 3         5 7 2     n 2
+--R               (154350a b c  + 205800a b c  + 30870a b c )n (x )
+--R             + 
+--R                      8 2 4          7 4 3         6 6 2    n
+--R               (77175a b c  + 102900a b c  + 15435a b c )n x
+--R             + 
+--R                      9   4         8 3 3        7 5 2
+--R               (15435a b c  + 20580a b c  + 3087a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     4 7 3        3 9 2        2 11      n 6
+--R               (5145a b c  + 6860a b c  + 1029a b  c)n (x )
+--R             + 
+--R                      5 6 3         4 8 2        3 10      n 5
+--R               (30870a b c  + 41160a b c  + 6174a b  c)n (x )
+--R             + 
+--R                      6 5 3          5 7 2         4 9      n 4
+--R               (77175a b c  + 102900a b c  + 15435a b c)n (x )
+--R             + 
+--R                       7 4 3          6 6 2         5 8      n 3
+--R               (102900a b c  + 137200a b c  + 20580a b c)n (x )
+--R             + 
+--R                      8 3 3          7 5 2         6 7      n 2
+--R               (77175a b c  + 102900a b c  + 15435a b c)n (x )
+--R             + 
+--R                      9 2 3         8 4 2        7 6     n
+--R               (30870a b c  + 41160a b c  + 6174a b c)n x
+--R             + 
+--R                     10   3        9 3 2        8 5
+--R               (5145a  b c  + 6860a b c  + 1029a b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                4 8 2       3 10        2 12     n 7
+--R           (735a b c  + 980a b  c + 147a b  )n (x )
+--R         + 
+--R                 5 7 2        4 9         3 11     n 6
+--R           (5145a b c  + 6860a b c + 1029a b  )n (x )
+--R         + 
+--R                  6 6 2         5 8         4 10     n 5
+--R           (15435a b c  + 20580a b c + 3087a b  )n (x )
+--R         + 
+--R                  7 5 2         6 7         5 9     n 4
+--R           (25725a b c  + 34300a b c + 5145a b )n (x )
+--R         + 
+--R                  8 4 2         7 6         6 8     n 3
+--R           (25725a b c  + 34300a b c + 5145a b )n (x )
+--R         + 
+--R                  9 3 2         8 5         7 7     n 2
+--R           (15435a b c  + 20580a b c + 3087a b )n (x )
+--R         + 
+--R                 10 2 2        9 4         8 6    n
+--R           (5145a  b c  + 6860a b c + 1029a b )n x
+--R         + 
+--R                11   2       10 3        9 5
+--R           (735a  b c  + 980a  b c + 147a b )n
+--R      *
+--R            n log(x) 5
+--R         (%e        )
+--R     + 
+--R                5 9       4 2 8       3 4 7     2n 7
+--R           (147a c  + 735a b c  + 245a b c )n (x  )
+--R         + 
+--R                     5   8        4 3 7        3 5 6    n
+--R               (1029a b c  + 5145a b c  + 1715a b c )n x
+--R             + 
+--R                     6 8        5 2 7        4 4 6
+--R               (1029a c  + 5145a b c  + 1715a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     5 2 7         4 4 6        3 6 5     n 2
+--R               (3087a b c  + 15435a b c  + 5145a b c )n (x )
+--R             + 
+--R                     6   7         5 3 6         4 5 5    n
+--R               (6174a b c  + 30870a b c  + 10290a b c )n x
+--R             + 
+--R                     7 7         6 2 6        5 4 5
+--R               (3087a c  + 15435a b c  + 5145a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     5 3 6         4 5 5        3 7 4     n 3
+--R               (5145a b c  + 25725a b c  + 8575a b c )n (x )
+--R             + 
+--R                      6 2 6         5 4 5         4 6 4     n 2
+--R               (15435a b c  + 77175a b c  + 25725a b c )n (x )
+--R             + 
+--R                      7   6         6 3 5         5 5 4    n
+--R               (15435a b c  + 77175a b c  + 25725a b c )n x
+--R             + 
+--R                     8 6         7 2 5        6 4 4
+--R               (5145a c  + 25725a b c  + 8575a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     5 4 5         4 6 4        3 8 3     n 4
+--R               (5145a b c  + 25725a b c  + 8575a b c )n (x )
+--R             + 
+--R                      6 3 5          5 5 4         4 7 3     n 3
+--R               (20580a b c  + 102900a b c  + 34300a b c )n (x )
+--R             + 
+--R                      7 2 5          6 4 4         5 6 3     n 2
+--R               (30870a b c  + 154350a b c  + 51450a b c )n (x )
+--R             + 
+--R                      8   5          7 3 4         6 5 3    n
+--R               (20580a b c  + 102900a b c  + 34300a b c )n x
+--R             + 
+--R                     9 5         8 2 4        7 4 3
+--R               (5145a c  + 25725a b c  + 8575a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     5 5 4         4 7 3        3 9 2     n 5
+--R               (3087a b c  + 15435a b c  + 5145a b c )n (x )
+--R             + 
+--R                      6 4 4         5 6 3         4 8 2     n 4
+--R               (15435a b c  + 77175a b c  + 25725a b c )n (x )
+--R             + 
+--R                      7 3 4          6 5 3         5 7 2     n 3
+--R               (30870a b c  + 154350a b c  + 51450a b c )n (x )
+--R             + 
+--R                      8 2 4          7 4 3         6 6 2     n 2
+--R               (30870a b c  + 154350a b c  + 51450a b c )n (x )
+--R             + 
+--R                      9   4         8 3 3         7 5 2    n
+--R               (15435a b c  + 77175a b c  + 25725a b c )n x
+--R             + 
+--R                     10 4         9 2 3        8 4 2
+--R               (3087a  c  + 15435a b c  + 5145a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     5 6 3        4 8 2        3 10      n 6
+--R               (1029a b c  + 5145a b c  + 1715a b  c)n (x )
+--R             + 
+--R                     6 5 3         5 7 2         4 9      n 5
+--R               (6174a b c  + 30870a b c  + 10290a b c)n (x )
+--R             + 
+--R                      7 4 3         6 6 2         5 8      n 4
+--R               (15435a b c  + 77175a b c  + 25725a b c)n (x )
+--R             + 
+--R                      8 3 3          7 5 2         6 7      n 3
+--R               (20580a b c  + 102900a b c  + 34300a b c)n (x )
+--R             + 
+--R                      9 2 3         8 4 2         7 6      n 2
+--R               (15435a b c  + 77175a b c  + 25725a b c)n (x )
+--R             + 
+--R                     10   3         9 3 2         8 5     n
+--R               (6174a  b c  + 30870a b c  + 10290a b c)n x
+--R             + 
+--R                     11 3        10 2 2        9 4
+--R               (1029a  c  + 5145a  b c  + 1715a b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                5 7 2       4 9        3 11     n 7
+--R           (147a b c  + 735a b c + 245a b  )n (x )
+--R         + 
+--R                 6 6 2        5 8         4 10     n 6
+--R           (1029a b c  + 5145a b c + 1715a b  )n (x )
+--R         + 
+--R                 7 5 2         6 7         5 9     n 5
+--R           (3087a b c  + 15435a b c + 5145a b )n (x )
+--R         + 
+--R                 8 4 2         7 6         6 8     n 4
+--R           (5145a b c  + 25725a b c + 8575a b )n (x )
+--R         + 
+--R                 9 3 2         8 5         7 7     n 3
+--R           (5145a b c  + 25725a b c + 8575a b )n (x )
+--R         + 
+--R                 10 2 2         9 4         8 6     n 2
+--R           (3087a  b c  + 15435a b c + 5145a b )n (x )
+--R         + 
+--R                 11   2        10 3         9 5    n
+--R           (1029a  b c  + 5145a  b c + 1715a b )n x
+--R         + 
+--R                12 2       11 2        10 4
+--R           (147a  c  + 735a  b c + 245a  b )n
+--R      *
+--R            n log(x) 4
+--R         (%e        )
+--R     + 
+--R                5   8       4 3 7     2n 7
+--R           (294a b c  + 245a b c )n (x  )
+--R         + 
+--R                  5 2 7        4 4 6    n         6   7        5 3 6     2n 6
+--R           ((2058a b c  + 1715a b c )n x  + (2058a b c  + 1715a b c )n)(x  )
+--R         + 
+--R                     5 3 6        4 5 5     n 2
+--R               (6174a b c  + 5145a b c )n (x )
+--R             + 
+--R                      6 2 6         5 4 5    n         7   6        6 3 5
+--R               (12348a b c  + 10290a b c )n x  + (6174a b c  + 5145a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      5 4 5        4 6 4     n 3
+--R               (10290a b c  + 8575a b c )n (x )
+--R             + 
+--R                      6 3 5         5 5 4     n 2
+--R               (30870a b c  + 25725a b c )n (x )
+--R             + 
+--R                      7 2 5         6 4 4    n          8   5        7 3 4
+--R               (30870a b c  + 25725a b c )n x  + (10290a b c  + 8575a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      5 5 4        4 7 3     n 4
+--R               (10290a b c  + 8575a b c )n (x )
+--R             + 
+--R                      6 4 4         5 6 3     n 3
+--R               (41160a b c  + 34300a b c )n (x )
+--R             + 
+--R                      7 3 4         6 5 3     n 2
+--R               (61740a b c  + 51450a b c )n (x )
+--R             + 
+--R                      8 2 4         7 4 3    n          9   4        8 3 3
+--R               (41160a b c  + 34300a b c )n x  + (10290a b c  + 8575a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     5 6 3        4 8 2     n 5
+--R               (6174a b c  + 5145a b c )n (x )
+--R             + 
+--R                      6 5 3         5 7 2     n 4
+--R               (30870a b c  + 25725a b c )n (x )
+--R             + 
+--R                      7 4 3         6 6 2     n 3
+--R               (61740a b c  + 51450a b c )n (x )
+--R             + 
+--R                      8 3 3         7 5 2     n 2
+--R               (61740a b c  + 51450a b c )n (x )
+--R             + 
+--R                      9 2 3         8 4 2    n         10   3        9 3 2
+--R               (30870a b c  + 25725a b c )n x  + (6174a  b c  + 5145a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     5 7 2        4 9      n 6
+--R               (2058a b c  + 1715a b c)n (x )
+--R             + 
+--R                      6 6 2         5 8      n 5
+--R               (12348a b c  + 10290a b c)n (x )
+--R             + 
+--R                      7 5 2         6 7      n 4
+--R               (30870a b c  + 25725a b c)n (x )
+--R             + 
+--R                      8 4 2         7 6      n 3
+--R               (41160a b c  + 34300a b c)n (x )
+--R             + 
+--R                      9 3 2         8 5      n 2
+--R               (30870a b c  + 25725a b c)n (x )
+--R             + 
+--R                      10 2 2         9 4     n         11   2        10 3
+--R               (12348a  b c  + 10290a b c)n x  + (2058a  b c  + 1715a  b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                5 8        4 10     n 7         6 7         5 9     n 6
+--R           (294a b c + 245a b  )n (x )  + (2058a b c + 1715a b )n (x )
+--R         + 
+--R                 7 6         6 8     n 5          8 5         7 7     n 4
+--R           (6174a b c + 5145a b )n (x )  + (10290a b c + 8575a b )n (x )
+--R         + 
+--R                  9 4         8 6     n 3         10 3         9 5     n 2
+--R           (10290a b c + 8575a b )n (x )  + (6174a  b c + 5145a b )n (x )
+--R         + 
+--R                 11 2         10 4    n        12          11 3
+--R           (2058a  b c + 1715a  b )n x  + (294a  b c + 245a  b )n
+--R      *
+--R            n log(x) 3
+--R         (%e        )
+--R     + 
+--R               6 8       5 2 7     2n 7
+--R           (49a c  + 147a b c )n (x  )
+--R         + 
+--R                 6   7        5 3 6    n        7 7        6 2 6     2n 6
+--R           ((343a b c  + 1029a b c )n x  + (343a c  + 1029a b c )n)(x  )
+--R         + 
+--R                     6 2 6        5 4 5     n 2         7   6        6 3 5    n
+--R               (1029a b c  + 3087a b c )n (x )  + (2058a b c  + 6174a b c )n x
+--R             + 
+--R                     8 6        7 2 5
+--R               (1029a c  + 3087a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     6 3 5        5 5 4     n 3
+--R               (1715a b c  + 5145a b c )n (x )
+--R             + 
+--R                     7 2 5         6 4 4     n 2
+--R               (5145a b c  + 15435a b c )n (x )
+--R             + 
+--R                     8   5         7 3 4    n         9 5        8 2 4
+--R               (5145a b c  + 15435a b c )n x  + (1715a c  + 5145a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     6 4 4        5 6 3     n 4
+--R               (1715a b c  + 5145a b c )n (x )
+--R             + 
+--R                     7 3 4         6 5 3     n 3
+--R               (6860a b c  + 20580a b c )n (x )
+--R             + 
+--R                      8 2 4         7 4 3     n 2
+--R               (10290a b c  + 30870a b c )n (x )
+--R             + 
+--R                     9   4         8 3 3    n         10 4        9 2 3
+--R               (6860a b c  + 20580a b c )n x  + (1715a  c  + 5145a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     6 5 3        5 7 2     n 5
+--R               (1029a b c  + 3087a b c )n (x )
+--R             + 
+--R                     7 4 3         6 6 2     n 4
+--R               (5145a b c  + 15435a b c )n (x )
+--R             + 
+--R                      8 3 3         7 5 2     n 3
+--R               (10290a b c  + 30870a b c )n (x )
+--R             + 
+--R                      9 2 3         8 4 2     n 2
+--R               (10290a b c  + 30870a b c )n (x )
+--R             + 
+--R                     10   3         9 3 2    n         11 3        10 2 2
+--R               (5145a  b c  + 15435a b c )n x  + (1029a  c  + 3087a  b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    6 6 2        5 8      n 6         7 5 2        6 7      n 5
+--R               (343a b c  + 1029a b c)n (x )  + (2058a b c  + 6174a b c)n (x )
+--R             + 
+--R                     8 4 2         7 6      n 4
+--R               (5145a b c  + 15435a b c)n (x )
+--R             + 
+--R                     9 3 2         8 5      n 3
+--R               (6860a b c  + 20580a b c)n (x )
+--R             + 
+--R                     10 2 2         9 4      n 2
+--R               (5145a  b c  + 15435a b c)n (x )
+--R             + 
+--R                     11   2        10 3     n        12 2        11 2
+--R               (2058a  b c  + 6174a  b c)n x  + (343a  c  + 1029a  b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               6 7        5 9     n 7        7 6         6 8     n 6
+--R           (49a b c + 147a b )n (x )  + (343a b c + 1029a b )n (x )
+--R         + 
+--R                 8 5         7 7     n 5         9 4         8 6     n 4
+--R           (1029a b c + 3087a b )n (x )  + (1715a b c + 5145a b )n (x )
+--R         + 
+--R                 10 3         9 5     n 3         11 2         10 4     n 2
+--R           (1715a  b c + 5145a b )n (x )  + (1029a  b c + 3087a  b )n (x )
+--R         + 
+--R                12           11 3    n       13        12 2
+--R           (343a  b c + 1029a  b )n x  + (49a  c + 147a  b )n
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R              6   7    2n 7        6 2 6   n       7   6    2n 6
+--R           49a b c n (x  )  + (343a b c n x  + 343a b c n)(x  )
+--R         + 
+--R                 6 3 5    n 2        7 2 5   n        8   5    2n 5
+--R           (1029a b c n (x )  + 2058a b c n x  + 1029a b c n)(x  )
+--R         + 
+--R                    6 4 4    n 3        7 3 4    n 2        8 2 4   n
+--R               1715a b c n (x )  + 5145a b c n (x )  + 5145a b c n x
+--R             + 
+--R                    9   4
+--R               1715a b c n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                    6 5 3    n 4        7 4 3    n 3         8 3 3    n 2
+--R               1715a b c n (x )  + 6860a b c n (x )  + 10290a b c n (x )
+--R             + 
+--R                    9 2 3   n        10   3
+--R               6860a b c n x  + 1715a  b c n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                    6 6 2    n 5        7 5 2    n 4         8 4 2    n 3
+--R               1029a b c n (x )  + 5145a b c n (x )  + 10290a b c n (x )
+--R             + 
+--R                     9 3 2    n 2        10 2 2   n        11   2
+--R               10290a b c n (x )  + 5145a  b c n x  + 1029a  b c n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                   6 7      n 6        7 6      n 5        8 5      n 4
+--R               343a b c n (x )  + 2058a b c n (x )  + 5145a b c n (x )
+--R             + 
+--R                    9 4      n 3        10 3      n 2        11 2     n
+--R               6860a b c n (x )  + 5145a  b c n (x )  + 2058a  b c n x
+--R             + 
+--R                   12
+--R               343a  b c n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R              6 8    n 7       7 7    n 6        8 6    n 5        9 5    n 4
+--R           49a b n (x )  + 343a b n (x )  + 1029a b n (x )  + 1715a b n (x )
+--R         + 
+--R                10 4    n 3        11 3    n 2       12 2   n      13
+--R           1715a  b n (x )  + 1029a  b n (x )  + 343a  b n x  + 49a  b n
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R         7 7    2n 7       7   6   n      8 6    2n 6
+--R       7a c n (x  )  + (49a b c n x  + 49a c n)(x  )
+--R     + 
+--R            7 2 5    n 2       8   5   n       9 5    2n 5
+--R       (147a b c n (x )  + 294a b c n x  + 147a c n)(x  )
+--R     + 
+--R            7 3 4    n 3       8 2 4    n 2       9   4   n       10 4    2n 4
+--R       (245a b c n (x )  + 735a b c n (x )  + 735a b c n x  + 245a  c n)(x  )
+--R     + 
+--R               7 4 3    n 4       8 3 3    n 3        9 2 3    n 2
+--R           245a b c n (x )  + 980a b c n (x )  + 1470a b c n (x )
+--R         + 
+--R               10   3   n       11 3
+--R           980a  b c n x  + 245a  c n
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R               7 5 2    n 5       8 4 2    n 4        9 3 2    n 3
+--R           147a b c n (x )  + 735a b c n (x )  + 1470a b c n (x )
+--R         + 
+--R                10 2 2    n 2       11   2   n       12 2
+--R           1470a  b c n (x )  + 735a  b c n x  + 147a  c n
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R              7 6      n 6       8 5      n 5       9 4      n 4
+--R           49a b c n (x )  + 294a b c n (x )  + 735a b c n (x )
+--R         + 
+--R               10 3      n 3       11 2      n 2       12       n      13
+--R           980a  b c n (x )  + 735a  b c n (x )  + 294a  b c n x  + 49a  c n
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R         7 7    n 7      8 6    n 6       9 5    n 5       10 4    n 4
+--R       7a b n (x )  + 49a b n (x )  + 147a b n (x )  + 245a  b n (x )
+--R     + 
+--R           11 3    n 3       12 2    n 2      13     n     14
+--R       245a  b n (x )  + 147a  b n (x )  + 49a  b n x  + 7a  n
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            9   2n - 1      8   n - 1    n log(x) 16
+--R       (- 2c x x       - b c x x     )(%e        )
+--R     + 
+--R               8   2n - 1     2 7   n - 1    n log(x) 15
+--R       (- 16b c x x       - 8b c x x     )(%e        )
+--R     + 
+--R                  8      2 7    2n - 1            7      3 6    n - 1
+--R         ((- 16a c  - 56b c )x x       + (- 8a b c  - 28b c )x x     )
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                     7       3 6    2n - 1           2 6      4 5    n - 1
+--R         ((- 112a b c  - 112b c )x x       + (- 56a b c  - 56b c )x x     )
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R                 2 7         2 6       4 5    2n - 1
+--R           (- 56a c  - 336a b c  - 140b c )x x
+--R         + 
+--R                 2   6         3 5      5 4    n - 1
+--R           (- 28a b c  - 168a b c  - 70b c )x x
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                  2   6         3 5       5 4    2n - 1
+--R           (- 336a b c  - 560a b c  - 112b c )x x
+--R         + 
+--R                  2 2 5         4 4      6 3    n - 1
+--R           (- 168a b c  - 280a b c  - 56b c )x x
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                  3 6       2 2 5         4 4      6 3    2n - 1
+--R           (- 112a c  - 840a b c  - 560a b c  - 56b c )x x
+--R         + 
+--R                 3   5       2 3 4         5 3      7 2    n - 1
+--R           (- 56a b c  - 420a b c  - 280a b c  - 28b c )x x
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                  3   5        2 3 4         5 3      7 2    2n - 1
+--R           (- 560a b c  - 1120a b c  - 336a b c  - 16b c )x x
+--R         + 
+--R                  3 2 4       2 4 3         6 2     8     n - 1
+--R           (- 280a b c  - 560a b c  - 168a b c  - 8b c)x x
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R                  4 5        3 2 4       2 4 3         6 2     8     2n - 1
+--R           (- 140a c  - 1120a b c  - 840a b c  - 112a b c  - 2b c)x x
+--R         + 
+--R                 4   4       3 3 3       2 5 2        7     9    n - 1
+--R           (- 70a b c  - 560a b c  - 420a b c  - 56a b c - b )x x
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R                  4   4        3 3 3       2 5 2        7     2n - 1
+--R           (- 560a b c  - 1120a b c  - 336a b c  - 16a b c)x x
+--R         + 
+--R                  4 2 3       3 4 2       2 6        8    n - 1
+--R           (- 280a b c  - 560a b c  - 168a b c - 8a b )x x
+--R      *
+--R            n log(x) 7
+--R         (%e        )
+--R     + 
+--R                  5 4       4 2 3       3 4 2      2 6     2n - 1
+--R           (- 112a c  - 840a b c  - 560a b c  - 56a b c)x x
+--R         + 
+--R                 5   3       4 3 2       3 5       2 7    n - 1
+--R           (- 56a b c  - 420a b c  - 280a b c - 28a b )x x
+--R      *
+--R            n log(x) 6
+--R         (%e        )
+--R     + 
+--R                  5   3       4 3 2       3 5     2n - 1
+--R           (- 336a b c  - 560a b c  - 112a b c)x x
+--R         + 
+--R                  5 2 2       4 4       3 6    n - 1
+--R           (- 168a b c  - 280a b c - 56a b )x x
+--R      *
+--R            n log(x) 5
+--R         (%e        )
+--R     + 
+--R                 6 3       5 2 2       4 4     2n - 1
+--R           (- 56a c  - 336a b c  - 140a b c)x x
+--R         + 
+--R                 6   2       5 3       4 5    n - 1
+--R           (- 28a b c  - 168a b c - 70a b )x x
+--R      *
+--R            n log(x) 4
+--R         (%e        )
+--R     + 
+--R                 6   2       5 3     2n - 1         6 2       5 4    n - 1
+--R         ((- 112a b c  - 112a b c)x x       + (- 56a b c - 56a b )x x     )
+--R      *
+--R            n log(x) 3
+--R         (%e        )
+--R     + 
+--R             9  2n 8         8 n        8   2n 7
+--R           2c (x  )  + (16b c x  + 16a c )(x  )
+--R         + 
+--R               2 7  n 2           7 n      2 7   2n 6
+--R           (56b c (x )  + 112a b c x  + 56a c )(x  )
+--R         + 
+--R                3 6  n 3         2 6  n 2       2   6 n       3 6   2n 5
+--R           (112b c (x )  + 336a b c (x )  + 336a b c x  + 112a c )(x  )
+--R         + 
+--R                   4 5  n 4         3 5  n 3       2 2 5  n 2       3   5 n
+--R               140b c (x )  + 560a b c (x )  + 840a b c (x )  + 560a b c x
+--R             + 
+--R                   4 5
+--R               140a c
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                   5 4  n 5         4 4  n 4        2 3 4  n 3        3 2 4  n 2
+--R               112b c (x )  + 560a b c (x )  + 1120a b c (x )  + 1120a b c (x )
+--R             + 
+--R                   4   4 n       5 4
+--R               560a b c x  + 112a c
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                  6 3  n 6         5 3  n 5       2 4 3  n 4        3 3 3  n 3
+--R               56b c (x )  + 336a b c (x )  + 840a b c (x )  + 1120a b c (x )
+--R             + 
+--R                   4 2 3  n 2       5   3 n      6 3
+--R               840a b c (x )  + 336a b c x  + 56a c
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                  7 2  n 7         6 2  n 6       2 5 2  n 5       3 4 2  n 4
+--R               16b c (x )  + 112a b c (x )  + 336a b c (x )  + 560a b c (x )
+--R             + 
+--R                   4 3 2  n 3       5 2 2  n 2       6   2 n      7 2
+--R               560a b c (x )  + 336a b c (x )  + 112a b c x  + 16a c
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                 7 2      6 2     2n - 1     8    n 8        7    n 7
+--R           (- 16a c  - 56a b c)x x       + 2b c (x )  + 16a b c (x )
+--R         + 
+--R              2 6    n 6       3 5    n 5       4 4    n 4       5 3    n 3
+--R           56a b c (x )  + 112a b c (x )  + 140a b c (x )  + 112a b c (x )
+--R         + 
+--R              6 2    n 2      7     n        7         6 3    n - 1     8
+--R           56a b c (x )  + 16a b c x  + (- 8a b c - 28a b )x x      + 2a c
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R              8  2n 8      2 7 n         7   2n 7
+--R           b c (x  )  + (8b c x  + 8a b c )(x  )
+--R         + 
+--R               3 6  n 2        2 6 n      2   6   2n 6
+--R           (28b c (x )  + 56a b c x  + 28a b c )(x  )
+--R         + 
+--R               4 5  n 3         3 5  n 2       2 2 5 n      3   5   2n 5
+--R           (56b c (x )  + 168a b c (x )  + 168a b c x  + 56a b c )(x  )
+--R         + 
+--R                  5 4  n 4         4 4  n 3       2 3 4  n 2       3 2 4 n
+--R               70b c (x )  + 280a b c (x )  + 420a b c (x )  + 280a b c x
+--R             + 
+--R                  4   4
+--R               70a b c
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                  6 3  n 5         5 3  n 4       2 4 3  n 3       3 3 3  n 2
+--R               56b c (x )  + 280a b c (x )  + 560a b c (x )  + 560a b c (x )
+--R             + 
+--R                   4 2 3 n      5   3
+--R               280a b c x  + 56a b c
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                  7 2  n 6         6 2  n 5       2 5 2  n 4       3 4 2  n 3
+--R               28b c (x )  + 168a b c (x )  + 420a b c (x )  + 560a b c (x )
+--R             + 
+--R                   4 3 2  n 2       5 2 2 n      6   2
+--R               420a b c (x )  + 168a b c x  + 28a b c
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                 8    n 7        7    n 6       2 6    n 5       3 5    n 4
+--R               8b c (x )  + 56a b c (x )  + 168a b c (x )  + 280a b c (x )
+--R             + 
+--R                   4 4    n 3       5 3    n 2      6 2   n     7
+--R               280a b c (x )  + 168a b c (x )  + 56a b c x  + 8a b c
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                7       2n - 1    9  n 8       8  n 7      2 7  n 6
+--R           - 16a b c x x       + b (x )  + 8a b (x )  + 28a b (x )
+--R         + 
+--R              3 6  n 5      4 5  n 4      5 4  n 3      6 3  n 2     7 2 n
+--R           56a b (x )  + 70a b (x )  + 56a b (x )  + 28a b (x )  + 8a b x
+--R         + 
+--R               7 2   n - 1    8
+--R           - 8a b x x      + a b
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R           8     2n - 1    8     n - 1
+--R       - 2a c x x       - a b x x
+--R  /
+--R            16    2n 8        15   n       15    2n 7
+--R           c  x (x  )  + (8b c  x x  + 8a c  x)(x  )
+--R         + 
+--R               2 14    n 2          14   n      2 14    2n 6
+--R           (28b c  x (x )  + 56a b c  x x  + 28a c  x)(x  )
+--R         + 
+--R                 3 13    n 3         2 13    n 2       2   13   n      3 13
+--R             (56b c  x (x )  + 168a b c  x (x )  + 168a b c  x x  + 56a c  x)
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                  4 12    n 4         3 12    n 3       2 2 12    n 2
+--R               70b c  x (x )  + 280a b c  x (x )  + 420a b c  x (x )
+--R             + 
+--R                   3   12   n      4 12
+--R               280a b c  x x  + 70a c  x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                  5 11    n 5         4 11    n 4       2 3 11    n 3
+--R               56b c  x (x )  + 280a b c  x (x )  + 560a b c  x (x )
+--R             + 
+--R                   3 2 11    n 2       4   11   n      5 11
+--R               560a b c  x (x )  + 280a b c  x x  + 56a c  x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                  6 10    n 6         5 10    n 5       2 4 10    n 4
+--R               28b c  x (x )  + 168a b c  x (x )  + 420a b c  x (x )
+--R             + 
+--R                 3 3 10    n 3       4 2 10    n 2       5   10   n      6 10
+--R             560a b c  x (x )  + 420a b c  x (x )  + 168a b c  x x  + 28a c  x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                 7 9    n 7        6 9    n 6       2 5 9    n 5
+--R               8b c x (x )  + 56a b c x (x )  + 168a b c x (x )
+--R             + 
+--R                   3 4 9    n 4       4 3 9    n 3       5 2 9    n 2
+--R               280a b c x (x )  + 280a b c x (x )  + 168a b c x (x )
+--R             + 
+--R                  6   9   n     7 9
+--R               56a b c x x  + 8a c x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R            8 8    n 8       7 8    n 7      2 6 8    n 6      3 5 8    n 5
+--R           b c x (x )  + 8a b c x (x )  + 28a b c x (x )  + 56a b c x (x )
+--R         + 
+--R              4 4 8    n 4      5 3 8    n 3      6 2 8    n 2     7   8   n
+--R           70a b c x (x )  + 56a b c x (x )  + 28a b c x (x )  + 8a b c x x
+--R         + 
+--R            8 8
+--R           a c x
+--R      *
+--R            n log(x) 16
+--R         (%e        )
+--R     + 
+--R               15    2n 8       2 14   n          14    2n 7
+--R           8b c  x (x  )  + (64b c  x x  + 64a b c  x)(x  )
+--R         + 
+--R                3 13    n 2         2 13   n       2   13    2n 6
+--R           (224b c  x (x )  + 448a b c  x x  + 224a b c  x)(x  )
+--R         + 
+--R                   4 12    n 3          3 12    n 2        2 2 12   n
+--R               448b c  x (x )  + 1344a b c  x (x )  + 1344a b c  x x
+--R             + 
+--R                   3   12
+--R               448a b c  x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                   5 11    n 4          4 11    n 3        2 3 11    n 2
+--R               560b c  x (x )  + 2240a b c  x (x )  + 3360a b c  x (x )
+--R             + 
+--R                    3 2 11   n       4   11
+--R               2240a b c  x x  + 560a b c  x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                   6 10    n 5          5 10    n 4        2 4 10    n 3
+--R               448b c  x (x )  + 2240a b c  x (x )  + 4480a b c  x (x )
+--R             + 
+--R                    3 3 10    n 2        4 2 10   n       5   10
+--R               4480a b c  x (x )  + 2240a b c  x x  + 448a b c  x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                   7 9    n 6          6 9    n 5        2 5 9    n 4
+--R               224b c x (x )  + 1344a b c x (x )  + 3360a b c x (x )
+--R             + 
+--R                  3 4 9    n 3        4 3 9    n 2        5 2 9   n       6   9
+--R             4480a b c x (x )  + 3360a b c x (x )  + 1344a b c x x  + 224a b c x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                  8 8    n 7         7 8    n 6        2 6 8    n 5
+--R               64b c x (x )  + 448a b c x (x )  + 1344a b c x (x )
+--R             + 
+--R                    3 5 8    n 4        4 4 8    n 3        5 3 8    n 2
+--R               2240a b c x (x )  + 2240a b c x (x )  + 1344a b c x (x )
+--R             + 
+--R                   6 2 8   n      7   8
+--R               448a b c x x  + 64a b c x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R             9 7    n 8        8 7    n 7       2 7 7    n 6       3 6 7    n 5
+--R           8b c x (x )  + 64a b c x (x )  + 224a b c x (x )  + 448a b c x (x )
+--R         + 
+--R               4 5 7    n 4       5 4 7    n 3       6 3 7    n 2      7 2 7   n
+--R           560a b c x (x )  + 448a b c x (x )  + 224a b c x (x )  + 64a b c x x
+--R         + 
+--R             8   7
+--R           8a b c x
+--R      *
+--R            n log(x) 15
+--R         (%e        )
+--R     + 
+--R                15      2 14     2n 8
+--R           (8a c   + 28b c  )x (x  )
+--R         + 
+--R                    14       3 13    n       2 14         2 13     2n 7
+--R           ((64a b c   + 224b c  )x x  + (64a c   + 224a b c  )x)(x  )
+--R         + 
+--R                      2 13       4 12     n 2        2   13          3 12    n
+--R               (224a b c   + 784b c  )x (x )  + (448a b c   + 1568a b c  )x x
+--R             + 
+--R                    3 13       2 2 12
+--R               (224a c   + 784a b c  )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                      3 12        5 11     n 3
+--R               (448a b c   + 1568b c  )x (x )
+--R             + 
+--R                     2 2 12          4 11     n 2
+--R               (1344a b c   + 4704a b c  )x (x )
+--R             + 
+--R                     3   12        2 3 11    n        4 12        3 2 11
+--R               (1344a b c   + 4704a b c  )x x  + (448a c   + 1568a b c  )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      4 11        6 10     n 4
+--R               (560a b c   + 1960b c  )x (x )
+--R             + 
+--R                     2 3 11          5 10     n 3
+--R               (2240a b c   + 7840a b c  )x (x )
+--R             + 
+--R                     3 2 11         2 4 10     n 2
+--R               (3360a b c   + 11760a b c  )x (x )
+--R             + 
+--R                     4   11        3 3 10    n        5 11        4 2 10
+--R               (2240a b c   + 7840a b c  )x x  + (560a c   + 1960a b c  )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      5 10        7 9     n 5
+--R               (448a b c   + 1568b c )x (x )
+--R             + 
+--R                     2 4 10          6 9     n 4
+--R               (2240a b c   + 7840a b c )x (x )
+--R             + 
+--R                     3 3 10         2 5 9     n 3
+--R               (4480a b c   + 15680a b c )x (x )
+--R             + 
+--R                     4 2 10         3 4 9     n 2
+--R               (4480a b c   + 15680a b c )x (x )
+--R             + 
+--R                     5   10        4 3 9    n        6 10        5 2 9
+--R               (2240a b c   + 7840a b c )x x  + (448a c   + 1568a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                      6 9       8 8     n 6         2 5 9          7 8     n 5
+--R               (224a b c  + 784b c )x (x )  + (1344a b c  + 4704a b c )x (x )
+--R             + 
+--R                     3 4 9         2 6 8     n 4
+--R               (3360a b c  + 11760a b c )x (x )
+--R             + 
+--R                     4 3 9         3 5 8     n 3
+--R               (4480a b c  + 15680a b c )x (x )
+--R             + 
+--R                     5 2 9         4 4 8     n 2         6   9        5 3 8    n
+--R               (3360a b c  + 11760a b c )x (x )  + (1344a b c  + 4704a b c )x x
+--R             + 
+--R                    7 9       6 2 8
+--R               (224a c  + 784a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     7 8       9 7     n 7        2 6 8          8 7     n 6
+--R               (64a b c  + 224b c )x (x )  + (448a b c  + 1568a b c )x (x )
+--R             + 
+--R                     3 5 8        2 7 7     n 5
+--R               (1344a b c  + 4704a b c )x (x )
+--R             + 
+--R                     4 4 8        3 6 7     n 4
+--R               (2240a b c  + 7840a b c )x (x )
+--R             + 
+--R                     5 3 8        4 5 7     n 3
+--R               (2240a b c  + 7840a b c )x (x )
+--R             + 
+--R                     6 2 8        5 4 7     n 2        7   8        6 3 7    n
+--R               (1344a b c  + 4704a b c )x (x )  + (448a b c  + 1568a b c )x x
+--R             + 
+--R                   8 8       7 2 7
+--R               (64a c  + 224a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                8 7      10 6     n 8       2 7 7         9 6     n 7
+--R           (8a b c  + 28b  c )x (x )  + (64a b c  + 224a b c )x (x )
+--R         + 
+--R                3 6 7       2 8 6     n 6        4 5 7        3 7 6     n 5
+--R           (224a b c  + 784a b c )x (x )  + (448a b c  + 1568a b c )x (x )
+--R         + 
+--R                5 4 7        4 6 6     n 4        6 3 7        5 5 6     n 3
+--R           (560a b c  + 1960a b c )x (x )  + (448a b c  + 1568a b c )x (x )
+--R         + 
+--R                7 2 7       6 4 6     n 2       8   7       7 3 6    n
+--R           (224a b c  + 784a b c )x (x )  + (64a b c  + 224a b c )x x
+--R         + 
+--R              9 7      8 2 6
+--R           (8a c  + 28a b c )x
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                   14      3 13     2n 8
+--R           (56a b c   + 56b c  )x (x  )
+--R         + 
+--R                   2 13       4 12    n        2   13         3 12     2n 7
+--R           ((448a b c   + 448b c  )x x  + (448a b c   + 448a b c  )x)(x  )
+--R         + 
+--R                       3 12        5 11     n 2
+--R               (1568a b c   + 1568b c  )x (x )
+--R             + 
+--R                     2 2 12          4 11    n         3   12        2 3 11
+--R               (3136a b c   + 3136a b c  )x x  + (1568a b c   + 1568a b c  )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                       4 11        6 10     n 3
+--R               (3136a b c   + 3136b c  )x (x )
+--R             + 
+--R                     2 3 11          5 10     n 2
+--R               (9408a b c   + 9408a b c  )x (x )
+--R             + 
+--R                     3 2 11        2 4 10    n         4   11        3 3 10
+--R               (9408a b c   + 9408a b c  )x x  + (3136a b c   + 3136a b c  )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                       5 10        7 9     n 4
+--R               (3920a b c   + 3920b c )x (x )
+--R             + 
+--R                      2 4 10           6 9     n 3
+--R               (15680a b c   + 15680a b c )x (x )
+--R             + 
+--R                      3 3 10         2 5 9     n 2
+--R               (23520a b c   + 23520a b c )x (x )
+--R             + 
+--R                      4 2 10         3 4 9    n         5   10        4 3 9
+--R               (15680a b c   + 15680a b c )x x  + (3920a b c   + 3920a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                       6 9        8 8     n 5
+--R               (3136a b c  + 3136b c )x (x )
+--R             + 
+--R                      2 5 9           7 8     n 4
+--R               (15680a b c  + 15680a b c )x (x )
+--R             + 
+--R                      3 4 9         2 6 8     n 3
+--R               (31360a b c  + 31360a b c )x (x )
+--R             + 
+--R                      4 3 9         3 5 8     n 2
+--R               (31360a b c  + 31360a b c )x (x )
+--R             + 
+--R                      5 2 9         4 4 8    n         6   9        5 3 8
+--R               (15680a b c  + 15680a b c )x x  + (3136a b c  + 3136a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                       7 8        9 7     n 6         2 6 8          8 7     n 5
+--R               (1568a b c  + 1568b c )x (x )  + (9408a b c  + 9408a b c )x (x )
+--R             + 
+--R                      3 5 8         2 7 7     n 4
+--R               (23520a b c  + 23520a b c )x (x )
+--R             + 
+--R                      4 4 8         3 6 7     n 3
+--R               (31360a b c  + 31360a b c )x (x )
+--R             + 
+--R                      5 3 8         4 5 7     n 2
+--R               (23520a b c  + 23520a b c )x (x )
+--R             + 
+--R                     6 2 8        5 4 7    n         7   8        6 3 7
+--R               (9408a b c  + 9408a b c )x x  + (1568a b c  + 1568a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                      8 7       10 6     n 7         2 7 7          9 6     n 6
+--R               (448a b c  + 448b  c )x (x )  + (3136a b c  + 3136a b c )x (x )
+--R             + 
+--R                     3 6 7        2 8 6     n 5
+--R               (9408a b c  + 9408a b c )x (x )
+--R             + 
+--R                      4 5 7         3 7 6     n 4
+--R               (15680a b c  + 15680a b c )x (x )
+--R             + 
+--R                      5 4 7         4 6 6     n 3
+--R               (15680a b c  + 15680a b c )x (x )
+--R             + 
+--R                     6 3 7        5 5 6     n 2         7 2 7        6 4 6    n
+--R               (9408a b c  + 9408a b c )x (x )  + (3136a b c  + 3136a b c )x x
+--R             + 
+--R                    8   7       7 3 6
+--R               (448a b c  + 448a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                 9 6      11 5     n 8        2 8 6         10 5     n 7
+--R           (56a b c  + 56b  c )x (x )  + (448a b c  + 448a b  c )x (x )
+--R         + 
+--R                 3 7 6        2 9 5     n 6         4 6 6        3 8 5     n 5
+--R           (1568a b c  + 1568a b c )x (x )  + (3136a b c  + 3136a b c )x (x )
+--R         + 
+--R                 5 5 6        4 7 5     n 4         6 4 6        5 6 5     n 3
+--R           (3920a b c  + 3920a b c )x (x )  + (3136a b c  + 3136a b c )x (x )
+--R         + 
+--R                 7 3 6        6 5 5     n 2        8 2 6       7 4 5    n
+--R           (1568a b c  + 1568a b c )x (x )  + (448a b c  + 448a b c )x x
+--R         + 
+--R               9   6      8 3 5
+--R           (56a b c  + 56a b c )x
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R               2 14         2 13      4 12     2n 8
+--R           (28a c   + 168a b c   + 70b c  )x (x  )
+--R         + 
+--R                    2   13          3 12       5 11    n
+--R               (224a b c   + 1344a b c   + 560b c  )x x
+--R             + 
+--R                    3 13        2 2 12         4 11
+--R               (224a c   + 1344a b c   + 560a b c  )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                    2 2 12          4 11        6 10     n 2
+--R               (784a b c   + 4704a b c   + 1960b c  )x (x )
+--R             + 
+--R                     3   12        2 3 11          5 10    n
+--R               (1568a b c   + 9408a b c   + 3920a b c  )x x
+--R             + 
+--R                    4 12        3 2 11        2 4 10
+--R               (784a c   + 4704a b c   + 1960a b c  )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     2 3 11          5 10        7 9     n 3
+--R               (1568a b c   + 9408a b c   + 3920b c )x (x )
+--R             + 
+--R                     3 2 11         2 4 10           6 9     n 2
+--R               (4704a b c   + 28224a b c   + 11760a b c )x (x )
+--R             + 
+--R                     4   11         3 3 10         2 5 9    n
+--R               (4704a b c   + 28224a b c   + 11760a b c )x x
+--R             + 
+--R                     5 11        4 2 10        3 4 9
+--R               (1568a c   + 9408a b c   + 3920a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     2 4 10           6 9        8 8     n 4
+--R               (1960a b c   + 11760a b c  + 4900b c )x (x )
+--R             + 
+--R                     3 3 10         2 5 9           7 8     n 3
+--R               (7840a b c   + 47040a b c  + 19600a b c )x (x )
+--R             + 
+--R                      4 2 10         3 4 9         2 6 8     n 2
+--R               (11760a b c   + 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                     5   10         4 3 9         3 5 8    n
+--R               (7840a b c   + 47040a b c  + 19600a b c )x x
+--R             + 
+--R                     6 10         5 2 9        4 4 8
+--R               (1960a c   + 11760a b c  + 4900a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     2 5 9          7 8        9 7     n 5
+--R               (1568a b c  + 9408a b c  + 3920b c )x (x )
+--R             + 
+--R                     3 4 9         2 6 8           8 7     n 4
+--R               (7840a b c  + 47040a b c  + 19600a b c )x (x )
+--R             + 
+--R                      4 3 9         3 5 8         2 7 7     n 3
+--R               (15680a b c  + 94080a b c  + 39200a b c )x (x )
+--R             + 
+--R                      5 2 9         4 4 8         3 6 7     n 2
+--R               (15680a b c  + 94080a b c  + 39200a b c )x (x )
+--R             + 
+--R                     6   9         5 3 8         4 5 7    n
+--R               (7840a b c  + 47040a b c  + 19600a b c )x x
+--R             + 
+--R                     7 9        6 2 8        5 4 7
+--R               (1568a c  + 9408a b c  + 3920a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                    2 6 8          8 7        10 6     n 6
+--R               (784a b c  + 4704a b c  + 1960b  c )x (x )
+--R             + 
+--R                     3 5 8         2 7 7           9 6     n 5
+--R               (4704a b c  + 28224a b c  + 11760a b c )x (x )
+--R             + 
+--R                      4 4 8         3 6 7         2 8 6     n 4
+--R               (11760a b c  + 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                      5 3 8         4 5 7         3 7 6     n 3
+--R               (15680a b c  + 94080a b c  + 39200a b c )x (x )
+--R             + 
+--R                      6 2 8         5 4 7         4 6 6     n 2
+--R               (11760a b c  + 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                     7   8         6 3 7         5 5 6    n
+--R               (4704a b c  + 28224a b c  + 11760a b c )x x
+--R             + 
+--R                    8 8        7 2 7        6 4 6
+--R               (784a c  + 4704a b c  + 1960a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    2 7 7          9 6       11 5     n 7
+--R               (224a b c  + 1344a b c  + 560b  c )x (x )
+--R             + 
+--R                     3 6 7        2 8 6          10 5     n 6
+--R               (1568a b c  + 9408a b c  + 3920a b  c )x (x )
+--R             + 
+--R                     4 5 7         3 7 6         2 9 5     n 5
+--R               (4704a b c  + 28224a b c  + 11760a b c )x (x )
+--R             + 
+--R                     5 4 7         4 6 6         3 8 5     n 4
+--R               (7840a b c  + 47040a b c  + 19600a b c )x (x )
+--R             + 
+--R                     6 3 7         5 5 6         4 7 5     n 3
+--R               (7840a b c  + 47040a b c  + 19600a b c )x (x )
+--R             + 
+--R                     7 2 7         6 4 6         5 6 5     n 2
+--R               (4704a b c  + 28224a b c  + 11760a b c )x (x )
+--R             + 
+--R                     8   7        7 3 6        6 5 5    n
+--R               (1568a b c  + 9408a b c  + 3920a b c )x x
+--R             + 
+--R                    9 7        8 2 6       7 4 5
+--R               (224a c  + 1344a b c  + 560a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               2 8 6         10 5      12 4     n 8
+--R           (28a b c  + 168a b  c  + 70b  c )x (x )
+--R         + 
+--R                3 7 6        2 9 5         11 4     n 7
+--R           (224a b c  + 1344a b c  + 560a b  c )x (x )
+--R         + 
+--R                4 6 6        3 8 5        2 10 4     n 6
+--R           (784a b c  + 4704a b c  + 1960a b  c )x (x )
+--R         + 
+--R                 5 5 6        4 7 5        3 9 4     n 5
+--R           (1568a b c  + 9408a b c  + 3920a b c )x (x )
+--R         + 
+--R                 6 4 6         5 6 5        4 8 4     n 4
+--R           (1960a b c  + 11760a b c  + 4900a b c )x (x )
+--R         + 
+--R                 7 3 6        6 5 5        5 7 4     n 3
+--R           (1568a b c  + 9408a b c  + 3920a b c )x (x )
+--R         + 
+--R                8 2 6        7 4 5        6 6 4     n 2
+--R           (784a b c  + 4704a b c  + 1960a b c )x (x )
+--R         + 
+--R                9   6        8 3 5       7 5 4    n
+--R           (224a b c  + 1344a b c  + 560a b c )x x
+--R         + 
+--R               10 6       9 2 5      8 4 4
+--R           (28a  c  + 168a b c  + 70a b c )x
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                2   13         3 12      5 11     2n 8
+--R           (168a b c   + 280a b c   + 56b c  )x (x  )
+--R         + 
+--R                     2 2 12          4 11       6 10    n
+--R               (1344a b c   + 2240a b c   + 448b c  )x x
+--R             + 
+--R                     3   12        2 3 11         5 10
+--R               (1344a b c   + 2240a b c   + 448a b c  )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                     2 3 11          5 10        7 9     n 2
+--R               (4704a b c   + 7840a b c   + 1568b c )x (x )
+--R             + 
+--R                     3 2 11         2 4 10          6 9    n
+--R               (9408a b c   + 15680a b c   + 3136a b c )x x
+--R             + 
+--R                     4   11        3 3 10        2 5 9
+--R               (4704a b c   + 7840a b c   + 1568a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     2 4 10           6 9        8 8     n 3
+--R               (9408a b c   + 15680a b c  + 3136b c )x (x )
+--R             + 
+--R                      3 3 10         2 5 9          7 8     n 2
+--R               (28224a b c   + 47040a b c  + 9408a b c )x (x )
+--R             + 
+--R                      4 2 10         3 4 9        2 6 8    n
+--R               (28224a b c   + 47040a b c  + 9408a b c )x x
+--R             + 
+--R                     5   10         4 3 9        3 5 8
+--R               (9408a b c   + 15680a b c  + 3136a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      2 5 9           7 8        9 7     n 4
+--R               (11760a b c  + 19600a b c  + 3920b c )x (x )
+--R             + 
+--R                      3 4 9         2 6 8           8 7     n 3
+--R               (47040a b c  + 78400a b c  + 15680a b c )x (x )
+--R             + 
+--R                      4 3 9          3 5 8         2 7 7     n 2
+--R               (70560a b c  + 117600a b c  + 23520a b c )x (x )
+--R             + 
+--R                      5 2 9         4 4 8         3 6 7    n
+--R               (47040a b c  + 78400a b c  + 15680a b c )x x
+--R             + 
+--R                      6   9         5 3 8        4 5 7
+--R               (11760a b c  + 19600a b c  + 3920a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     2 6 8           8 7        10 6     n 5
+--R               (9408a b c  + 15680a b c  + 3136b  c )x (x )
+--R             + 
+--R                      3 5 8         2 7 7           9 6     n 4
+--R               (47040a b c  + 78400a b c  + 15680a b c )x (x )
+--R             + 
+--R                      4 4 8          3 6 7         2 8 6     n 3
+--R               (94080a b c  + 156800a b c  + 31360a b c )x (x )
+--R             + 
+--R                      5 3 8          4 5 7         3 7 6     n 2
+--R               (94080a b c  + 156800a b c  + 31360a b c )x (x )
+--R             + 
+--R                      6 2 8         5 4 7         4 6 6    n
+--R               (47040a b c  + 78400a b c  + 15680a b c )x x
+--R             + 
+--R                     7   8         6 3 7        5 5 6
+--R               (9408a b c  + 15680a b c  + 3136a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     2 7 7          9 6        11 5     n 6
+--R               (4704a b c  + 7840a b c  + 1568b  c )x (x )
+--R             + 
+--R                      3 6 7         2 8 6          10 5     n 5
+--R               (28224a b c  + 47040a b c  + 9408a b  c )x (x )
+--R             + 
+--R                      4 5 7          3 7 6         2 9 5     n 4
+--R               (70560a b c  + 117600a b c  + 23520a b c )x (x )
+--R             + 
+--R                      5 4 7          4 6 6         3 8 5     n 3
+--R               (94080a b c  + 156800a b c  + 31360a b c )x (x )
+--R             + 
+--R                      6 3 7          5 5 6         4 7 5     n 2
+--R               (70560a b c  + 117600a b c  + 23520a b c )x (x )
+--R             + 
+--R                      7 2 7         6 4 6        5 6 5    n
+--R               (28224a b c  + 47040a b c  + 9408a b c )x x
+--R             + 
+--R                     8   7        7 3 6        6 5 5
+--R               (4704a b c  + 7840a b c  + 1568a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     2 8 6          10 5       12 4     n 7
+--R               (1344a b c  + 2240a b  c  + 448b  c )x (x )
+--R             + 
+--R                     3 7 6         2 9 5          11 4     n 6
+--R               (9408a b c  + 15680a b c  + 3136a b  c )x (x )
+--R             + 
+--R                      4 6 6         3 8 5        2 10 4     n 5
+--R               (28224a b c  + 47040a b c  + 9408a b  c )x (x )
+--R             + 
+--R                      5 5 6         4 7 5         3 9 4     n 4
+--R               (47040a b c  + 78400a b c  + 15680a b c )x (x )
+--R             + 
+--R                      6 4 6         5 6 5         4 8 4     n 3
+--R               (47040a b c  + 78400a b c  + 15680a b c )x (x )
+--R             + 
+--R                      7 3 6         6 5 5        5 7 4     n 2
+--R               (28224a b c  + 47040a b c  + 9408a b c )x (x )
+--R             + 
+--R                     8 2 6         7 4 5        6 6 4    n
+--R               (9408a b c  + 15680a b c  + 3136a b c )x x
+--R             + 
+--R                     9   6        8 3 5       7 5 4
+--R               (1344a b c  + 2240a b c  + 448a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                2 9 5         11 4      13 3     n 8
+--R           (168a b c  + 280a b  c  + 56b  c )x (x )
+--R         + 
+--R                 3 8 5        2 10 4         12 3     n 7
+--R           (1344a b c  + 2240a b  c  + 448a b  c )x (x )
+--R         + 
+--R                 4 7 5        3 9 4        2 11 3     n 6
+--R           (4704a b c  + 7840a b c  + 1568a b  c )x (x )
+--R         + 
+--R                 5 6 5         4 8 4        3 10 3     n 5
+--R           (9408a b c  + 15680a b c  + 3136a b  c )x (x )
+--R         + 
+--R                  6 5 5         5 7 4        4 9 3     n 4
+--R           (11760a b c  + 19600a b c  + 3920a b c )x (x )
+--R         + 
+--R                 7 4 5         6 6 4        5 8 3     n 3
+--R           (9408a b c  + 15680a b c  + 3136a b c )x (x )
+--R         + 
+--R                 8 3 5        7 5 4        6 7 3     n 2
+--R           (4704a b c  + 7840a b c  + 1568a b c )x (x )
+--R         + 
+--R                 9 2 5        8 4 4       7 6 3    n
+--R           (1344a b c  + 2240a b c  + 448a b c )x x
+--R         + 
+--R                10   5       9 3 4      8 5 3
+--R           (168a  b c  + 280a b c  + 56a b c )x
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R               3 13       2 2 12         4 11      6 10     2n 8
+--R           (56a c   + 420a b c   + 280a b c   + 28b c  )x (x  )
+--R         + 
+--R                    3   12        2 3 11          5 10       7 9    n
+--R               (448a b c   + 3360a b c   + 2240a b c   + 224b c )x x
+--R             + 
+--R                    4 12        3 2 11        2 4 10         6 9
+--R               (448a c   + 3360a b c   + 2240a b c   + 224a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                     3 2 11         2 4 10          6 9       8 8     n 2
+--R               (1568a b c   + 11760a b c   + 7840a b c  + 784b c )x (x )
+--R             + 
+--R                     4   11         3 3 10         2 5 9          7 8    n
+--R               (3136a b c   + 23520a b c   + 15680a b c  + 1568a b c )x x
+--R             + 
+--R                     5 11         4 2 10        3 4 9       2 6 8
+--R               (1568a c   + 11760a b c   + 7840a b c  + 784a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     3 3 10         2 5 9           7 8        9 7     n 3
+--R               (3136a b c   + 23520a b c  + 15680a b c  + 1568b c )x (x )
+--R             + 
+--R                     4 2 10         3 4 9         2 6 8          8 7     n 2
+--R               (9408a b c   + 70560a b c  + 47040a b c  + 4704a b c )x (x )
+--R             + 
+--R                     5   10         4 3 9         3 5 8        2 7 7    n
+--R               (9408a b c   + 70560a b c  + 47040a b c  + 4704a b c )x x
+--R             + 
+--R                     6 10         5 2 9         4 4 8        3 6 7
+--R               (3136a c   + 23520a b c  + 15680a b c  + 1568a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     3 4 9         2 6 8           8 7        10 6     n 4
+--R               (3920a b c  + 29400a b c  + 19600a b c  + 1960b  c )x (x )
+--R             + 
+--R                      4 3 9          3 5 8         2 7 7          9 6     n 3
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b c )x (x )
+--R             + 
+--R                      5 2 9          4 4 8          3 6 7         2 8 6     n 2
+--R               (23520a b c  + 176400a b c  + 117600a b c  + 11760a b c )x (x )
+--R             + 
+--R                      6   9          5 3 8         4 5 7        3 7 6    n
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b c )x x
+--R             + 
+--R                     7 9         6 2 8         5 4 7        4 6 6
+--R               (3920a c  + 29400a b c  + 19600a b c  + 1960a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     3 5 8         2 7 7           9 6        11 5     n 5
+--R               (3136a b c  + 23520a b c  + 15680a b c  + 1568b  c )x (x )
+--R             + 
+--R                      4 4 8          3 6 7         2 8 6          10 5     n 4
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b  c )x (x )
+--R             + 
+--R                      5 3 8          4 5 7          3 7 6         2 9 5     n 3
+--R               (31360a b c  + 235200a b c  + 156800a b c  + 15680a b c )x (x )
+--R             + 
+--R                      6 2 8          5 4 7          4 6 6         3 8 5     n 2
+--R               (31360a b c  + 235200a b c  + 156800a b c  + 15680a b c )x (x )
+--R             + 
+--R                      7   8          6 3 7         5 5 6        4 7 5    n
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b c )x x
+--R             + 
+--R                     8 8         7 2 7         6 4 6        5 6 5
+--R               (3136a c  + 23520a b c  + 15680a b c  + 1568a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     3 6 7         2 8 6          10 5       12 4     n 6
+--R               (1568a b c  + 11760a b c  + 7840a b  c  + 784b  c )x (x )
+--R             + 
+--R                     4 5 7         3 7 6         2 9 5          11 4     n 5
+--R               (9408a b c  + 70560a b c  + 47040a b c  + 4704a b  c )x (x )
+--R             + 
+--R                      5 4 7          4 6 6          3 8 5         2 10 4     n 4
+--R               (23520a b c  + 176400a b c  + 117600a b c  + 11760a b  c )x (x )
+--R             + 
+--R                      6 3 7          5 5 6          4 7 5         3 9 4     n 3
+--R               (31360a b c  + 235200a b c  + 156800a b c  + 15680a b c )x (x )
+--R             + 
+--R                      7 2 7          6 4 6          5 6 5         4 8 4     n 2
+--R               (23520a b c  + 176400a b c  + 117600a b c  + 11760a b c )x (x )
+--R             + 
+--R                     8   7         7 3 6         6 5 5        5 7 4    n
+--R               (9408a b c  + 70560a b c  + 47040a b c  + 4704a b c )x x
+--R             + 
+--R                     9 7         8 2 6        7 4 5       6 6 4
+--R               (1568a c  + 11760a b c  + 7840a b c  + 784a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    3 7 6        2 9 5          11 4       13 3     n 7
+--R               (448a b c  + 3360a b c  + 2240a b  c  + 224b  c )x (x )
+--R             + 
+--R                     4 6 6         3 8 5         2 10 4          12 3     n 6
+--R               (3136a b c  + 23520a b c  + 15680a b  c  + 1568a b  c )x (x )
+--R             + 
+--R                     5 5 6         4 7 5         3 9 4        2 11 3     n 5
+--R               (9408a b c  + 70560a b c  + 47040a b c  + 4704a b  c )x (x )
+--R             + 
+--R                      6 4 6          5 6 5         4 8 4        3 10 3     n 4
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b  c )x (x )
+--R             + 
+--R                      7 3 6          6 5 5         5 7 4        4 9 3     n 3
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b c )x (x )
+--R             + 
+--R                     8 2 6         7 4 5         6 6 4        5 8 3     n 2
+--R               (9408a b c  + 70560a b c  + 47040a b c  + 4704a b c )x (x )
+--R             + 
+--R                     9   6         8 3 5         7 5 4        6 7 3    n
+--R               (3136a b c  + 23520a b c  + 15680a b c  + 1568a b c )x x
+--R             + 
+--R                    10 6        9 2 5        8 4 4       7 6 3
+--R               (448a  c  + 3360a b c  + 2240a b c  + 224a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               3 8 5       2 10 4         12 3      14 2     n 8
+--R           (56a b c  + 420a b  c  + 280a b  c  + 28b  c )x (x )
+--R         + 
+--R                4 7 5        3 9 4        2 11 3         13 2     n 7
+--R           (448a b c  + 3360a b c  + 2240a b  c  + 224a b  c )x (x )
+--R         + 
+--R                 5 6 5         4 8 4        3 10 3       2 12 2     n 6
+--R           (1568a b c  + 11760a b c  + 7840a b  c  + 784a b  c )x (x )
+--R         + 
+--R                 6 5 5         5 7 4         4 9 3        3 11 2     n 5
+--R           (3136a b c  + 23520a b c  + 15680a b c  + 1568a b  c )x (x )
+--R         + 
+--R                 7 4 5         6 6 4         5 8 3        4 10 2     n 4
+--R           (3920a b c  + 29400a b c  + 19600a b c  + 1960a b  c )x (x )
+--R         + 
+--R                 8 3 5         7 5 4         6 7 3        5 9 2     n 3
+--R           (3136a b c  + 23520a b c  + 15680a b c  + 1568a b c )x (x )
+--R         + 
+--R                 9 2 5         8 4 4        7 6 3       6 8 2     n 2
+--R           (1568a b c  + 11760a b c  + 7840a b c  + 784a b c )x (x )
+--R         + 
+--R                10   5        9 3 4        8 5 3       7 7 2    n
+--R           (448a  b c  + 3360a b c  + 2240a b c  + 224a b c )x x
+--R         + 
+--R               11 5       10 2 4       9 4 3      8 6 2
+--R           (56a  c  + 420a  b c  + 280a b c  + 28a b c )x
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                3   12       2 3 11         5 10     7 9     2n 8
+--R           (280a b c   + 560a b c   + 168a b c   + 8b c )x (x  )
+--R         + 
+--R                     3 2 11        2 4 10          6 9      8 8    n
+--R               (2240a b c   + 4480a b c   + 1344a b c  + 64b c )x x
+--R             + 
+--R                     4   11        3 3 10        2 5 9        7 8
+--R               (2240a b c   + 4480a b c   + 1344a b c  + 64a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                     3 3 10         2 5 9          7 8       9 7     n 2
+--R               (7840a b c   + 15680a b c  + 4704a b c  + 224b c )x (x )
+--R             + 
+--R                      4 2 10         3 4 9        2 6 8         8 7    n
+--R               (15680a b c   + 31360a b c  + 9408a b c  + 448a b c )x x
+--R             + 
+--R                     5   10         4 3 9        3 5 8       2 7 7
+--R               (7840a b c   + 15680a b c  + 4704a b c  + 224a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                      3 4 9         2 6 8          8 7       10 6     n 3
+--R               (15680a b c  + 31360a b c  + 9408a b c  + 448b  c )x (x )
+--R             + 
+--R                      4 3 9         3 5 8         2 7 7          9 6     n 2
+--R               (47040a b c  + 94080a b c  + 28224a b c  + 1344a b c )x (x )
+--R             + 
+--R                      5 2 9         4 4 8         3 6 7        2 8 6    n
+--R               (47040a b c  + 94080a b c  + 28224a b c  + 1344a b c )x x
+--R             + 
+--R                      6   9         5 3 8        4 5 7       3 7 6
+--R               (15680a b c  + 31360a b c  + 9408a b c  + 448a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      3 5 8         2 7 7           9 6       11 5     n 4
+--R               (19600a b c  + 39200a b c  + 11760a b c  + 560b  c )x (x )
+--R             + 
+--R                      4 4 8          3 6 7         2 8 6          10 5     n 3
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b  c )x (x )
+--R             + 
+--R                       5 3 8          4 5 7         3 7 6        2 9 5     n 2
+--R               (117600a b c  + 235200a b c  + 70560a b c  + 3360a b c )x (x )
+--R             + 
+--R                      6 2 8          5 4 7         4 6 6        3 8 5    n
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b c )x x
+--R             + 
+--R                      7   8         6 3 7         5 5 6       4 7 5
+--R               (19600a b c  + 39200a b c  + 11760a b c  + 560a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      3 6 7         2 8 6          10 5       12 4     n 5
+--R               (15680a b c  + 31360a b c  + 9408a b  c  + 448b  c )x (x )
+--R             + 
+--R                      4 5 7          3 7 6         2 9 5          11 4     n 4
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b  c )x (x )
+--R             + 
+--R                       5 4 7          4 6 6         3 8 5        2 10 4     n 3
+--R               (156800a b c  + 313600a b c  + 94080a b c  + 4480a b  c )x (x )
+--R             + 
+--R                       6 3 7          5 5 6         4 7 5        3 9 4     n 2
+--R               (156800a b c  + 313600a b c  + 94080a b c  + 4480a b c )x (x )
+--R             + 
+--R                      7 2 7          6 4 6         5 6 5        4 8 4    n
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b c )x x
+--R             + 
+--R                      8   7         7 3 6        6 5 5       5 7 4
+--R               (15680a b c  + 31360a b c  + 9408a b c  + 448a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     3 7 6         2 9 5          11 4       13 3     n 6
+--R               (7840a b c  + 15680a b c  + 4704a b  c  + 224b  c )x (x )
+--R             + 
+--R                      4 6 6         3 8 5         2 10 4          12 3     n 5
+--R               (47040a b c  + 94080a b c  + 28224a b  c  + 1344a b  c )x (x )
+--R             + 
+--R                       5 5 6          4 7 5         3 9 4        2 11 3     n 4
+--R               (117600a b c  + 235200a b c  + 70560a b c  + 3360a b  c )x (x )
+--R             + 
+--R                       6 4 6          5 6 5         4 8 4        3 10 3     n 3
+--R               (156800a b c  + 313600a b c  + 94080a b c  + 4480a b  c )x (x )
+--R             + 
+--R                       7 3 6          6 5 5         5 7 4        4 9 3     n 2
+--R               (117600a b c  + 235200a b c  + 70560a b c  + 3360a b c )x (x )
+--R             + 
+--R                      8 2 6         7 4 5         6 6 4        5 8 3    n
+--R               (47040a b c  + 94080a b c  + 28224a b c  + 1344a b c )x x
+--R             + 
+--R                     9   6         8 3 5        7 5 4       6 7 3
+--R               (7840a b c  + 15680a b c  + 4704a b c  + 224a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     3 8 5        2 10 4          12 3      14 2     n 7
+--R               (2240a b c  + 4480a b  c  + 1344a b  c  + 64b  c )x (x )
+--R             + 
+--R                      4 7 5         3 9 4        2 11 3         13 2     n 6
+--R               (15680a b c  + 31360a b c  + 9408a b  c  + 448a b  c )x (x )
+--R             + 
+--R                      5 6 5         4 8 4         3 10 3        2 12 2     n 5
+--R               (47040a b c  + 94080a b c  + 28224a b  c  + 1344a b  c )x (x )
+--R             + 
+--R                      6 5 5          5 7 4         4 9 3        3 11 2     n 4
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b  c )x (x )
+--R             + 
+--R                      7 4 5          6 6 4         5 8 3        4 10 2     n 3
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b  c )x (x )
+--R             + 
+--R                      8 3 5         7 5 4         6 7 3        5 9 2     n 2
+--R               (47040a b c  + 94080a b c  + 28224a b c  + 1344a b c )x (x )
+--R             + 
+--R                      9 2 5         8 4 4        7 6 3       6 8 2    n
+--R               (15680a b c  + 31360a b c  + 9408a b c  + 448a b c )x x
+--R             + 
+--R                     10   5        9 3 4        8 5 3      7 7 2
+--R               (2240a  b c  + 4480a b c  + 1344a b c  + 64a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                3 9 4       2 11 3         13 2     15      n 8
+--R           (280a b c  + 560a b  c  + 168a b  c  + 8b  c)x (x )
+--R         + 
+--R                 4 8 4        3 10 3        2 12 2        14      n 7
+--R           (2240a b c  + 4480a b  c  + 1344a b  c  + 64a b  c)x (x )
+--R         + 
+--R                 5 7 4         4 9 3        3 11 2       2 13      n 6
+--R           (7840a b c  + 15680a b c  + 4704a b  c  + 224a b  c)x (x )
+--R         + 
+--R                  6 6 4         5 8 3        4 10 2       3 12      n 5
+--R           (15680a b c  + 31360a b c  + 9408a b  c  + 448a b  c)x (x )
+--R         + 
+--R                  7 5 4         6 7 3         5 9 2       4 11      n 4
+--R           (19600a b c  + 39200a b c  + 11760a b c  + 560a b  c)x (x )
+--R         + 
+--R                  8 4 4         7 6 3        6 8 2       5 10      n 3
+--R           (15680a b c  + 31360a b c  + 9408a b c  + 448a b  c)x (x )
+--R         + 
+--R                 9 3 4         8 5 3        7 7 2       6 9      n 2
+--R           (7840a b c  + 15680a b c  + 4704a b c  + 224a b c)x (x )
+--R         + 
+--R                 10 2 4        9 4 3        8 6 2      7 8     n
+--R           (2240a  b c  + 4480a b c  + 1344a b c  + 64a b c)x x
+--R         + 
+--R                11   4       10 3 3       9 5 2     8 7
+--R           (280a  b c  + 560a  b c  + 168a b c  + 8a b c)x
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R               4 12       3 2 11       2 4 10        6 9    8 8     2n 8
+--R           (70a c   + 560a b c   + 420a b c   + 56a b c  + b c )x (x  )
+--R         + 
+--R                    4   11        3 3 10        2 5 9         7 8     9 7    n
+--R               (560a b c   + 4480a b c   + 3360a b c  + 448a b c  + 8b c )x x
+--R             + 
+--R                    5 11        4 2 10        3 4 9       2 6 8       8 7
+--R               (560a c   + 4480a b c   + 3360a b c  + 448a b c  + 8a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                          4 2 10         3 4 9         2 6 8          8 7
+--R                     1960a b c   + 15680a b c  + 11760a b c  + 1568a b c
+--R                   + 
+--R                        10 6
+--R                     28b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                          5   10         4 3 9         3 5 8        2 7 7
+--R                     3920a b c   + 31360a b c  + 23520a b c  + 3136a b c
+--R                   + 
+--R                          9 6
+--R                     56a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                     6 10         5 2 9         4 4 8        3 6 7      2 8 6
+--R               (1960a c   + 15680a b c  + 11760a b c  + 1568a b c  + 28a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                       4 3 9         3 5 8         2 7 7          9 6      11 5
+--R                 (3920a b c  + 31360a b c  + 23520a b c  + 3136a b c  + 56b  c )
+--R              *
+--R                     n 3
+--R                 x (x )
+--R             + 
+--R                         5 2 9         4 4 8         3 6 7        2 8 6
+--R                   11760a b c  + 94080a b c  + 70560a b c  + 9408a b c
+--R                 + 
+--R                         10 5
+--R                   168a b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                         6   9         5 3 8         4 5 7        3 7 6
+--R                   11760a b c  + 94080a b c  + 70560a b c  + 9408a b c
+--R                 + 
+--R                       2 9 5
+--R                   168a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                     7 9         6 2 8         5 4 7        4 6 6      3 8 5
+--R               (3920a c  + 31360a b c  + 23520a b c  + 3136a b c  + 56a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                          4 4 8         3 6 7         2 8 6          10 5
+--R                     4900a b c  + 39200a b c  + 29400a b c  + 3920a b  c
+--R                   + 
+--R                        12 4
+--R                     70b  c
+--R              *
+--R                     n 4
+--R                 x (x )
+--R             + 
+--R                         5 3 8          4 5 7          3 7 6         2 9 5
+--R                   19600a b c  + 156800a b c  + 117600a b c  + 15680a b c
+--R                 + 
+--R                         11 4
+--R                   280a b  c
+--R              *
+--R                     n 3
+--R                 x (x )
+--R             + 
+--R                         6 2 8          5 4 7          4 6 6         3 8 5
+--R                   29400a b c  + 235200a b c  + 176400a b c  + 23520a b c
+--R                 + 
+--R                       2 10 4
+--R                   420a b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                         7   8          6 3 7          5 5 6         4 7 5
+--R                   19600a b c  + 156800a b c  + 117600a b c  + 15680a b c
+--R                 + 
+--R                       3 9 4
+--R                   280a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                     8 8         7 2 7         6 4 6        5 6 5      4 8 4
+--R               (4900a c  + 39200a b c  + 29400a b c  + 3920a b c  + 70a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                          4 5 7         3 7 6         2 9 5          11 4
+--R                     3920a b c  + 31360a b c  + 23520a b c  + 3136a b  c
+--R                   + 
+--R                        13 3
+--R                     56b  c
+--R              *
+--R                     n 5
+--R                 x (x )
+--R             + 
+--R                         5 4 7          4 6 6          3 8 5         2 10 4
+--R                   19600a b c  + 156800a b c  + 117600a b c  + 15680a b  c
+--R                 + 
+--R                         12 3
+--R                   280a b  c
+--R              *
+--R                     n 4
+--R                 x (x )
+--R             + 
+--R                         6 3 7          5 5 6          4 7 5         3 9 4
+--R                   39200a b c  + 313600a b c  + 235200a b c  + 31360a b c
+--R                 + 
+--R                       2 11 3
+--R                   560a b  c
+--R              *
+--R                     n 3
+--R                 x (x )
+--R             + 
+--R                         7 2 7          6 4 6          5 6 5         4 8 4
+--R                   39200a b c  + 313600a b c  + 235200a b c  + 31360a b c
+--R                 + 
+--R                       3 10 3
+--R                   560a b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                         8   7          7 3 6          6 5 5         5 7 4
+--R                   19600a b c  + 156800a b c  + 117600a b c  + 15680a b c
+--R                 + 
+--R                       4 9 3
+--R                   280a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                     9 7         8 2 6         7 4 5        6 6 4      5 8 3
+--R               (3920a c  + 31360a b c  + 23520a b c  + 3136a b c  + 56a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                          4 6 6         3 8 5         2 10 4          12 3
+--R                     1960a b c  + 15680a b c  + 11760a b  c  + 1568a b  c
+--R                   + 
+--R                        14 2
+--R                     28b  c
+--R              *
+--R                     n 6
+--R                 x (x )
+--R             + 
+--R                         5 5 6         4 7 5         3 9 4        2 11 3
+--R                   11760a b c  + 94080a b c  + 70560a b c  + 9408a b  c
+--R                 + 
+--R                         13 2
+--R                   168a b  c
+--R              *
+--R                     n 5
+--R                 x (x )
+--R             + 
+--R                         6 4 6          5 6 5          4 8 4         3 10 3
+--R                   29400a b c  + 235200a b c  + 176400a b c  + 23520a b  c
+--R                 + 
+--R                       2 12 2
+--R                   420a b  c
+--R              *
+--R                     n 4
+--R                 x (x )
+--R             + 
+--R                         7 3 6          6 5 5          5 7 4         4 9 3
+--R                   39200a b c  + 313600a b c  + 235200a b c  + 31360a b c
+--R                 + 
+--R                       3 11 2
+--R                   560a b  c
+--R              *
+--R                     n 3
+--R                 x (x )
+--R             + 
+--R                         8 2 6          7 4 5          6 6 4         5 8 3
+--R                   29400a b c  + 235200a b c  + 176400a b c  + 23520a b c
+--R                 + 
+--R                       4 10 2
+--R                   420a b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                         9   6         8 3 5         7 5 4        6 7 3
+--R                   11760a b c  + 94080a b c  + 70560a b c  + 9408a b c
+--R                 + 
+--R                       5 9 2
+--R                   168a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                     10 6         9 2 5         8 4 4        7 6 3      6 8 2
+--R               (1960a  c  + 15680a b c  + 11760a b c  + 1568a b c  + 28a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                      4 7 5        3 9 4        2 11 3         13 2     15
+--R                 (560a b c  + 4480a b c  + 3360a b  c  + 448a b  c  + 8b  c)x
+--R              *
+--R                   n 7
+--R                 (x )
+--R             + 
+--R                        5 6 5         4 8 4         3 10 3        2 12 2
+--R                   3920a b c  + 31360a b c  + 23520a b  c  + 3136a b  c
+--R                 + 
+--R                        14
+--R                   56a b  c
+--R              *
+--R                     n 6
+--R                 x (x )
+--R             + 
+--R                         6 5 5         5 7 4         4 9 3        3 11 2
+--R                   11760a b c  + 94080a b c  + 70560a b c  + 9408a b  c
+--R                 + 
+--R                       2 13
+--R                   168a b  c
+--R              *
+--R                     n 5
+--R                 x (x )
+--R             + 
+--R                         7 4 5          6 6 4          5 8 3         4 10 2
+--R                   19600a b c  + 156800a b c  + 117600a b c  + 15680a b  c
+--R                 + 
+--R                       3 12
+--R                   280a b  c
+--R              *
+--R                     n 4
+--R                 x (x )
+--R             + 
+--R                         8 3 5          7 5 4          6 7 3         5 9 2
+--R                   19600a b c  + 156800a b c  + 117600a b c  + 15680a b c
+--R                 + 
+--R                       4 11
+--R                   280a b  c
+--R              *
+--R                     n 3
+--R                 x (x )
+--R             + 
+--R                         9 2 5         8 4 4         7 6 3        6 8 2
+--R                   11760a b c  + 94080a b c  + 70560a b c  + 9408a b c
+--R                 + 
+--R                       5 10
+--R                   168a b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                          10   5         9 3 4         8 5 3        7 7 2
+--R                     3920a  b c  + 31360a b c  + 23520a b c  + 3136a b c
+--R                   + 
+--R                        6 9
+--R                     56a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                    11 5        10 2 4        9 4 3       8 6 2     7 8
+--R               (560a  c  + 4480a  b c  + 3360a b c  + 448a b c  + 8a b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               4 8 4       3 10 3       2 12 2        14     16     n 8
+--R           (70a b c  + 560a b  c  + 420a b  c  + 56a b  c + b  )x (x )
+--R         + 
+--R                5 7 4        4 9 3        3 11 2       2 13        15     n 7
+--R           (560a b c  + 4480a b c  + 3360a b  c  + 448a b  c + 8a b  )x (x )
+--R         + 
+--R                   6 6 4         5 8 3         4 10 2        3 12       2 14
+--R             (1960a b c  + 15680a b c  + 11760a b  c  + 1568a b  c + 28a b  )x
+--R          *
+--R               n 6
+--R             (x )
+--R         + 
+--R                   7 5 4         6 7 3         5 9 2        4 11       3 13
+--R             (3920a b c  + 31360a b c  + 23520a b c  + 3136a b  c + 56a b  )x
+--R          *
+--R               n 5
+--R             (x )
+--R         + 
+--R                   8 4 4         7 6 3         6 8 2        5 10       4 12
+--R             (4900a b c  + 39200a b c  + 29400a b c  + 3920a b  c + 70a b  )x
+--R          *
+--R               n 4
+--R             (x )
+--R         + 
+--R                 9 3 4         8 5 3         7 7 2        6 9       5 11     n 3
+--R           (3920a b c  + 31360a b c  + 23520a b c  + 3136a b c + 56a b  )x (x )
+--R         + 
+--R                   10 2 4         9 4 3         8 6 2        7 8       6 10
+--R             (1960a  b c  + 15680a b c  + 11760a b c  + 1568a b c + 28a b  )x
+--R          *
+--R               n 2
+--R             (x )
+--R         + 
+--R                11   4        10 3 3        9 5 2       8 7      7 9    n
+--R           (560a  b c  + 4480a  b c  + 3360a b c  + 448a b c + 8a b )x x
+--R         + 
+--R               12 4       11 2 3       10 4 2      9 6     8 8
+--R           (70a  c  + 560a  b c  + 420a  b c  + 56a b c + a b )x
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R                4   11       3 3 10       2 5 9       7 8     2n 8
+--R           (280a b c   + 560a b c   + 168a b c  + 8a b c )x (x  )
+--R         + 
+--R                     4 2 10        3 4 9        2 6 8        8 7    n
+--R               (2240a b c   + 4480a b c  + 1344a b c  + 64a b c )x x
+--R             + 
+--R                     5   10        4 3 9        3 5 8      2 7 7
+--R               (2240a b c   + 4480a b c  + 1344a b c  + 64a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                     4 3 9         3 5 8        2 7 7         9 6     n 2
+--R               (7840a b c  + 15680a b c  + 4704a b c  + 224a b c )x (x )
+--R             + 
+--R                      5 2 9         4 4 8        3 6 7       2 8 6    n
+--R               (15680a b c  + 31360a b c  + 9408a b c  + 448a b c )x x
+--R             + 
+--R                     6   9         5 3 8        4 5 7       3 7 6
+--R               (7840a b c  + 15680a b c  + 4704a b c  + 224a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                      4 4 8         3 6 7        2 8 6         10 5     n 3
+--R               (15680a b c  + 31360a b c  + 9408a b c  + 448a b  c )x (x )
+--R             + 
+--R                      5 3 8         4 5 7         3 7 6        2 9 5     n 2
+--R               (47040a b c  + 94080a b c  + 28224a b c  + 1344a b c )x (x )
+--R             + 
+--R                      6 2 8         5 4 7         4 6 6        3 8 5    n
+--R               (47040a b c  + 94080a b c  + 28224a b c  + 1344a b c )x x
+--R             + 
+--R                      7   8         6 3 7        5 5 6       4 7 5
+--R               (15680a b c  + 31360a b c  + 9408a b c  + 448a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      4 5 7         3 7 6         2 9 5         11 4     n 4
+--R               (19600a b c  + 39200a b c  + 11760a b c  + 560a b  c )x (x )
+--R             + 
+--R                      5 4 7          4 6 6         3 8 5        2 10 4     n 3
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b  c )x (x )
+--R             + 
+--R                       6 3 7          5 5 6         4 7 5        3 9 4     n 2
+--R               (117600a b c  + 235200a b c  + 70560a b c  + 3360a b c )x (x )
+--R             + 
+--R                      7 2 7          6 4 6         5 6 5        4 8 4    n
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b c )x x
+--R             + 
+--R                      8   7         7 3 6         6 5 5       5 7 4
+--R               (19600a b c  + 39200a b c  + 11760a b c  + 560a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      4 6 6         3 8 5        2 10 4         12 3     n 5
+--R               (15680a b c  + 31360a b c  + 9408a b  c  + 448a b  c )x (x )
+--R             + 
+--R                      5 5 6          4 7 5         3 9 4        2 11 3     n 4
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b  c )x (x )
+--R             + 
+--R                       6 4 6          5 6 5         4 8 4        3 10 3     n 3
+--R               (156800a b c  + 313600a b c  + 94080a b c  + 4480a b  c )x (x )
+--R             + 
+--R                       7 3 6          6 5 5         5 7 4        4 9 3     n 2
+--R               (156800a b c  + 313600a b c  + 94080a b c  + 4480a b c )x (x )
+--R             + 
+--R                      8 2 6          7 4 5         6 6 4        5 8 3    n
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b c )x x
+--R             + 
+--R                      9   6         8 3 5        7 5 4       6 7 3
+--R               (15680a b c  + 31360a b c  + 9408a b c  + 448a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     4 7 5         3 9 4        2 11 3         13 2     n 6
+--R               (7840a b c  + 15680a b c  + 4704a b  c  + 224a b  c )x (x )
+--R             + 
+--R                      5 6 5         4 8 4         3 10 3        2 12 2     n 5
+--R               (47040a b c  + 94080a b c  + 28224a b  c  + 1344a b  c )x (x )
+--R             + 
+--R                       6 5 5          5 7 4         4 9 3        3 11 2     n 4
+--R               (117600a b c  + 235200a b c  + 70560a b c  + 3360a b  c )x (x )
+--R             + 
+--R                       7 4 5          6 6 4         5 8 3        4 10 2     n 3
+--R               (156800a b c  + 313600a b c  + 94080a b c  + 4480a b  c )x (x )
+--R             + 
+--R                       8 3 5          7 5 4         6 7 3        5 9 2     n 2
+--R               (117600a b c  + 235200a b c  + 70560a b c  + 3360a b c )x (x )
+--R             + 
+--R                      9 2 5         8 4 4         7 6 3        6 8 2    n
+--R               (47040a b c  + 94080a b c  + 28224a b c  + 1344a b c )x x
+--R             + 
+--R                     10   5         9 3 4        8 5 3       7 7 2
+--R               (7840a  b c  + 15680a b c  + 4704a b c  + 224a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     4 8 4        3 10 3        2 12 2        14      n 7
+--R               (2240a b c  + 4480a b  c  + 1344a b  c  + 64a b  c)x (x )
+--R             + 
+--R                      5 7 4         4 9 3        3 11 2       2 13      n 6
+--R               (15680a b c  + 31360a b c  + 9408a b  c  + 448a b  c)x (x )
+--R             + 
+--R                      6 6 4         5 8 3         4 10 2        3 12      n 5
+--R               (47040a b c  + 94080a b c  + 28224a b  c  + 1344a b  c)x (x )
+--R             + 
+--R                      7 5 4          6 7 3         5 9 2        4 11      n 4
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b  c)x (x )
+--R             + 
+--R                      8 4 4          7 6 3         6 8 2        5 10      n 3
+--R               (78400a b c  + 156800a b c  + 47040a b c  + 2240a b  c)x (x )
+--R             + 
+--R                      9 3 4         8 5 3         7 7 2        6 9      n 2
+--R               (47040a b c  + 94080a b c  + 28224a b c  + 1344a b c)x (x )
+--R             + 
+--R                      10 2 4         9 4 3        8 6 2       7 8     n
+--R               (15680a  b c  + 31360a b c  + 9408a b c  + 448a b c)x x
+--R             + 
+--R                     11   4        10 3 3        9 5 2      8 7
+--R               (2240a  b c  + 4480a  b c  + 1344a b c  + 64a b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                4 9 3       3 11 2       2 13        15     n 8
+--R           (280a b c  + 560a b  c  + 168a b  c + 8a b  )x (x )
+--R         + 
+--R                 5 8 3        4 10 2        3 12       2 14     n 7
+--R           (2240a b c  + 4480a b  c  + 1344a b  c + 64a b  )x (x )
+--R         + 
+--R                 6 7 3         5 9 2        4 11        3 13     n 6
+--R           (7840a b c  + 15680a b c  + 4704a b  c + 224a b  )x (x )
+--R         + 
+--R                  7 6 3         6 8 2        5 10        4 12     n 5
+--R           (15680a b c  + 31360a b c  + 9408a b  c + 448a b  )x (x )
+--R         + 
+--R                  8 5 3         7 7 2         6 9        5 11     n 4
+--R           (19600a b c  + 39200a b c  + 11760a b c + 560a b  )x (x )
+--R         + 
+--R                  9 4 3         8 6 2        7 8        6 10     n 3
+--R           (15680a b c  + 31360a b c  + 9408a b c + 448a b  )x (x )
+--R         + 
+--R                 10 3 3         9 5 2        8 7        7 9     n 2
+--R           (7840a  b c  + 15680a b c  + 4704a b c + 224a b )x (x )
+--R         + 
+--R                 11 2 3        10 4 2        9 6       8 8    n
+--R           (2240a  b c  + 4480a  b c  + 1344a b c + 64a b )x x
+--R         + 
+--R                12   3       11 3 2       10 5      9 7
+--R           (280a  b c  + 560a  b c  + 168a  b c + 8a b )x
+--R      *
+--R            n log(x) 7
+--R         (%e        )
+--R     + 
+--R               5 11       4 2 10       3 4 9      2 6 8     2n 8
+--R           (56a c   + 420a b c   + 280a b c  + 28a b c )x (x  )
+--R         + 
+--R                    5   10        4 3 9        3 5 8       2 7 7    n
+--R               (448a b c   + 3360a b c  + 2240a b c  + 224a b c )x x
+--R             + 
+--R                    6 10        5 2 9        4 4 8       3 6 7
+--R               (448a c   + 3360a b c  + 2240a b c  + 224a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                     5 2 9         4 4 8        3 6 7       2 8 6     n 2
+--R               (1568a b c  + 11760a b c  + 7840a b c  + 784a b c )x (x )
+--R             + 
+--R                     6   9         5 3 8         4 5 7        3 7 6    n
+--R               (3136a b c  + 23520a b c  + 15680a b c  + 1568a b c )x x
+--R             + 
+--R                     7 9         6 2 8        5 4 7       4 6 6
+--R               (1568a c  + 11760a b c  + 7840a b c  + 784a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     5 3 8         4 5 7         3 7 6        2 9 5     n 3
+--R               (3136a b c  + 23520a b c  + 15680a b c  + 1568a b c )x (x )
+--R             + 
+--R                     6 2 8         5 4 7         4 6 6        3 8 5     n 2
+--R               (9408a b c  + 70560a b c  + 47040a b c  + 4704a b c )x (x )
+--R             + 
+--R                     7   8         6 3 7         5 5 6        4 7 5    n
+--R               (9408a b c  + 70560a b c  + 47040a b c  + 4704a b c )x x
+--R             + 
+--R                     8 8         7 2 7         6 4 6        5 6 5
+--R               (3136a c  + 23520a b c  + 15680a b c  + 1568a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     5 4 7         4 6 6         3 8 5        2 10 4     n 4
+--R               (3920a b c  + 29400a b c  + 19600a b c  + 1960a b  c )x (x )
+--R             + 
+--R                      6 3 7          5 5 6         4 7 5        3 9 4     n 3
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b c )x (x )
+--R             + 
+--R                      7 2 7          6 4 6          5 6 5         4 8 4     n 2
+--R               (23520a b c  + 176400a b c  + 117600a b c  + 11760a b c )x (x )
+--R             + 
+--R                      8   7          7 3 6         6 5 5        5 7 4    n
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b c )x x
+--R             + 
+--R                     9 7         8 2 6         7 4 5        6 6 4
+--R               (3920a c  + 29400a b c  + 19600a b c  + 1960a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     5 5 6         4 7 5         3 9 4        2 11 3     n 5
+--R               (3136a b c  + 23520a b c  + 15680a b c  + 1568a b  c )x (x )
+--R             + 
+--R                      6 4 6          5 6 5         4 8 4        3 10 3     n 4
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b  c )x (x )
+--R             + 
+--R                      7 3 6          6 5 5          5 7 4         4 9 3     n 3
+--R               (31360a b c  + 235200a b c  + 156800a b c  + 15680a b c )x (x )
+--R             + 
+--R                      8 2 6          7 4 5          6 6 4         5 8 3     n 2
+--R               (31360a b c  + 235200a b c  + 156800a b c  + 15680a b c )x (x )
+--R             + 
+--R                      9   6          8 3 5         7 5 4        6 7 3    n
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b c )x x
+--R             + 
+--R                     10 6         9 2 5         8 4 4        7 6 3
+--R               (3136a  c  + 23520a b c  + 15680a b c  + 1568a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     5 6 5         4 8 4        3 10 3       2 12 2     n 6
+--R               (1568a b c  + 11760a b c  + 7840a b  c  + 784a b  c )x (x )
+--R             + 
+--R                     6 5 5         5 7 4         4 9 3        3 11 2     n 5
+--R               (9408a b c  + 70560a b c  + 47040a b c  + 4704a b  c )x (x )
+--R             + 
+--R                      7 4 5          6 6 4          5 8 3         4 10 2     n 4
+--R               (23520a b c  + 176400a b c  + 117600a b c  + 11760a b  c )x (x )
+--R             + 
+--R                      8 3 5          7 5 4          6 7 3         5 9 2     n 3
+--R               (31360a b c  + 235200a b c  + 156800a b c  + 15680a b c )x (x )
+--R             + 
+--R                      9 2 5          8 4 4          7 6 3         6 8 2     n 2
+--R               (23520a b c  + 176400a b c  + 117600a b c  + 11760a b c )x (x )
+--R             + 
+--R                     10   5         9 3 4         8 5 3        7 7 2    n
+--R               (9408a  b c  + 70560a b c  + 47040a b c  + 4704a b c )x x
+--R             + 
+--R                     11 5         10 2 4        9 4 3       8 6 2
+--R               (1568a  c  + 11760a  b c  + 7840a b c  + 784a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    5 7 4        4 9 3        3 11 2       2 13      n 7
+--R               (448a b c  + 3360a b c  + 2240a b  c  + 224a b  c)x (x )
+--R             + 
+--R                     6 6 4         5 8 3         4 10 2        3 12      n 6
+--R               (3136a b c  + 23520a b c  + 15680a b  c  + 1568a b  c)x (x )
+--R             + 
+--R                     7 5 4         6 7 3         5 9 2        4 11      n 5
+--R               (9408a b c  + 70560a b c  + 47040a b c  + 4704a b  c)x (x )
+--R             + 
+--R                      8 4 4          7 6 3         6 8 2        5 10      n 4
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b  c)x (x )
+--R             + 
+--R                      9 3 4          8 5 3         7 7 2        6 9      n 3
+--R               (15680a b c  + 117600a b c  + 78400a b c  + 7840a b c)x (x )
+--R             + 
+--R                     10 2 4         9 4 3         8 6 2        7 8      n 2
+--R               (9408a  b c  + 70560a b c  + 47040a b c  + 4704a b c)x (x )
+--R             + 
+--R                     11   4         10 3 3         9 5 2        8 7     n
+--R               (3136a  b c  + 23520a  b c  + 15680a b c  + 1568a b c)x x
+--R             + 
+--R                    12 4        11 2 3        10 4 2       9 6
+--R               (448a  c  + 3360a  b c  + 2240a  b c  + 224a b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               5 8 3       4 10 2       3 12       2 14     n 8
+--R           (56a b c  + 420a b  c  + 280a b  c + 28a b  )x (x )
+--R         + 
+--R                6 7 3        5 9 2        4 11        3 13     n 7
+--R           (448a b c  + 3360a b c  + 2240a b  c + 224a b  )x (x )
+--R         + 
+--R                 7 6 3         6 8 2        5 10        4 12     n 6
+--R           (1568a b c  + 11760a b c  + 7840a b  c + 784a b  )x (x )
+--R         + 
+--R                 8 5 3         7 7 2         6 9         5 11     n 5
+--R           (3136a b c  + 23520a b c  + 15680a b c + 1568a b  )x (x )
+--R         + 
+--R                 9 4 3         8 6 2         7 8         6 10     n 4
+--R           (3920a b c  + 29400a b c  + 19600a b c + 1960a b  )x (x )
+--R         + 
+--R                 10 3 3         9 5 2         8 7         7 9     n 3
+--R           (3136a  b c  + 23520a b c  + 15680a b c + 1568a b )x (x )
+--R         + 
+--R                 11 2 3         10 4 2        9 6        8 8     n 2
+--R           (1568a  b c  + 11760a  b c  + 7840a b c + 784a b )x (x )
+--R         + 
+--R                12   3        11 3 2        10 5        9 7    n
+--R           (448a  b c  + 3360a  b c  + 2240a  b c + 224a b )x x
+--R         + 
+--R               13 3       12 2 2       11 4       10 6
+--R           (56a  c  + 420a  b c  + 280a  b c + 28a  b )x
+--R      *
+--R            n log(x) 6
+--R         (%e        )
+--R     + 
+--R                5   10       4 3 9      3 5 8     2n 8
+--R           (168a b c   + 280a b c  + 56a b c )x (x  )
+--R         + 
+--R                     5 2 9        4 4 8       3 6 7    n
+--R               (1344a b c  + 2240a b c  + 448a b c )x x
+--R             + 
+--R                     6   9        5 3 8       4 5 7
+--R               (1344a b c  + 2240a b c  + 448a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                     5 3 8        4 5 7        3 7 6     n 2
+--R               (4704a b c  + 7840a b c  + 1568a b c )x (x )
+--R             + 
+--R                     6 2 8         5 4 7        4 6 6    n
+--R               (9408a b c  + 15680a b c  + 3136a b c )x x
+--R             + 
+--R                     7   8        6 3 7        5 5 6
+--R               (4704a b c  + 7840a b c  + 1568a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     5 4 7         4 6 6        3 8 5     n 3
+--R               (9408a b c  + 15680a b c  + 3136a b c )x (x )
+--R             + 
+--R                      6 3 7         5 5 6        4 7 5     n 2
+--R               (28224a b c  + 47040a b c  + 9408a b c )x (x )
+--R             + 
+--R                      7 2 7         6 4 6        5 6 5    n
+--R               (28224a b c  + 47040a b c  + 9408a b c )x x
+--R             + 
+--R                     8   7         7 3 6        6 5 5
+--R               (9408a b c  + 15680a b c  + 3136a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      5 5 6         4 7 5        3 9 4     n 4
+--R               (11760a b c  + 19600a b c  + 3920a b c )x (x )
+--R             + 
+--R                      6 4 6         5 6 5         4 8 4     n 3
+--R               (47040a b c  + 78400a b c  + 15680a b c )x (x )
+--R             + 
+--R                      7 3 6          6 5 5         5 7 4     n 2
+--R               (70560a b c  + 117600a b c  + 23520a b c )x (x )
+--R             + 
+--R                      8 2 6         7 4 5         6 6 4    n
+--R               (47040a b c  + 78400a b c  + 15680a b c )x x
+--R             + 
+--R                      9   6         8 3 5        7 5 4
+--R               (11760a b c  + 19600a b c  + 3920a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     5 6 5         4 8 4        3 10 3     n 5
+--R               (9408a b c  + 15680a b c  + 3136a b  c )x (x )
+--R             + 
+--R                      6 5 5         5 7 4         4 9 3     n 4
+--R               (47040a b c  + 78400a b c  + 15680a b c )x (x )
+--R             + 
+--R                      7 4 5          6 6 4         5 8 3     n 3
+--R               (94080a b c  + 156800a b c  + 31360a b c )x (x )
+--R             + 
+--R                      8 3 5          7 5 4         6 7 3     n 2
+--R               (94080a b c  + 156800a b c  + 31360a b c )x (x )
+--R             + 
+--R                      9 2 5         8 4 4         7 6 3    n
+--R               (47040a b c  + 78400a b c  + 15680a b c )x x
+--R             + 
+--R                     10   5         9 3 4        8 5 3
+--R               (9408a  b c  + 15680a b c  + 3136a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     5 7 4        4 9 3        3 11 2     n 6
+--R               (4704a b c  + 7840a b c  + 1568a b  c )x (x )
+--R             + 
+--R                      6 6 4         5 8 3        4 10 2     n 5
+--R               (28224a b c  + 47040a b c  + 9408a b  c )x (x )
+--R             + 
+--R                      7 5 4          6 7 3         5 9 2     n 4
+--R               (70560a b c  + 117600a b c  + 23520a b c )x (x )
+--R             + 
+--R                      8 4 4          7 6 3         6 8 2     n 3
+--R               (94080a b c  + 156800a b c  + 31360a b c )x (x )
+--R             + 
+--R                      9 3 4          8 5 3         7 7 2     n 2
+--R               (70560a b c  + 117600a b c  + 23520a b c )x (x )
+--R             + 
+--R                      10 2 4         9 4 3        8 6 2    n
+--R               (28224a  b c  + 47040a b c  + 9408a b c )x x
+--R             + 
+--R                     11   4        10 3 3        9 5 2
+--R               (4704a  b c  + 7840a  b c  + 1568a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     5 8 3        4 10 2       3 12      n 7
+--R               (1344a b c  + 2240a b  c  + 448a b  c)x (x )
+--R             + 
+--R                     6 7 3         5 9 2        4 11      n 6
+--R               (9408a b c  + 15680a b c  + 3136a b  c)x (x )
+--R             + 
+--R                      7 6 3         6 8 2        5 10      n 5
+--R               (28224a b c  + 47040a b c  + 9408a b  c)x (x )
+--R             + 
+--R                      8 5 3         7 7 2         6 9      n 4
+--R               (47040a b c  + 78400a b c  + 15680a b c)x (x )
+--R             + 
+--R                      9 4 3         8 6 2         7 8      n 3
+--R               (47040a b c  + 78400a b c  + 15680a b c)x (x )
+--R             + 
+--R                      10 3 3         9 5 2        8 7      n 2
+--R               (28224a  b c  + 47040a b c  + 9408a b c)x (x )
+--R             + 
+--R                     11 2 3         10 4 2        9 6     n
+--R               (9408a  b c  + 15680a  b c  + 3136a b c)x x
+--R             + 
+--R                     12   3        11 3 2       10 5
+--R               (1344a  b c  + 2240a  b c  + 448a  b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                5 9 2       4 11       3 13     n 8
+--R           (168a b c  + 280a b  c + 56a b  )x (x )
+--R         + 
+--R                 6 8 2        5 10        4 12     n 7
+--R           (1344a b c  + 2240a b  c + 448a b  )x (x )
+--R         + 
+--R                 7 7 2        6 9         5 11     n 6
+--R           (4704a b c  + 7840a b c + 1568a b  )x (x )
+--R         + 
+--R                 8 6 2         7 8         6 10     n 5
+--R           (9408a b c  + 15680a b c + 3136a b  )x (x )
+--R         + 
+--R                  9 5 2         8 7         7 9     n 4
+--R           (11760a b c  + 19600a b c + 3920a b )x (x )
+--R         + 
+--R                 10 4 2         9 6         8 8     n 3
+--R           (9408a  b c  + 15680a b c + 3136a b )x (x )
+--R         + 
+--R                 11 3 2        10 5         9 7     n 2
+--R           (4704a  b c  + 7840a  b c + 1568a b )x (x )
+--R         + 
+--R                 12 2 2        11 4        10 6    n
+--R           (1344a  b c  + 2240a  b c + 448a  b )x x
+--R         + 
+--R                13   2       12 3       11 5
+--R           (168a  b c  + 280a  b c + 56a  b )x
+--R      *
+--R            n log(x) 5
+--R         (%e        )
+--R     + 
+--R               6 10       5 2 9      4 4 8     2n 8
+--R           (28a c   + 168a b c  + 70a b c )x (x  )
+--R         + 
+--R                    6   9        5 3 8       4 5 7    n
+--R               (224a b c  + 1344a b c  + 560a b c )x x
+--R             + 
+--R                    7 9        6 2 8       5 4 7
+--R               (224a c  + 1344a b c  + 560a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                    6 2 8        5 4 7        4 6 6     n 2
+--R               (784a b c  + 4704a b c  + 1960a b c )x (x )
+--R             + 
+--R                     7   8        6 3 7        5 5 6    n
+--R               (1568a b c  + 9408a b c  + 3920a b c )x x
+--R             + 
+--R                    8 8        7 2 7        6 4 6
+--R               (784a c  + 4704a b c  + 1960a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     6 3 7        5 5 6        4 7 5     n 3
+--R               (1568a b c  + 9408a b c  + 3920a b c )x (x )
+--R             + 
+--R                     7 2 7         6 4 6         5 6 5     n 2
+--R               (4704a b c  + 28224a b c  + 11760a b c )x (x )
+--R             + 
+--R                     8   7         7 3 6         6 5 5    n
+--R               (4704a b c  + 28224a b c  + 11760a b c )x x
+--R             + 
+--R                     9 7        8 2 6        7 4 5
+--R               (1568a c  + 9408a b c  + 3920a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     6 4 6         5 6 5        4 8 4     n 4
+--R               (1960a b c  + 11760a b c  + 4900a b c )x (x )
+--R             + 
+--R                     7 3 6         6 5 5         5 7 4     n 3
+--R               (7840a b c  + 47040a b c  + 19600a b c )x (x )
+--R             + 
+--R                      8 2 6         7 4 5         6 6 4     n 2
+--R               (11760a b c  + 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                     9   6         8 3 5         7 5 4    n
+--R               (7840a b c  + 47040a b c  + 19600a b c )x x
+--R             + 
+--R                     10 6         9 2 5        8 4 4
+--R               (1960a  c  + 11760a b c  + 4900a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     6 5 5        5 7 4        4 9 3     n 5
+--R               (1568a b c  + 9408a b c  + 3920a b c )x (x )
+--R             + 
+--R                     7 4 5         6 6 4         5 8 3     n 4
+--R               (7840a b c  + 47040a b c  + 19600a b c )x (x )
+--R             + 
+--R                      8 3 5         7 5 4         6 7 3     n 3
+--R               (15680a b c  + 94080a b c  + 39200a b c )x (x )
+--R             + 
+--R                      9 2 5         8 4 4         7 6 3     n 2
+--R               (15680a b c  + 94080a b c  + 39200a b c )x (x )
+--R             + 
+--R                     10   5         9 3 4         8 5 3    n
+--R               (7840a  b c  + 47040a b c  + 19600a b c )x x
+--R             + 
+--R                     11 5        10 2 4        9 4 3
+--R               (1568a  c  + 9408a  b c  + 3920a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                    6 6 4        5 8 3        4 10 2     n 6
+--R               (784a b c  + 4704a b c  + 1960a b  c )x (x )
+--R             + 
+--R                     7 5 4         6 7 3         5 9 2     n 5
+--R               (4704a b c  + 28224a b c  + 11760a b c )x (x )
+--R             + 
+--R                      8 4 4         7 6 3         6 8 2     n 4
+--R               (11760a b c  + 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                      9 3 4         8 5 3         7 7 2     n 3
+--R               (15680a b c  + 94080a b c  + 39200a b c )x (x )
+--R             + 
+--R                      10 2 4         9 4 3         8 6 2     n 2
+--R               (11760a  b c  + 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                     11   4         10 3 3         9 5 2    n
+--R               (4704a  b c  + 28224a  b c  + 11760a b c )x x
+--R             + 
+--R                    12 4        11 2 3        10 4 2
+--R               (784a  c  + 4704a  b c  + 1960a  b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    6 7 3        5 9 2       4 11      n 7
+--R               (224a b c  + 1344a b c  + 560a b  c)x (x )
+--R             + 
+--R                     7 6 3        6 8 2        5 10      n 6
+--R               (1568a b c  + 9408a b c  + 3920a b  c)x (x )
+--R             + 
+--R                     8 5 3         7 7 2         6 9      n 5
+--R               (4704a b c  + 28224a b c  + 11760a b c)x (x )
+--R             + 
+--R                     9 4 3         8 6 2         7 8      n 4
+--R               (7840a b c  + 47040a b c  + 19600a b c)x (x )
+--R             + 
+--R                     10 3 3         9 5 2         8 7      n 3
+--R               (7840a  b c  + 47040a b c  + 19600a b c)x (x )
+--R             + 
+--R                     11 2 3         10 4 2         9 6      n 2
+--R               (4704a  b c  + 28224a  b c  + 11760a b c)x (x )
+--R             + 
+--R                     12   3        11 3 2        10 5     n
+--R               (1568a  b c  + 9408a  b c  + 3920a  b c)x x
+--R             + 
+--R                    13 3        12 2 2       11 4
+--R               (224a  c  + 1344a  b c  + 560a  b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               6 8 2       5 10       4 12     n 8
+--R           (28a b c  + 168a b  c + 70a b  )x (x )
+--R         + 
+--R                7 7 2        6 9        5 11     n 7
+--R           (224a b c  + 1344a b c + 560a b  )x (x )
+--R         + 
+--R                8 6 2        7 8         6 10     n 6
+--R           (784a b c  + 4704a b c + 1960a b  )x (x )
+--R         + 
+--R                 9 5 2        8 7         7 9     n 5
+--R           (1568a b c  + 9408a b c + 3920a b )x (x )
+--R         + 
+--R                 10 4 2         9 6         8 8     n 4
+--R           (1960a  b c  + 11760a b c + 4900a b )x (x )
+--R         + 
+--R                 11 3 2        10 5         9 7     n 3
+--R           (1568a  b c  + 9408a  b c + 3920a b )x (x )
+--R         + 
+--R                12 2 2        11 4         10 6     n 2
+--R           (784a  b c  + 4704a  b c + 1960a  b )x (x )
+--R         + 
+--R                13   2        12 3        11 5    n
+--R           (224a  b c  + 1344a  b c + 560a  b )x x
+--R         + 
+--R               14 2       13 2       12 4
+--R           (28a  c  + 168a  b c + 70a  b )x
+--R      *
+--R            n log(x) 4
+--R         (%e        )
+--R     + 
+--R               6   9      5 3 8     2n 8
+--R           (56a b c  + 56a b c )x (x  )
+--R         + 
+--R                 6 2 8       5 4 7    n        7   8       6 3 7     2n 7
+--R           ((448a b c  + 448a b c )x x  + (448a b c  + 448a b c )x)(x  )
+--R         + 
+--R                     6 3 7        5 5 6     n 2         7 2 7        6 4 6    n
+--R               (1568a b c  + 1568a b c )x (x )  + (3136a b c  + 3136a b c )x x
+--R             + 
+--R                     8   7        7 3 6
+--R               (1568a b c  + 1568a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     6 4 6        5 6 5     n 3
+--R               (3136a b c  + 3136a b c )x (x )
+--R             + 
+--R                     7 3 6        6 5 5     n 2         8 2 6        7 4 5    n
+--R               (9408a b c  + 9408a b c )x (x )  + (9408a b c  + 9408a b c )x x
+--R             + 
+--R                     9   6        8 3 5
+--R               (3136a b c  + 3136a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     6 5 5        5 7 4     n 4
+--R               (3920a b c  + 3920a b c )x (x )
+--R             + 
+--R                      7 4 5         6 6 4     n 3
+--R               (15680a b c  + 15680a b c )x (x )
+--R             + 
+--R                      8 3 5         7 5 4     n 2
+--R               (23520a b c  + 23520a b c )x (x )
+--R             + 
+--R                      9 2 5         8 4 4    n         10   5        9 3 4
+--R               (15680a b c  + 15680a b c )x x  + (3920a  b c  + 3920a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     6 6 4        5 8 3     n 5
+--R               (3136a b c  + 3136a b c )x (x )
+--R             + 
+--R                      7 5 4         6 7 3     n 4
+--R               (15680a b c  + 15680a b c )x (x )
+--R             + 
+--R                      8 4 4         7 6 3     n 3
+--R               (31360a b c  + 31360a b c )x (x )
+--R             + 
+--R                      9 3 4         8 5 3     n 2
+--R               (31360a b c  + 31360a b c )x (x )
+--R             + 
+--R                      10 2 4         9 4 3    n         11   4        10 3 3
+--R               (15680a  b c  + 15680a b c )x x  + (3136a  b c  + 3136a  b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     6 7 3        5 9 2     n 6
+--R               (1568a b c  + 1568a b c )x (x )
+--R             + 
+--R                     7 6 3        6 8 2     n 5
+--R               (9408a b c  + 9408a b c )x (x )
+--R             + 
+--R                      8 5 3         7 7 2     n 4
+--R               (23520a b c  + 23520a b c )x (x )
+--R             + 
+--R                      9 4 3         8 6 2     n 3
+--R               (31360a b c  + 31360a b c )x (x )
+--R             + 
+--R                      10 3 3         9 5 2     n 2
+--R               (23520a  b c  + 23520a b c )x (x )
+--R             + 
+--R                     11 2 3        10 4 2    n         12   3        11 3 2
+--R               (9408a  b c  + 9408a  b c )x x  + (1568a  b c  + 1568a  b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    6 8 2       5 10      n 7         7 7 2        6 9      n 6
+--R               (448a b c  + 448a b  c)x (x )  + (3136a b c  + 3136a b c)x (x )
+--R             + 
+--R                     8 6 2        7 8      n 5
+--R               (9408a b c  + 9408a b c)x (x )
+--R             + 
+--R                      9 5 2         8 7      n 4
+--R               (15680a b c  + 15680a b c)x (x )
+--R             + 
+--R                      10 4 2         9 6      n 3
+--R               (15680a  b c  + 15680a b c)x (x )
+--R             + 
+--R                     11 3 2        10 5      n 2
+--R               (9408a  b c  + 9408a  b c)x (x )
+--R             + 
+--R                     12 2 2        11 4     n        13   2       12 3
+--R               (3136a  b c  + 3136a  b c)x x  + (448a  b c  + 448a  b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               6 9       5 11     n 8        7 8        6 10     n 7
+--R           (56a b c + 56a b  )x (x )  + (448a b c + 448a b  )x (x )
+--R         + 
+--R                 8 7         7 9     n 6         9 6         8 8     n 5
+--R           (1568a b c + 1568a b )x (x )  + (3136a b c + 3136a b )x (x )
+--R         + 
+--R                 10 5         9 7     n 4         11 4         10 6     n 3
+--R           (3920a  b c + 3920a b )x (x )  + (3136a  b c + 3136a  b )x (x )
+--R         + 
+--R                 12 3         11 5     n 2        13 2        12 4    n
+--R           (1568a  b c + 1568a  b )x (x )  + (448a  b c + 448a  b )x x
+--R         + 
+--R               14         13 3
+--R           (56a  b c + 56a  b )x
+--R      *
+--R            n log(x) 3
+--R         (%e        )
+--R     + 
+--R              7 9      6 2 8     2n 8
+--R           (8a c  + 28a b c )x (x  )
+--R         + 
+--R                7   8       6 3 7    n       8 8       7 2 7     2n 7
+--R           ((64a b c  + 224a b c )x x  + (64a c  + 224a b c )x)(x  )
+--R         + 
+--R                    7 2 7       6 4 6     n 2        8   7        7 3 6    n
+--R               (224a b c  + 784a b c )x (x )  + (448a b c  + 1568a b c )x x
+--R             + 
+--R                    9 7       8 2 6
+--R               (224a c  + 784a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                    7 3 6        6 5 5     n 3
+--R               (448a b c  + 1568a b c )x (x )
+--R             + 
+--R                     8 2 6        7 4 5     n 2         9   6        8 3 5    n
+--R               (1344a b c  + 4704a b c )x (x )  + (1344a b c  + 4704a b c )x x
+--R             + 
+--R                    10 6        9 2 5
+--R               (448a  c  + 1568a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                    7 4 5        6 6 4     n 4
+--R               (560a b c  + 1960a b c )x (x )
+--R             + 
+--R                     8 3 5        7 5 4     n 3
+--R               (2240a b c  + 7840a b c )x (x )
+--R             + 
+--R                     9 2 5         8 4 4     n 2
+--R               (3360a b c  + 11760a b c )x (x )
+--R             + 
+--R                     10   5        9 3 4    n        11 5        10 2 4
+--R               (2240a  b c  + 7840a b c )x x  + (560a  c  + 1960a  b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                    7 5 4        6 7 3     n 5
+--R               (448a b c  + 1568a b c )x (x )
+--R             + 
+--R                     8 4 4        7 6 3     n 4
+--R               (2240a b c  + 7840a b c )x (x )
+--R             + 
+--R                     9 3 4         8 5 3     n 3
+--R               (4480a b c  + 15680a b c )x (x )
+--R             + 
+--R                     10 2 4         9 4 3     n 2
+--R               (4480a  b c  + 15680a b c )x (x )
+--R             + 
+--R                     11   4        10 3 3    n        12 4        11 2 3
+--R               (2240a  b c  + 7840a  b c )x x  + (448a  c  + 1568a  b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                    7 6 3       6 8 2     n 6         8 5 3        7 7 2     n 5
+--R               (224a b c  + 784a b c )x (x )  + (1344a b c  + 4704a b c )x (x )
+--R             + 
+--R                     9 4 3         8 6 2     n 4
+--R               (3360a b c  + 11760a b c )x (x )
+--R             + 
+--R                     10 3 3         9 5 2     n 3
+--R               (4480a  b c  + 15680a b c )x (x )
+--R             + 
+--R                     11 2 3         10 4 2     n 2
+--R               (3360a  b c  + 11760a  b c )x (x )
+--R             + 
+--R                     12   3        11 3 2    n        13 3       12 2 2
+--R               (1344a  b c  + 4704a  b c )x x  + (224a  c  + 784a  b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                   7 7 2       6 9      n 7        8 6 2        7 8      n 6
+--R               (64a b c  + 224a b c)x (x )  + (448a b c  + 1568a b c)x (x )
+--R             + 
+--R                     9 5 2        8 7      n 5
+--R               (1344a b c  + 4704a b c)x (x )
+--R             + 
+--R                     10 4 2        9 6      n 4
+--R               (2240a  b c  + 7840a b c)x (x )
+--R             + 
+--R                     11 3 2        10 5      n 3
+--R               (2240a  b c  + 7840a  b c)x (x )
+--R             + 
+--R                     12 2 2        11 4      n 2        13   2        12 3     n
+--R               (1344a  b c  + 4704a  b c)x (x )  + (448a  b c  + 1568a  b c)x x
+--R             + 
+--R                   14 2       13 2
+--R               (64a  c  + 224a  b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R              7 8       6 10     n 8       8 7        7 9     n 7
+--R           (8a b c + 28a b  )x (x )  + (64a b c + 224a b )x (x )
+--R         + 
+--R                9 6        8 8     n 6        10 5         9 7     n 5
+--R           (224a b c + 784a b )x (x )  + (448a  b c + 1568a b )x (x )
+--R         + 
+--R                11 4         10 6     n 4        12 3         11 5     n 3
+--R           (560a  b c + 1960a  b )x (x )  + (448a  b c + 1568a  b )x (x )
+--R         + 
+--R                13 2        12 4     n 2       14          13 3    n
+--R           (224a  b c + 784a  b )x (x )  + (64a  b c + 224a  b )x x
+--R         + 
+--R              15       14 2
+--R           (8a  c + 28a  b )x
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R             7   8    2n 8       7 2 7   n      8   7    2n 7
+--R           8a b c x (x  )  + (64a b c x x  + 64a b c x)(x  )
+--R         + 
+--R                7 3 6    n 2       8 2 6   n       9   6    2n 6
+--R           (224a b c x (x )  + 448a b c x x  + 224a b c x)(x  )
+--R         + 
+--R                     7 4 5    n 3        8 3 5    n 2        9 2 5   n
+--R                 448a b c x (x )  + 1344a b c x (x )  + 1344a b c x x
+--R               + 
+--R                     10   5
+--R                 448a  b c x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                   7 5 4    n 4        8 4 4    n 3        9 3 4    n 2
+--R               560a b c x (x )  + 2240a b c x (x )  + 3360a b c x (x )
+--R             + 
+--R                    10 2 4   n       11   4
+--R               2240a  b c x x  + 560a  b c x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                   7 6 3    n 5        8 5 3    n 4        9 4 3    n 3
+--R               448a b c x (x )  + 2240a b c x (x )  + 4480a b c x (x )
+--R             + 
+--R                    10 3 3    n 2        11 2 3   n       12   3
+--R               4480a  b c x (x )  + 2240a  b c x x  + 448a  b c x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                   7 7 2    n 6        8 6 2    n 5        9 5 2    n 4
+--R               224a b c x (x )  + 1344a b c x (x )  + 3360a b c x (x )
+--R             + 
+--R                    10 4 2    n 3        11 3 2    n 2        12 2 2   n
+--R               4480a  b c x (x )  + 3360a  b c x (x )  + 1344a  b c x x
+--R             + 
+--R                   13   2
+--R               224a  b c x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                  7 8      n 7       8 7      n 6        9 6      n 5
+--R               64a b c x (x )  + 448a b c x (x )  + 1344a b c x (x )
+--R             + 
+--R                    10 5      n 4        11 4      n 3        12 3      n 2
+--R               2240a  b c x (x )  + 2240a  b c x (x )  + 1344a  b c x (x )
+--R             + 
+--R                   13 2     n      14
+--R               448a  b c x x  + 64a  b c x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R             7 9    n 8      8 8    n 7       9 7    n 6       10 6    n 5
+--R           8a b x (x )  + 64a b x (x )  + 224a b x (x )  + 448a  b x (x )
+--R         + 
+--R               11 5    n 4       12 4    n 3       13 3    n 2      14 2   n
+--R           560a  b x (x )  + 448a  b x (x )  + 224a  b x (x )  + 64a  b x x
+--R         + 
+--R             15
+--R           8a  b x
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R        8 8    2n 8      8   7   n     9 7    2n 7
+--R       a c x (x  )  + (8a b c x x  + 8a c x)(x  )
+--R     + 
+--R           8 2 6    n 2      9   6   n      10 6    2n 6
+--R       (28a b c x (x )  + 56a b c x x  + 28a  c x)(x  )
+--R     + 
+--R           8 3 5    n 3       9 2 5    n 2       10   5   n      11 5    2n 5
+--R       (56a b c x (x )  + 168a b c x (x )  + 168a  b c x x  + 56a  c x)(x  )
+--R     + 
+--R              8 4 4    n 4       9 3 4    n 3       10 2 4    n 2
+--R           70a b c x (x )  + 280a b c x (x )  + 420a  b c x (x )
+--R         + 
+--R               11   4   n      12 4
+--R           280a  b c x x  + 70a  c x
+--R      *
+--R           2n 4
+--R         (x  )
+--R     + 
+--R              8 5 3    n 5       9 4 3    n 4       10 3 3    n 3
+--R           56a b c x (x )  + 280a b c x (x )  + 560a  b c x (x )
+--R         + 
+--R               11 2 3    n 2       12   3   n      13 3
+--R           560a  b c x (x )  + 280a  b c x x  + 56a  c x
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R              8 6 2    n 6       9 5 2    n 5       10 4 2    n 4
+--R           28a b c x (x )  + 168a b c x (x )  + 420a  b c x (x )
+--R         + 
+--R               11 3 2    n 3       12 2 2    n 2       13   2   n      14 2
+--R           560a  b c x (x )  + 420a  b c x (x )  + 168a  b c x x  + 28a  c x
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R             8 7      n 7      9 6      n 6       10 5      n 5
+--R           8a b c x (x )  + 56a b c x (x )  + 168a  b c x (x )
+--R         + 
+--R               11 4      n 4       12 3      n 3       13 2      n 2
+--R           280a  b c x (x )  + 280a  b c x (x )  + 168a  b c x (x )
+--R         + 
+--R              14       n     15
+--R           56a  b c x x  + 8a  c x
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R        8 8    n 8     9 7    n 7      10 6    n 6      11 5    n 5
+--R       a b x (x )  + 8a b x (x )  + 28a  b x (x )  + 56a  b x (x )
+--R     + 
+--R          12 4    n 4      13 3    n 3      14 2    n 2     15     n    16
+--R       70a  b x (x )  + 56a  b x (x )  + 28a  b x (x )  + 8a  b x x  + a  x
+--R                                                    Type: Expression(Integer)
+--E 482
+
+)clear all
+
+--S 483 of 649
+t0:=(b+2*c*x)/(-a+b*x+c*x^2)
+--R 
+--R
+--R           2c x + b
+--R   (1)  --------------
+--R           2
+--R        c x  + b x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 483
+
+--S 484 of 649
+r0:=log(a-b*x-c*x^2)
+--R 
+--R
+--R                 2
+--R   (2)  log(- c x  - b x + a)
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R   (3)  log(c x  + b x - a)
+--R                                         Type: Union(Expression(Integer),...)
+--E 485
+
+--S 486 of 649
+m0:=a0-r0
+--R 
+--R
+--R               2                       2
+--R   (4)  log(c x  + b x - a) - log(- c x  - b x + a)
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 487
+
+)clear all
+
+--S 488 of 649
+t0:=x*(b+2*c*x^2)/(-a+b*x^2+c*x^4)
+--R 
+--R
+--R              3
+--R          2c x  + b x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 488
+
+--S 489 of 649
+r0:=1/2*log(a-b*x^2-c*x^4)
+--R 
+--R
+--R                 4      2
+--R        log(- c x  - b x  + a)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4      2
+--R        log(c x  + b x  - a)
+--R   (3)  --------------------
+--R                  2
+--R                                         Type: Union(Expression(Integer),...)
+--E 490
+
+--S 491 of 649
+m0:=a0-r0
+--R 
+--R
+--R               4      2                 4      2
+--R        log(c x  + b x  - a) - log(- c x  - b x  + a)
+--R   (4)  ---------------------------------------------
+--R                              2
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 649
+t0:=x^2*(b+2*c*x^3)/(-a+b*x^3+c*x^6)
+--R 
+--R
+--R              5      2
+--R          2c x  + b x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 493
+
+--S 494 of 649
+r0:=1/3*log(a-b*x^3-c*x^6)
+--R 
+--R
+--R                 6      3
+--R        log(- c x  - b x  + a)
+--R   (2)  ----------------------
+--R                   3
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               6      3
+--R        log(c x  + b x  - a)
+--R   (3)  --------------------
+--R                  3
+--R                                         Type: Union(Expression(Integer),...)
+--E 495
+
+--S 496 of 649
+m0:=a0-r0
+--R 
+--R
+--R               6      3                 6      3
+--R        log(c x  + b x  - a) - log(- c x  - b x  + a)
+--R   (4)  ---------------------------------------------
+--R                              3
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 497
+
+)clear all
+
+--S 498 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)/(-a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 1 n      n - 1
+--R        2c x     x  + b x
+--R   (1)  ----------------------
+--R              2n      n
+--R           c x   + b x  - a
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 649
+r0:=log(a-b*x^n-c*x^(2*n))/n
+--R 
+--R
+--R                 2n      n
+--R        log(- c x   - b x  + a)
+--R   (2)  -----------------------
+--R                   n
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 n log(x) 2       n log(x)
+--R        log(c (%e        )  + b %e         - a)
+--R   (3)  ---------------------------------------
+--R                           n
+--R                                         Type: Union(Expression(Integer),...)
+--E 500
+
+--S 501 of 649
+m0:=a0-r0
+--R 
+--R
+--R                 n log(x) 2       n log(x)                 2n      n
+--R        log(c (%e        )  + b %e         - a) - log(- c x   - b x  + a)
+--R   (4)  -----------------------------------------------------------------
+--R                                        n
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R          2 2n     2   2n - 1         n          n - 1           n log(x) 2
+--R       (2c x   - 2c x x       + 2b c x  - b c x x      - 2a c)(%e        )
+--R     + 
+--R             2n           2n - 1    2 n    2   n - 1         n log(x)
+--R       (b c x   - 2b c x x       + b x  - b x x      - a b)%e
+--R     + 
+--R               2n - 1          n - 1
+--R       2a c x x       + a b x x
+--R  /
+--R         2   2n          n            n log(x) 2
+--R       (c x x   + b c x x  - a c x)(%e        )
+--R     + 
+--R               2n    2   n           n log(x)          2n          n    2
+--R       (b c x x   + b x x  - a b x)%e         - a c x x   - a b x x  + a x
+--R                                                    Type: Expression(Integer)
+--E 502
+
+)clear all
+
+--S 503 of 649
+t0:=(b+2*c*x)/(-a+b*x+c*x^2)^8
+--R 
+--R
+--R   (1)
+--R     2c x + b
+--R  /
+--R        8 16       7 15          7      2 6  14             6      3 5  13
+--R       c x   + 8b c x   + (- 8a c  + 28b c )x   + (- 56a b c  + 56b c )x
+--R     + 
+--R           2 6         2 5      4 4  12        2   5         3 4      5 3  11
+--R       (28a c  - 168a b c  + 70b c )x   + (168a b c  - 280a b c  + 56b c )x
+--R     + 
+--R             3 5       2 2 4         4 3      6 2  10
+--R       (- 56a c  + 420a b c  - 280a b c  + 28b c )x
+--R     + 
+--R              3   4       2 3 3         5 2     7   9
+--R       (- 280a b c  + 560a b c  - 168a b c  + 8b c)x
+--R     + 
+--R           4 4       3 2 3       2 4 2        6     8  8
+--R       (70a c  - 560a b c  + 420a b c  - 56a b c + b )x
+--R     + 
+--R            4   3       3 3 2       2 5        7  7
+--R       (280a b c  - 560a b c  + 168a b c - 8a b )x
+--R     + 
+--R             5 3       4 2 2       3 4       2 6  6
+--R       (- 56a c  + 420a b c  - 280a b c + 28a b )x
+--R     + 
+--R              5   2       4 3       3 5  5       6 2       5 2       4 4  4
+--R       (- 168a b c  + 280a b c - 56a b )x  + (28a c  - 168a b c + 70a b )x
+--R     + 
+--R           6         5 3  3        7       6 2  2     7       8
+--R       (56a b c - 56a b )x  + (- 8a c + 28a b )x  - 8a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 503
+
+--S 504 of 649
+r0:=1/7/(a-b*x-c*x^2)^7
+--R 
+--R
+--R   (2)
+--R   -
+--R        1
+--R        -
+--R        7
+--R     /
+--R           7 14       6 13          6      2 5  12             5      3 4  11
+--R          c x   + 7b c x   + (- 7a c  + 21b c )x   + (- 42a b c  + 35b c )x
+--R        + 
+--R              2 5         2 4      4 3  10        2   4         3 3      5 2  9
+--R          (21a c  - 105a b c  + 35b c )x   + (105a b c  - 140a b c  + 21b c )x
+--R        + 
+--R                3 4       2 2 3         4 2     6   8
+--R          (- 35a c  + 210a b c  - 105a b c  + 7b c)x
+--R        + 
+--R                 3   3       2 3 2        5     7  7
+--R          (- 140a b c  + 210a b c  - 42a b c + b )x
+--R        + 
+--R              4 3       3 2 2       2 4        6  6
+--R          (35a c  - 210a b c  + 105a b c - 7a b )x
+--R        + 
+--R               4   2       3 3       2 5  5         5 2       4 2       3 4  4
+--R          (105a b c  - 140a b c + 21a b )x  + (- 21a c  + 105a b c - 35a b )x
+--R        + 
+--R                5         4 3  3      6       5 2  2     6       7
+--R          (- 42a b c + 35a b )x  + (7a c - 21a b )x  + 7a b x - a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 504
+
+--S 505 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R            7 14        6 13           6       2 5  12
+--R          7c x   + 49b c x   + (- 49a c  + 147b c )x
+--R        + 
+--R                     5       3 4  11        2 5         2 4       4 3  10
+--R          (- 294a b c  + 245b c )x   + (147a c  - 735a b c  + 245b c )x
+--R        + 
+--R               2   4         3 3       5 2  9
+--R          (735a b c  - 980a b c  + 147b c )x
+--R        + 
+--R                 3 4        2 2 3         4 2      6   8
+--R          (- 245a c  + 1470a b c  - 735a b c  + 49b c)x
+--R        + 
+--R                 3   3        2 3 2         5      7  7
+--R          (- 980a b c  + 1470a b c  - 294a b c + 7b )x
+--R        + 
+--R               4 3        3 2 2       2 4         6  6
+--R          (245a c  - 1470a b c  + 735a b c - 49a b )x
+--R        + 
+--R               4   2       3 3        2 5  5
+--R          (735a b c  - 980a b c + 147a b )x
+--R        + 
+--R                 5 2       4 2        3 4  4          5          4 3  3
+--R          (- 147a c  + 735a b c - 245a b )x  + (- 294a b c + 245a b )x
+--R        + 
+--R              6        5 2  2      6        7
+--R          (49a c - 147a b )x  + 49a b x - 7a
+--R                                         Type: Union(Expression(Integer),...)
+--E 505
+
+--S 506 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 649
+t0:=x*(b+2*c*x^2)/(-a+b*x^2+c*x^4)^8
+--R 
+--R
+--R   (1)
+--R         3
+--R     2c x  + b x
+--R  /
+--R        8 32       7 30          7      2 6  28             6      3 5  26
+--R       c x   + 8b c x   + (- 8a c  + 28b c )x   + (- 56a b c  + 56b c )x
+--R     + 
+--R           2 6         2 5      4 4  24        2   5         3 4      5 3  22
+--R       (28a c  - 168a b c  + 70b c )x   + (168a b c  - 280a b c  + 56b c )x
+--R     + 
+--R             3 5       2 2 4         4 3      6 2  20
+--R       (- 56a c  + 420a b c  - 280a b c  + 28b c )x
+--R     + 
+--R              3   4       2 3 3         5 2     7   18
+--R       (- 280a b c  + 560a b c  - 168a b c  + 8b c)x
+--R     + 
+--R           4 4       3 2 3       2 4 2        6     8  16
+--R       (70a c  - 560a b c  + 420a b c  - 56a b c + b )x
+--R     + 
+--R            4   3       3 3 2       2 5        7  14
+--R       (280a b c  - 560a b c  + 168a b c - 8a b )x
+--R     + 
+--R             5 3       4 2 2       3 4       2 6  12
+--R       (- 56a c  + 420a b c  - 280a b c + 28a b )x
+--R     + 
+--R              5   2       4 3       3 5  10       6 2       5 2       4 4  8
+--R       (- 168a b c  + 280a b c - 56a b )x   + (28a c  - 168a b c + 70a b )x
+--R     + 
+--R           6         5 3  6        7       6 2  4     7   2    8
+--R       (56a b c - 56a b )x  + (- 8a c + 28a b )x  - 8a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 508
+
+--S 509 of 649
+r0:=1/14/(a-b*x^2-c*x^4)^7
+--R 
+--R
+--R   (2)
+--R   -
+--R         1
+--R        --
+--R        14
+--R     /
+--R           7 28       6 26          6      2 5  24             5      3 4  22
+--R          c x   + 7b c x   + (- 7a c  + 21b c )x   + (- 42a b c  + 35b c )x
+--R        + 
+--R              2 5         2 4      4 3  20        2   4         3 3      5 2  18
+--R          (21a c  - 105a b c  + 35b c )x   + (105a b c  - 140a b c  + 21b c )x
+--R        + 
+--R                3 4       2 2 3         4 2     6   16
+--R          (- 35a c  + 210a b c  - 105a b c  + 7b c)x
+--R        + 
+--R                 3   3       2 3 2        5     7  14
+--R          (- 140a b c  + 210a b c  - 42a b c + b )x
+--R        + 
+--R              4 3       3 2 2       2 4        6  12
+--R          (35a c  - 210a b c  + 105a b c - 7a b )x
+--R        + 
+--R               4   2       3 3       2 5  10         5 2       4 2       3 4  8
+--R          (105a b c  - 140a b c + 21a b )x   + (- 21a c  + 105a b c - 35a b )x
+--R        + 
+--R                5         4 3  6      6       5 2  4     6   2    7
+--R          (- 42a b c + 35a b )x  + (7a c - 21a b )x  + 7a b x  - a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 509
+
+--S 510 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R             7 28        6 26           6       2 5  24
+--R          14c x   + 98b c x   + (- 98a c  + 294b c )x
+--R        + 
+--R                     5       3 4  22        2 5          2 4       4 3  20
+--R          (- 588a b c  + 490b c )x   + (294a c  - 1470a b c  + 490b c )x
+--R        + 
+--R                2   4          3 3       5 2  18
+--R          (1470a b c  - 1960a b c  + 294b c )x
+--R        + 
+--R                 3 4        2 2 3          4 2      6   16
+--R          (- 490a c  + 2940a b c  - 1470a b c  + 98b c)x
+--R        + 
+--R                  3   3        2 3 2         5       7  14
+--R          (- 1960a b c  + 2940a b c  - 588a b c + 14b )x
+--R        + 
+--R               4 3        3 2 2        2 4         6  12
+--R          (490a c  - 2940a b c  + 1470a b c - 98a b )x
+--R        + 
+--R                4   2        3 3        2 5  10
+--R          (1470a b c  - 1960a b c + 294a b )x
+--R        + 
+--R                 5 2        4 2        3 4  8          5          4 3  6
+--R          (- 294a c  + 1470a b c - 490a b )x  + (- 588a b c + 490a b )x
+--R        + 
+--R              6        5 2  4      6   2      7
+--R          (98a c - 294a b )x  + 98a b x  - 14a
+--R                                         Type: Union(Expression(Integer),...)
+--E 510
+
+--S 511 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 512
+
+)clear all
+
+--S 513 of 649
+t0:=x^2*(b+2*c*x^3)/(-a+b*x^3+c*x^6)^8
+--R 
+--R
+--R   (1)
+--R         5      2
+--R     2c x  + b x
+--R  /
+--R        8 48       7 45          7      2 6  42             6      3 5  39
+--R       c x   + 8b c x   + (- 8a c  + 28b c )x   + (- 56a b c  + 56b c )x
+--R     + 
+--R           2 6         2 5      4 4  36        2   5         3 4      5 3  33
+--R       (28a c  - 168a b c  + 70b c )x   + (168a b c  - 280a b c  + 56b c )x
+--R     + 
+--R             3 5       2 2 4         4 3      6 2  30
+--R       (- 56a c  + 420a b c  - 280a b c  + 28b c )x
+--R     + 
+--R              3   4       2 3 3         5 2     7   27
+--R       (- 280a b c  + 560a b c  - 168a b c  + 8b c)x
+--R     + 
+--R           4 4       3 2 3       2 4 2        6     8  24
+--R       (70a c  - 560a b c  + 420a b c  - 56a b c + b )x
+--R     + 
+--R            4   3       3 3 2       2 5        7  21
+--R       (280a b c  - 560a b c  + 168a b c - 8a b )x
+--R     + 
+--R             5 3       4 2 2       3 4       2 6  18
+--R       (- 56a c  + 420a b c  - 280a b c + 28a b )x
+--R     + 
+--R              5   2       4 3       3 5  15       6 2       5 2       4 4  12
+--R       (- 168a b c  + 280a b c - 56a b )x   + (28a c  - 168a b c + 70a b )x
+--R     + 
+--R           6         5 3  9        7       6 2  6     7   3    8
+--R       (56a b c - 56a b )x  + (- 8a c + 28a b )x  - 8a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 513
+
+--S 514 of 649
+r0:=1/21/(a-b*x^3-c*x^6)^7
+--R 
+--R
+--R   (2)
+--R   -
+--R         1
+--R        --
+--R        21
+--R     /
+--R           7 42       6 39          6      2 5  36             5      3 4  33
+--R          c x   + 7b c x   + (- 7a c  + 21b c )x   + (- 42a b c  + 35b c )x
+--R        + 
+--R              2 5         2 4      4 3  30        2   4         3 3      5 2  27
+--R          (21a c  - 105a b c  + 35b c )x   + (105a b c  - 140a b c  + 21b c )x
+--R        + 
+--R                3 4       2 2 3         4 2     6   24
+--R          (- 35a c  + 210a b c  - 105a b c  + 7b c)x
+--R        + 
+--R                 3   3       2 3 2        5     7  21
+--R          (- 140a b c  + 210a b c  - 42a b c + b )x
+--R        + 
+--R              4 3       3 2 2       2 4        6  18
+--R          (35a c  - 210a b c  + 105a b c - 7a b )x
+--R        + 
+--R               4   2       3 3       2 5  15         5 2       4 2       3 4  12
+--R          (105a b c  - 140a b c + 21a b )x   + (- 21a c  + 105a b c - 35a b )x
+--R        + 
+--R                5         4 3  9      6       5 2  6     6   3    7
+--R          (- 42a b c + 35a b )x  + (7a c - 21a b )x  + 7a b x  - a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 514
+
+--S 515 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R             7 42         6 39            6       2 5  36
+--R          21c x   + 147b c x   + (- 147a c  + 441b c )x
+--R        + 
+--R                     5       3 4  33        2 5          2 4       4 3  30
+--R          (- 882a b c  + 735b c )x   + (441a c  - 2205a b c  + 735b c )x
+--R        + 
+--R                2   4          3 3       5 2  27
+--R          (2205a b c  - 2940a b c  + 441b c )x
+--R        + 
+--R                 3 4        2 2 3          4 2       6   24
+--R          (- 735a c  + 4410a b c  - 2205a b c  + 147b c)x
+--R        + 
+--R                  3   3        2 3 2         5       7  21
+--R          (- 2940a b c  + 4410a b c  - 882a b c + 21b )x
+--R        + 
+--R               4 3        3 2 2        2 4          6  18
+--R          (735a c  - 4410a b c  + 2205a b c - 147a b )x
+--R        + 
+--R                4   2        3 3        2 5  15
+--R          (2205a b c  - 2940a b c + 441a b )x
+--R        + 
+--R                 5 2        4 2        3 4  12          5          4 3  9
+--R          (- 441a c  + 2205a b c - 735a b )x   + (- 882a b c + 735a b )x
+--R        + 
+--R               6        5 2  6       6   3      7
+--R          (147a c - 441a b )x  + 147a b x  - 21a
+--R                                         Type: Union(Expression(Integer),...)
+--E 515
+
+--S 516 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 517
+
+)clear all
+
+--S 518 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)/(-a+b*x^n+c*x^(2*n))^8
+--R 
+--R
+--R   (1)
+--R         n - 1 n      n - 1
+--R     2c x     x  + b x
+--R  /
+--R        8  2n 8        7 n       7   2n 7
+--R       c (x  )  + (8b c x  - 8a c )(x  )
+--R     + 
+--R           2 6  n 2          6 n      2 6   2n 6
+--R       (28b c (x )  - 56a b c x  + 28a c )(x  )
+--R     + 
+--R           3 5  n 3         2 5  n 2       2   5 n      3 5   2n 5
+--R       (56b c (x )  - 168a b c (x )  + 168a b c x  - 56a c )(x  )
+--R     + 
+--R             4 4  n 4         3 4  n 3       2 2 4  n 2       3   4 n      4 4
+--R         (70b c (x )  - 280a b c (x )  + 420a b c (x )  - 280a b c x  + 70a c )
+--R      *
+--R           2n 4
+--R         (x  )
+--R     + 
+--R              5 3  n 5         4 3  n 4       2 3 3  n 3       3 2 3  n 2
+--R           56b c (x )  - 280a b c (x )  + 560a b c (x )  - 560a b c (x )
+--R         + 
+--R               4   3 n      5 3
+--R           280a b c x  - 56a c
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R              6 2  n 6         5 2  n 5       2 4 2  n 4       3 3 2  n 3
+--R           28b c (x )  - 168a b c (x )  + 420a b c (x )  - 560a b c (x )
+--R         + 
+--R               4 2 2  n 2       5   2 n      6 2
+--R           420a b c (x )  - 168a b c x  + 28a c
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R             7    n 7        6    n 6       2 5    n 5       3 4    n 4
+--R           8b c (x )  - 56a b c (x )  + 168a b c (x )  - 280a b c (x )
+--R         + 
+--R               4 3    n 3       5 2    n 2      6     n     7
+--R           280a b c (x )  - 168a b c (x )  + 56a b c x  - 8a c
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R        8  n 8       7  n 7      2 6  n 6      3 5  n 5      4 4  n 4
+--R       b (x )  - 8a b (x )  + 28a b (x )  - 56a b (x )  + 70a b (x )
+--R     + 
+--R            5 3  n 3      6 2  n 2     7   n    8
+--R       - 56a b (x )  + 28a b (x )  - 8a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 649
+r0:=1/7/(n*(a-b*x^n-c*x^(2*n))^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R        1
+--R     /
+--R            7    2n 7         6   n        6    2n 6
+--R          7c n (x  )  + (49b c n x  - 49a c n)(x  )
+--R        + 
+--R               2 5    n 2           5   n       2 5    2n 5
+--R          (147b c n (x )  - 294a b c n x  + 147a c n)(x  )
+--R        + 
+--R               3 4    n 3         2 4    n 2       2   4   n       3 4    2n 4
+--R          (245b c n (x )  - 735a b c n (x )  + 735a b c n x  - 245a c n)(x  )
+--R        + 
+--R                  4 3    n 4         3 3    n 3        2 2 3    n 2
+--R              245b c n (x )  - 980a b c n (x )  + 1470a b c n (x )
+--R            + 
+--R                    3   3   n       4 3
+--R              - 980a b c n x  + 245a c n
+--R         *
+--R              2n 3
+--R            (x  )
+--R        + 
+--R                  5 2    n 5         4 2    n 4        2 3 2    n 3
+--R              147b c n (x )  - 735a b c n (x )  + 1470a b c n (x )
+--R            + 
+--R                     3 2 2    n 2       4   2   n       5 2
+--R              - 1470a b c n (x )  + 735a b c n x  - 147a c n
+--R         *
+--R              2n 2
+--R            (x  )
+--R        + 
+--R                 6      n 6         5      n 5       2 4      n 4
+--R              49b c n (x )  - 294a b c n (x )  + 735a b c n (x )
+--R            + 
+--R                    3 3      n 3       4 2      n 2       5       n      6
+--R              - 980a b c n (x )  + 735a b c n (x )  - 294a b c n x  + 49a c n
+--R         *
+--R             2n
+--R            x
+--R        + 
+--R            7    n 7        6    n 6       2 5    n 5       3 4    n 4
+--R          7b n (x )  - 49a b n (x )  + 147a b n (x )  - 245a b n (x )
+--R        + 
+--R              4 3    n 3       5 2    n 2      6     n     7
+--R          245a b n (x )  - 147a b n (x )  + 49a b n x  - 7a n
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R            7     n log(x) 14        6     n log(x) 13
+--R          7c n (%e        )   + 49b c n (%e        )
+--R        + 
+--R                  6       2 5      n log(x) 12
+--R          (- 49a c  + 147b c )n (%e        )
+--R        + 
+--R                     5       3 4      n log(x) 11
+--R          (- 294a b c  + 245b c )n (%e        )
+--R        + 
+--R               2 5         2 4       4 3      n log(x) 10
+--R          (147a c  - 735a b c  + 245b c )n (%e        )
+--R        + 
+--R               2   4         3 3       5 2      n log(x) 9
+--R          (735a b c  - 980a b c  + 147b c )n (%e        )
+--R        + 
+--R                 3 4        2 2 3         4 2      6       n log(x) 8
+--R          (- 245a c  + 1470a b c  - 735a b c  + 49b c)n (%e        )
+--R        + 
+--R                 3   3        2 3 2         5      7      n log(x) 7
+--R          (- 980a b c  + 1470a b c  - 294a b c + 7b )n (%e        )
+--R        + 
+--R               4 3        3 2 2       2 4         6      n log(x) 6
+--R          (245a c  - 1470a b c  + 735a b c - 49a b )n (%e        )
+--R        + 
+--R               4   2       3 3        2 5      n log(x) 5
+--R          (735a b c  - 980a b c + 147a b )n (%e        )
+--R        + 
+--R                 5 2       4 2        3 4      n log(x) 4
+--R          (- 147a c  + 735a b c - 245a b )n (%e        )
+--R        + 
+--R                 5          4 3      n log(x) 3
+--R          (- 294a b c + 245a b )n (%e        )
+--R        + 
+--R              6        5 2      n log(x) 2      6      n log(x)     7
+--R          (49a c - 147a b )n (%e        )  + 49a b n %e         - 7a n
+--R                                         Type: Union(Expression(Integer),...)
+--E 520
+
+--S 521 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        7   n log(x) 14       6   n log(x) 13          6      2 5    n log(x) 12
+--R       c (%e        )   + 7b c (%e        )   + (- 7a c  + 21b c )(%e        )
+--R     + 
+--R                 5      3 4    n log(x) 11
+--R       (- 42a b c  + 35b c )(%e        )
+--R     + 
+--R           2 5         2 4      4 3    n log(x) 10
+--R       (21a c  - 105a b c  + 35b c )(%e        )
+--R     + 
+--R            2   4         3 3      5 2    n log(x) 9
+--R       (105a b c  - 140a b c  + 21b c )(%e        )
+--R     + 
+--R             3 4       2 2 3         4 2     6     n log(x) 8
+--R       (- 35a c  + 210a b c  - 105a b c  + 7b c)(%e        )
+--R     + 
+--R              3   3       2 3 2        5     7    n log(x) 7
+--R       (- 140a b c  + 210a b c  - 42a b c + b )(%e        )
+--R     + 
+--R           4 3       3 2 2       2 4        6    n log(x) 6
+--R       (35a c  - 210a b c  + 105a b c - 7a b )(%e        )
+--R     + 
+--R            4   2       3 3       2 5    n log(x) 5
+--R       (105a b c  - 140a b c + 21a b )(%e        )
+--R     + 
+--R             5 2       4 2       3 4    n log(x) 4
+--R       (- 21a c  + 105a b c - 35a b )(%e        )
+--R     + 
+--R             5         4 3    n log(x) 3      6       5 2    n log(x) 2
+--R       (- 42a b c + 35a b )(%e        )  + (7a c - 21a b )(%e        )
+--R     + 
+--R         6    n log(x)    7  2n 7          6 n       6   2n 6
+--R       7a b %e         - c (x  )  + (- 7b c x  + 7a c )(x  )
+--R     + 
+--R             2 5  n 2          5 n      2 5   2n 5
+--R       (- 21b c (x )  + 42a b c x  - 21a c )(x  )
+--R     + 
+--R             3 4  n 3         2 4  n 2       2   4 n      3 4   2n 4
+--R       (- 35b c (x )  + 105a b c (x )  - 105a b c x  + 35a c )(x  )
+--R     + 
+--R                  4 3  n 4         3 3  n 3       2 2 3  n 2       3   3 n
+--R             - 35b c (x )  + 140a b c (x )  - 210a b c (x )  + 140a b c x
+--R           + 
+--R                  4 3
+--R             - 35a c
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R                5 2  n 5         4 2  n 4       2 3 2  n 3       3 2 2  n 2
+--R           - 21b c (x )  + 105a b c (x )  - 210a b c (x )  + 210a b c (x )
+--R         + 
+--R                 4   2 n      5 2
+--R           - 105a b c x  + 21a c
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R               6    n 6        5    n 5       2 4    n 4       3 3    n 3
+--R           - 7b c (x )  + 42a b c (x )  - 105a b c (x )  + 140a b c (x )
+--R         + 
+--R                 4 2    n 2      5     n     6
+--R           - 105a b c (x )  + 42a b c x  - 7a c
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R          7  n 7       6  n 6      2 5  n 5      3 4  n 4      4 3  n 3
+--R       - b (x )  + 7a b (x )  - 21a b (x )  + 35a b (x )  - 35a b (x )
+--R     + 
+--R          5 2  n 2     6   n
+--R       21a b (x )  - 7a b x
+--R  /
+--R             14    2n 7         13   n        13    2n 6
+--R           7c  n (x  )  + (49b c  n x  - 49a c  n)(x  )
+--R         + 
+--R                2 12    n 2           12   n       2 12    2n 5
+--R           (147b c  n (x )  - 294a b c  n x  + 147a c  n)(x  )
+--R         + 
+--R                  3 11    n 3         2 11    n 2       2   11   n       3 11
+--R             (245b c  n (x )  - 735a b c  n (x )  + 735a b c  n x  - 245a c  n)
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                   4 10    n 4         3 10    n 3        2 2 10    n 2
+--R               245b c  n (x )  - 980a b c  n (x )  + 1470a b c  n (x )
+--R             + 
+--R                     3   10   n       4 10
+--R               - 980a b c  n x  + 245a c  n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                   5 9    n 5         4 9    n 4        2 3 9    n 3
+--R               147b c n (x )  - 735a b c n (x )  + 1470a b c n (x )
+--R             + 
+--R                      3 2 9    n 2       4   9   n       5 9
+--R               - 1470a b c n (x )  + 735a b c n x  - 147a c n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                  6 8    n 6         5 8    n 5       2 4 8    n 4
+--R               49b c n (x )  - 294a b c n (x )  + 735a b c n (x )
+--R             + 
+--R                     3 3 8    n 3       4 2 8    n 2       5   8   n      6 8
+--R               - 980a b c n (x )  + 735a b c n (x )  - 294a b c n x  + 49a c n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R             7 7    n 7        6 7    n 6       2 5 7    n 5       3 4 7    n 4
+--R           7b c n (x )  - 49a b c n (x )  + 147a b c n (x )  - 245a b c n (x )
+--R         + 
+--R               4 3 7    n 3       5 2 7    n 2      6   7   n     7 7
+--R           245a b c n (x )  - 147a b c n (x )  + 49a b c n x  - 7a c n
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                13    2n 7        2 12   n           12    2n 6
+--R           49b c  n (x  )  + (343b c  n x  - 343a b c  n)(x  )
+--R         + 
+--R                 3 11    n 2          2 11   n        2   11    2n 5
+--R           (1029b c  n (x )  - 2058a b c  n x  + 1029a b c  n)(x  )
+--R         + 
+--R                    4 10    n 3          3 10    n 2        2 2 10   n
+--R               1715b c  n (x )  - 5145a b c  n (x )  + 5145a b c  n x
+--R             + 
+--R                      3   10
+--R               - 1715a b c  n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                    5 9    n 4          4 9    n 3         2 3 9    n 2
+--R               1715b c n (x )  - 6860a b c n (x )  + 10290a b c n (x )
+--R             + 
+--R                      3 2 9   n        4   9
+--R               - 6860a b c n x  + 1715a b c n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                    6 8    n 5          5 8    n 4         2 4 8    n 3
+--R               1029b c n (x )  - 5145a b c n (x )  + 10290a b c n (x )
+--R             + 
+--R                       3 3 8    n 2        4 2 8   n        5   8
+--R               - 10290a b c n (x )  + 5145a b c n x  - 1029a b c n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                   7 7    n 6          6 7    n 5        2 5 7    n 4
+--R               343b c n (x )  - 2058a b c n (x )  + 5145a b c n (x )
+--R             + 
+--R                      3 4 7    n 3        4 3 7    n 2        5 2 7   n
+--R               - 6860a b c n (x )  + 5145a b c n (x )  - 2058a b c n x
+--R             + 
+--R                   6   7
+--R               343a b c n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R              8 6    n 7         7 6    n 6        2 6 6    n 5
+--R           49b c n (x )  - 343a b c n (x )  + 1029a b c n (x )
+--R         + 
+--R                  3 5 6    n 4        4 4 6    n 3        5 3 6    n 2
+--R           - 1715a b c n (x )  + 1715a b c n (x )  - 1029a b c n (x )
+--R         + 
+--R               6 2 6   n      7   6
+--R           343a b c n x  - 49a b c n
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R                   13       2 12     2n 7
+--R           (- 49a c   + 147b c  )n (x  )
+--R         + 
+--R                       12        3 11    n        2 12          2 11     2n 6
+--R           ((- 343a b c   + 1029b c  )n x  + (343a c   - 1029a b c  )n)(x  )
+--R         + 
+--R                         2 11        4 10     n 2
+--R               (- 1029a b c   + 3087b c  )n (x )
+--R             + 
+--R                     2   11          3 10    n           3 11        2 2 10
+--R               (2058a b c   - 6174a b c  )n x  + (- 1029a c   + 3087a b c  )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                         3 10        5 9     n 3
+--R               (- 1715a b c   + 5145b c )n (x )
+--R             + 
+--R                     2 2 10           4 9     n 2
+--R               (5145a b c   - 15435a b c )n (x )
+--R             + 
+--R                       3   10         2 3 9    n         4 10        3 2 9
+--R               (- 5145a b c   + 15435a b c )n x  + (1715a c   - 5145a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                         4 9        6 8     n 4
+--R               (- 1715a b c  + 5145b c )n (x )
+--R             + 
+--R                     2 3 9           5 8     n 3
+--R               (6860a b c  - 20580a b c )n (x )
+--R             + 
+--R                        3 2 9         2 4 8     n 2
+--R               (- 10290a b c  + 30870a b c )n (x )
+--R             + 
+--R                     4   9         3 3 8    n           5 9        4 2 8
+--R               (6860a b c  - 20580a b c )n x  + (- 1715a c  + 5145a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                         5 8        7 7     n 5
+--R               (- 1029a b c  + 3087b c )n (x )
+--R             + 
+--R                     2 4 8           6 7     n 4
+--R               (5145a b c  - 15435a b c )n (x )
+--R             + 
+--R                        3 3 8         2 5 7     n 3
+--R               (- 10290a b c  + 30870a b c )n (x )
+--R             + 
+--R                      4 2 8         3 4 7     n 2
+--R               (10290a b c  - 30870a b c )n (x )
+--R             + 
+--R                       5   8         4 3 7    n         6 8        5 2 7
+--R               (- 5145a b c  + 15435a b c )n x  + (1029a c  - 3087a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                        6 7        8 6     n 6
+--R               (- 343a b c  + 1029b c )n (x )
+--R             + 
+--R                     2 5 7          7 6     n 5
+--R               (2058a b c  - 6174a b c )n (x )
+--R             + 
+--R                       3 4 7         2 6 6     n 4
+--R               (- 5145a b c  + 15435a b c )n (x )
+--R             + 
+--R                     4 3 7         3 5 6     n 3
+--R               (6860a b c  - 20580a b c )n (x )
+--R             + 
+--R                       5 2 7         4 4 6     n 2
+--R               (- 5145a b c  + 15435a b c )n (x )
+--R             + 
+--R                     6   7        5 3 6    n          7 7        6 2 6
+--R               (2058a b c  - 6174a b c )n x  + (- 343a c  + 1029a b c )n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                   7 6       9 5     n 7        2 6 6          8 5     n 6
+--R           (- 49a b c  + 147b c )n (x )  + (343a b c  - 1029a b c )n (x )
+--R         + 
+--R                   3 5 6        2 7 5     n 5         4 4 6        3 6 5     n 4
+--R           (- 1029a b c  + 3087a b c )n (x )  + (1715a b c  - 5145a b c )n (x )
+--R         + 
+--R                   5 3 6        4 5 5     n 3         6 2 6        5 4 5     n 2
+--R           (- 1715a b c  + 5145a b c )n (x )  + (1029a b c  - 3087a b c )n (x )
+--R         + 
+--R                  7   6        6 3 5    n       8 6       7 2 5
+--R           (- 343a b c  + 1029a b c )n x  + (49a c  - 147a b c )n
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                      12       3 11     2n 7
+--R           (- 294a b c   + 245b c  )n (x  )
+--R         + 
+--R                        2 11        4 10    n         2   11          3 10
+--R             ((- 2058a b c   + 1715b c  )n x  + (2058a b c   - 1715a b c  )n)
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                         3 10        5 9     n 2
+--R               (- 6174a b c   + 5145b c )n (x )
+--R             + 
+--R                      2 2 10           4 9    n           3   10        2 3 9
+--R               (12348a b c   - 10290a b c )n x  + (- 6174a b c   + 5145a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                          4 9        6 8     n 3
+--R               (- 10290a b c  + 8575b c )n (x )
+--R             + 
+--R                      2 3 9           5 8     n 2
+--R               (30870a b c  - 25725a b c )n (x )
+--R             + 
+--R                        3 2 9         2 4 8    n          4   9        3 3 8
+--R               (- 30870a b c  + 25725a b c )n x  + (10290a b c  - 8575a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                          5 8        7 7     n 4
+--R               (- 10290a b c  + 8575b c )n (x )
+--R             + 
+--R                      2 4 8           6 7     n 3
+--R               (41160a b c  - 34300a b c )n (x )
+--R             + 
+--R                        3 3 8         2 5 7     n 2
+--R               (- 61740a b c  + 51450a b c )n (x )
+--R             + 
+--R                      4 2 8         3 4 7    n            5   8        4 3 7
+--R               (41160a b c  - 34300a b c )n x  + (- 10290a b c  + 8575a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                         6 7        8 6     n 5
+--R               (- 6174a b c  + 5145b c )n (x )
+--R             + 
+--R                      2 5 7           7 6     n 4
+--R               (30870a b c  - 25725a b c )n (x )
+--R             + 
+--R                        3 4 7         2 6 6     n 3
+--R               (- 61740a b c  + 51450a b c )n (x )
+--R             + 
+--R                      4 3 7         3 5 6     n 2
+--R               (61740a b c  - 51450a b c )n (x )
+--R             + 
+--R                        5 2 7         4 4 6    n         6   7        5 3 6
+--R               (- 30870a b c  + 25725a b c )n x  + (6174a b c  - 5145a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                         7 6        9 5     n 6
+--R               (- 2058a b c  + 1715b c )n (x )
+--R             + 
+--R                      2 6 6           8 5     n 5
+--R               (12348a b c  - 10290a b c )n (x )
+--R             + 
+--R                        3 5 6         2 7 5     n 4
+--R               (- 30870a b c  + 25725a b c )n (x )
+--R             + 
+--R                      4 4 6         3 6 5     n 3
+--R               (41160a b c  - 34300a b c )n (x )
+--R             + 
+--R                        5 3 6         4 5 5     n 2
+--R               (- 30870a b c  + 25725a b c )n (x )
+--R             + 
+--R                      6 2 6         5 4 5    n           7   6        6 3 5
+--R               (12348a b c  - 10290a b c )n x  + (- 2058a b c  + 1715a b c )n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                    8 5       10 4     n 7         2 7 5          9 4     n 6
+--R           (- 294a b c  + 245b  c )n (x )  + (2058a b c  - 1715a b c )n (x )
+--R         + 
+--R                   3 6 5        2 8 4     n 5
+--R           (- 6174a b c  + 5145a b c )n (x )
+--R         + 
+--R                  4 5 5        3 7 4     n 4
+--R           (10290a b c  - 8575a b c )n (x )
+--R         + 
+--R                    5 4 5        4 6 4     n 3
+--R           (- 10290a b c  + 8575a b c )n (x )
+--R         + 
+--R                 6 3 5        5 5 4     n 2           7 2 5        6 4 4    n
+--R           (6174a b c  - 5145a b c )n (x )  + (- 2058a b c  + 1715a b c )n x
+--R         + 
+--R                8   5       7 3 4
+--R           (294a b c  - 245a b c )n
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                2 12         2 11       4 10     2n 7
+--R           (147a c   - 735a b c   + 245b c  )n (x  )
+--R         + 
+--R                     2   11          3 10        5 9    n
+--R               (1029a b c   - 5145a b c   + 1715b c )n x
+--R             + 
+--R                       3 11        2 2 10          4 9
+--R               (- 1029a c   + 5145a b c   - 1715a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     2 2 10           4 9        6 8     n 2
+--R               (3087a b c   - 15435a b c  + 5145b c )n (x )
+--R             + 
+--R                       3   10         2 3 9           5 8    n
+--R               (- 6174a b c   + 30870a b c  - 10290a b c )n x
+--R             + 
+--R                     4 10         3 2 9        2 4 8
+--R               (3087a c   - 15435a b c  + 5145a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     2 3 9           5 8        7 7     n 3
+--R               (5145a b c  - 25725a b c  + 8575b c )n (x )
+--R             + 
+--R                        3 2 9         2 4 8           6 7     n 2
+--R               (- 15435a b c  + 77175a b c  - 25725a b c )n (x )
+--R             + 
+--R                      4   9         3 3 8         2 5 7    n
+--R               (15435a b c  - 77175a b c  + 25725a b c )n x
+--R             + 
+--R                       5 9         4 2 8        3 4 7
+--R               (- 5145a c  + 25725a b c  - 8575a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     2 4 8           6 7        8 6     n 4
+--R               (5145a b c  - 25725a b c  + 8575b c )n (x )
+--R             + 
+--R                        3 3 8          2 5 7           7 6     n 3
+--R               (- 20580a b c  + 102900a b c  - 34300a b c )n (x )
+--R             + 
+--R                      4 2 8          3 4 7         2 6 6     n 2
+--R               (30870a b c  - 154350a b c  + 51450a b c )n (x )
+--R             + 
+--R                        5   8          4 3 7         3 5 6    n
+--R               (- 20580a b c  + 102900a b c  - 34300a b c )n x
+--R             + 
+--R                     6 8         5 2 7        4 4 6
+--R               (5145a c  - 25725a b c  + 8575a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     2 5 7           7 6        9 5     n 5
+--R               (3087a b c  - 15435a b c  + 5145b c )n (x )
+--R             + 
+--R                        3 4 7         2 6 6           8 5     n 4
+--R               (- 15435a b c  + 77175a b c  - 25725a b c )n (x )
+--R             + 
+--R                      4 3 7          3 5 6         2 7 5     n 3
+--R               (30870a b c  - 154350a b c  + 51450a b c )n (x )
+--R             + 
+--R                        5 2 7          4 4 6         3 6 5     n 2
+--R               (- 30870a b c  + 154350a b c  - 51450a b c )n (x )
+--R             + 
+--R                      6   7         5 3 6         4 5 5    n
+--R               (15435a b c  - 77175a b c  + 25725a b c )n x
+--R             + 
+--R                       7 7         6 2 6        5 4 5
+--R               (- 3087a c  + 15435a b c  - 5145a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     2 6 6          8 5        10 4     n 6
+--R               (1029a b c  - 5145a b c  + 1715b  c )n (x )
+--R             + 
+--R                       3 5 6         2 7 5           9 4     n 5
+--R               (- 6174a b c  + 30870a b c  - 10290a b c )n (x )
+--R             + 
+--R                      4 4 6         3 6 5         2 8 4     n 4
+--R               (15435a b c  - 77175a b c  + 25725a b c )n (x )
+--R             + 
+--R                        5 3 6          4 5 5         3 7 4     n 3
+--R               (- 20580a b c  + 102900a b c  - 34300a b c )n (x )
+--R             + 
+--R                      6 2 6         5 4 5         4 6 4     n 2
+--R               (15435a b c  - 77175a b c  + 25725a b c )n (x )
+--R             + 
+--R                       7   6         6 3 5         5 5 4    n
+--R               (- 6174a b c  + 30870a b c  - 10290a b c )n x
+--R             + 
+--R                     8 6        7 2 5        6 4 4
+--R               (1029a c  - 5145a b c  + 1715a b c )n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                2 7 5         9 4       11 3     n 7
+--R           (147a b c  - 735a b c  + 245b  c )n (x )
+--R         + 
+--R                   3 6 5        2 8 4          10 3     n 6
+--R           (- 1029a b c  + 5145a b c  - 1715a b  c )n (x )
+--R         + 
+--R                 4 5 5         3 7 4        2 9 3     n 5
+--R           (3087a b c  - 15435a b c  + 5145a b c )n (x )
+--R         + 
+--R                   5 4 5         4 6 4        3 8 3     n 4
+--R           (- 5145a b c  + 25725a b c  - 8575a b c )n (x )
+--R         + 
+--R                 6 3 5         5 5 4        4 7 3     n 3
+--R           (5145a b c  - 25725a b c  + 8575a b c )n (x )
+--R         + 
+--R                   7 2 5         6 4 4        5 6 3     n 2
+--R           (- 3087a b c  + 15435a b c  - 5145a b c )n (x )
+--R         + 
+--R                 8   5        7 3 4        6 5 3    n
+--R           (1029a b c  - 5145a b c  + 1715a b c )n x
+--R         + 
+--R                  9 5       8 2 4       7 4 3
+--R           (- 147a c  + 735a b c  - 245a b c )n
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                2   11         3 10       5 9     2n 7
+--R           (735a b c   - 980a b c   + 147b c )n (x  )
+--R         + 
+--R                     2 2 10          4 9        6 8    n
+--R               (5145a b c   - 6860a b c  + 1029b c )n x
+--R             + 
+--R                       3   10        2 3 9          5 8
+--R               (- 5145a b c   + 6860a b c  - 1029a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                      2 3 9           5 8        7 7     n 2
+--R               (15435a b c  - 20580a b c  + 3087b c )n (x )
+--R             + 
+--R                        3 2 9         2 4 8          6 7    n
+--R               (- 30870a b c  + 41160a b c  - 6174a b c )n x
+--R             + 
+--R                      4   9         3 3 8        2 5 7
+--R               (15435a b c  - 20580a b c  + 3087a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      2 4 8           6 7        8 6     n 3
+--R               (25725a b c  - 34300a b c  + 5145b c )n (x )
+--R             + 
+--R                        3 3 8          2 5 7           7 6     n 2
+--R               (- 77175a b c  + 102900a b c  - 15435a b c )n (x )
+--R             + 
+--R                      4 2 8          3 4 7         2 6 6    n
+--R               (77175a b c  - 102900a b c  + 15435a b c )n x
+--R             + 
+--R                        5   8         4 3 7        3 5 6
+--R               (- 25725a b c  + 34300a b c  - 5145a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      2 5 7           7 6        9 5     n 4
+--R               (25725a b c  - 34300a b c  + 5145b c )n (x )
+--R             + 
+--R                         3 4 7          2 6 6           8 5     n 3
+--R               (- 102900a b c  + 137200a b c  - 20580a b c )n (x )
+--R             + 
+--R                       4 3 7          3 5 6         2 7 5     n 2
+--R               (154350a b c  - 205800a b c  + 30870a b c )n (x )
+--R             + 
+--R                         5 2 7          4 4 6         3 6 5    n
+--R               (- 102900a b c  + 137200a b c  - 20580a b c )n x
+--R             + 
+--R                      6   7         5 3 6        4 5 5
+--R               (25725a b c  - 34300a b c  + 5145a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                      2 6 6           8 5        10 4     n 5
+--R               (15435a b c  - 20580a b c  + 3087b  c )n (x )
+--R             + 
+--R                        3 5 6          2 7 5           9 4     n 4
+--R               (- 77175a b c  + 102900a b c  - 15435a b c )n (x )
+--R             + 
+--R                       4 4 6          3 6 5         2 8 4     n 3
+--R               (154350a b c  - 205800a b c  + 30870a b c )n (x )
+--R             + 
+--R                         5 3 6          4 5 5         3 7 4     n 2
+--R               (- 154350a b c  + 205800a b c  - 30870a b c )n (x )
+--R             + 
+--R                      6 2 6          5 4 5         4 6 4    n
+--R               (77175a b c  - 102900a b c  + 15435a b c )n x
+--R             + 
+--R                        7   6         6 3 5        5 5 4
+--R               (- 15435a b c  + 20580a b c  - 3087a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     2 7 5          9 4        11 3     n 6
+--R               (5145a b c  - 6860a b c  + 1029b  c )n (x )
+--R             + 
+--R                        3 6 5         2 8 4          10 3     n 5
+--R               (- 30870a b c  + 41160a b c  - 6174a b  c )n (x )
+--R             + 
+--R                      4 5 5          3 7 4         2 9 3     n 4
+--R               (77175a b c  - 102900a b c  + 15435a b c )n (x )
+--R             + 
+--R                         5 4 5          4 6 4         3 8 3     n 3
+--R               (- 102900a b c  + 137200a b c  - 20580a b c )n (x )
+--R             + 
+--R                      6 3 5          5 5 4         4 7 3     n 2
+--R               (77175a b c  - 102900a b c  + 15435a b c )n (x )
+--R             + 
+--R                        7 2 5         6 4 4        5 6 3    n
+--R               (- 30870a b c  + 41160a b c  - 6174a b c )n x
+--R             + 
+--R                     8   5        7 3 4        6 5 3
+--R               (5145a b c  - 6860a b c  + 1029a b c )n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                2 8 4         10 3       12 2     n 7
+--R           (735a b c  - 980a b  c  + 147b  c )n (x )
+--R         + 
+--R                   3 7 4        2 9 3          11 2     n 6
+--R           (- 5145a b c  + 6860a b c  - 1029a b  c )n (x )
+--R         + 
+--R                  4 6 4         3 8 3        2 10 2     n 5
+--R           (15435a b c  - 20580a b c  + 3087a b  c )n (x )
+--R         + 
+--R                    5 5 4         4 7 3        3 9 2     n 4
+--R           (- 25725a b c  + 34300a b c  - 5145a b c )n (x )
+--R         + 
+--R                  6 4 4         5 6 3        4 8 2     n 3
+--R           (25725a b c  - 34300a b c  + 5145a b c )n (x )
+--R         + 
+--R                    7 3 4         6 5 3        5 7 2     n 2
+--R           (- 15435a b c  + 20580a b c  - 3087a b c )n (x )
+--R         + 
+--R                 8 2 4        7 4 3        6 6 2    n
+--R           (5145a b c  - 6860a b c  + 1029a b c )n x
+--R         + 
+--R                  9   4       8 3 3       7 5 2
+--R           (- 735a b c  + 980a b c  - 147a b c )n
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R                  3 11        2 2 10         4 9      6 8     2n 7
+--R           (- 245a c   + 1470a b c   - 735a b c  + 49b c )n (x  )
+--R         + 
+--R                       3   10         2 3 9          5 8       7 7    n
+--R               (- 1715a b c   + 10290a b c  - 5145a b c  + 343b c )n x
+--R             + 
+--R                     4 10         3 2 9        2 4 8         6 7
+--R               (1715a c   - 10290a b c  + 5145a b c  - 343a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                       3 2 9         2 4 8           6 7        8 6     n 2
+--R               (- 5145a b c  + 30870a b c  - 15435a b c  + 1029b c )n (x )
+--R             + 
+--R                      4   9         3 3 8         2 5 7          7 6    n
+--R               (10290a b c  - 61740a b c  + 30870a b c  - 2058a b c )n x
+--R             + 
+--R                       5 9         4 2 8         3 4 7        2 6 6
+--R               (- 5145a c  + 30870a b c  - 15435a b c  + 1029a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                       3 3 8         2 5 7           7 6        9 5     n 3
+--R               (- 8575a b c  + 51450a b c  - 25725a b c  + 1715b c )n (x )
+--R             + 
+--R                      4 2 8          3 4 7         2 6 6          8 5     n 2
+--R               (25725a b c  - 154350a b c  + 77175a b c  - 5145a b c )n (x )
+--R             + 
+--R                        5   8          4 3 7         3 5 6        2 7 5    n
+--R               (- 25725a b c  + 154350a b c  - 77175a b c  + 5145a b c )n x
+--R             + 
+--R                     6 8         5 2 7         4 4 6        3 6 5
+--R               (8575a c  - 51450a b c  + 25725a b c  - 1715a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                       3 4 7         2 6 6           8 5        10 4     n 4
+--R               (- 8575a b c  + 51450a b c  - 25725a b c  + 1715b  c )n (x )
+--R             + 
+--R                      4 3 7          3 5 6          2 7 5          9 4     n 3
+--R               (34300a b c  - 205800a b c  + 102900a b c  - 6860a b c )n (x )
+--R             + 
+--R                          5 2 7          4 4 6          3 6 5         2 8 4
+--R                 (- 51450a b c  + 308700a b c  - 154350a b c  + 10290a b c )n
+--R              *
+--R                   n 2
+--R                 (x )
+--R             + 
+--R                      6   7          5 3 6          4 5 5        3 7 4    n
+--R               (34300a b c  - 205800a b c  + 102900a b c  - 6860a b c )n x
+--R             + 
+--R                       7 7         6 2 6         5 4 5        4 6 4
+--R               (- 8575a c  + 51450a b c  - 25725a b c  + 1715a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                       3 5 6         2 7 5           9 4        11 3     n 5
+--R               (- 5145a b c  + 30870a b c  - 15435a b c  + 1029b  c )n (x )
+--R             + 
+--R                      4 4 6          3 6 5         2 8 4          10 3     n 4
+--R               (25725a b c  - 154350a b c  + 77175a b c  - 5145a b  c )n (x )
+--R             + 
+--R                          5 3 6          4 5 5          3 7 4         2 9 3
+--R                 (- 51450a b c  + 308700a b c  - 154350a b c  + 10290a b c )n
+--R              *
+--R                   n 3
+--R                 (x )
+--R             + 
+--R                      6 2 6          5 4 5          4 6 4         3 8 3     n 2
+--R               (51450a b c  - 308700a b c  + 154350a b c  - 10290a b c )n (x )
+--R             + 
+--R                        7   6          6 3 5         5 5 4        4 7 3    n
+--R               (- 25725a b c  + 154350a b c  - 77175a b c  + 5145a b c )n x
+--R             + 
+--R                     8 6         7 2 5         6 4 4        5 6 3
+--R               (5145a c  - 30870a b c  + 15435a b c  - 1029a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                       3 6 5         2 8 4          10 3       12 2     n 6
+--R               (- 1715a b c  + 10290a b c  - 5145a b  c  + 343b  c )n (x )
+--R             + 
+--R                      4 5 5         3 7 4         2 9 3          11 2     n 5
+--R               (10290a b c  - 61740a b c  + 30870a b c  - 2058a b  c )n (x )
+--R             + 
+--R                        5 4 5          4 6 4         3 8 3        2 10 2     n 4
+--R               (- 25725a b c  + 154350a b c  - 77175a b c  + 5145a b  c )n (x )
+--R             + 
+--R                      6 3 5          5 5 4          4 7 3        3 9 2     n 3
+--R               (34300a b c  - 205800a b c  + 102900a b c  - 6860a b c )n (x )
+--R             + 
+--R                        7 2 5          6 4 4         5 6 3        4 8 2     n 2
+--R               (- 25725a b c  + 154350a b c  - 77175a b c  + 5145a b c )n (x )
+--R             + 
+--R                      8   5         7 3 4         6 5 3        5 7 2    n
+--R               (10290a b c  - 61740a b c  + 30870a b c  - 2058a b c )n x
+--R             + 
+--R                       9 5         8 2 4        7 4 3       6 6 2
+--R               (- 1715a c  + 10290a b c  - 5145a b c  + 343a b c )n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                  3 7 4        2 9 3         11 2      13      n 7
+--R           (- 245a b c  + 1470a b c  - 735a b  c  + 49b  c)n (x )
+--R         + 
+--R                 4 6 4         3 8 3        2 10 2         12      n 6
+--R           (1715a b c  - 10290a b c  + 5145a b  c  - 343a b  c)n (x )
+--R         + 
+--R                   5 5 4         4 7 3         3 9 2        2 11      n 5
+--R           (- 5145a b c  + 30870a b c  - 15435a b c  + 1029a b  c)n (x )
+--R         + 
+--R                 6 4 4         5 6 3         4 8 2        3 10      n 4
+--R           (8575a b c  - 51450a b c  + 25725a b c  - 1715a b  c)n (x )
+--R         + 
+--R                   7 3 4         6 5 3         5 7 2        4 9      n 3
+--R           (- 8575a b c  + 51450a b c  - 25725a b c  + 1715a b c)n (x )
+--R         + 
+--R                 8 2 4         7 4 3         6 6 2        5 8      n 2
+--R           (5145a b c  - 30870a b c  + 15435a b c  - 1029a b c)n (x )
+--R         + 
+--R                   9   4         8 3 3        7 5 2       6 7     n
+--R           (- 1715a b c  + 10290a b c  - 5145a b c  + 343a b c)n x
+--R         + 
+--R                10 4        9 2 3       8 4 2      7 6
+--R           (245a  c  - 1470a b c  + 735a b c  - 49a b c)n
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R                  3   10        2 3 9         5 8     7 7     2n 7
+--R           (- 980a b c   + 1470a b c  - 294a b c  + 7b c )n (x  )
+--R         + 
+--R                       3 2 9         2 4 8          6 7      8 6    n
+--R               (- 6860a b c  + 10290a b c  - 2058a b c  + 49b c )n x
+--R             + 
+--R                     4   9         3 3 8        2 5 7        7 6
+--R               (6860a b c  - 10290a b c  + 2058a b c  - 49a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                        3 3 8         2 5 7          7 6       9 5     n 2
+--R               (- 20580a b c  + 30870a b c  - 6174a b c  + 147b c )n (x )
+--R             + 
+--R                      4 2 8         3 4 7         2 6 6         8 5    n
+--R               (41160a b c  - 61740a b c  + 12348a b c  - 294a b c )n x
+--R             + 
+--R                        5   8         4 3 7        3 5 6       2 7 5
+--R               (- 20580a b c  + 30870a b c  - 6174a b c  + 147a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                        3 4 7         2 6 6           8 5       10 4     n 3
+--R               (- 34300a b c  + 51450a b c  - 10290a b c  + 245b  c )n (x )
+--R             + 
+--R                       4 3 7          3 5 6         2 7 5         9 4     n 2
+--R               (102900a b c  - 154350a b c  + 30870a b c  - 735a b c )n (x )
+--R             + 
+--R                         5 2 7          4 4 6         3 6 5       2 8 4    n
+--R               (- 102900a b c  + 154350a b c  - 30870a b c  + 735a b c )n x
+--R             + 
+--R                      6   7         5 3 6         4 5 5       3 7 4
+--R               (34300a b c  - 51450a b c  + 10290a b c  - 245a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                        3 5 6         2 7 5           9 4       11 3     n 4
+--R               (- 34300a b c  + 51450a b c  - 10290a b c  + 245b  c )n (x )
+--R             + 
+--R                       4 4 6          3 6 5         2 8 4         10 3     n 3
+--R               (137200a b c  - 205800a b c  + 41160a b c  - 980a b  c )n (x )
+--R             + 
+--R                         5 3 6          4 5 5         3 7 4        2 9 3     n 2
+--R               (- 205800a b c  + 308700a b c  - 61740a b c  + 1470a b c )n (x )
+--R             + 
+--R                       6 2 6          5 4 5         4 6 4       3 8 3    n
+--R               (137200a b c  - 205800a b c  + 41160a b c  - 980a b c )n x
+--R             + 
+--R                        7   6         6 3 5         5 5 4       4 7 3
+--R               (- 34300a b c  + 51450a b c  - 10290a b c  + 245a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                        3 6 5         2 8 4          10 3       12 2     n 5
+--R               (- 20580a b c  + 30870a b c  - 6174a b  c  + 147b  c )n (x )
+--R             + 
+--R                       4 5 5          3 7 4         2 9 3         11 2     n 4
+--R               (102900a b c  - 154350a b c  + 30870a b c  - 735a b  c )n (x )
+--R             + 
+--R                           5 4 5          4 6 4         3 8 3        2 10 2
+--R                 (- 205800a b c  + 308700a b c  - 61740a b c  + 1470a b  c )n
+--R              *
+--R                   n 3
+--R                 (x )
+--R             + 
+--R                       6 3 5          5 5 4         4 7 3        3 9 2     n 2
+--R               (205800a b c  - 308700a b c  + 61740a b c  - 1470a b c )n (x )
+--R             + 
+--R                         7 2 5          6 4 4         5 6 3       4 8 2    n
+--R               (- 102900a b c  + 154350a b c  - 30870a b c  + 735a b c )n x
+--R             + 
+--R                      8   5         7 3 4        6 5 3       5 7 2
+--R               (20580a b c  - 30870a b c  + 6174a b c  - 147a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                       3 7 4         2 9 3          11 2      13      n 6
+--R               (- 6860a b c  + 10290a b c  - 2058a b  c  + 49b  c)n (x )
+--R             + 
+--R                      4 6 4         3 8 3         2 10 2         12      n 5
+--R               (41160a b c  - 61740a b c  + 12348a b  c  - 294a b  c)n (x )
+--R             + 
+--R                         5 5 4          4 7 3         3 9 2       2 11      n 4
+--R               (- 102900a b c  + 154350a b c  - 30870a b c  + 735a b  c)n (x )
+--R             + 
+--R                       6 4 4          5 6 3         4 8 2       3 10      n 3
+--R               (137200a b c  - 205800a b c  + 41160a b c  - 980a b  c)n (x )
+--R             + 
+--R                         7 3 4          6 5 3         5 7 2       4 9      n 2
+--R               (- 102900a b c  + 154350a b c  - 30870a b c  + 735a b c)n (x )
+--R             + 
+--R                      8 2 4         7 4 3         6 6 2       5 8     n
+--R               (41160a b c  - 61740a b c  + 12348a b c  - 294a b c)n x
+--R             + 
+--R                       9   4         8 3 3        7 5 2      6 7
+--R               (- 6860a b c  + 10290a b c  - 2058a b c  + 49a b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                  3 8 3        2 10 2         12      14     n 7
+--R           (- 980a b c  + 1470a b  c  - 294a b  c + 7b  )n (x )
+--R         + 
+--R                 4 7 3         3 9 2        2 11         13     n 6
+--R           (6860a b c  - 10290a b c  + 2058a b  c - 49a b  )n (x )
+--R         + 
+--R                    5 6 3         4 8 2        3 10        2 12     n 5
+--R           (- 20580a b c  + 30870a b c  - 6174a b  c + 147a b  )n (x )
+--R         + 
+--R                  6 5 3         5 7 2         4 9        3 11     n 4
+--R           (34300a b c  - 51450a b c  + 10290a b c - 245a b  )n (x )
+--R         + 
+--R                    7 4 3         6 6 2         5 8        4 10     n 3
+--R           (- 34300a b c  + 51450a b c  - 10290a b c + 245a b  )n (x )
+--R         + 
+--R                  8 3 3         7 5 2        6 7        5 9     n 2
+--R           (20580a b c  - 30870a b c  + 6174a b c - 147a b )n (x )
+--R         + 
+--R                   9 2 3         8 4 2        7 6       6 8    n
+--R           (- 6860a b c  + 10290a b c  - 2058a b c + 49a b )n x
+--R         + 
+--R                10   3        9 3 2       8 5      7 7
+--R           (980a  b c  - 1470a b c  + 294a b c - 7a b )n
+--R      *
+--R            n log(x) 7
+--R         (%e        )
+--R     + 
+--R                4 10        3 2 9       2 4 8        6 7     2n 7
+--R           (245a c   - 1470a b c  + 735a b c  - 49a b c )n (x  )
+--R         + 
+--R                     4   9         3 3 8        2 5 7         7 6    n
+--R               (1715a b c  - 10290a b c  + 5145a b c  - 343a b c )n x
+--R             + 
+--R                       5 9         4 2 8        3 4 7       2 6 6
+--R               (- 1715a c  + 10290a b c  - 5145a b c  + 343a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     4 2 8         3 4 7         2 6 6          8 5     n 2
+--R               (5145a b c  - 30870a b c  + 15435a b c  - 1029a b c )n (x )
+--R             + 
+--R                        5   8         4 3 7         3 5 6        2 7 5    n
+--R               (- 10290a b c  + 61740a b c  - 30870a b c  + 2058a b c )n x
+--R             + 
+--R                     6 8         5 2 7         4 4 6        3 6 5
+--R               (5145a c  - 30870a b c  + 15435a b c  - 1029a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     4 3 7         3 5 6         2 7 5          9 4     n 3
+--R               (8575a b c  - 51450a b c  + 25725a b c  - 1715a b c )n (x )
+--R             + 
+--R                        5 2 7          4 4 6         3 6 5        2 8 4     n 2
+--R               (- 25725a b c  + 154350a b c  - 77175a b c  + 5145a b c )n (x )
+--R             + 
+--R                      6   7          5 3 6         4 5 5        3 7 4    n
+--R               (25725a b c  - 154350a b c  + 77175a b c  - 5145a b c )n x
+--R             + 
+--R                       7 7         6 2 6         5 4 5        4 6 4
+--R               (- 8575a c  + 51450a b c  - 25725a b c  + 1715a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     4 4 6         3 6 5         2 8 4          10 3     n 4
+--R               (8575a b c  - 51450a b c  + 25725a b c  - 1715a b  c )n (x )
+--R             + 
+--R                        5 3 6          4 5 5          3 7 4        2 9 3     n 3
+--R               (- 34300a b c  + 205800a b c  - 102900a b c  + 6860a b c )n (x )
+--R             + 
+--R                      6 2 6          5 4 5          4 6 4         3 8 3     n 2
+--R               (51450a b c  - 308700a b c  + 154350a b c  - 10290a b c )n (x )
+--R             + 
+--R                        7   6          6 3 5          5 5 4        4 7 3    n
+--R               (- 34300a b c  + 205800a b c  - 102900a b c  + 6860a b c )n x
+--R             + 
+--R                     8 6         7 2 5         6 4 4        5 6 3
+--R               (8575a c  - 51450a b c  + 25725a b c  - 1715a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     4 5 5         3 7 4         2 9 3          11 2     n 5
+--R               (5145a b c  - 30870a b c  + 15435a b c  - 1029a b  c )n (x )
+--R             + 
+--R                        5 4 5          4 6 4         3 8 3        2 10 2     n 4
+--R               (- 25725a b c  + 154350a b c  - 77175a b c  + 5145a b  c )n (x )
+--R             + 
+--R                      6 3 5          5 5 4          4 7 3         3 9 2     n 3
+--R               (51450a b c  - 308700a b c  + 154350a b c  - 10290a b c )n (x )
+--R             + 
+--R                          7 2 5          6 4 4          5 6 3         4 8 2
+--R                 (- 51450a b c  + 308700a b c  - 154350a b c  + 10290a b c )n
+--R              *
+--R                   n 2
+--R                 (x )
+--R             + 
+--R                      8   5          7 3 4         6 5 3        5 7 2    n
+--R               (25725a b c  - 154350a b c  + 77175a b c  - 5145a b c )n x
+--R             + 
+--R                       9 5         8 2 4         7 4 3        6 6 2
+--R               (- 5145a c  + 30870a b c  - 15435a b c  + 1029a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     4 6 4         3 8 3        2 10 2         12      n 6
+--R               (1715a b c  - 10290a b c  + 5145a b  c  - 343a b  c)n (x )
+--R             + 
+--R                        5 5 4         4 7 3         3 9 2        2 11      n 5
+--R               (- 10290a b c  + 61740a b c  - 30870a b c  + 2058a b  c)n (x )
+--R             + 
+--R                      6 4 4          5 6 3         4 8 2        3 10      n 4
+--R               (25725a b c  - 154350a b c  + 77175a b c  - 5145a b  c)n (x )
+--R             + 
+--R                        7 3 4          6 5 3          5 7 2        4 9      n 3
+--R               (- 34300a b c  + 205800a b c  - 102900a b c  + 6860a b c)n (x )
+--R             + 
+--R                      8 2 4          7 4 3         6 6 2        5 8      n 2
+--R               (25725a b c  - 154350a b c  + 77175a b c  - 5145a b c)n (x )
+--R             + 
+--R                        9   4         8 3 3         7 5 2        6 7     n
+--R               (- 10290a b c  + 61740a b c  - 30870a b c  + 2058a b c)n x
+--R             + 
+--R                     10 4         9 2 3        8 4 2       7 6
+--R               (1715a  c  - 10290a b c  + 5145a b c  - 343a b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                4 7 3        3 9 2       2 11         13     n 7
+--R           (245a b c  - 1470a b c  + 735a b  c - 49a b  )n (x )
+--R         + 
+--R                   5 6 3         4 8 2        3 10        2 12     n 6
+--R           (- 1715a b c  + 10290a b c  - 5145a b  c + 343a b  )n (x )
+--R         + 
+--R                 6 5 3         5 7 2         4 9         3 11     n 5
+--R           (5145a b c  - 30870a b c  + 15435a b c - 1029a b  )n (x )
+--R         + 
+--R                   7 4 3         6 6 2         5 8         4 10     n 4
+--R           (- 8575a b c  + 51450a b c  - 25725a b c + 1715a b  )n (x )
+--R         + 
+--R                 8 3 3         7 5 2         6 7         5 9     n 3
+--R           (8575a b c  - 51450a b c  + 25725a b c - 1715a b )n (x )
+--R         + 
+--R                   9 2 3         8 4 2         7 6         6 8     n 2
+--R           (- 5145a b c  + 30870a b c  - 15435a b c + 1029a b )n (x )
+--R         + 
+--R                 10   3         9 3 2        8 5        7 7    n
+--R           (1715a  b c  - 10290a b c  + 5145a b c - 343a b )n x
+--R         + 
+--R                  11 3        10 2 2       9 4       8 6
+--R           (- 245a  c  + 1470a  b c  - 735a b c + 49a b )n
+--R      *
+--R            n log(x) 6
+--R         (%e        )
+--R     + 
+--R                4   9       3 3 8       2 5 7     2n 7
+--R           (735a b c  - 980a b c  + 147a b c )n (x  )
+--R         + 
+--R                     4 2 8        3 4 7        2 6 6    n
+--R               (5145a b c  - 6860a b c  + 1029a b c )n x
+--R             + 
+--R                       5   8        4 3 7        3 5 6
+--R               (- 5145a b c  + 6860a b c  - 1029a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                      4 3 7         3 5 6        2 7 5     n 2
+--R               (15435a b c  - 20580a b c  + 3087a b c )n (x )
+--R             + 
+--R                        5 2 7         4 4 6        3 6 5    n
+--R               (- 30870a b c  + 41160a b c  - 6174a b c )n x
+--R             + 
+--R                      6   7         5 3 6        4 5 5
+--R               (15435a b c  - 20580a b c  + 3087a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      4 4 6         3 6 5        2 8 4     n 3
+--R               (25725a b c  - 34300a b c  + 5145a b c )n (x )
+--R             + 
+--R                        5 3 6          4 5 5         3 7 4     n 2
+--R               (- 77175a b c  + 102900a b c  - 15435a b c )n (x )
+--R             + 
+--R                      6 2 6          5 4 5         4 6 4    n
+--R               (77175a b c  - 102900a b c  + 15435a b c )n x
+--R             + 
+--R                        7   6         6 3 5        5 5 4
+--R               (- 25725a b c  + 34300a b c  - 5145a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      4 5 5         3 7 4        2 9 3     n 4
+--R               (25725a b c  - 34300a b c  + 5145a b c )n (x )
+--R             + 
+--R                         5 4 5          4 6 4         3 8 3     n 3
+--R               (- 102900a b c  + 137200a b c  - 20580a b c )n (x )
+--R             + 
+--R                       6 3 5          5 5 4         4 7 3     n 2
+--R               (154350a b c  - 205800a b c  + 30870a b c )n (x )
+--R             + 
+--R                         7 2 5          6 4 4         5 6 3    n
+--R               (- 102900a b c  + 137200a b c  - 20580a b c )n x
+--R             + 
+--R                      8   5         7 3 4        6 5 3
+--R               (25725a b c  - 34300a b c  + 5145a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                      4 6 4         3 8 3        2 10 2     n 5
+--R               (15435a b c  - 20580a b c  + 3087a b  c )n (x )
+--R             + 
+--R                        5 5 4          4 7 3         3 9 2     n 4
+--R               (- 77175a b c  + 102900a b c  - 15435a b c )n (x )
+--R             + 
+--R                       6 4 4          5 6 3         4 8 2     n 3
+--R               (154350a b c  - 205800a b c  + 30870a b c )n (x )
+--R             + 
+--R                         7 3 4          6 5 3         5 7 2     n 2
+--R               (- 154350a b c  + 205800a b c  - 30870a b c )n (x )
+--R             + 
+--R                      8 2 4          7 4 3         6 6 2    n
+--R               (77175a b c  - 102900a b c  + 15435a b c )n x
+--R             + 
+--R                        9   4         8 3 3        7 5 2
+--R               (- 15435a b c  + 20580a b c  - 3087a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     4 7 3        3 9 2        2 11      n 6
+--R               (5145a b c  - 6860a b c  + 1029a b  c)n (x )
+--R             + 
+--R                        5 6 3         4 8 2        3 10      n 5
+--R               (- 30870a b c  + 41160a b c  - 6174a b  c)n (x )
+--R             + 
+--R                      6 5 3          5 7 2         4 9      n 4
+--R               (77175a b c  - 102900a b c  + 15435a b c)n (x )
+--R             + 
+--R                         7 4 3          6 6 2         5 8      n 3
+--R               (- 102900a b c  + 137200a b c  - 20580a b c)n (x )
+--R             + 
+--R                      8 3 3          7 5 2         6 7      n 2
+--R               (77175a b c  - 102900a b c  + 15435a b c)n (x )
+--R             + 
+--R                        9 2 3         8 4 2        7 6     n
+--R               (- 30870a b c  + 41160a b c  - 6174a b c)n x
+--R             + 
+--R                     10   3        9 3 2        8 5
+--R               (5145a  b c  - 6860a b c  + 1029a b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                4 8 2       3 10        2 12     n 7
+--R           (735a b c  - 980a b  c + 147a b  )n (x )
+--R         + 
+--R                   5 7 2        4 9         3 11     n 6
+--R           (- 5145a b c  + 6860a b c - 1029a b  )n (x )
+--R         + 
+--R                  6 6 2         5 8         4 10     n 5
+--R           (15435a b c  - 20580a b c + 3087a b  )n (x )
+--R         + 
+--R                    7 5 2         6 7         5 9     n 4
+--R           (- 25725a b c  + 34300a b c - 5145a b )n (x )
+--R         + 
+--R                  8 4 2         7 6         6 8     n 3
+--R           (25725a b c  - 34300a b c + 5145a b )n (x )
+--R         + 
+--R                    9 3 2         8 5         7 7     n 2
+--R           (- 15435a b c  + 20580a b c - 3087a b )n (x )
+--R         + 
+--R                 10 2 2        9 4         8 6    n
+--R           (5145a  b c  - 6860a b c + 1029a b )n x
+--R         + 
+--R                  11   2       10 3        9 5
+--R           (- 735a  b c  + 980a  b c - 147a b )n
+--R      *
+--R            n log(x) 5
+--R         (%e        )
+--R     + 
+--R                  5 9       4 2 8       3 4 7     2n 7
+--R           (- 147a c  + 735a b c  - 245a b c )n (x  )
+--R         + 
+--R                       5   8        4 3 7        3 5 6    n
+--R               (- 1029a b c  + 5145a b c  - 1715a b c )n x
+--R             + 
+--R                     6 8        5 2 7        4 4 6
+--R               (1029a c  - 5145a b c  + 1715a b c )n
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                       5 2 7         4 4 6        3 6 5     n 2
+--R               (- 3087a b c  + 15435a b c  - 5145a b c )n (x )
+--R             + 
+--R                     6   7         5 3 6         4 5 5    n
+--R               (6174a b c  - 30870a b c  + 10290a b c )n x
+--R             + 
+--R                       7 7         6 2 6        5 4 5
+--R               (- 3087a c  + 15435a b c  - 5145a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                       5 3 6         4 5 5        3 7 4     n 3
+--R               (- 5145a b c  + 25725a b c  - 8575a b c )n (x )
+--R             + 
+--R                      6 2 6         5 4 5         4 6 4     n 2
+--R               (15435a b c  - 77175a b c  + 25725a b c )n (x )
+--R             + 
+--R                        7   6         6 3 5         5 5 4    n
+--R               (- 15435a b c  + 77175a b c  - 25725a b c )n x
+--R             + 
+--R                     8 6         7 2 5        6 4 4
+--R               (5145a c  - 25725a b c  + 8575a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                       5 4 5         4 6 4        3 8 3     n 4
+--R               (- 5145a b c  + 25725a b c  - 8575a b c )n (x )
+--R             + 
+--R                      6 3 5          5 5 4         4 7 3     n 3
+--R               (20580a b c  - 102900a b c  + 34300a b c )n (x )
+--R             + 
+--R                        7 2 5          6 4 4         5 6 3     n 2
+--R               (- 30870a b c  + 154350a b c  - 51450a b c )n (x )
+--R             + 
+--R                      8   5          7 3 4         6 5 3    n
+--R               (20580a b c  - 102900a b c  + 34300a b c )n x
+--R             + 
+--R                       9 5         8 2 4        7 4 3
+--R               (- 5145a c  + 25725a b c  - 8575a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                       5 5 4         4 7 3        3 9 2     n 5
+--R               (- 3087a b c  + 15435a b c  - 5145a b c )n (x )
+--R             + 
+--R                      6 4 4         5 6 3         4 8 2     n 4
+--R               (15435a b c  - 77175a b c  + 25725a b c )n (x )
+--R             + 
+--R                        7 3 4          6 5 3         5 7 2     n 3
+--R               (- 30870a b c  + 154350a b c  - 51450a b c )n (x )
+--R             + 
+--R                      8 2 4          7 4 3         6 6 2     n 2
+--R               (30870a b c  - 154350a b c  + 51450a b c )n (x )
+--R             + 
+--R                        9   4         8 3 3         7 5 2    n
+--R               (- 15435a b c  + 77175a b c  - 25725a b c )n x
+--R             + 
+--R                     10 4         9 2 3        8 4 2
+--R               (3087a  c  - 15435a b c  + 5145a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                       5 6 3        4 8 2        3 10      n 6
+--R               (- 1029a b c  + 5145a b c  - 1715a b  c)n (x )
+--R             + 
+--R                     6 5 3         5 7 2         4 9      n 5
+--R               (6174a b c  - 30870a b c  + 10290a b c)n (x )
+--R             + 
+--R                        7 4 3         6 6 2         5 8      n 4
+--R               (- 15435a b c  + 77175a b c  - 25725a b c)n (x )
+--R             + 
+--R                      8 3 3          7 5 2         6 7      n 3
+--R               (20580a b c  - 102900a b c  + 34300a b c)n (x )
+--R             + 
+--R                        9 2 3         8 4 2         7 6      n 2
+--R               (- 15435a b c  + 77175a b c  - 25725a b c)n (x )
+--R             + 
+--R                     10   3         9 3 2         8 5     n
+--R               (6174a  b c  - 30870a b c  + 10290a b c)n x
+--R             + 
+--R                       11 3        10 2 2        9 4
+--R               (- 1029a  c  + 5145a  b c  - 1715a b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                  5 7 2       4 9        3 11     n 7
+--R           (- 147a b c  + 735a b c - 245a b  )n (x )
+--R         + 
+--R                 6 6 2        5 8         4 10     n 6
+--R           (1029a b c  - 5145a b c + 1715a b  )n (x )
+--R         + 
+--R                   7 5 2         6 7         5 9     n 5
+--R           (- 3087a b c  + 15435a b c - 5145a b )n (x )
+--R         + 
+--R                 8 4 2         7 6         6 8     n 4
+--R           (5145a b c  - 25725a b c + 8575a b )n (x )
+--R         + 
+--R                   9 3 2         8 5         7 7     n 3
+--R           (- 5145a b c  + 25725a b c - 8575a b )n (x )
+--R         + 
+--R                 10 2 2         9 4         8 6     n 2
+--R           (3087a  b c  - 15435a b c + 5145a b )n (x )
+--R         + 
+--R                   11   2        10 3         9 5    n
+--R           (- 1029a  b c  + 5145a  b c - 1715a b )n x
+--R         + 
+--R                12 2       11 2        10 4
+--R           (147a  c  - 735a  b c + 245a  b )n
+--R      *
+--R            n log(x) 4
+--R         (%e        )
+--R     + 
+--R                  5   8       4 3 7     2n 7
+--R           (- 294a b c  + 245a b c )n (x  )
+--R         + 
+--R                    5 2 7        4 4 6    n         6   7        5 3 6     2n 6
+--R           ((- 2058a b c  + 1715a b c )n x  + (2058a b c  - 1715a b c )n)(x  )
+--R         + 
+--R                       5 3 6        4 5 5     n 2
+--R               (- 6174a b c  + 5145a b c )n (x )
+--R             + 
+--R                      6 2 6         5 4 5    n           7   6        6 3 5
+--R               (12348a b c  - 10290a b c )n x  + (- 6174a b c  + 5145a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                        5 4 5        4 6 4     n 3
+--R               (- 10290a b c  + 8575a b c )n (x )
+--R             + 
+--R                      6 3 5         5 5 4     n 2
+--R               (30870a b c  - 25725a b c )n (x )
+--R             + 
+--R                        7 2 5         6 4 4    n          8   5        7 3 4
+--R               (- 30870a b c  + 25725a b c )n x  + (10290a b c  - 8575a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                        5 5 4        4 7 3     n 4
+--R               (- 10290a b c  + 8575a b c )n (x )
+--R             + 
+--R                      6 4 4         5 6 3     n 3
+--R               (41160a b c  - 34300a b c )n (x )
+--R             + 
+--R                        7 3 4         6 5 3     n 2
+--R               (- 61740a b c  + 51450a b c )n (x )
+--R             + 
+--R                      8 2 4         7 4 3    n            9   4        8 3 3
+--R               (41160a b c  - 34300a b c )n x  + (- 10290a b c  + 8575a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                       5 6 3        4 8 2     n 5
+--R               (- 6174a b c  + 5145a b c )n (x )
+--R             + 
+--R                      6 5 3         5 7 2     n 4
+--R               (30870a b c  - 25725a b c )n (x )
+--R             + 
+--R                        7 4 3         6 6 2     n 3
+--R               (- 61740a b c  + 51450a b c )n (x )
+--R             + 
+--R                      8 3 3         7 5 2     n 2
+--R               (61740a b c  - 51450a b c )n (x )
+--R             + 
+--R                        9 2 3         8 4 2    n         10   3        9 3 2
+--R               (- 30870a b c  + 25725a b c )n x  + (6174a  b c  - 5145a b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                       5 7 2        4 9      n 6
+--R               (- 2058a b c  + 1715a b c)n (x )
+--R             + 
+--R                      6 6 2         5 8      n 5
+--R               (12348a b c  - 10290a b c)n (x )
+--R             + 
+--R                        7 5 2         6 7      n 4
+--R               (- 30870a b c  + 25725a b c)n (x )
+--R             + 
+--R                      8 4 2         7 6      n 3
+--R               (41160a b c  - 34300a b c)n (x )
+--R             + 
+--R                        9 3 2         8 5      n 2
+--R               (- 30870a b c  + 25725a b c)n (x )
+--R             + 
+--R                      10 2 2         9 4     n           11   2        10 3
+--R               (12348a  b c  - 10290a b c)n x  + (- 2058a  b c  + 1715a  b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                  5 8        4 10     n 7         6 7         5 9     n 6
+--R           (- 294a b c + 245a b  )n (x )  + (2058a b c - 1715a b )n (x )
+--R         + 
+--R                   7 6         6 8     n 5          8 5         7 7     n 4
+--R           (- 6174a b c + 5145a b )n (x )  + (10290a b c - 8575a b )n (x )
+--R         + 
+--R                    9 4         8 6     n 3         10 3         9 5     n 2
+--R           (- 10290a b c + 8575a b )n (x )  + (6174a  b c - 5145a b )n (x )
+--R         + 
+--R                   11 2         10 4    n        12          11 3
+--R           (- 2058a  b c + 1715a  b )n x  + (294a  b c - 245a  b )n
+--R      *
+--R            n log(x) 3
+--R         (%e        )
+--R     + 
+--R               6 8       5 2 7     2n 7
+--R           (49a c  - 147a b c )n (x  )
+--R         + 
+--R                 6   7        5 3 6    n          7 7        6 2 6     2n 6
+--R           ((343a b c  - 1029a b c )n x  + (- 343a c  + 1029a b c )n)(x  )
+--R         + 
+--R                     6 2 6        5 4 5     n 2
+--R               (1029a b c  - 3087a b c )n (x )
+--R             + 
+--R                       7   6        6 3 5    n         8 6        7 2 5
+--R               (- 2058a b c  + 6174a b c )n x  + (1029a c  - 3087a b c )n
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     6 3 5        5 5 4     n 3
+--R               (1715a b c  - 5145a b c )n (x )
+--R             + 
+--R                       7 2 5         6 4 4     n 2
+--R               (- 5145a b c  + 15435a b c )n (x )
+--R             + 
+--R                     8   5         7 3 4    n           9 5        8 2 4
+--R               (5145a b c  - 15435a b c )n x  + (- 1715a c  + 5145a b c )n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     6 4 4        5 6 3     n 4
+--R               (1715a b c  - 5145a b c )n (x )
+--R             + 
+--R                       7 3 4         6 5 3     n 3
+--R               (- 6860a b c  + 20580a b c )n (x )
+--R             + 
+--R                      8 2 4         7 4 3     n 2
+--R               (10290a b c  - 30870a b c )n (x )
+--R             + 
+--R                       9   4         8 3 3    n         10 4        9 2 3
+--R               (- 6860a b c  + 20580a b c )n x  + (1715a  c  - 5145a b c )n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     6 5 3        5 7 2     n 5
+--R               (1029a b c  - 3087a b c )n (x )
+--R             + 
+--R                       7 4 3         6 6 2     n 4
+--R               (- 5145a b c  + 15435a b c )n (x )
+--R             + 
+--R                      8 3 3         7 5 2     n 3
+--R               (10290a b c  - 30870a b c )n (x )
+--R             + 
+--R                        9 2 3         8 4 2     n 2
+--R               (- 10290a b c  + 30870a b c )n (x )
+--R             + 
+--R                     10   3         9 3 2    n           11 3        10 2 2
+--R               (5145a  b c  - 15435a b c )n x  + (- 1029a  c  + 3087a  b c )n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    6 6 2        5 8      n 6
+--R               (343a b c  - 1029a b c)n (x )
+--R             + 
+--R                       7 5 2        6 7      n 5
+--R               (- 2058a b c  + 6174a b c)n (x )
+--R             + 
+--R                     8 4 2         7 6      n 4
+--R               (5145a b c  - 15435a b c)n (x )
+--R             + 
+--R                       9 3 2         8 5      n 3
+--R               (- 6860a b c  + 20580a b c)n (x )
+--R             + 
+--R                     10 2 2         9 4      n 2
+--R               (5145a  b c  - 15435a b c)n (x )
+--R             + 
+--R                       11   2        10 3     n        12 2        11 2
+--R               (- 2058a  b c  + 6174a  b c)n x  + (343a  c  - 1029a  b c)n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               6 7        5 9     n 7          7 6         6 8     n 6
+--R           (49a b c - 147a b )n (x )  + (- 343a b c + 1029a b )n (x )
+--R         + 
+--R                 8 5         7 7     n 5           9 4         8 6     n 4
+--R           (1029a b c - 3087a b )n (x )  + (- 1715a b c + 5145a b )n (x )
+--R         + 
+--R                 10 3         9 5     n 3           11 2         10 4     n 2
+--R           (1715a  b c - 5145a b )n (x )  + (- 1029a  b c + 3087a  b )n (x )
+--R         + 
+--R                12           11 3    n         13        12 2
+--R           (343a  b c - 1029a  b )n x  + (- 49a  c + 147a  b )n
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R              6   7    2n 7        6 2 6   n       7   6    2n 6
+--R           49a b c n (x  )  + (343a b c n x  - 343a b c n)(x  )
+--R         + 
+--R                 6 3 5    n 2        7 2 5   n        8   5    2n 5
+--R           (1029a b c n (x )  - 2058a b c n x  + 1029a b c n)(x  )
+--R         + 
+--R                    6 4 4    n 3        7 3 4    n 2        8 2 4   n
+--R               1715a b c n (x )  - 5145a b c n (x )  + 5145a b c n x
+--R             + 
+--R                      9   4
+--R               - 1715a b c n
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                    6 5 3    n 4        7 4 3    n 3         8 3 3    n 2
+--R               1715a b c n (x )  - 6860a b c n (x )  + 10290a b c n (x )
+--R             + 
+--R                      9 2 3   n        10   3
+--R               - 6860a b c n x  + 1715a  b c n
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                    6 6 2    n 5        7 5 2    n 4         8 4 2    n 3
+--R               1029a b c n (x )  - 5145a b c n (x )  + 10290a b c n (x )
+--R             + 
+--R                       9 3 2    n 2        10 2 2   n        11   2
+--R               - 10290a b c n (x )  + 5145a  b c n x  - 1029a  b c n
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                   6 7      n 6        7 6      n 5        8 5      n 4
+--R               343a b c n (x )  - 2058a b c n (x )  + 5145a b c n (x )
+--R             + 
+--R                      9 4      n 3        10 3      n 2        11 2     n
+--R               - 6860a b c n (x )  + 5145a  b c n (x )  - 2058a  b c n x
+--R             + 
+--R                   12
+--R               343a  b c n
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R              6 8    n 7       7 7    n 6        8 6    n 5        9 5    n 4
+--R           49a b n (x )  - 343a b n (x )  + 1029a b n (x )  - 1715a b n (x )
+--R         + 
+--R                10 4    n 3        11 3    n 2       12 2   n      13
+--R           1715a  b n (x )  - 1029a  b n (x )  + 343a  b n x  - 49a  b n
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R           7 7    2n 7         7   6   n      8 6    2n 6
+--R       - 7a c n (x  )  + (- 49a b c n x  + 49a c n)(x  )
+--R     + 
+--R              7 2 5    n 2       8   5   n       9 5    2n 5
+--R       (- 147a b c n (x )  + 294a b c n x  - 147a c n)(x  )
+--R     + 
+--R              7 3 4    n 3       8 2 4    n 2       9   4   n       10 4    2n 4
+--R       (- 245a b c n (x )  + 735a b c n (x )  - 735a b c n x  + 245a  c n)(x  )
+--R     + 
+--R                 7 4 3    n 4       8 3 3    n 3        9 2 3    n 2
+--R           - 245a b c n (x )  + 980a b c n (x )  - 1470a b c n (x )
+--R         + 
+--R               10   3   n       11 3
+--R           980a  b c n x  - 245a  c n
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R                 7 5 2    n 5       8 4 2    n 4        9 3 2    n 3
+--R           - 147a b c n (x )  + 735a b c n (x )  - 1470a b c n (x )
+--R         + 
+--R                10 2 2    n 2       11   2   n       12 2
+--R           1470a  b c n (x )  - 735a  b c n x  + 147a  c n
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R                7 6      n 6       8 5      n 5       9 4      n 4
+--R           - 49a b c n (x )  + 294a b c n (x )  - 735a b c n (x )
+--R         + 
+--R               10 3      n 3       11 2      n 2       12       n      13
+--R           980a  b c n (x )  - 735a  b c n (x )  + 294a  b c n x  - 49a  c n
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R           7 7    n 7      8 6    n 6       9 5    n 5       10 4    n 4
+--R       - 7a b n (x )  + 49a b n (x )  - 147a b n (x )  + 245a  b n (x )
+--R     + 
+--R             11 3    n 3       12 2    n 2      13     n     14
+--R       - 245a  b n (x )  + 147a  b n (x )  - 49a  b n x  + 7a  n
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            9   2n - 1      8   n - 1    n log(x) 16
+--R       (- 2c x x       - b c x x     )(%e        )
+--R     + 
+--R               8   2n - 1     2 7   n - 1    n log(x) 15
+--R       (- 16b c x x       - 8b c x x     )(%e        )
+--R     + 
+--R              8      2 7    2n - 1          7      3 6    n - 1    n log(x) 14
+--R       ((16a c  - 56b c )x x       + (8a b c  - 28b c )x x     )(%e        )
+--R     + 
+--R                   7       3 6    2n - 1         2 6      4 5    n - 1
+--R         ((112a b c  - 112b c )x x       + (56a b c  - 56b c )x x     )
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R                 2 7         2 6       4 5    2n - 1
+--R           (- 56a c  + 336a b c  - 140b c )x x
+--R         + 
+--R                 2   6         3 5      5 4    n - 1
+--R           (- 28a b c  + 168a b c  - 70b c )x x
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                  2   6         3 5       5 4    2n - 1
+--R           (- 336a b c  + 560a b c  - 112b c )x x
+--R         + 
+--R                  2 2 5         4 4      6 3    n - 1
+--R           (- 168a b c  + 280a b c  - 56b c )x x
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                3 6       2 2 5         4 4      6 3    2n - 1
+--R           (112a c  - 840a b c  + 560a b c  - 56b c )x x
+--R         + 
+--R               3   5       2 3 4         5 3      7 2    n - 1
+--R           (56a b c  - 420a b c  + 280a b c  - 28b c )x x
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                3   5        2 3 4         5 3      7 2    2n - 1
+--R           (560a b c  - 1120a b c  + 336a b c  - 16b c )x x
+--R         + 
+--R                3 2 4       2 4 3         6 2     8     n - 1
+--R           (280a b c  - 560a b c  + 168a b c  - 8b c)x x
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R                  4 5        3 2 4       2 4 3         6 2     8     2n - 1
+--R           (- 140a c  + 1120a b c  - 840a b c  + 112a b c  - 2b c)x x
+--R         + 
+--R                 4   4       3 3 3       2 5 2        7     9    n - 1
+--R           (- 70a b c  + 560a b c  - 420a b c  + 56a b c - b )x x
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R                  4   4        3 3 3       2 5 2        7     2n - 1
+--R           (- 560a b c  + 1120a b c  - 336a b c  + 16a b c)x x
+--R         + 
+--R                  4 2 3       3 4 2       2 6        8    n - 1
+--R           (- 280a b c  + 560a b c  - 168a b c + 8a b )x x
+--R      *
+--R            n log(x) 7
+--R         (%e        )
+--R     + 
+--R                5 4       4 2 3       3 4 2      2 6     2n - 1
+--R           (112a c  - 840a b c  + 560a b c  - 56a b c)x x
+--R         + 
+--R               5   3       4 3 2       3 5       2 7    n - 1
+--R           (56a b c  - 420a b c  + 280a b c - 28a b )x x
+--R      *
+--R            n log(x) 6
+--R         (%e        )
+--R     + 
+--R                5   3       4 3 2       3 5     2n - 1
+--R           (336a b c  - 560a b c  + 112a b c)x x
+--R         + 
+--R                5 2 2       4 4       3 6    n - 1
+--R           (168a b c  - 280a b c + 56a b )x x
+--R      *
+--R            n log(x) 5
+--R         (%e        )
+--R     + 
+--R                 6 3       5 2 2       4 4     2n - 1
+--R           (- 56a c  + 336a b c  - 140a b c)x x
+--R         + 
+--R                 6   2       5 3       4 5    n - 1
+--R           (- 28a b c  + 168a b c - 70a b )x x
+--R      *
+--R            n log(x) 4
+--R         (%e        )
+--R     + 
+--R                 6   2       5 3     2n - 1         6 2       5 4    n - 1
+--R         ((- 112a b c  + 112a b c)x x       + (- 56a b c + 56a b )x x     )
+--R      *
+--R            n log(x) 3
+--R         (%e        )
+--R     + 
+--R             9  2n 8         8 n        8   2n 7
+--R           2c (x  )  + (16b c x  - 16a c )(x  )
+--R         + 
+--R               2 7  n 2           7 n      2 7   2n 6
+--R           (56b c (x )  - 112a b c x  + 56a c )(x  )
+--R         + 
+--R                3 6  n 3         2 6  n 2       2   6 n       3 6   2n 5
+--R           (112b c (x )  - 336a b c (x )  + 336a b c x  - 112a c )(x  )
+--R         + 
+--R                   4 5  n 4         3 5  n 3       2 2 5  n 2       3   5 n
+--R               140b c (x )  - 560a b c (x )  + 840a b c (x )  - 560a b c x
+--R             + 
+--R                   4 5
+--R               140a c
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                   5 4  n 5         4 4  n 4        2 3 4  n 3        3 2 4  n 2
+--R               112b c (x )  - 560a b c (x )  + 1120a b c (x )  - 1120a b c (x )
+--R             + 
+--R                   4   4 n       5 4
+--R               560a b c x  - 112a c
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                  6 3  n 6         5 3  n 5       2 4 3  n 4        3 3 3  n 3
+--R               56b c (x )  - 336a b c (x )  + 840a b c (x )  - 1120a b c (x )
+--R             + 
+--R                   4 2 3  n 2       5   3 n      6 3
+--R               840a b c (x )  - 336a b c x  + 56a c
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                  7 2  n 7         6 2  n 6       2 5 2  n 5       3 4 2  n 4
+--R               16b c (x )  - 112a b c (x )  + 336a b c (x )  - 560a b c (x )
+--R             + 
+--R                   4 3 2  n 3       5 2 2  n 2       6   2 n      7 2
+--R               560a b c (x )  - 336a b c (x )  + 112a b c x  - 16a c
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               7 2      6 2     2n - 1     8    n 8        7    n 7
+--R           (16a c  - 56a b c)x x       + 2b c (x )  - 16a b c (x )
+--R         + 
+--R              2 6    n 6       3 5    n 5       4 4    n 4       5 3    n 3
+--R           56a b c (x )  - 112a b c (x )  + 140a b c (x )  - 112a b c (x )
+--R         + 
+--R              6 2    n 2      7     n      7         6 3    n - 1     8
+--R           56a b c (x )  - 16a b c x  + (8a b c - 28a b )x x      + 2a c
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R              8  2n 8      2 7 n         7   2n 7
+--R           b c (x  )  + (8b c x  - 8a b c )(x  )
+--R         + 
+--R               3 6  n 2        2 6 n      2   6   2n 6
+--R           (28b c (x )  - 56a b c x  + 28a b c )(x  )
+--R         + 
+--R               4 5  n 3         3 5  n 2       2 2 5 n      3   5   2n 5
+--R           (56b c (x )  - 168a b c (x )  + 168a b c x  - 56a b c )(x  )
+--R         + 
+--R                  5 4  n 4         4 4  n 3       2 3 4  n 2       3 2 4 n
+--R               70b c (x )  - 280a b c (x )  + 420a b c (x )  - 280a b c x
+--R             + 
+--R                  4   4
+--R               70a b c
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                  6 3  n 5         5 3  n 4       2 4 3  n 3       3 3 3  n 2
+--R               56b c (x )  - 280a b c (x )  + 560a b c (x )  - 560a b c (x )
+--R             + 
+--R                   4 2 3 n      5   3
+--R               280a b c x  - 56a b c
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                  7 2  n 6         6 2  n 5       2 5 2  n 4       3 4 2  n 3
+--R               28b c (x )  - 168a b c (x )  + 420a b c (x )  - 560a b c (x )
+--R             + 
+--R                   4 3 2  n 2       5 2 2 n      6   2
+--R               420a b c (x )  - 168a b c x  + 28a b c
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                 8    n 7        7    n 6       2 6    n 5       3 5    n 4
+--R               8b c (x )  - 56a b c (x )  + 168a b c (x )  - 280a b c (x )
+--R             + 
+--R                   4 4    n 3       5 3    n 2      6 2   n     7
+--R               280a b c (x )  - 168a b c (x )  + 56a b c x  - 8a b c
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R              7       2n - 1    9  n 8       8  n 7      2 7  n 6      3 6  n 5
+--R           16a b c x x       + b (x )  - 8a b (x )  + 28a b (x )  - 56a b (x )
+--R         + 
+--R            4 5  n 4      5 4  n 3      6 3  n 2     7 2 n     7 2   n - 1    8
+--R         70a b (x )  - 56a b (x )  + 28a b (x )  - 8a b x  + 8a b x x      + a b
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R           8     2n - 1    8     n - 1
+--R       - 2a c x x       - a b x x
+--R  /
+--R            16    2n 8        15   n       15    2n 7
+--R           c  x (x  )  + (8b c  x x  - 8a c  x)(x  )
+--R         + 
+--R               2 14    n 2          14   n      2 14    2n 6
+--R           (28b c  x (x )  - 56a b c  x x  + 28a c  x)(x  )
+--R         + 
+--R                 3 13    n 3         2 13    n 2       2   13   n      3 13
+--R             (56b c  x (x )  - 168a b c  x (x )  + 168a b c  x x  - 56a c  x)
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                  4 12    n 4         3 12    n 3       2 2 12    n 2
+--R               70b c  x (x )  - 280a b c  x (x )  + 420a b c  x (x )
+--R             + 
+--R                     3   12   n      4 12
+--R               - 280a b c  x x  + 70a c  x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                  5 11    n 5         4 11    n 4       2 3 11    n 3
+--R               56b c  x (x )  - 280a b c  x (x )  + 560a b c  x (x )
+--R             + 
+--R                     3 2 11    n 2       4   11   n      5 11
+--R               - 560a b c  x (x )  + 280a b c  x x  - 56a c  x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                  6 10    n 6         5 10    n 5       2 4 10    n 4
+--R               28b c  x (x )  - 168a b c  x (x )  + 420a b c  x (x )
+--R             + 
+--R                   3 3 10    n 3       4 2 10    n 2       5   10   n      6 10
+--R             - 560a b c  x (x )  + 420a b c  x (x )  - 168a b c  x x  + 28a c  x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                 7 9    n 7        6 9    n 6       2 5 9    n 5
+--R               8b c x (x )  - 56a b c x (x )  + 168a b c x (x )
+--R             + 
+--R                     3 4 9    n 4       4 3 9    n 3       5 2 9    n 2
+--R               - 280a b c x (x )  + 280a b c x (x )  - 168a b c x (x )
+--R             + 
+--R                  6   9   n     7 9
+--R               56a b c x x  - 8a c x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R            8 8    n 8       7 8    n 7      2 6 8    n 6      3 5 8    n 5
+--R           b c x (x )  - 8a b c x (x )  + 28a b c x (x )  - 56a b c x (x )
+--R         + 
+--R              4 4 8    n 4      5 3 8    n 3      6 2 8    n 2     7   8   n
+--R           70a b c x (x )  - 56a b c x (x )  + 28a b c x (x )  - 8a b c x x
+--R         + 
+--R            8 8
+--R           a c x
+--R      *
+--R            n log(x) 16
+--R         (%e        )
+--R     + 
+--R               15    2n 8       2 14   n          14    2n 7
+--R           8b c  x (x  )  + (64b c  x x  - 64a b c  x)(x  )
+--R         + 
+--R                3 13    n 2         2 13   n       2   13    2n 6
+--R           (224b c  x (x )  - 448a b c  x x  + 224a b c  x)(x  )
+--R         + 
+--R                   4 12    n 3          3 12    n 2        2 2 12   n
+--R               448b c  x (x )  - 1344a b c  x (x )  + 1344a b c  x x
+--R             + 
+--R                     3   12
+--R               - 448a b c  x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                   5 11    n 4          4 11    n 3        2 3 11    n 2
+--R               560b c  x (x )  - 2240a b c  x (x )  + 3360a b c  x (x )
+--R             + 
+--R                      3 2 11   n       4   11
+--R               - 2240a b c  x x  + 560a b c  x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                   6 10    n 5          5 10    n 4        2 4 10    n 3
+--R               448b c  x (x )  - 2240a b c  x (x )  + 4480a b c  x (x )
+--R             + 
+--R                      3 3 10    n 2        4 2 10   n       5   10
+--R               - 4480a b c  x (x )  + 2240a b c  x x  - 448a b c  x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                   7 9    n 6          6 9    n 5        2 5 9    n 4
+--R               224b c x (x )  - 1344a b c x (x )  + 3360a b c x (x )
+--R             + 
+--R                      3 4 9    n 3        4 3 9    n 2        5 2 9   n
+--R               - 4480a b c x (x )  + 3360a b c x (x )  - 1344a b c x x
+--R             + 
+--R                   6   9
+--R               224a b c x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                  8 8    n 7         7 8    n 6        2 6 8    n 5
+--R               64b c x (x )  - 448a b c x (x )  + 1344a b c x (x )
+--R             + 
+--R                      3 5 8    n 4        4 4 8    n 3        5 3 8    n 2
+--R               - 2240a b c x (x )  + 2240a b c x (x )  - 1344a b c x (x )
+--R             + 
+--R                   6 2 8   n      7   8
+--R               448a b c x x  - 64a b c x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R             9 7    n 8        8 7    n 7       2 7 7    n 6       3 6 7    n 5
+--R           8b c x (x )  - 64a b c x (x )  + 224a b c x (x )  - 448a b c x (x )
+--R         + 
+--R               4 5 7    n 4       5 4 7    n 3       6 3 7    n 2      7 2 7   n
+--R           560a b c x (x )  - 448a b c x (x )  + 224a b c x (x )  - 64a b c x x
+--R         + 
+--R             8   7
+--R           8a b c x
+--R      *
+--R            n log(x) 15
+--R         (%e        )
+--R     + 
+--R                  15      2 14     2n 8
+--R           (- 8a c   + 28b c  )x (x  )
+--R         + 
+--R                      14       3 13    n       2 14         2 13     2n 7
+--R           ((- 64a b c   + 224b c  )x x  + (64a c   - 224a b c  )x)(x  )
+--R         + 
+--R                        2 13       4 12     n 2        2   13          3 12    n
+--R               (- 224a b c   + 784b c  )x (x )  + (448a b c   - 1568a b c  )x x
+--R             + 
+--R                      3 13       2 2 12
+--R               (- 224a c   + 784a b c  )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                        3 12        5 11     n 3
+--R               (- 448a b c   + 1568b c  )x (x )
+--R             + 
+--R                     2 2 12          4 11     n 2
+--R               (1344a b c   - 4704a b c  )x (x )
+--R             + 
+--R                       3   12        2 3 11    n        4 12        3 2 11
+--R               (- 1344a b c   + 4704a b c  )x x  + (448a c   - 1568a b c  )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                        4 11        6 10     n 4
+--R               (- 560a b c   + 1960b c  )x (x )
+--R             + 
+--R                     2 3 11          5 10     n 3
+--R               (2240a b c   - 7840a b c  )x (x )
+--R             + 
+--R                       3 2 11         2 4 10     n 2
+--R               (- 3360a b c   + 11760a b c  )x (x )
+--R             + 
+--R                     4   11        3 3 10    n          5 11        4 2 10
+--R               (2240a b c   - 7840a b c  )x x  + (- 560a c   + 1960a b c  )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                        5 10        7 9     n 5
+--R               (- 448a b c   + 1568b c )x (x )
+--R             + 
+--R                     2 4 10          6 9     n 4
+--R               (2240a b c   - 7840a b c )x (x )
+--R             + 
+--R                       3 3 10         2 5 9     n 3
+--R               (- 4480a b c   + 15680a b c )x (x )
+--R             + 
+--R                     4 2 10         3 4 9     n 2
+--R               (4480a b c   - 15680a b c )x (x )
+--R             + 
+--R                       5   10        4 3 9    n        6 10        5 2 9
+--R               (- 2240a b c   + 7840a b c )x x  + (448a c   - 1568a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                        6 9       8 8     n 6         2 5 9          7 8     n 5
+--R               (- 224a b c  + 784b c )x (x )  + (1344a b c  - 4704a b c )x (x )
+--R             + 
+--R                       3 4 9         2 6 8     n 4
+--R               (- 3360a b c  + 11760a b c )x (x )
+--R             + 
+--R                     4 3 9         3 5 8     n 3
+--R               (4480a b c  - 15680a b c )x (x )
+--R             + 
+--R                       5 2 9         4 4 8     n 2
+--R               (- 3360a b c  + 11760a b c )x (x )
+--R             + 
+--R                     6   9        5 3 8    n          7 9       6 2 8
+--R               (1344a b c  - 4704a b c )x x  + (- 224a c  + 784a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                       7 8       9 7     n 7        2 6 8          8 7     n 6
+--R               (- 64a b c  + 224b c )x (x )  + (448a b c  - 1568a b c )x (x )
+--R             + 
+--R                       3 5 8        2 7 7     n 5
+--R               (- 1344a b c  + 4704a b c )x (x )
+--R             + 
+--R                     4 4 8        3 6 7     n 4
+--R               (2240a b c  - 7840a b c )x (x )
+--R             + 
+--R                       5 3 8        4 5 7     n 3
+--R               (- 2240a b c  + 7840a b c )x (x )
+--R             + 
+--R                     6 2 8        5 4 7     n 2          7   8        6 3 7    n
+--R               (1344a b c  - 4704a b c )x (x )  + (- 448a b c  + 1568a b c )x x
+--R             + 
+--R                   8 8       7 2 7
+--R               (64a c  - 224a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                  8 7      10 6     n 8       2 7 7         9 6     n 7
+--R           (- 8a b c  + 28b  c )x (x )  + (64a b c  - 224a b c )x (x )
+--R         + 
+--R                  3 6 7       2 8 6     n 6        4 5 7        3 7 6     n 5
+--R           (- 224a b c  + 784a b c )x (x )  + (448a b c  - 1568a b c )x (x )
+--R         + 
+--R                  5 4 7        4 6 6     n 4        6 3 7        5 5 6     n 3
+--R           (- 560a b c  + 1960a b c )x (x )  + (448a b c  - 1568a b c )x (x )
+--R         + 
+--R                  7 2 7       6 4 6     n 2       8   7       7 3 6    n
+--R           (- 224a b c  + 784a b c )x (x )  + (64a b c  - 224a b c )x x
+--R         + 
+--R                9 7      8 2 6
+--R           (- 8a c  + 28a b c )x
+--R      *
+--R            n log(x) 14
+--R         (%e        )
+--R     + 
+--R                     14      3 13     2n 8
+--R           (- 56a b c   + 56b c  )x (x  )
+--R         + 
+--R                     2 13       4 12    n        2   13         3 12     2n 7
+--R           ((- 448a b c   + 448b c  )x x  + (448a b c   - 448a b c  )x)(x  )
+--R         + 
+--R                         3 12        5 11     n 2
+--R               (- 1568a b c   + 1568b c  )x (x )
+--R             + 
+--R                     2 2 12          4 11    n           3   12        2 3 11
+--R               (3136a b c   - 3136a b c  )x x  + (- 1568a b c   + 1568a b c  )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                         4 11        6 10     n 3
+--R               (- 3136a b c   + 3136b c  )x (x )
+--R             + 
+--R                     2 3 11          5 10     n 2
+--R               (9408a b c   - 9408a b c  )x (x )
+--R             + 
+--R                       3 2 11        2 4 10    n         4   11        3 3 10
+--R               (- 9408a b c   + 9408a b c  )x x  + (3136a b c   - 3136a b c  )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                         5 10        7 9     n 4
+--R               (- 3920a b c   + 3920b c )x (x )
+--R             + 
+--R                      2 4 10           6 9     n 3
+--R               (15680a b c   - 15680a b c )x (x )
+--R             + 
+--R                        3 3 10         2 5 9     n 2
+--R               (- 23520a b c   + 23520a b c )x (x )
+--R             + 
+--R                      4 2 10         3 4 9    n           5   10        4 3 9
+--R               (15680a b c   - 15680a b c )x x  + (- 3920a b c   + 3920a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                         6 9        8 8     n 5
+--R               (- 3136a b c  + 3136b c )x (x )
+--R             + 
+--R                      2 5 9           7 8     n 4
+--R               (15680a b c  - 15680a b c )x (x )
+--R             + 
+--R                        3 4 9         2 6 8     n 3
+--R               (- 31360a b c  + 31360a b c )x (x )
+--R             + 
+--R                      4 3 9         3 5 8     n 2
+--R               (31360a b c  - 31360a b c )x (x )
+--R             + 
+--R                        5 2 9         4 4 8    n         6   9        5 3 8
+--R               (- 15680a b c  + 15680a b c )x x  + (3136a b c  - 3136a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                         7 8        9 7     n 6
+--R               (- 1568a b c  + 1568b c )x (x )
+--R             + 
+--R                     2 6 8          8 7     n 5
+--R               (9408a b c  - 9408a b c )x (x )
+--R             + 
+--R                        3 5 8         2 7 7     n 4
+--R               (- 23520a b c  + 23520a b c )x (x )
+--R             + 
+--R                      4 4 8         3 6 7     n 3
+--R               (31360a b c  - 31360a b c )x (x )
+--R             + 
+--R                        5 3 8         4 5 7     n 2
+--R               (- 23520a b c  + 23520a b c )x (x )
+--R             + 
+--R                     6 2 8        5 4 7    n           7   8        6 3 7
+--R               (9408a b c  - 9408a b c )x x  + (- 1568a b c  + 1568a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                        8 7       10 6     n 7
+--R               (- 448a b c  + 448b  c )x (x )
+--R             + 
+--R                     2 7 7          9 6     n 6
+--R               (3136a b c  - 3136a b c )x (x )
+--R             + 
+--R                       3 6 7        2 8 6     n 5
+--R               (- 9408a b c  + 9408a b c )x (x )
+--R             + 
+--R                      4 5 7         3 7 6     n 4
+--R               (15680a b c  - 15680a b c )x (x )
+--R             + 
+--R                        5 4 7         4 6 6     n 3
+--R               (- 15680a b c  + 15680a b c )x (x )
+--R             + 
+--R                     6 3 7        5 5 6     n 2
+--R               (9408a b c  - 9408a b c )x (x )
+--R             + 
+--R                       7 2 7        6 4 6    n        8   7       7 3 6
+--R               (- 3136a b c  + 3136a b c )x x  + (448a b c  - 448a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                   9 6      11 5     n 8        2 8 6         10 5     n 7
+--R           (- 56a b c  + 56b  c )x (x )  + (448a b c  - 448a b  c )x (x )
+--R         + 
+--R                   3 7 6        2 9 5     n 6         4 6 6        3 8 5     n 5
+--R           (- 1568a b c  + 1568a b c )x (x )  + (3136a b c  - 3136a b c )x (x )
+--R         + 
+--R                   5 5 6        4 7 5     n 4         6 4 6        5 6 5     n 3
+--R           (- 3920a b c  + 3920a b c )x (x )  + (3136a b c  - 3136a b c )x (x )
+--R         + 
+--R                   7 3 6        6 5 5     n 2        8 2 6       7 4 5    n
+--R           (- 1568a b c  + 1568a b c )x (x )  + (448a b c  - 448a b c )x x
+--R         + 
+--R                 9   6      8 3 5
+--R           (- 56a b c  + 56a b c )x
+--R      *
+--R            n log(x) 13
+--R         (%e        )
+--R     + 
+--R               2 14         2 13      4 12     2n 8
+--R           (28a c   - 168a b c   + 70b c  )x (x  )
+--R         + 
+--R                    2   13          3 12       5 11    n
+--R               (224a b c   - 1344a b c   + 560b c  )x x
+--R             + 
+--R                      3 13        2 2 12         4 11
+--R               (- 224a c   + 1344a b c   - 560a b c  )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                    2 2 12          4 11        6 10     n 2
+--R               (784a b c   - 4704a b c   + 1960b c  )x (x )
+--R             + 
+--R                       3   12        2 3 11          5 10    n
+--R               (- 1568a b c   + 9408a b c   - 3920a b c  )x x
+--R             + 
+--R                    4 12        3 2 11        2 4 10
+--R               (784a c   - 4704a b c   + 1960a b c  )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     2 3 11          5 10        7 9     n 3
+--R               (1568a b c   - 9408a b c   + 3920b c )x (x )
+--R             + 
+--R                       3 2 11         2 4 10           6 9     n 2
+--R               (- 4704a b c   + 28224a b c   - 11760a b c )x (x )
+--R             + 
+--R                     4   11         3 3 10         2 5 9    n
+--R               (4704a b c   - 28224a b c   + 11760a b c )x x
+--R             + 
+--R                       5 11        4 2 10        3 4 9
+--R               (- 1568a c   + 9408a b c   - 3920a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     2 4 10           6 9        8 8     n 4
+--R               (1960a b c   - 11760a b c  + 4900b c )x (x )
+--R             + 
+--R                       3 3 10         2 5 9           7 8     n 3
+--R               (- 7840a b c   + 47040a b c  - 19600a b c )x (x )
+--R             + 
+--R                      4 2 10         3 4 9         2 6 8     n 2
+--R               (11760a b c   - 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                       5   10         4 3 9         3 5 8    n
+--R               (- 7840a b c   + 47040a b c  - 19600a b c )x x
+--R             + 
+--R                     6 10         5 2 9        4 4 8
+--R               (1960a c   - 11760a b c  + 4900a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     2 5 9          7 8        9 7     n 5
+--R               (1568a b c  - 9408a b c  + 3920b c )x (x )
+--R             + 
+--R                       3 4 9         2 6 8           8 7     n 4
+--R               (- 7840a b c  + 47040a b c  - 19600a b c )x (x )
+--R             + 
+--R                      4 3 9         3 5 8         2 7 7     n 3
+--R               (15680a b c  - 94080a b c  + 39200a b c )x (x )
+--R             + 
+--R                        5 2 9         4 4 8         3 6 7     n 2
+--R               (- 15680a b c  + 94080a b c  - 39200a b c )x (x )
+--R             + 
+--R                     6   9         5 3 8         4 5 7    n
+--R               (7840a b c  - 47040a b c  + 19600a b c )x x
+--R             + 
+--R                       7 9        6 2 8        5 4 7
+--R               (- 1568a c  + 9408a b c  - 3920a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                    2 6 8          8 7        10 6     n 6
+--R               (784a b c  - 4704a b c  + 1960b  c )x (x )
+--R             + 
+--R                       3 5 8         2 7 7           9 6     n 5
+--R               (- 4704a b c  + 28224a b c  - 11760a b c )x (x )
+--R             + 
+--R                      4 4 8         3 6 7         2 8 6     n 4
+--R               (11760a b c  - 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                        5 3 8         4 5 7         3 7 6     n 3
+--R               (- 15680a b c  + 94080a b c  - 39200a b c )x (x )
+--R             + 
+--R                      6 2 8         5 4 7         4 6 6     n 2
+--R               (11760a b c  - 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                       7   8         6 3 7         5 5 6    n
+--R               (- 4704a b c  + 28224a b c  - 11760a b c )x x
+--R             + 
+--R                    8 8        7 2 7        6 4 6
+--R               (784a c  - 4704a b c  + 1960a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    2 7 7          9 6       11 5     n 7
+--R               (224a b c  - 1344a b c  + 560b  c )x (x )
+--R             + 
+--R                       3 6 7        2 8 6          10 5     n 6
+--R               (- 1568a b c  + 9408a b c  - 3920a b  c )x (x )
+--R             + 
+--R                     4 5 7         3 7 6         2 9 5     n 5
+--R               (4704a b c  - 28224a b c  + 11760a b c )x (x )
+--R             + 
+--R                       5 4 7         4 6 6         3 8 5     n 4
+--R               (- 7840a b c  + 47040a b c  - 19600a b c )x (x )
+--R             + 
+--R                     6 3 7         5 5 6         4 7 5     n 3
+--R               (7840a b c  - 47040a b c  + 19600a b c )x (x )
+--R             + 
+--R                       7 2 7         6 4 6         5 6 5     n 2
+--R               (- 4704a b c  + 28224a b c  - 11760a b c )x (x )
+--R             + 
+--R                     8   7        7 3 6        6 5 5    n
+--R               (1568a b c  - 9408a b c  + 3920a b c )x x
+--R             + 
+--R                      9 7        8 2 6       7 4 5
+--R               (- 224a c  + 1344a b c  - 560a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               2 8 6         10 5      12 4     n 8
+--R           (28a b c  - 168a b  c  + 70b  c )x (x )
+--R         + 
+--R                  3 7 6        2 9 5         11 4     n 7
+--R           (- 224a b c  + 1344a b c  - 560a b  c )x (x )
+--R         + 
+--R                4 6 6        3 8 5        2 10 4     n 6
+--R           (784a b c  - 4704a b c  + 1960a b  c )x (x )
+--R         + 
+--R                   5 5 6        4 7 5        3 9 4     n 5
+--R           (- 1568a b c  + 9408a b c  - 3920a b c )x (x )
+--R         + 
+--R                 6 4 6         5 6 5        4 8 4     n 4
+--R           (1960a b c  - 11760a b c  + 4900a b c )x (x )
+--R         + 
+--R                   7 3 6        6 5 5        5 7 4     n 3
+--R           (- 1568a b c  + 9408a b c  - 3920a b c )x (x )
+--R         + 
+--R                8 2 6        7 4 5        6 6 4     n 2
+--R           (784a b c  - 4704a b c  + 1960a b c )x (x )
+--R         + 
+--R                  9   6        8 3 5       7 5 4    n
+--R           (- 224a b c  + 1344a b c  - 560a b c )x x
+--R         + 
+--R               10 6       9 2 5      8 4 4
+--R           (28a  c  - 168a b c  + 70a b c )x
+--R      *
+--R            n log(x) 12
+--R         (%e        )
+--R     + 
+--R                2   13         3 12      5 11     2n 8
+--R           (168a b c   - 280a b c   + 56b c  )x (x  )
+--R         + 
+--R                     2 2 12          4 11       6 10    n
+--R               (1344a b c   - 2240a b c   + 448b c  )x x
+--R             + 
+--R                       3   12        2 3 11         5 10
+--R               (- 1344a b c   + 2240a b c   - 448a b c  )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                     2 3 11          5 10        7 9     n 2
+--R               (4704a b c   - 7840a b c   + 1568b c )x (x )
+--R             + 
+--R                       3 2 11         2 4 10          6 9    n
+--R               (- 9408a b c   + 15680a b c   - 3136a b c )x x
+--R             + 
+--R                     4   11        3 3 10        2 5 9
+--R               (4704a b c   - 7840a b c   + 1568a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     2 4 10           6 9        8 8     n 3
+--R               (9408a b c   - 15680a b c  + 3136b c )x (x )
+--R             + 
+--R                        3 3 10         2 5 9          7 8     n 2
+--R               (- 28224a b c   + 47040a b c  - 9408a b c )x (x )
+--R             + 
+--R                      4 2 10         3 4 9        2 6 8    n
+--R               (28224a b c   - 47040a b c  + 9408a b c )x x
+--R             + 
+--R                       5   10         4 3 9        3 5 8
+--R               (- 9408a b c   + 15680a b c  - 3136a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      2 5 9           7 8        9 7     n 4
+--R               (11760a b c  - 19600a b c  + 3920b c )x (x )
+--R             + 
+--R                        3 4 9         2 6 8           8 7     n 3
+--R               (- 47040a b c  + 78400a b c  - 15680a b c )x (x )
+--R             + 
+--R                      4 3 9          3 5 8         2 7 7     n 2
+--R               (70560a b c  - 117600a b c  + 23520a b c )x (x )
+--R             + 
+--R                        5 2 9         4 4 8         3 6 7    n
+--R               (- 47040a b c  + 78400a b c  - 15680a b c )x x
+--R             + 
+--R                      6   9         5 3 8        4 5 7
+--R               (11760a b c  - 19600a b c  + 3920a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     2 6 8           8 7        10 6     n 5
+--R               (9408a b c  - 15680a b c  + 3136b  c )x (x )
+--R             + 
+--R                        3 5 8         2 7 7           9 6     n 4
+--R               (- 47040a b c  + 78400a b c  - 15680a b c )x (x )
+--R             + 
+--R                      4 4 8          3 6 7         2 8 6     n 3
+--R               (94080a b c  - 156800a b c  + 31360a b c )x (x )
+--R             + 
+--R                        5 3 8          4 5 7         3 7 6     n 2
+--R               (- 94080a b c  + 156800a b c  - 31360a b c )x (x )
+--R             + 
+--R                      6 2 8         5 4 7         4 6 6    n
+--R               (47040a b c  - 78400a b c  + 15680a b c )x x
+--R             + 
+--R                       7   8         6 3 7        5 5 6
+--R               (- 9408a b c  + 15680a b c  - 3136a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     2 7 7          9 6        11 5     n 6
+--R               (4704a b c  - 7840a b c  + 1568b  c )x (x )
+--R             + 
+--R                        3 6 7         2 8 6          10 5     n 5
+--R               (- 28224a b c  + 47040a b c  - 9408a b  c )x (x )
+--R             + 
+--R                      4 5 7          3 7 6         2 9 5     n 4
+--R               (70560a b c  - 117600a b c  + 23520a b c )x (x )
+--R             + 
+--R                        5 4 7          4 6 6         3 8 5     n 3
+--R               (- 94080a b c  + 156800a b c  - 31360a b c )x (x )
+--R             + 
+--R                      6 3 7          5 5 6         4 7 5     n 2
+--R               (70560a b c  - 117600a b c  + 23520a b c )x (x )
+--R             + 
+--R                        7 2 7         6 4 6        5 6 5    n
+--R               (- 28224a b c  + 47040a b c  - 9408a b c )x x
+--R             + 
+--R                     8   7        7 3 6        6 5 5
+--R               (4704a b c  - 7840a b c  + 1568a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     2 8 6          10 5       12 4     n 7
+--R               (1344a b c  - 2240a b  c  + 448b  c )x (x )
+--R             + 
+--R                       3 7 6         2 9 5          11 4     n 6
+--R               (- 9408a b c  + 15680a b c  - 3136a b  c )x (x )
+--R             + 
+--R                      4 6 6         3 8 5        2 10 4     n 5
+--R               (28224a b c  - 47040a b c  + 9408a b  c )x (x )
+--R             + 
+--R                        5 5 6         4 7 5         3 9 4     n 4
+--R               (- 47040a b c  + 78400a b c  - 15680a b c )x (x )
+--R             + 
+--R                      6 4 6         5 6 5         4 8 4     n 3
+--R               (47040a b c  - 78400a b c  + 15680a b c )x (x )
+--R             + 
+--R                        7 3 6         6 5 5        5 7 4     n 2
+--R               (- 28224a b c  + 47040a b c  - 9408a b c )x (x )
+--R             + 
+--R                     8 2 6         7 4 5        6 6 4    n
+--R               (9408a b c  - 15680a b c  + 3136a b c )x x
+--R             + 
+--R                       9   6        8 3 5       7 5 4
+--R               (- 1344a b c  + 2240a b c  - 448a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                2 9 5         11 4      13 3     n 8
+--R           (168a b c  - 280a b  c  + 56b  c )x (x )
+--R         + 
+--R                   3 8 5        2 10 4         12 3     n 7
+--R           (- 1344a b c  + 2240a b  c  - 448a b  c )x (x )
+--R         + 
+--R                 4 7 5        3 9 4        2 11 3     n 6
+--R           (4704a b c  - 7840a b c  + 1568a b  c )x (x )
+--R         + 
+--R                   5 6 5         4 8 4        3 10 3     n 5
+--R           (- 9408a b c  + 15680a b c  - 3136a b  c )x (x )
+--R         + 
+--R                  6 5 5         5 7 4        4 9 3     n 4
+--R           (11760a b c  - 19600a b c  + 3920a b c )x (x )
+--R         + 
+--R                   7 4 5         6 6 4        5 8 3     n 3
+--R           (- 9408a b c  + 15680a b c  - 3136a b c )x (x )
+--R         + 
+--R                 8 3 5        7 5 4        6 7 3     n 2
+--R           (4704a b c  - 7840a b c  + 1568a b c )x (x )
+--R         + 
+--R                   9 2 5        8 4 4       7 6 3    n
+--R           (- 1344a b c  + 2240a b c  - 448a b c )x x
+--R         + 
+--R                10   5       9 3 4      8 5 3
+--R           (168a  b c  - 280a b c  + 56a b c )x
+--R      *
+--R            n log(x) 11
+--R         (%e        )
+--R     + 
+--R                 3 13       2 2 12         4 11      6 10     2n 8
+--R           (- 56a c   + 420a b c   - 280a b c   + 28b c  )x (x  )
+--R         + 
+--R                      3   12        2 3 11          5 10       7 9    n
+--R               (- 448a b c   + 3360a b c   - 2240a b c   + 224b c )x x
+--R             + 
+--R                    4 12        3 2 11        2 4 10         6 9
+--R               (448a c   - 3360a b c   + 2240a b c   - 224a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                       3 2 11         2 4 10          6 9       8 8     n 2
+--R               (- 1568a b c   + 11760a b c   - 7840a b c  + 784b c )x (x )
+--R             + 
+--R                     4   11         3 3 10         2 5 9          7 8    n
+--R               (3136a b c   - 23520a b c   + 15680a b c  - 1568a b c )x x
+--R             + 
+--R                       5 11         4 2 10        3 4 9       2 6 8
+--R               (- 1568a c   + 11760a b c   - 7840a b c  + 784a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                       3 3 10         2 5 9           7 8        9 7     n 3
+--R               (- 3136a b c   + 23520a b c  - 15680a b c  + 1568b c )x (x )
+--R             + 
+--R                     4 2 10         3 4 9         2 6 8          8 7     n 2
+--R               (9408a b c   - 70560a b c  + 47040a b c  - 4704a b c )x (x )
+--R             + 
+--R                       5   10         4 3 9         3 5 8        2 7 7    n
+--R               (- 9408a b c   + 70560a b c  - 47040a b c  + 4704a b c )x x
+--R             + 
+--R                     6 10         5 2 9         4 4 8        3 6 7
+--R               (3136a c   - 23520a b c  + 15680a b c  - 1568a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                       3 4 9         2 6 8           8 7        10 6     n 4
+--R               (- 3920a b c  + 29400a b c  - 19600a b c  + 1960b  c )x (x )
+--R             + 
+--R                      4 3 9          3 5 8         2 7 7          9 6     n 3
+--R               (15680a b c  - 117600a b c  + 78400a b c  - 7840a b c )x (x )
+--R             + 
+--R                          5 2 9          4 4 8          3 6 7         2 8 6
+--R                 (- 23520a b c  + 176400a b c  - 117600a b c  + 11760a b c )x
+--R              *
+--R                   n 2
+--R                 (x )
+--R             + 
+--R                      6   9          5 3 8         4 5 7        3 7 6    n
+--R               (15680a b c  - 117600a b c  + 78400a b c  - 7840a b c )x x
+--R             + 
+--R                       7 9         6 2 8         5 4 7        4 6 6
+--R               (- 3920a c  + 29400a b c  - 19600a b c  + 1960a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                       3 5 8         2 7 7           9 6        11 5     n 5
+--R               (- 3136a b c  + 23520a b c  - 15680a b c  + 1568b  c )x (x )
+--R             + 
+--R                      4 4 8          3 6 7         2 8 6          10 5     n 4
+--R               (15680a b c  - 117600a b c  + 78400a b c  - 7840a b  c )x (x )
+--R             + 
+--R                          5 3 8          4 5 7          3 7 6         2 9 5
+--R                 (- 31360a b c  + 235200a b c  - 156800a b c  + 15680a b c )x
+--R              *
+--R                   n 3
+--R                 (x )
+--R             + 
+--R                      6 2 8          5 4 7          4 6 6         3 8 5     n 2
+--R               (31360a b c  - 235200a b c  + 156800a b c  - 15680a b c )x (x )
+--R             + 
+--R                        7   8          6 3 7         5 5 6        4 7 5    n
+--R               (- 15680a b c  + 117600a b c  - 78400a b c  + 7840a b c )x x
+--R             + 
+--R                     8 8         7 2 7         6 4 6        5 6 5
+--R               (3136a c  - 23520a b c  + 15680a b c  - 1568a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                       3 6 7         2 8 6          10 5       12 4     n 6
+--R               (- 1568a b c  + 11760a b c  - 7840a b  c  + 784b  c )x (x )
+--R             + 
+--R                     4 5 7         3 7 6         2 9 5          11 4     n 5
+--R               (9408a b c  - 70560a b c  + 47040a b c  - 4704a b  c )x (x )
+--R             + 
+--R                          5 4 7          4 6 6          3 8 5         2 10 4
+--R                 (- 23520a b c  + 176400a b c  - 117600a b c  + 11760a b  c )x
+--R              *
+--R                   n 4
+--R                 (x )
+--R             + 
+--R                      6 3 7          5 5 6          4 7 5         3 9 4     n 3
+--R               (31360a b c  - 235200a b c  + 156800a b c  - 15680a b c )x (x )
+--R             + 
+--R                          7 2 7          6 4 6          5 6 5         4 8 4
+--R                 (- 23520a b c  + 176400a b c  - 117600a b c  + 11760a b c )x
+--R              *
+--R                   n 2
+--R                 (x )
+--R             + 
+--R                     8   7         7 3 6         6 5 5        5 7 4    n
+--R               (9408a b c  - 70560a b c  + 47040a b c  - 4704a b c )x x
+--R             + 
+--R                       9 7         8 2 6        7 4 5       6 6 4
+--R               (- 1568a c  + 11760a b c  - 7840a b c  + 784a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                      3 7 6        2 9 5          11 4       13 3     n 7
+--R               (- 448a b c  + 3360a b c  - 2240a b  c  + 224b  c )x (x )
+--R             + 
+--R                     4 6 6         3 8 5         2 10 4          12 3     n 6
+--R               (3136a b c  - 23520a b c  + 15680a b  c  - 1568a b  c )x (x )
+--R             + 
+--R                       5 5 6         4 7 5         3 9 4        2 11 3     n 5
+--R               (- 9408a b c  + 70560a b c  - 47040a b c  + 4704a b  c )x (x )
+--R             + 
+--R                      6 4 6          5 6 5         4 8 4        3 10 3     n 4
+--R               (15680a b c  - 117600a b c  + 78400a b c  - 7840a b  c )x (x )
+--R             + 
+--R                        7 3 6          6 5 5         5 7 4        4 9 3     n 3
+--R               (- 15680a b c  + 117600a b c  - 78400a b c  + 7840a b c )x (x )
+--R             + 
+--R                     8 2 6         7 4 5         6 6 4        5 8 3     n 2
+--R               (9408a b c  - 70560a b c  + 47040a b c  - 4704a b c )x (x )
+--R             + 
+--R                       9   6         8 3 5         7 5 4        6 7 3    n
+--R               (- 3136a b c  + 23520a b c  - 15680a b c  + 1568a b c )x x
+--R             + 
+--R                    10 6        9 2 5        8 4 4       7 6 3
+--R               (448a  c  - 3360a b c  + 2240a b c  - 224a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                 3 8 5       2 10 4         12 3      14 2     n 8
+--R           (- 56a b c  + 420a b  c  - 280a b  c  + 28b  c )x (x )
+--R         + 
+--R                4 7 5        3 9 4        2 11 3         13 2     n 7
+--R           (448a b c  - 3360a b c  + 2240a b  c  - 224a b  c )x (x )
+--R         + 
+--R                   5 6 5         4 8 4        3 10 3       2 12 2     n 6
+--R           (- 1568a b c  + 11760a b c  - 7840a b  c  + 784a b  c )x (x )
+--R         + 
+--R                 6 5 5         5 7 4         4 9 3        3 11 2     n 5
+--R           (3136a b c  - 23520a b c  + 15680a b c  - 1568a b  c )x (x )
+--R         + 
+--R                   7 4 5         6 6 4         5 8 3        4 10 2     n 4
+--R           (- 3920a b c  + 29400a b c  - 19600a b c  + 1960a b  c )x (x )
+--R         + 
+--R                 8 3 5         7 5 4         6 7 3        5 9 2     n 3
+--R           (3136a b c  - 23520a b c  + 15680a b c  - 1568a b c )x (x )
+--R         + 
+--R                   9 2 5         8 4 4        7 6 3       6 8 2     n 2
+--R           (- 1568a b c  + 11760a b c  - 7840a b c  + 784a b c )x (x )
+--R         + 
+--R                10   5        9 3 4        8 5 3       7 7 2    n
+--R           (448a  b c  - 3360a b c  + 2240a b c  - 224a b c )x x
+--R         + 
+--R                 11 5       10 2 4       9 4 3      8 6 2
+--R           (- 56a  c  + 420a  b c  - 280a b c  + 28a b c )x
+--R      *
+--R            n log(x) 10
+--R         (%e        )
+--R     + 
+--R                  3   12       2 3 11         5 10     7 9     2n 8
+--R           (- 280a b c   + 560a b c   - 168a b c   + 8b c )x (x  )
+--R         + 
+--R                       3 2 11        2 4 10          6 9      8 8    n
+--R               (- 2240a b c   + 4480a b c   - 1344a b c  + 64b c )x x
+--R             + 
+--R                     4   11        3 3 10        2 5 9        7 8
+--R               (2240a b c   - 4480a b c   + 1344a b c  - 64a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                       3 3 10         2 5 9          7 8       9 7     n 2
+--R               (- 7840a b c   + 15680a b c  - 4704a b c  + 224b c )x (x )
+--R             + 
+--R                      4 2 10         3 4 9        2 6 8         8 7    n
+--R               (15680a b c   - 31360a b c  + 9408a b c  - 448a b c )x x
+--R             + 
+--R                       5   10         4 3 9        3 5 8       2 7 7
+--R               (- 7840a b c   + 15680a b c  - 4704a b c  + 224a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                        3 4 9         2 6 8          8 7       10 6     n 3
+--R               (- 15680a b c  + 31360a b c  - 9408a b c  + 448b  c )x (x )
+--R             + 
+--R                      4 3 9         3 5 8         2 7 7          9 6     n 2
+--R               (47040a b c  - 94080a b c  + 28224a b c  - 1344a b c )x (x )
+--R             + 
+--R                        5 2 9         4 4 8         3 6 7        2 8 6    n
+--R               (- 47040a b c  + 94080a b c  - 28224a b c  + 1344a b c )x x
+--R             + 
+--R                      6   9         5 3 8        4 5 7       3 7 6
+--R               (15680a b c  - 31360a b c  + 9408a b c  - 448a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                        3 5 8         2 7 7           9 6       11 5     n 4
+--R               (- 19600a b c  + 39200a b c  - 11760a b c  + 560b  c )x (x )
+--R             + 
+--R                      4 4 8          3 6 7         2 8 6          10 5     n 3
+--R               (78400a b c  - 156800a b c  + 47040a b c  - 2240a b  c )x (x )
+--R             + 
+--R                         5 3 8          4 5 7         3 7 6        2 9 5     n 2
+--R               (- 117600a b c  + 235200a b c  - 70560a b c  + 3360a b c )x (x )
+--R             + 
+--R                      6 2 8          5 4 7         4 6 6        3 8 5    n
+--R               (78400a b c  - 156800a b c  + 47040a b c  - 2240a b c )x x
+--R             + 
+--R                        7   8         6 3 7         5 5 6       4 7 5
+--R               (- 19600a b c  + 39200a b c  - 11760a b c  + 560a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                        3 6 7         2 8 6          10 5       12 4     n 5
+--R               (- 15680a b c  + 31360a b c  - 9408a b  c  + 448b  c )x (x )
+--R             + 
+--R                      4 5 7          3 7 6         2 9 5          11 4     n 4
+--R               (78400a b c  - 156800a b c  + 47040a b c  - 2240a b  c )x (x )
+--R             + 
+--R                           5 4 7          4 6 6         3 8 5        2 10 4
+--R                 (- 156800a b c  + 313600a b c  - 94080a b c  + 4480a b  c )x
+--R              *
+--R                   n 3
+--R                 (x )
+--R             + 
+--R                       6 3 7          5 5 6         4 7 5        3 9 4     n 2
+--R               (156800a b c  - 313600a b c  + 94080a b c  - 4480a b c )x (x )
+--R             + 
+--R                        7 2 7          6 4 6         5 6 5        4 8 4    n
+--R               (- 78400a b c  + 156800a b c  - 47040a b c  + 2240a b c )x x
+--R             + 
+--R                      8   7         7 3 6        6 5 5       5 7 4
+--R               (15680a b c  - 31360a b c  + 9408a b c  - 448a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                       3 7 6         2 9 5          11 4       13 3     n 6
+--R               (- 7840a b c  + 15680a b c  - 4704a b  c  + 224b  c )x (x )
+--R             + 
+--R                      4 6 6         3 8 5         2 10 4          12 3     n 5
+--R               (47040a b c  - 94080a b c  + 28224a b  c  - 1344a b  c )x (x )
+--R             + 
+--R                           5 5 6          4 7 5         3 9 4        2 11 3
+--R                 (- 117600a b c  + 235200a b c  - 70560a b c  + 3360a b  c )x
+--R              *
+--R                   n 4
+--R                 (x )
+--R             + 
+--R                       6 4 6          5 6 5         4 8 4        3 10 3     n 3
+--R               (156800a b c  - 313600a b c  + 94080a b c  - 4480a b  c )x (x )
+--R             + 
+--R                         7 3 6          6 5 5         5 7 4        4 9 3     n 2
+--R               (- 117600a b c  + 235200a b c  - 70560a b c  + 3360a b c )x (x )
+--R             + 
+--R                      8 2 6         7 4 5         6 6 4        5 8 3    n
+--R               (47040a b c  - 94080a b c  + 28224a b c  - 1344a b c )x x
+--R             + 
+--R                       9   6         8 3 5        7 5 4       6 7 3
+--R               (- 7840a b c  + 15680a b c  - 4704a b c  + 224a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                       3 8 5        2 10 4          12 3      14 2     n 7
+--R               (- 2240a b c  + 4480a b  c  - 1344a b  c  + 64b  c )x (x )
+--R             + 
+--R                      4 7 5         3 9 4        2 11 3         13 2     n 6
+--R               (15680a b c  - 31360a b c  + 9408a b  c  - 448a b  c )x (x )
+--R             + 
+--R                        5 6 5         4 8 4         3 10 3        2 12 2     n 5
+--R               (- 47040a b c  + 94080a b c  - 28224a b  c  + 1344a b  c )x (x )
+--R             + 
+--R                      6 5 5          5 7 4         4 9 3        3 11 2     n 4
+--R               (78400a b c  - 156800a b c  + 47040a b c  - 2240a b  c )x (x )
+--R             + 
+--R                        7 4 5          6 6 4         5 8 3        4 10 2     n 3
+--R               (- 78400a b c  + 156800a b c  - 47040a b c  + 2240a b  c )x (x )
+--R             + 
+--R                      8 3 5         7 5 4         6 7 3        5 9 2     n 2
+--R               (47040a b c  - 94080a b c  + 28224a b c  - 1344a b c )x (x )
+--R             + 
+--R                        9 2 5         8 4 4        7 6 3       6 8 2    n
+--R               (- 15680a b c  + 31360a b c  - 9408a b c  + 448a b c )x x
+--R             + 
+--R                     10   5        9 3 4        8 5 3      7 7 2
+--R               (2240a  b c  - 4480a b c  + 1344a b c  - 64a b c )x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                  3 9 4       2 11 3         13 2     15      n 8
+--R           (- 280a b c  + 560a b  c  - 168a b  c  + 8b  c)x (x )
+--R         + 
+--R                 4 8 4        3 10 3        2 12 2        14      n 7
+--R           (2240a b c  - 4480a b  c  + 1344a b  c  - 64a b  c)x (x )
+--R         + 
+--R                   5 7 4         4 9 3        3 11 2       2 13      n 6
+--R           (- 7840a b c  + 15680a b c  - 4704a b  c  + 224a b  c)x (x )
+--R         + 
+--R                  6 6 4         5 8 3        4 10 2       3 12      n 5
+--R           (15680a b c  - 31360a b c  + 9408a b  c  - 448a b  c)x (x )
+--R         + 
+--R                    7 5 4         6 7 3         5 9 2       4 11      n 4
+--R           (- 19600a b c  + 39200a b c  - 11760a b c  + 560a b  c)x (x )
+--R         + 
+--R                  8 4 4         7 6 3        6 8 2       5 10      n 3
+--R           (15680a b c  - 31360a b c  + 9408a b c  - 448a b  c)x (x )
+--R         + 
+--R                   9 3 4         8 5 3        7 7 2       6 9      n 2
+--R           (- 7840a b c  + 15680a b c  - 4704a b c  + 224a b c)x (x )
+--R         + 
+--R                 10 2 4        9 4 3        8 6 2      7 8     n
+--R           (2240a  b c  - 4480a b c  + 1344a b c  - 64a b c)x x
+--R         + 
+--R                  11   4       10 3 3       9 5 2     8 7
+--R           (- 280a  b c  + 560a  b c  - 168a b c  + 8a b c)x
+--R      *
+--R            n log(x) 9
+--R         (%e        )
+--R     + 
+--R               4 12       3 2 11       2 4 10        6 9    8 8     2n 8
+--R           (70a c   - 560a b c   + 420a b c   - 56a b c  + b c )x (x  )
+--R         + 
+--R                    4   11        3 3 10        2 5 9         7 8     9 7    n
+--R               (560a b c   - 4480a b c   + 3360a b c  - 448a b c  + 8b c )x x
+--R             + 
+--R                      5 11        4 2 10        3 4 9       2 6 8       8 7
+--R               (- 560a c   + 4480a b c   - 3360a b c  + 448a b c  - 8a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                          4 2 10         3 4 9         2 6 8          8 7
+--R                     1960a b c   - 15680a b c  + 11760a b c  - 1568a b c
+--R                   + 
+--R                        10 6
+--R                     28b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                          5   10         4 3 9         3 5 8        2 7 7
+--R                   - 3920a b c   + 31360a b c  - 23520a b c  + 3136a b c
+--R                 + 
+--R                          9 6
+--R                   - 56a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                     6 10         5 2 9         4 4 8        3 6 7      2 8 6
+--R               (1960a c   - 15680a b c  + 11760a b c  - 1568a b c  + 28a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                       4 3 9         3 5 8         2 7 7          9 6      11 5
+--R                 (3920a b c  - 31360a b c  + 23520a b c  - 3136a b c  + 56b  c )
+--R              *
+--R                     n 3
+--R                 x (x )
+--R             + 
+--R                           5 2 9         4 4 8         3 6 7        2 8 6
+--R                   - 11760a b c  + 94080a b c  - 70560a b c  + 9408a b c
+--R                 + 
+--R                           10 5
+--R                   - 168a b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                         6   9         5 3 8         4 5 7        3 7 6
+--R                   11760a b c  - 94080a b c  + 70560a b c  - 9408a b c
+--R                 + 
+--R                       2 9 5
+--R                   168a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                     7 9         6 2 8         5 4 7        4 6 6      3 8 5
+--R             (- 3920a c  + 31360a b c  - 23520a b c  + 3136a b c  - 56a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                          4 4 8         3 6 7         2 8 6          10 5
+--R                     4900a b c  - 39200a b c  + 29400a b c  - 3920a b  c
+--R                   + 
+--R                        12 4
+--R                     70b  c
+--R              *
+--R                     n 4
+--R                 x (x )
+--R             + 
+--R                           5 3 8          4 5 7          3 7 6         2 9 5
+--R                   - 19600a b c  + 156800a b c  - 117600a b c  + 15680a b c
+--R                 + 
+--R                           11 4
+--R                   - 280a b  c
+--R              *
+--R                     n 3
+--R                 x (x )
+--R             + 
+--R                         6 2 8          5 4 7          4 6 6         3 8 5
+--R                   29400a b c  - 235200a b c  + 176400a b c  - 23520a b c
+--R                 + 
+--R                       2 10 4
+--R                   420a b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                           7   8          6 3 7          5 5 6         4 7 5
+--R                   - 19600a b c  + 156800a b c  - 117600a b c  + 15680a b c
+--R                 + 
+--R                         3 9 4
+--R                   - 280a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                     8 8         7 2 7         6 4 6        5 6 5      4 8 4
+--R               (4900a c  - 39200a b c  + 29400a b c  - 3920a b c  + 70a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                          4 5 7         3 7 6         2 9 5          11 4
+--R                     3920a b c  - 31360a b c  + 23520a b c  - 3136a b  c
+--R                   + 
+--R                        13 3
+--R                     56b  c
+--R              *
+--R                     n 5
+--R                 x (x )
+--R             + 
+--R                           5 4 7          4 6 6          3 8 5         2 10 4
+--R                   - 19600a b c  + 156800a b c  - 117600a b c  + 15680a b  c
+--R                 + 
+--R                           12 3
+--R                   - 280a b  c
+--R              *
+--R                     n 4
+--R                 x (x )
+--R             + 
+--R                         6 3 7          5 5 6          4 7 5         3 9 4
+--R                   39200a b c  - 313600a b c  + 235200a b c  - 31360a b c
+--R                 + 
+--R                       2 11 3
+--R                   560a b  c
+--R              *
+--R                     n 3
+--R                 x (x )
+--R             + 
+--R                           7 2 7          6 4 6          5 6 5         4 8 4
+--R                   - 39200a b c  + 313600a b c  - 235200a b c  + 31360a b c
+--R                 + 
+--R                         3 10 3
+--R                   - 560a b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                         8   7          7 3 6          6 5 5         5 7 4
+--R                   19600a b c  - 156800a b c  + 117600a b c  - 15680a b c
+--R                 + 
+--R                       4 9 3
+--R                   280a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                     9 7         8 2 6         7 4 5        6 6 4      5 8 3
+--R             (- 3920a c  + 31360a b c  - 23520a b c  + 3136a b c  - 56a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                          4 6 6         3 8 5         2 10 4          12 3
+--R                     1960a b c  - 15680a b c  + 11760a b  c  - 1568a b  c
+--R                   + 
+--R                        14 2
+--R                     28b  c
+--R              *
+--R                     n 6
+--R                 x (x )
+--R             + 
+--R                           5 5 6         4 7 5         3 9 4        2 11 3
+--R                   - 11760a b c  + 94080a b c  - 70560a b c  + 9408a b  c
+--R                 + 
+--R                           13 2
+--R                   - 168a b  c
+--R              *
+--R                     n 5
+--R                 x (x )
+--R             + 
+--R                         6 4 6          5 6 5          4 8 4         3 10 3
+--R                   29400a b c  - 235200a b c  + 176400a b c  - 23520a b  c
+--R                 + 
+--R                       2 12 2
+--R                   420a b  c
+--R              *
+--R                     n 4
+--R                 x (x )
+--R             + 
+--R                           7 3 6          6 5 5          5 7 4         4 9 3
+--R                   - 39200a b c  + 313600a b c  - 235200a b c  + 31360a b c
+--R                 + 
+--R                         3 11 2
+--R                   - 560a b  c
+--R              *
+--R                     n 3
+--R                 x (x )
+--R             + 
+--R                         8 2 6          7 4 5          6 6 4         5 8 3
+--R                   29400a b c  - 235200a b c  + 176400a b c  - 23520a b c
+--R                 + 
+--R                       4 10 2
+--R                   420a b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                           9   6         8 3 5         7 5 4        6 7 3
+--R                   - 11760a b c  + 94080a b c  - 70560a b c  + 9408a b c
+--R                 + 
+--R                         5 9 2
+--R                   - 168a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                     10 6         9 2 5         8 4 4        7 6 3      6 8 2
+--R               (1960a  c  - 15680a b c  + 11760a b c  - 1568a b c  + 28a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                      4 7 5        3 9 4        2 11 3         13 2     15
+--R                 (560a b c  - 4480a b c  + 3360a b  c  - 448a b  c  + 8b  c)x
+--R              *
+--R                   n 7
+--R                 (x )
+--R             + 
+--R                          5 6 5         4 8 4         3 10 3        2 12 2
+--R                   - 3920a b c  + 31360a b c  - 23520a b  c  + 3136a b  c
+--R                 + 
+--R                          14
+--R                   - 56a b  c
+--R              *
+--R                     n 6
+--R                 x (x )
+--R             + 
+--R                         6 5 5         5 7 4         4 9 3        3 11 2
+--R                   11760a b c  - 94080a b c  + 70560a b c  - 9408a b  c
+--R                 + 
+--R                       2 13
+--R                   168a b  c
+--R              *
+--R                     n 5
+--R                 x (x )
+--R             + 
+--R                           7 4 5          6 6 4          5 8 3         4 10 2
+--R                   - 19600a b c  + 156800a b c  - 117600a b c  + 15680a b  c
+--R                 + 
+--R                         3 12
+--R                   - 280a b  c
+--R              *
+--R                     n 4
+--R                 x (x )
+--R             + 
+--R                         8 3 5          7 5 4          6 7 3         5 9 2
+--R                   19600a b c  - 156800a b c  + 117600a b c  - 15680a b c
+--R                 + 
+--R                       4 11
+--R                   280a b  c
+--R              *
+--R                     n 3
+--R                 x (x )
+--R             + 
+--R                           9 2 5         8 4 4         7 6 3        6 8 2
+--R                   - 11760a b c  + 94080a b c  - 70560a b c  + 9408a b c
+--R                 + 
+--R                         5 10
+--R                   - 168a b  c
+--R              *
+--R                     n 2
+--R                 x (x )
+--R             + 
+--R                          10   5         9 3 4         8 5 3        7 7 2
+--R                     3920a  b c  - 31360a b c  + 23520a b c  - 3136a b c
+--R                   + 
+--R                        6 9
+--R                     56a b c
+--R              *
+--R                    n
+--R                 x x
+--R             + 
+--R                      11 5        10 2 4        9 4 3       8 6 2     7 8
+--R               (- 560a  c  + 4480a  b c  - 3360a b c  + 448a b c  - 8a b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               4 8 4       3 10 3       2 12 2        14     16     n 8
+--R           (70a b c  - 560a b  c  + 420a b  c  - 56a b  c + b  )x (x )
+--R         + 
+--R                  5 7 4        4 9 3        3 11 2       2 13        15     n 7
+--R           (- 560a b c  + 4480a b c  - 3360a b  c  + 448a b  c - 8a b  )x (x )
+--R         + 
+--R                   6 6 4         5 8 3         4 10 2        3 12       2 14
+--R             (1960a b c  - 15680a b c  + 11760a b  c  - 1568a b  c + 28a b  )x
+--R          *
+--R               n 6
+--R             (x )
+--R         + 
+--R                     7 5 4         6 7 3         5 9 2        4 11       3 13
+--R             (- 3920a b c  + 31360a b c  - 23520a b c  + 3136a b  c - 56a b  )x
+--R          *
+--R               n 5
+--R             (x )
+--R         + 
+--R                   8 4 4         7 6 3         6 8 2        5 10       4 12
+--R             (4900a b c  - 39200a b c  + 29400a b c  - 3920a b  c + 70a b  )x
+--R          *
+--R               n 4
+--R             (x )
+--R         + 
+--R                     9 3 4         8 5 3         7 7 2        6 9       5 11
+--R             (- 3920a b c  + 31360a b c  - 23520a b c  + 3136a b c - 56a b  )x
+--R          *
+--R               n 3
+--R             (x )
+--R         + 
+--R                   10 2 4         9 4 3         8 6 2        7 8       6 10
+--R             (1960a  b c  - 15680a b c  + 11760a b c  - 1568a b c + 28a b  )x
+--R          *
+--R               n 2
+--R             (x )
+--R         + 
+--R                  11   4        10 3 3        9 5 2       8 7      7 9    n
+--R           (- 560a  b c  + 4480a  b c  - 3360a b c  + 448a b c - 8a b )x x
+--R         + 
+--R               12 4       11 2 3       10 4 2      9 6     8 8
+--R           (70a  c  - 560a  b c  + 420a  b c  - 56a b c + a b )x
+--R      *
+--R            n log(x) 8
+--R         (%e        )
+--R     + 
+--R                4   11       3 3 10       2 5 9       7 8     2n 8
+--R           (280a b c   - 560a b c   + 168a b c  - 8a b c )x (x  )
+--R         + 
+--R                     4 2 10        3 4 9        2 6 8        8 7    n
+--R               (2240a b c   - 4480a b c  + 1344a b c  - 64a b c )x x
+--R             + 
+--R                       5   10        4 3 9        3 5 8      2 7 7
+--R               (- 2240a b c   + 4480a b c  - 1344a b c  + 64a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                     4 3 9         3 5 8        2 7 7         9 6     n 2
+--R               (7840a b c  - 15680a b c  + 4704a b c  - 224a b c )x (x )
+--R             + 
+--R                        5 2 9         4 4 8        3 6 7       2 8 6    n
+--R               (- 15680a b c  + 31360a b c  - 9408a b c  + 448a b c )x x
+--R             + 
+--R                     6   9         5 3 8        4 5 7       3 7 6
+--R               (7840a b c  - 15680a b c  + 4704a b c  - 224a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                      4 4 8         3 6 7        2 8 6         10 5     n 3
+--R               (15680a b c  - 31360a b c  + 9408a b c  - 448a b  c )x (x )
+--R             + 
+--R                        5 3 8         4 5 7         3 7 6        2 9 5     n 2
+--R               (- 47040a b c  + 94080a b c  - 28224a b c  + 1344a b c )x (x )
+--R             + 
+--R                      6 2 8         5 4 7         4 6 6        3 8 5    n
+--R               (47040a b c  - 94080a b c  + 28224a b c  - 1344a b c )x x
+--R             + 
+--R                        7   8         6 3 7        5 5 6       4 7 5
+--R               (- 15680a b c  + 31360a b c  - 9408a b c  + 448a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      4 5 7         3 7 6         2 9 5         11 4     n 4
+--R               (19600a b c  - 39200a b c  + 11760a b c  - 560a b  c )x (x )
+--R             + 
+--R                        5 4 7          4 6 6         3 8 5        2 10 4     n 3
+--R               (- 78400a b c  + 156800a b c  - 47040a b c  + 2240a b  c )x (x )
+--R             + 
+--R                       6 3 7          5 5 6         4 7 5        3 9 4     n 2
+--R               (117600a b c  - 235200a b c  + 70560a b c  - 3360a b c )x (x )
+--R             + 
+--R                        7 2 7          6 4 6         5 6 5        4 8 4    n
+--R               (- 78400a b c  + 156800a b c  - 47040a b c  + 2240a b c )x x
+--R             + 
+--R                      8   7         7 3 6         6 5 5       5 7 4
+--R               (19600a b c  - 39200a b c  + 11760a b c  - 560a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      4 6 6         3 8 5        2 10 4         12 3     n 5
+--R               (15680a b c  - 31360a b c  + 9408a b  c  - 448a b  c )x (x )
+--R             + 
+--R                        5 5 6          4 7 5         3 9 4        2 11 3     n 4
+--R               (- 78400a b c  + 156800a b c  - 47040a b c  + 2240a b  c )x (x )
+--R             + 
+--R                       6 4 6          5 6 5         4 8 4        3 10 3     n 3
+--R               (156800a b c  - 313600a b c  + 94080a b c  - 4480a b  c )x (x )
+--R             + 
+--R                         7 3 6          6 5 5         5 7 4        4 9 3     n 2
+--R               (- 156800a b c  + 313600a b c  - 94080a b c  + 4480a b c )x (x )
+--R             + 
+--R                      8 2 6          7 4 5         6 6 4        5 8 3    n
+--R               (78400a b c  - 156800a b c  + 47040a b c  - 2240a b c )x x
+--R             + 
+--R                        9   6         8 3 5        7 5 4       6 7 3
+--R               (- 15680a b c  + 31360a b c  - 9408a b c  + 448a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     4 7 5         3 9 4        2 11 3         13 2     n 6
+--R               (7840a b c  - 15680a b c  + 4704a b  c  - 224a b  c )x (x )
+--R             + 
+--R                        5 6 5         4 8 4         3 10 3        2 12 2     n 5
+--R               (- 47040a b c  + 94080a b c  - 28224a b  c  + 1344a b  c )x (x )
+--R             + 
+--R                       6 5 5          5 7 4         4 9 3        3 11 2     n 4
+--R               (117600a b c  - 235200a b c  + 70560a b c  - 3360a b  c )x (x )
+--R             + 
+--R                           7 4 5          6 6 4         5 8 3        4 10 2
+--R                 (- 156800a b c  + 313600a b c  - 94080a b c  + 4480a b  c )x
+--R              *
+--R                   n 3
+--R                 (x )
+--R             + 
+--R                       8 3 5          7 5 4         6 7 3        5 9 2     n 2
+--R               (117600a b c  - 235200a b c  + 70560a b c  - 3360a b c )x (x )
+--R             + 
+--R                        9 2 5         8 4 4         7 6 3        6 8 2    n
+--R               (- 47040a b c  + 94080a b c  - 28224a b c  + 1344a b c )x x
+--R             + 
+--R                     10   5         9 3 4        8 5 3       7 7 2
+--R               (7840a  b c  - 15680a b c  + 4704a b c  - 224a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     4 8 4        3 10 3        2 12 2        14      n 7
+--R               (2240a b c  - 4480a b  c  + 1344a b  c  - 64a b  c)x (x )
+--R             + 
+--R                        5 7 4         4 9 3        3 11 2       2 13      n 6
+--R               (- 15680a b c  + 31360a b c  - 9408a b  c  + 448a b  c)x (x )
+--R             + 
+--R                      6 6 4         5 8 3         4 10 2        3 12      n 5
+--R               (47040a b c  - 94080a b c  + 28224a b  c  - 1344a b  c)x (x )
+--R             + 
+--R                        7 5 4          6 7 3         5 9 2        4 11      n 4
+--R               (- 78400a b c  + 156800a b c  - 47040a b c  + 2240a b  c)x (x )
+--R             + 
+--R                      8 4 4          7 6 3         6 8 2        5 10      n 3
+--R               (78400a b c  - 156800a b c  + 47040a b c  - 2240a b  c)x (x )
+--R             + 
+--R                        9 3 4         8 5 3         7 7 2        6 9      n 2
+--R               (- 47040a b c  + 94080a b c  - 28224a b c  + 1344a b c)x (x )
+--R             + 
+--R                      10 2 4         9 4 3        8 6 2       7 8     n
+--R               (15680a  b c  - 31360a b c  + 9408a b c  - 448a b c)x x
+--R             + 
+--R                       11   4        10 3 3        9 5 2      8 7
+--R               (- 2240a  b c  + 4480a  b c  - 1344a b c  + 64a b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                4 9 3       3 11 2       2 13        15     n 8
+--R           (280a b c  - 560a b  c  + 168a b  c - 8a b  )x (x )
+--R         + 
+--R                   5 8 3        4 10 2        3 12       2 14     n 7
+--R           (- 2240a b c  + 4480a b  c  - 1344a b  c + 64a b  )x (x )
+--R         + 
+--R                 6 7 3         5 9 2        4 11        3 13     n 6
+--R           (7840a b c  - 15680a b c  + 4704a b  c - 224a b  )x (x )
+--R         + 
+--R                    7 6 3         6 8 2        5 10        4 12     n 5
+--R           (- 15680a b c  + 31360a b c  - 9408a b  c + 448a b  )x (x )
+--R         + 
+--R                  8 5 3         7 7 2         6 9        5 11     n 4
+--R           (19600a b c  - 39200a b c  + 11760a b c - 560a b  )x (x )
+--R         + 
+--R                    9 4 3         8 6 2        7 8        6 10     n 3
+--R           (- 15680a b c  + 31360a b c  - 9408a b c + 448a b  )x (x )
+--R         + 
+--R                 10 3 3         9 5 2        8 7        7 9     n 2
+--R           (7840a  b c  - 15680a b c  + 4704a b c - 224a b )x (x )
+--R         + 
+--R                   11 2 3        10 4 2        9 6       8 8    n
+--R           (- 2240a  b c  + 4480a  b c  - 1344a b c + 64a b )x x
+--R         + 
+--R                12   3       11 3 2       10 5      9 7
+--R           (280a  b c  - 560a  b c  + 168a  b c - 8a b )x
+--R      *
+--R            n log(x) 7
+--R         (%e        )
+--R     + 
+--R                 5 11       4 2 10       3 4 9      2 6 8     2n 8
+--R           (- 56a c   + 420a b c   - 280a b c  + 28a b c )x (x  )
+--R         + 
+--R                      5   10        4 3 9        3 5 8       2 7 7    n
+--R               (- 448a b c   + 3360a b c  - 2240a b c  + 224a b c )x x
+--R             + 
+--R                    6 10        5 2 9        4 4 8       3 6 7
+--R               (448a c   - 3360a b c  + 2240a b c  - 224a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                       5 2 9         4 4 8        3 6 7       2 8 6     n 2
+--R               (- 1568a b c  + 11760a b c  - 7840a b c  + 784a b c )x (x )
+--R             + 
+--R                     6   9         5 3 8         4 5 7        3 7 6    n
+--R               (3136a b c  - 23520a b c  + 15680a b c  - 1568a b c )x x
+--R             + 
+--R                       7 9         6 2 8        5 4 7       4 6 6
+--R               (- 1568a c  + 11760a b c  - 7840a b c  + 784a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                       5 3 8         4 5 7         3 7 6        2 9 5     n 3
+--R               (- 3136a b c  + 23520a b c  - 15680a b c  + 1568a b c )x (x )
+--R             + 
+--R                     6 2 8         5 4 7         4 6 6        3 8 5     n 2
+--R               (9408a b c  - 70560a b c  + 47040a b c  - 4704a b c )x (x )
+--R             + 
+--R                       7   8         6 3 7         5 5 6        4 7 5    n
+--R               (- 9408a b c  + 70560a b c  - 47040a b c  + 4704a b c )x x
+--R             + 
+--R                     8 8         7 2 7         6 4 6        5 6 5
+--R               (3136a c  - 23520a b c  + 15680a b c  - 1568a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                       5 4 7         4 6 6         3 8 5        2 10 4     n 4
+--R               (- 3920a b c  + 29400a b c  - 19600a b c  + 1960a b  c )x (x )
+--R             + 
+--R                      6 3 7          5 5 6         4 7 5        3 9 4     n 3
+--R               (15680a b c  - 117600a b c  + 78400a b c  - 7840a b c )x (x )
+--R             + 
+--R                          7 2 7          6 4 6          5 6 5         4 8 4
+--R                 (- 23520a b c  + 176400a b c  - 117600a b c  + 11760a b c )x
+--R              *
+--R                   n 2
+--R                 (x )
+--R             + 
+--R                      8   7          7 3 6         6 5 5        5 7 4    n
+--R               (15680a b c  - 117600a b c  + 78400a b c  - 7840a b c )x x
+--R             + 
+--R                       9 7         8 2 6         7 4 5        6 6 4
+--R               (- 3920a c  + 29400a b c  - 19600a b c  + 1960a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                       5 5 6         4 7 5         3 9 4        2 11 3     n 5
+--R               (- 3136a b c  + 23520a b c  - 15680a b c  + 1568a b  c )x (x )
+--R             + 
+--R                      6 4 6          5 6 5         4 8 4        3 10 3     n 4
+--R               (15680a b c  - 117600a b c  + 78400a b c  - 7840a b  c )x (x )
+--R             + 
+--R                          7 3 6          6 5 5          5 7 4         4 9 3
+--R                 (- 31360a b c  + 235200a b c  - 156800a b c  + 15680a b c )x
+--R              *
+--R                   n 3
+--R                 (x )
+--R             + 
+--R                      8 2 6          7 4 5          6 6 4         5 8 3     n 2
+--R               (31360a b c  - 235200a b c  + 156800a b c  - 15680a b c )x (x )
+--R             + 
+--R                        9   6          8 3 5         7 5 4        6 7 3    n
+--R               (- 15680a b c  + 117600a b c  - 78400a b c  + 7840a b c )x x
+--R             + 
+--R                     10 6         9 2 5         8 4 4        7 6 3
+--R               (3136a  c  - 23520a b c  + 15680a b c  - 1568a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                       5 6 5         4 8 4        3 10 3       2 12 2     n 6
+--R               (- 1568a b c  + 11760a b c  - 7840a b  c  + 784a b  c )x (x )
+--R             + 
+--R                     6 5 5         5 7 4         4 9 3        3 11 2     n 5
+--R               (9408a b c  - 70560a b c  + 47040a b c  - 4704a b  c )x (x )
+--R             + 
+--R                          7 4 5          6 6 4          5 8 3         4 10 2
+--R                 (- 23520a b c  + 176400a b c  - 117600a b c  + 11760a b  c )x
+--R              *
+--R                   n 4
+--R                 (x )
+--R             + 
+--R                      8 3 5          7 5 4          6 7 3         5 9 2     n 3
+--R               (31360a b c  - 235200a b c  + 156800a b c  - 15680a b c )x (x )
+--R             + 
+--R                          9 2 5          8 4 4          7 6 3         6 8 2
+--R                 (- 23520a b c  + 176400a b c  - 117600a b c  + 11760a b c )x
+--R              *
+--R                   n 2
+--R                 (x )
+--R             + 
+--R                     10   5         9 3 4         8 5 3        7 7 2    n
+--R               (9408a  b c  - 70560a b c  + 47040a b c  - 4704a b c )x x
+--R             + 
+--R                       11 5         10 2 4        9 4 3       8 6 2
+--R               (- 1568a  c  + 11760a  b c  - 7840a b c  + 784a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                      5 7 4        4 9 3        3 11 2       2 13      n 7
+--R               (- 448a b c  + 3360a b c  - 2240a b  c  + 224a b  c)x (x )
+--R             + 
+--R                     6 6 4         5 8 3         4 10 2        3 12      n 6
+--R               (3136a b c  - 23520a b c  + 15680a b  c  - 1568a b  c)x (x )
+--R             + 
+--R                       7 5 4         6 7 3         5 9 2        4 11      n 5
+--R               (- 9408a b c  + 70560a b c  - 47040a b c  + 4704a b  c)x (x )
+--R             + 
+--R                      8 4 4          7 6 3         6 8 2        5 10      n 4
+--R               (15680a b c  - 117600a b c  + 78400a b c  - 7840a b  c)x (x )
+--R             + 
+--R                        9 3 4          8 5 3         7 7 2        6 9      n 3
+--R               (- 15680a b c  + 117600a b c  - 78400a b c  + 7840a b c)x (x )
+--R             + 
+--R                     10 2 4         9 4 3         8 6 2        7 8      n 2
+--R               (9408a  b c  - 70560a b c  + 47040a b c  - 4704a b c)x (x )
+--R             + 
+--R                       11   4         10 3 3         9 5 2        8 7     n
+--R               (- 3136a  b c  + 23520a  b c  - 15680a b c  + 1568a b c)x x
+--R             + 
+--R                    12 4        11 2 3        10 4 2       9 6
+--R               (448a  c  - 3360a  b c  + 2240a  b c  - 224a b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                 5 8 3       4 10 2       3 12       2 14     n 8
+--R           (- 56a b c  + 420a b  c  - 280a b  c + 28a b  )x (x )
+--R         + 
+--R                6 7 3        5 9 2        4 11        3 13     n 7
+--R           (448a b c  - 3360a b c  + 2240a b  c - 224a b  )x (x )
+--R         + 
+--R                   7 6 3         6 8 2        5 10        4 12     n 6
+--R           (- 1568a b c  + 11760a b c  - 7840a b  c + 784a b  )x (x )
+--R         + 
+--R                 8 5 3         7 7 2         6 9         5 11     n 5
+--R           (3136a b c  - 23520a b c  + 15680a b c - 1568a b  )x (x )
+--R         + 
+--R                   9 4 3         8 6 2         7 8         6 10     n 4
+--R           (- 3920a b c  + 29400a b c  - 19600a b c + 1960a b  )x (x )
+--R         + 
+--R                 10 3 3         9 5 2         8 7         7 9     n 3
+--R           (3136a  b c  - 23520a b c  + 15680a b c - 1568a b )x (x )
+--R         + 
+--R                   11 2 3         10 4 2        9 6        8 8     n 2
+--R           (- 1568a  b c  + 11760a  b c  - 7840a b c + 784a b )x (x )
+--R         + 
+--R                12   3        11 3 2        10 5        9 7    n
+--R           (448a  b c  - 3360a  b c  + 2240a  b c - 224a b )x x
+--R         + 
+--R                 13 3       12 2 2       11 4       10 6
+--R           (- 56a  c  + 420a  b c  - 280a  b c + 28a  b )x
+--R      *
+--R            n log(x) 6
+--R         (%e        )
+--R     + 
+--R                  5   10       4 3 9      3 5 8     2n 8
+--R           (- 168a b c   + 280a b c  - 56a b c )x (x  )
+--R         + 
+--R                       5 2 9        4 4 8       3 6 7    n
+--R               (- 1344a b c  + 2240a b c  - 448a b c )x x
+--R             + 
+--R                     6   9        5 3 8       4 5 7
+--R               (1344a b c  - 2240a b c  + 448a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                       5 3 8        4 5 7        3 7 6     n 2
+--R               (- 4704a b c  + 7840a b c  - 1568a b c )x (x )
+--R             + 
+--R                     6 2 8         5 4 7        4 6 6    n
+--R               (9408a b c  - 15680a b c  + 3136a b c )x x
+--R             + 
+--R                       7   8        6 3 7        5 5 6
+--R               (- 4704a b c  + 7840a b c  - 1568a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                       5 4 7         4 6 6        3 8 5     n 3
+--R               (- 9408a b c  + 15680a b c  - 3136a b c )x (x )
+--R             + 
+--R                      6 3 7         5 5 6        4 7 5     n 2
+--R               (28224a b c  - 47040a b c  + 9408a b c )x (x )
+--R             + 
+--R                        7 2 7         6 4 6        5 6 5    n
+--R               (- 28224a b c  + 47040a b c  - 9408a b c )x x
+--R             + 
+--R                     8   7         7 3 6        6 5 5
+--R               (9408a b c  - 15680a b c  + 3136a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                        5 5 6         4 7 5        3 9 4     n 4
+--R               (- 11760a b c  + 19600a b c  - 3920a b c )x (x )
+--R             + 
+--R                      6 4 6         5 6 5         4 8 4     n 3
+--R               (47040a b c  - 78400a b c  + 15680a b c )x (x )
+--R             + 
+--R                        7 3 6          6 5 5         5 7 4     n 2
+--R               (- 70560a b c  + 117600a b c  - 23520a b c )x (x )
+--R             + 
+--R                      8 2 6         7 4 5         6 6 4    n
+--R               (47040a b c  - 78400a b c  + 15680a b c )x x
+--R             + 
+--R                        9   6         8 3 5        7 5 4
+--R               (- 11760a b c  + 19600a b c  - 3920a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                       5 6 5         4 8 4        3 10 3     n 5
+--R               (- 9408a b c  + 15680a b c  - 3136a b  c )x (x )
+--R             + 
+--R                      6 5 5         5 7 4         4 9 3     n 4
+--R               (47040a b c  - 78400a b c  + 15680a b c )x (x )
+--R             + 
+--R                        7 4 5          6 6 4         5 8 3     n 3
+--R               (- 94080a b c  + 156800a b c  - 31360a b c )x (x )
+--R             + 
+--R                      8 3 5          7 5 4         6 7 3     n 2
+--R               (94080a b c  - 156800a b c  + 31360a b c )x (x )
+--R             + 
+--R                        9 2 5         8 4 4         7 6 3    n
+--R               (- 47040a b c  + 78400a b c  - 15680a b c )x x
+--R             + 
+--R                     10   5         9 3 4        8 5 3
+--R               (9408a  b c  - 15680a b c  + 3136a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                       5 7 4        4 9 3        3 11 2     n 6
+--R               (- 4704a b c  + 7840a b c  - 1568a b  c )x (x )
+--R             + 
+--R                      6 6 4         5 8 3        4 10 2     n 5
+--R               (28224a b c  - 47040a b c  + 9408a b  c )x (x )
+--R             + 
+--R                        7 5 4          6 7 3         5 9 2     n 4
+--R               (- 70560a b c  + 117600a b c  - 23520a b c )x (x )
+--R             + 
+--R                      8 4 4          7 6 3         6 8 2     n 3
+--R               (94080a b c  - 156800a b c  + 31360a b c )x (x )
+--R             + 
+--R                        9 3 4          8 5 3         7 7 2     n 2
+--R               (- 70560a b c  + 117600a b c  - 23520a b c )x (x )
+--R             + 
+--R                      10 2 4         9 4 3        8 6 2    n
+--R               (28224a  b c  - 47040a b c  + 9408a b c )x x
+--R             + 
+--R                       11   4        10 3 3        9 5 2
+--R               (- 4704a  b c  + 7840a  b c  - 1568a b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                       5 8 3        4 10 2       3 12      n 7
+--R               (- 1344a b c  + 2240a b  c  - 448a b  c)x (x )
+--R             + 
+--R                     6 7 3         5 9 2        4 11      n 6
+--R               (9408a b c  - 15680a b c  + 3136a b  c)x (x )
+--R             + 
+--R                        7 6 3         6 8 2        5 10      n 5
+--R               (- 28224a b c  + 47040a b c  - 9408a b  c)x (x )
+--R             + 
+--R                      8 5 3         7 7 2         6 9      n 4
+--R               (47040a b c  - 78400a b c  + 15680a b c)x (x )
+--R             + 
+--R                        9 4 3         8 6 2         7 8      n 3
+--R               (- 47040a b c  + 78400a b c  - 15680a b c)x (x )
+--R             + 
+--R                      10 3 3         9 5 2        8 7      n 2
+--R               (28224a  b c  - 47040a b c  + 9408a b c)x (x )
+--R             + 
+--R                       11 2 3         10 4 2        9 6     n
+--R               (- 9408a  b c  + 15680a  b c  - 3136a b c)x x
+--R             + 
+--R                     12   3        11 3 2       10 5
+--R               (1344a  b c  - 2240a  b c  + 448a  b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                  5 9 2       4 11       3 13     n 8
+--R           (- 168a b c  + 280a b  c - 56a b  )x (x )
+--R         + 
+--R                 6 8 2        5 10        4 12     n 7
+--R           (1344a b c  - 2240a b  c + 448a b  )x (x )
+--R         + 
+--R                   7 7 2        6 9         5 11     n 6
+--R           (- 4704a b c  + 7840a b c - 1568a b  )x (x )
+--R         + 
+--R                 8 6 2         7 8         6 10     n 5
+--R           (9408a b c  - 15680a b c + 3136a b  )x (x )
+--R         + 
+--R                    9 5 2         8 7         7 9     n 4
+--R           (- 11760a b c  + 19600a b c - 3920a b )x (x )
+--R         + 
+--R                 10 4 2         9 6         8 8     n 3
+--R           (9408a  b c  - 15680a b c + 3136a b )x (x )
+--R         + 
+--R                   11 3 2        10 5         9 7     n 2
+--R           (- 4704a  b c  + 7840a  b c - 1568a b )x (x )
+--R         + 
+--R                 12 2 2        11 4        10 6    n
+--R           (1344a  b c  - 2240a  b c + 448a  b )x x
+--R         + 
+--R                  13   2       12 3       11 5
+--R           (- 168a  b c  + 280a  b c - 56a  b )x
+--R      *
+--R            n log(x) 5
+--R         (%e        )
+--R     + 
+--R               6 10       5 2 9      4 4 8     2n 8
+--R           (28a c   - 168a b c  + 70a b c )x (x  )
+--R         + 
+--R                    6   9        5 3 8       4 5 7    n
+--R               (224a b c  - 1344a b c  + 560a b c )x x
+--R             + 
+--R                      7 9        6 2 8       5 4 7
+--R               (- 224a c  + 1344a b c  - 560a b c )x
+--R          *
+--R               2n 7
+--R             (x  )
+--R         + 
+--R                    6 2 8        5 4 7        4 6 6     n 2
+--R               (784a b c  - 4704a b c  + 1960a b c )x (x )
+--R             + 
+--R                       7   8        6 3 7        5 5 6    n
+--R               (- 1568a b c  + 9408a b c  - 3920a b c )x x
+--R             + 
+--R                    8 8        7 2 7        6 4 6
+--R               (784a c  - 4704a b c  + 1960a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     6 3 7        5 5 6        4 7 5     n 3
+--R               (1568a b c  - 9408a b c  + 3920a b c )x (x )
+--R             + 
+--R                       7 2 7         6 4 6         5 6 5     n 2
+--R               (- 4704a b c  + 28224a b c  - 11760a b c )x (x )
+--R             + 
+--R                     8   7         7 3 6         6 5 5    n
+--R               (4704a b c  - 28224a b c  + 11760a b c )x x
+--R             + 
+--R                       9 7        8 2 6        7 4 5
+--R               (- 1568a c  + 9408a b c  - 3920a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     6 4 6         5 6 5        4 8 4     n 4
+--R               (1960a b c  - 11760a b c  + 4900a b c )x (x )
+--R             + 
+--R                       7 3 6         6 5 5         5 7 4     n 3
+--R               (- 7840a b c  + 47040a b c  - 19600a b c )x (x )
+--R             + 
+--R                      8 2 6         7 4 5         6 6 4     n 2
+--R               (11760a b c  - 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                       9   6         8 3 5         7 5 4    n
+--R               (- 7840a b c  + 47040a b c  - 19600a b c )x x
+--R             + 
+--R                     10 6         9 2 5        8 4 4
+--R               (1960a  c  - 11760a b c  + 4900a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     6 5 5        5 7 4        4 9 3     n 5
+--R               (1568a b c  - 9408a b c  + 3920a b c )x (x )
+--R             + 
+--R                       7 4 5         6 6 4         5 8 3     n 4
+--R               (- 7840a b c  + 47040a b c  - 19600a b c )x (x )
+--R             + 
+--R                      8 3 5         7 5 4         6 7 3     n 3
+--R               (15680a b c  - 94080a b c  + 39200a b c )x (x )
+--R             + 
+--R                        9 2 5         8 4 4         7 6 3     n 2
+--R               (- 15680a b c  + 94080a b c  - 39200a b c )x (x )
+--R             + 
+--R                     10   5         9 3 4         8 5 3    n
+--R               (7840a  b c  - 47040a b c  + 19600a b c )x x
+--R             + 
+--R                       11 5        10 2 4        9 4 3
+--R               (- 1568a  c  + 9408a  b c  - 3920a b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                    6 6 4        5 8 3        4 10 2     n 6
+--R               (784a b c  - 4704a b c  + 1960a b  c )x (x )
+--R             + 
+--R                       7 5 4         6 7 3         5 9 2     n 5
+--R               (- 4704a b c  + 28224a b c  - 11760a b c )x (x )
+--R             + 
+--R                      8 4 4         7 6 3         6 8 2     n 4
+--R               (11760a b c  - 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                        9 3 4         8 5 3         7 7 2     n 3
+--R               (- 15680a b c  + 94080a b c  - 39200a b c )x (x )
+--R             + 
+--R                      10 2 4         9 4 3         8 6 2     n 2
+--R               (11760a  b c  - 70560a b c  + 29400a b c )x (x )
+--R             + 
+--R                       11   4         10 3 3         9 5 2    n
+--R               (- 4704a  b c  + 28224a  b c  - 11760a b c )x x
+--R             + 
+--R                    12 4        11 2 3        10 4 2
+--R               (784a  c  - 4704a  b c  + 1960a  b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    6 7 3        5 9 2       4 11      n 7
+--R               (224a b c  - 1344a b c  + 560a b  c)x (x )
+--R             + 
+--R                       7 6 3        6 8 2        5 10      n 6
+--R               (- 1568a b c  + 9408a b c  - 3920a b  c)x (x )
+--R             + 
+--R                     8 5 3         7 7 2         6 9      n 5
+--R               (4704a b c  - 28224a b c  + 11760a b c)x (x )
+--R             + 
+--R                       9 4 3         8 6 2         7 8      n 4
+--R               (- 7840a b c  + 47040a b c  - 19600a b c)x (x )
+--R             + 
+--R                     10 3 3         9 5 2         8 7      n 3
+--R               (7840a  b c  - 47040a b c  + 19600a b c)x (x )
+--R             + 
+--R                       11 2 3         10 4 2         9 6      n 2
+--R               (- 4704a  b c  + 28224a  b c  - 11760a b c)x (x )
+--R             + 
+--R                     12   3        11 3 2        10 5     n
+--R               (1568a  b c  - 9408a  b c  + 3920a  b c)x x
+--R             + 
+--R                      13 3        12 2 2       11 4
+--R               (- 224a  c  + 1344a  b c  - 560a  b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               6 8 2       5 10       4 12     n 8
+--R           (28a b c  - 168a b  c + 70a b  )x (x )
+--R         + 
+--R                  7 7 2        6 9        5 11     n 7
+--R           (- 224a b c  + 1344a b c - 560a b  )x (x )
+--R         + 
+--R                8 6 2        7 8         6 10     n 6
+--R           (784a b c  - 4704a b c + 1960a b  )x (x )
+--R         + 
+--R                   9 5 2        8 7         7 9     n 5
+--R           (- 1568a b c  + 9408a b c - 3920a b )x (x )
+--R         + 
+--R                 10 4 2         9 6         8 8     n 4
+--R           (1960a  b c  - 11760a b c + 4900a b )x (x )
+--R         + 
+--R                   11 3 2        10 5         9 7     n 3
+--R           (- 1568a  b c  + 9408a  b c - 3920a b )x (x )
+--R         + 
+--R                12 2 2        11 4         10 6     n 2
+--R           (784a  b c  - 4704a  b c + 1960a  b )x (x )
+--R         + 
+--R                  13   2        12 3        11 5    n
+--R           (- 224a  b c  + 1344a  b c - 560a  b )x x
+--R         + 
+--R               14 2       13 2       12 4
+--R           (28a  c  - 168a  b c + 70a  b )x
+--R      *
+--R            n log(x) 4
+--R         (%e        )
+--R     + 
+--R               6   9      5 3 8     2n 8
+--R           (56a b c  - 56a b c )x (x  )
+--R         + 
+--R                 6 2 8       5 4 7    n          7   8       6 3 7     2n 7
+--R           ((448a b c  - 448a b c )x x  + (- 448a b c  + 448a b c )x)(x  )
+--R         + 
+--R                     6 3 7        5 5 6     n 2
+--R               (1568a b c  - 1568a b c )x (x )
+--R             + 
+--R                       7 2 7        6 4 6    n         8   7        7 3 6
+--R               (- 3136a b c  + 3136a b c )x x  + (1568a b c  - 1568a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                     6 4 6        5 6 5     n 3
+--R               (3136a b c  - 3136a b c )x (x )
+--R             + 
+--R                       7 3 6        6 5 5     n 2
+--R               (- 9408a b c  + 9408a b c )x (x )
+--R             + 
+--R                     8 2 6        7 4 5    n           9   6        8 3 5
+--R               (9408a b c  - 9408a b c )x x  + (- 3136a b c  + 3136a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     6 5 5        5 7 4     n 4
+--R               (3920a b c  - 3920a b c )x (x )
+--R             + 
+--R                        7 4 5         6 6 4     n 3
+--R               (- 15680a b c  + 15680a b c )x (x )
+--R             + 
+--R                      8 3 5         7 5 4     n 2
+--R               (23520a b c  - 23520a b c )x (x )
+--R             + 
+--R                        9 2 5         8 4 4    n         10   5        9 3 4
+--R               (- 15680a b c  + 15680a b c )x x  + (3920a  b c  - 3920a b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     6 6 4        5 8 3     n 5
+--R               (3136a b c  - 3136a b c )x (x )
+--R             + 
+--R                        7 5 4         6 7 3     n 4
+--R               (- 15680a b c  + 15680a b c )x (x )
+--R             + 
+--R                      8 4 4         7 6 3     n 3
+--R               (31360a b c  - 31360a b c )x (x )
+--R             + 
+--R                        9 3 4         8 5 3     n 2
+--R               (- 31360a b c  + 31360a b c )x (x )
+--R             + 
+--R                    10 2 4         9 4 3    n           11   4        10 3 3
+--R             (15680a  b c  - 15680a b c )x x  + (- 3136a  b c  + 3136a  b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     6 7 3        5 9 2     n 6
+--R               (1568a b c  - 1568a b c )x (x )
+--R             + 
+--R                       7 6 3        6 8 2     n 5
+--R               (- 9408a b c  + 9408a b c )x (x )
+--R             + 
+--R                      8 5 3         7 7 2     n 4
+--R               (23520a b c  - 23520a b c )x (x )
+--R             + 
+--R                        9 4 3         8 6 2     n 3
+--R               (- 31360a b c  + 31360a b c )x (x )
+--R             + 
+--R                      10 3 3         9 5 2     n 2
+--R               (23520a  b c  - 23520a b c )x (x )
+--R             + 
+--R                       11 2 3        10 4 2    n         12   3        11 3 2
+--R               (- 9408a  b c  + 9408a  b c )x x  + (1568a  b c  - 1568a  b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    6 8 2       5 10      n 7
+--R               (448a b c  - 448a b  c)x (x )
+--R             + 
+--R                       7 7 2        6 9      n 6
+--R               (- 3136a b c  + 3136a b c)x (x )
+--R             + 
+--R                     8 6 2        7 8      n 5
+--R               (9408a b c  - 9408a b c)x (x )
+--R             + 
+--R                        9 5 2         8 7      n 4
+--R               (- 15680a b c  + 15680a b c)x (x )
+--R             + 
+--R                      10 4 2         9 6      n 3
+--R               (15680a  b c  - 15680a b c)x (x )
+--R             + 
+--R                       11 3 2        10 5      n 2
+--R               (- 9408a  b c  + 9408a  b c)x (x )
+--R             + 
+--R                     12 2 2        11 4     n          13   2       12 3
+--R               (3136a  b c  - 3136a  b c)x x  + (- 448a  b c  + 448a  b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               6 9       5 11     n 8          7 8        6 10     n 7
+--R           (56a b c - 56a b  )x (x )  + (- 448a b c + 448a b  )x (x )
+--R         + 
+--R                 8 7         7 9     n 6           9 6         8 8     n 5
+--R           (1568a b c - 1568a b )x (x )  + (- 3136a b c + 3136a b )x (x )
+--R         + 
+--R                 10 5         9 7     n 4           11 4         10 6     n 3
+--R           (3920a  b c - 3920a b )x (x )  + (- 3136a  b c + 3136a  b )x (x )
+--R         + 
+--R                 12 3         11 5     n 2          13 2        12 4    n
+--R           (1568a  b c - 1568a  b )x (x )  + (- 448a  b c + 448a  b )x x
+--R         + 
+--R               14         13 3
+--R           (56a  b c - 56a  b )x
+--R      *
+--R            n log(x) 3
+--R         (%e        )
+--R     + 
+--R                7 9      6 2 8     2n 8
+--R           (- 8a c  + 28a b c )x (x  )
+--R         + 
+--R                  7   8       6 3 7    n       8 8       7 2 7     2n 7
+--R           ((- 64a b c  + 224a b c )x x  + (64a c  - 224a b c )x)(x  )
+--R         + 
+--R                      7 2 7       6 4 6     n 2        8   7        7 3 6    n
+--R               (- 224a b c  + 784a b c )x (x )  + (448a b c  - 1568a b c )x x
+--R             + 
+--R                      9 7       8 2 6
+--R               (- 224a c  + 784a b c )x
+--R          *
+--R               2n 6
+--R             (x  )
+--R         + 
+--R                      7 3 6        6 5 5     n 3
+--R               (- 448a b c  + 1568a b c )x (x )
+--R             + 
+--R                     8 2 6        7 4 5     n 2
+--R               (1344a b c  - 4704a b c )x (x )
+--R             + 
+--R                       9   6        8 3 5    n        10 6        9 2 5
+--R               (- 1344a b c  + 4704a b c )x x  + (448a  c  - 1568a b c )x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                      7 4 5        6 6 4     n 4
+--R               (- 560a b c  + 1960a b c )x (x )
+--R             + 
+--R                     8 3 5        7 5 4     n 3
+--R               (2240a b c  - 7840a b c )x (x )
+--R             + 
+--R                       9 2 5         8 4 4     n 2
+--R               (- 3360a b c  + 11760a b c )x (x )
+--R             + 
+--R                     10   5        9 3 4    n          11 5        10 2 4
+--R               (2240a  b c  - 7840a b c )x x  + (- 560a  c  + 1960a  b c )x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                      7 5 4        6 7 3     n 5
+--R               (- 448a b c  + 1568a b c )x (x )
+--R             + 
+--R                     8 4 4        7 6 3     n 4
+--R               (2240a b c  - 7840a b c )x (x )
+--R             + 
+--R                       9 3 4         8 5 3     n 3
+--R               (- 4480a b c  + 15680a b c )x (x )
+--R             + 
+--R                     10 2 4         9 4 3     n 2
+--R               (4480a  b c  - 15680a b c )x (x )
+--R             + 
+--R                       11   4        10 3 3    n        12 4        11 2 3
+--R               (- 2240a  b c  + 7840a  b c )x x  + (448a  c  - 1568a  b c )x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                      7 6 3       6 8 2     n 6
+--R               (- 224a b c  + 784a b c )x (x )
+--R             + 
+--R                     8 5 3        7 7 2     n 5
+--R               (1344a b c  - 4704a b c )x (x )
+--R             + 
+--R                       9 4 3         8 6 2     n 4
+--R               (- 3360a b c  + 11760a b c )x (x )
+--R             + 
+--R                     10 3 3         9 5 2     n 3
+--R               (4480a  b c  - 15680a b c )x (x )
+--R             + 
+--R                       11 2 3         10 4 2     n 2
+--R               (- 3360a  b c  + 11760a  b c )x (x )
+--R             + 
+--R                     12   3        11 3 2    n          13 3       12 2 2
+--R               (1344a  b c  - 4704a  b c )x x  + (- 224a  c  + 784a  b c )x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                     7 7 2       6 9      n 7        8 6 2        7 8      n 6
+--R               (- 64a b c  + 224a b c)x (x )  + (448a b c  - 1568a b c)x (x )
+--R             + 
+--R                       9 5 2        8 7      n 5
+--R               (- 1344a b c  + 4704a b c)x (x )
+--R             + 
+--R                     10 4 2        9 6      n 4
+--R               (2240a  b c  - 7840a b c)x (x )
+--R             + 
+--R                       11 3 2        10 5      n 3
+--R               (- 2240a  b c  + 7840a  b c)x (x )
+--R             + 
+--R                     12 2 2        11 4      n 2
+--R               (1344a  b c  - 4704a  b c)x (x )
+--R             + 
+--R                      13   2        12 3     n       14 2       13 2
+--R               (- 448a  b c  + 1568a  b c)x x  + (64a  c  - 224a  b c)x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R                7 8       6 10     n 8       8 7        7 9     n 7
+--R           (- 8a b c + 28a b  )x (x )  + (64a b c - 224a b )x (x )
+--R         + 
+--R                  9 6        8 8     n 6        10 5         9 7     n 5
+--R           (- 224a b c + 784a b )x (x )  + (448a  b c - 1568a b )x (x )
+--R         + 
+--R                  11 4         10 6     n 4        12 3         11 5     n 3
+--R           (- 560a  b c + 1960a  b )x (x )  + (448a  b c - 1568a  b )x (x )
+--R         + 
+--R                  13 2        12 4     n 2       14          13 3    n
+--R           (- 224a  b c + 784a  b )x (x )  + (64a  b c - 224a  b )x x
+--R         + 
+--R                15       14 2
+--R           (- 8a  c + 28a  b )x
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R               7   8    2n 8         7 2 7   n      8   7    2n 7
+--R           - 8a b c x (x  )  + (- 64a b c x x  + 64a b c x)(x  )
+--R         + 
+--R                  7 3 6    n 2       8 2 6   n       9   6    2n 6
+--R           (- 224a b c x (x )  + 448a b c x x  - 224a b c x)(x  )
+--R         + 
+--R                     7 4 5    n 3        8 3 5    n 2        9 2 5   n
+--R               - 448a b c x (x )  + 1344a b c x (x )  - 1344a b c x x
+--R             + 
+--R                   10   5
+--R               448a  b c x
+--R          *
+--R               2n 5
+--R             (x  )
+--R         + 
+--R                     7 5 4    n 4        8 4 4    n 3        9 3 4    n 2
+--R               - 560a b c x (x )  + 2240a b c x (x )  - 3360a b c x (x )
+--R             + 
+--R                    10 2 4   n       11   4
+--R               2240a  b c x x  - 560a  b c x
+--R          *
+--R               2n 4
+--R             (x  )
+--R         + 
+--R                     7 6 3    n 5        8 5 3    n 4        9 4 3    n 3
+--R               - 448a b c x (x )  + 2240a b c x (x )  - 4480a b c x (x )
+--R             + 
+--R                    10 3 3    n 2        11 2 3   n       12   3
+--R               4480a  b c x (x )  - 2240a  b c x x  + 448a  b c x
+--R          *
+--R               2n 3
+--R             (x  )
+--R         + 
+--R                     7 7 2    n 6        8 6 2    n 5        9 5 2    n 4
+--R               - 224a b c x (x )  + 1344a b c x (x )  - 3360a b c x (x )
+--R             + 
+--R                    10 4 2    n 3        11 3 2    n 2        12 2 2   n
+--R               4480a  b c x (x )  - 3360a  b c x (x )  + 1344a  b c x x
+--R             + 
+--R                     13   2
+--R               - 224a  b c x
+--R          *
+--R               2n 2
+--R             (x  )
+--R         + 
+--R                    7 8      n 7       8 7      n 6        9 6      n 5
+--R               - 64a b c x (x )  + 448a b c x (x )  - 1344a b c x (x )
+--R             + 
+--R                    10 5      n 4        11 4      n 3        12 3      n 2
+--R               2240a  b c x (x )  - 2240a  b c x (x )  + 1344a  b c x (x )
+--R             + 
+--R                     13 2     n      14
+--R               - 448a  b c x x  + 64a  b c x
+--R          *
+--R              2n
+--R             x
+--R         + 
+--R               7 9    n 8      8 8    n 7       9 7    n 6       10 6    n 5
+--R           - 8a b x (x )  + 64a b x (x )  - 224a b x (x )  + 448a  b x (x )
+--R         + 
+--R                 11 5    n 4       12 4    n 3       13 3    n 2      14 2   n
+--R           - 560a  b x (x )  + 448a  b x (x )  - 224a  b x (x )  + 64a  b x x
+--R         + 
+--R               15
+--R           - 8a  b x
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R        8 8    2n 8      8   7   n     9 7    2n 7
+--R       a c x (x  )  + (8a b c x x  - 8a c x)(x  )
+--R     + 
+--R           8 2 6    n 2      9   6   n      10 6    2n 6
+--R       (28a b c x (x )  - 56a b c x x  + 28a  c x)(x  )
+--R     + 
+--R           8 3 5    n 3       9 2 5    n 2       10   5   n      11 5    2n 5
+--R       (56a b c x (x )  - 168a b c x (x )  + 168a  b c x x  - 56a  c x)(x  )
+--R     + 
+--R              8 4 4    n 4       9 3 4    n 3       10 2 4    n 2
+--R           70a b c x (x )  - 280a b c x (x )  + 420a  b c x (x )
+--R         + 
+--R                 11   4   n      12 4
+--R           - 280a  b c x x  + 70a  c x
+--R      *
+--R           2n 4
+--R         (x  )
+--R     + 
+--R              8 5 3    n 5       9 4 3    n 4       10 3 3    n 3
+--R           56a b c x (x )  - 280a b c x (x )  + 560a  b c x (x )
+--R         + 
+--R                 11 2 3    n 2       12   3   n      13 3
+--R           - 560a  b c x (x )  + 280a  b c x x  - 56a  c x
+--R      *
+--R           2n 3
+--R         (x  )
+--R     + 
+--R              8 6 2    n 6       9 5 2    n 5       10 4 2    n 4
+--R           28a b c x (x )  - 168a b c x (x )  + 420a  b c x (x )
+--R         + 
+--R                 11 3 2    n 3       12 2 2    n 2       13   2   n      14 2
+--R           - 560a  b c x (x )  + 420a  b c x (x )  - 168a  b c x x  + 28a  c x
+--R      *
+--R           2n 2
+--R         (x  )
+--R     + 
+--R             8 7      n 7      9 6      n 6       10 5      n 5
+--R           8a b c x (x )  - 56a b c x (x )  + 168a  b c x (x )
+--R         + 
+--R                 11 4      n 4       12 3      n 3       13 2      n 2
+--R           - 280a  b c x (x )  + 280a  b c x (x )  - 168a  b c x (x )
+--R         + 
+--R              14       n     15
+--R           56a  b c x x  - 8a  c x
+--R      *
+--R          2n
+--R         x
+--R     + 
+--R        8 8    n 8     9 7    n 7      10 6    n 6      11 5    n 5
+--R       a b x (x )  - 8a b x (x )  + 28a  b x (x )  - 56a  b x (x )
+--R     + 
+--R          12 4    n 4      13 3    n 3      14 2    n 2     15     n    16
+--R       70a  b x (x )  - 56a  b x (x )  + 28a  b x (x )  - 8a  b x x  + a  x
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 649
+t0:=(b+2*c*x)/(b*x+c*x^2)
+--R 
+--R
+--R         2c x + b
+--R   (1)  ----------
+--R           2
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 523
+
+--S 524 of 649
+r0:=log(x*(b+c*x)),log(x)+log(b+c*x)
+--R 
+--R
+--R                2
+--R   (2)  [log(c x  + b x),log(c x + b) + log(x)]
+--R                                             Type: Tuple(Expression(Integer))
+--E 524
+
+--S 525 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R   (3)  log(c x  + b x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 525
+
+--S 526 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 527
+
+)clear all
+
+--S 528 of 649
+t0:=x*(b+2*c*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R             2
+--R         2c x  + b
+--R   (1)  ----------
+--R           3
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 528
+
+--S 529 of 649
+r0:=log(x)+1/2*log(b+c*x^2)
+--R 
+--R
+--R               2
+--R        log(c x  + b) + 2log(x)
+--R   (2)  -----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R        log(c x  + b) + 2log(x)
+--R   (3)  -----------------------
+--R                   2
+--R                                         Type: Union(Expression(Integer),...)
+--E 530
+
+--S 531 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 532
+
+)clear all
+
+--S 533 of 649
+t0:=x^2*(b+2*c*x^3)/(b*x^3+c*x^6)
+--R 
+--R
+--R             3
+--R         2c x  + b
+--R   (1)  ----------
+--R           4
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 533
+
+--S 534 of 649
+r0:=log(x)+1/3*log(b+c*x^3)
+--R 
+--R
+--R               3
+--R        log(c x  + b) + 3log(x)
+--R   (2)  -----------------------
+--R                   3
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3
+--R        log(c x  + b) + 3log(x)
+--R   (3)  -----------------------
+--R                   3
+--R                                         Type: Union(Expression(Integer),...)
+--E 535
+
+--S 536 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 537
+
+)clear all
+
+--S 538 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 1 n      n - 1
+--R        2c x     x  + b x
+--R   (1)  ----------------------
+--R                2n      n
+--R             c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 649
+r0:=log(x)+log(b+c*x^n)/n
+--R 
+--R
+--R               n
+--R        log(c x  + b) + n log(x)
+--R   (2)  ------------------------
+--R                    n
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                n log(x)
+--R        log(c %e         + b) + n log(x)
+--R   (3)  --------------------------------
+--R                        n
+--R                                         Type: Union(Expression(Integer),...)
+--E 540
+
+--S 541 of 649
+m0:=a0-r0
+--R 
+--R
+--R                n log(x)               n
+--R        log(c %e         + b) - log(c x  + b)
+--R   (4)  -------------------------------------
+--R                          n
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R          2 n    2   n - 1         n log(x)          n - 1
+--R        (c x  - c x x      + b c)%e         - b c x x
+--R   (5)  --------------------------------------------------
+--R              2   n           n log(x)          n    2
+--R            (c x x  + b c x)%e         + b c x x  + b x
+--R                                                    Type: Expression(Integer)
+--E 542
+
+)clear all
+
+--S 543 of 649
+t0:=(b+2*c*x)/(b*x+c*x^2)^8
+--R 
+--R
+--R   (1)
+--R     2c x + b
+--R  /
+--R        8 16       7 15      2 6 14      3 5 13      4 4 12      5 3 11
+--R       c x   + 8b c x   + 28b c x   + 56b c x   + 70b c x   + 56b c x
+--R     + 
+--R          6 2 10     7   9    8 8
+--R       28b c x   + 8b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 543
+
+--S 544 of 649
+r0:=(-1/7)/(x^7*(b+c*x)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R        1
+--R        -
+--R        7
+--R     /
+--R           7 14       6 13      2 5 12      3 4 11      4 3 10      5 2 9
+--R          c x   + 7b c x   + 21b c x   + 35b c x   + 35b c x   + 21b c x
+--R        + 
+--R            6   8    7 7
+--R          7b c x  + b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 544
+
+--S 545 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R            7 14        6 13       2 5 12       3 4 11       4 3 10       5 2 9
+--R          7c x   + 49b c x   + 147b c x   + 245b c x   + 245b c x   + 147b c x
+--R        + 
+--R             6   8     7 7
+--R          49b c x  + 7b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 545
+
+--S 546 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 547
+
+)clear all
+
+--S 548 of 649
+t0:=x*(b+2*c*x^2)/(b*x^2+c*x^4)^8
+--R 
+--R
+--R   (1)
+--R         2
+--R     2c x  + b
+--R  /
+--R        8 31       7 29      2 6 27      3 5 25      4 4 23      5 3 21
+--R       c x   + 8b c x   + 28b c x   + 56b c x   + 70b c x   + 56b c x
+--R     + 
+--R          6 2 19     7   17    8 15
+--R       28b c x   + 8b c x   + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 548
+
+--S 549 of 649
+r0:=(-1/14)/(x^14*(b+c*x^2)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R         1
+--R        --
+--R        14
+--R     /
+--R           7 28       6 26      2 5 24      3 4 22      4 3 20      5 2 18
+--R          c x   + 7b c x   + 21b c x   + 35b c x   + 35b c x   + 21b c x
+--R        + 
+--R            6   16    7 14
+--R          7b c x   + b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 549
+
+--S 550 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R             7 28        6 26       2 5 24       3 4 22       4 3 20
+--R          14c x   + 98b c x   + 294b c x   + 490b c x   + 490b c x
+--R        + 
+--R              5 2 18      6   16      7 14
+--R          294b c x   + 98b c x   + 14b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 550
+
+--S 551 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 649
+t0:=x^2*(b+2*c*x^3)/(b*x^3+c*x^6)^8
+--R 
+--R
+--R   (1)
+--R         3
+--R     2c x  + b
+--R  /
+--R        8 46       7 43      2 6 40      3 5 37      4 4 34      5 3 31
+--R       c x   + 8b c x   + 28b c x   + 56b c x   + 70b c x   + 56b c x
+--R     + 
+--R          6 2 28     7   25    8 22
+--R       28b c x   + 8b c x   + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 553
+
+--S 554 of 649
+r0:=(-1/21)/(x^21*(b+c*x^3)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R         1
+--R        --
+--R        21
+--R     /
+--R           7 42       6 39      2 5 36      3 4 33      4 3 30      5 2 27
+--R          c x   + 7b c x   + 21b c x   + 35b c x   + 35b c x   + 21b c x
+--R        + 
+--R            6   24    7 21
+--R          7b c x   + b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 554
+
+--S 555 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R             7 42         6 39       2 5 36       3 4 33       4 3 30
+--R          21c x   + 147b c x   + 441b c x   + 735b c x   + 735b c x
+--R        + 
+--R              5 2 27       6   24      7 21
+--R          441b c x   + 147b c x   + 21b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 555
+
+--S 556 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 557
+
+)clear all
+
+--S 558 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)/(b*x^n+c*x^(2*n))^8
+--R 
+--R
+--R   (1)
+--R         n - 1 n      n - 1
+--R     2c x     x  + b x
+--R  /
+--R        8  2n 8       7 n  2n 7      2 6  n 2  2n 6      3 5  n 3  2n 5
+--R       c (x  )  + 8b c x (x  )  + 28b c (x ) (x  )  + 56b c (x ) (x  )
+--R     + 
+--R          4 4  n 4  2n 4      5 3  n 5  2n 3      6 2  n 6  2n 2     7    n 7 2n
+--R       70b c (x ) (x  )  + 56b c (x ) (x  )  + 28b c (x ) (x  )  + 8b c (x ) x
+--R     + 
+--R        8  n 8
+--R       b (x )
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 649
+r0:=(-1/7)/(n*x^(7*n)*(b+c*x^n)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R        1
+--R     /
+--R              7    n 7        6    n 6       2 5    n 5       3 4    n 4
+--R            7c n (x )  + 49b c n (x )  + 147b c n (x )  + 245b c n (x )
+--R          + 
+--R                4 3    n 3       5 2    n 2      6     n     7
+--R            245b c n (x )  + 147b c n (x )  + 49b c n x  + 7b n
+--R       *
+--R           7n
+--R          x
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R            7     n log(x) 14        6     n log(x) 13       2 5     n log(x) 12
+--R          7c n (%e        )   + 49b c n (%e        )   + 147b c n (%e        )
+--R        + 
+--R              3 4     n log(x) 11       4 3     n log(x) 10
+--R          245b c n (%e        )   + 245b c n (%e        )
+--R        + 
+--R              5 2     n log(x) 9      6       n log(x) 8     7     n log(x) 7
+--R          147b c n (%e        )  + 49b c n (%e        )  + 7b n (%e        )
+--R                                         Type: Union(Expression(Integer),...)
+--E 560
+
+--S 561 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        7   n log(x) 14       6   n log(x) 13      2 5   n log(x) 12
+--R       c (%e        )   + 7b c (%e        )   + 21b c (%e        )
+--R     + 
+--R          3 4   n log(x) 11      4 3   n log(x) 10      5 2   n log(x) 9
+--R       35b c (%e        )   + 35b c (%e        )   + 21b c (%e        )
+--R     + 
+--R         6     n log(x) 8    7   n log(x) 7
+--R       7b c (%e        )  + b (%e        )
+--R     + 
+--R              7  n 7       6  n 6      2 5  n 5      3 4  n 4      4 3  n 3
+--R           - c (x )  - 7b c (x )  - 21b c (x )  - 35b c (x )  - 35b c (x )
+--R         + 
+--R                5 2  n 2     6   n    7
+--R           - 21b c (x )  - 7b c x  - b
+--R      *
+--R          7n
+--R         x
+--R  /
+--R             14    n 7        13    n 6       2 12    n 5       3 11    n 4
+--R           7c  n (x )  + 49b c  n (x )  + 147b c  n (x )  + 245b c  n (x )
+--R         + 
+--R               4 10    n 3       5 9    n 2      6 8   n     7 7
+--R           245b c  n (x )  + 147b c n (x )  + 49b c n x  + 7b c n
+--R      *
+--R          7n   n log(x) 14
+--R         x  (%e        )
+--R     + 
+--R                13    n 7       2 12    n 6        3 11    n 5
+--R           49b c  n (x )  + 343b c  n (x )  + 1029b c  n (x )
+--R         + 
+--R                4 10    n 4        5 9    n 3        6 8    n 2       7 7   n
+--R           1715b c  n (x )  + 1715b c n (x )  + 1029b c n (x )  + 343b c n x
+--R         + 
+--R              8 6
+--R           49b c n
+--R      *
+--R          7n   n log(x) 13
+--R         x  (%e        )
+--R     + 
+--R               2 12    n 7        3 11    n 6        4 10    n 5
+--R           147b c  n (x )  + 1029b c  n (x )  + 3087b c  n (x )
+--R         + 
+--R                5 9    n 4        6 8    n 3        7 7    n 2        8 6   n
+--R           5145b c n (x )  + 5145b c n (x )  + 3087b c n (x )  + 1029b c n x
+--R         + 
+--R               9 5
+--R           147b c n
+--R      *
+--R          7n   n log(x) 12
+--R         x  (%e        )
+--R     + 
+--R               3 11    n 7        4 10    n 6        5 9    n 5
+--R           245b c  n (x )  + 1715b c  n (x )  + 5145b c n (x )
+--R         + 
+--R                6 8    n 4        7 7    n 3        8 6    n 2        9 5   n
+--R           8575b c n (x )  + 8575b c n (x )  + 5145b c n (x )  + 1715b c n x
+--R         + 
+--R               10 4
+--R           245b  c n
+--R      *
+--R          7n   n log(x) 11
+--R         x  (%e        )
+--R     + 
+--R               4 10    n 7        5 9    n 6        6 8    n 5        7 7    n 4
+--R           245b c  n (x )  + 1715b c n (x )  + 5145b c n (x )  + 8575b c n (x )
+--R         + 
+--R                8 6    n 3        9 5    n 2        10 4   n       11 3
+--R           8575b c n (x )  + 5145b c n (x )  + 1715b  c n x  + 245b  c n
+--R      *
+--R          7n   n log(x) 10
+--R         x  (%e        )
+--R     + 
+--R               5 9    n 7        6 8    n 6        7 7    n 5        8 6    n 4
+--R           147b c n (x )  + 1029b c n (x )  + 3087b c n (x )  + 5145b c n (x )
+--R         + 
+--R                9 5    n 3        10 4    n 2        11 3   n       12 2
+--R           5145b c n (x )  + 3087b  c n (x )  + 1029b  c n x  + 147b  c n
+--R      *
+--R          7n   n log(x) 9
+--R         x  (%e        )
+--R     + 
+--R              6 8    n 7       7 7    n 6        8 6    n 5        9 5    n 4
+--R           49b c n (x )  + 343b c n (x )  + 1029b c n (x )  + 1715b c n (x )
+--R         + 
+--R                10 4    n 3        11 3    n 2       12 2   n      13
+--R           1715b  c n (x )  + 1029b  c n (x )  + 343b  c n x  + 49b  c n
+--R      *
+--R          7n   n log(x) 8
+--R         x  (%e        )
+--R     + 
+--R             7 7    n 7      8 6    n 6       9 5    n 5       10 4    n 4
+--R           7b c n (x )  + 49b c n (x )  + 147b c n (x )  + 245b  c n (x )
+--R         + 
+--R               11 3    n 3       12 2    n 2      13     n     14
+--R           245b  c n (x )  + 147b  c n (x )  + 49b  c n x  + 7b  n
+--R      *
+--R          7n   n log(x) 7
+--R         x  (%e        )
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           9   n - 1 7n       9   n      8   7n - 1    n log(x) 15
+--R       (- c x x     x   + (- c x x  - b c x)x      )(%e        )
+--R     + 
+--R              8   n - 1 7n          8   n     2 7   7n - 1    n log(x) 14
+--R       (- 8b c x x     x   + (- 8b c x x  - 8b c x)x      )(%e        )
+--R     + 
+--R             2 7   n - 1 7n         2 7   n      3 6   7n - 1    n log(x) 13
+--R       (- 28b c x x     x   + (- 28b c x x  - 28b c x)x      )(%e        )
+--R     + 
+--R             3 6   n - 1 7n         3 6   n      4 5   7n - 1    n log(x) 12
+--R       (- 56b c x x     x   + (- 56b c x x  - 56b c x)x      )(%e        )
+--R     + 
+--R             4 5   n - 1 7n         4 5   n      5 4   7n - 1    n log(x) 11
+--R       (- 70b c x x     x   + (- 70b c x x  - 70b c x)x      )(%e        )
+--R     + 
+--R             5 4   n - 1 7n         5 4   n      6 3   7n - 1    n log(x) 10
+--R       (- 56b c x x     x   + (- 56b c x x  - 56b c x)x      )(%e        )
+--R     + 
+--R             6 3   n - 1 7n         6 3   n      7 2   7n - 1    n log(x) 9
+--R       (- 28b c x x     x   + (- 28b c x x  - 28b c x)x      )(%e        )
+--R     + 
+--R            7 2   n - 1 7n        7 2   n     8     7n - 1    n log(x) 8
+--R       (- 8b c x x     x   + (- 8b c x x  - 8b c x)x      )(%e        )
+--R     + 
+--R           8     n - 1 7n       8     n    9   7n - 1    n log(x) 7
+--R       (- b c x x     x   + (- b c x x  - b x)x      )(%e        )
+--R     + 
+--R             9  n 8        8  n 7      2 7  n 6       3 6  n 5       4 5  n 4
+--R           2c (x )  + 16b c (x )  + 56b c (x )  + 112b c (x )  + 140b c (x )
+--R         + 
+--R               5 4  n 3      6 3  n 2      7 2 n     8
+--R           112b c (x )  + 56b c (x )  + 16b c x  + 2b c
+--R      *
+--R           7n 2  n log(x)
+--R         (x  ) %e
+--R     + 
+--R              8  n 8     2 7  n 7      3 6  n 6      4 5  n 5      5 4  n 4
+--R           b c (x )  + 8b c (x )  + 28b c (x )  + 56b c (x )  + 70b c (x )
+--R         + 
+--R              6 3  n 3      7 2  n 2     8   n    9
+--R           56b c (x )  + 28b c (x )  + 8b c x  + b
+--R      *
+--R           7n 2
+--R         (x  )
+--R  /
+--R            16    n 8       15    n 7      2 14    n 6      3 13    n 5
+--R           c  x (x )  + 8b c  x (x )  + 28b c  x (x )  + 56b c  x (x )
+--R         + 
+--R              4 12    n 4      5 11    n 3      6 10    n 2     7 9   n    8 8
+--R           70b c  x (x )  + 56b c  x (x )  + 28b c  x (x )  + 8b c x x  + b c x
+--R      *
+--R           7n 2   n log(x) 15
+--R         (x  ) (%e        )
+--R     + 
+--R               15    n 8      2 14    n 7       3 13    n 6       4 12    n 5
+--R           8b c  x (x )  + 64b c  x (x )  + 224b c  x (x )  + 448b c  x (x )
+--R         + 
+--R               5 11    n 4       6 10    n 3       7 9    n 2      8 8   n
+--R           560b c  x (x )  + 448b c  x (x )  + 224b c x (x )  + 64b c x x
+--R         + 
+--R             9 7
+--R           8b c x
+--R      *
+--R           7n 2   n log(x) 14
+--R         (x  ) (%e        )
+--R     + 
+--R              2 14    n 8       3 13    n 7       4 12    n 6        5 11    n 5
+--R           28b c  x (x )  + 224b c  x (x )  + 784b c  x (x )  + 1568b c  x (x )
+--R         + 
+--R                6 10    n 4        7 9    n 3       8 8    n 2       9 7   n
+--R           1960b c  x (x )  + 1568b c x (x )  + 784b c x (x )  + 224b c x x
+--R         + 
+--R              10 6
+--R           28b  c x
+--R      *
+--R           7n 2   n log(x) 13
+--R         (x  ) (%e        )
+--R     + 
+--R              3 13    n 8       4 12    n 7        5 11    n 6
+--R           56b c  x (x )  + 448b c  x (x )  + 1568b c  x (x )
+--R         + 
+--R                6 10    n 5        7 9    n 4        8 8    n 3
+--R           3136b c  x (x )  + 3920b c x (x )  + 3136b c x (x )
+--R         + 
+--R                9 7    n 2       10 6   n      11 5
+--R           1568b c x (x )  + 448b  c x x  + 56b  c x
+--R      *
+--R           7n 2   n log(x) 12
+--R         (x  ) (%e        )
+--R     + 
+--R              4 12    n 8       5 11    n 7        6 10    n 6        7 9    n 5
+--R           70b c  x (x )  + 560b c  x (x )  + 1960b c  x (x )  + 3920b c x (x )
+--R         + 
+--R                8 8    n 4        9 7    n 3        10 6    n 2       11 5   n
+--R           4900b c x (x )  + 3920b c x (x )  + 1960b  c x (x )  + 560b  c x x
+--R         + 
+--R              12 4
+--R           70b  c x
+--R      *
+--R           7n 2   n log(x) 11
+--R         (x  ) (%e        )
+--R     + 
+--R              5 11    n 8       6 10    n 7        7 9    n 6        8 8    n 5
+--R           56b c  x (x )  + 448b c  x (x )  + 1568b c x (x )  + 3136b c x (x )
+--R         + 
+--R                9 7    n 4        10 6    n 3        11 5    n 2       12 4   n
+--R           3920b c x (x )  + 3136b  c x (x )  + 1568b  c x (x )  + 448b  c x x
+--R         + 
+--R              13 3
+--R           56b  c x
+--R      *
+--R           7n 2   n log(x) 10
+--R         (x  ) (%e        )
+--R     + 
+--R              6 10    n 8       7 9    n 7       8 8    n 6        9 7    n 5
+--R           28b c  x (x )  + 224b c x (x )  + 784b c x (x )  + 1568b c x (x )
+--R         + 
+--R                10 6    n 4        11 5    n 3       12 4    n 2       13 3   n
+--R           1960b  c x (x )  + 1568b  c x (x )  + 784b  c x (x )  + 224b  c x x
+--R         + 
+--R              14 2
+--R           28b  c x
+--R      *
+--R           7n 2   n log(x) 9
+--R         (x  ) (%e        )
+--R     + 
+--R             7 9    n 8      8 8    n 7       9 7    n 6       10 6    n 5
+--R           8b c x (x )  + 64b c x (x )  + 224b c x (x )  + 448b  c x (x )
+--R         + 
+--R               11 5    n 4       12 4    n 3       13 3    n 2      14 2   n
+--R           560b  c x (x )  + 448b  c x (x )  + 224b  c x (x )  + 64b  c x x
+--R         + 
+--R             15
+--R           8b  c x
+--R      *
+--R           7n 2   n log(x) 8
+--R         (x  ) (%e        )
+--R     + 
+--R            8 8    n 8     9 7    n 7      10 6    n 6      11 5    n 5
+--R           b c x (x )  + 8b c x (x )  + 28b  c x (x )  + 56b  c x (x )
+--R         + 
+--R              12 4    n 4      13 3    n 3      14 2    n 2     15     n    16
+--R           70b  c x (x )  + 56b  c x (x )  + 28b  c x (x )  + 8b  c x x  + b  x
+--R      *
+--R           7n 2   n log(x) 7
+--R         (x  ) (%e        )
+--R                                                    Type: Expression(Integer)
+--E 562
+
+)clear all
+
+--S 563 of 649
+t0:=(b+2*c*x)*(a+b*x+c*x^2)^p
+--R 
+--R
+--R                      2           p
+--R   (1)  (2c x + b)(c x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 649
+r0:=(a+b*x+c*x^2)^(1+p)/(1+p)
+--R 
+--R
+--R            2           p + 1
+--R        (c x  + b x + a)
+--R   (2)  ---------------------
+--R                p + 1
+--R                                                    Type: Expression(Integer)
+--E 564
+
+--S 565 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   2
+--R            2             p log(c x  + b x + a)
+--R        (c x  + b x + a)%e
+--R   (3)  ---------------------------------------
+--R                         p + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 565
+
+--S 566 of 649
+m0:=a0-r0
+--R 
+--R
+--R                                   2
+--R            2             p log(c x  + b x + a)       2           p + 1
+--R        (c x  + b x + a)%e                      - (c x  + b x + a)
+--R   (4)  ---------------------------------------------------------------
+--R                                     p + 1
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R                             2
+--R                    p log(c x  + b x + a)                   2           p
+--R   (5)  (2c x + b)%e                      + (- 2c x - b)(c x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 567
+
+)clear all
+
+--S 568 of 649
+t0:=x*(b+2*c*x^2)*(a+b*x^2+c*x^4)^p
+--R 
+--R
+--R             3           4      2     p
+--R   (1)  (2c x  + b x)(c x  + b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 649
+r0:=1/2*(a+b*x^2+c*x^4)^(1+p)/(1+p)
+--R 
+--R
+--R            4      2     p + 1
+--R        (c x  + b x  + a)
+--R   (2)  ----------------------
+--R                2p + 2
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                    4      2
+--R            4      2       p log(c x  + b x  + a)
+--R        (c x  + b x  + a)%e
+--R   (3)  -----------------------------------------
+--R                          2p + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 570
+
+--S 571 of 649
+m0:=a0-r0
+--R 
+--R
+--R                                    4      2
+--R            4      2       p log(c x  + b x  + a)       4      2     p + 1
+--R        (c x  + b x  + a)%e                       - (c x  + b x  + a)
+--R   (4)  ------------------------------------------------------------------
+--R                                      2p + 2
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                           4      2
+--R        3         p log(c x  + b x  + a)          3           4      2     p
+--R   (2c x  + b x)%e                       + (- 2c x  - b x)(c x  + b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 572
+
+)clear all
+
+--S 573 of 649
+t0:=x^2*(b+2*c*x^3)*(a+b*x^3+c*x^6)^p
+--R 
+--R
+--R             5      2     6      3     p
+--R   (1)  (2c x  + b x )(c x  + b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 649
+r0:=1/3*(a+b*x^3+c*x^6)^(1+p)/(1+p)
+--R 
+--R
+--R            6      3     p + 1
+--R        (c x  + b x  + a)
+--R   (2)  ----------------------
+--R                3p + 3
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                    6      3
+--R            6      3       p log(c x  + b x  + a)
+--R        (c x  + b x  + a)%e
+--R   (3)  -----------------------------------------
+--R                          3p + 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 575
+
+--S 576 of 649
+m0:=a0-r0
+--R 
+--R
+--R                                    6      3
+--R            6      3       p log(c x  + b x  + a)       6      3     p + 1
+--R        (c x  + b x  + a)%e                       - (c x  + b x  + a)
+--R   (4)  ------------------------------------------------------------------
+--R                                      3p + 3
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                            6      3
+--R        5      2   p log(c x  + b x  + a)          5      2     6      3     p
+--R   (2c x  + b x )%e                       + (- 2c x  - b x )(c x  + b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 577
+
+)clear all
+
+--S 578 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)*(a+b*x^n+c*x^(2*n))^p
+--R 
+--R
+--R             n - 1 n      n - 1     2n      n     p
+--R   (1)  (2c x     x  + b x     )(c x   + b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 649
+r0:=(a+b*x^n+c*x^(2*n))^(1+p)/(n*(1+p))
+--R 
+--R
+--R            2n      n     p + 1
+--R        (c x   + b x  + a)
+--R   (2)  -----------------------
+--R                n p + n
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             n log(x) 2       n log(x)
+--R       (c (%e        )  + b %e         + a)
+--R    *
+--R                    n log(x) 2       n log(x)
+--R         p log(c (%e        )  + b %e         + a)
+--R       %e
+--R  /
+--R     n p + n
+--R                                         Type: Union(Expression(Integer),...)
+--E 580
+
+--S 581 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               n log(x) 2       n log(x)
+--R         (c (%e        )  + b %e         + a)
+--R      *
+--R                      n log(x) 2       n log(x)
+--R           p log(c (%e        )  + b %e         + a)
+--R         %e
+--R     + 
+--R             2n      n     p + 1
+--R       - (c x   + b x  + a)
+--R  /
+--R     n p + n
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                n log(x) 2       n log(x)
+--R         (2c (%e        )  + b %e        )
+--R      *
+--R                      n log(x) 2       n log(x)
+--R           p log(c (%e        )  + b %e         + a)
+--R         %e
+--R     + 
+--R                2n - 1        n - 1     2n      n     p
+--R       (- 2c x x       - b x x     )(c x   + b x  + a)
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 649
+t0:=(b+2*c*x)*(-a+b*x+c*x^2)^p
+--R 
+--R
+--R                      2           p
+--R   (1)  (2c x + b)(c x  + b x - a)
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 649
+r0:=(-a+b*x+c*x^2)^(1+p)/(1+p)
+--R 
+--R
+--R            2           p + 1
+--R        (c x  + b x - a)
+--R   (2)  ---------------------
+--R                p + 1
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   2
+--R            2             p log(c x  + b x - a)
+--R        (c x  + b x - a)%e
+--R   (3)  ---------------------------------------
+--R                         p + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 585
+
+--S 586 of 649
+m0:=a0-r0
+--R 
+--R
+--R                                   2
+--R            2             p log(c x  + b x - a)       2           p + 1
+--R        (c x  + b x - a)%e                      - (c x  + b x - a)
+--R   (4)  ---------------------------------------------------------------
+--R                                     p + 1
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R                             2
+--R                    p log(c x  + b x - a)                   2           p
+--R   (5)  (2c x + b)%e                      + (- 2c x - b)(c x  + b x - a)
+--R                                                    Type: Expression(Integer)
+--E 587
+
+)clear all
+
+--S 588 of 649
+t0:=x*(b+2*c*x^2)*(-a+b*x^2+c*x^4)^p
+--R 
+--R
+--R             3           4      2     p
+--R   (1)  (2c x  + b x)(c x  + b x  - a)
+--R                                                    Type: Expression(Integer)
+--E 588
+
+--S 589 of 649
+r0:=1/2*(-a+b*x^2+c*x^4)^(1+p)/(1+p)
+--R 
+--R
+--R            4      2     p + 1
+--R        (c x  + b x  - a)
+--R   (2)  ----------------------
+--R                2p + 2
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                    4      2
+--R            4      2       p log(c x  + b x  - a)
+--R        (c x  + b x  - a)%e
+--R   (3)  -----------------------------------------
+--R                          2p + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 590
+
+--S 591 of 649
+m0:=a0-r0
+--R 
+--R
+--R                                    4      2
+--R            4      2       p log(c x  + b x  - a)       4      2     p + 1
+--R        (c x  + b x  - a)%e                       - (c x  + b x  - a)
+--R   (4)  ------------------------------------------------------------------
+--R                                      2p + 2
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                           4      2
+--R        3         p log(c x  + b x  - a)          3           4      2     p
+--R   (2c x  + b x)%e                       + (- 2c x  - b x)(c x  + b x  - a)
+--R                                                    Type: Expression(Integer)
+--E 592
+
+)clear all
+
+--S 593 of 649
+t0:=x^2*(b+2*c*x^3)*(-a+b*x^3+c*x^6)^p
+--R 
+--R
+--R             5      2     6      3     p
+--R   (1)  (2c x  + b x )(c x  + b x  - a)
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 649
+r0:=1/3*(-a+b*x^3+c*x^6)^(1+p)/(1+p)
+--R 
+--R
+--R            6      3     p + 1
+--R        (c x  + b x  - a)
+--R   (2)  ----------------------
+--R                3p + 3
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                    6      3
+--R            6      3       p log(c x  + b x  - a)
+--R        (c x  + b x  - a)%e
+--R   (3)  -----------------------------------------
+--R                          3p + 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 595
+
+--S 596 of 649
+m0:=a0-r0
+--R 
+--R
+--R                                    6      3
+--R            6      3       p log(c x  + b x  - a)       6      3     p + 1
+--R        (c x  + b x  - a)%e                       - (c x  + b x  - a)
+--R   (4)  ------------------------------------------------------------------
+--R                                      3p + 3
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                            6      3
+--R        5      2   p log(c x  + b x  - a)          5      2     6      3     p
+--R   (2c x  + b x )%e                       + (- 2c x  - b x )(c x  + b x  - a)
+--R                                                    Type: Expression(Integer)
+--E 597
+
+)clear all
+
+--S 598 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)*(-a+b*x^n+c*x^(2*n))^p
+--R 
+--R
+--R             n - 1 n      n - 1     2n      n     p
+--R   (1)  (2c x     x  + b x     )(c x   + b x  - a)
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 649
+r0:=(-a+b*x^n+c*x^(2*n))^(1+p)/(n*(1+p))
+--R 
+--R
+--R            2n      n     p + 1
+--R        (c x   + b x  - a)
+--R   (2)  -----------------------
+--R                n p + n
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             n log(x) 2       n log(x)
+--R       (c (%e        )  + b %e         - a)
+--R    *
+--R                    n log(x) 2       n log(x)
+--R         p log(c (%e        )  + b %e         - a)
+--R       %e
+--R  /
+--R     n p + n
+--R                                         Type: Union(Expression(Integer),...)
+--E 600
+
+--S 601 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               n log(x) 2       n log(x)
+--R         (c (%e        )  + b %e         - a)
+--R      *
+--R                      n log(x) 2       n log(x)
+--R           p log(c (%e        )  + b %e         - a)
+--R         %e
+--R     + 
+--R             2n      n     p + 1
+--R       - (c x   + b x  - a)
+--R  /
+--R     n p + n
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                n log(x) 2       n log(x)
+--R         (2c (%e        )  + b %e        )
+--R      *
+--R                      n log(x) 2       n log(x)
+--R           p log(c (%e        )  + b %e         - a)
+--R         %e
+--R     + 
+--R                2n - 1        n - 1     2n      n     p
+--R       (- 2c x x       - b x x     )(c x   + b x  - a)
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 602
+
+)clear all
+
+--S 603 of 649
+t0:=(b+2*c*x)*(b*x+c*x^2)^p
+--R 
+--R
+--R                      2       p
+--R   (1)  (2c x + b)(c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 649
+r0:=(b*x+c*x^2)^(1+p)/(1+p)
+--R 
+--R
+--R            2       p + 1
+--R        (c x  + b x)
+--R   (2)  -----------------
+--R              p + 1
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               2
+--R            2         p log(c x  + b x)
+--R        (c x  + b x)%e
+--R   (3)  -------------------------------
+--R                     p + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 605
+
+--S 606 of 649
+m0:=a0-r0
+--R 
+--R
+--R                               2
+--R            2         p log(c x  + b x)       2       p + 1
+--R        (c x  + b x)%e                  - (c x  + b x)
+--R   (4)  ---------------------------------------------------
+--R                               p + 1
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R                             2
+--R                    p log(c x  + b x)                   2       p
+--R   (5)  (2c x + b)%e                  + (- 2c x - b)(c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 607
+
+)clear all
+
+--S 608 of 649
+t0:=x*(b+2*c*x^2)*(b*x^2+c*x^4)^p
+--R 
+--R
+--R             3           4      2 p
+--R   (1)  (2c x  + b x)(c x  + b x )
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 649
+r0:=1/2*(b*x^2+c*x^4)^(1+p)/(1+p)
+--R 
+--R
+--R            4      2 p + 1
+--R        (c x  + b x )
+--R   (2)  ------------------
+--R              2p + 2
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                4      2
+--R            4      2   p log(c x  + b x )
+--R        (c x  + b x )%e
+--R   (3)  ---------------------------------
+--R                      2p + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 610
+
+--S 611 of 649
+m0:=a0-r0
+--R 
+--R
+--R                                4      2
+--R            4      2   p log(c x  + b x )       4      2 p + 1
+--R        (c x  + b x )%e                   - (c x  + b x )
+--R   (4)  ------------------------------------------------------
+--R                                2p + 2
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R                                4      2
+--R             3         p log(c x  + b x )          3           4      2 p
+--R   (5)  (2c x  + b x)%e                   + (- 2c x  - b x)(c x  + b x )
+--R                                                    Type: Expression(Integer)
+--E 612
+
+)clear all
+
+--S 613 of 649
+t0:=x^2*(b+2*c*x^3)*(b*x^3+c*x^6)^p
+--R 
+--R
+--R             5      2     6      3 p
+--R   (1)  (2c x  + b x )(c x  + b x )
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 649
+r0:=1/3*(b*x^3+c*x^6)^(1+p)/(1+p)
+--R 
+--R
+--R            6      3 p + 1
+--R        (c x  + b x )
+--R   (2)  ------------------
+--R              3p + 3
+--R                                                    Type: Expression(Integer)
+--E 614
+
+--S 615 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                6      3
+--R            6      3   p log(c x  + b x )
+--R        (c x  + b x )%e
+--R   (3)  ---------------------------------
+--R                      3p + 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 615
+
+--S 616 of 649
+m0:=a0-r0
+--R 
+--R
+--R                                6      3
+--R            6      3   p log(c x  + b x )       6      3 p + 1
+--R        (c x  + b x )%e                   - (c x  + b x )
+--R   (4)  ------------------------------------------------------
+--R                                3p + 3
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R                                 6      3
+--R             5      2   p log(c x  + b x )          5      2     6      3 p
+--R   (5)  (2c x  + b x )%e                   + (- 2c x  - b x )(c x  + b x )
+--R                                                    Type: Expression(Integer)
+--E 617
+
+)clear all
+
+--S 618 of 649
+t0:=x^(-1+n)*(b+2*c*x^n)*(b*x^n+c*x^(2*n))^p
+--R 
+--R
+--R             n - 1 n      n - 1     2n      n p
+--R   (1)  (2c x     x  + b x     )(c x   + b x )
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 649
+r0:=(b*x^n+c*x^(2*n))^(1+p)/(n*(1+p))
+--R 
+--R
+--R            2n      n p + 1
+--R        (c x   + b x )
+--R   (2)  -------------------
+--R              n p + n
+--R                                                    Type: Expression(Integer)
+--E 619
+
+--S 620 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                n log(x) 2       n log(x)
+--R         n log(x) 2       n log(x)   p log(c (%e        )  + b %e        )
+--R   (c (%e        )  + b %e        )%e
+--R   -----------------------------------------------------------------------
+--R                                   n p + n
+--R                                         Type: Union(Expression(Integer),...)
+--E 620
+
+--S 621 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    n log(x) 2       n log(x)
+--R             n log(x) 2       n log(x)   p log(c (%e        )  + b %e        )
+--R       (c (%e        )  + b %e        )%e
+--R     + 
+--R             2n      n p + 1
+--R       - (c x   + b x )
+--R  /
+--R     n p + n
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                     n log(x) 2       n log(x)
+--R              n log(x) 2       n log(x)   p log(c (%e        )  + b %e        )
+--R       (2c (%e        )  + b %e        )%e
+--R     + 
+--R                2n - 1        n - 1     2n      n p
+--R       (- 2c x x       - b x x     )(c x   + b x )
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 622
+
+)clear all
+
+--S 623 of 649
+t0:=(d+e*x^n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R               n
+--R            e x  + d
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 649
+--r0:=x*hypergeometric(1,1/n,1+1/n,-2*c*x^n/(b-sqrt(b^2-4*a*c)))*_
+--  (e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c))+x*_
+--  hypergeometric(1,1/n,1+1/n,-2*c*x^n/(b+sqrt(b^2-4*a*c)))*_
+--  (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c))
+--E 624
+
+--S 625 of 649
+--a0:=integrate(t0,x)
+--E 625
+
+--S 626 of 649
+--m0:=a0-r0
+--E 626
+
+--S 627 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (2)  0
+--R                                                    Type: Polynomial(Integer)
+--E 627
+
+)clear all
+
+--S 628 of 649
+t0:=(d+e*x)/(a+b*x+c*x^2)
+--R 
+--R
+--R            e x + d
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 628
+
+--S 629 of 649
+r0:=1/2*e*log(a+b*x+c*x^2)/c-(2*c*d-b*e)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                                              +-----------+
+--R                         2c x + b                2            |          2
+--R   (2b e - 4c d)atanh(--------------) + e log(c x  + b x + a)\|- 4a c + b
+--R                       +-----------+
+--R                       |          2
+--R                      \|- 4a c + b
+--R   ------------------------------------------------------------------------
+--R                                  +-----------+
+--R                                  |          2
+--R                               2c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           (b e - 2c d)
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                               +-----------+
+--R                  2            |          2
+--R         e log(c x  + b x + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       2c\|- 4a c + b
+--R     ,
+--R
+--R                                        +---------+
+--R                                        |        2
+--R                             (2c x + b)\|4a c - b
+--R         (- 2b e + 4c d)atan(----------------------)
+--R                                            2
+--R                                    4a c - b
+--R       + 
+--R                               +---------+
+--R                  2            |        2
+--R         e log(c x  + b x + a)\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       2c\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 630
+
+--S 631 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         (b e - 2c d)
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                               2c x + b
+--R       (- 2b e + 4c d)atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     2c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      +---------+
+--R                      |        2          2c x + b
+--R       (- b e + 2c d)\|4a c - b  atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                      +-----------+                |        2
+--R                      |          2      (2c x + b)\|4a c - b
+--R       (- b e + 2c d)\|- 4a c + b  atan(----------------------)
+--R                                                       2
+--R                                               4a c - b
+--R  /
+--R       +-----------+ +---------+
+--R       |          2  |        2
+--R     c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 633
+
+--S 634 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 634
+
+)clear all
+
+--S 635 of 649
+t0:=(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 635
+
+--S 636 of 649
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(e+(2*c*d-b*e)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(e+(-2*c*d+b*e)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2                | |          2
+--R         (e\|- 4a c + b   - b e + 2c d)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2                |   |          2
+--R         (e\|- 4a c + b   + b e - 2c d)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R                                  +-------------------------+
+--R                                  |   2 4         2 2    2 4
+--R                    2 2       2   |- a e  + 2a c d e  - c d          2
+--R                (16a c  - 4a b c) |-------------------------  + a b e
+--R                                  |       3 3      2 2 2
+--R                                 \|    64a c  - 16a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                         3 2     2 2            2   2       3
+--R                    ((32a c  - 8a b c)e + (- 16a b c  + 4a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                         +-------------------------+
+--R                                         |   2 4         2 2    2 4
+--R                           2 2       2   |- a e  + 2a c d e  - c d          2
+--R                       (16a c  - 4a b c) |-------------------------  + a b e
+--R                                         |       3 3      2 2 2
+--R                                        \|    64a c  - 16a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 2 4           3         3      2 4
+--R              (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R       -
+--R            ROOT
+--R                                       +-------------------------+
+--R                                       |   2 4         2 2    2 4
+--R                         2 2       2   |- a e  + 2a c d e  - c d          2
+--R                   (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                       |       3 3      2 2 2
+--R                                      \|    64a c  - 16a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                            3 2     2 2            2   2       3
+--R                       ((32a c  - 8a b c)e + (- 16a b c  + 4a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                              +-------------------------+
+--R                                              |   2 4         2 2    2 4
+--R                                2 2       2   |- a e  + 2a c d e  - c d
+--R                          (- 16a c  + 4a b c) |-------------------------
+--R                                              |       3 3      2 2 2
+--R                                             \|    64a c  - 16a b c
+--R                        + 
+--R                               2                   2
+--R                          a b e  - 4a c d e + b c d
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    2 4           3         3      2 4
+--R                 (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R         ROOT
+--R                                    +-------------------------+
+--R                                    |   2 4         2 2    2 4
+--R                      2 2       2   |- a e  + 2a c d e  - c d          2
+--R                (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                    |       3 3      2 2 2
+--R                                   \|    64a c  - 16a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R         log
+--R                           3 2     2 2          2   2       3
+--R                    ((- 32a c  + 8a b c)e + (16a b c  - 4a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                           +-------------------------+
+--R                                           |   2 4         2 2    2 4
+--R                             2 2       2   |- a e  + 2a c d e  - c d          2
+--R                       (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                           |       3 3      2 2 2
+--R                                          \|    64a c  - 16a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 2 4           3         3      2 4
+--R              (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R       -
+--R            ROOT
+--R                                     +-------------------------+
+--R                                     |   2 4         2 2    2 4
+--R                       2 2       2   |- a e  + 2a c d e  - c d          2
+--R                   (16a c  - 4a b c) |-------------------------  + a b e
+--R                                     |       3 3      2 2 2
+--R                                    \|    64a c  - 16a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R            log
+--R                              3 2     2 2          2   2       3
+--R                       ((- 32a c  + 8a b c)e + (16a b c  - 4a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                            +-------------------------+
+--R                                            |   2 4         2 2    2 4
+--R                              2 2       2   |- a e  + 2a c d e  - c d          2
+--R                          (16a c  - 4a b c) |-------------------------  + a b e
+--R                                            |       3 3      2 2 2
+--R                                           \|    64a c  - 16a b c
+--R                        + 
+--R                                            2
+--R                          - 4a c d e + b c d
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    2 4           3         3      2 4
+--R                 (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 637
+
+--S 638 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +--------------------+
+--R              +-----------+     |   +-----------+
+--R          +-+ |          2  +-+ |   |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                  +-------------------------+
+--R                                  |   2 4         2 2    2 4
+--R                    2 2       2   |- a e  + 2a c d e  - c d          2
+--R                (16a c  - 4a b c) |-------------------------  + a b e
+--R                                  |       3 3      2 2 2
+--R                                 \|    64a c  - 16a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                         3 2     2 2            2   2       3
+--R                    ((32a c  - 8a b c)e + (- 16a b c  + 4a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                         +-------------------------+
+--R                                         |   2 4         2 2    2 4
+--R                           2 2       2   |- a e  + 2a c d e  - c d          2
+--R                       (16a c  - 4a b c) |-------------------------  + a b e
+--R                                         |       3 3      2 2 2
+--R                                        \|    64a c  - 16a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 2 4           3         3      2 4
+--R              (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R       -
+--R                                   +--------------------+
+--R                 +-----------+     |   +-----------+
+--R             +-+ |          2  +-+ |   |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                       +-------------------------+
+--R                                       |   2 4         2 2    2 4
+--R                         2 2       2   |- a e  + 2a c d e  - c d          2
+--R                   (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                       |       3 3      2 2 2
+--R                                      \|    64a c  - 16a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                            3 2     2 2            2   2       3
+--R                       ((32a c  - 8a b c)e + (- 16a b c  + 4a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                              +-------------------------+
+--R                                              |   2 4         2 2    2 4
+--R                                2 2       2   |- a e  + 2a c d e  - c d
+--R                          (- 16a c  + 4a b c) |-------------------------
+--R                                              |       3 3      2 2 2
+--R                                             \|    64a c  - 16a b c
+--R                        + 
+--R                               2                   2
+--R                          a b e  - 4a c d e + b c d
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    2 4           3         3      2 4
+--R                 (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R                                +--------------------+
+--R              +-----------+     |   +-----------+
+--R          +-+ |          2  +-+ |   |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                    +-------------------------+
+--R                                    |   2 4         2 2    2 4
+--R                      2 2       2   |- a e  + 2a c d e  - c d          2
+--R                (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                    |       3 3      2 2 2
+--R                                   \|    64a c  - 16a b c
+--R              + 
+--R                                  2
+--R                - 4a c d e + b c d
+--R           /
+--R                2 2       2
+--R              8a c  - 2a b c
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                           3 2     2 2          2   2       3
+--R                    ((- 32a c  + 8a b c)e + (16a b c  - 4a b c)d)
+--R                 *
+--R                     +-------------------------+
+--R                     |   2 4         2 2    2 4
+--R                     |- a e  + 2a c d e  - c d
+--R                     |-------------------------
+--R                     |       3 3      2 2 2
+--R                    \|    64a c  - 16a b c
+--R                + 
+--R                     2       2    2          2    2   3
+--R                  (4a c - a b )d e  + (- 4a c  + b c)d
+--R             *
+--R                ROOT
+--R                                           +-------------------------+
+--R                                           |   2 4         2 2    2 4
+--R                             2 2       2   |- a e  + 2a c d e  - c d          2
+--R                       (- 16a c  + 4a b c) |-------------------------  + a b e
+--R                                           |       3 3      2 2 2
+--R                                          \|    64a c  - 16a b c
+--R                     + 
+--R                                         2
+--R                       - 4a c d e + b c d
+--R                  /
+--R                       2 2       2
+--R                     8a c  - 2a b c
+--R            + 
+--R                 2 4           3         3      2 4
+--R              (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R       -
+--R                                   +--------------------+
+--R                 +-----------+     |   +-----------+
+--R             +-+ |          2  +-+ |   |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                     +-------------------------+
+--R                                     |   2 4         2 2    2 4
+--R                       2 2       2   |- a e  + 2a c d e  - c d          2
+--R                   (16a c  - 4a b c) |-------------------------  + a b e
+--R                                     |       3 3      2 2 2
+--R                                    \|    64a c  - 16a b c
+--R                 + 
+--R                                     2
+--R                   - 4a c d e + b c d
+--R              /
+--R                   2 2       2
+--R                 8a c  - 2a b c
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                              3 2     2 2          2   2       3
+--R                       ((- 32a c  + 8a b c)e + (16a b c  - 4a b c)d)
+--R                    *
+--R                        +-------------------------+
+--R                        |   2 4         2 2    2 4
+--R                        |- a e  + 2a c d e  - c d
+--R                        |-------------------------
+--R                        |       3 3      2 2 2
+--R                       \|    64a c  - 16a b c
+--R                   + 
+--R                          2       2    2        2    2   3
+--R                     (- 4a c + a b )d e  + (4a c  - b c)d
+--R                *
+--R                   ROOT
+--R                                            +-------------------------+
+--R                                            |   2 4         2 2    2 4
+--R                              2 2       2   |- a e  + 2a c d e  - c d          2
+--R                          (16a c  - 4a b c) |-------------------------  + a b e
+--R                                            |       3 3      2 2 2
+--R                                           \|    64a c  - 16a b c
+--R                        + 
+--R                                            2
+--R                          - 4a c d e + b c d
+--R                     /
+--R                          2 2       2
+--R                        8a c  - 2a b c
+--R               + 
+--R                    2 4           3         3      2 4
+--R                 (2a e  - 2a b d e  + 2b c d e - 2c d )x
+--R     + 
+--R                                            +------------------+
+--R               +-----------+                | +-----------+
+--R               |          2                 | |          2
+--R         (- 2e\|- 4a c + b   + 2b e - 4c d)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R               +-----------+                |   +-----------+
+--R               |          2                 |   |          2
+--R         (- 2e\|- 4a c + b   - 2b e + 4c d)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 639
+
+)clear all
+
+--S 640 of 649
+t0:=(d+e*x^4)/(a+b*x^4+c*x^8)
+--R 
+--R
+--R               4
+--R            e x  + d
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 640
+
+--S 641 of 649
+r0:=-1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*c^(1/4)*_
+   x/(-b-sqrt(b^2-4*a*c))^(1/4))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(1/4)*(-b-sqrt(b^2-4*a*c))^(3/4))-1/2*atan(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(1/4)*(-b+sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(1/4)*(-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                          +------------------+3
+--R              +-----------+               | +-----------+
+--R              |          2               4| |          2
+--R         (- e\|- 4a c + b   - b e + 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                          +--------------------+3
+--R              +-----------+               |   +-----------+
+--R              |          2               4|   |          2
+--R         (- e\|- 4a c + b   + b e - 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                          +------------------+3
+--R              +-----------+               | +-----------+
+--R              |          2               4| |          2
+--R         (- e\|- 4a c + b   - b e + 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                          +--------------------+3
+--R              +-----------+               |   +-----------+
+--R              |          2               4|   |          2
+--R         (- e\|- 4a c + b   + b e - 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                             +--------------------+3  +------------------+3
+--R           +-----------+     |   +-----------+        | +-----------+
+--R      4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                5 3        4 2 2       3 4
+--R                          (4096a c  - 2048a b c  + 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                               6 3        5 2 2       4 4
+--R                         (8192a c  - 4096a b c  + 512a b c)e
+--R                       + 
+--R                                 5   3        4 3 2       3 5
+--R                         (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                          4     3 2    4       3 2     2 2   3 2
+--R                     (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                   + 
+--R                           2   2       3   4         2 3       2 2    4   5
+--R                     (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       5 3        4 2 2       3 4
+--R                                 (4096a c  - 2048a b c  + 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               5 3        4 2 2       3 4
+--R                       (- 4096a c  + 2048a b c  - 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                            6 3        5 2 2       4 4
+--R                      (8192a c  - 4096a b c  + 512a b c)e
+--R                    + 
+--R                              5   3        4 3 2       3 5
+--R                      (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                     4     3 2    4         3 2     2 2   3 2
+--R                  (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                + 
+--R                      2   2       3   4       2 3       2 2    4   5
+--R                  (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      5 3        4 2 2       3 4
+--R                              (- 4096a c  + 2048a b c  - 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 3        4 2 2       3 4
+--R                          (- 4096a c  + 2048a b c  - 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                                 6 3        5 2 2       4 4
+--R                         (- 8192a c  + 4096a b c  - 512a b c)e
+--R                       + 
+--R                               5   3        4 3 2       3 5
+--R                         (4096a b c  - 2048a b c  + 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                          4     3 2    4       3 2     2 2   3 2
+--R                     (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                   + 
+--R                           2   2       3   4         2 3       2 2    4   5
+--R                     (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 3        4 2 2       3 4
+--R                                 (- 4096a c  + 2048a b c  - 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 3        4 2 2       3 4
+--R                       (4096a c  - 2048a b c  + 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                              6 3        5 2 2       4 4
+--R                      (- 8192a c  + 4096a b c  - 512a b c)e
+--R                    + 
+--R                            5   3        4 3 2       3 5
+--R                      (4096a b c  - 2048a b c  + 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                     4     3 2    4         3 2     2 2   3 2
+--R                  (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                + 
+--R                      2   2       3   4       2 3       2 2    4   5
+--R                  (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 3        4 2 2       3 4
+--R                              (4096a c  - 2048a b c  + 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R         2
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 3        4 2 2       3 4
+--R                       (4096a c  - 2048a b c  + 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         atan
+--R                            6 3        5 2 2       4 4
+--R                      (8192a c  - 4096a b c  + 512a b c)e
+--R                    + 
+--R                              5   3        4 3 2       3 5
+--R                      (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                       4     3 2    4       3 2     2 2   3 2
+--R                  (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                + 
+--R                        2   2       3   4         2 3       2 2    4   5
+--R                  (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 3        4 2 2       3 4
+--R                              (4096a c  - 2048a b c  + 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R           /
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 3        4 2 2       3 4
+--R                          (- 4096a c  + 2048a b c  - 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            atan
+--R                               6 3        5 2 2       4 4
+--R                         (8192a c  - 4096a b c  + 512a b c)e
+--R                       + 
+--R                                 5   3        4 3 2       3 5
+--R                         (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        4     3 2    4         3 2     2 2   3 2
+--R                     (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                   + 
+--R                         2   2       3   4       2 3       2 2    4   5
+--R                     (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 3        4 2 2       3 4
+--R                                 (- 4096a c  + 2048a b c  - 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R              /
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 642
+
+--S 643 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                   +--------------------+3  +------------------+3
+--R                 +-----------+     |   +-----------+        | +-----------+
+--R            4+-+ |          2 4+-+4|   |          2        4| |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                5 3        4 2 2       3 4
+--R                          (4096a c  - 2048a b c  + 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                               6 3        5 2 2       4 4
+--R                         (8192a c  - 4096a b c  + 512a b c)e
+--R                       + 
+--R                                 5   3        4 3 2       3 5
+--R                         (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                          4     3 2    4       3 2     2 2   3 2
+--R                     (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                   + 
+--R                           2   2       3   4         2 3       2 2    4   5
+--R                     (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                       5 3        4 2 2       3 4
+--R                                 (4096a c  - 2048a b c  + 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                               5 3        4 2 2       3 4
+--R                       (- 4096a c  + 2048a b c  - 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                            6 3        5 2 2       4 4
+--R                      (8192a c  - 4096a b c  + 512a b c)e
+--R                    + 
+--R                              5   3        4 3 2       3 5
+--R                      (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                     4     3 2    4         3 2     2 2   3 2
+--R                  (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                + 
+--R                      2   2       3   4       2 3       2 2    4   5
+--R                  (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                      5 3        4 2 2       3 4
+--R                              (- 4096a c  + 2048a b c  - 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                   +--------------------+3  +------------------+3
+--R                 +-----------+     |   +-----------+        | +-----------+
+--R            4+-+ |          2 4+-+4|   |          2        4| |          2
+--R            \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 3        4 2 2       3 4
+--R                          (- 4096a c  + 2048a b c  - 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            log
+--R                                 6 3        5 2 2       4 4
+--R                         (- 8192a c  + 4096a b c  - 512a b c)e
+--R                       + 
+--R                               5   3        4 3 2       3 5
+--R                         (4096a b c  - 2048a b c  + 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                          4     3 2    4       3 2     2 2   3 2
+--R                     (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                   + 
+--R                           2   2       3   4         2 3       2 2    4   5
+--R                     (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 3        4 2 2       3 4
+--R                                 (- 4096a c  + 2048a b c  - 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R               + 
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 3        4 2 2       3 4
+--R                       (4096a c  - 2048a b c  + 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         log
+--R                              6 3        5 2 2       4 4
+--R                      (- 8192a c  + 4096a b c  - 512a b c)e
+--R                    + 
+--R                            5   3        4 3 2       3 5
+--R                      (4096a b c  - 2048a b c  + 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                     4     3 2    4         3 2     2 2   3 2
+--R                  (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                + 
+--R                      2   2       3   4       2 3       2 2    4   5
+--R                  (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 3        4 2 2       3 4
+--R                              (4096a c  - 2048a b c  + 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R            + 
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R                                 +--------------------+3  +------------------+3
+--R               +-----------+     |   +-----------+        | +-----------+
+--R          4+-+ |          2 4+-+4|   |          2        4| |          2
+--R         2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R      *
+--R         ROOT
+--R              2
+--R           *
+--R              ROOT
+--R                             5 3        4 2 2       3 4
+--R                       (4096a c  - 2048a b c  + 256a b c)
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        3   4     3     3     2     2 2        2 2       2   3
+--R                     - a b e  + 8a c d e  - 6a b c d e  + (- 8a c  + 4a b c)d e
+--R                   + 
+--R                            2    3   4
+--R                     (3a b c  - b c)d
+--R                /
+--R                        5 3        4 2 2       3 4
+--R                   2048a c  - 1024a b c  + 128a b c
+--R      *
+--R         atan
+--R                            6 3        5 2 2       4 4
+--R                      (8192a c  - 4096a b c  + 512a b c)e
+--R                    + 
+--R                              5   3        4 3 2       3 5
+--R                      (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                 *
+--R                    ROOT
+--R                              6 8      5   2 6     4     3 5
+--R                           - a e  + 12a c d e  - 8a b c d e
+--R                         + 
+--R                                 4 2     3 2   4 4      3   2 5 3
+--R                           (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                         + 
+--R                               3 3      2 2 2  6 2        2   3       3 2  7
+--R                           (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                         + 
+--R                               2 4       2 3    4 2  8
+--R                           (- a c  + 2a b c  - b c )d
+--R                      /
+--R                                   9 5           8 2 4          7 4 3
+--R                           4194304a c  - 3145728a b c  + 786432a b c
+--R                         + 
+--R                                   6 6 2
+--R                           - 65536a b c
+--R                + 
+--R                       4     3 2    4       3 2     2 2   3 2
+--R                  (- 4a c + a b )d e  + (24a c  - 6a b c)d e
+--R                + 
+--R                        2   2       3   4         2 3       2 2    4   5
+--R                  (- 16a b c  + 4a b c)d e + (- 4a c  + 5a b c  - b c)d
+--R             *
+--R                ROOT
+--R                     2
+--R                  *
+--R                     ROOT
+--R                                    5 3        4 2 2       3 4
+--R                              (4096a c  - 2048a b c  + 256a b c)
+--R                           *
+--R                              ROOT
+--R                                        6 8      5   2 6     4     3 5
+--R                                     - a e  + 12a c d e  - 8a b c d e
+--R                                   + 
+--R                                           4 2     3 2   4 4      3   2 5 3
+--R                                     (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                   + 
+--R                                         3 3      2 2 2  6 2
+--R                                     (12a c  - 28a b c )d e
+--R                                   + 
+--R                                          2   3       3 2  7
+--R                                     (- 8a b c  + 8a b c )d e
+--R                                   + 
+--R                                         2 4       2 3    4 2  8
+--R                                     (- a c  + 2a b c  - b c )d
+--R                                /
+--R                                             9 5           8 2 4          7 4 3
+--R                                     4194304a c  - 3145728a b c  + 786432a b c
+--R                                   + 
+--R                                             6 6 2
+--R                                     - 65536a b c
+--R                          + 
+--R                               3   4     3     3     2     2 2
+--R                            - a b e  + 8a c d e  - 6a b c d e
+--R                          + 
+--R                                 2 2       2   3           2    3   4
+--R                            (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                       /
+--R                               5 3        4 2 2       3 4
+--R                          2048a c  - 1024a b c  + 128a b c
+--R           /
+--R                   4 6    3     5     3   2 4      2     3 3
+--R                  a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                + 
+--R                       2 2       2   4 2          2    3   5        3    2 2  6
+--R                  (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R             *
+--R                x
+--R     + 
+--R       -
+--R                                    +--------------------+3
+--R                  +-----------+     |   +-----------+
+--R             4+-+ |          2 4+-+4|   |          2
+--R            2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b
+--R         *
+--R             +------------------+3
+--R             | +-----------+
+--R            4| |          2
+--R            \|\|- 4a c + b   - b
+--R         *
+--R            ROOT
+--R                 2
+--R              *
+--R                 ROOT
+--R                                  5 3        4 2 2       3 4
+--R                          (- 4096a c  + 2048a b c  - 256a b c)
+--R                       *
+--R                          ROOT
+--R                                    6 8      5   2 6     4     3 5
+--R                                 - a e  + 12a c d e  - 8a b c d e
+--R                               + 
+--R                                       4 2     3 2   4 4      3   2 5 3
+--R                                 (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                               + 
+--R                                     3 3      2 2 2  6 2
+--R                                 (12a c  - 28a b c )d e
+--R                               + 
+--R                                      2   3       3 2  7
+--R                                 (- 8a b c  + 8a b c )d e
+--R                               + 
+--R                                     2 4       2 3    4 2  8
+--R                                 (- a c  + 2a b c  - b c )d
+--R                            /
+--R                                         9 5           8 2 4          7 4 3
+--R                                 4194304a c  - 3145728a b c  + 786432a b c
+--R                               + 
+--R                                         6 6 2
+--R                                 - 65536a b c
+--R                      + 
+--R                           3   4     3     3     2     2 2
+--R                        - a b e  + 8a c d e  - 6a b c d e
+--R                      + 
+--R                             2 2       2   3           2    3   4
+--R                        (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                   /
+--R                           5 3        4 2 2       3 4
+--R                      2048a c  - 1024a b c  + 128a b c
+--R         *
+--R            atan
+--R                               6 3        5 2 2       4 4
+--R                         (8192a c  - 4096a b c  + 512a b c)e
+--R                       + 
+--R                                 5   3        4 3 2       3 5
+--R                         (- 4096a b c  + 2048a b c  - 256a b c)d
+--R                    *
+--R                       ROOT
+--R                                 6 8      5   2 6     4     3 5
+--R                              - a e  + 12a c d e  - 8a b c d e
+--R                            + 
+--R                                    4 2     3 2   4 4      3   2 5 3
+--R                              (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                            + 
+--R                                  3 3      2 2 2  6 2        2   3       3 2  7
+--R                              (12a c  - 28a b c )d e  + (- 8a b c  + 8a b c )d e
+--R                            + 
+--R                                  2 4       2 3    4 2  8
+--R                              (- a c  + 2a b c  - b c )d
+--R                         /
+--R                                      9 5           8 2 4          7 4 3
+--R                              4194304a c  - 3145728a b c  + 786432a b c
+--R                            + 
+--R                                      6 6 2
+--R                              - 65536a b c
+--R                   + 
+--R                        4     3 2    4         3 2     2 2   3 2
+--R                     (4a c - a b )d e  + (- 24a c  + 6a b c)d e
+--R                   + 
+--R                         2   2       3   4       2 3       2 2    4   5
+--R                     (16a b c  - 4a b c)d e + (4a c  - 5a b c  + b c)d
+--R                *
+--R                   ROOT
+--R                        2
+--R                     *
+--R                        ROOT
+--R                                         5 3        4 2 2       3 4
+--R                                 (- 4096a c  + 2048a b c  - 256a b c)
+--R                              *
+--R                                 ROOT
+--R                                           6 8      5   2 6     4     3 5
+--R                                        - a e  + 12a c d e  - 8a b c d e
+--R                                      + 
+--R                                              4 2     3 2   4 4      3   2 5 3
+--R                                        (- 38a c  + 2a b c)d e  + 48a b c d e
+--R                                      + 
+--R                                            3 3      2 2 2  6 2
+--R                                        (12a c  - 28a b c )d e
+--R                                      + 
+--R                                             2   3       3 2  7
+--R                                        (- 8a b c  + 8a b c )d e
+--R                                      + 
+--R                                            2 4       2 3    4 2  8
+--R                                        (- a c  + 2a b c  - b c )d
+--R                                   /
+--R                                                9 5           8 2 4
+--R                                        4194304a c  - 3145728a b c
+--R                                      + 
+--R                                               7 4 3         6 6 2
+--R                                        786432a b c  - 65536a b c
+--R                             + 
+--R                                  3   4     3     3     2     2 2
+--R                               - a b e  + 8a c d e  - 6a b c d e
+--R                             + 
+--R                                    2 2       2   3           2    3   4
+--R                               (- 8a c  + 4a b c)d e + (3a b c  - b c)d
+--R                          /
+--R                                  5 3        4 2 2       3 4
+--R                             2048a c  - 1024a b c  + 128a b c
+--R              /
+--R                      4 6    3     5     3   2 4      2     3 3
+--R                     a e  - a b d e  - 5a c d e  + 10a b c d e
+--R                   + 
+--R                        2 2       2   4 2          2    3   5        3    2 2  6
+--R                   (- 5a c  - 5a b c)d e  + (3a b c  + b c)d e + (a c  - b c )d
+--R                *
+--R                   x
+--R     + 
+--R                                        +------------------+3
+--R            +-----------+               | +-----------+
+--R            |          2               4| |          2
+--R         (e\|- 4a c + b   + b e - 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+3
+--R            +-----------+               |   +-----------+
+--R            |          2               4|   |          2
+--R         (e\|- 4a c + b   - b e + 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                        +------------------+3
+--R            +-----------+               | +-----------+
+--R            |          2               4| |          2
+--R         (e\|- 4a c + b   + b e - 2c d)\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+3
+--R            +-----------+               |   +-----------+
+--R            |          2               4|   |          2
+--R         (e\|- 4a c + b   - b e + 2c d)\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R  /
+--R                             +--------------------+3  +------------------+3
+--R           +-----------+     |   +-----------+        | +-----------+
+--R      4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 644
+
+)clear all
+
+--S 645 of 649
+t0:=(1+x^3)/(x-x^4+x^7)
+--R 
+--R
+--R            3
+--R           x  + 1
+--R   (1)  -----------
+--R         7    4
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 645
+
+--S 646 of 649
+r0:=log(x)-1/6*log(1-x^3+x^6)-atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                        3      +-+
+--R           +-+     6    3          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 6\|3 log(x) + 6atan(-------------)
+--R                                                           3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   6\|3
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        3      +-+
+--R           +-+     6    3          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 6\|3 log(x) + 6atan(-------------)
+--R                                                           3
+--R   (3)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 647
+
+--S 648 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 649
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich18.input.pamphlet b/src/input/rich18.input.pamphlet
new file mode 100644
index 0000000..77175c7
--- /dev/null
+++ b/src/input/rich18.input.pamphlet
@@ -0,0 +1,104984 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich18.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a x^q+b x^n+c x^(2 n-q))^p|
+There are:
+\begin{itemize}
+\item 255 integrals in this file.
+\item 255 supplied "optimal results".
+\item 307 matching answers.
+\item 0 cases where Axiom answer differs from Rubi
+\item 91 cases where Axiom supplied 2 results.
+\item 12 cases that Axiom failed to integrate.
+\item 31 that contain expressions Axiom does not recognize.
+\end{itemize}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich18.output
+)spool rich18.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1457
+t0:=(A+B*x)*(d+e*x)^m*(b*x+c*x^2)
+--R 
+--R
+--R              3               2                  m
+--R   (1)  (B c x  + (A c + B b)x  + A b x)(e x + d)
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1457
+r0:=-d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^(1+m)/(e^4*(1+m))+(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^(2+m)/(e^4*(2+m))-(3*B*c*d-b*B*e-A*c*e)*_
+     (d+e*x)^(3+m)/(e^4*(3+m))+B*c*(d+e*x)^(4+m)/(e^4*(4+m))
+--R 
+--R
+--R   (2)
+--R             3         2                           m + 4
+--R       (B c m  + 6B c m  + 11B c m + 6B c)(e x + d)
+--R     + 
+--R                                   3                              2
+--R           ((A c + B b)e - 3B c d)m  + ((7A c + 7B b)e - 21B c d)m
+--R         + 
+--R           ((14A c + 14B b)e - 42B c d)m + (8A c + 8B b)e - 24B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                 2                              2  3
+--R           (A b e  + (- 2A c - 2B b)d e + 3B c d )m
+--R         + 
+--R                  2                                 2  2
+--R           (8A b e  + (- 16A c - 16B b)d e + 24B c d )m
+--R         + 
+--R                   2                                 2            2
+--R           (19A b e  + (- 38A c - 38B b)d e + 57B c d )m + 12A b e
+--R         + 
+--R                                         2
+--R           (- 24A c - 24B b)d e + 36B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R                     2               2         3  3
+--R           (- A b d e  + (A c + B b)d e - B c d )m
+--R         + 
+--R                      2                 2          3  2
+--R           (- 9A b d e  + (9A c + 9B b)d e - 9B c d )m
+--R         + 
+--R                       2                   2           3              2
+--R           (- 26A b d e  + (26A c + 26B b)d e - 26B c d )m - 24A b d e
+--R         + 
+--R                           2           3
+--R           (24A c + 24B b)d e - 24B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     e m  + 10e m  + 35e m  + 50e m + 24e
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 3         4 2          4          4  4
+--R         (B c e m  + 6B c e m  + 11B c e m + 6B c e )x
+--R       + 
+--R                          4          3  3                  4           3  2
+--R             ((A c + B b)e  + B c d e )m  + ((7A c + 7B b)e  + 3B c d e )m
+--R           + 
+--R                              4           3                   4
+--R             ((14A c + 14B b)e  + 2B c d e )m + (8A c + 8B b)e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                   4                 3  3
+--R             (A b e  + (A c + B b)d e )m
+--R           + 
+--R                    4                   3         2 2  2
+--R             (8A b e  + (5A c + 5B b)d e  - 3B c d e )m
+--R           + 
+--R                     4                   3         2 2            4
+--R             (19A b e  + (4A c + 4B b)d e  - 3B c d e )m + 12A b e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                    3 3            3                   2 2  2
+--R             A b d e m  + (7A b d e  + (- 2A c - 2B b)d e )m
+--R           + 
+--R                       3                   2 2         3
+--R             (12A b d e  + (- 8A c - 8B b)d e  + 6B c d e)m
+--R        *
+--R           x
+--R       + 
+--R                2 2 2            2 2                 3             2 2
+--R         - A b d e m  + (- 7A b d e  + (2A c + 2B b)d e)m - 12A b d e
+--R       + 
+--R                       3          4
+--R         (8A c + 8B b)d e - 6B c d
+--R    *
+--R         m log(e x + d)
+--R       %e
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     e m  + 10e m  + 35e m  + 50e m + 24e
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 4 3         4 2          4          4  4
+--R           (B c e m  + 6B c e m  + 11B c e m + 6B c e )x
+--R         + 
+--R                            4          3  3                  4           3  2
+--R               ((A c + B b)e  + B c d e )m  + ((7A c + 7B b)e  + 3B c d e )m
+--R             + 
+--R                                4           3                   4
+--R               ((14A c + 14B b)e  + 2B c d e )m + (8A c + 8B b)e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     4                 3  3
+--R               (A b e  + (A c + B b)d e )m
+--R             + 
+--R                      4                   3         2 2  2
+--R               (8A b e  + (5A c + 5B b)d e  - 3B c d e )m
+--R             + 
+--R                       4                   3         2 2            4
+--R               (19A b e  + (4A c + 4B b)d e  - 3B c d e )m + 12A b e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3 3            3                   2 2  2
+--R               A b d e m  + (7A b d e  + (- 2A c - 2B b)d e )m
+--R             + 
+--R                         3                   2 2         3
+--R               (12A b d e  + (- 8A c - 8B b)d e  + 6B c d e)m
+--R          *
+--R             x
+--R         + 
+--R                  2 2 2            2 2                 3             2 2
+--R           - A b d e m  + (- 7A b d e  + (2A c + 2B b)d e)m - 12A b d e
+--R         + 
+--R                         3          4
+--R           (8A c + 8B b)d e - 6B c d
+--R      *
+--R           m log(e x + d)
+--R         %e
+--R     + 
+--R               3         2                           m + 4
+--R       (- B c m  - 6B c m  - 11B c m - 6B c)(e x + d)
+--R     + 
+--R                                     3                                2
+--R           ((- A c - B b)e + 3B c d)m  + ((- 7A c - 7B b)e + 21B c d)m
+--R         + 
+--R           ((- 14A c - 14B b)e + 42B c d)m + (- 8A c - 8B b)e + 24B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                   2                            2  3
+--R           (- A b e  + (2A c + 2B b)d e - 3B c d )m
+--R         + 
+--R                    2                               2  2
+--R           (- 8A b e  + (16A c + 16B b)d e - 24B c d )m
+--R         + 
+--R                     2                               2            2
+--R           (- 19A b e  + (38A c + 38B b)d e - 57B c d )m - 12A b e
+--R         + 
+--R                                       2
+--R           (24A c + 24B b)d e - 36B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R                   2                 2         3  3
+--R           (A b d e  + (- A c - B b)d e + B c d )m
+--R         + 
+--R                    2                   2          3  2
+--R           (9A b d e  + (- 9A c - 9B b)d e + 9B c d )m
+--R         + 
+--R                     2                     2           3              2
+--R           (26A b d e  + (- 26A c - 26B b)d e + 26B c d )m + 24A b d e
+--R         + 
+--R                             2           3
+--R           (- 24A c - 24B b)d e + 24B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     e m  + 10e m  + 35e m  + 50e m + 24e
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 1457
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 1457
+t0:=(A+B*x)*(d+e*x)^5*(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R          5 8                5           4  7
+--R     B c e x  + ((A c + B b)e  + 5B c d e )x
+--R   + 
+--R           5                   4          2 3  6
+--R     (A b e  + (5A c + 5B b)d e  + 10B c d e )x
+--R   + 
+--R              4                   2 3          3 2  5
+--R     (5A b d e  + (10A c + 10B b)d e  + 10B c d e )x
+--R   + 
+--R             2 3                   3 2         4   4
+--R     (10A b d e  + (10A c + 10B b)d e  + 5B c d e)x
+--R   + 
+--R             3 2                 4         5  3          4                5  2
+--R     (10A b d e  + (5A c + 5B b)d e + B c d )x  + (5A b d e + (A c + B b)d )x
+--R   + 
+--R          5
+--R     A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 6
+
+--S 7 of 1457
+r0:=-1/6*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^6/e^4+1/7*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^7/e^4-1/8*(3*B*c*d-b*B*e-A*c*e)*(d+e*x)^8/e^4+_
+     1/9*B*c*(d+e*x)^9/e^4
+--R 
+--R
+--R   (2)
+--R       1      9 9     1       1      9   5        8  8
+--R       - B c e x  + ((- A c + - B b)e  + - B c d e )x
+--R       9              8       8          8
+--R     + 
+--R        1      9    5       5        8   10      2 7  7
+--R       (- A b e  + (- A c + - B b)d e  + -- B c d e )x
+--R        7           7       7             7
+--R     + 
+--R        5        8    5       5      2 7   5      3 6  6
+--R       (- A b d e  + (- A c + - B b)d e  + - B c d e )x
+--R        6             3       3            3
+--R     + 
+--R              2 7                 3 6        4 5  5
+--R       (2A b d e  + (2A c + 2B b)d e  + B c d e )x
+--R     + 
+--R        5      3 6    5       5      4 5   1      5 4  4
+--R       (- A b d e  + (- A c + - B b)d e  + - B c d e )x
+--R        2             4       4            4
+--R     + 
+--R        5      4 5    1       1      5 4  3   1      5 4 2    1      7 2
+--R       (- A b d e  + (- A c + - B b)d e )x  + - A b d e x  - -- A b d e
+--R        3             3       3               2              42
+--R     + 
+--R         1         1       8     1       9
+--R       (--- A c + --- B b)d e - --- B c d
+--R        168       168           504
+--R  /
+--R      4
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 7
+
+--S 8 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1      5 9     1       1      5   5        4  8
+--R     - B c e x  + ((- A c + - B b)e  + - B c d e )x
+--R     9              8       8          8
+--R   + 
+--R      1      5    5       5        4   10      2 3  7
+--R     (- A b e  + (- A c + - B b)d e  + -- B c d e )x
+--R      7           7       7             7
+--R   + 
+--R      5        4    5       5      2 3   5      3 2  6
+--R     (- A b d e  + (- A c + - B b)d e  + - B c d e )x
+--R      6             3       3            3
+--R   + 
+--R            2 3                 3 2        4   5
+--R     (2A b d e  + (2A c + 2B b)d e  + B c d e)x
+--R   + 
+--R      5      3 2    5       5      4    1      5  4
+--R     (- A b d e  + (- A c + - B b)d e + - B c d )x
+--R      2             4       4           4
+--R   + 
+--R      5      4     1       1      5  3   1      5 2
+--R     (- A b d e + (- A c + - B b)d )x  + - A b d x
+--R      3            3       3             2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 8
+
+--S 9 of 1457
+m0:=a0-r0
+--R 
+--R
+--R         1      7 2       1         1       8     1       9
+--R        -- A b d e  + (- --- A c - --- B b)d e + --- B c d
+--R        42               168       168           504
+--R   (4)  ---------------------------------------------------
+--R                                  4
+--R                                 e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 9
+
+--S 10 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 10
+
+)clear all
+
+--S 11 of 1457
+t0:=(A+B*x)*(d+e*x)^4*(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R          4 7                4           3  6
+--R     B c e x  + ((A c + B b)e  + 4B c d e )x
+--R   + 
+--R           4                   3         2 2  5
+--R     (A b e  + (4A c + 4B b)d e  + 6B c d e )x
+--R   + 
+--R              3                 2 2         3   4
+--R     (4A b d e  + (6A c + 6B b)d e  + 4B c d e)x
+--R   + 
+--R            2 2                 3         4  3          3                4  2
+--R     (6A b d e  + (4A c + 4B b)d e + B c d )x  + (4A b d e + (A c + B b)d )x
+--R   + 
+--R          4
+--R     A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 11
+
+--S 12 of 1457
+r0:=-1/5*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^5/e^4+1/6*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^6/e^4-1/7*(3*B*c*d-b*B*e-A*c*e)*(d+e*x)^7/e^4+_
+     1/8*B*c*(d+e*x)^8/e^4
+--R 
+--R
+--R   (2)
+--R       1      8 8     1       1      8   4        7  7
+--R       - B c e x  + ((- A c + - B b)e  + - B c d e )x
+--R       8              7       7          7
+--R     + 
+--R        1      8    2       2        7        2 6  6
+--R       (- A b e  + (- A c + - B b)d e  + B c d e )x
+--R        6           3       3
+--R     + 
+--R        4        7    6       6      2 6   4      3 5  5
+--R       (- A b d e  + (- A c + - B b)d e  + - B c d e )x
+--R        5             5       5            5
+--R     + 
+--R        3      2 6               3 5   1      4 4  4
+--R       (- A b d e  + (A c + B b)d e  + - B c d e )x
+--R        2                              4
+--R     + 
+--R        4      3 5    1       1      4 4  3   1      4 4 2    1      6 2
+--R       (- A b d e  + (- A c + - B b)d e )x  + - A b d e x  - -- A b d e
+--R        3             3       3               2              30
+--R     + 
+--R         1         1       7     1       8
+--R       (--- A c + --- B b)d e - --- B c d
+--R        105       105           280
+--R  /
+--R      4
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 12
+
+--S 13 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1      4 8     1       1      4   4        3  7
+--R     - B c e x  + ((- A c + - B b)e  + - B c d e )x
+--R     8              7       7          7
+--R   + 
+--R      1      4    2       2        3        2 2  6
+--R     (- A b e  + (- A c + - B b)d e  + B c d e )x
+--R      6           3       3
+--R   + 
+--R      4        3    6       6      2 2   4      3   5
+--R     (- A b d e  + (- A c + - B b)d e  + - B c d e)x
+--R      5             5       5            5
+--R   + 
+--R      3      2 2               3    1      4  4
+--R     (- A b d e  + (A c + B b)d e + - B c d )x
+--R      2                             4
+--R   + 
+--R      4      3     1       1      4  3   1      4 2
+--R     (- A b d e + (- A c + - B b)d )x  + - A b d x
+--R      3            3       3             2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 13
+
+--S 14 of 1457
+m0:=a0-r0
+--R 
+--R
+--R         1      6 2       1         1       7     1       8
+--R        -- A b d e  + (- --- A c - --- B b)d e + --- B c d
+--R        30               105       105           280
+--R   (4)  ---------------------------------------------------
+--R                                  4
+--R                                 e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 14
+
+--S 15 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 15
+
+)clear all
+
+--S 16 of 1457
+t0:=(A+B*x)*(d+e*x)^3*(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R          3 6                3           2  5
+--R     B c e x  + ((A c + B b)e  + 3B c d e )x
+--R   + 
+--R           3                   2         2   4
+--R     (A b e  + (3A c + 3B b)d e  + 3B c d e)x
+--R   + 
+--R              2                 2         3  3          2                3  2
+--R     (3A b d e  + (3A c + 3B b)d e + B c d )x  + (3A b d e + (A c + B b)d )x
+--R   + 
+--R          3
+--R     A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 16
+
+--S 17 of 1457
+r0:=-1/4*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^4/e^4+1/5*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^5/e^4-1/6*(3*B*c*d-b*B*e-A*c*e)*(d+e*x)^6/e^4+_
+     1/7*B*c*(d+e*x)^7/e^4
+--R 
+--R
+--R   (2)
+--R       1      7 7     1       1      7   1        6  6
+--R       - B c e x  + ((- A c + - B b)e  + - B c d e )x
+--R       7              6       6          2
+--R     + 
+--R        1      7    3       3        6   3      2 5  5
+--R       (- A b e  + (- A c + - B b)d e  + - B c d e )x
+--R        5           5       5            5
+--R     + 
+--R        3        6    3       3      2 5   1      3 4  4
+--R       (- A b d e  + (- A c + - B b)d e  + - B c d e )x
+--R        4             4       4            4
+--R     + 
+--R             2 5    1       1      3 4  3   1      3 4 2    1      5 2
+--R       (A b d e  + (- A c + - B b)d e )x  + - A b d e x  - -- A b d e
+--R                    3       3               2              20
+--R     + 
+--R         1        1      6     1       7
+--R       (-- A c + -- B b)d e - --- B c d
+--R        60       60           140
+--R  /
+--R      4
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 17
+
+--S 18 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1      3 7     1       1      3   1        2  6
+--R     - B c e x  + ((- A c + - B b)e  + - B c d e )x
+--R     7              6       6          2
+--R   + 
+--R      1      3    3       3        2   3      2   5
+--R     (- A b e  + (- A c + - B b)d e  + - B c d e)x
+--R      5           5       5            5
+--R   + 
+--R      3        2    3       3      2    1      3  4
+--R     (- A b d e  + (- A c + - B b)d e + - B c d )x
+--R      4             4       4           4
+--R   + 
+--R           2     1       1      3  3   1      3 2
+--R     (A b d e + (- A c + - B b)d )x  + - A b d x
+--R                 3       3             2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 18
+
+--S 19 of 1457
+m0:=a0-r0
+--R 
+--R
+--R         1      5 2       1        1      6     1       7
+--R        -- A b d e  + (- -- A c - -- B b)d e + --- B c d
+--R        20               60       60           140
+--R   (4)  -------------------------------------------------
+--R                                 4
+--R                                e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 19
+
+--S 20 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 20
+
+)clear all
+
+--S 21 of 1457
+t0:=(A+B*x)*(d+e*x)^2*(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R          2 5                2             4
+--R     B c e x  + ((A c + B b)e  + 2B c d e)x
+--R   + 
+--R           2                           2  3                           2  2
+--R     (A b e  + (2A c + 2B b)d e + B c d )x  + (2A b d e + (A c + B b)d )x
+--R   + 
+--R          2
+--R     A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 21
+
+--S 22 of 1457
+r0:=1/2*A*b*d^2*x^2+1/3*d*(b*B*d+A*c*d+2*A*b*e)*x^3+1/4*(A*e*(2*c*d+b*e)+_
+     B*d*(c*d+2*b*e))*x^4+1/5*e*(2*B*c*d+b*B*e+A*c*e)*x^5+1/6*B*c*e^2*x^6
+--R 
+--R
+--R   (2)
+--R     1      2 6     1       1      2   2          5
+--R     - B c e x  + ((- A c + - B b)e  + - B c d e)x
+--R     6              5       5          5
+--R   + 
+--R      1      2    1       1           1      2  4
+--R     (- A b e  + (- A c + - B b)d e + - B c d )x
+--R      4           2       2           4
+--R   + 
+--R      2            1       1      2  3   1      2 2
+--R     (- A b d e + (- A c + - B b)d )x  + - A b d x
+--R      3            3       3             2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 22
+
+--S 23 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1      2 6     1       1      2   2          5
+--R     - B c e x  + ((- A c + - B b)e  + - B c d e)x
+--R     6              5       5          5
+--R   + 
+--R      1      2    1       1           1      2  4
+--R     (- A b e  + (- A c + - B b)d e + - B c d )x
+--R      4           2       2           4
+--R   + 
+--R      2            1       1      2  3   1      2 2
+--R     (- A b d e + (- A c + - B b)d )x  + - A b d x
+--R      3            3       3             2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 23
+
+--S 24 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 24
+
+--S 25 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 25
+
+)clear all
+
+--S 26 of 1457
+t0:=(A+B*x)*(d+e*x)*(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R          4                          3                          2
+--R   B c e x  + ((A c + B b)e + B c d)x  + (A b e + (A c + B b)d)x  + A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 26
+
+--S 27 of 1457
+r0:=1/2*A*b*d*x^2+1/3*(b*B*d+A*c*d+A*b*e)*x^3+1/4*(B*c*d+b*B*e+A*c*e)*x^4+_
+     1/5*B*c*e*x^5
+--R 
+--R
+--R   (2)
+--R     1        5     1       1         1        4
+--R     - B c e x  + ((- A c + - B b)e + - B c d)x
+--R     5              4       4         4
+--R   + 
+--R      1          1       1        3   1        2
+--R     (- A b e + (- A c + - B b)d)x  + - A b d x
+--R      3          3       3            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 27
+
+--S 28 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1        5     1       1         1        4
+--R     - B c e x  + ((- A c + - B b)e + - B c d)x
+--R     5              4       4         4
+--R   + 
+--R      1          1       1        3   1        2
+--R     (- A b e + (- A c + - B b)d)x  + - A b d x
+--R      3          3       3            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 28
+
+--S 29 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 29
+
+--S 30 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 30
+
+)clear all
+
+--S 31 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)
+--R 
+--R
+--R             3               2
+--R   (1)  B c x  + (A c + B b)x  + A b x
+--R                                                    Type: Polynomial(Integer)
+--E 31
+
+--S 32 of 1457
+r0:=1/2*A*b*x^2+1/3*(b*B+A*c)*x^3+1/4*B*c*x^4
+--R 
+--R
+--R        1      4    1       1      3   1      2
+--R   (2)  - B c x  + (- A c + - B b)x  + - A b x
+--R        4           3       3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 32
+
+--S 33 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1      4    1       1      3   1      2
+--R   (3)  - B c x  + (- A c + - B b)x  + - A b x
+--R        4           3       3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 33
+
+--S 34 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 34
+
+--S 35 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 35
+
+)clear all
+
+--S 36 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)
+--R 
+--R
+--R             3               2
+--R        B c x  + (A c + B b)x  + A b x
+--R   (1)  ------------------------------
+--R                    e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 36
+
+--S 37 of 1457
+r0:=(B*d-A*e)*(c*d-b*e)*x/e^3-1/2*(B*c*d-b*B*e-A*c*e)*x^2/e^2+_
+     1/3*B*c*x^3/e-d*(B*d-A*e)*(c*d-b*e)*log(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R                  2                 2          3                      3 3
+--R       (- 6A b d e  + (6A c + 6B b)d e - 6B c d )log(e x + d) + 2B c e x
+--R     + 
+--R                      3           2  2
+--R       ((3A c + 3B b)e  - 3B c d e )x
+--R     + 
+--R              3                     2         2
+--R       (6A b e  + (- 6A c - 6B b)d e  + 6B c d e)x
+--R  /
+--R       4
+--R     6e
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2                 2          3                      3 3
+--R       (- 6A b d e  + (6A c + 6B b)d e - 6B c d )log(e x + d) + 2B c e x
+--R     + 
+--R                      3           2  2
+--R       ((3A c + 3B b)e  - 3B c d e )x
+--R     + 
+--R              3                     2         2
+--R       (6A b e  + (- 6A c - 6B b)d e  + 6B c d e)x
+--R  /
+--R       4
+--R     6e
+--R                                         Type: Union(Expression(Integer),...)
+--E 38
+
+--S 39 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 40
+
+)clear all
+
+--S 41 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^2
+--R 
+--R
+--R             3               2
+--R        B c x  + (A c + B b)x  + A b x
+--R   (1)  ------------------------------
+--R               2 2             2
+--R              e x  + 2d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 41
+
+--S 42 of 1457
+r0:=-(2*B*c*d-b*B*e-A*c*e)*x/e^3+1/2*B*c*x^2/e^2+d*(B*d-A*e)*_
+     (c*d-b*e)/(e^4*(d+e*x))+(B*d*(3*c*d-2*b*e)-A*e*(2*c*d-b*e))*log(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R                  3                     2         2              2
+--R           (2A b e  + (- 4A c - 4B b)d e  + 6B c d e)x + 2A b d e
+--R         + 
+--R                           2          3
+--R           (- 4A c - 4B b)d e + 6B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 3                  3           2  2
+--R       B c e x  + ((2A c + 2B b)e  - 3B c d e )x
+--R     + 
+--R                      2         2              2                   2          3
+--R     ((2A c + 2B b)d e  - 4B c d e)x + 2A b d e  + (- 2A c - 2B b)d e + 2B c d
+--R  /
+--R       5        4
+--R     2e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  3                     2         2              2
+--R           (2A b e  + (- 4A c - 4B b)d e  + 6B c d e)x + 2A b d e
+--R         + 
+--R                           2          3
+--R           (- 4A c - 4B b)d e + 6B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 3                  3           2  2
+--R       B c e x  + ((2A c + 2B b)e  - 3B c d e )x
+--R     + 
+--R                      2         2              2                   2          3
+--R     ((2A c + 2B b)d e  - 4B c d e)x + 2A b d e  + (- 2A c - 2B b)d e + 2B c d
+--R  /
+--R       5        4
+--R     2e x + 2d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 43
+
+--S 44 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^3
+--R 
+--R
+--R             3               2
+--R        B c x  + (A c + B b)x  + A b x
+--R   (1)  ------------------------------
+--R          3 3       2 2     2       3
+--R         e x  + 3d e x  + 3d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 46
+
+--S 47 of 1457
+r0:=B*c*x/e^3+1/2*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^2)+(-B*d*(3*c*d-_
+     2*b*e)+A*e*(2*c*d-b*e))/(e^4*(d+e*x))-(3*B*c*d-b*B*e-A*c*e)*log(d+_
+     e*x)/e^4
+--R 
+--R
+--R   (2)
+--R                          3           2  2                    2          2
+--R           ((2A c + 2B b)e  - 6B c d e )x  + ((4A c + 4B b)d e  - 12B c d e)x
+--R         + 
+--R                         2          3
+--R           (2A c + 2B b)d e - 6B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R             3 3           2 2            3                   2         2
+--R       2B c e x  + 4B c d e x  + (- 2A b e  + (4A c + 4B b)d e  - 4B c d e)x
+--R     + 
+--R                2                 2          3
+--R       - A b d e  + (3A c + 3B b)d e - 5B c d
+--R  /
+--R       6 2       5      2 4
+--R     2e x  + 4d e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          3           2  2                    2          2
+--R           ((2A c + 2B b)e  - 6B c d e )x  + ((4A c + 4B b)d e  - 12B c d e)x
+--R         + 
+--R                         2          3
+--R           (2A c + 2B b)d e - 6B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R             3 3           2 2            3                   2         2
+--R       2B c e x  + 4B c d e x  + (- 2A b e  + (4A c + 4B b)d e  - 4B c d e)x
+--R     + 
+--R                2                 2          3
+--R       - A b d e  + (3A c + 3B b)d e - 5B c d
+--R  /
+--R       6 2       5      2 4
+--R     2e x  + 4d e x + 2d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^4
+--R 
+--R
+--R                 3               2
+--R            B c x  + (A c + B b)x  + A b x
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 51
+
+--S 52 of 1457
+r0:=1/3*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^3)+1/2*(-B*d*(3*c*d-2*b*e)+_
+     A*e*(2*c*d-b*e))/(e^4*(d+e*x)^2)+(3*B*c*d-b*B*e-A*c*e)/(e^4*(d+e*x))+_
+     B*c*log(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R              3 3            2 2          2            3
+--R       (6B c e x  + 18B c d e x  + 18B c d e x + 6B c d )log(e x + d)
+--R     + 
+--R                        3            2  2
+--R       ((- 6A c - 6B b)e  + 18B c d e )x
+--R     + 
+--R                3                     2          2             2
+--R       (- 3A b e  + (- 6A c - 6B b)d e  + 27B c d e)x - A b d e
+--R     + 
+--R                       2           3
+--R       (- 2A c - 2B b)d e + 11B c d
+--R  /
+--R       7 3        6 2      2 5      3 4
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 3            2 2          2            3
+--R       (6B c e x  + 18B c d e x  + 18B c d e x + 6B c d )log(e x + d)
+--R     + 
+--R                        3            2  2
+--R       ((- 6A c - 6B b)e  + 18B c d e )x
+--R     + 
+--R                3                     2          2             2
+--R       (- 3A b e  + (- 6A c - 6B b)d e  + 27B c d e)x - A b d e
+--R     + 
+--R                       2           3
+--R       (- 2A c - 2B b)d e + 11B c d
+--R  /
+--R       7 3        6 2      2 5      3 4
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 53
+
+--S 54 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 55
+
+)clear all
+
+--S 56 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^5
+--R 
+--R
+--R                       3               2
+--R                  B c x  + (A c + B b)x  + A b x
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 56
+
+--S 57 of 1457
+r0:=1/4*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^4)+1/3*(-B*d*(3*c*d-2*b*e)+_
+     A*e*(2*c*d-b*e))/(e^4*(d+e*x)^3)+1/2*(3*B*c*d-b*B*e-A*c*e)/(e^4*_
+     (d+e*x)^2)-B*c/(e^4*(d+e*x))
+--R 
+--R
+--R   (2)
+--R              3 3       1       1      3   3        2  2
+--R       - B c e x  + ((- - A c - - B b)e  - - B c d e )x
+--R                        2       2          2
+--R     + 
+--R          1      3      1       1        2        2       1        2
+--R       (- - A b e  + (- - A c - - B b)d e  - B c d e)x - -- A b d e
+--R          3             3       3                        12
+--R     + 
+--R           1        1      2    1      3
+--R       (- -- A c - -- B b)d e - - B c d
+--R          12       12           4
+--R  /
+--R      8 4       7 3     2 6 2     3 5     4 4
+--R     e x  + 4d e x  + 6d e x  + 4d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 57
+
+--S 58 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 3                    3            2  2
+--R       - 12B c e x  + ((- 6A c - 6B b)e  - 18B c d e )x
+--R     + 
+--R                3                     2          2             2
+--R       (- 4A b e  + (- 4A c - 4B b)d e  - 12B c d e)x - A b d e
+--R     + 
+--R                     2          3
+--R       (- A c - B b)d e - 3B c d
+--R  /
+--R        8 4        7 3      2 6 2      3 5       4 4
+--R     12e x  + 48d e x  + 72d e x  + 48d e x + 12d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 58
+
+--S 59 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^6
+--R 
+--R
+--R                             3               2
+--R                        B c x  + (A c + B b)x  + A b x
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 61
+
+--S 62 of 1457
+r0:=1/5*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^5)+1/4*(-B*d*(3*c*d-2*b*e)+_
+     A*e*(2*c*d-b*e))/(e^4*(d+e*x)^4)+1/3*(3*B*c*d-b*B*e-A*c*e)/(e^4*_
+     (d+e*x)^3)-1/2*B*c/(e^4*(d+e*x)^2)
+--R 
+--R
+--R   (2)
+--R         1      3 3       1       1      3   1        2  2
+--R       - - B c e x  + ((- - A c - - B b)e  - - B c d e )x
+--R         2                3       3          2
+--R     + 
+--R          1      3      1       1        2   1      2       1        2
+--R       (- - A b e  + (- - A c - - B b)d e  - - B c d e)x - -- A b d e
+--R          4             6       6            4             20
+--R     + 
+--R           1        1      2     1      3
+--R       (- -- A c - -- B b)d e - -- B c d
+--R          30       30           20
+--R  /
+--R      9 5       8 4      2 7 3      3 6 2     4 5     5 4
+--R     e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 62
+
+--S 63 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 3                      3            2  2
+--R       - 30B c e x  + ((- 20A c - 20B b)e  - 30B c d e )x
+--R     + 
+--R                 3                       2          2              2
+--R       (- 15A b e  + (- 10A c - 10B b)d e  - 15B c d e)x - 3A b d e
+--R     + 
+--R                       2          3
+--R       (- 2A c - 2B b)d e - 3B c d
+--R  /
+--R        9 5         8 4       2 7 3       3 6 2       4 5       5 4
+--R     60e x  + 300d e x  + 600d e x  + 600d e x  + 300d e x + 60d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 63
+
+--S 64 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 65
+
+)clear all
+
+--S 66 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^7
+--R 
+--R
+--R   (1)
+--R                             3               2
+--R                        B c x  + (A c + B b)x  + A b x
+--R   ------------------------------------------------------------------------
+--R    7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R   e x  + 7d e x  + 21d e x  + 35d e x  + 35d e x  + 21d e x  + 7d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 66
+
+--S 67 of 1457
+r0:=1/6*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^6)+1/5*(-B*d*(3*c*d-2*b*e)+_
+     A*e*(2*c*d-b*e))/(e^4*(d+e*x)^5)+1/4*(3*B*c*d-b*B*e-A*c*e)/(e^4*_
+     (d+e*x)^4)-1/3*B*c/(e^4*(d+e*x)^3)
+--R 
+--R
+--R   (2)
+--R         1      3 3       1       1      3   1        2  2
+--R       - - B c e x  + ((- - A c - - B b)e  - - B c d e )x
+--R         3                4       4          4
+--R     + 
+--R          1      3       1        1        2    1      2       1        2
+--R       (- - A b e  + (- -- A c - -- B b)d e  - -- B c d e)x - -- A b d e
+--R          5             10       10            10             30
+--R     + 
+--R           1        1      2     1      3
+--R       (- -- A c - -- B b)d e - -- B c d
+--R          60       60           60
+--R  /
+--R      10 6       9 5      2 8 4      3 7 3      4 6 2     5 5     6 4
+--R     e  x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 67
+
+--S 68 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 3                      3            2  2
+--R       - 20B c e x  + ((- 15A c - 15B b)e  - 15B c d e )x
+--R     + 
+--R                 3                     2         2              2
+--R       (- 12A b e  + (- 6A c - 6B b)d e  - 6B c d e)x - 2A b d e
+--R     + 
+--R                     2         3
+--R       (- A c - B b)d e - B c d
+--R  /
+--R          10 6         9 5       2 8 4        3 7 3       4 6 2       5 5
+--R       60e  x  + 360d e x  + 900d e x  + 1200d e x  + 900d e x  + 360d e x
+--R     + 
+--R          6 4
+--R       60d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 68
+
+--S 69 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 70
+
+)clear all
+
+--S 71 of 1457
+t0:=(A+B*x)*(d+e*x)^m*(b*x+c*x^2)^2
+--R 
+--R
+--R            2 5       2           4                2  3      2 2          m
+--R   (1)  (B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )(e x + d)
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1457
+r0:=-d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^(1+m)/(e^6*(1+m))+d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(2+m)/(e^6*(2+m))+_
+     (A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*(d+e*x)^(3+m)/(e^6*(3+m))-(2*A*c*e*(2*c*d-b*e)-_
+     B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*(d+e*x)^(4+m)/(e^6*(4+m))-_
+     c*(5*B*c*d-2*b*B*e-A*c*e)*(d+e*x)^(5+m)/(e^6*(5+m))+B*c^2*_
+     (d+e*x)^(6+m)/(e^6*(6+m))
+--R 
+--R
+--R   (2)
+--R             2 5        2 4        2 3         2 2         2          2
+--R         (B c m  + 15B c m  + 85B c m  + 225B c m  + 274B c m + 120B c )
+--R      *
+--R                  m + 6
+--R         (e x + d)
+--R     + 
+--R                2                  2   5          2                    2   4
+--R           ((A c  + 2B b c)e - 5B c d)m  + ((16A c  + 32B b c)e - 80B c d)m
+--R         + 
+--R                  2                      2   3
+--R           ((95A c  + 190B b c)e - 475B c d)m
+--R         + 
+--R                   2                       2   2
+--R           ((260A c  + 520B b c)e - 1300B c d)m
+--R         + 
+--R                 2                       2             2                      2
+--R         ((324A c  + 648B b c)e - 1620B c d)m + (144A c  + 288B b c)e - 720B c d
+--R      *
+--R                  m + 5
+--R         (e x + d)
+--R     + 
+--R                         2  2          2                     2 2  5
+--R           ((2A b c + B b )e  + (- 4A c  - 8B b c)d e + 10B c d )m
+--R         + 
+--R                            2  2           2                        2 2  4
+--R           ((34A b c + 17B b )e  + (- 68A c  - 136B b c)d e + 170B c d )m
+--R         + 
+--R                              2  2            2                         2 2  3
+--R           ((214A b c + 107B b )e  + (- 428A c  - 856B b c)d e + 1070B c d )m
+--R         + 
+--R                              2  2             2                          2 2  2
+--R           ((614A b c + 307B b )e  + (- 1228A c  - 2456B b c)d e + 3070B c d )m
+--R         + 
+--R                              2  2             2                          2 2
+--R           ((792A b c + 396B b )e  + (- 1584A c  - 3168B b c)d e + 3960B c d )m
+--R         + 
+--R                             2  2            2                          2 2
+--R           (360A b c + 180B b )e  + (- 720A c  - 1440B b c)d e + 1800B c d
+--R      *
+--R                  m + 4
+--R         (e x + d)
+--R     + 
+--R               2 3                   2    2        2            2         2 3  5
+--R           (A b e  + (- 6A b c - 3B b )d e  + (6A c  + 12B b c)d e - 10B c d )m
+--R         + 
+--R                    2 3                      2    2          2             2
+--R               18A b e  + (- 108A b c - 54B b )d e  + (108A c  + 216B b c)d e
+--R             + 
+--R                       2 3
+--R               - 180B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                     2 3                       2    2          2              2
+--R               121A b e  + (- 726A b c - 363B b )d e  + (726A c  + 1452B b c)d e
+--R             + 
+--R                        2 3
+--R               - 1210B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                     2 3                         2    2
+--R               372A b e  + (- 2232A b c - 1116B b )d e
+--R             + 
+--R                       2              2           2 3
+--R               (2232A c  + 4464B b c)d e - 3720B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                     2 3                         2    2
+--R               508A b e  + (- 3048A b c - 1524B b )d e
+--R             + 
+--R                       2              2           2 3
+--R               (3048A c  + 6096B b c)d e - 5080B c d
+--R          *
+--R             m
+--R         + 
+--R                 2 3                        2    2           2              2
+--R           240A b e  + (- 1440A b c - 720B b )d e  + (1440A c  + 2880B b c)d e
+--R         + 
+--R                    2 3
+--R           - 2400B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                     2   3                 2  2 2          2           3
+--R               - 2A b d e  + (6A b c + 3B b )d e  + (- 4A c  - 8B b c)d e
+--R             + 
+--R                   2 4
+--R               5B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                      2   3                    2  2 2           2             3
+--R               - 38A b d e  + (114A b c + 57B b )d e  + (- 76A c  - 152B b c)d e
+--R             + 
+--R                    2 4
+--R               95B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       2   3                     2  2 2
+--R               - 274A b d e  + (822A b c + 411B b )d e
+--R             + 
+--R                        2              3          2 4
+--R               (- 548A c  - 1096B b c)d e + 685B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       2   3                       2  2 2
+--R               - 922A b d e  + (2766A b c + 1383B b )d e
+--R             + 
+--R                         2              3           2 4
+--R               (- 1844A c  - 3688B b c)d e + 2305B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                        2   3                       2  2 2
+--R               - 1404A b d e  + (4212A b c + 2106B b )d e
+--R             + 
+--R                         2              3           2 4
+--R               (- 2808A c  - 5616B b c)d e + 3510B c d
+--R          *
+--R             m
+--R         + 
+--R                   2   3                       2  2 2
+--R           - 720A b d e  + (2160A b c + 1080B b )d e
+--R         + 
+--R                     2              3           2 4
+--R           (- 1440A c  - 2880B b c)d e + 1800B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R               2 2 3                  2  3 2       2           4       2 5  5
+--R           (A b d e  + (- 2A b c - B b )d e  + (A c  + 2B b c)d e - B c d )m
+--R         + 
+--R                    2 2 3                     2  3 2         2            4
+--R               20A b d e  + (- 40A b c - 20B b )d e  + (20A c  + 40B b c)d e
+--R             + 
+--R                      2 5
+--R               - 20B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                     2 2 3                       2  3 2
+--R               155A b d e  + (- 310A b c - 155B b )d e
+--R             + 
+--R                      2             4          2 5
+--R               (155A c  + 310B b c)d e - 155B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                     2 2 3                        2  3 2
+--R               580A b d e  + (- 1160A b c - 580B b )d e
+--R             + 
+--R                      2              4          2 5
+--R               (580A c  + 1160B b c)d e - 580B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                      2 2 3                         2  3 2
+--R               1044A b d e  + (- 2088A b c - 1044B b )d e
+--R             + 
+--R                       2              4           2 5
+--R               (1044A c  + 2088B b c)d e - 1044B c d
+--R          *
+--R             m
+--R         + 
+--R                 2 2 3                        2  3 2          2              4
+--R           720A b d e  + (- 1440A b c - 720B b )d e  + (720A c  + 1440B b c)d e
+--R         + 
+--R                   2 5
+--R           - 720B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     e m  + 21e m  + 175e m  + 735e m  + 1624e m  + 1764e m + 720e
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 6 5        2 6 4        2 6 3         2 6 2         2 6
+--R             B c e m  + 15B c e m  + 85B c e m  + 225B c e m  + 274B c e m
+--R           + 
+--R                   2 6
+--R             120B c e
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                  2           6      2   5  5
+--R             ((A c  + 2B b c)e  + B c d e )m
+--R           + 
+--R                    2            6        2   5  4
+--R             ((16A c  + 32B b c)e  + 10B c d e )m
+--R           + 
+--R                    2             6        2   5  3
+--R             ((95A c  + 190B b c)e  + 35B c d e )m
+--R           + 
+--R                     2             6        2   5  2
+--R             ((260A c  + 520B b c)e  + 50B c d e )m
+--R           + 
+--R                     2             6        2   5            2             6
+--R             ((324A c  + 648B b c)e  + 24B c d e )m + (144A c  + 288B b c)e
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                           2  6       2             5  5
+--R             ((2A b c + B b )e  + (A c  + 2B b c)d e )m
+--R           + 
+--R                              2  6         2              5       2 2 4  4
+--R             ((34A b c + 17B b )e  + (12A c  + 24B b c)d e  - 5B c d e )m
+--R           + 
+--R                                2  6         2              5        2 2 4  3
+--R             ((214A b c + 107B b )e  + (47A c  + 94B b c)d e  - 30B c d e )m
+--R           + 
+--R                                2  6         2               5        2 2 4  2
+--R             ((614A b c + 307B b )e  + (72A c  + 144B b c)d e  - 55B c d e )m
+--R           + 
+--R                                2  6         2              5        2 2 4
+--R             ((792A b c + 396B b )e  + (36A c  + 72B b c)d e  - 30B c d e )m
+--R           + 
+--R                               2  6
+--R             (360A b c + 180B b )e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                 2 6                2    5  5
+--R             (A b e  + (2A b c + B b )d e )m
+--R           + 
+--R                   2 6                   2    5          2           2 4  4
+--R             (18A b e  + (28A b c + 14B b )d e  + (- 4A c  - 8B b c)d e )m
+--R           + 
+--R                       2 6                    2    5           2            2 4
+--R                 121A b e  + (130A b c + 65B b )d e  + (- 36A c  - 72B b c)d e
+--R               + 
+--R                      2 3 3
+--R                 20B c d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                       2 6                     2    5
+--R                 372A b e  + (224A b c + 112B b )d e
+--R               + 
+--R                         2             2 4        2 3 3
+--R                 (- 80A c  - 160B b c)d e  + 60B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                       2 6                    2    5           2            2 4
+--R                 508A b e  + (120A b c + 60B b )d e  + (- 48A c  - 96B b c)d e
+--R               + 
+--R                      2 3 3
+--R                 40B c d e
+--R            *
+--R               m
+--R           + 
+--R                   2 6
+--R             240A b e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                2   5 5         2   5                   2  2 4  4
+--R             A b d e m  + (16A b d e  + (- 6A b c - 3B b )d e )m
+--R           + 
+--R                   2   5                     2  2 4         2            3 3  3
+--R             (89A b d e  + (- 72A b c - 36B b )d e  + (12A c  + 24B b c)d e )m
+--R           + 
+--R                       2   5                       2  2 4
+--R                 194A b d e  + (- 246A b c - 123B b )d e
+--R               + 
+--R                       2             3 3        2 4 2
+--R                 (84A c  + 168B b c)d e  - 60B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                       2   5                      2  2 4
+--R                 120A b d e  + (- 180A b c - 90B b )d e
+--R               + 
+--R                       2             3 3        2 4 2
+--R                 (72A c  + 144B b c)d e  - 60B c d e
+--R            *
+--R               m
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                   2 2 4 4           2 2 4                  2  3 3  3
+--R             - 2A b d e m  + (- 30A b d e  + (12A b c + 6B b )d e )m
+--R           + 
+--R                         2 2 4                    2  3 3
+--R                 - 148A b d e  + (132A b c + 66B b )d e
+--R               + 
+--R                         2            4 2
+--R                 (- 24A c  - 48B b c)d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                         2 2 4                     2  3 3
+--R                 - 240A b d e  + (360A b c + 180B b )d e
+--R               + 
+--R                          2             4 2         2 5
+--R                 (- 144A c  - 288B b c)d e  + 120B c d e
+--R            *
+--R               m
+--R        *
+--R           x
+--R       + 
+--R             2 3 3 3         2 3 3                    2  4 2  2
+--R         2A b d e m  + (30A b d e  + (- 12A b c - 6B b )d e )m
+--R       + 
+--R                2 3 3                      2  4 2         2            5
+--R         (148A b d e  + (- 132A b c - 66B b )d e  + (24A c  + 48B b c)d e)m
+--R       + 
+--R               2 3 3                       2  4 2          2             5
+--R         240A b d e  + (- 360A b c - 180B b )d e  + (144A c  + 288B b c)d e
+--R       + 
+--R                 2 6
+--R         - 120B c d
+--R    *
+--R         m log(e x + d)
+--R       %e
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     e m  + 21e m  + 175e m  + 735e m  + 1624e m  + 1764e m + 720e
+--R                                         Type: Union(Expression(Integer),...)
+--E 73
+
+--S 74 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  2 6 5        2 6 4        2 6 3         2 6 2         2 6
+--R               B c e m  + 15B c e m  + 85B c e m  + 225B c e m  + 274B c e m
+--R             + 
+--R                     2 6
+--R               120B c e
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                    2           6      2   5  5
+--R               ((A c  + 2B b c)e  + B c d e )m
+--R             + 
+--R                      2            6        2   5  4
+--R               ((16A c  + 32B b c)e  + 10B c d e )m
+--R             + 
+--R                      2             6        2   5  3
+--R               ((95A c  + 190B b c)e  + 35B c d e )m
+--R             + 
+--R                       2             6        2   5  2
+--R               ((260A c  + 520B b c)e  + 50B c d e )m
+--R             + 
+--R                       2             6        2   5            2             6
+--R               ((324A c  + 648B b c)e  + 24B c d e )m + (144A c  + 288B b c)e
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                             2  6       2             5  5
+--R               ((2A b c + B b )e  + (A c  + 2B b c)d e )m
+--R             + 
+--R                                2  6         2              5       2 2 4  4
+--R               ((34A b c + 17B b )e  + (12A c  + 24B b c)d e  - 5B c d e )m
+--R             + 
+--R                                  2  6         2              5        2 2 4  3
+--R               ((214A b c + 107B b )e  + (47A c  + 94B b c)d e  - 30B c d e )m
+--R             + 
+--R                                  2  6         2               5        2 2 4  2
+--R               ((614A b c + 307B b )e  + (72A c  + 144B b c)d e  - 55B c d e )m
+--R             + 
+--R                                  2  6         2              5        2 2 4
+--R               ((792A b c + 396B b )e  + (36A c  + 72B b c)d e  - 30B c d e )m
+--R             + 
+--R                                 2  6
+--R               (360A b c + 180B b )e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   2 6                2    5  5
+--R               (A b e  + (2A b c + B b )d e )m
+--R             + 
+--R                     2 6                   2    5          2           2 4  4
+--R               (18A b e  + (28A b c + 14B b )d e  + (- 4A c  - 8B b c)d e )m
+--R             + 
+--R                         2 6                    2    5
+--R                   121A b e  + (130A b c + 65B b )d e
+--R                 + 
+--R                           2            2 4        2 3 3
+--R                   (- 36A c  - 72B b c)d e  + 20B c d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                         2 6                     2    5
+--R                   372A b e  + (224A b c + 112B b )d e
+--R                 + 
+--R                           2             2 4        2 3 3
+--R                   (- 80A c  - 160B b c)d e  + 60B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                         2 6                    2    5
+--R                   508A b e  + (120A b c + 60B b )d e
+--R                 + 
+--R                           2            2 4        2 3 3
+--R                   (- 48A c  - 96B b c)d e  + 40B c d e
+--R              *
+--R                 m
+--R             + 
+--R                     2 6
+--R               240A b e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  2   5 5         2   5                   2  2 4  4
+--R               A b d e m  + (16A b d e  + (- 6A b c - 3B b )d e )m
+--R             + 
+--R                          2   5                     2  2 4
+--R                     89A b d e  + (- 72A b c - 36B b )d e
+--R                   + 
+--R                           2            3 3
+--R                     (12A c  + 24B b c)d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                         2   5                       2  2 4
+--R                   194A b d e  + (- 246A b c - 123B b )d e
+--R                 + 
+--R                         2             3 3        2 4 2
+--R                   (84A c  + 168B b c)d e  - 60B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                         2   5                      2  2 4
+--R                   120A b d e  + (- 180A b c - 90B b )d e
+--R                 + 
+--R                         2             3 3        2 4 2
+--R                   (72A c  + 144B b c)d e  - 60B c d e
+--R              *
+--R                 m
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     2 2 4 4           2 2 4                  2  3 3  3
+--R               - 2A b d e m  + (- 30A b d e  + (12A b c + 6B b )d e )m
+--R             + 
+--R                           2 2 4                    2  3 3
+--R                   - 148A b d e  + (132A b c + 66B b )d e
+--R                 + 
+--R                           2            4 2
+--R                   (- 24A c  - 48B b c)d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                           2 2 4                     2  3 3
+--R                   - 240A b d e  + (360A b c + 180B b )d e
+--R                 + 
+--R                            2             4 2         2 5
+--R                   (- 144A c  - 288B b c)d e  + 120B c d e
+--R              *
+--R                 m
+--R          *
+--R             x
+--R         + 
+--R               2 3 3 3         2 3 3                    2  4 2  2
+--R           2A b d e m  + (30A b d e  + (- 12A b c - 6B b )d e )m
+--R         + 
+--R                  2 3 3                      2  4 2         2            5
+--R           (148A b d e  + (- 132A b c - 66B b )d e  + (24A c  + 48B b c)d e)m
+--R         + 
+--R                 2 3 3                       2  4 2          2             5
+--R           240A b d e  + (- 360A b c - 180B b )d e  + (144A c  + 288B b c)d e
+--R         + 
+--R                   2 6
+--R           - 120B c d
+--R      *
+--R           m log(e x + d)
+--R         %e
+--R     + 
+--R               2 5        2 4        2 3         2 2         2          2
+--R         (- B c m  - 15B c m  - 85B c m  - 225B c m  - 274B c m - 120B c )
+--R      *
+--R                  m + 6
+--R         (e x + d)
+--R     + 
+--R                  2                  2   5            2                    2   4
+--R           ((- A c  - 2B b c)e + 5B c d)m  + ((- 16A c  - 32B b c)e + 80B c d)m
+--R         + 
+--R                    2                      2   3
+--R           ((- 95A c  - 190B b c)e + 475B c d)m
+--R         + 
+--R                     2                       2   2
+--R           ((- 260A c  - 520B b c)e + 1300B c d)m
+--R         + 
+--R                     2                       2               2
+--R           ((- 324A c  - 648B b c)e + 1620B c d)m + (- 144A c  - 288B b c)e
+--R         + 
+--R                 2
+--R           720B c d
+--R      *
+--R                  m + 5
+--R         (e x + d)
+--R     + 
+--R                           2  2        2                     2 2  5
+--R           ((- 2A b c - B b )e  + (4A c  + 8B b c)d e - 10B c d )m
+--R         + 
+--R                              2  2         2                        2 2  4
+--R           ((- 34A b c - 17B b )e  + (68A c  + 136B b c)d e - 170B c d )m
+--R         + 
+--R                                2  2          2                         2 2  3
+--R           ((- 214A b c - 107B b )e  + (428A c  + 856B b c)d e - 1070B c d )m
+--R         + 
+--R                                2  2           2                          2 2  2
+--R           ((- 614A b c - 307B b )e  + (1228A c  + 2456B b c)d e - 3070B c d )m
+--R         + 
+--R                                2  2           2                          2 2
+--R           ((- 792A b c - 396B b )e  + (1584A c  + 3168B b c)d e - 3960B c d )m
+--R         + 
+--R                               2  2          2                          2 2
+--R           (- 360A b c - 180B b )e  + (720A c  + 1440B b c)d e - 1800B c d
+--R      *
+--R                  m + 4
+--R         (e x + d)
+--R     + 
+--R                      2 3                 2    2          2            2
+--R                 - A b e  + (6A b c + 3B b )d e  + (- 6A c  - 12B b c)d e
+--R               + 
+--R                      2 3
+--R                 10B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                      2 3                    2    2            2             2
+--R               - 18A b e  + (108A b c + 54B b )d e  + (- 108A c  - 216B b c)d e
+--R             + 
+--R                     2 3
+--R               180B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       2 3                     2    2
+--R               - 121A b e  + (726A b c + 363B b )d e
+--R             + 
+--R                        2              2           2 3
+--R               (- 726A c  - 1452B b c)d e + 1210B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       2 3                       2    2
+--R               - 372A b e  + (2232A b c + 1116B b )d e
+--R             + 
+--R                         2              2           2 3
+--R               (- 2232A c  - 4464B b c)d e + 3720B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                       2 3                       2    2
+--R               - 508A b e  + (3048A b c + 1524B b )d e
+--R             + 
+--R                         2              2           2 3
+--R               (- 3048A c  - 6096B b c)d e + 5080B c d
+--R          *
+--R             m
+--R         + 
+--R                   2 3                      2    2             2              2
+--R           - 240A b e  + (1440A b c + 720B b )d e  + (- 1440A c  - 2880B b c)d e
+--R         + 
+--R                  2 3
+--R           2400B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                     2   3                   2  2 2        2           3
+--R                 2A b d e  + (- 6A b c - 3B b )d e  + (4A c  + 8B b c)d e
+--R               + 
+--R                       2 4
+--R                 - 5B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                    2   3                      2  2 2         2             3
+--R               38A b d e  + (- 114A b c - 57B b )d e  + (76A c  + 152B b c)d e
+--R             + 
+--R                      2 4
+--R               - 95B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                     2   3                       2  2 2
+--R               274A b d e  + (- 822A b c - 411B b )d e
+--R             + 
+--R                      2              3          2 4
+--R               (548A c  + 1096B b c)d e - 685B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                     2   3                         2  2 2
+--R               922A b d e  + (- 2766A b c - 1383B b )d e
+--R             + 
+--R                       2              3           2 4
+--R               (1844A c  + 3688B b c)d e - 2305B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                      2   3                         2  2 2
+--R               1404A b d e  + (- 4212A b c - 2106B b )d e
+--R             + 
+--R                       2              3           2 4
+--R               (2808A c  + 5616B b c)d e - 3510B c d
+--R          *
+--R             m
+--R         + 
+--R                 2   3                         2  2 2
+--R           720A b d e  + (- 2160A b c - 1080B b )d e
+--R         + 
+--R                   2              3           2 4
+--R           (1440A c  + 2880B b c)d e - 1800B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R                 2 2 3                2  3 2         2           4       2 5  5
+--R           (- A b d e  + (2A b c + B b )d e  + (- A c  - 2B b c)d e + B c d )m
+--R         + 
+--R                      2 2 3                   2  3 2           2            4
+--R               - 20A b d e  + (40A b c + 20B b )d e  + (- 20A c  - 40B b c)d e
+--R             + 
+--R                    2 5
+--R               20B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       2 2 3                     2  3 2
+--R               - 155A b d e  + (310A b c + 155B b )d e
+--R             + 
+--R                        2             4          2 5
+--R               (- 155A c  - 310B b c)d e + 155B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       2 2 3                      2  3 2
+--R               - 580A b d e  + (1160A b c + 580B b )d e
+--R             + 
+--R                        2              4          2 5
+--R               (- 580A c  - 1160B b c)d e + 580B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                        2 2 3                       2  3 2
+--R               - 1044A b d e  + (2088A b c + 1044B b )d e
+--R             + 
+--R                         2              4           2 5
+--R               (- 1044A c  - 2088B b c)d e + 1044B c d
+--R          *
+--R             m
+--R         + 
+--R                   2 2 3                      2  3 2
+--R           - 720A b d e  + (1440A b c + 720B b )d e
+--R         + 
+--R                    2              4          2 5
+--R           (- 720A c  - 1440B b c)d e + 720B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     e m  + 21e m  + 175e m  + 735e m  + 1624e m  + 1764e m + 720e
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 1457
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 1457
+t0:=(A+B*x)*(d+e*x)^4*(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R        2 4 9        2           4       2   3  8
+--R     B c e x  + ((A c  + 2B b c)e  + 4B c d e )x
+--R   + 
+--R                   2  4        2             3       2 2 2  7
+--R     ((2A b c + B b )e  + (4A c  + 8B b c)d e  + 6B c d e )x
+--R   + 
+--R         2 4                 2    3        2            2 2       2 3   6
+--R     (A b e  + (8A b c + 4B b )d e  + (6A c  + 12B b c)d e  + 4B c d e)x
+--R   + 
+--R          2   3                  2  2 2        2           3       2 4  5
+--R     (4A b d e  + (12A b c + 6B b )d e  + (4A c  + 8B b c)d e + B c d )x
+--R   + 
+--R          2 2 2                 2  3        2           4  4
+--R     (6A b d e  + (8A b c + 4B b )d e + (A c  + 2B b c)d )x
+--R   + 
+--R          2 3                 2  4  3      2 4 2
+--R     (4A b d e + (2A b c + B b )d )x  + A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 76
+
+--S 77 of 1457
+r0:=-1/5*d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^5/e^6+1/6*d*(c*d-b*e)*(B*d*_
+     (5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^6/e^6+1/7*(A*e*(6*c^2*d^2-_
+     6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*_
+     (d+e*x)^7/e^6-1/8*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-8*b*c*d*e+_
+     b^2*e^2))*(d+e*x)^8/e^6-1/9*c*(5*B*c*d-2*b*B*e-A*c*e)*_
+     (d+e*x)^9/e^6+1/10*B*c^2*(d+e*x)^10/e^6
+--R 
+--R
+--R   (2)
+--R        1    2 10 10     1    2   2        10   4    2   9  9
+--R       -- B c e  x   + ((- A c  + - B b c)e   + - B c d e )x
+--R       10                9        9             9
+--R     + 
+--R         1         1    2  10    1    2            9   3    2 2 8  8
+--R       ((- A b c + - B b )e   + (- A c  + B b c)d e  + - B c d e )x
+--R         4         8             2                     4
+--R     + 
+--R           1    2 10    8         4    2    9    6    2   12        2 8
+--R           - A b e   + (- A b c + - B b )d e  + (- A c  + -- B b c)d e
+--R           7            7         7              7         7
+--R         + 
+--R           4    2 3 7
+--R           - B c d e
+--R           7
+--R      *
+--R          7
+--R         x
+--R     + 
+--R             2    2   9                2  2 8    2    2   4        3 7
+--R             - A b d e  + (2A b c + B b )d e  + (- A c  + - B b c)d e
+--R             3                                   3        3
+--R           + 
+--R             1    2 4 6
+--R             - B c d e
+--R             6
+--R      *
+--R          6
+--R         x
+--R     + 
+--R        6    2 2 8    8         4    2  3 7    1    2   2        4 6  5
+--R       (- A b d e  + (- A b c + - B b )d e  + (- A c  + - B b c)d e )x
+--R        5             5         5              5        5
+--R     + 
+--R           2 3 7    1         1    2  4 6  4   1    2 4 6 3    1     2 7 3
+--R       (A b d e  + (- A b c + - B b )d e )x  + - A b d e x  + --- A b d e
+--R                    2         4                3              105
+--R     + 
+--R           1           1     2  8 2     1     2    1         9      1     2 10
+--R       (- --- A b c - --- B b )d e  + (--- A c  + --- B b c)d e - ---- B c d
+--R          140         280              630        315             1260
+--R  /
+--R      6
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 77
+
+--S 78 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    2 4 10     1    2   2        4   4    2   3  9
+--R     -- B c e x   + ((- A c  + - B b c)e  + - B c d e )x
+--R     10               9        9            9
+--R   + 
+--R       1         1    2  4    1    2            3   3    2 2 2  8
+--R     ((- A b c + - B b )e  + (- A c  + B b c)d e  + - B c d e )x
+--R       4         8            2                     4
+--R   + 
+--R      1    2 4    8         4    2    3    6    2   12        2 2   4    2 3   7
+--R     (- A b e  + (- A b c + - B b )d e  + (- A c  + -- B b c)d e  + - B c d e)x
+--R      7           7         7              7         7              7
+--R   + 
+--R      2    2   3                2  2 2    2    2   4        3    1    2 4  6
+--R     (- A b d e  + (2A b c + B b )d e  + (- A c  + - B b c)d e + - B c d )x
+--R      3                                   3        3             6
+--R   + 
+--R      6    2 2 2    8         4    2  3     1    2   2        4  5
+--R     (- A b d e  + (- A b c + - B b )d e + (- A c  + - B b c)d )x
+--R      5             5         5             5        5
+--R   + 
+--R         2 3     1         1    2  4  4   1    2 4 3
+--R     (A b d e + (- A b c + - B b )d )x  + - A b d x
+--R                 2         4              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 78
+
+--S 79 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          1     2 7 3     1           1     2  8 2       1     2    1         9
+--R       - --- A b d e  + (--- A b c + --- B b )d e  + (- --- A c  - --- B b c)d e
+--R         105             140         280                630        315
+--R     + 
+--R         1     2 10
+--R       ---- B c d
+--R       1260
+--R  /
+--R      6
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 79
+
+--S 80 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 80
+
+)clear all
+
+--S 81 of 1457
+t0:=(A+B*x)*(d+e*x)^3*(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R        2 3 8        2           3       2   2  7
+--R     B c e x  + ((A c  + 2B b c)e  + 3B c d e )x
+--R   + 
+--R                   2  3        2             2       2 2   6
+--R     ((2A b c + B b )e  + (3A c  + 6B b c)d e  + 3B c d e)x
+--R   + 
+--R         2 3                 2    2        2           2       2 3  5
+--R     (A b e  + (6A b c + 3B b )d e  + (3A c  + 6B b c)d e + B c d )x
+--R   + 
+--R          2   2                 2  2        2           3  4
+--R     (3A b d e  + (6A b c + 3B b )d e + (A c  + 2B b c)d )x
+--R   + 
+--R          2 2                 2  3  3      2 3 2
+--R     (3A b d e + (2A b c + B b )d )x  + A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 81
+
+--S 82 of 1457
+r0:=1/3*A*b^2*d^3*x^3+1/4*b*d^2*(b*B*d+2*A*c*d+3*A*b*e)*x^4+1/5*d*(A*c^2*_
+     d^2+3*b^2*e*(B*d+A*e)+2*b*c*d*(B*d+3*A*e))*x^5+1/6*(A*e*(3*c^2*d^2+_
+     6*b*c*d*e+b^2*e^2)+B*d*(c^2*d^2+6*b*c*d*e+3*b^2*e^2))*x^6+1/7*e*_
+     (A*c*e*(3*c*d+2*b*e)+B*(3*c^2*d^2+6*b*c*d*e+b^2*e^2))*x^7+_
+     1/8*c*e^2*(3*B*c*d+2*b*B*e+A*c*e)*x^8+1/9*B*c^2*e^3*x^9
+--R 
+--R
+--R   (2)
+--R     1    2 3 9     1    2   1        3   3    2   2  8
+--R     - B c e x  + ((- A c  + - B b c)e  + - B c d e )x
+--R     9              8        4            8
+--R   + 
+--R       2         1    2  3    3    2   6          2   3    2 2   7
+--R     ((- A b c + - B b )e  + (- A c  + - B b c)d e  + - B c d e)x
+--R       7         7            7        7              7
+--R   + 
+--R      1    2 3            1    2    2    1    2          2    1    2 3  6
+--R     (- A b e  + (A b c + - B b )d e  + (- A c  + B b c)d e + - B c d )x
+--R      6                   2              2                    6
+--R   + 
+--R      3    2   2    6         3    2  2     1    2   2        3  5
+--R     (- A b d e  + (- A b c + - B b )d e + (- A c  + - B b c)d )x
+--R      5             5         5             5        5
+--R   + 
+--R      3    2 2     1         1    2  3  4   1    2 3 3
+--R     (- A b d e + (- A b c + - B b )d )x  + - A b d x
+--R      4            2         4              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 82
+
+--S 83 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    2 3 9     1    2   1        3   3    2   2  8
+--R     - B c e x  + ((- A c  + - B b c)e  + - B c d e )x
+--R     9              8        4            8
+--R   + 
+--R       2         1    2  3    3    2   6          2   3    2 2   7
+--R     ((- A b c + - B b )e  + (- A c  + - B b c)d e  + - B c d e)x
+--R       7         7            7        7              7
+--R   + 
+--R      1    2 3            1    2    2    1    2          2    1    2 3  6
+--R     (- A b e  + (A b c + - B b )d e  + (- A c  + B b c)d e + - B c d )x
+--R      6                   2              2                    6
+--R   + 
+--R      3    2   2    6         3    2  2     1    2   2        3  5
+--R     (- A b d e  + (- A b c + - B b )d e + (- A c  + - B b c)d )x
+--R      5             5         5             5        5
+--R   + 
+--R      3    2 2     1         1    2  3  4   1    2 3 3
+--R     (- A b d e + (- A b c + - B b )d )x  + - A b d x
+--R      4            2         4              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 83
+
+--S 84 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 84
+
+--S 85 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 85
+
+)clear all
+
+--S 86 of 1457
+t0:=(A+B*x)*(d+e*x)^2*(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R        2 2 7        2           2       2     6
+--R     B c e x  + ((A c  + 2B b c)e  + 2B c d e)x
+--R   + 
+--R                   2  2        2                   2 2  5
+--R     ((2A b c + B b )e  + (2A c  + 4B b c)d e + B c d )x
+--R   + 
+--R         2 2                 2           2           2  4
+--R     (A b e  + (4A b c + 2B b )d e + (A c  + 2B b c)d )x
+--R   + 
+--R          2                   2  2  3      2 2 2
+--R     (2A b d e + (2A b c + B b )d )x  + A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 86
+
+--S 87 of 1457
+r0:=1/3*A*b^2*d^2*x^3+1/4*b*d*(b*B*d+2*A*c*d+2*A*b*e)*x^4+1/5*(A*c^2*d^2+_
+     b^2*e*(2*B*d+A*e)+2*b*c*d*(B*d+2*A*e))*x^5+1/6*(2*A*c*e*(c*d+b*e)+_
+     B*(c^2*d^2+4*b*c*d*e+b^2*e^2))*x^6+1/7*c*e*(A*c*e+2*B*(c*d+b*e))*_
+     x^7+1/8*B*c^2*e^2*x^8
+--R 
+--R
+--R   (2)
+--R     1    2 2 8     1    2   2        2   2    2     7
+--R     - B c e x  + ((- A c  + - B b c)e  + - B c d e)x
+--R     8              7        7            7
+--R   + 
+--R       1         1    2  2    1    2   2             1    2 2  6
+--R     ((- A b c + - B b )e  + (- A c  + - B b c)d e + - B c d )x
+--R       3         6            3        3             6
+--R   + 
+--R      1    2 2    4         2    2        1    2   2        2  5
+--R     (- A b e  + (- A b c + - B b )d e + (- A c  + - B b c)d )x
+--R      5           5         5             5        5
+--R   + 
+--R      1    2       1         1    2  2  4   1    2 2 3
+--R     (- A b d e + (- A b c + - B b )d )x  + - A b d x
+--R      2            2         4              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 87
+
+--S 88 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    2 2 8     1    2   2        2   2    2     7
+--R     - B c e x  + ((- A c  + - B b c)e  + - B c d e)x
+--R     8              7        7            7
+--R   + 
+--R       1         1    2  2    1    2   2             1    2 2  6
+--R     ((- A b c + - B b )e  + (- A c  + - B b c)d e + - B c d )x
+--R       3         6            3        3             6
+--R   + 
+--R      1    2 2    4         2    2        1    2   2        2  5
+--R     (- A b e  + (- A b c + - B b )d e + (- A c  + - B b c)d )x
+--R      5           5         5             5        5
+--R   + 
+--R      1    2       1         1    2  2  4   1    2 2 3
+--R     (- A b d e + (- A b c + - B b )d )x  + - A b d x
+--R      2            2         4              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 88
+
+--S 89 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 89
+
+--S 90 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 90
+
+)clear all
+
+--S 91 of 1457
+t0:=(A+B*x)*(d+e*x)*(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R        2   6        2                 2   5
+--R     B c e x  + ((A c  + 2B b c)e + B c d)x
+--R   + 
+--R                   2         2             4       2                 2    3
+--R     ((2A b c + B b )e + (A c  + 2B b c)d)x  + (A b e + (2A b c + B b )d)x
+--R   + 
+--R        2   2
+--R     A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 91
+
+--S 92 of 1457
+r0:=1/3*A*b^2*d*x^3+1/4*b*(b*B*d+2*A*c*d+A*b*e)*x^4+1/5*(A*c^2*d+b^2*B*e+_
+     2*b*c*(B*d+A*e))*x^5+1/6*c*(B*c*d+2*b*B*e+A*c*e)*x^6+1/7*B*c^2*e*x^7
+--R 
+--R
+--R   (2)
+--R     1    2   7     1    2   1           1    2   6
+--R     - B c e x  + ((- A c  + - B b c)e + - B c d)x
+--R     7              6        3           6
+--R   + 
+--R       2         1    2      1    2   2          5
+--R     ((- A b c + - B b )e + (- A c  + - B b c)d)x
+--R       5         5           5        5
+--R   + 
+--R      1    2     1         1    2    4   1    2   3
+--R     (- A b e + (- A b c + - B b )d)x  + - A b d x
+--R      4          2         4             3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 92
+
+--S 93 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    2   7     1    2   1           1    2   6
+--R     - B c e x  + ((- A c  + - B b c)e + - B c d)x
+--R     7              6        3           6
+--R   + 
+--R       2         1    2      1    2   2          5
+--R     ((- A b c + - B b )e + (- A c  + - B b c)d)x
+--R       5         5           5        5
+--R   + 
+--R      1    2     1         1    2    4   1    2   3
+--R     (- A b e + (- A b c + - B b )d)x  + - A b d x
+--R      4          2         4             3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 93
+
+--S 94 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 94
+
+--S 95 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 95
+
+)clear all
+
+--S 96 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^2
+--R 
+--R
+--R           2 5       2           4                2  3      2 2
+--R   (1)  B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R                                                    Type: Polynomial(Integer)
+--E 96
+
+--S 97 of 1457
+r0:=1/3*A*b^2*x^3+1/4*b*(b*B+2*A*c)*x^4+1/5*c*(2*b*B+A*c)*x^5+1/6*B*c^2*x^6
+--R 
+--R
+--R        1    2 6    1    2   2        5    1         1    2  4   1    2 3
+--R   (2)  - B c x  + (- A c  + - B b c)x  + (- A b c + - B b )x  + - A b x
+--R        6           5        5             2         4           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 97
+
+--S 98 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    2 6    1    2   2        5    1         1    2  4   1    2 3
+--R   (3)  - B c x  + (- A c  + - B b c)x  + (- A b c + - B b )x  + - A b x
+--R        6           5        5             2         4           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 98
+
+--S 99 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 99
+
+--S 100 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 100
+
+)clear all
+
+--S 101 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)
+--R 
+--R
+--R           2 5       2           4                2  3      2 2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                                e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 101
+
+--S 102 of 1457
+r0:=d*(B*d-A*e)*(c*d-b*e)^2*x/e^5-1/2*(B*d-A*e)*(c*d-b*e)^2*x^2/e^4-_
+     1/3*(A*c*e*(c*d-2*b*e)-B*(c*d-b*e)^2)*x^3/e^3-1/4*c*(B*c*d-2*b*B*e-_
+     A*c*e)*x^4/e^2+1/5*B*c^2*x^5/e-d^2*(B*d-A*e)*(c*d-b*e)^2*log(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R                2 2 3                      2  3 2         2             4
+--R           60A b d e  + (- 120A b c - 60B b )d e  + (60A c  + 120B b c)d e
+--R         + 
+--R                  2 5
+--R           - 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            2 5 5          2            5        2   4  4
+--R       12B c e x  + ((15A c  + 30B b c)e  - 15B c d e )x
+--R     + 
+--R                        2  5           2              4        2 2 3  3
+--R       ((40A b c + 20B b )e  + (- 20A c  - 40B b c)d e  + 20B c d e )x
+--R     + 
+--R                2 5                     2    4         2            2 3
+--R           30A b e  + (- 60A b c - 30B b )d e  + (30A c  + 60B b c)d e
+--R         + 
+--R                  2 3 2
+--R           - 30B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  2   4                    2  2 3           2             3 2
+--R           - 60A b d e  + (120A b c + 60B b )d e  + (- 60A c  - 120B b c)d e
+--R         + 
+--R                2 4
+--R           60B c d e
+--R      *
+--R         x
+--R  /
+--R        6
+--R     60e
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 2 3                      2  3 2         2             4
+--R           60A b d e  + (- 120A b c - 60B b )d e  + (60A c  + 120B b c)d e
+--R         + 
+--R                  2 5
+--R           - 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            2 5 5          2            5        2   4  4
+--R       12B c e x  + ((15A c  + 30B b c)e  - 15B c d e )x
+--R     + 
+--R                        2  5           2              4        2 2 3  3
+--R       ((40A b c + 20B b )e  + (- 20A c  - 40B b c)d e  + 20B c d e )x
+--R     + 
+--R                2 5                     2    4         2            2 3
+--R           30A b e  + (- 60A b c - 30B b )d e  + (30A c  + 60B b c)d e
+--R         + 
+--R                  2 3 2
+--R           - 30B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  2   4                    2  2 3           2             3 2
+--R           - 60A b d e  + (120A b c + 60B b )d e  + (- 60A c  - 120B b c)d e
+--R         + 
+--R                2 4
+--R           60B c d e
+--R      *
+--R         x
+--R  /
+--R        6
+--R     60e
+--R                                         Type: Union(Expression(Integer),...)
+--E 103
+
+--S 104 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^2
+--R 
+--R
+--R           2 5       2           4                2  3      2 2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                            2 2             2
+--R                           e x  + 2d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 106
+
+--S 107 of 1457
+r0:=-(c*d-b*e)*(2*B*d*(2*c*d-b*e)-A*e*(3*c*d-b*e))*x/e^5+1/2*(c*d-b*e)*_
+     (3*B*c*d-b*B*e-2*A*c*e)*x^2/e^4-1/3*c*(2*B*c*d-2*b*B*e-A*c*e)*x^3/e^3+_
+     1/4*B*c^2*x^4/e^2+d^2*(B*d-A*e)*(c*d-b*e)^2/(e^6*(d+e*x))+d*_
+     (c*d-b*e)*(B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*log(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R                      2   4                   2  2 3           2            3 2
+--R               - 24A b d e  + (72A b c + 36B b )d e  + (- 48A c  - 96B b c)d e
+--R             + 
+--R                    2 4
+--R               60B c d e
+--R          *
+--R             x
+--R         + 
+--R                  2 2 3                   2  3 2           2            4
+--R           - 24A b d e  + (72A b c + 36B b )d e  + (- 48A c  - 96B b c)d e
+--R         + 
+--R                2 5
+--R           60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5         2           5       2   4  4
+--R       3B c e x  + ((4A c  + 8B b c)e  - 5B c d e )x
+--R     + 
+--R                       2  5          2              4        2 2 3  3
+--R       ((12A b c + 6B b )e  + (- 8A c  - 16B b c)d e  + 10B c d e )x
+--R     + 
+--R                2 5                     2    4         2            2 3
+--R           12A b e  + (- 36A b c - 18B b )d e  + (24A c  + 48B b c)d e
+--R         + 
+--R                  2 3 2
+--R           - 30B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                2   4                     2  2 3         2            3 2
+--R           12A b d e  + (- 48A b c - 24B b )d e  + (36A c  + 72B b c)d e
+--R         + 
+--R                  2 4
+--R           - 48B c d e
+--R      *
+--R         x
+--R     + 
+--R            2 2 3                   2  3 2           2            4         2 5
+--R     - 12A b d e  + (24A b c + 12B b )d e  + (- 12A c  - 24B b c)d e + 12B c d
+--R  /
+--R        7         6
+--R     12e x + 12d e
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      2   4                   2  2 3           2            3 2
+--R               - 24A b d e  + (72A b c + 36B b )d e  + (- 48A c  - 96B b c)d e
+--R             + 
+--R                    2 4
+--R               60B c d e
+--R          *
+--R             x
+--R         + 
+--R                  2 2 3                   2  3 2           2            4
+--R           - 24A b d e  + (72A b c + 36B b )d e  + (- 48A c  - 96B b c)d e
+--R         + 
+--R                2 5
+--R           60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5         2           5       2   4  4
+--R       3B c e x  + ((4A c  + 8B b c)e  - 5B c d e )x
+--R     + 
+--R                       2  5          2              4        2 2 3  3
+--R       ((12A b c + 6B b )e  + (- 8A c  - 16B b c)d e  + 10B c d e )x
+--R     + 
+--R                2 5                     2    4         2            2 3
+--R           12A b e  + (- 36A b c - 18B b )d e  + (24A c  + 48B b c)d e
+--R         + 
+--R                  2 3 2
+--R           - 30B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                2   4                     2  2 3         2            3 2
+--R           12A b d e  + (- 48A b c - 24B b )d e  + (36A c  + 72B b c)d e
+--R         + 
+--R                  2 4
+--R           - 48B c d e
+--R      *
+--R         x
+--R     + 
+--R            2 2 3                   2  3 2           2            4         2 5
+--R     - 12A b d e  + (24A b c + 12B b )d e  + (- 12A c  - 24B b c)d e + 12B c d
+--R  /
+--R        7         6
+--R     12e x + 12d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 108
+
+--S 109 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 110
+
+)clear all
+
+--S 111 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^3
+--R 
+--R
+--R           2 5       2           4                2  3      2 2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                       3 3       2 2     2       3
+--R                      e x  + 3d e x  + 3d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 111
+
+--S 112 of 1457
+r0:=-(A*c*e*(3*c*d-2*b*e)-B*(6*c^2*d^2-6*b*c*d*e+b^2*e^2))*x/e^5-1/2*c*_
+     (3*B*c*d-2*b*B*e-A*c*e)*x^2/e^4+1/3*B*c^2*x^3/e^3+1/2*d^2*(B*d-A*e)*_
+     (c*d-b*e)^2/(e^6*(d+e*x)^2)-d*(c*d-b*e)*(B*d*(5*c*d-3*b*e)-2*A*e*_
+     (2*c*d-b*e))/(e^6*(d+e*x))+(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-_
+     B*d*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*log(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R                   2 5                     2    4         2            2 3
+--R               6A b e  + (- 36A b c - 18B b )d e  + (36A c  + 72B b c)d e
+--R             + 
+--R                      2 3 2
+--R               - 60B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    2   4                     2  2 3         2             3 2
+--R               12A b d e  + (- 72A b c - 36B b )d e  + (72A c  + 144B b c)d e
+--R             + 
+--R                       2 4
+--R               - 120B c d e
+--R          *
+--R             x
+--R         + 
+--R             2 2 3                     2  3 2         2            4         2 5
+--R         6A b d e  + (- 36A b c - 18B b )d e  + (36A c  + 72B b c)d e - 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5         2           5       2   4  4
+--R       2B c e x  + ((3A c  + 6B b c)e  - 5B c d e )x
+--R     + 
+--R                       2  5           2              4        2 2 3  3
+--R       ((12A b c + 6B b )e  + (- 12A c  - 24B b c)d e  + 20B c d e )x
+--R     + 
+--R                        2    4           2            2 3        2 3 2  2
+--R       ((24A b c + 12B b )d e  + (- 33A c  - 66B b c)d e  + 63B c d e )x
+--R     + 
+--R                2   4                     2  2 3        2            3 2
+--R           12A b d e  + (- 24A b c - 12B b )d e  + (6A c  + 12B b c)d e
+--R         + 
+--R               2 4
+--R           6B c d e
+--R      *
+--R         x
+--R     + 
+--R           2 2 3                     2  3 2         2            4         2 5
+--R       9A b d e  + (- 30A b c - 15B b )d e  + (21A c  + 42B b c)d e - 27B c d
+--R  /
+--R       8 2        7      2 6
+--R     6e x  + 12d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   2 5                     2    4         2            2 3
+--R               6A b e  + (- 36A b c - 18B b )d e  + (36A c  + 72B b c)d e
+--R             + 
+--R                      2 3 2
+--R               - 60B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    2   4                     2  2 3         2             3 2
+--R               12A b d e  + (- 72A b c - 36B b )d e  + (72A c  + 144B b c)d e
+--R             + 
+--R                       2 4
+--R               - 120B c d e
+--R          *
+--R             x
+--R         + 
+--R             2 2 3                     2  3 2         2            4         2 5
+--R         6A b d e  + (- 36A b c - 18B b )d e  + (36A c  + 72B b c)d e - 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5         2           5       2   4  4
+--R       2B c e x  + ((3A c  + 6B b c)e  - 5B c d e )x
+--R     + 
+--R                       2  5           2              4        2 2 3  3
+--R       ((12A b c + 6B b )e  + (- 12A c  - 24B b c)d e  + 20B c d e )x
+--R     + 
+--R                        2    4           2            2 3        2 3 2  2
+--R       ((24A b c + 12B b )d e  + (- 33A c  - 66B b c)d e  + 63B c d e )x
+--R     + 
+--R                2   4                     2  2 3        2            3 2
+--R           12A b d e  + (- 24A b c - 12B b )d e  + (6A c  + 12B b c)d e
+--R         + 
+--R               2 4
+--R           6B c d e
+--R      *
+--R         x
+--R     + 
+--R           2 2 3                     2  3 2         2            4         2 5
+--R       9A b d e  + (- 30A b c - 15B b )d e  + (21A c  + 42B b c)d e - 27B c d
+--R  /
+--R       8 2        7      2 6
+--R     6e x  + 12d e x + 6d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 113
+
+--S 114 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 115
+
+)clear all
+
+--S 116 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^4
+--R 
+--R
+--R           2 5       2           4                2  3      2 2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                  4 4       3 3     2 2 2     3       4
+--R                 e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 116
+
+--S 117 of 1457
+r0:=-c*(4*B*c*d-2*b*B*e-A*c*e)*x/e^5+1/2*B*c^2*x^2/e^4+1/3*d^2*(B*d-A*e)*_
+     (c*d-b*e)^2/(e^6*(d+e*x)^3)-1/2*d*(c*d-b*e)*(B*d*(5*c*d-3*b*e)-_
+     2*A*e*(2*c*d-b*e))/(e^6*(d+e*x)^2)+(-A*e*(6*c^2*d^2-6*b*c*d*e+_
+     b^2*e^2)+B*d*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))/(e^6*(d+e*x))-_
+     (2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*log(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R                           2  5           2              4        2 2 3  3
+--R           ((12A b c + 6B b )e  + (- 24A c  - 48B b c)d e  + 60B c d e )x
+--R         + 
+--R                            2    4           2             2 3         2 3 2  2
+--R           ((36A b c + 18B b )d e  + (- 72A c  - 144B b c)d e  + 180B c d e )x
+--R         + 
+--R                            2  2 3           2             3 2         2 4
+--R           ((36A b c + 18B b )d e  + (- 72A c  - 144B b c)d e  + 180B c d e)x
+--R         + 
+--R                          2  3 2           2            4         2 5
+--R           (12A b c + 6B b )d e  + (- 24A c  - 48B b c)d e + 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5         2            5        2   4  4
+--R       3B c e x  + ((6A c  + 12B b c)e  - 15B c d e )x
+--R     + 
+--R              2              4        2 2 3  3
+--R       ((18A c  + 36B b c)d e  - 63B c d e )x
+--R     + 
+--R                 2 5                   2    4           2            2 3
+--R           - 6A b e  + (36A b c + 18B b )d e  + (- 18A c  - 36B b c)d e
+--R         + 
+--R                 2 3 2
+--R           - 9B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 2   4                   2  2 3           2             3 2
+--R           - 6A b d e  + (54A b c + 27B b )d e  + (- 54A c  - 108B b c)d e
+--R         + 
+--R                2 4
+--R           81B c d e
+--R      *
+--R         x
+--R     + 
+--R           2 2 3                   2  3 2           2            4         2 5
+--R     - 2A b d e  + (22A b c + 11B b )d e  + (- 26A c  - 52B b c)d e + 47B c d
+--R  /
+--R       9 3        8 2      2 7      3 6
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                           2  5           2              4        2 2 3  3
+--R           ((12A b c + 6B b )e  + (- 24A c  - 48B b c)d e  + 60B c d e )x
+--R         + 
+--R                            2    4           2             2 3         2 3 2  2
+--R           ((36A b c + 18B b )d e  + (- 72A c  - 144B b c)d e  + 180B c d e )x
+--R         + 
+--R                            2  2 3           2             3 2         2 4
+--R           ((36A b c + 18B b )d e  + (- 72A c  - 144B b c)d e  + 180B c d e)x
+--R         + 
+--R                          2  3 2           2            4         2 5
+--R           (12A b c + 6B b )d e  + (- 24A c  - 48B b c)d e + 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5         2            5        2   4  4
+--R       3B c e x  + ((6A c  + 12B b c)e  - 15B c d e )x
+--R     + 
+--R              2              4        2 2 3  3
+--R       ((18A c  + 36B b c)d e  - 63B c d e )x
+--R     + 
+--R                 2 5                   2    4           2            2 3
+--R           - 6A b e  + (36A b c + 18B b )d e  + (- 18A c  - 36B b c)d e
+--R         + 
+--R                 2 3 2
+--R           - 9B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 2   4                   2  2 3           2             3 2
+--R           - 6A b d e  + (54A b c + 27B b )d e  + (- 54A c  - 108B b c)d e
+--R         + 
+--R                2 4
+--R           81B c d e
+--R      *
+--R         x
+--R     + 
+--R           2 2 3                   2  3 2           2            4         2 5
+--R     - 2A b d e  + (22A b c + 11B b )d e  + (- 26A c  - 52B b c)d e + 47B c d
+--R  /
+--R       9 3        8 2      2 7      3 6
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 118
+
+--S 119 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 1457
+t0:=(A+B*x)*(d+e*x)^m*(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R          3 7       3         2  6          2       2   5        2       3  4
+--R       B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 3
+--R       A b x
+--R  *
+--R              m
+--R     (e x + d)
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1457
+r0:=-d^3*(B*d-A*e)*(c*d-b*e)^3*(d+e*x)^(1+m)/(e^8*(1+m))+d^2*(c*d-b*e)^2*_
+     (B*d*(7*c*d-4*b*e)-3*A*e*(2*c*d-b*e))*(d+e*x)^(2+m)/(e^8*(2+m))+_
+     3*d*(c*d-b*e)*(A*e*(5*c^2*d^2-5*b*c*d*e+b^2*e^2)-B*d*(7*c^2*d^2-_
+     8*b*c*d*e+2*b^2*e^2))*(d+e*x)^(3+m)/(e^8*(3+m))+(B*d*(35*c^3*d^3-_
+     60*b*c^2*d^2*e+30*b^2*c*d*e^2-4*b^3*e^3)-A*e*(20*c^3*d^3-30*b*c^2*_
+     d^2*e+12*b^2*c*d*e^2-b^3*e^3))*(d+e*x)^(4+m)/(e^8*(4+m))+(3*A*c*e*_
+     (5*c^2*d^2-5*b*c*d*e+b^2*e^2)-B*(35*c^3*d^3-45*b*c^2*d^2*e+15*b^2*_
+     c*d*e^2-b^3*e^3))*(d+e*x)^(5+m)/(e^8*(5+m))-3*c*(A*c*e*(2*c*d-b*e)-_
+     B*(7*c^2*d^2-6*b*c*d*e+b^2*e^2))*(d+e*x)^(6+m)/(e^8*(6+m))-c^2*_
+     (7*B*c*d-3*b*B*e-A*c*e)*(d+e*x)^(7+m)/(e^8*(7+m))+B*c^3*_
+     (d+e*x)^(8+m)/(e^8*(8+m))
+--R 
+--R
+--R   (2)
+--R              3 7        3 6         3 5          3 4          3 3           3 2
+--R           B c m  + 28B c m  + 322B c m  + 1960B c m  + 6769B c m  + 13132B c m
+--R         + 
+--R                   3           3
+--R           13068B c m + 5040B c
+--R      *
+--R                  m + 8
+--R         (e x + d)
+--R     + 
+--R                3         2         3   7          3          2           3   6
+--R           ((A c  + 3B b c )e - 7B c d)m  + ((29A c  + 87B b c )e - 203B c d)m
+--R         + 
+--R                   3            2            3   5
+--R           ((343A c  + 1029B b c )e - 2401B c d)m
+--R         + 
+--R                    3            2             3   4
+--R           ((2135A c  + 6405B b c )e - 14945B c d)m
+--R         + 
+--R                    3             2             3   3
+--R           ((7504A c  + 22512B b c )e - 52528B c d)m
+--R         + 
+--R                     3             2              3   2
+--R           ((14756A c  + 44268B b c )e - 103292B c d)m
+--R         + 
+--R                     3             2              3
+--R           ((14832A c  + 44496B b c )e - 103824B c d)m
+--R         + 
+--R                   3             2             3
+--R           (5760A c  + 17280B b c )e - 40320B c d
+--R      *
+--R                  m + 7
+--R         (e x + d)
+--R     + 
+--R                   2       2   2          3          2            3 2  7
+--R           ((3A b c  + 3B b c)e  + (- 6A c  - 18B b c )d e + 21B c d )m
+--R         + 
+--R                    2        2   2            3           2             3 2  6
+--R           ((90A b c  + 90B b c)e  + (- 180A c  - 540B b c )d e + 630B c d )m
+--R         + 
+--R                         2          2   2             3            2
+--R               (1098A b c  + 1098B b c)e  + (- 2196A c  - 6588B b c )d e
+--R             + 
+--R                      3 2
+--R               7686B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                         2          2   2              3             2
+--R               (7020A b c  + 7020B b c)e  + (- 14040A c  - 42120B b c )d e
+--R             + 
+--R                       3 2
+--R               49140B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                          2           2   2              3              2
+--R               (25227A b c  + 25227B b c)e  + (- 50454A c  - 151362B b c )d e
+--R             + 
+--R                        3 2
+--R               176589B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                          2           2   2               3              2
+--R               (50490A b c  + 50490B b c)e  + (- 100980A c  - 302940B b c )d e
+--R             + 
+--R                        3 2
+--R               353430B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                          2           2   2               3              2
+--R               (51432A b c  + 51432B b c)e  + (- 102864A c  - 308592B b c )d e
+--R             + 
+--R                        3 2
+--R               360024B c d
+--R          *
+--R             m
+--R         + 
+--R                      2           2   2              3              2
+--R           (20160A b c  + 20160B b c)e  + (- 40320A c  - 120960B b c )d e
+--R         + 
+--R                    3 2
+--R           141120B c d
+--R      *
+--R                  m + 6
+--R         (e x + d)
+--R     + 
+--R                    2       3  3             2        2     2
+--R               (3A b c + B b )e  + (- 15A b c  - 15B b c)d e
+--R             + 
+--R                     3          2  2         3 3
+--R               (15A c  + 45B b c )d e - 35B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                     2         3  3              2         2     2
+--R               (93A b c + 31B b )e  + (- 465A b c  - 465B b c)d e
+--R             + 
+--R                      3            2  2           3 3
+--R               (465A c  + 1395B b c )d e - 1085B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                       2          3  3               2          2     2
+--R               (1173A b c + 391B b )e  + (- 5865A b c  - 5865B b c)d e
+--R             + 
+--R                       3             2  2            3 3
+--R               (5865A c  + 17595B b c )d e - 13685B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                       2           3  3                2           2     2
+--R               (7743A b c + 2581B b )e  + (- 38715A b c  - 38715B b c)d e
+--R             + 
+--R                        3              2  2            3 3
+--R               (38715A c  + 116145B b c )d e - 90335B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                        2           3  3                 2            2     2
+--R               (28632A b c + 9544B b )e  + (- 143160A b c  - 143160B b c)d e
+--R             + 
+--R                         3              2  2             3 3
+--R               (143160A c  + 429480B b c )d e - 334040B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                        2            3  3                 2            2     2
+--R               (58692A b c + 19564B b )e  + (- 293460A b c  - 293460B b c)d e
+--R             + 
+--R                         3              2  2             3 3
+--R               (293460A c  + 880380B b c )d e - 684740B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                        2            3  3                 2            2     2
+--R               (60912A b c + 20304B b )e  + (- 304560A b c  - 304560B b c)d e
+--R             + 
+--R                         3              2  2             3 3
+--R               (304560A c  + 913680B b c )d e - 710640B c d
+--R          *
+--R             m
+--R         + 
+--R                    2           3  3                 2            2     2
+--R           (24192A b c + 8064B b )e  + (- 120960A b c  - 120960B b c)d e
+--R         + 
+--R                     3              2  2             3 3
+--R           (120960A c  + 362880B b c )d e - 282240B c d
+--R      *
+--R                  m + 5
+--R         (e x + d)
+--R     + 
+--R                  3 4           2        3    3           2        2   2 2
+--R               A b e  + (- 12A b c - 4B b )d e  + (30A b c  + 30B b c)d e
+--R             + 
+--R                       3          2  3         3 4
+--R               (- 20A c  - 60B b c )d e + 35B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                    3 4            2          3    3
+--R               32A b e  + (- 384A b c - 128B b )d e
+--R             + 
+--R                        2         2   2 2            3            2  3
+--R               (960A b c  + 960B b c)d e  + (- 640A c  - 1920B b c )d e
+--R             + 
+--R                      3 4
+--R               1120B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                     3 4             2           3    3
+--R               418A b e  + (- 5016A b c - 1672B b )d e
+--R             + 
+--R                          2           2   2 2             3             2  3
+--R               (12540A b c  + 12540B b c)d e  + (- 8360A c  - 25080B b c )d e
+--R             + 
+--R                       3 4
+--R               14630B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                      3 4              2            3    3
+--R               2864A b e  + (- 34368A b c - 11456B b )d e
+--R             + 
+--R                          2           2   2 2              3              2  3
+--R               (85920A b c  + 85920B b c)d e  + (- 57280A c  - 171840B b c )d e
+--R             + 
+--R                        3 4
+--R               100240B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       3 4               2            3    3
+--R               10993A b e  + (- 131916A b c - 43972B b )d e
+--R             + 
+--R                           2            2   2 2
+--R               (329790A b c  + 329790B b c)d e
+--R             + 
+--R                           3              2  3             3 4
+--R               (- 219860A c  - 659580B b c )d e + 384755B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       3 4               2            3    3
+--R               23312A b e  + (- 279744A b c - 93248B b )d e
+--R             + 
+--R                           2            2   2 2
+--R               (699360A b c  + 699360B b c)d e
+--R             + 
+--R                           3               2  3             3 4
+--R               (- 466240A c  - 1398720B b c )d e + 815920B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                       3 4               2            3    3
+--R               24876A b e  + (- 298512A b c - 99504B b )d e
+--R             + 
+--R                           2            2   2 2
+--R               (746280A b c  + 746280B b c)d e
+--R             + 
+--R                           3               2  3             3 4
+--R               (- 497520A c  - 1492560B b c )d e + 870660B c d
+--R          *
+--R             m
+--R         + 
+--R                   3 4               2            3    3
+--R           10080A b e  + (- 120960A b c - 40320B b )d e
+--R         + 
+--R                       2            2   2 2               3              2  3
+--R           (302400A b c  + 302400B b c)d e  + (- 201600A c  - 604800B b c )d e
+--R         + 
+--R                    3 4
+--R           352800B c d
+--R      *
+--R                  m + 4
+--R         (e x + d)
+--R     + 
+--R                     3   4         2        3  2 3             2        2   3 2
+--R               - 3A b d e  + (18A b c + 6B b )d e  + (- 30A b c  - 30B b c)d e
+--R             + 
+--R                     3          2  4         3 5
+--R               (15A c  + 45B b c )d e - 21B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                      3   4          2          3  2 3
+--R               - 99A b d e  + (594A b c + 198B b )d e
+--R             + 
+--R                          2         2   3 2          3            2  4
+--R               (- 990A b c  - 990B b c)d e  + (495A c  + 1485B b c )d e
+--R             + 
+--R                       3 5
+--R               - 693B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                        3   4           2           3  2 3
+--R               - 1341A b d e  + (8046A b c + 2682B b )d e
+--R             + 
+--R                            2           2   3 2           3             2  4
+--R               (- 13410A b c  - 13410B b c)d e  + (6705A c  + 20115B b c )d e
+--R             + 
+--R                        3 5
+--R               - 9387B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                        3   4            2            3  2 3
+--R               - 9585A b d e  + (57510A b c + 19170B b )d e
+--R             + 
+--R                            2           2   3 2            3              2  4
+--R               (- 95850A b c  - 95850B b c)d e  + (47925A c  + 143775B b c )d e
+--R             + 
+--R                         3 5
+--R               - 67095B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                         3   4             2            3  2 3
+--R               - 38592A b d e  + (231552A b c + 77184B b )d e
+--R             + 
+--R                             2            2   3 2
+--R               (- 385920A b c  - 385920B b c)d e
+--R             + 
+--R                         3              2  4             3 5
+--R               (192960A c  + 578880B b c )d e - 270144B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                         3   4             2             3  2 3
+--R               - 86076A b d e  + (516456A b c + 172152B b )d e
+--R             + 
+--R                             2            2   3 2
+--R               (- 860760A b c  - 860760B b c)d e
+--R             + 
+--R                         3               2  4             3 5
+--R               (430380A c  + 1291140B b c )d e - 602532B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                         3   4             2             3  2 3
+--R               - 96144A b d e  + (576864A b c + 192288B b )d e
+--R             + 
+--R                             2            2   3 2
+--R               (- 961440A b c  - 961440B b c)d e
+--R             + 
+--R                         3               2  4             3 5
+--R               (480720A c  + 1442160B b c )d e - 673008B c d
+--R          *
+--R             m
+--R         + 
+--R                     3   4             2            3  2 3
+--R           - 40320A b d e  + (241920A b c + 80640B b )d e
+--R         + 
+--R                         2            2   3 2             3              2  4
+--R           (- 403200A b c  - 403200B b c)d e  + (201600A c  + 604800B b c )d e
+--R         + 
+--R                      3 5
+--R           - 282240B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                   3 2 4           2        3  3 3           2        2   4 2
+--R               3A b d e  + (- 12A b c - 4B b )d e  + (15A b c  + 15B b c)d e
+--R             + 
+--R                      3          2  5        3 6
+--R               (- 6A c  - 18B b c )d e + 7B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                     3 2 4            2          3  3 3
+--R               102A b d e  + (- 408A b c - 136B b )d e
+--R             + 
+--R                      2         2   4 2            3           2  5          3 6
+--R             (510A b c  + 510B b c)d e  + (- 204A c  - 612B b c )d e + 238B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                      3 2 4             2           3  3 3
+--R               1434A b d e  + (- 5736A b c - 1912B b )d e
+--R             + 
+--R                         2          2   4 2             3            2  5
+--R               (7170A b c  + 7170B b c)d e  + (- 2868A c  - 8604B b c )d e
+--R             + 
+--R                      3 6
+--R               3346B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                       3 2 4              2            3  3 3
+--R               10740A b d e  + (- 42960A b c - 14320B b )d e
+--R             + 
+--R                          2           2   4 2              3             2  5
+--R               (53700A b c  + 53700B b c)d e  + (- 21480A c  - 64440B b c )d e
+--R             + 
+--R                       3 6
+--R               25060B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       3 2 4               2            3  3 3
+--R               45867A b d e  + (- 183468A b c - 61156B b )d e
+--R             + 
+--R                           2            2   4 2
+--R               (229335A b c  + 229335B b c)d e
+--R             + 
+--R                          3              2  5             3 6
+--R               (- 91734A c  - 275202B b c )d e + 107023B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                        3 2 4               2             3  3 3
+--R               110118A b d e  + (- 440472A b c - 146824B b )d e
+--R             + 
+--R                           2            2   4 2
+--R               (550590A b c  + 550590B b c)d e
+--R             + 
+--R                           3              2  5             3 6
+--R               (- 220236A c  - 660708B b c )d e + 256942B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                        3 2 4               2             3  3 3
+--R               134136A b d e  + (- 536544A b c - 178848B b )d e
+--R             + 
+--R                           2            2   4 2
+--R               (670680A b c  + 670680B b c)d e
+--R             + 
+--R                           3              2  5             3 6
+--R               (- 268272A c  - 804816B b c )d e + 312984B c d
+--R          *
+--R             m
+--R         + 
+--R                   3 2 4               2            3  3 3
+--R           60480A b d e  + (- 241920A b c - 80640B b )d e
+--R         + 
+--R                       2            2   4 2               3              2  5
+--R           (302400A b c  + 302400B b c)d e  + (- 120960A c  - 362880B b c )d e
+--R         + 
+--R                    3 6
+--R           141120B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R                    3 3 4        2       3  4 3            2       2   5 2
+--R               - A b d e  + (3A b c + B b )d e  + (- 3A b c  - 3B b c)d e
+--R             + 
+--R                   3         2  6       3 7
+--R               (A c  + 3B b c )d e - B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                      3 3 4          2         3  4 3
+--R               - 35A b d e  + (105A b c + 35B b )d e
+--R             + 
+--R                        2         2   5 2         3           2  6         3 7
+--R             (- 105A b c  - 105B b c)d e  + (35A c  + 105B b c )d e - 35B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                       3 3 4           2          3  4 3
+--R               - 511A b d e  + (1533A b c + 511B b )d e
+--R             + 
+--R                           2          2   5 2          3            2  6
+--R               (- 1533A b c  - 1533B b c)d e  + (511A c  + 1533B b c )d e
+--R             + 
+--R                       3 7
+--R               - 511B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                        3 3 4            2           3  4 3
+--R               - 4025A b d e  + (12075A b c + 4025B b )d e
+--R             + 
+--R                            2           2   5 2           3             2  6
+--R               (- 12075A b c  - 12075B b c)d e  + (4025A c  + 12075B b c )d e
+--R             + 
+--R                        3 7
+--R               - 4025B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                         3 3 4            2            3  4 3
+--R               - 18424A b d e  + (55272A b c + 18424B b )d e
+--R             + 
+--R                            2           2   5 2            3             2  6
+--R               (- 55272A b c  - 55272B b c)d e  + (18424A c  + 55272B b c )d e
+--R             + 
+--R                         3 7
+--R               - 18424B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                         3 3 4             2            3  4 3
+--R               - 48860A b d e  + (146580A b c + 48860B b )d e
+--R             + 
+--R                             2            2   5 2
+--R               (- 146580A b c  - 146580B b c)d e
+--R             + 
+--R                        3              2  6            3 7
+--R               (48860A c  + 146580B b c )d e - 48860B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                         3 3 4             2            3  4 3
+--R               - 69264A b d e  + (207792A b c + 69264B b )d e
+--R             + 
+--R                             2            2   5 2
+--R               (- 207792A b c  - 207792B b c)d e
+--R             + 
+--R                        3              2  6            3 7
+--R               (69264A c  + 207792B b c )d e - 69264B c d
+--R          *
+--R             m
+--R         + 
+--R                     3 3 4             2            3  4 3
+--R           - 40320A b d e  + (120960A b c + 40320B b )d e
+--R         + 
+--R                         2            2   5 2            3              2  6
+--R           (- 120960A b c  - 120960B b c)d e  + (40320A c  + 120960B b c )d e
+--R         + 
+--R                     3 7
+--R           - 40320B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R        8 8      8 7       8 6        8 5         8 4         8 3          8 2
+--R       e m  + 36e m  + 546e m  + 4536e m  + 22449e m  + 67284e m  + 118124e m
+--R     + 
+--R              8          8
+--R       109584e m + 40320e
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 8 7        3 8 6         3 8 5          3 8 4          3 8 3
+--R             B c e m  + 28B c e m  + 322B c e m  + 1960B c e m  + 6769B c e m
+--R           + 
+--R                     3 8 2           3 8           3 8
+--R             13132B c e m  + 13068B c e m + 5040B c e
+--R        *
+--R            8
+--R           x
+--R       + 
+--R                  3         2  8      3   7  7
+--R             ((A c  + 3B b c )e  + B c d e )m
+--R           + 
+--R                    3          2  8        3   7  6
+--R             ((29A c  + 87B b c )e  + 21B c d e )m
+--R           + 
+--R                     3            2  8         3   7  5
+--R             ((343A c  + 1029B b c )e  + 175B c d e )m
+--R           + 
+--R                      3            2  8         3   7  4
+--R             ((2135A c  + 6405B b c )e  + 735B c d e )m
+--R           + 
+--R                      3             2  8          3   7  3
+--R             ((7504A c  + 22512B b c )e  + 1624B c d e )m
+--R           + 
+--R                       3             2  8          3   7  2
+--R             ((14756A c  + 44268B b c )e  + 1764B c d e )m
+--R           + 
+--R                       3             2  8         3   7
+--R             ((14832A c  + 44496B b c )e  + 720B c d e )m
+--R           + 
+--R                     3             2  8
+--R             (5760A c  + 17280B b c )e
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                     2       2   8       3         2    7  7
+--R             ((3A b c  + 3B b c)e  + (A c  + 3B b c )d e )m
+--R           + 
+--R                      2        2   8         3          2    7       3 2 6  6
+--R             ((90A b c  + 90B b c)e  + (23A c  + 69B b c )d e  - 7B c d e )m
+--R           + 
+--R                           2          2   8          3           2    7
+--R                 (1098A b c  + 1098B b c)e  + (205A c  + 615B b c )d e
+--R               + 
+--R                         3 2 6
+--R                 - 105B c d e
+--R            *
+--R                5
+--R               m
+--R           + 
+--R                           2          2   8          3            2    7
+--R                 (7020A b c  + 7020B b c)e  + (905A c  + 2715B b c )d e
+--R               + 
+--R                         3 2 6
+--R                 - 595B c d e
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                            2           2   8           3            2    7
+--R                 (25227A b c  + 25227B b c)e  + (2074A c  + 6222B b c )d e
+--R               + 
+--R                          3 2 6
+--R                 - 1575B c d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                            2           2   8           3            2    7
+--R                 (50490A b c  + 50490B b c)e  + (2312A c  + 6936B b c )d e
+--R               + 
+--R                          3 2 6
+--R                 - 1918B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                            2           2   8          3            2    7
+--R                 (51432A b c  + 51432B b c)e  + (960A c  + 2880B b c )d e
+--R               + 
+--R                         3 2 6
+--R                 - 840B c d e
+--R            *
+--R               m
+--R           + 
+--R                        2           2   8
+--R             (20160A b c  + 20160B b c)e
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                   2       3  8          2       2     7  7
+--R             ((3A b c + B b )e  + (3A b c  + 3B b c)d e )m
+--R           + 
+--R                       2         3  8           2        2     7
+--R                 (93A b c + 31B b )e  + (75A b c  + 75B b c)d e
+--R               + 
+--R                        3          2  2 6
+--R                 (- 6A c  - 18B b c )d e
+--R            *
+--R                6
+--R               m
+--R           + 
+--R                         2          3  8            2         2     7
+--R                 (1173A b c + 391B b )e  + (723A b c  + 723B b c)d e
+--R               + 
+--R                          3           2  2 6        3 3 5
+--R                 (- 108A c  - 324B b c )d e  + 42B c d e
+--R            *
+--R                5
+--R               m
+--R           + 
+--R                         2           3  8             2          2     7
+--R                 (7743A b c + 2581B b )e  + (3405A b c  + 3405B b c)d e
+--R               + 
+--R                          3            2  2 6         3 3 5
+--R                 (- 690A c  - 2070B b c )d e  + 420B c d e
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                          2           3  8             2          2     7
+--R                 (28632A b c + 9544B b )e  + (8202A b c  + 8202B b c)d e
+--R               + 
+--R                           3            2  2 6          3 3 5
+--R                 (- 1980A c  - 5940B b c )d e  + 1470B c d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                          2            3  8             2          2     7
+--R                 (58692A b c + 19564B b )e  + (9480A b c  + 9480B b c)d e
+--R               + 
+--R                           3            2  2 6          3 3 5
+--R                 (- 2544A c  - 7632B b c )d e  + 2100B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                          2            3  8             2          2     7
+--R                 (60912A b c + 20304B b )e  + (4032A b c  + 4032B b c)d e
+--R               + 
+--R                           3            2  2 6          3 3 5
+--R                 (- 1152A c  - 3456B b c )d e  + 1008B c d e
+--R            *
+--R               m
+--R           + 
+--R                      2           3  8
+--R             (24192A b c + 8064B b )e
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                 3 8        2       3    7  7
+--R             (A b e  + (3A b c + B b )d e )m
+--R           + 
+--R                   3 8         2         3    7             2        2   2 6  6
+--R             (32A b e  + (81A b c + 27B b )d e  + (- 15A b c  - 15B b c)d e )m
+--R           + 
+--R                       3 8          2          3    7
+--R                 418A b e  + (849A b c + 283B b )d e
+--R               + 
+--R                            2         2   2 6         3          2  3 5
+--R                 (- 315A b c  - 315B b c)d e  + (30A c  + 90B b c )d e
+--R            *
+--R                5
+--R               m
+--R           + 
+--R                        3 8           2           3    7
+--R                 2864A b e  + (4347A b c + 1449B b )d e
+--R               + 
+--R                             2          2   2 6          3            2  3 5
+--R                 (- 2355A b c  - 2355B b c)d e  + (420A c  + 1260B b c )d e
+--R               + 
+--R                         3 4 4
+--R                 - 210B c d e
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                         3 8            2           3    7
+--R                 10993A b e  + (11244A b c + 3748B b )d e
+--R               + 
+--R                             2          2   2 6           3            2  3 5
+--R                 (- 7605A b c  - 7605B b c)d e  + (1770A c  + 5310B b c )d e
+--R               + 
+--R                          3 4 4
+--R                 - 1260B c d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                         3 8            2           3    7
+--R                 23312A b e  + (13716A b c + 4572B b )d e
+--R               + 
+--R                              2           2   2 6           3            2  3 5
+--R                 (- 10590A b c  - 10590B b c)d e  + (2820A c  + 8460B b c )d e
+--R               + 
+--R                          3 4 4
+--R                 - 2310B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                         3 8           2           3    7
+--R                 24876A b e  + (6048A b c + 2016B b )d e
+--R               + 
+--R                             2          2   2 6           3            2  3 5
+--R                 (- 5040A b c  - 5040B b c)d e  + (1440A c  + 4320B b c )d e
+--R               + 
+--R                          3 4 4
+--R                 - 1260B c d e
+--R            *
+--R               m
+--R           + 
+--R                     3 8
+--R             10080A b e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                3   7 7         3   7           2        3  2 6  6
+--R             A b d e m  + (29A b d e  + (- 12A b c - 4B b )d e )m
+--R           + 
+--R                       3   7            2         3  2 6
+--R                 331A b d e  + (- 288A b c - 96B b )d e
+--R               + 
+--R                         2        2   3 5
+--R                 (60A b c  + 60B b c)d e
+--R            *
+--R                5
+--R               m
+--R           + 
+--R                        3   7             2          3  2 6
+--R                 1871A b d e  + (- 2532A b c - 844B b )d e
+--R               + 
+--R                           2          2   3 5            3           2  4 4
+--R                 (1080A b c  + 1080B b c)d e  + (- 120A c  - 360B b c )d e
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                        3   7             2           3  2 6
+--R                 5380A b d e  + (- 9792A b c - 3264B b )d e
+--R               + 
+--R                           2          2   3 5             3            2  4 4
+--R                 (6180A b c  + 6180B b c)d e  + (- 1320A c  - 3960B b c )d e
+--R               + 
+--R                       3 5 3
+--R                 840B c d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                        3   7              2           3  2 6
+--R                 7172A b d e  + (- 15600A b c - 5200B b )d e
+--R               + 
+--R                            2           2   3 5             3            2  4 4
+--R                 (11880A b c  + 11880B b c)d e  + (- 3120A c  - 9360B b c )d e
+--R               + 
+--R                        3 5 3
+--R                 2520B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                        3   7             2           3  2 6
+--R                 3360A b d e  + (- 8064A b c - 2688B b )d e
+--R               + 
+--R                           2          2   3 5             3            2  4 4
+--R                 (6720A b c  + 6720B b c)d e  + (- 1920A c  - 5760B b c )d e
+--R               + 
+--R                        3 5 3
+--R                 1680B c d e
+--R            *
+--R               m
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                   3 2 6 6           3 2 6         2         3  3 5  5
+--R             - 3A b d e m  + (- 81A b d e  + (36A b c + 12B b )d e )m
+--R           + 
+--R                         3 2 6          2          3  3 5
+--R                 - 831A b d e  + (792A b c + 264B b )d e
+--R               + 
+--R                            2         2   4 4
+--R                 (- 180A b c  - 180B b c)d e
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                          3 2 6           2           3  3 5
+--R                 - 3951A b d e  + (6012A b c + 2004B b )d e
+--R               + 
+--R                             2          2   4 4          3            2  5 3
+--R                 (- 2880A b c  - 2880B b c)d e  + (360A c  + 1080B b c )d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                          3 2 6            2           3  3 5
+--R                 - 8238A b d e  + (17352A b c + 5784B b )d e
+--R               + 
+--R                              2           2   4 4           3            2  5 3
+--R                 (- 12780A b c  - 12780B b c)d e  + (3240A c  + 9720B b c )d e
+--R               + 
+--R                          3 6 2
+--R                 - 2520B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                          3 2 6            2           3  3 5
+--R                 - 5040A b d e  + (12096A b c + 4032B b )d e
+--R               + 
+--R                              2           2   4 4           3            2  5 3
+--R                 (- 10080A b c  - 10080B b c)d e  + (2880A c  + 8640B b c )d e
+--R               + 
+--R                          3 6 2
+--R                 - 2520B c d e
+--R            *
+--R               m
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                 3 3 5 5          3 3 5           2         3  4 4  4
+--R             6A b d e m  + (156A b d e  + (- 72A b c - 24B b )d e )m
+--R           + 
+--R                        3 3 5             2          3  4 4
+--R                 1506A b d e  + (- 1512A b c - 504B b )d e
+--R               + 
+--R                          2         2   5 3
+--R                 (360A b c  + 360B b c)d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                        3 3 5              2           3  4 4
+--R                 6396A b d e  + (- 10512A b c - 3504B b )d e
+--R               + 
+--R                           2          2   5 3            3            2  6 2
+--R                 (5400A b c  + 5400B b c)d e  + (- 720A c  - 2160B b c )d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                         3 3 5              2           3  4 4
+--R                 10080A b d e  + (- 24192A b c - 8064B b )d e
+--R               + 
+--R                            2           2   5 3             3             2  6 2
+--R                 (20160A b c  + 20160B b c)d e  + (- 5760A c  - 17280B b c )d e
+--R               + 
+--R                        3 7
+--R                 5040B c d e
+--R            *
+--R               m
+--R        *
+--R           x
+--R       + 
+--R               3 4 4 4            3 4 4         2         3  5 3  3
+--R         - 6A b d e m  + (- 156A b d e  + (72A b c + 24B b )d e )m
+--R       + 
+--R                      3 4 4           2          3  5 3
+--R             - 1506A b d e  + (1512A b c + 504B b )d e
+--R           + 
+--R                        2         2   6 2
+--R             (- 360A b c  - 360B b c)d e
+--R        *
+--R            2
+--R           m
+--R       + 
+--R                      3 4 4            2           3  5 3
+--R             - 6396A b d e  + (10512A b c + 3504B b )d e
+--R           + 
+--R                         2          2   6 2          3            2  7
+--R             (- 5400A b c  - 5400B b c)d e  + (720A c  + 2160B b c )d e
+--R        *
+--R           m
+--R       + 
+--R                   3 4 4            2           3  5 3
+--R         - 10080A b d e  + (24192A b c + 8064B b )d e
+--R       + 
+--R                      2           2   6 2           3             2  7
+--R         (- 20160A b c  - 20160B b c)d e  + (5760A c  + 17280B b c )d e
+--R       + 
+--R                  3 8
+--R         - 5040B c d
+--R    *
+--R         m log(e x + d)
+--R       %e
+--R  /
+--R        8 8      8 7       8 6        8 5         8 4         8 3          8 2
+--R       e m  + 36e m  + 546e m  + 4536e m  + 22449e m  + 67284e m  + 118124e m
+--R     + 
+--R              8          8
+--R       109584e m + 40320e
+--R                                         Type: Union(Expression(Integer),...)
+--E 123
+
+--S 124 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  3 8 7        3 8 6         3 8 5          3 8 4          3 8 3
+--R               B c e m  + 28B c e m  + 322B c e m  + 1960B c e m  + 6769B c e m
+--R             + 
+--R                       3 8 2           3 8           3 8
+--R               13132B c e m  + 13068B c e m + 5040B c e
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    3         2  8      3   7  7
+--R               ((A c  + 3B b c )e  + B c d e )m
+--R             + 
+--R                      3          2  8        3   7  6
+--R               ((29A c  + 87B b c )e  + 21B c d e )m
+--R             + 
+--R                       3            2  8         3   7  5
+--R               ((343A c  + 1029B b c )e  + 175B c d e )m
+--R             + 
+--R                        3            2  8         3   7  4
+--R               ((2135A c  + 6405B b c )e  + 735B c d e )m
+--R             + 
+--R                        3             2  8          3   7  3
+--R               ((7504A c  + 22512B b c )e  + 1624B c d e )m
+--R             + 
+--R                         3             2  8          3   7  2
+--R               ((14756A c  + 44268B b c )e  + 1764B c d e )m
+--R             + 
+--R                         3             2  8         3   7
+--R               ((14832A c  + 44496B b c )e  + 720B c d e )m
+--R             + 
+--R                       3             2  8
+--R               (5760A c  + 17280B b c )e
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                       2       2   8       3         2    7  7
+--R               ((3A b c  + 3B b c)e  + (A c  + 3B b c )d e )m
+--R             + 
+--R                        2        2   8         3          2    7       3 2 6  6
+--R               ((90A b c  + 90B b c)e  + (23A c  + 69B b c )d e  - 7B c d e )m
+--R             + 
+--R                             2          2   8          3           2    7
+--R                   (1098A b c  + 1098B b c)e  + (205A c  + 615B b c )d e
+--R                 + 
+--R                           3 2 6
+--R                   - 105B c d e
+--R              *
+--R                  5
+--R                 m
+--R             + 
+--R                             2          2   8          3            2    7
+--R                   (7020A b c  + 7020B b c)e  + (905A c  + 2715B b c )d e
+--R                 + 
+--R                           3 2 6
+--R                   - 595B c d e
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                              2           2   8           3            2    7
+--R                   (25227A b c  + 25227B b c)e  + (2074A c  + 6222B b c )d e
+--R                 + 
+--R                            3 2 6
+--R                   - 1575B c d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                              2           2   8           3            2    7
+--R                   (50490A b c  + 50490B b c)e  + (2312A c  + 6936B b c )d e
+--R                 + 
+--R                            3 2 6
+--R                   - 1918B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                              2           2   8          3            2    7
+--R                   (51432A b c  + 51432B b c)e  + (960A c  + 2880B b c )d e
+--R                 + 
+--R                           3 2 6
+--R                   - 840B c d e
+--R              *
+--R                 m
+--R             + 
+--R                          2           2   8
+--R               (20160A b c  + 20160B b c)e
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                     2       3  8          2       2     7  7
+--R               ((3A b c + B b )e  + (3A b c  + 3B b c)d e )m
+--R             + 
+--R                         2         3  8           2        2     7
+--R                   (93A b c + 31B b )e  + (75A b c  + 75B b c)d e
+--R                 + 
+--R                          3          2  2 6
+--R                   (- 6A c  - 18B b c )d e
+--R              *
+--R                  6
+--R                 m
+--R             + 
+--R                           2          3  8            2         2     7
+--R                   (1173A b c + 391B b )e  + (723A b c  + 723B b c)d e
+--R                 + 
+--R                            3           2  2 6        3 3 5
+--R                   (- 108A c  - 324B b c )d e  + 42B c d e
+--R              *
+--R                  5
+--R                 m
+--R             + 
+--R                           2           3  8             2          2     7
+--R                   (7743A b c + 2581B b )e  + (3405A b c  + 3405B b c)d e
+--R                 + 
+--R                            3            2  2 6         3 3 5
+--R                   (- 690A c  - 2070B b c )d e  + 420B c d e
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                            2           3  8             2          2     7
+--R                   (28632A b c + 9544B b )e  + (8202A b c  + 8202B b c)d e
+--R                 + 
+--R                             3            2  2 6          3 3 5
+--R                   (- 1980A c  - 5940B b c )d e  + 1470B c d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                            2            3  8             2          2     7
+--R                   (58692A b c + 19564B b )e  + (9480A b c  + 9480B b c)d e
+--R                 + 
+--R                             3            2  2 6          3 3 5
+--R                   (- 2544A c  - 7632B b c )d e  + 2100B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                            2            3  8             2          2     7
+--R                   (60912A b c + 20304B b )e  + (4032A b c  + 4032B b c)d e
+--R                 + 
+--R                             3            2  2 6          3 3 5
+--R                   (- 1152A c  - 3456B b c )d e  + 1008B c d e
+--R              *
+--R                 m
+--R             + 
+--R                        2           3  8
+--R               (24192A b c + 8064B b )e
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                   3 8        2       3    7  7
+--R               (A b e  + (3A b c + B b )d e )m
+--R             + 
+--R                          3 8         2         3    7
+--R                     32A b e  + (81A b c + 27B b )d e
+--R                   + 
+--R                               2        2   2 6
+--R                     (- 15A b c  - 15B b c)d e
+--R              *
+--R                  6
+--R                 m
+--R             + 
+--R                         3 8          2          3    7
+--R                   418A b e  + (849A b c + 283B b )d e
+--R                 + 
+--R                              2         2   2 6         3          2  3 5
+--R                   (- 315A b c  - 315B b c)d e  + (30A c  + 90B b c )d e
+--R              *
+--R                  5
+--R                 m
+--R             + 
+--R                          3 8           2           3    7
+--R                   2864A b e  + (4347A b c + 1449B b )d e
+--R                 + 
+--R                               2          2   2 6          3            2  3 5
+--R                   (- 2355A b c  - 2355B b c)d e  + (420A c  + 1260B b c )d e
+--R                 + 
+--R                           3 4 4
+--R                   - 210B c d e
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                           3 8            2           3    7
+--R                   10993A b e  + (11244A b c + 3748B b )d e
+--R                 + 
+--R                               2          2   2 6           3            2  3 5
+--R                   (- 7605A b c  - 7605B b c)d e  + (1770A c  + 5310B b c )d e
+--R                 + 
+--R                            3 4 4
+--R                   - 1260B c d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                           3 8            2           3    7
+--R                   23312A b e  + (13716A b c + 4572B b )d e
+--R                 + 
+--R                                2           2   2 6
+--R                   (- 10590A b c  - 10590B b c)d e
+--R                 + 
+--R                           3            2  3 5          3 4 4
+--R                   (2820A c  + 8460B b c )d e  - 2310B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                           3 8           2           3    7
+--R                   24876A b e  + (6048A b c + 2016B b )d e
+--R                 + 
+--R                               2          2   2 6           3            2  3 5
+--R                   (- 5040A b c  - 5040B b c)d e  + (1440A c  + 4320B b c )d e
+--R                 + 
+--R                            3 4 4
+--R                   - 1260B c d e
+--R              *
+--R                 m
+--R             + 
+--R                       3 8
+--R               10080A b e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                  3   7 7         3   7           2        3  2 6  6
+--R               A b d e m  + (29A b d e  + (- 12A b c - 4B b )d e )m
+--R             + 
+--R                         3   7            2         3  2 6
+--R                   331A b d e  + (- 288A b c - 96B b )d e
+--R                 + 
+--R                           2        2   3 5
+--R                   (60A b c  + 60B b c)d e
+--R              *
+--R                  5
+--R                 m
+--R             + 
+--R                          3   7             2          3  2 6
+--R                   1871A b d e  + (- 2532A b c - 844B b )d e
+--R                 + 
+--R                             2          2   3 5            3           2  4 4
+--R                   (1080A b c  + 1080B b c)d e  + (- 120A c  - 360B b c )d e
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                          3   7             2           3  2 6
+--R                   5380A b d e  + (- 9792A b c - 3264B b )d e
+--R                 + 
+--R                             2          2   3 5             3            2  4 4
+--R                   (6180A b c  + 6180B b c)d e  + (- 1320A c  - 3960B b c )d e
+--R                 + 
+--R                         3 5 3
+--R                   840B c d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                          3   7              2           3  2 6
+--R                   7172A b d e  + (- 15600A b c - 5200B b )d e
+--R                 + 
+--R                              2           2   3 5
+--R                   (11880A b c  + 11880B b c)d e
+--R                 + 
+--R                             3            2  4 4          3 5 3
+--R                   (- 3120A c  - 9360B b c )d e  + 2520B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                          3   7             2           3  2 6
+--R                   3360A b d e  + (- 8064A b c - 2688B b )d e
+--R                 + 
+--R                             2          2   3 5             3            2  4 4
+--R                   (6720A b c  + 6720B b c)d e  + (- 1920A c  - 5760B b c )d e
+--R                 + 
+--R                          3 5 3
+--R                   1680B c d e
+--R              *
+--R                 m
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     3 2 6 6           3 2 6         2         3  3 5  5
+--R               - 3A b d e m  + (- 81A b d e  + (36A b c + 12B b )d e )m
+--R             + 
+--R                           3 2 6          2          3  3 5
+--R                   - 831A b d e  + (792A b c + 264B b )d e
+--R                 + 
+--R                              2         2   4 4
+--R                   (- 180A b c  - 180B b c)d e
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                            3 2 6           2           3  3 5
+--R                   - 3951A b d e  + (6012A b c + 2004B b )d e
+--R                 + 
+--R                               2          2   4 4          3            2  5 3
+--R                   (- 2880A b c  - 2880B b c)d e  + (360A c  + 1080B b c )d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                            3 2 6            2           3  3 5
+--R                   - 8238A b d e  + (17352A b c + 5784B b )d e
+--R                 + 
+--R                                2           2   4 4
+--R                   (- 12780A b c  - 12780B b c)d e
+--R                 + 
+--R                           3            2  5 3          3 6 2
+--R                   (3240A c  + 9720B b c )d e  - 2520B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                            3 2 6            2           3  3 5
+--R                   - 5040A b d e  + (12096A b c + 4032B b )d e
+--R                 + 
+--R                                2           2   4 4
+--R                   (- 10080A b c  - 10080B b c)d e
+--R                 + 
+--R                           3            2  5 3          3 6 2
+--R                   (2880A c  + 8640B b c )d e  - 2520B c d e
+--R              *
+--R                 m
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   3 3 5 5          3 3 5           2         3  4 4  4
+--R               6A b d e m  + (156A b d e  + (- 72A b c - 24B b )d e )m
+--R             + 
+--R                          3 3 5             2          3  4 4
+--R                   1506A b d e  + (- 1512A b c - 504B b )d e
+--R                 + 
+--R                            2         2   5 3
+--R                   (360A b c  + 360B b c)d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                          3 3 5              2           3  4 4
+--R                   6396A b d e  + (- 10512A b c - 3504B b )d e
+--R                 + 
+--R                             2          2   5 3            3            2  6 2
+--R                   (5400A b c  + 5400B b c)d e  + (- 720A c  - 2160B b c )d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                           3 3 5              2           3  4 4
+--R                   10080A b d e  + (- 24192A b c - 8064B b )d e
+--R                 + 
+--R                              2           2   5 3
+--R                   (20160A b c  + 20160B b c)d e
+--R                 + 
+--R                             3             2  6 2          3 7
+--R                   (- 5760A c  - 17280B b c )d e  + 5040B c d e
+--R              *
+--R                 m
+--R          *
+--R             x
+--R         + 
+--R                 3 4 4 4            3 4 4         2         3  5 3  3
+--R           - 6A b d e m  + (- 156A b d e  + (72A b c + 24B b )d e )m
+--R         + 
+--R                        3 4 4           2          3  5 3
+--R               - 1506A b d e  + (1512A b c + 504B b )d e
+--R             + 
+--R                          2         2   6 2
+--R               (- 360A b c  - 360B b c)d e
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                        3 4 4            2           3  5 3
+--R               - 6396A b d e  + (10512A b c + 3504B b )d e
+--R             + 
+--R                           2          2   6 2          3            2  7
+--R               (- 5400A b c  - 5400B b c)d e  + (720A c  + 2160B b c )d e
+--R          *
+--R             m
+--R         + 
+--R                     3 4 4            2           3  5 3
+--R           - 10080A b d e  + (24192A b c + 8064B b )d e
+--R         + 
+--R                        2           2   6 2           3             2  7
+--R           (- 20160A b c  - 20160B b c)d e  + (5760A c  + 17280B b c )d e
+--R         + 
+--R                    3 8
+--R           - 5040B c d
+--R      *
+--R           m log(e x + d)
+--R         %e
+--R     + 
+--R                3 7        3 6         3 5          3 4          3 3
+--R           - B c m  - 28B c m  - 322B c m  - 1960B c m  - 6769B c m
+--R         + 
+--R                     3 2           3           3
+--R           - 13132B c m  - 13068B c m - 5040B c
+--R      *
+--R                  m + 8
+--R         (e x + d)
+--R     + 
+--R                  3         2         3   7
+--R           ((- A c  - 3B b c )e + 7B c d)m
+--R         + 
+--R                    3          2           3   6
+--R           ((- 29A c  - 87B b c )e + 203B c d)m
+--R         + 
+--R                     3            2            3   5
+--R           ((- 343A c  - 1029B b c )e + 2401B c d)m
+--R         + 
+--R                      3            2             3   4
+--R           ((- 2135A c  - 6405B b c )e + 14945B c d)m
+--R         + 
+--R                      3             2             3   3
+--R           ((- 7504A c  - 22512B b c )e + 52528B c d)m
+--R         + 
+--R                       3             2              3   2
+--R           ((- 14756A c  - 44268B b c )e + 103292B c d)m
+--R         + 
+--R                       3             2              3
+--R           ((- 14832A c  - 44496B b c )e + 103824B c d)m
+--R         + 
+--R                     3             2             3
+--R           (- 5760A c  - 17280B b c )e + 40320B c d
+--R      *
+--R                  m + 7
+--R         (e x + d)
+--R     + 
+--R                     2       2   2        3          2            3 2  7
+--R           ((- 3A b c  - 3B b c)e  + (6A c  + 18B b c )d e - 21B c d )m
+--R         + 
+--R                      2        2   2          3           2             3 2  6
+--R           ((- 90A b c  - 90B b c)e  + (180A c  + 540B b c )d e - 630B c d )m
+--R         + 
+--R                           2          2   2           3            2
+--R               (- 1098A b c  - 1098B b c)e  + (2196A c  + 6588B b c )d e
+--R             + 
+--R                        3 2
+--R               - 7686B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                           2          2   2            3             2
+--R               (- 7020A b c  - 7020B b c)e  + (14040A c  + 42120B b c )d e
+--R             + 
+--R                         3 2
+--R               - 49140B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                            2           2   2            3              2
+--R               (- 25227A b c  - 25227B b c)e  + (50454A c  + 151362B b c )d e
+--R             + 
+--R                          3 2
+--R               - 176589B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                            2           2   2             3              2
+--R               (- 50490A b c  - 50490B b c)e  + (100980A c  + 302940B b c )d e
+--R             + 
+--R                          3 2
+--R               - 353430B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                            2           2   2             3              2
+--R               (- 51432A b c  - 51432B b c)e  + (102864A c  + 308592B b c )d e
+--R             + 
+--R                          3 2
+--R               - 360024B c d
+--R          *
+--R             m
+--R         + 
+--R                        2           2   2            3              2
+--R           (- 20160A b c  - 20160B b c)e  + (40320A c  + 120960B b c )d e
+--R         + 
+--R                      3 2
+--R           - 141120B c d
+--R      *
+--R                  m + 6
+--R         (e x + d)
+--R     + 
+--R                      2       3  3           2        2     2
+--R               (- 3A b c - B b )e  + (15A b c  + 15B b c)d e
+--R             + 
+--R                       3          2  2         3 3
+--R               (- 15A c  - 45B b c )d e + 35B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                       2         3  3            2         2     2
+--R               (- 93A b c - 31B b )e  + (465A b c  + 465B b c)d e
+--R             + 
+--R                        3            2  2           3 3
+--R               (- 465A c  - 1395B b c )d e + 1085B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                         2          3  3             2          2     2
+--R               (- 1173A b c - 391B b )e  + (5865A b c  + 5865B b c)d e
+--R             + 
+--R                         3             2  2            3 3
+--R               (- 5865A c  - 17595B b c )d e + 13685B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                         2           3  3              2           2     2
+--R               (- 7743A b c - 2581B b )e  + (38715A b c  + 38715B b c)d e
+--R             + 
+--R                          3              2  2            3 3
+--R               (- 38715A c  - 116145B b c )d e + 90335B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                          2           3  3               2            2     2
+--R               (- 28632A b c - 9544B b )e  + (143160A b c  + 143160B b c)d e
+--R             + 
+--R                           3              2  2             3 3
+--R               (- 143160A c  - 429480B b c )d e + 334040B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                          2            3  3               2            2     2
+--R               (- 58692A b c - 19564B b )e  + (293460A b c  + 293460B b c)d e
+--R             + 
+--R                           3              2  2             3 3
+--R               (- 293460A c  - 880380B b c )d e + 684740B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                          2            3  3               2            2     2
+--R               (- 60912A b c - 20304B b )e  + (304560A b c  + 304560B b c)d e
+--R             + 
+--R                           3              2  2             3 3
+--R               (- 304560A c  - 913680B b c )d e + 710640B c d
+--R          *
+--R             m
+--R         + 
+--R                      2           3  3               2            2     2
+--R           (- 24192A b c - 8064B b )e  + (120960A b c  + 120960B b c)d e
+--R         + 
+--R                       3              2  2             3 3
+--R           (- 120960A c  - 362880B b c )d e + 282240B c d
+--R      *
+--R                  m + 5
+--R         (e x + d)
+--R     + 
+--R                    3 4         2        3    3             2        2   2 2
+--R               - A b e  + (12A b c + 4B b )d e  + (- 30A b c  - 30B b c)d e
+--R             + 
+--R                     3          2  3         3 4
+--R               (20A c  + 60B b c )d e - 35B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                      3 4          2          3    3
+--R               - 32A b e  + (384A b c + 128B b )d e
+--R             + 
+--R                          2         2   2 2          3            2  3
+--R               (- 960A b c  - 960B b c)d e  + (640A c  + 1920B b c )d e
+--R             + 
+--R                        3 4
+--R               - 1120B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                       3 4           2           3    3
+--R               - 418A b e  + (5016A b c + 1672B b )d e
+--R             + 
+--R                            2           2   2 2           3             2  3
+--R               (- 12540A b c  - 12540B b c)d e  + (8360A c  + 25080B b c )d e
+--R             + 
+--R                         3 4
+--R               - 14630B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                        3 4            2            3    3
+--R               - 2864A b e  + (34368A b c + 11456B b )d e
+--R             + 
+--R                            2           2   2 2            3              2  3
+--R               (- 85920A b c  - 85920B b c)d e  + (57280A c  + 171840B b c )d e
+--R             + 
+--R                          3 4
+--R               - 100240B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                         3 4             2            3    3
+--R               - 10993A b e  + (131916A b c + 43972B b )d e
+--R             + 
+--R                             2            2   2 2
+--R               (- 329790A b c  - 329790B b c)d e
+--R             + 
+--R                         3              2  3             3 4
+--R               (219860A c  + 659580B b c )d e - 384755B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                         3 4             2            3    3
+--R               - 23312A b e  + (279744A b c + 93248B b )d e
+--R             + 
+--R                             2            2   2 2
+--R               (- 699360A b c  - 699360B b c)d e
+--R             + 
+--R                         3               2  3             3 4
+--R               (466240A c  + 1398720B b c )d e - 815920B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                         3 4             2            3    3
+--R               - 24876A b e  + (298512A b c + 99504B b )d e
+--R             + 
+--R                             2            2   2 2
+--R               (- 746280A b c  - 746280B b c)d e
+--R             + 
+--R                         3               2  3             3 4
+--R               (497520A c  + 1492560B b c )d e - 870660B c d
+--R          *
+--R             m
+--R         + 
+--R                     3 4             2            3    3
+--R           - 10080A b e  + (120960A b c + 40320B b )d e
+--R         + 
+--R                         2            2   2 2             3              2  3
+--R           (- 302400A b c  - 302400B b c)d e  + (201600A c  + 604800B b c )d e
+--R         + 
+--R                      3 4
+--R           - 352800B c d
+--R      *
+--R                  m + 4
+--R         (e x + d)
+--R     + 
+--R                   3   4           2        3  2 3           2        2   3 2
+--R               3A b d e  + (- 18A b c - 6B b )d e  + (30A b c  + 30B b c)d e
+--R             + 
+--R                       3          2  4         3 5
+--R               (- 15A c  - 45B b c )d e + 21B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                    3   4            2          3  2 3
+--R               99A b d e  + (- 594A b c - 198B b )d e
+--R             + 
+--R                        2         2   3 2            3            2  4
+--R               (990A b c  + 990B b c)d e  + (- 495A c  - 1485B b c )d e
+--R             + 
+--R                     3 5
+--R               693B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                      3   4             2           3  2 3
+--R               1341A b d e  + (- 8046A b c - 2682B b )d e
+--R             + 
+--R                          2           2   3 2             3             2  4
+--R               (13410A b c  + 13410B b c)d e  + (- 6705A c  - 20115B b c )d e
+--R             + 
+--R                      3 5
+--R               9387B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                      3   4              2            3  2 3
+--R               9585A b d e  + (- 57510A b c - 19170B b )d e
+--R             + 
+--R                          2           2   3 2              3              2  4
+--R               (95850A b c  + 95850B b c)d e  + (- 47925A c  - 143775B b c )d e
+--R             + 
+--R                       3 5
+--R               67095B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       3   4               2            3  2 3
+--R               38592A b d e  + (- 231552A b c - 77184B b )d e
+--R             + 
+--R                           2            2   3 2
+--R               (385920A b c  + 385920B b c)d e
+--R             + 
+--R                           3              2  4             3 5
+--R               (- 192960A c  - 578880B b c )d e + 270144B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       3   4               2             3  2 3
+--R               86076A b d e  + (- 516456A b c - 172152B b )d e
+--R             + 
+--R                           2            2   3 2
+--R               (860760A b c  + 860760B b c)d e
+--R             + 
+--R                           3               2  4             3 5
+--R               (- 430380A c  - 1291140B b c )d e + 602532B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                       3   4               2             3  2 3
+--R               96144A b d e  + (- 576864A b c - 192288B b )d e
+--R             + 
+--R                           2            2   3 2
+--R               (961440A b c  + 961440B b c)d e
+--R             + 
+--R                           3               2  4             3 5
+--R               (- 480720A c  - 1442160B b c )d e + 673008B c d
+--R          *
+--R             m
+--R         + 
+--R                   3   4               2            3  2 3
+--R           40320A b d e  + (- 241920A b c - 80640B b )d e
+--R         + 
+--R                       2            2   3 2               3              2  4
+--R           (403200A b c  + 403200B b c)d e  + (- 201600A c  - 604800B b c )d e
+--R         + 
+--R                    3 5
+--R           282240B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                     3 2 4         2        3  3 3             2        2   4 2
+--R               - 3A b d e  + (12A b c + 4B b )d e  + (- 15A b c  - 15B b c)d e
+--R             + 
+--R                    3          2  5        3 6
+--R               (6A c  + 18B b c )d e - 7B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                       3 2 4          2          3  3 3
+--R               - 102A b d e  + (408A b c + 136B b )d e
+--R             + 
+--R                        2         2   4 2          3           2  5          3 6
+--R             (- 510A b c  - 510B b c)d e  + (204A c  + 612B b c )d e - 238B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                        3 2 4           2           3  3 3
+--R               - 1434A b d e  + (5736A b c + 1912B b )d e
+--R             + 
+--R                           2          2   4 2           3            2  5
+--R               (- 7170A b c  - 7170B b c)d e  + (2868A c  + 8604B b c )d e
+--R             + 
+--R                        3 6
+--R               - 3346B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                         3 2 4            2            3  3 3
+--R               - 10740A b d e  + (42960A b c + 14320B b )d e
+--R             + 
+--R                            2           2   4 2            3             2  5
+--R               (- 53700A b c  - 53700B b c)d e  + (21480A c  + 64440B b c )d e
+--R             + 
+--R                         3 6
+--R               - 25060B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                         3 2 4             2            3  3 3
+--R               - 45867A b d e  + (183468A b c + 61156B b )d e
+--R             + 
+--R                             2            2   4 2
+--R               (- 229335A b c  - 229335B b c)d e
+--R             + 
+--R                        3              2  5             3 6
+--R               (91734A c  + 275202B b c )d e - 107023B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                          3 2 4             2             3  3 3
+--R               - 110118A b d e  + (440472A b c + 146824B b )d e
+--R             + 
+--R                             2            2   4 2
+--R               (- 550590A b c  - 550590B b c)d e
+--R             + 
+--R                         3              2  5             3 6
+--R               (220236A c  + 660708B b c )d e - 256942B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                          3 2 4             2             3  3 3
+--R               - 134136A b d e  + (536544A b c + 178848B b )d e
+--R             + 
+--R                             2            2   4 2
+--R               (- 670680A b c  - 670680B b c)d e
+--R             + 
+--R                         3              2  5             3 6
+--R               (268272A c  + 804816B b c )d e - 312984B c d
+--R          *
+--R             m
+--R         + 
+--R                     3 2 4             2            3  3 3
+--R           - 60480A b d e  + (241920A b c + 80640B b )d e
+--R         + 
+--R                         2            2   4 2             3              2  5
+--R           (- 302400A b c  - 302400B b c)d e  + (120960A c  + 362880B b c )d e
+--R         + 
+--R                      3 6
+--R           - 141120B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R                  3 3 4          2       3  4 3          2       2   5 2
+--R               A b d e  + (- 3A b c - B b )d e  + (3A b c  + 3B b c)d e
+--R             + 
+--R                     3         2  6       3 7
+--R               (- A c  - 3B b c )d e + B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                    3 3 4            2         3  4 3
+--R               35A b d e  + (- 105A b c - 35B b )d e
+--R             + 
+--R                      2         2   5 2           3           2  6         3 7
+--R             (105A b c  + 105B b c)d e  + (- 35A c  - 105B b c )d e + 35B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                     3 3 4             2          3  4 3
+--R               511A b d e  + (- 1533A b c - 511B b )d e
+--R             + 
+--R                         2          2   5 2            3            2  6
+--R               (1533A b c  + 1533B b c)d e  + (- 511A c  - 1533B b c )d e
+--R             + 
+--R                     3 7
+--R               511B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                      3 3 4              2           3  4 3
+--R               4025A b d e  + (- 12075A b c - 4025B b )d e
+--R             + 
+--R                          2           2   5 2             3             2  6
+--R               (12075A b c  + 12075B b c)d e  + (- 4025A c  - 12075B b c )d e
+--R             + 
+--R                      3 7
+--R               4025B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       3 3 4              2            3  4 3
+--R               18424A b d e  + (- 55272A b c - 18424B b )d e
+--R             + 
+--R                          2           2   5 2              3             2  6
+--R               (55272A b c  + 55272B b c)d e  + (- 18424A c  - 55272B b c )d e
+--R             + 
+--R                       3 7
+--R               18424B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       3 3 4               2            3  4 3
+--R               48860A b d e  + (- 146580A b c - 48860B b )d e
+--R             + 
+--R                           2            2   5 2
+--R               (146580A b c  + 146580B b c)d e
+--R             + 
+--R                          3              2  6            3 7
+--R               (- 48860A c  - 146580B b c )d e + 48860B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                       3 3 4               2            3  4 3
+--R               69264A b d e  + (- 207792A b c - 69264B b )d e
+--R             + 
+--R                           2            2   5 2
+--R               (207792A b c  + 207792B b c)d e
+--R             + 
+--R                          3              2  6            3 7
+--R               (- 69264A c  - 207792B b c )d e + 69264B c d
+--R          *
+--R             m
+--R         + 
+--R                   3 3 4               2            3  4 3
+--R           40320A b d e  + (- 120960A b c - 40320B b )d e
+--R         + 
+--R                       2            2   5 2              3              2  6
+--R           (120960A b c  + 120960B b c)d e  + (- 40320A c  - 120960B b c )d e
+--R         + 
+--R                   3 7
+--R           40320B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R        8 8      8 7       8 6        8 5         8 4         8 3          8 2
+--R       e m  + 36e m  + 546e m  + 4536e m  + 22449e m  + 67284e m  + 118124e m
+--R     + 
+--R              8          8
+--R       109584e m + 40320e
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 1457
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 125
+
+)clear all
+
+--S 126 of 1457
+t0:=(A+B*x)*(d+e*x)^4*(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3 4 11        3         2  4       3   3  10
+--R     B c e x   + ((A c  + 3B b c )e  + 4B c d e )x
+--R   + 
+--R             2       2   4        3          2    3       3 2 2  9
+--R     ((3A b c  + 3B b c)e  + (4A c  + 12B b c )d e  + 6B c d e )x
+--R   + 
+--R              2       3  4           2        2     3        3          2  2 2
+--R         (3A b c + B b )e  + (12A b c  + 12B b c)d e  + (6A c  + 18B b c )d e
+--R       + 
+--R             3 3
+--R         4B c d e
+--R    *
+--R        8
+--R       x
+--R   + 
+--R            3 4         2        3    3           2        2   2 2
+--R         A b e  + (12A b c + 4B b )d e  + (18A b c  + 18B b c)d e
+--R       + 
+--R              3          2  3       3 4
+--R         (4A c  + 12B b c )d e + B c d
+--R    *
+--R        7
+--R       x
+--R   + 
+--R             3   3         2        3  2 2           2        2   3
+--R         4A b d e  + (18A b c + 6B b )d e  + (12A b c  + 12B b c)d e
+--R       + 
+--R             3         2  4
+--R         (A c  + 3B b c )d
+--R    *
+--R        6
+--R       x
+--R   + 
+--R          3 2 2         2        3  3           2       2   4  5
+--R     (6A b d e  + (12A b c + 4B b )d e + (3A b c  + 3B b c)d )x
+--R   + 
+--R          3 3         2       3  4  4      3 4 3
+--R     (4A b d e + (3A b c + B b )d )x  + A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 126
+
+--S 127 of 1457
+r0:=1/4*A*b^3*d^4*x^4+1/5*b^2*d^3*(b*B*d+3*A*c*d+4*A*b*e)*x^5+1/6*b*d^2*_
+     (3*A*c^2*d^2+2*b^2*e*(2*B*d+3*A*e)+3*b*c*d*(B*d+4*A*e))*x^6+1/7*d*_
+     (A*c^3*d^3+2*b^3*e^2*(3*B*d+2*A*e)+6*b^2*c*d*e*(2*B*d+3*A*e)+3*b*_
+     c^2*d^2*(B*d+4*A*e))*x^7+1/8*(A*e*(4*c^3*d^3+18*b*c^2*d^2*e+12*_
+     b^2*c*d*e^2+b^3*e^3)+B*d*(c^3*d^3+12*b*c^2*d^2*e+18*b^2*c*d*e^2+4*_
+     b^3*e^3))*x^8+1/9*e*(3*A*c*e*(2*c^2*d^2+4*b*c*d*e+b^2*e^2)+B*_
+     (4*c^3*d^3+18*b*c^2*d^2*e+12*b^2*c*d*e^2+b^3*e^3))*x^9+1/10*c*e^2*_
+     (A*c*e*(4*c*d+3*b*e)+3*B*(2*c^2*d^2+4*b*c*d*e+b^2*e^2))*x^10+1/11*_
+     c^2*e^3*(4*B*c*d+3*b*B*e+A*c*e)*x^11+1/12*B*c^3*e^4*x^12
+--R 
+--R
+--R   (2)
+--R      1    3 4 12      1    3    3      2  4    4    3   3  11
+--R     -- B c e x   + ((-- A c  + -- B b c )e  + -- B c d e )x
+--R     12               11        11             11
+--R   + 
+--R        3      2    3    2   4    2    3   6      2    3   3    3 2 2  10
+--R     ((-- A b c  + -- B b c)e  + (- A c  + - B b c )d e  + - B c d e )x
+--R       10          10             5        5               5
+--R   + 
+--R          1    2    1    3  4    4      2   4    2     3
+--R         (- A b c + - B b )e  + (- A b c  + - B b c)d e
+--R          3         9            3          3
+--R       + 
+--R          2    3         2  2 2   4    3 3
+--R         (- A c  + 2B b c )d e  + - B c d e
+--R          3                       9
+--R    *
+--R        9
+--R       x
+--R   + 
+--R         1    3 4    3    2    1    3    3    9      2   9    2   2 2
+--R         - A b e  + (- A b c + - B b )d e  + (- A b c  + - B b c)d e
+--R         8           2         2              4          4
+--R       + 
+--R          1    3   3      2  3    1    3 4
+--R         (- A c  + - B b c )d e + - B c d
+--R          2        2              8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R         4    3   3    18    2    6    3  2 2    12      2   12    2   3
+--R         - A b d e  + (-- A b c + - B b )d e  + (-- A b c  + -- B b c)d e
+--R         7              7         7               7           7
+--R       + 
+--R          1    3   3      2  4
+--R         (- A c  + - B b c )d
+--R          7        7
+--R    *
+--R        7
+--R       x
+--R   + 
+--R         3 2 2        2    2    3  3     1      2   1    2   4  6
+--R     (A b d e  + (2A b c + - B b )d e + (- A b c  + - B b c)d )x
+--R                           3             2          2
+--R   + 
+--R      4    3 3     3    2    1    3  4  5   1    3 4 4
+--R     (- A b d e + (- A b c + - B b )d )x  + - A b d x
+--R      5            5         5              4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 127
+
+--S 128 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    3 4 12      1    3    3      2  4    4    3   3  11
+--R     -- B c e x   + ((-- A c  + -- B b c )e  + -- B c d e )x
+--R     12               11        11             11
+--R   + 
+--R        3      2    3    2   4    2    3   6      2    3   3    3 2 2  10
+--R     ((-- A b c  + -- B b c)e  + (- A c  + - B b c )d e  + - B c d e )x
+--R       10          10             5        5               5
+--R   + 
+--R          1    2    1    3  4    4      2   4    2     3
+--R         (- A b c + - B b )e  + (- A b c  + - B b c)d e
+--R          3         9            3          3
+--R       + 
+--R          2    3         2  2 2   4    3 3
+--R         (- A c  + 2B b c )d e  + - B c d e
+--R          3                       9
+--R    *
+--R        9
+--R       x
+--R   + 
+--R         1    3 4    3    2    1    3    3    9      2   9    2   2 2
+--R         - A b e  + (- A b c + - B b )d e  + (- A b c  + - B b c)d e
+--R         8           2         2              4          4
+--R       + 
+--R          1    3   3      2  3    1    3 4
+--R         (- A c  + - B b c )d e + - B c d
+--R          2        2              8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R         4    3   3    18    2    6    3  2 2    12      2   12    2   3
+--R         - A b d e  + (-- A b c + - B b )d e  + (-- A b c  + -- B b c)d e
+--R         7              7         7               7           7
+--R       + 
+--R          1    3   3      2  4
+--R         (- A c  + - B b c )d
+--R          7        7
+--R    *
+--R        7
+--R       x
+--R   + 
+--R         3 2 2        2    2    3  3     1      2   1    2   4  6
+--R     (A b d e  + (2A b c + - B b )d e + (- A b c  + - B b c)d )x
+--R                           3             2          2
+--R   + 
+--R      4    3 3     3    2    1    3  4  5   1    3 4 4
+--R     (- A b d e + (- A b c + - B b )d )x  + - A b d x
+--R      5            5         5              4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 128
+
+--S 129 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 129
+
+--S 130 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 130
+
+)clear all
+
+--S 131 of 1457
+t0:=(A+B*x)*(d+e*x)^3*(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3 3 10        3         2  3       3   2  9
+--R     B c e x   + ((A c  + 3B b c )e  + 3B c d e )x
+--R   + 
+--R             2       2   3        3         2    2       3 2   8
+--R     ((3A b c  + 3B b c)e  + (3A c  + 9B b c )d e  + 3B c d e)x
+--R   + 
+--R              2       3  3          2       2     2        3         2  2
+--R         (3A b c + B b )e  + (9A b c  + 9B b c)d e  + (3A c  + 9B b c )d e
+--R       + 
+--R            3 3
+--R         B c d
+--R    *
+--R        7
+--R       x
+--R   + 
+--R            3 3        2        3    2          2       2   2
+--R         A b e  + (9A b c + 3B b )d e  + (9A b c  + 9B b c)d e
+--R       + 
+--R             3         2  3
+--R         (A c  + 3B b c )d
+--R    *
+--R        6
+--R       x
+--R   + 
+--R          3   2        2        3  2           2       2   3  5
+--R     (3A b d e  + (9A b c + 3B b )d e + (3A b c  + 3B b c)d )x
+--R   + 
+--R          3 2         2       3  3  4      3 3 3
+--R     (3A b d e + (3A b c + B b )d )x  + A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 131
+
+--S 132 of 1457
+r0:=1/4*A*b^3*d^3*x^4+1/5*b^2*d^2*(b*B*d+3*A*c*d+3*A*b*e)*x^5+1/2*b*d*_
+     (A*c^2*d^2+b^2*e*(B*d+A*e)+b*c*d*(B*d+3*A*e))*x^6+1/7*(A*c^3*d^3+_
+     9*b^2*c*d*e*(B*d+A*e)+b^3*e^2*(3*B*d+A*e)+3*b*c^2*d^2*(B*d+3*A*e))*_
+     x^7+1/8*(3*A*c*e*(c^2*d^2+3*b*c*d*e+b^2*e^2)+B*(c^3*d^3+9*b*c^2*d^2*e+_
+     9*b^2*c*d*e^2+b^3*e^3))*x^8+1/3*c*e*(A*c*e*(c*d+b*e)+B*(c^2*d^2+_
+     3*b*c*d*e+b^2*e^2))*x^9+1/10*c^2*e^2*(A*c*e+3*B*(c*d+b*e))*x^10+_
+     1/11*B*c^3*e^3*x^11
+--R 
+--R
+--R   (2)
+--R      1    3 3 11      1    3    3      2  3    3    3   2  10
+--R     -- B c e x   + ((-- A c  + -- B b c )e  + -- B c d e )x
+--R     11               10        10             10
+--R   + 
+--R       1      2   1    2   3    1    3        2    2   1    3 2   9
+--R     ((- A b c  + - B b c)e  + (- A c  + B b c )d e  + - B c d e)x
+--R       3          3             3                      3
+--R   + 
+--R          3    2    1    3  3    9      2   9    2     2
+--R         (- A b c + - B b )e  + (- A b c  + - B b c)d e
+--R          8         8            8          8
+--R       + 
+--R          3    3   9      2  2    1    3 3
+--R         (- A c  + - B b c )d e + - B c d
+--R          8        8              8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R         1    3 3    9    2    3    3    2    9      2   9    2   2
+--R         - A b e  + (- A b c + - B b )d e  + (- A b c  + - B b c)d e
+--R         7           7         7              7          7
+--R       + 
+--R          1    3   3      2  3
+--R         (- A c  + - B b c )d
+--R          7        7
+--R    *
+--R        7
+--R       x
+--R   + 
+--R      1    3   2    3    2    1    3  2     1      2   1    2   3  6
+--R     (- A b d e  + (- A b c + - B b )d e + (- A b c  + - B b c)d )x
+--R      2             2         2             2          2
+--R   + 
+--R      3    3 2     3    2    1    3  3  5   1    3 3 4
+--R     (- A b d e + (- A b c + - B b )d )x  + - A b d x
+--R      5            5         5              4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 132
+
+--S 133 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    3 3 11      1    3    3      2  3    3    3   2  10
+--R     -- B c e x   + ((-- A c  + -- B b c )e  + -- B c d e )x
+--R     11               10        10             10
+--R   + 
+--R       1      2   1    2   3    1    3        2    2   1    3 2   9
+--R     ((- A b c  + - B b c)e  + (- A c  + B b c )d e  + - B c d e)x
+--R       3          3             3                      3
+--R   + 
+--R          3    2    1    3  3    9      2   9    2     2
+--R         (- A b c + - B b )e  + (- A b c  + - B b c)d e
+--R          8         8            8          8
+--R       + 
+--R          3    3   9      2  2    1    3 3
+--R         (- A c  + - B b c )d e + - B c d
+--R          8        8              8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R         1    3 3    9    2    3    3    2    9      2   9    2   2
+--R         - A b e  + (- A b c + - B b )d e  + (- A b c  + - B b c)d e
+--R         7           7         7              7          7
+--R       + 
+--R          1    3   3      2  3
+--R         (- A c  + - B b c )d
+--R          7        7
+--R    *
+--R        7
+--R       x
+--R   + 
+--R      1    3   2    3    2    1    3  2     1      2   1    2   3  6
+--R     (- A b d e  + (- A b c + - B b )d e + (- A b c  + - B b c)d )x
+--R      2             2         2             2          2
+--R   + 
+--R      3    3 2     3    2    1    3  3  5   1    3 3 4
+--R     (- A b d e + (- A b c + - B b )d )x  + - A b d x
+--R      5            5         5              4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 133
+
+--S 134 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 134
+
+--S 135 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 135
+
+)clear all
+
+--S 136 of 1457
+t0:=(A+B*x)*(d+e*x)^2*(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3 2 9        3         2  2       3     8
+--R     B c e x  + ((A c  + 3B b c )e  + 2B c d e)x
+--R   + 
+--R             2       2   2        3         2          3 2  7
+--R     ((3A b c  + 3B b c)e  + (2A c  + 6B b c )d e + B c d )x
+--R   + 
+--R           2       3  2          2       2            3         2  2  6
+--R     ((3A b c + B b )e  + (6A b c  + 6B b c)d e + (A c  + 3B b c )d )x
+--R   + 
+--R         3 2        2        3              2       2   2  5
+--R     (A b e  + (6A b c + 2B b )d e + (3A b c  + 3B b c)d )x
+--R   + 
+--R          3           2       3  2  4      3 2 3
+--R     (2A b d e + (3A b c + B b )d )x  + A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 136
+
+--S 137 of 1457
+r0:=1/4*A*b^3*d^2*x^4+1/5*b^2*d*(b*B*d+3*A*c*d+2*A*b*e)*x^5+1/6*b*_
+     (3*A*c^2*d^2+b^2*e*(2*B*d+A*e)+3*b*c*d*(B*d+2*A*e))*x^6+1/7*_
+     (A*c^3*d^2+b^3*B*e^2+3*b^2*c*e*(2*B*d+A*e)+3*b*c^2*d*(B*d+2*A*e))*x^7+_
+     1/8*c*(A*c*e*(2*c*d+3*b*e)+B*(c^2*d^2+6*b*c*d*e+3*b^2*e^2))*x^8+_
+     1/9*c^2*e*(2*B*c*d+3*b*B*e+A*c*e)*x^9+1/10*B*c^3*e^2*x^10
+--R 
+--R
+--R   (2)
+--R      1    3 2 10     1    3   1      2  2   2    3     9
+--R     -- B c e x   + ((- A c  + - B b c )e  + - B c d e)x
+--R     10               9        3             9
+--R   + 
+--R       3      2   3    2   2    1    3   3      2       1    3 2  8
+--R     ((- A b c  + - B b c)e  + (- A c  + - B b c )d e + - B c d )x
+--R       8          8             4        4              8
+--R   + 
+--R       3    2    1    3  2    6      2   6    2         1    3   3      2  2  7
+--R     ((- A b c + - B b )e  + (- A b c  + - B b c)d e + (- A c  + - B b c )d )x
+--R       7         7            7          7              7        7
+--R   + 
+--R      1    3 2       2    1    3        1      2   1    2   2  6
+--R     (- A b e  + (A b c + - B b )d e + (- A b c  + - B b c)d )x
+--R      6                   3             2          2
+--R   + 
+--R      2    3       3    2    1    3  2  5   1    3 2 4
+--R     (- A b d e + (- A b c + - B b )d )x  + - A b d x
+--R      5            5         5              4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 137
+
+--S 138 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    3 2 10     1    3   1      2  2   2    3     9
+--R     -- B c e x   + ((- A c  + - B b c )e  + - B c d e)x
+--R     10               9        3             9
+--R   + 
+--R       3      2   3    2   2    1    3   3      2       1    3 2  8
+--R     ((- A b c  + - B b c)e  + (- A c  + - B b c )d e + - B c d )x
+--R       8          8             4        4              8
+--R   + 
+--R       3    2    1    3  2    6      2   6    2         1    3   3      2  2  7
+--R     ((- A b c + - B b )e  + (- A b c  + - B b c)d e + (- A c  + - B b c )d )x
+--R       7         7            7          7              7        7
+--R   + 
+--R      1    3 2       2    1    3        1      2   1    2   2  6
+--R     (- A b e  + (A b c + - B b )d e + (- A b c  + - B b c)d )x
+--R      6                   3             2          2
+--R   + 
+--R      2    3       3    2    1    3  2  5   1    3 2 4
+--R     (- A b d e + (- A b c + - B b )d )x  + - A b d x
+--R      5            5         5              4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 138
+
+--S 139 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 139
+
+--S 140 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 140
+
+)clear all
+
+--S 141 of 1457
+t0:=(A+B*x)*(d+e*x)*(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3   8        3         2        3   7
+--R     B c e x  + ((A c  + 3B b c )e + B c d)x
+--R   + 
+--R             2       2          3         2    6
+--R     ((3A b c  + 3B b c)e + (A c  + 3B b c )d)x
+--R   + 
+--R           2       3            2       2     5       3         2       3    4
+--R     ((3A b c + B b )e + (3A b c  + 3B b c)d)x  + (A b e + (3A b c + B b )d)x
+--R   + 
+--R        3   3
+--R     A b d x
+--R                                                    Type: Polynomial(Integer)
+--E 141
+
+--S 142 of 1457
+r0:=1/4*A*b^3*d*x^4+1/5*b^2*(b*B*d+3*A*c*d+A*b*e)*x^5+1/6*b*(3*A*c^2*d+_
+     b^2*B*e+3*b*c*(B*d+A*e))*x^6+1/7*c*(A*c^2*d+3*b^2*B*e+3*b*c*(B*d+_
+     A*e))*x^7+1/8*c^2*(B*c*d+3*b*B*e+A*c*e)*x^8+1/9*B*c^3*e*x^9
+--R 
+--R
+--R   (2)
+--R     1    3   9     1    3   3      2     1    3   8
+--R     - B c e x  + ((- A c  + - B b c )e + - B c d)x
+--R     9              8        8            8
+--R   + 
+--R       3      2   3    2       1    3   3      2    7
+--R     ((- A b c  + - B b c)e + (- A c  + - B b c )d)x
+--R       7          7            7        7
+--R   + 
+--R       1    2    1    3      1      2   1    2     6
+--R     ((- A b c + - B b )e + (- A b c  + - B b c)d)x
+--R       2         6           2          2
+--R   + 
+--R      1    3     3    2    1    3    5   1    3   4
+--R     (- A b e + (- A b c + - B b )d)x  + - A b d x
+--R      5          5         5             4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 142
+
+--S 143 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    3   9     1    3   3      2     1    3   8
+--R     - B c e x  + ((- A c  + - B b c )e + - B c d)x
+--R     9              8        8            8
+--R   + 
+--R       3      2   3    2       1    3   3      2    7
+--R     ((- A b c  + - B b c)e + (- A c  + - B b c )d)x
+--R       7          7            7        7
+--R   + 
+--R       1    2    1    3      1      2   1    2     6
+--R     ((- A b c + - B b )e + (- A b c  + - B b c)d)x
+--R       2         6           2          2
+--R   + 
+--R      1    3     3    2    1    3    5   1    3   4
+--R     (- A b e + (- A b c + - B b )d)x  + - A b d x
+--R      5          5         5             4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 143
+
+--S 144 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 144
+
+--S 145 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 145
+
+)clear all
+
+--S 146 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3 7       3         2  6          2       2   5        2       3  4
+--R     B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R   + 
+--R        3 3
+--R     A b x
+--R                                                    Type: Polynomial(Integer)
+--E 146
+
+--S 147 of 1457
+r0:=1/4*A*b^3*x^4+1/5*b^2*(b*B+3*A*c)*x^5+1/2*b*c*(b*B+A*c)*x^6+_
+     1/7*c^2*(3*b*B+A*c)*x^7+1/8*B*c^3*x^8
+--R 
+--R
+--R   (2)
+--R     1    3 8    1    3   3      2  7    1      2   1    2   6
+--R     - B c x  + (- A c  + - B b c )x  + (- A b c  + - B b c)x
+--R     8           7        7              2          2
+--R   + 
+--R      3    2    1    3  5   1    3 4
+--R     (- A b c + - B b )x  + - A b x
+--R      5         5           4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 147
+
+--S 148 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    3 8    1    3   3      2  7    1      2   1    2   6
+--R     - B c x  + (- A c  + - B b c )x  + (- A b c  + - B b c)x
+--R     8           7        7              2          2
+--R   + 
+--R      3    2    1    3  5   1    3 4
+--R     (- A b c + - B b )x  + - A b x
+--R      5         5           4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 148
+
+--S 149 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 149
+
+--S 150 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 150
+
+)clear all
+
+--S 151 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^3/(d+e*x)
+--R 
+--R
+--R   (1)
+--R          3 7       3         2  6          2       2   5        2       3  4
+--R       B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 3
+--R       A b x
+--R  /
+--R     e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 151
+
+--S 152 of 1457
+r0:=d^2*(B*d-A*e)*(c*d-b*e)^3*x/e^7-1/2*d*(B*d-A*e)*(c*d-b*e)^3*x^2/e^6+_
+     1/3*(B*d-A*e)*(c*d-b*e)^3*x^3/e^5-1/4*(B*(c*d-b*e)^3-A*c*e*(c^2*d^2-_
+     3*b*c*d*e+3*b^2*e^2))*x^4/e^4-1/5*c*(A*c*e*(c*d-3*b*e)-B*(c^2*d^2-_
+     3*b*c*d*e+3*b^2*e^2))*x^5/e^3-1/6*c^2*(B*c*d-3*b*B*e-A*c*e)*x^6/e^2+_
+     1/7*B*c^3*x^7/e-d^3*(B*d-A*e)*(c*d-b*e)^3*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                   3 3 4           2          3  4 3
+--R           - 420A b d e  + (1260A b c + 420B b )d e
+--R         + 
+--R                     2          2   5 2          3            2  6          3 7
+--R         (- 1260A b c  - 1260B b c)d e  + (420A c  + 1260B b c )d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7          3           2  7        3   6  6
+--R       60B c e x  + ((70A c  + 210B b c )e  - 70B c d e )x
+--R     + 
+--R                 2         2   7           3           2    6        3 2 5  5
+--R       ((252A b c  + 252B b c)e  + (- 84A c  - 252B b c )d e  + 84B c d e )x
+--R     + 
+--R                  2          3  7              2         2     6
+--R           (315A b c + 105B b )e  + (- 315A b c  - 315B b c)d e
+--R         + 
+--R                  3           2  2 5         3 3 4
+--R           (105A c  + 315B b c )d e  - 105B c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                 3 7            2          3    6            2         2   2 5
+--R           140A b e  + (- 420A b c - 140B b )d e  + (420A b c  + 420B b c)d e
+--R         + 
+--R                    3           2  3 4         3 4 3
+--R           (- 140A c  - 420B b c )d e  + 140B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                   3   6          2          3  2 5
+--R           - 210A b d e  + (630A b c + 210B b )d e
+--R         + 
+--R                    2         2   3 4          3           2  4 3         3 5 2
+--R         (- 630A b c  - 630B b c)d e  + (210A c  + 630B b c )d e  - 210B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 2 5             2          3  3 4
+--R           420A b d e  + (- 1260A b c - 420B b )d e
+--R         + 
+--R                     2          2   4 3            3            2  5 2
+--R           (1260A b c  + 1260B b c)d e  + (- 420A c  - 1260B b c )d e
+--R         + 
+--R                 3 6
+--R           420B c d e
+--R      *
+--R         x
+--R  /
+--R         8
+--R     420e
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   3 3 4           2          3  4 3
+--R           - 420A b d e  + (1260A b c + 420B b )d e
+--R         + 
+--R                     2          2   5 2          3            2  6          3 7
+--R         (- 1260A b c  - 1260B b c)d e  + (420A c  + 1260B b c )d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7          3           2  7        3   6  6
+--R       60B c e x  + ((70A c  + 210B b c )e  - 70B c d e )x
+--R     + 
+--R                 2         2   7           3           2    6        3 2 5  5
+--R       ((252A b c  + 252B b c)e  + (- 84A c  - 252B b c )d e  + 84B c d e )x
+--R     + 
+--R                  2          3  7              2         2     6
+--R           (315A b c + 105B b )e  + (- 315A b c  - 315B b c)d e
+--R         + 
+--R                  3           2  2 5         3 3 4
+--R           (105A c  + 315B b c )d e  - 105B c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                 3 7            2          3    6            2         2   2 5
+--R           140A b e  + (- 420A b c - 140B b )d e  + (420A b c  + 420B b c)d e
+--R         + 
+--R                    3           2  3 4         3 4 3
+--R           (- 140A c  - 420B b c )d e  + 140B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                   3   6          2          3  2 5
+--R           - 210A b d e  + (630A b c + 210B b )d e
+--R         + 
+--R                    2         2   3 4          3           2  4 3         3 5 2
+--R         (- 630A b c  - 630B b c)d e  + (210A c  + 630B b c )d e  - 210B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 2 5             2          3  3 4
+--R           420A b d e  + (- 1260A b c - 420B b )d e
+--R         + 
+--R                     2          2   4 3            3            2  5 2
+--R           (1260A b c  + 1260B b c)d e  + (- 420A c  - 1260B b c )d e
+--R         + 
+--R                 3 6
+--R           420B c d e
+--R      *
+--R         x
+--R  /
+--R         8
+--R     420e
+--R                                         Type: Union(Expression(Integer),...)
+--E 153
+
+--S 154 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 155
+
+)clear all
+
+--S 156 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^3/(d+e*x)^2
+--R 
+--R
+--R   (1)
+--R          3 7       3         2  6          2       2   5        2       3  4
+--R       B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 3
+--R       A b x
+--R  /
+--R      2 2             2
+--R     e x  + 2d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 156
+
+--S 157 of 1457
+r0:=d*(c*d-b*e)^2*(A*e*(5*c*d-2*b*e)-3*B*d*(2*c*d-b*e))*x/e^7+_
+     1/2*(c*d-b*e)^2*(B*d*(5*c*d-2*b*e)-A*e*(4*c*d-b*e))*x^2/e^6-_
+     1/3*(c*d-b*e)^2*(4*B*c*d-b*B*e-3*A*c*e)*x^3/e^5-1/4*c*(A*c*e*_
+     (2*c*d-3*b*e)-3*B*(c*d-b*e)^2)*x^4/e^4-1/5*c^2*(2*B*c*d-3*b*B*e-_
+     A*c*e)*x^5/e^3+1/6*B*c^3*x^6/e^2+d^3*(B*d-A*e)*(c*d-b*e)^3/(e^8*_
+     (d+e*x))+d^2*(c*d-b*e)^2*(B*d*(7*c*d-4*b*e)-3*A*e*(2*c*d-b*e))*_
+     log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                     3 2 5            2          3  3 4
+--R               180A b d e  + (- 720A b c - 240B b )d e
+--R             + 
+--R                        2         2   4 3            3            2  5 2
+--R               (900A b c  + 900B b c)d e  + (- 360A c  - 1080B b c )d e
+--R             + 
+--R                     3 6
+--R               420B c d e
+--R          *
+--R             x
+--R         + 
+--R                 3 3 4            2          3  4 3            2         2   5 2
+--R           180A b d e  + (- 720A b c - 240B b )d e  + (900A b c  + 900B b c)d e
+--R         + 
+--R                    3            2  6          3 7
+--R           (- 360A c  - 1080B b c )d e + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7          3          2  7        3   6  6
+--R       10B c e x  + ((12A c  + 36B b c )e  - 14B c d e )x
+--R     + 
+--R                2        2   7           3          2    6        3 2 5  5
+--R       ((45A b c  + 45B b c)e  + (- 18A c  - 54B b c )d e  + 21B c d e )x
+--R     + 
+--R                 2         3  7             2        2     6
+--R           (60A b c + 20B b )e  + (- 75A b c  - 75B b c)d e
+--R         + 
+--R                 3          2  2 5        3 3 4
+--R           (30A c  + 90B b c )d e  - 35B c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                3 7            2         3    6            2         2   2 5
+--R           30A b e  + (- 120A b c - 40B b )d e  + (150A b c  + 150B b c)d e
+--R         + 
+--R                   3           2  3 4        3 4 3
+--R           (- 60A c  - 180B b c )d e  + 70B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                  3   6          2          3  2 5
+--R           - 90A b d e  + (360A b c + 120B b )d e
+--R         + 
+--R                    2         2   3 4          3           2  4 3         3 5 2
+--R         (- 450A b c  - 450B b c)d e  + (180A c  + 540B b c )d e  - 210B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                   3 2 5          2          3  3 4
+--R           - 120A b d e  + (540A b c + 180B b )d e
+--R         + 
+--R                    2         2   4 3          3           2  5 2         3 6
+--R         (- 720A b c  - 720B b c)d e  + (300A c  + 900B b c )d e  - 360B c d e
+--R      *
+--R         x
+--R     + 
+--R            3 3 4            2         3  4 3            2         2   5 2
+--R       60A b d e  + (- 180A b c - 60B b )d e  + (180A b c  + 180B b c)d e
+--R     + 
+--R               3           2  6         3 7
+--R       (- 60A c  - 180B b c )d e + 60B c d
+--R  /
+--R        9         8
+--R     60e x + 60d e
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     3 2 5            2          3  3 4
+--R               180A b d e  + (- 720A b c - 240B b )d e
+--R             + 
+--R                        2         2   4 3            3            2  5 2
+--R               (900A b c  + 900B b c)d e  + (- 360A c  - 1080B b c )d e
+--R             + 
+--R                     3 6
+--R               420B c d e
+--R          *
+--R             x
+--R         + 
+--R                 3 3 4            2          3  4 3            2         2   5 2
+--R           180A b d e  + (- 720A b c - 240B b )d e  + (900A b c  + 900B b c)d e
+--R         + 
+--R                    3            2  6          3 7
+--R           (- 360A c  - 1080B b c )d e + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7          3          2  7        3   6  6
+--R       10B c e x  + ((12A c  + 36B b c )e  - 14B c d e )x
+--R     + 
+--R                2        2   7           3          2    6        3 2 5  5
+--R       ((45A b c  + 45B b c)e  + (- 18A c  - 54B b c )d e  + 21B c d e )x
+--R     + 
+--R                 2         3  7             2        2     6
+--R           (60A b c + 20B b )e  + (- 75A b c  - 75B b c)d e
+--R         + 
+--R                 3          2  2 5        3 3 4
+--R           (30A c  + 90B b c )d e  - 35B c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                3 7            2         3    6            2         2   2 5
+--R           30A b e  + (- 120A b c - 40B b )d e  + (150A b c  + 150B b c)d e
+--R         + 
+--R                   3           2  3 4        3 4 3
+--R           (- 60A c  - 180B b c )d e  + 70B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                  3   6          2          3  2 5
+--R           - 90A b d e  + (360A b c + 120B b )d e
+--R         + 
+--R                    2         2   3 4          3           2  4 3         3 5 2
+--R         (- 450A b c  - 450B b c)d e  + (180A c  + 540B b c )d e  - 210B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                   3 2 5          2          3  3 4
+--R           - 120A b d e  + (540A b c + 180B b )d e
+--R         + 
+--R                    2         2   4 3          3           2  5 2         3 6
+--R         (- 720A b c  - 720B b c)d e  + (300A c  + 900B b c )d e  - 360B c d e
+--R      *
+--R         x
+--R     + 
+--R            3 3 4            2         3  4 3            2         2   5 2
+--R       60A b d e  + (- 180A b c - 60B b )d e  + (180A b c  + 180B b c)d e
+--R     + 
+--R               3           2  6         3 7
+--R       (- 60A c  - 180B b c )d e + 60B c d
+--R  /
+--R        9         8
+--R     60e x + 60d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 158
+
+--S 159 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 160
+
+)clear all
+
+--S 161 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^3/(d+e*x)^3
+--R 
+--R
+--R   (1)
+--R          3 7       3         2  6          2       2   5        2       3  4
+--R       B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 3
+--R       A b x
+--R  /
+--R      3 3       2 2     2       3
+--R     e x  + 3d e x  + 3d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 161
+
+--S 162 of 1457
+r0:=-(c*d-b*e)*(A*e*(10*c^2*d^2-8*b*c*d*e+b^2*e^2)-3*B*d*(5*c^2*d^2-_
+     5*b*c*d*e+b^2*e^2))*x/e^7+1/2*(c*d-b*e)*(3*A*c*e*(2*c*d-b*e)-_
+     B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*x^2/e^6+c*(c*d-b*e)*(2*B*c*d-b*B*e-_
+     A*c*e)*x^3/e^5-1/4*c^2*(3*B*c*d-3*b*B*e-A*c*e)*x^4/e^4+1/5*B*c^3*_
+     x^5/e^3+1/2*d^3*(B*d-A*e)*(c*d-b*e)^3/(e^8*(d+e*x)^2)-d^2*_
+     (c*d-b*e)^2*(B*d*(7*c*d-4*b*e)-3*A*e*(2*c*d-b*e))/(e^8*(d+e*x))+_
+     3*d*(c*d-b*e)*(A*e*(5*c^2*d^2-5*b*c*d*e+b^2*e^2)-B*d*(7*c^2*d^2-_
+     8*b*c*d*e+2*b^2*e^2))*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                      3   6          2          3  2 5
+--R               - 60A b d e  + (360A b c + 120B b )d e
+--R             + 
+--R                          2         2   3 4          3           2  4 3
+--R               (- 600A b c  - 600B b c)d e  + (300A c  + 900B b c )d e
+--R             + 
+--R                       3 5 2
+--R               - 420B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       3 2 5          2          3  3 4
+--R               - 120A b d e  + (720A b c + 240B b )d e
+--R             + 
+--R                           2          2   4 3          3            2  5 2
+--R               (- 1200A b c  - 1200B b c)d e  + (600A c  + 1800B b c )d e
+--R             + 
+--R                       3 6
+--R               - 840B c d e
+--R          *
+--R             x
+--R         + 
+--R                  3 3 4          2          3  4 3
+--R           - 60A b d e  + (360A b c + 120B b )d e
+--R         + 
+--R                      2         2   5 2          3           2  6          3 7
+--R           (- 600A b c  - 600B b c)d e  + (300A c  + 900B b c )d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 7 7         3          2  7       3   6  6
+--R       4B c e x  + ((5A c  + 15B b c )e  - 7B c d e )x
+--R     + 
+--R                2        2   7           3          2    6        3 2 5  5
+--R       ((20A b c  + 20B b c)e  + (- 10A c  - 30B b c )d e  + 14B c d e )x
+--R     + 
+--R                 2         3  7             2        2     6
+--R           (30A b c + 10B b )e  + (- 50A b c  - 50B b c)d e
+--R         + 
+--R                 3          2  2 5        3 3 4
+--R           (25A c  + 75B b c )d e  - 35B c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                3 7            2         3    6            2         2   2 5
+--R           20A b e  + (- 120A b c - 40B b )d e  + (200A b c  + 200B b c)d e
+--R         + 
+--R                    3           2  3 4         3 4 3
+--R           (- 100A c  - 300B b c )d e  + 140B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                3   6            2          3  2 5            2         2   3 4
+--R           40A b d e  + (- 330A b c - 110B b )d e  + (630A b c  + 630B b c)d e
+--R         + 
+--R                    3            2  4 3         3 5 2
+--R           (- 340A c  - 1020B b c )d e  + 500B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 2 5         2         3  3 4           2        2   4 3
+--R           - 40A b d e  + (60A b c + 20B b )d e  + (60A b c  + 60B b c)d e
+--R         + 
+--R                   3           2  5 2         3 6
+--R           (- 80A c  - 240B b c )d e  + 160B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 3 4          2         3  4 3              2         2   5 2
+--R       - 50A b d e  + (210A b c + 70B b )d e  + (- 270A b c  - 270B b c)d e
+--R     + 
+--R              3           2  6          3 7
+--R       (110A c  + 330B b c )d e - 130B c d
+--R  /
+--R        10 2        9       2 8
+--R     20e  x  + 40d e x + 20d e
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      3   6          2          3  2 5
+--R               - 60A b d e  + (360A b c + 120B b )d e
+--R             + 
+--R                          2         2   3 4          3           2  4 3
+--R               (- 600A b c  - 600B b c)d e  + (300A c  + 900B b c )d e
+--R             + 
+--R                       3 5 2
+--R               - 420B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       3 2 5          2          3  3 4
+--R               - 120A b d e  + (720A b c + 240B b )d e
+--R             + 
+--R                           2          2   4 3          3            2  5 2
+--R               (- 1200A b c  - 1200B b c)d e  + (600A c  + 1800B b c )d e
+--R             + 
+--R                       3 6
+--R               - 840B c d e
+--R          *
+--R             x
+--R         + 
+--R                  3 3 4          2          3  4 3
+--R           - 60A b d e  + (360A b c + 120B b )d e
+--R         + 
+--R                      2         2   5 2          3           2  6          3 7
+--R           (- 600A b c  - 600B b c)d e  + (300A c  + 900B b c )d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 7 7         3          2  7       3   6  6
+--R       4B c e x  + ((5A c  + 15B b c )e  - 7B c d e )x
+--R     + 
+--R                2        2   7           3          2    6        3 2 5  5
+--R       ((20A b c  + 20B b c)e  + (- 10A c  - 30B b c )d e  + 14B c d e )x
+--R     + 
+--R                 2         3  7             2        2     6
+--R           (30A b c + 10B b )e  + (- 50A b c  - 50B b c)d e
+--R         + 
+--R                 3          2  2 5        3 3 4
+--R           (25A c  + 75B b c )d e  - 35B c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                3 7            2         3    6            2         2   2 5
+--R           20A b e  + (- 120A b c - 40B b )d e  + (200A b c  + 200B b c)d e
+--R         + 
+--R                    3           2  3 4         3 4 3
+--R           (- 100A c  - 300B b c )d e  + 140B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                3   6            2          3  2 5            2         2   3 4
+--R           40A b d e  + (- 330A b c - 110B b )d e  + (630A b c  + 630B b c)d e
+--R         + 
+--R                    3            2  4 3         3 5 2
+--R           (- 340A c  - 1020B b c )d e  + 500B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 2 5         2         3  3 4           2        2   4 3
+--R           - 40A b d e  + (60A b c + 20B b )d e  + (60A b c  + 60B b c)d e
+--R         + 
+--R                   3           2  5 2         3 6
+--R           (- 80A c  - 240B b c )d e  + 160B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 3 4          2         3  4 3              2         2   5 2
+--R       - 50A b d e  + (210A b c + 70B b )d e  + (- 270A b c  - 270B b c)d e
+--R     + 
+--R              3           2  6          3 7
+--R       (110A c  + 330B b c )d e - 130B c d
+--R  /
+--R        10 2        9       2 8
+--R     20e  x  + 40d e x + 20d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 163
+
+--S 164 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^3/(d+e*x)^4
+--R 
+--R
+--R   (1)
+--R          3 7       3         2  6          2       2   5        2       3  4
+--R       B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 3
+--R       A b x
+--R  /
+--R      4 4       3 3     2 2 2     3       4
+--R     e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 166
+
+--S 167 of 1457
+r0:=(A*c*e*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2)-B*(20*c^3*d^3-30*b*c^2*d^2*e+_
+     12*b^2*c*d*e^2-b^3*e^3))*x/e^7-1/2*c*(A*c*e*(4*c*d-3*b*e)-_
+     B*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*x^2/e^6-1/3*c^2*(4*B*c*d-_
+     3*b*B*e-A*c*e)*x^3/e^5+1/4*B*c^3*x^4/e^4+1/3*d^3*(B*d-A*e)*_
+     (c*d-b*e)^3/(e^8*(d+e*x)^3)-1/2*d^2*(c*d-b*e)^2*(B*d*(7*c*d-4*b*e)-_
+     3*A*e*(2*c*d-b*e))/(e^8*(d+e*x)^2)-3*d*(c*d-b*e)*(A*e*(5*c^2*d^2-_
+     5*b*c*d*e+b^2*e^2)-B*d*(7*c^2*d^2-8*b*c*d*e+2*b^2*e^2))/(e^8*_
+     (d+e*x))+(B*d*(35*c^3*d^3-60*b*c^2*d^2*e+30*b^2*c*d*e^2-4*b^3*e^3)-_
+     A*e*(20*c^3*d^3-30*b*c^2*d^2*e+12*b^2*c*d*e^2-b^3*e^3))*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                    3 7            2         3    6            2         2   2 5
+--R               12A b e  + (- 144A b c - 48B b )d e  + (360A b c  + 360B b c)d e
+--R             + 
+--R                        3           2  3 4         3 4 3
+--R               (- 240A c  - 720B b c )d e  + 420B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    3   6            2          3  2 5
+--R               36A b d e  + (- 432A b c - 144B b )d e
+--R             + 
+--R                         2          2   3 4            3            2  4 3
+--R               (1080A b c  + 1080B b c)d e  + (- 720A c  - 2160B b c )d e
+--R             + 
+--R                      3 5 2
+--R               1260B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 2 5            2          3  3 4
+--R               36A b d e  + (- 432A b c - 144B b )d e
+--R             + 
+--R                         2          2   4 3            3            2  5 2
+--R               (1080A b c  + 1080B b c)d e  + (- 720A c  - 2160B b c )d e
+--R             + 
+--R                      3 6
+--R               1260B c d e
+--R          *
+--R             x
+--R         + 
+--R                3 3 4            2         3  4 3            2         2   5 2
+--R           12A b d e  + (- 144A b c - 48B b )d e  + (360A b c  + 360B b c)d e
+--R         + 
+--R                    3           2  6          3 7
+--R           (- 240A c  - 720B b c )d e + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 7 7         3          2  7       3   6  6
+--R       3B c e x  + ((4A c  + 12B b c )e  - 7B c d e )x
+--R     + 
+--R                2        2   7           3          2    6        3 2 5  5
+--R       ((18A b c  + 18B b c)e  + (- 12A c  - 36B b c )d e  + 21B c d e )x
+--R     + 
+--R                 2         3  7             2        2     6
+--R           (36A b c + 12B b )e  + (- 90A b c  - 90B b c)d e
+--R         + 
+--R                 3           2  2 5         3 3 4
+--R           (60A c  + 180B b c )d e  - 105B c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                  2         3    6              2         2   2 5
+--R           (108A b c + 36B b )d e  + (- 378A b c  - 378B b c)d e
+--R         + 
+--R                  3           2  3 4         3 4 3
+--R           (292A c  + 876B b c )d e  - 556B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                3   6            2         3  2 5             2        2   3 4
+--R           36A b d e  + (- 108A b c - 36B b )d e  + (- 54A b c  - 54B b c)d e
+--R         + 
+--R                  3           2  4 3         3 5 2
+--R           (156A c  + 468B b c )d e  - 408B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                3 2 5            2          3  3 4            2         2   4 3
+--R           54A b d e  + (- 324A b c - 108B b )d e  + (486A b c  + 486B b c)d e
+--R         + 
+--R                    3           2  5 2         3 6
+--R           (- 204A c  - 612B b c )d e  + 222B c d e
+--R      *
+--R         x
+--R     + 
+--R            3 3 4            2         3  4 3            2         2   5 2
+--R       22A b d e  + (- 156A b c - 52B b )d e  + (282A b c  + 282B b c)d e
+--R     + 
+--R                3           2  6          3 7
+--R       (- 148A c  - 444B b c )d e + 214B c d
+--R  /
+--R        11 3        10 2      2 9       3 8
+--R     12e  x  + 36d e  x  + 36d e x + 12d e
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    3 7            2         3    6            2         2   2 5
+--R               12A b e  + (- 144A b c - 48B b )d e  + (360A b c  + 360B b c)d e
+--R             + 
+--R                        3           2  3 4         3 4 3
+--R               (- 240A c  - 720B b c )d e  + 420B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    3   6            2          3  2 5
+--R               36A b d e  + (- 432A b c - 144B b )d e
+--R             + 
+--R                         2          2   3 4            3            2  4 3
+--R               (1080A b c  + 1080B b c)d e  + (- 720A c  - 2160B b c )d e
+--R             + 
+--R                      3 5 2
+--R               1260B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 2 5            2          3  3 4
+--R               36A b d e  + (- 432A b c - 144B b )d e
+--R             + 
+--R                         2          2   4 3            3            2  5 2
+--R               (1080A b c  + 1080B b c)d e  + (- 720A c  - 2160B b c )d e
+--R             + 
+--R                      3 6
+--R               1260B c d e
+--R          *
+--R             x
+--R         + 
+--R                3 3 4            2         3  4 3            2         2   5 2
+--R           12A b d e  + (- 144A b c - 48B b )d e  + (360A b c  + 360B b c)d e
+--R         + 
+--R                    3           2  6          3 7
+--R           (- 240A c  - 720B b c )d e + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 7 7         3          2  7       3   6  6
+--R       3B c e x  + ((4A c  + 12B b c )e  - 7B c d e )x
+--R     + 
+--R                2        2   7           3          2    6        3 2 5  5
+--R       ((18A b c  + 18B b c)e  + (- 12A c  - 36B b c )d e  + 21B c d e )x
+--R     + 
+--R                 2         3  7             2        2     6
+--R           (36A b c + 12B b )e  + (- 90A b c  - 90B b c)d e
+--R         + 
+--R                 3           2  2 5         3 3 4
+--R           (60A c  + 180B b c )d e  - 105B c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                  2         3    6              2         2   2 5
+--R           (108A b c + 36B b )d e  + (- 378A b c  - 378B b c)d e
+--R         + 
+--R                  3           2  3 4         3 4 3
+--R           (292A c  + 876B b c )d e  - 556B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                3   6            2         3  2 5             2        2   3 4
+--R           36A b d e  + (- 108A b c - 36B b )d e  + (- 54A b c  - 54B b c)d e
+--R         + 
+--R                  3           2  4 3         3 5 2
+--R           (156A c  + 468B b c )d e  - 408B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                3 2 5            2          3  3 4            2         2   4 3
+--R           54A b d e  + (- 324A b c - 108B b )d e  + (486A b c  + 486B b c)d e
+--R         + 
+--R                    3           2  5 2         3 6
+--R           (- 204A c  - 612B b c )d e  + 222B c d e
+--R      *
+--R         x
+--R     + 
+--R            3 3 4            2         3  4 3            2         2   5 2
+--R       22A b d e  + (- 156A b c - 52B b )d e  + (282A b c  + 282B b c)d e
+--R     + 
+--R                3           2  6          3 7
+--R       (- 148A c  - 444B b c )d e + 214B c d
+--R  /
+--R        11 3        10 2      2 9       3 8
+--R     12e  x  + 36d e  x  + 36d e x + 12d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 168
+
+--S 169 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 170
+
+)clear all
+
+--S 171 of 1457
+t0:=(A+B*x)*(d+e*x)^4/(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R          4 5       4         3  4          3       2 2  3
+--R       B e x  + (A e  + 4B d e )x  + (4A d e  + 6B d e )x
+--R     + 
+--R            2 2       3   2        3       4        4
+--R       (6A d e  + 4B d e)x  + (4A d e + B d )x + A d
+--R  /
+--R        2
+--R     c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 171
+
+--S 172 of 1457
+r0:=e*(A*c*e*(6*c^2*d^2-4*b*c*d*e+b^2*e^2)+B*(4*c^3*d^3-6*b*c^2*d^2*e+_
+     4*b^2*c*d*e^2-b^3*e^3))*x/c^4+1/2*e^2*(A*c*e*(4*c*d-b*e)+B*_
+     (6*c^2*d^2-4*b*c*d*e+b^2*e^2))*x^2/c^3+1/3*e^3*(4*B*c*d-b*B*e+_
+     A*c*e)*x^3/c^2+1/4*B*e^4*x^4/c+A*d^4*log(x)/b+(b*B-A*c)*_
+     (c*d-b*e)^4*log(b+c*x)/(b*c^5)
+--R 
+--R
+--R   (2)
+--R                   4         5  4         3 2        4     3
+--R           (- 12A b c + 12B b )e  + (48A b c  - 48B b c)d e
+--R         + 
+--R                   2 3        3 2  2 2           4        2 3  3
+--R           (- 72A b c  + 72B b c )d e  + (48A b c  - 48B b c )d e
+--R         + 
+--R                   5          4  4
+--R           (- 12A c  + 12B b c )d
+--R      *
+--R         log(c x + b)
+--R     + 
+--R            5 4               4 4 4           4       2 3  4          4   3  3
+--R       12A c d log(x) + 3B b c e x  + ((4A b c  - 4B b c )e  + 16B b c d e )x
+--R     + 
+--R               2 3       3 2  4           4        2 3    3          4 2 2  2
+--R       ((- 6A b c  + 6B b c )e  + (24A b c  - 24B b c )d e  + 36B b c d e )x
+--R     + 
+--R                 3 2        4   4           2 3        3 2    3
+--R           (12A b c  - 12B b c)e  + (- 48A b c  + 48B b c )d e
+--R         + 
+--R                   4        2 3  2 2          4 3
+--R           (72A b c  - 72B b c )d e  + 48B b c d e
+--R      *
+--R         x
+--R  /
+--R          5
+--R     12b c
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   4         5  4         3 2        4     3
+--R           (- 12A b c + 12B b )e  + (48A b c  - 48B b c)d e
+--R         + 
+--R                   2 3        3 2  2 2           4        2 3  3
+--R           (- 72A b c  + 72B b c )d e  + (48A b c  - 48B b c )d e
+--R         + 
+--R                   5          4  4
+--R           (- 12A c  + 12B b c )d
+--R      *
+--R         log(c x + b)
+--R     + 
+--R            5 4               4 4 4           4       2 3  4          4   3  3
+--R       12A c d log(x) + 3B b c e x  + ((4A b c  - 4B b c )e  + 16B b c d e )x
+--R     + 
+--R               2 3       3 2  4           4        2 3    3          4 2 2  2
+--R       ((- 6A b c  + 6B b c )e  + (24A b c  - 24B b c )d e  + 36B b c d e )x
+--R     + 
+--R                 3 2        4   4           2 3        3 2    3
+--R           (12A b c  - 12B b c)e  + (- 48A b c  + 48B b c )d e
+--R         + 
+--R                   4        2 3  2 2          4 3
+--R           (72A b c  - 72B b c )d e  + 48B b c d e
+--R      *
+--R         x
+--R  /
+--R          5
+--R     12b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 173
+
+--S 174 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 175
+
+)clear all
+
+--S 176 of 1457
+t0:=(A+B*x)*(d+e*x)^3/(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R      3 4       3         2  3          2       2   2        2       3        3
+--R   B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x + A d
+--R   ----------------------------------------------------------------------------
+--R                                       2
+--R                                    c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 176
+
+--S 177 of 1457
+r0:=e*(A*c*e*(3*c*d-b*e)+B*(3*c^2*d^2-3*b*c*d*e+b^2*e^2))*x/c^3+_
+     1/2*e^2*(3*B*c*d-b*B*e+A*c*e)*x^2/c^2+1/3*B*e^3*x^3/c+A*d^3*_
+     log(x)/b+(b*B-A*c)*(c*d-b*e)^3*log(b+c*x)/(b*c^4)
+--R 
+--R
+--R   (2)
+--R                3        4  3           2 2        3     2
+--R           (6A b c - 6B b )e  + (- 18A b c  + 18B b c)d e
+--R         + 
+--R                   3        2 2  2           4         3  3
+--R           (18A b c  - 18B b c )d e + (- 6A c  + 6B b c )d
+--R      *
+--R         log(c x + b)
+--R     + 
+--R           4 3               3 3 3           3       2 2  3         3   2  2
+--R       6A c d log(x) + 2B b c e x  + ((3A b c  - 3B b c )e  + 9B b c d e )x
+--R     + 
+--R               2 2       3   3           3        2 2    2          3 2
+--R       ((- 6A b c  + 6B b c)e  + (18A b c  - 18B b c )d e  + 18B b c d e)x
+--R  /
+--R         4
+--R     6b c
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3        4  3           2 2        3     2
+--R           (6A b c - 6B b )e  + (- 18A b c  + 18B b c)d e
+--R         + 
+--R                   3        2 2  2           4         3  3
+--R           (18A b c  - 18B b c )d e + (- 6A c  + 6B b c )d
+--R      *
+--R         log(c x + b)
+--R     + 
+--R           4 3               3 3 3           3       2 2  3         3   2  2
+--R       6A c d log(x) + 2B b c e x  + ((3A b c  - 3B b c )e  + 9B b c d e )x
+--R     + 
+--R               2 2       3   3           3        2 2    2          3 2
+--R       ((- 6A b c  + 6B b c)e  + (18A b c  - 18B b c )d e  + 18B b c d e)x
+--R  /
+--R         4
+--R     6b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 178
+
+--S 179 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 1457
+t0:=(A+B*x)*(d+e*x)^2/(b*x+c*x^2)
+--R 
+--R
+--R           2 3       2           2                2        2
+--R        B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d
+--R   (1)  ----------------------------------------------------
+--R                                2
+--R                             c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 181
+
+--S 182 of 1457
+r0:=e*(2*B*c*d-b*B*e+A*c*e)*x/c^2+1/2*B*e^2*x^2/c+A*d^2*log(x)/b+_
+     (b*B-A*c)*(c*d-b*e)^2*log(b+c*x)/(b*c^3)
+--R 
+--R
+--R   (2)
+--R                 2        3  2          2       2               3         2  2
+--R         ((- 2A b c + 2B b )e  + (4A b c  - 4B b c)d e + (- 2A c  + 2B b c )d )
+--R      *
+--R         log(c x + b)
+--R     + 
+--R           3 2              2 2 2           2       2   2         2
+--R       2A c d log(x) + B b c e x  + ((2A b c  - 2B b c)e  + 4B b c d e)x
+--R  /
+--R         3
+--R     2b c
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2        3  2          2       2               3         2  2
+--R         ((- 2A b c + 2B b )e  + (4A b c  - 4B b c)d e + (- 2A c  + 2B b c )d )
+--R      *
+--R         log(c x + b)
+--R     + 
+--R           3 2              2 2 2           2       2   2         2
+--R       2A c d log(x) + B b c e x  + ((2A b c  - 2B b c)e  + 4B b c d e)x
+--R  /
+--R         3
+--R     2b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 183
+
+--S 184 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 185
+
+)clear all
+
+--S 186 of 1457
+t0:=(A+B*x)*(d+e*x)/(b*x+c*x^2)
+--R 
+--R
+--R             2
+--R        B e x  + (A e + B d)x + A d
+--R   (1)  ---------------------------
+--R                    2
+--R                 c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 186
+
+--S 187 of 1457
+r0:=B*e*x/c+A*d*log(x)/b+(b*B-A*c)*(c*d-b*e)*log(b+c*x)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R                2           2                             2
+--R   ((A b c - B b )e + (- A c  + B b c)d)log(c x + b) + A c d log(x) + B b c e x
+--R   ----------------------------------------------------------------------------
+--R                                          2
+--R                                       b c
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2           2                             2
+--R   ((A b c - B b )e + (- A c  + B b c)d)log(c x + b) + A c d log(x) + B b c e x
+--R   ----------------------------------------------------------------------------
+--R                                          2
+--R                                       b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 188
+
+--S 189 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 190
+
+)clear all
+
+--S 191 of 1457
+t0:=(A+B*x)/(b*x+c*x^2)
+--R 
+--R
+--R          B x + A
+--R   (1)  ----------
+--R           2
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 191
+
+--S 192 of 1457
+r0:=A*log(x)/b+(b*B-A*c)*log(b+c*x)/(b*c)
+--R 
+--R
+--R        (- A c + B b)log(c x + b) + A c log(x)
+--R   (2)  --------------------------------------
+--R                          b c
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (- A c + B b)log(c x + b) + A c log(x)
+--R   (3)  --------------------------------------
+--R                          b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 193
+
+--S 194 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 1457
+t0:=(A+B*x)/((d+e*x)*(b*x+c*x^2))
+--R 
+--R
+--R                    B x + A
+--R   (1)  ------------------------------
+--R             3               2
+--R        c e x  + (b e + c d)x  + b d x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 196
+
+--S 197 of 1457
+r0:=A*log(x)/(b*d)+(b*B-A*c)*log(b+c*x)/(b*(c*d-b*e))-_
+     (B*d-A*e)*log(d+e*x)/(d*(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R       (- A b e + B b d)log(e x + d) + (A c - B b)d log(c x + b)
+--R     + 
+--R       (A b e - A c d)log(x)
+--R  /
+--R      2           2
+--R     b d e - b c d
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       (- A b e + B b d)log(e x + d) + (A c - B b)d log(c x + b)
+--R     + 
+--R       (A b e - A c d)log(x)
+--R  /
+--R      2           2
+--R     b d e - b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 198
+
+--S 199 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 200
+
+)clear all
+
+--S 201 of 1457
+t0:=(A+B*x)/((d+e*x)^2*(b*x+c*x^2))
+--R 
+--R
+--R                                B x + A
+--R   (1)  ------------------------------------------------------
+--R           2 4       2           3                2  2      2
+--R        c e x  + (b e  + 2c d e)x  + (2b d e + c d )x  + b d x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 201
+
+--S 202 of 1457
+r0:=(B*d-A*e)/(d*(c*d-b*e)*(d+e*x))+A*log(x)/(b*d^2)+c*(b*B-A*c)*_
+     log(b+c*x)/(b*(c*d-b*e)^2)-(B*c*d^2-A*e*(2*c*d-b*e))*log(d+e*x)/_
+     (d^2*(c*d-b*e)^2)
+--R 
+--R
+--R   (2)
+--R                 2 3             2          2         2   2           2
+--R           (- A b e  + 2A b c d e  - B b c d e)x - A b d e  + 2A b c d e
+--R         + 
+--R                    3
+--R           - B b c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R              2          2            2          3
+--R       ((- A c  + B b c)d e x + (- A c  + B b c)d )log(c x + b)
+--R     + 
+--R              2 3             2      2 2         2   2           2       2 3
+--R         ((A b e  - 2A b c d e  + A c d e)x + A b d e  - 2A b c d e + A c d )
+--R      *
+--R         log(x)
+--R     + 
+--R          2   2                 2  2           3
+--R       A b d e  + (- A b c - B b )d e + B b c d
+--R  /
+--R       3 2 3     2   3 2      2 4       3 3 2     2   4       2 5
+--R     (b d e  - 2b c d e  + b c d e)x + b d e  - 2b c d e + b c d
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2 3             2          2         2   2           2
+--R           (- A b e  + 2A b c d e  - B b c d e)x - A b d e  + 2A b c d e
+--R         + 
+--R                    3
+--R           - B b c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R              2          2            2          3
+--R       ((- A c  + B b c)d e x + (- A c  + B b c)d )log(c x + b)
+--R     + 
+--R              2 3             2      2 2         2   2           2       2 3
+--R         ((A b e  - 2A b c d e  + A c d e)x + A b d e  - 2A b c d e + A c d )
+--R      *
+--R         log(x)
+--R     + 
+--R          2   2                 2  2           3
+--R       A b d e  + (- A b c - B b )d e + B b c d
+--R  /
+--R       3 2 3     2   3 2      2 4       3 3 2     2   4       2 5
+--R     (b d e  - 2b c d e  + b c d e)x + b d e  - 2b c d e + b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 203
+
+--S 204 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 205
+
+)clear all
+
+--S 206 of 1457
+t0:=(A+B*x)/((d+e*x)^3*(b*x+c*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R          3 5       3         2  4          2       2   3        2       3  2
+--R       c e x  + (b e  + 3c d e )x  + (3b d e  + 3c d e)x  + (3b d e + c d )x
+--R     + 
+--R          3
+--R       b d x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 206
+
+--S 207 of 1457
+r0:=1/2*(B*d-A*e)/(d*(c*d-b*e)*(d+e*x)^2)+(B*c*d^2-A*e*(2*c*d-b*e))/_
+     (d^2*(c*d-b*e)^2*(d+e*x))+A*log(x)/(b*d^3)+c^2*(b*B-A*c)*_
+     log(b+c*x)/(b*(c*d-b*e)^3)-(B*c^2*d^3-A*e*(3*c^2*d^2-3*b*c*d*e+_
+     b^2*e^2))*log(d+e*x)/(d^3*(c*d-b*e)^3)
+--R 
+--R
+--R   (2)
+--R                  3 5       2     4         2 2 3         2 3 2  2
+--R           (- 2A b e  + 6A b c d e  - 6A b c d e  + 2B b c d e )x
+--R         + 
+--R                  3   4        2   2 3          2 3 2         2 4          3 2 3
+--R           (- 4A b d e  + 12A b c d e  - 12A b c d e  + 4B b c d e)x - 2A b d e
+--R         + 
+--R               2   3 2         2 4          2 5
+--R           6A b c d e  - 6A b c d e + 2B b c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                  3         2  3 2 2        3         2  4
+--R             (2A c  - 2B b c )d e x  + (4A c  - 4B b c )d e x
+--R           + 
+--R                  3         2  5
+--R             (2A c  - 2B b c )d
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                3 5       2     4         2 2 3       3 3 2  2
+--R           (2A b e  - 6A b c d e  + 6A b c d e  - 2A c d e )x
+--R         + 
+--R                3   4        2   2 3          2 3 2       3 4          3 2 3
+--R           (4A b d e  - 12A b c d e  + 12A b c d e  - 4A c d e)x + 2A b d e
+--R         + 
+--R                 2   3 2         2 4        3 5
+--R           - 6A b c d e  + 6A b c d e - 2A c d
+--R      *
+--R         log(x)
+--R     + 
+--R            3   4       2   2 3          2       2   3 2         2 4
+--R       (2A b d e  - 6A b c d e  + (4A b c  + 2B b c)d e  - 2B b c d e)x
+--R     + 
+--R           3 2 3          2       3  3 2          2       2   4          2 5
+--R       3A b d e  + (- 8A b c - B b )d e  + (5A b c  + 4B b c)d e - 3B b c d
+--R  /
+--R          4 3 5     3   4 4     2 2 5 3       3 6 2  2
+--R       (2b d e  - 6b c d e  + 6b c d e  - 2b c d e )x
+--R     + 
+--R          4 4 4      3   5 3      2 2 6 2       3 7        4 5 3     3   6 2
+--R       (4b d e  - 12b c d e  + 12b c d e  - 4b c d e)x + 2b d e  - 6b c d e
+--R     + 
+--R         2 2 7        3 8
+--R       6b c d e - 2b c d
+--R                                                    Type: Expression(Integer)
+--E 207
+
+--S 208 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  3 5       2     4         2 2 3         2 3 2  2
+--R           (- 2A b e  + 6A b c d e  - 6A b c d e  + 2B b c d e )x
+--R         + 
+--R                  3   4        2   2 3          2 3 2         2 4          3 2 3
+--R           (- 4A b d e  + 12A b c d e  - 12A b c d e  + 4B b c d e)x - 2A b d e
+--R         + 
+--R               2   3 2         2 4          2 5
+--R           6A b c d e  - 6A b c d e + 2B b c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                  3         2  3 2 2        3         2  4
+--R             (2A c  - 2B b c )d e x  + (4A c  - 4B b c )d e x
+--R           + 
+--R                  3         2  5
+--R             (2A c  - 2B b c )d
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                3 5       2     4         2 2 3       3 3 2  2
+--R           (2A b e  - 6A b c d e  + 6A b c d e  - 2A c d e )x
+--R         + 
+--R                3   4        2   2 3          2 3 2       3 4          3 2 3
+--R           (4A b d e  - 12A b c d e  + 12A b c d e  - 4A c d e)x + 2A b d e
+--R         + 
+--R                 2   3 2         2 4        3 5
+--R           - 6A b c d e  + 6A b c d e - 2A c d
+--R      *
+--R         log(x)
+--R     + 
+--R            3   4       2   2 3          2       2   3 2         2 4
+--R       (2A b d e  - 6A b c d e  + (4A b c  + 2B b c)d e  - 2B b c d e)x
+--R     + 
+--R           3 2 3          2       3  3 2          2       2   4          2 5
+--R       3A b d e  + (- 8A b c - B b )d e  + (5A b c  + 4B b c)d e - 3B b c d
+--R  /
+--R          4 3 5     3   4 4     2 2 5 3       3 6 2  2
+--R       (2b d e  - 6b c d e  + 6b c d e  - 2b c d e )x
+--R     + 
+--R          4 4 4      3   5 3      2 2 6 2       3 7        4 5 3     3   6 2
+--R       (4b d e  - 12b c d e  + 12b c d e  - 4b c d e)x + 2b d e  - 6b c d e
+--R     + 
+--R         2 2 7        3 8
+--R       6b c d e - 2b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 208
+
+--S 209 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 1457
+t0:=(A+B*x)/((d+e*x)^4*(b*x+c*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R          4 6       4         3  5          3       2 2  4
+--R       c e x  + (b e  + 4c d e )x  + (4b d e  + 6c d e )x
+--R     + 
+--R            2 2       3   3        3       4  2      4
+--R       (6b d e  + 4c d e)x  + (4b d e + c d )x  + b d x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 211
+
+--S 212 of 1457
+r0:=1/3*(B*d-A*e)/(d*(c*d-b*e)*(d+e*x)^3)+1/2*(B*c*d^2-A*e*(2*c*d-b*e))/_
+     (d^2*(c*d-b*e)^2*(d+e*x)^2)+(B*c^2*d^3-A*e*(3*c^2*d^2-3*b*c*d*e+_
+     b^2*e^2))/(d^3*(c*d-b*e)^3*(d+e*x))+A*log(x)/(b*d^4)+c^3*(b*B-A*c)*_
+     log(b+c*x)/(b*(c*d-b*e)^4)-(B*c^3*d^4-A*e*(4*c^3*d^3-_
+     6*b*c^2*d^2*e+4*b^2*c*d*e^2-b^3*e^3))*log(d+e*x)/(d^4*(c*d-b*e)^4)
+--R 
+--R
+--R   (2)
+--R                     4 7        3     6        2 2 2 5          3 3 4
+--R               - 6A b e  + 24A b c d e  - 36A b c d e  + 24A b c d e
+--R             + 
+--R                       3 4 3
+--R               - 6B b c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      4   6        3   2 5         2 2 3 4          3 4 3
+--R               - 18A b d e  + 72A b c d e  - 108A b c d e  + 72A b c d e
+--R             + 
+--R                        3 5 2
+--R               - 18B b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      4 2 5        3   3 4         2 2 4 3          3 5 2
+--R               - 18A b d e  + 72A b c d e  - 108A b c d e  + 72A b c d e
+--R             + 
+--R                        3 6
+--R               - 18B b c d e
+--R          *
+--R             x
+--R         + 
+--R                 4 3 4        3   4 3        2 2 5 2          3 6          3 7
+--R           - 6A b d e  + 24A b c d e  - 36A b c d e  + 24A b c d e - 6B b c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                  4         3  4 3 3           4          3  5 2 2
+--R           (- 6A c  + 6B b c )d e x  + (- 18A c  + 18B b c )d e x
+--R         + 
+--R                   4          3  6             4         3  7
+--R           (- 18A c  + 18B b c )d e x + (- 6A c  + 6B b c )d
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                4 7        3     6        2 2 2 5          3 3 4       4 4 3  3
+--R           (6A b e  - 24A b c d e  + 36A b c d e  - 24A b c d e  + 6A c d e )x
+--R         + 
+--R                    4   6        3   2 5         2 2 3 4          3 4 3
+--R               18A b d e  - 72A b c d e  + 108A b c d e  - 72A b c d e
+--R             + 
+--R                    4 5 2
+--R               18A c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    4 2 5        3   3 4         2 2 4 3          3 5 2
+--R               18A b d e  - 72A b c d e  + 108A b c d e  - 72A b c d e
+--R             + 
+--R                    4 6
+--R               18A c d e
+--R          *
+--R             x
+--R         + 
+--R               4 3 4        3   4 3        2 2 5 2          3 6        4 7
+--R           6A b d e  - 24A b c d e  + 36A b c d e  - 24A b c d e + 6A c d
+--R      *
+--R         log(x)
+--R     + 
+--R               4   6        3   2 5        2 2 3 4             3       2 2  4 3
+--R           6A b d e  - 24A b c d e  + 36A b c d e  + (- 18A b c  - 6B b c )d e
+--R         + 
+--R                 3 5 2
+--R           6B b c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                4 2 5        3   3 4         2 2       3   4 3
+--R           15A b d e  - 60A b c d e  + (87A b c  + 3B b c)d e
+--R         + 
+--R                     3        2 2  5 2          3 6
+--R           (- 42A b c  - 18B b c )d e  + 15B b c d e
+--R      *
+--R         x
+--R     + 
+--R            4 3 4           3        4  4 3         2 2       3   5 2
+--R       11A b d e  + (- 42A b c - 2B b )d e  + (57A b c  + 9B b c)d e
+--R     + 
+--R                 3        2 2  6           3 7
+--R       (- 26A b c  - 18B b c )d e + 11B b c d
+--R  /
+--R          5 4 7      4   5 6      3 2 6 5      2 3 7 4       4 8 3  3
+--R       (6b d e  - 24b c d e  + 36b c d e  - 24b c d e  + 6b c d e )x
+--R     + 
+--R           5 5 6      4   6 5       3 2 7 4      2 3 8 3        4 9 2  2
+--R       (18b d e  - 72b c d e  + 108b c d e  - 72b c d e  + 18b c d e )x
+--R     + 
+--R           5 6 5      4   7 4       3 2 8 3      2 3 9 2        4 10
+--R       (18b d e  - 72b c d e  + 108b c d e  - 72b c d e  + 18b c d  e)x
+--R     + 
+--R         5 7 4      4   8 3      3 2 9 2      2 3 10        4 11
+--R       6b d e  - 24b c d e  + 36b c d e  - 24b c d  e + 6b c d
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 1457
+--a0:=integrate(t0,x)
+--E 213
+
+--S 214 of 1457
+--m0:=a0-r0
+--E 214
+
+--S 215 of 1457
+--d0:=D(m0,x)
+--E 215
+
+)clear all
+
+--S 216 of 1457
+t0:=(A+B*x)*(d+e*x)^4/(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R          4 5       4         3  4          3       2 2  3
+--R       B e x  + (A e  + 4B d e )x  + (4A d e  + 6B d e )x
+--R     + 
+--R            2 2       3   2        3       4        4
+--R       (6A d e  + 4B d e)x  + (4A d e + B d )x + A d
+--R  /
+--R      2 4         3    2 2
+--R     c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 216
+
+--S 217 of 1457
+r0:=-A*d^4/(b^2*x)+e^3*(4*B*c*d-2*b*B*e+A*c*e)*x/c^3+1/2*B*e^4*x^2/c^2+_
+     (b*B-A*c)*(c*d-b*e)^4/(b^2*c^4*(b+c*x))+d^3*(b*B*d-2*A*c*d+_
+     4*A*b*e)*log(x)/b^3+(c*d-b*e)^3*(2*A*c^2*d-3*b^2*B*e-b*c*(B*d-_
+     2*A*e))*log(b+c*x)/(b^3*c^4)
+--R 
+--R
+--R   (2)
+--R                      4 2       5   4        3 3        4 2    3        3 3 2 2
+--R               (- 4A b c  + 6B b c)e  + (8A b c  - 16B b c )d e  + 12B b c d e
+--R             + 
+--R                       5 3         6         5  4
+--R               - 8A b c d e + (4A c  - 2B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      5        6  4        4 2        5     3        4 2 2 2
+--R               (- 4A b c + 6B b )e  + (8A b c  - 16B b c)d e  + 12B b c d e
+--R             + 
+--R                     2 4 3           5       2 4  4
+--R               - 8A b c d e + (4A b c  - 2B b c )d
+--R          *
+--R             x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                  5 3           6         5  4  2
+--R           (8A b c d e + (- 4A c  + 2B b c )d )x
+--R         + 
+--R                2 4 3             5       2 4  4
+--R           (8A b c d e + (- 4A b c  + 2B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R          3 3 4 4         3 3       4 2  4       3 3   3  3
+--R       B b c e x  + ((2A b c  - 3B b c )e  + 8B b c d e )x
+--R     + 
+--R             4 2       5   4       4 2   3  2
+--R       ((2A b c  - 4B b c)e  + 8B b c d e )x
+--R     + 
+--R                  5        6  4        4 2       5     3
+--R           (- 2A b c + 2B b )e  + (8A b c  - 8B b c)d e
+--R         + 
+--R                   3 3        4 2  2 2        2 4       3 3  3
+--R           (- 12A b c  + 12B b c )d e  + (8A b c  - 8B b c )d e
+--R         + 
+--R                    5       2 4  4
+--R           (- 4A b c  + 2B b c )d
+--R      *
+--R         x
+--R     + 
+--R             2 4 4
+--R       - 2A b c d
+--R  /
+--R       3 5 2     4 4
+--R     2b c x  + 2b c x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      4 2       5   4        3 3        4 2    3        3 3 2 2
+--R               (- 4A b c  + 6B b c)e  + (8A b c  - 16B b c )d e  + 12B b c d e
+--R             + 
+--R                       5 3         6         5  4
+--R               - 8A b c d e + (4A c  - 2B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      5        6  4        4 2        5     3        4 2 2 2
+--R               (- 4A b c + 6B b )e  + (8A b c  - 16B b c)d e  + 12B b c d e
+--R             + 
+--R                     2 4 3           5       2 4  4
+--R               - 8A b c d e + (4A b c  - 2B b c )d
+--R          *
+--R             x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                  5 3           6         5  4  2
+--R           (8A b c d e + (- 4A c  + 2B b c )d )x
+--R         + 
+--R                2 4 3             5       2 4  4
+--R           (8A b c d e + (- 4A b c  + 2B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R          3 3 4 4         3 3       4 2  4       3 3   3  3
+--R       B b c e x  + ((2A b c  - 3B b c )e  + 8B b c d e )x
+--R     + 
+--R             4 2       5   4       4 2   3  2
+--R       ((2A b c  - 4B b c)e  + 8B b c d e )x
+--R     + 
+--R                  5        6  4        4 2       5     3
+--R           (- 2A b c + 2B b )e  + (8A b c  - 8B b c)d e
+--R         + 
+--R                   3 3        4 2  2 2        2 4       3 3  3
+--R           (- 12A b c  + 12B b c )d e  + (8A b c  - 8B b c )d e
+--R         + 
+--R                    5       2 4  4
+--R           (- 4A b c  + 2B b c )d
+--R      *
+--R         x
+--R     + 
+--R             2 4 4
+--R       - 2A b c d
+--R  /
+--R       3 5 2     4 4
+--R     2b c x  + 2b c x
+--R                                         Type: Union(Expression(Integer),...)
+--E 218
+
+--S 219 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 220
+
+)clear all
+
+--S 221 of 1457
+t0:=(A+B*x)*(d+e*x)^3/(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R      3 4       3         2  3          2       2   2        2       3        3
+--R   B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x + A d
+--R   ----------------------------------------------------------------------------
+--R                                2 4         3    2 2
+--R                               c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 221
+
+--S 222 of 1457
+r0:=-A*d^3/(b^2*x)+B*e^3*x/c^2+(b*B-A*c)*(c*d-b*e)^3/(b^2*c^3*(b+c*x))+_
+     d^2*(b*B*d-2*A*c*d+3*A*b*e)*log(x)/b^3-(c*d-b*e)^2*(b*B*c*d-_
+     2*A*c^2*d+2*b^2*B*e-A*b*c*e)*log(b+c*x)/(b^3*c^3)
+--R 
+--R
+--R   (2)
+--R                     3 2       4   3       3 2   2         4 2
+--R                 (A b c  - 2B b c)e  + 3B b c d e  - 3A b c d e
+--R               + 
+--R                      5        4  3
+--R                 (2A c  - B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R              4        5  3       4     2       2 3 2           4      2 3  3
+--R         ((A b c - 2B b )e  + 3B b c d e  - 3A b c d e + (2A b c  - B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                  4 2           5        4  3  2
+--R           (3A b c d e + (- 2A c  + B b c )d )x
+--R         + 
+--R                2 3 2             4      2 3  3
+--R           (3A b c d e + (- 2A b c  + B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R          3 2 3 3      4   3 2
+--R       B b c e x  + B b c e x
+--R     + 
+--R               4       5  3          3 2       4     2        2 3       3 2  2
+--R           (A b c - B b )e  + (- 3A b c  + 3B b c)d e  + (3A b c  - 3B b c )d e
+--R         + 
+--R                    4      2 3  3
+--R           (- 2A b c  + B b c )d
+--R      *
+--R         x
+--R     + 
+--R            2 3 3
+--R       - A b c d
+--R  /
+--R      3 4 2    4 3
+--R     b c x  + b c x
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     3 2       4   3       3 2   2         4 2
+--R                 (A b c  - 2B b c)e  + 3B b c d e  - 3A b c d e
+--R               + 
+--R                      5        4  3
+--R                 (2A c  - B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R              4        5  3       4     2       2 3 2           4      2 3  3
+--R         ((A b c - 2B b )e  + 3B b c d e  - 3A b c d e + (2A b c  - B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                  4 2           5        4  3  2
+--R           (3A b c d e + (- 2A c  + B b c )d )x
+--R         + 
+--R                2 3 2             4      2 3  3
+--R           (3A b c d e + (- 2A b c  + B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R          3 2 3 3      4   3 2
+--R       B b c e x  + B b c e x
+--R     + 
+--R               4       5  3          3 2       4     2        2 3       3 2  2
+--R           (A b c - B b )e  + (- 3A b c  + 3B b c)d e  + (3A b c  - 3B b c )d e
+--R         + 
+--R                    4      2 3  3
+--R           (- 2A b c  + B b c )d
+--R      *
+--R         x
+--R     + 
+--R            2 3 3
+--R       - A b c d
+--R  /
+--R      3 4 2    4 3
+--R     b c x  + b c x
+--R                                         Type: Union(Expression(Integer),...)
+--E 223
+
+--S 224 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 1457
+t0:=(A+B*x)*(d+e*x)^2/(b*x+c*x^2)^2
+--R 
+--R
+--R           2 3       2           2                2        2
+--R        B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d
+--R   (1)  ----------------------------------------------------
+--R                         2 4         3    2 2
+--R                        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 226
+
+--S 227 of 1457
+r0:=-A*d^2/(b^2*x)+(b*B-A*c)*(c*d-b*e)^2/(b^2*c^2*(b+c*x))+d*_
+     (b*B*d-2*A*c*d+2*A*b*e)*log(x)/b^3-(c*d-b*e)*(b*B*c*d-2*A*c^2*d+_
+     b^2*B*e)*log(b+c*x)/(b^3*c^2)
+--R 
+--R
+--R   (2)
+--R               3   2         3           4        3  2  2
+--R           (B b c e  - 2A b c d e + (2A c  - B b c )d )x
+--R         + 
+--R               4 2       2 2             3      2 2  2
+--R           (B b e  - 2A b c d e + (2A b c  - B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                  3             4        3  2  2
+--R           (2A b c d e + (- 2A c  + B b c )d )x
+--R         + 
+--R                2 2               3      2 2  2
+--R           (2A b c d e + (- 2A b c  + B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R              3       4  2        2 2       3                 3      2 2  2
+--R       ((- A b c + B b )e  + (2A b c  - 2B b c)d e + (- 2A b c  + B b c )d )x
+--R     + 
+--R            2 2 2
+--R       - A b c d
+--R  /
+--R      3 3 2    4 2
+--R     b c x  + b c x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3   2         3           4        3  2  2
+--R           (B b c e  - 2A b c d e + (2A c  - B b c )d )x
+--R         + 
+--R               4 2       2 2             3      2 2  2
+--R           (B b e  - 2A b c d e + (2A b c  - B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                  3             4        3  2  2
+--R           (2A b c d e + (- 2A c  + B b c )d )x
+--R         + 
+--R                2 2               3      2 2  2
+--R           (2A b c d e + (- 2A b c  + B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R              3       4  2        2 2       3                 3      2 2  2
+--R       ((- A b c + B b )e  + (2A b c  - 2B b c)d e + (- 2A b c  + B b c )d )x
+--R     + 
+--R            2 2 2
+--R       - A b c d
+--R  /
+--R      3 3 2    4 2
+--R     b c x  + b c x
+--R                                         Type: Union(Expression(Integer),...)
+--E 228
+
+--S 229 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 230
+
+)clear all
+
+--S 231 of 1457
+t0:=(A+B*x)*(d+e*x)/(b*x+c*x^2)^2
+--R 
+--R
+--R             2
+--R        B e x  + (A e + B d)x + A d
+--R   (1)  ---------------------------
+--R            2 4         3    2 2
+--R           c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 231
+
+--S 232 of 1457
+r0:=-A*d/(b^2*x)+(b*B-A*c)*(c*d-b*e)/(b^2*c*(b+c*x))+(b*B*d-2*A*c*d+A*b*e)*_
+     log(x)/b^3-(b*B*d-2*A*c*d+A*b*e)*log(b+c*x)/b^3
+--R 
+--R
+--R   (2)
+--R                  2         3        2    2         2             2      2
+--R         ((- A b c e + (2A c  - B b c )d)x  + (- A b c e + (2A b c  - B b c)d)x)
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                2           3        2    2       2               2      2
+--R         ((A b c e + (- 2A c  + B b c )d)x  + (A b c e + (- 2A b c  + B b c)d)x)
+--R      *
+--R         log(x)
+--R     + 
+--R            2       3              2      2           2
+--R       ((A b c - B b )e + (- 2A b c  + B b c)d)x - A b c d
+--R  /
+--R      3 2 2    4
+--R     b c x  + b c x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2         3        2    2         2             2      2
+--R         ((- A b c e + (2A c  - B b c )d)x  + (- A b c e + (2A b c  - B b c)d)x)
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                2           3        2    2       2               2      2
+--R         ((A b c e + (- 2A c  + B b c )d)x  + (A b c e + (- 2A b c  + B b c)d)x)
+--R      *
+--R         log(x)
+--R     + 
+--R            2       3              2      2           2
+--R       ((A b c - B b )e + (- 2A b c  + B b c)d)x - A b c d
+--R  /
+--R      3 2 2    4
+--R     b c x  + b c x
+--R                                         Type: Union(Expression(Integer),...)
+--E 233
+
+--S 234 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 235
+
+)clear all
+
+--S 236 of 1457
+t0:=(A+B*x)/(b*x+c*x^2)^2
+--R 
+--R
+--R               B x + A
+--R   (1)  ---------------------
+--R         2 4         3    2 2
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 236
+
+--S 237 of 1457
+r0:=-A/(b^2*x)+(b*B-A*c)/(b^2*(b+c*x))+(b*B-2*A*c)*log(x)/b^3-(b*B-2*A*c)*_
+     log(b+c*x)/b^3
+--R 
+--R
+--R   (2)
+--R             2          2                2
+--R       ((2A c  - B b c)x  + (2A b c - B b )x)log(c x + b)
+--R     + 
+--R               2          2                  2                           2
+--R       ((- 2A c  + B b c)x  + (- 2A b c + B b )x)log(x) + (- 2A b c + B b )x
+--R     + 
+--R            2
+--R       - A b
+--R  /
+--R      3   2    4
+--R     b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 237
+
+--S 238 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2          2                2
+--R       ((2A c  - B b c)x  + (2A b c - B b )x)log(c x + b)
+--R     + 
+--R               2          2                  2                           2
+--R       ((- 2A c  + B b c)x  + (- 2A b c + B b )x)log(x) + (- 2A b c + B b )x
+--R     + 
+--R            2
+--R       - A b
+--R  /
+--R      3   2    4
+--R     b c x  + b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 238
+
+--S 239 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 1457
+t0:=(A+B*x)/((d+e*x)*(b*x+c*x^2)^2)
+--R 
+--R
+--R                               B x + A
+--R   (1)  -----------------------------------------------------
+--R         2   5              2   4     2            3    2   2
+--R        c e x  + (2b c e + c d)x  + (b e + 2b c d)x  + b d x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 241
+
+--S 242 of 1457
+r0:=-A/(b^2*d*x)+c*(b*B-A*c)/(b^2*(c*d-b*e)*(b+c*x))+(b*B*d-2*A*c*d-A*b*e)*_
+     log(x)/(b^3*d^2)+c*(2*A*c^2*d+2*b^2*B*e-b*c*(B*d+3*A*e))*log(b+c*x)/_
+     (b^3*(c*d-b*e)^2)-e^2*(B*d-A*e)*log(d+e*x)/(d^2*(c*d-b*e)^2)
+--R 
+--R
+--R   (2)
+--R            3   3      3     2  2       4 3      4   2
+--R       ((A b c e  - B b c d e )x  + (A b e  - B b d e )x)log(e x + d)
+--R     + 
+--R                     3       2 2  2         4        3  3  2
+--R           ((- 3A b c  + 2B b c )d e + (2A c  - B b c )d )x
+--R         + 
+--R                   2 2       3   2           3      2 2  3
+--R           ((- 3A b c  + 2B b c)d e + (2A b c  - B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                    3   3      3     2          3       2 2  2
+--R               - A b c e  + B b c d e  + (3A b c  - 2B b c )d e
+--R             + 
+--R                      4        3  3
+--R               (- 2A c  + B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R               4 3      4   2        2 2       3   2             3      2 2  3
+--R         (- A b e  + B b d e  + (3A b c  - 2B b c)d e + (- 2A b c  + B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R             3     2        2 2      3   2             3      2 2  3
+--R       (- A b c d e  + (3A b c  - B b c)d e + (- 2A b c  + B b c )d )x
+--R     + 
+--R            4   2       3   2       2 2 3
+--R       - A b d e  + 2A b c d e - A b c d
+--R  /
+--R       5   2 2     4 2 3     3 3 4  2     6 2 2     5   3     4 2 4
+--R     (b c d e  - 2b c d e + b c d )x  + (b d e  - 2b c d e + b c d )x
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3   3      3     2  2       4 3      4   2
+--R       ((A b c e  - B b c d e )x  + (A b e  - B b d e )x)log(e x + d)
+--R     + 
+--R                     3       2 2  2         4        3  3  2
+--R           ((- 3A b c  + 2B b c )d e + (2A c  - B b c )d )x
+--R         + 
+--R                   2 2       3   2           3      2 2  3
+--R           ((- 3A b c  + 2B b c)d e + (2A b c  - B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                    3   3      3     2          3       2 2  2
+--R               - A b c e  + B b c d e  + (3A b c  - 2B b c )d e
+--R             + 
+--R                      4        3  3
+--R               (- 2A c  + B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R               4 3      4   2        2 2       3   2             3      2 2  3
+--R         (- A b e  + B b d e  + (3A b c  - 2B b c)d e + (- 2A b c  + B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R             3     2        2 2      3   2             3      2 2  3
+--R       (- A b c d e  + (3A b c  - B b c)d e + (- 2A b c  + B b c )d )x
+--R     + 
+--R            4   2       3   2       2 2 3
+--R       - A b d e  + 2A b c d e - A b c d
+--R  /
+--R       5   2 2     4 2 3     3 3 4  2     6 2 2     5   3     4 2 4
+--R     (b c d e  - 2b c d e + b c d )x  + (b d e  - 2b c d e + b c d )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 243
+
+--S 244 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 245
+
+)clear all
+
+--S 246 of 1457
+t0:=(A+B*x)/((d+e*x)^2*(b*x+c*x^2)^2)
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R        2 2 6          2     2     5     2 2               2 2  4
+--R       c e x  + (2b c e  + 2c d e)x  + (b e  + 4b c d e + c d )x
+--R     + 
+--R          2            2  3    2 2 2
+--R       (2b d e + 2b c d )x  + b d x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 246
+
+--S 247 of 1457
+r0:=-A/(b^2*d^2*x)+c^2*(b*B-A*c)/(b^2*(c*d-b*e)^2*(b+c*x))+e^2*(B*d-A*e)/_
+     (d^2*(c*d-b*e)^2*(d+e*x))+(b*B*d-2*A*c*d-2*A*b*e)*log(x)/(b^3*d^3)+_
+     c^2*(2*A*c^2*d+3*b^2*B*e-b*c*(B*d+4*A*e))*log(b+c*x)/(b^3*_
+     (c*d-b*e)^3)+e^2*(2*A*e*(2*c*d-b*e)-B*d*(3*c*d-b*e))*log(d+e*x)/_
+     (d^3*(c*d-b*e)^3)
+--R 
+--R
+--R   (2)
+--R                4   5          3 2      4     4       3 2 2 3  3
+--R           (2A b c e  + (- 4A b c  - B b c)d e  + 3B b c d e )x
+--R         + 
+--R                   5 5          4       5    4          3 2       4   2 3
+--R               2A b e  + (- 2A b c - B b )d e  + (- 4A b c  + 2B b c)d e
+--R             + 
+--R                   3 2 3 2
+--R               3B b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                5   4          4       5  2 3       4   3 2
+--R           (2A b d e  + (- 4A b c - B b )d e  + 3B b c d e )x
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                   4       2 3  3 2          5        4  4   3
+--R           ((4A b c  - 3B b c )d e  + (- 2A c  + B b c )d e)x
+--R         + 
+--R                    2 3       3 2  3 2          4       2 3  4
+--R               (4A b c  - 3B b c )d e  + (2A b c  - 2B b c )d e
+--R             + 
+--R                      5        4  5
+--R               (- 2A c  + B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                 2 3       3 2  4             4      2 3  5
+--R           ((4A b c  - 3B b c )d e + (- 2A b c  + B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                     4   5        3 2      4     4       3 2 2 3
+--R               - 2A b c e  + (4A b c  + B b c)d e  - 3B b c d e
+--R             + 
+--R                        4       2 3  3 2        5        4  4
+--R               (- 4A b c  + 3B b c )d e  + (2A c  - B b c )d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     5 5        4       5    4        3 2       4   2 3
+--R               - 2A b e  + (2A b c + B b )d e  + (4A b c  - 2B b c)d e
+--R             + 
+--R                     2 3 3 2            4       2 3  4         5        4  5
+--R               - 4A b c d e  + (- 2A b c  + 2B b c )d e + (2A c  - B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     5   4        4       5  2 3       4   3 2
+--R               - 2A b d e  + (4A b c + B b )d e  - 3B b c d e
+--R             + 
+--R                      2 3       3 2  4           4      2 3  5
+--R               (- 4A b c  + 3B b c )d e + (2A b c  - B b c )d
+--R          *
+--R             x
+--R      *
+--R         log(x)
+--R     + 
+--R                 4     4        3 2      4   2 3       2 3 3 2
+--R           - 2A b c d e  + (4A b c  + B b c)d e  - 4A b c d e
+--R         + 
+--R                  4      2 3  4
+--R           (2A b c  - B b c )d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 5   4        4       5  2 3      4   3 2
+--R           - 2A b d e  + (3A b c + B b )d e  - B b c d e
+--R         + 
+--R                  2 3      3 2  4           4      2 3  5
+--R           (- 3A b c  + B b c )d e + (2A b c  - B b c )d
+--R      *
+--R         x
+--R     + 
+--R            5 2 3       4   3 2       3 2 4       2 3 5
+--R       - A b d e  + 3A b c d e  - 3A b c d e + A b c d
+--R  /
+--R         6   3 4     5 2 4 3     4 3 5 2    3 4 6   3
+--R       (b c d e  - 3b c d e  + 3b c d e  - b c d e)x
+--R     + 
+--R         7 3 4     6   4 3     4 3 6     3 4 7  2
+--R       (b d e  - 2b c d e  + 2b c d e - b c d )x
+--R     + 
+--R         7 4 3     6   5 2     5 2 6     4 3 7
+--R       (b d e  - 3b c d e  + 3b c d e - b c d )x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 1457
+--a0:=integrate(t0,x)
+--E 248
+
+--S 249 of 1457
+--m0:=a0-r0
+--E 249
+
+--S 250 of 1457
+--d0:=D(m0,x)
+--E 250
+
+)clear all
+
+--S 251 of 1457
+t0:=(A+B*x)/((d+e*x)^3*(b*x+c*x^2)^2)
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R        2 3 7          3     2   2  6     2 3           2     2 2   5
+--R       c e x  + (2b c e  + 3c d e )x  + (b e  + 6b c d e  + 3c d e)x
+--R     + 
+--R          2   2         2     2 3  4      2 2          3  3    2 3 2
+--R       (3b d e  + 6b c d e + c d )x  + (3b d e + 2b c d )x  + b d x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 251
+
+--S 252 of 1457
+r0:=-A/(b^2*d^3*x)+c^3*(b*B-A*c)/(b^2*(c*d-b*e)^3*(b+c*x))+1/2*e^2*_
+     (B*d-A*e)/(d^2*(c*d-b*e)^2*(d+e*x)^2)-e^2*(2*A*e*(2*c*d-b*e)-B*d*_
+     (3*c*d-b*e))/(d^3*(c*d-b*e)^3*(d+e*x))+(b*B*d-2*A*c*d-3*A*b*e)*_
+     log(x)/(b^3*d^4)+c^3*(2*A*c^2*d+4*b^2*B*e-b*c*(B*d+5*A*e))*log(b+_
+     c*x)/(b^3*(c*d-b*e)^4)-e^2*(B*d*(6*c^2*d^2-4*b*c*d*e+b^2*e^2)-_
+     A*e*(10*c^2*d^2-10*b*c*d*e+3*b^2*e^2))*log(d+e*x)/(d^4*(c*d-b*e)^4)
+--R 
+--R
+--R   (2)
+--R                   5   7           4 2       5     6         3 3       4 2  2 5
+--R               6A b c e  + (- 20A b c  - 2B b c)d e  + (20A b c  + 8B b c )d e
+--R             + 
+--R                      3 3 3 4
+--R               - 12B b c d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   6 7          5        6    6           4 2       5   2 5
+--R               6A b e  + (- 8A b c - 2B b )d e  + (- 20A b c  + 4B b c)d e
+--R             + 
+--R                     3 3       4 2  3 4        3 3 4 3
+--R               (40A b c  + 4B b c )d e  - 24B b c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    6   6           5        6  2 5         4 2        5   3 4
+--R               12A b d e  + (- 34A b c - 4B b )d e  + (20A b c  + 14B b c)d e
+--R             + 
+--R                     3 3        4 2  4 3        3 3 5 2
+--R               (20A b c  - 16B b c )d e  - 12B b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   6 2 5           5        6  3 4         4 2       5   4 3
+--R               6A b d e  + (- 20A b c - 2B b )d e  + (20A b c  + 8B b c)d e
+--R             + 
+--R                      4 2 5 2
+--R               - 12B b c d e
+--R          *
+--R             x
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                      5       2 4  4 3        6         5  5 2  4
+--R           ((- 10A b c  + 8B b c )d e  + (4A c  - 2B b c )d e )x
+--R         + 
+--R                       2 4       3 3  4 3             5        2 4  5 2
+--R               (- 10A b c  + 8B b c )d e  + (- 16A b c  + 14B b c )d e
+--R             + 
+--R                    6         5  6
+--R               (8A c  - 4B b c )d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       2 4        3 3  5 2            5       2 4  6
+--R               (- 20A b c  + 16B b c )d e  + (- 2A b c  + 4B b c )d e
+--R             + 
+--R                    6         5  7
+--R               (4A c  - 2B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    2 4       3 3  6           5       2 4  7
+--R           ((- 10A b c  + 8B b c )d e + (4A b c  - 2B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                     5   7         4 2       5     6
+--R               - 6A b c e  + (20A b c  + 2B b c)d e
+--R             + 
+--R                       3 3       4 2  2 5        3 3 3 4
+--R               (- 20A b c  - 8B b c )d e  + 12B b c d e
+--R             + 
+--R                       5       2 4  4 3          6         5  5 2
+--R               (10A b c  - 8B b c )d e  + (- 4A c  + 2B b c )d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     6 7        5        6    6         4 2       5   2 5
+--R               - 6A b e  + (8A b c + 2B b )d e  + (20A b c  - 4B b c)d e
+--R             + 
+--R                       3 3       4 2  3 4         2 4        3 3  4 3
+--R               (- 40A b c  - 4B b c )d e  + (10A b c  + 16B b c )d e
+--R             + 
+--R                       5        2 4  5 2          6         5  6
+--R               (16A b c  - 14B b c )d e  + (- 8A c  + 4B b c )d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      6   6         5        6  2 5           4 2        5   3 4
+--R               - 12A b d e  + (34A b c + 4B b )d e  + (- 20A b c  - 14B b c)d e
+--R             + 
+--R                       3 3        4 2  4 3         2 4       3 3  5 2
+--R               (- 20A b c  + 16B b c )d e  + (20A b c  - 4B b c )d e
+--R             + 
+--R                      5       2 4  6           6         5  7
+--R               (2A b c  - 4B b c )d e + (- 4A c  + 2B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     6 2 5         5        6  3 4           4 2       5   4 3
+--R               - 6A b d e  + (20A b c + 2B b )d e  + (- 20A b c  - 8B b c)d e
+--R             + 
+--R                    4 2 5 2         2 4       3 3  6             5       2 4  7
+--R               12B b c d e  + (10A b c  - 8B b c )d e + (- 4A b c  + 2B b c )d
+--R          *
+--R             x
+--R      *
+--R         log(x)
+--R     + 
+--R                 5     6         4 2       5   2 5           3 3       4 2  3 4
+--R           - 6A b c d e  + (20A b c  + 2B b c)d e  + (- 20A b c  - 8B b c )d e
+--R         + 
+--R                 2 4       3 3  4 3            5       2 4  5 2
+--R           (10A b c  + 4B b c )d e  + (- 4A b c  + 2B b c )d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                 6   6         5        6  2 5         4 2       5   3 4
+--R           - 6A b d e  + (11A b c + 2B b )d e  + (10A b c  - 5B b c)d e
+--R         + 
+--R                   3 3       4 2  4 3         2 4       3 3  5 2
+--R           (- 25A b c  - 4B b c )d e  + (18A b c  + 3B b c )d e
+--R         + 
+--R                    5       2 4  6
+--R           (- 8A b c  + 4B b c )d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 6 2 5         5        6  3 4           4 2        5   4 3
+--R           - 9A b d e  + (28A b c + 3B b )d e  + (- 25A b c  - 10B b c)d e
+--R         + 
+--R                3 3       4 2  5 2        2 4       3 3  6
+--R           (4A b c  + 7B b c )d e  + (6A b c  - 2B b c )d e
+--R         + 
+--R                    5       2 4  7
+--R           (- 4A b c  + 2B b c )d
+--R      *
+--R         x
+--R     + 
+--R             6 3 4       5   4 3        4 2 5 2       3 3 6        2 4 7
+--R       - 2A b d e  + 8A b c d e  - 12A b c d e  + 8A b c d e - 2A b c d
+--R  /
+--R          7   4 6     6 2 5 5      5 3 6 4     4 4 7 3     3 5 8 2  4
+--R       (2b c d e  - 8b c d e  + 12b c d e  - 8b c d e  + 2b c d e )x
+--R     + 
+--R          8 4 6     7   5 5     6 2 6 4      5 3 7 3      4 4 8 2     3 5 9   3
+--R       (2b d e  - 4b c d e  - 4b c d e  + 16b c d e  - 14b c d e  + 4b c d e)x
+--R     + 
+--R          8 5 5      7   6 4      6 2 7 3     5 3 8 2     4 4 9      3 5 10  2
+--R       (4b d e  - 14b c d e  + 16b c d e  - 4b c d e  - 4b c d e + 2b c d  )x
+--R     + 
+--R          8 6 4     7   7 3      6 2 8 2     5 3 9      4 4 10
+--R       (2b d e  - 8b c d e  + 12b c d e  - 8b c d e + 2b c d  )x
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 1457
+--a0:=integrate(t0,x)
+--E 253
+
+--S 254 of 1457
+--m0:=a0-r0
+--E 254
+
+--S 255 of 1457
+--d0:=D(m0,x)
+--E 255
+
+)clear all
+
+--S 256 of 1457
+t0:=(A+B*x)*(d+e*x)^5/(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R          5 6       5         4  5          4        2 3  4
+--R       B e x  + (A e  + 5B d e )x  + (5A d e  + 10B d e )x
+--R     + 
+--R           2 3        3 2  3         3 2       4   2        4       5        5
+--R     (10A d e  + 10B d e )x  + (10A d e  + 5B d e)x  + (5A d e + B d )x + A d
+--R  /
+--R      3 6       2 5     2   4    3 3
+--R     c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 256
+
+--S 257 of 1457
+r0:=-1/2*A*d^5/(b^3*x^2)-d^4*(b*B*d-3*A*c*d+5*A*b*e)/(b^4*x)+B*e^5*x/c^3-_
+     1/2*(b*B-A*c)*(c*d-b*e)^5/(b^3*c^4*(b+c*x)^2)-(c*d-b*e)^4*(2*b*B*c*d-_
+     3*A*c^2*d+3*b^2*B*e-2*A*b*c*e)/(b^4*c^4*(b+c*x))+d^3*(6*A*c^2*d^2+_
+     5*b^2*e*(B*d+2*A*e)-3*b*c*d*(B*d+5*A*e))*log(x)/b^5-(c*d-b*e)^3*_
+     (6*A*c^3*d^2-3*b^3*B*e^2-3*b*c^2*d*(B*d-A*e)-b^2*c*e*(4*B*d-A*e))*_
+     log(b+c*x)/(b^5*c^4)
+--R 
+--R
+--R   (2)
+--R                    5 3       6 2  5        5 3   4        2 6 3 2
+--R               (2A b c  - 6B b c )e  + 10B b c d e  - 20A b c d e
+--R             + 
+--R                       7        2 6  4            8         7  5
+--R               (30A b c  - 10B b c )d e + (- 12A c  + 6B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    6 2        7   5        6 2   4        3 5 3 2
+--R               (4A b c  - 12B b c)e  + 20B b c d e  - 40A b c d e
+--R             + 
+--R                     2 6        3 5  4              7        2 6  5
+--R               (60A b c  - 20B b c )d e + (- 24A b c  + 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    7        8  5        7     4        4 4 3 2
+--R               (2A b c - 6B b )e  + 10B b c d e  - 20A b c d e
+--R             + 
+--R                     3 5        4 4  4            2 6       3 5  5
+--R               (30A b c  - 10B b c )d e + (- 12A b c  + 6B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                 2 6 3 2             7        2 6  4          8         7  5  4
+--R           (20A b c d e  + (- 30A b c  + 10B b c )d e + (12A c  - 6B b c )d )x
+--R         + 
+--R                      3 5 3 2           2 6        3 5  4
+--R                 40A b c d e  + (- 60A b c  + 20B b c )d e
+--R               + 
+--R                         7        2 6  5
+--R                 (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R               4 4 3 2           3 5        4 4  4          2 6       3 5  5  2
+--R         (20A b c d e  + (- 30A b c  + 10B b c )d e + (12A b c  - 6B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R           5 3 5 5       6 2 5 4
+--R       2B b c e x  + 4B b c e x
+--R     + 
+--R                6 2       7   5           5 3        6 2    4        5 3 2 3
+--R           (4A b c  - 4B b c)e  + (- 10A b c  + 20B b c )d e  - 20B b c d e
+--R         + 
+--R                3 5 3 2           2 6        3 5  4            7       2 6  5
+--R           20A b c d e  + (- 30A b c  + 10B b c )d e + (12A b c  - 6B b c )d
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                7        8  5          6 2        7     4
+--R           (3A b c - 5B b )e  + (- 5A b c  + 15B b c)d e
+--R         + 
+--R                   5 3        6 2  2 3         4 4        5 3  3 2
+--R           (- 10A b c  - 10B b c )d e  + (30A b c  - 10B b c )d e
+--R         + 
+--R                   3 5        4 4  4          2 6       3 5  5
+--R           (- 45A b c  + 15B b c )d e + (18A b c  - 9B b c )d
+--R      *
+--R          2
+--R         x
+--R     + 
+--R               4 4 4         3 5       4 4  5        4 4 5
+--R       (- 10A b c d e + (4A b c  - 2B b c )d )x - A b c d
+--R  /
+--R       5 6 4     6 5 3     7 4 2
+--R     2b c x  + 4b c x  + 2b c x
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    5 3       6 2  5        5 3   4        2 6 3 2
+--R               (2A b c  - 6B b c )e  + 10B b c d e  - 20A b c d e
+--R             + 
+--R                       7        2 6  4            8         7  5
+--R               (30A b c  - 10B b c )d e + (- 12A c  + 6B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    6 2        7   5        6 2   4        3 5 3 2
+--R               (4A b c  - 12B b c)e  + 20B b c d e  - 40A b c d e
+--R             + 
+--R                     2 6        3 5  4              7        2 6  5
+--R               (60A b c  - 20B b c )d e + (- 24A b c  + 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    7        8  5        7     4        4 4 3 2
+--R               (2A b c - 6B b )e  + 10B b c d e  - 20A b c d e
+--R             + 
+--R                     3 5        4 4  4            2 6       3 5  5
+--R               (30A b c  - 10B b c )d e + (- 12A b c  + 6B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                 2 6 3 2             7        2 6  4          8         7  5  4
+--R           (20A b c d e  + (- 30A b c  + 10B b c )d e + (12A c  - 6B b c )d )x
+--R         + 
+--R                      3 5 3 2           2 6        3 5  4
+--R                 40A b c d e  + (- 60A b c  + 20B b c )d e
+--R               + 
+--R                         7        2 6  5
+--R                 (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R               4 4 3 2           3 5        4 4  4          2 6       3 5  5  2
+--R         (20A b c d e  + (- 30A b c  + 10B b c )d e + (12A b c  - 6B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R           5 3 5 5       6 2 5 4
+--R       2B b c e x  + 4B b c e x
+--R     + 
+--R                6 2       7   5           5 3        6 2    4        5 3 2 3
+--R           (4A b c  - 4B b c)e  + (- 10A b c  + 20B b c )d e  - 20B b c d e
+--R         + 
+--R                3 5 3 2           2 6        3 5  4            7       2 6  5
+--R           20A b c d e  + (- 30A b c  + 10B b c )d e + (12A b c  - 6B b c )d
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                7        8  5          6 2        7     4
+--R           (3A b c - 5B b )e  + (- 5A b c  + 15B b c)d e
+--R         + 
+--R                   5 3        6 2  2 3         4 4        5 3  3 2
+--R           (- 10A b c  - 10B b c )d e  + (30A b c  - 10B b c )d e
+--R         + 
+--R                   3 5        4 4  4          2 6       3 5  5
+--R           (- 45A b c  + 15B b c )d e + (18A b c  - 9B b c )d
+--R      *
+--R          2
+--R         x
+--R     + 
+--R               4 4 4         3 5       4 4  5        4 4 5
+--R       (- 10A b c d e + (4A b c  - 2B b c )d )x - A b c d
+--R  /
+--R       5 6 4     6 5 3     7 4 2
+--R     2b c x  + 4b c x  + 2b c x
+--R                                         Type: Union(Expression(Integer),...)
+--E 258
+
+--S 259 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 260
+
+)clear all
+
+--S 261 of 1457
+t0:=(A+B*x)*(d+e*x)^4/(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R          4 5       4         3  4          3       2 2  3
+--R       B e x  + (A e  + 4B d e )x  + (4A d e  + 6B d e )x
+--R     + 
+--R            2 2       3   2        3       4        4
+--R       (6A d e  + 4B d e)x  + (4A d e + B d )x + A d
+--R  /
+--R      3 6       2 5     2   4    3 3
+--R     c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 261
+
+--S 262 of 1457
+r0:=-1/2*A*d^4/(b^3*x^2)-d^3*(b*B*d-3*A*c*d+4*A*b*e)/(b^4*x)-1/2*(b*B-_
+     A*c)*(c*d-b*e)^4/(b^3*c^3*(b+c*x)^2)+(c*d-b*e)^3*(3*A*c^2*d-2*b^2*_
+     B*e-b*c*(2*B*d-A*e))/(b^4*c^3*(b+c*x))+d^2*(6*A*c^2*d^2+2*b^2*e*_
+     (2*B*d+3*A*e)-3*b*c*d*(B*d+4*A*e))*log(x)/b^5+(c*d-b*e)^2*(3*b*B*_
+     c^2*d^2-6*A*c^3*d^2+2*b^2*B*c*d*e+b^3*B*e^2)*log(b+c*x)/(b^5*c^3)
+--R 
+--R
+--R   (2)
+--R                   5 2 4        2 5 2 2           6       2 5  3
+--R               2B b c e  - 12A b c d e  + (24A b c  - 8B b c )d e
+--R             + 
+--R                       7         6  4
+--R               (- 12A c  + 6B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   6   4        3 4 2 2         2 5        3 4  3
+--R               4B b c e  - 24A b c d e  + (48A b c  - 16B b c )d e
+--R             + 
+--R                         6        2 5  4
+--R               (- 24A b c  + 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   7 4        4 3 2 2         3 4       4 3  3
+--R               2B b e  - 12A b c d e  + (24A b c  - 8B b c )d e
+--R             + 
+--R                       2 5       3 4  4
+--R               (- 12A b c  + 6B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                 2 5 2 2             6       2 5  3          7         6  4  4
+--R           (12A b c d e  + (- 24A b c  + 8B b c )d e + (12A c  - 6B b c )d )x
+--R         + 
+--R                      3 4 2 2           2 5        3 4  3
+--R                 24A b c d e  + (- 48A b c  + 16B b c )d e
+--R               + 
+--R                         6        2 5  4
+--R                 (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R               4 3 2 2           3 4       4 3  3          2 5       3 4  4  2
+--R         (12A b c d e  + (- 24A b c  + 8B b c )d e + (12A b c  - 6B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R                  5 2       6   4       5 2   3        3 4 2 2
+--R           (- 2A b c  + 4B b c)e  - 8B b c d e  + 12A b c d e
+--R         + 
+--R                   2 5       3 4  3            6       2 5  4
+--R           (- 24A b c  + 8B b c )d e + (12A b c  - 6B b c )d
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                 6        7  4          5 2       6     3
+--R           (- A b c + 3B b )e  + (- 4A b c  - 4B b c)d e
+--R         + 
+--R                 4 3       5 2  2 2           3 4        4 3  3
+--R           (18A b c  - 6B b c )d e  + (- 36A b c  + 12B b c )d e
+--R         + 
+--R                 2 5       3 4  4
+--R           (18A b c  - 9B b c )d
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              4 3 3         3 4       4 3  4        4 3 4
+--R       (- 8A b c d e + (4A b c  - 2B b c )d )x - A b c d
+--R  /
+--R       5 5 4     6 4 3     7 3 2
+--R     2b c x  + 4b c x  + 2b c x
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   5 2 4        2 5 2 2           6       2 5  3
+--R               2B b c e  - 12A b c d e  + (24A b c  - 8B b c )d e
+--R             + 
+--R                       7         6  4
+--R               (- 12A c  + 6B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   6   4        3 4 2 2         2 5        3 4  3
+--R               4B b c e  - 24A b c d e  + (48A b c  - 16B b c )d e
+--R             + 
+--R                         6        2 5  4
+--R               (- 24A b c  + 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   7 4        4 3 2 2         3 4       4 3  3
+--R               2B b e  - 12A b c d e  + (24A b c  - 8B b c )d e
+--R             + 
+--R                       2 5       3 4  4
+--R               (- 12A b c  + 6B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                 2 5 2 2             6       2 5  3          7         6  4  4
+--R           (12A b c d e  + (- 24A b c  + 8B b c )d e + (12A c  - 6B b c )d )x
+--R         + 
+--R                      3 4 2 2           2 5        3 4  3
+--R                 24A b c d e  + (- 48A b c  + 16B b c )d e
+--R               + 
+--R                         6        2 5  4
+--R                 (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R               4 3 2 2           3 4       4 3  3          2 5       3 4  4  2
+--R         (12A b c d e  + (- 24A b c  + 8B b c )d e + (12A b c  - 6B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R                  5 2       6   4       5 2   3        3 4 2 2
+--R           (- 2A b c  + 4B b c)e  - 8B b c d e  + 12A b c d e
+--R         + 
+--R                   2 5       3 4  3            6       2 5  4
+--R           (- 24A b c  + 8B b c )d e + (12A b c  - 6B b c )d
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                 6        7  4          5 2       6     3
+--R           (- A b c + 3B b )e  + (- 4A b c  - 4B b c)d e
+--R         + 
+--R                 4 3       5 2  2 2           3 4        4 3  3
+--R           (18A b c  - 6B b c )d e  + (- 36A b c  + 12B b c )d e
+--R         + 
+--R                 2 5       3 4  4
+--R           (18A b c  - 9B b c )d
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              4 3 3         3 4       4 3  4        4 3 4
+--R       (- 8A b c d e + (4A b c  - 2B b c )d )x - A b c d
+--R  /
+--R       5 5 4     6 4 3     7 3 2
+--R     2b c x  + 4b c x  + 2b c x
+--R                                         Type: Union(Expression(Integer),...)
+--E 263
+
+--S 264 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 265
+
+)clear all
+
+--S 266 of 1457
+t0:=(A+B*x)*(d+e*x)^3/(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R      3 4       3         2  3          2       2   2        2       3        3
+--R   B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x + A d
+--R   ----------------------------------------------------------------------------
+--R                           3 6       2 5     2   4    3 3
+--R                          c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 266
+
+--S 267 of 1457
+r0:=-1/2*A*d^3/(b^3*x^2)-d^2*(b*B*d-3*A*c*d+3*A*b*e)/(b^4*x)-1/2*(b*B-A*c)*_
+     (c*d-b*e)^3/(b^3*c^2*(b+c*x)^2)-(c*d-b*e)^2*(2*b*B*c*d-3*A*c^2*d+_
+     b^2*B*e)/(b^4*c^2*(b+c*x))-3*d*(c*d-b*e)*(b*B*d-2*A*c*d+A*b*e)*_
+     log(x)/b^5+3*d*(c*d-b*e)*(b*B*d-2*A*c*d+A*b*e)*log(b+c*x)/b^5
+--R 
+--R
+--R   (2)
+--R                  2 4   2           5       2 4  2            6         5  3  4
+--R           (- 6A b c d e  + (18A b c  - 6B b c )d e + (- 12A c  + 6B b c )d )x
+--R         + 
+--R                      3 3   2         2 4        3 3  2
+--R               - 12A b c d e  + (36A b c  - 12B b c )d e
+--R             + 
+--R                         5        2 4  3
+--R               (- 24A b c  + 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                4 2   2         3 3       4 2  2            2 4       3 3  3  2
+--R         (- 6A b c d e  + (18A b c  - 6B b c )d e + (- 12A b c  + 6B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                2 4   2             5       2 4  2          6         5  3  4
+--R           (6A b c d e  + (- 18A b c  + 6B b c )d e + (12A c  - 6B b c )d )x
+--R         + 
+--R                      3 3   2           2 4        3 3  2
+--R                 12A b c d e  + (- 36A b c  + 12B b c )d e
+--R               + 
+--R                         5        2 4  3
+--R                 (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                4 2   2           3 3       4 2  2          2 4       3 3  3  2
+--R           (6A b c d e  + (- 18A b c  + 6B b c )d e + (12A b c  - 6B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R                 5   3       3 3   2           2 4       3 3  2
+--R           - 2B b c e  + 6A b c d e  + (- 18A b c  + 6B b c )d e
+--R         + 
+--R                   5       2 4  3
+--R           (12A b c  - 6B b c )d
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                 5       6  3        4 2       5     2
+--R           (- A b c - B b )e  + (9A b c  - 3B b c)d e
+--R         + 
+--R                   3 3       4 2  2          2 4       3 3  3
+--R           (- 27A b c  + 9B b c )d e + (18A b c  - 9B b c )d
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              4 2 2         3 3       4 2  3        4 2 3
+--R       (- 6A b c d e + (4A b c  - 2B b c )d )x - A b c d
+--R  /
+--R       5 4 4     6 3 3     7 2 2
+--R     2b c x  + 4b c x  + 2b c x
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2 4   2           5       2 4  2            6         5  3  4
+--R           (- 6A b c d e  + (18A b c  - 6B b c )d e + (- 12A c  + 6B b c )d )x
+--R         + 
+--R                      3 3   2         2 4        3 3  2
+--R               - 12A b c d e  + (36A b c  - 12B b c )d e
+--R             + 
+--R                         5        2 4  3
+--R               (- 24A b c  + 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                4 2   2         3 3       4 2  2            2 4       3 3  3  2
+--R         (- 6A b c d e  + (18A b c  - 6B b c )d e + (- 12A b c  + 6B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                2 4   2             5       2 4  2          6         5  3  4
+--R           (6A b c d e  + (- 18A b c  + 6B b c )d e + (12A c  - 6B b c )d )x
+--R         + 
+--R                      3 3   2           2 4        3 3  2
+--R                 12A b c d e  + (- 36A b c  + 12B b c )d e
+--R               + 
+--R                         5        2 4  3
+--R                 (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                4 2   2           3 3       4 2  2          2 4       3 3  3  2
+--R           (6A b c d e  + (- 18A b c  + 6B b c )d e + (12A b c  - 6B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R                 5   3       3 3   2           2 4       3 3  2
+--R           - 2B b c e  + 6A b c d e  + (- 18A b c  + 6B b c )d e
+--R         + 
+--R                   5       2 4  3
+--R           (12A b c  - 6B b c )d
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                 5       6  3        4 2       5     2
+--R           (- A b c - B b )e  + (9A b c  - 3B b c)d e
+--R         + 
+--R                   3 3       4 2  2          2 4       3 3  3
+--R           (- 27A b c  + 9B b c )d e + (18A b c  - 9B b c )d
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              4 2 2         3 3       4 2  3        4 2 3
+--R       (- 6A b c d e + (4A b c  - 2B b c )d )x - A b c d
+--R  /
+--R       5 4 4     6 3 3     7 2 2
+--R     2b c x  + 4b c x  + 2b c x
+--R                                         Type: Union(Expression(Integer),...)
+--E 268
+
+--S 269 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 1457
+t0:=(A+B*x)*(d+e*x)^2/(b*x+c*x^2)^3
+--R 
+--R
+--R           2 3       2           2                2        2
+--R        B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d
+--R   (1)  ----------------------------------------------------
+--R                    3 6       2 5     2   4    3 3
+--R                   c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 271
+
+--S 272 of 1457
+r0:=-1/2*A*d^2/(b^3*x^2)-d*(b*B*d-3*A*c*d+2*A*b*e)/(b^4*x)-1/2*(b*B-A*c)*_
+     (c*d-b*e)^2/(b^3*c*(b+c*x)^2)-(c*d-b*e)*(2*b*B*d-3*A*c*d+A*b*e)/_
+     (b^4*(b+c*x))+(6*A*c^2*d^2+b^2*e*(2*B*d+A*e)-3*b*c*d*(B*d+2*A*e))*_
+     log(x)/b^5-(6*A*c^2*d^2+b^2*e*(2*B*d+A*e)-3*b*c*d*(B*d+2*A*e))*_
+     log(b+c*x)/b^5
+--R 
+--R
+--R   (2)
+--R                  2 3 2           4       2 3               5         4  2  4
+--R           (- 2A b c e  + (12A b c  - 4B b c )d e + (- 12A c  + 6B b c )d )x
+--R         + 
+--R                  3 2 2         2 3       3 2                 4        2 3  2  3
+--R           (- 4A b c e  + (24A b c  - 8B b c )d e + (- 24A b c  + 12B b c )d )x
+--R         + 
+--R                  4   2         3 2       4                2 3       3 2  2  2
+--R           (- 2A b c e  + (12A b c  - 4B b c)d e + (- 12A b c  + 6B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                2 3 2             4       2 3             5         4  2  4
+--R           (2A b c e  + (- 12A b c  + 4B b c )d e + (12A c  - 6B b c )d )x
+--R         + 
+--R                3 2 2           2 3       3 2               4        2 3  2  3
+--R           (4A b c e  + (- 24A b c  + 8B b c )d e + (24A b c  - 12B b c )d )x
+--R         + 
+--R                4   2           3 2       4              2 3       3 2  2  2
+--R           (2A b c e  + (- 12A b c  + 4B b c)d e + (12A b c  - 6B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R            3 2 2           2 3       3 2               4       2 3  2  3
+--R       (2A b c e  + (- 12A b c  + 4B b c )d e + (12A b c  - 6B b c )d )x
+--R     + 
+--R             4       5  2           3 2       4              2 3       3 2  2  2
+--R       ((3A b c - B b )e  + (- 18A b c  + 6B b c)d e + (18A b c  - 9B b c )d )x
+--R     + 
+--R              4             3 2       4   2        4   2
+--R       (- 4A b c d e + (4A b c  - 2B b c)d )x - A b c d
+--R  /
+--R       5 3 4     6 2 3     7   2
+--R     2b c x  + 4b c x  + 2b c x
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2 3 2           4       2 3               5         4  2  4
+--R           (- 2A b c e  + (12A b c  - 4B b c )d e + (- 12A c  + 6B b c )d )x
+--R         + 
+--R                  3 2 2         2 3       3 2                 4        2 3  2  3
+--R           (- 4A b c e  + (24A b c  - 8B b c )d e + (- 24A b c  + 12B b c )d )x
+--R         + 
+--R                  4   2         3 2       4                2 3       3 2  2  2
+--R           (- 2A b c e  + (12A b c  - 4B b c)d e + (- 12A b c  + 6B b c )d )x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                2 3 2             4       2 3             5         4  2  4
+--R           (2A b c e  + (- 12A b c  + 4B b c )d e + (12A c  - 6B b c )d )x
+--R         + 
+--R                3 2 2           2 3       3 2               4        2 3  2  3
+--R           (4A b c e  + (- 24A b c  + 8B b c )d e + (24A b c  - 12B b c )d )x
+--R         + 
+--R                4   2           3 2       4              2 3       3 2  2  2
+--R           (2A b c e  + (- 12A b c  + 4B b c)d e + (12A b c  - 6B b c )d )x
+--R      *
+--R         log(x)
+--R     + 
+--R            3 2 2           2 3       3 2               4       2 3  2  3
+--R       (2A b c e  + (- 12A b c  + 4B b c )d e + (12A b c  - 6B b c )d )x
+--R     + 
+--R             4       5  2           3 2       4              2 3       3 2  2  2
+--R       ((3A b c - B b )e  + (- 18A b c  + 6B b c)d e + (18A b c  - 9B b c )d )x
+--R     + 
+--R              4             3 2       4   2        4   2
+--R       (- 4A b c d e + (4A b c  - 2B b c)d )x - A b c d
+--R  /
+--R       5 3 4     6 2 3     7   2
+--R     2b c x  + 4b c x  + 2b c x
+--R                                         Type: Union(Expression(Integer),...)
+--E 273
+
+--S 274 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 275
+
+)clear all
+
+--S 276 of 1457
+t0:=(A+B*x)*(d+e*x)/(b*x+c*x^2)^3
+--R 
+--R
+--R               2
+--R          B e x  + (A e + B d)x + A d
+--R   (1)  -------------------------------
+--R         3 6       2 5     2   4    3 3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 276
+
+--S 277 of 1457
+r0:=-1/2*A*d/(b^3*x^2)+(-b*B*d+3*A*c*d-A*b*e)/(b^4*x)-1/2*(b*B-A*c)*_
+     (c*d-b*e)/(b^3*(b+c*x)^2)+(3*A*c^2*d+b^2*B*e-2*b*c*(B*d+A*e))/_
+     (b^4*(b+c*x))+(6*A*c^2*d+b^2*B*e-3*b*c*(B*d+A*e))*log(x)/b^5-_
+     (6*A*c^2*d+b^2*B*e-3*b*c*(B*d+A*e))*log(b+c*x)/b^5
+--R 
+--R
+--R   (2)
+--R                   3       2 2             4         3    4
+--R           ((6A b c  - 2B b c )e + (- 12A c  + 6B b c )d)x
+--R         + 
+--R                  2 2       3                3        2 2    3
+--R           ((12A b c  - 4B b c)e + (- 24A b c  + 12B b c )d)x
+--R         + 
+--R                 3        4             2 2       3     2
+--R           ((6A b c - 2B b )e + (- 12A b c  + 6B b c)d)x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                     3       2 2           4         3    4
+--R           ((- 6A b c  + 2B b c )e + (12A c  - 6B b c )d)x
+--R         + 
+--R                    2 2       3              3        2 2    3
+--R           ((- 12A b c  + 4B b c)e + (24A b c  - 12B b c )d)x
+--R         + 
+--R                   3        4           2 2       3     2
+--R           ((- 6A b c + 2B b )e + (12A b c  - 6B b c)d)x
+--R      *
+--R         log(x)
+--R     + 
+--R               2 2       3              3       2 2    3
+--R       ((- 6A b c  + 2B b c)e + (12A b c  - 6B b c )d)x
+--R     + 
+--R               3        4           2 2       3     2
+--R       ((- 9A b c + 3B b )e + (18A b c  - 9B b c)d)x
+--R     + 
+--R              4         3        4          4
+--R       (- 2A b e + (4A b c - 2B b )d)x - A b d
+--R  /
+--R       5 2 4     6   3     7 2
+--R     2b c x  + 4b c x  + 2b x
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   3       2 2             4         3    4
+--R           ((6A b c  - 2B b c )e + (- 12A c  + 6B b c )d)x
+--R         + 
+--R                  2 2       3                3        2 2    3
+--R           ((12A b c  - 4B b c)e + (- 24A b c  + 12B b c )d)x
+--R         + 
+--R                 3        4             2 2       3     2
+--R           ((6A b c - 2B b )e + (- 12A b c  + 6B b c)d)x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                     3       2 2           4         3    4
+--R           ((- 6A b c  + 2B b c )e + (12A c  - 6B b c )d)x
+--R         + 
+--R                    2 2       3              3        2 2    3
+--R           ((- 12A b c  + 4B b c)e + (24A b c  - 12B b c )d)x
+--R         + 
+--R                   3        4           2 2       3     2
+--R           ((- 6A b c + 2B b )e + (12A b c  - 6B b c)d)x
+--R      *
+--R         log(x)
+--R     + 
+--R               2 2       3              3       2 2    3
+--R       ((- 6A b c  + 2B b c)e + (12A b c  - 6B b c )d)x
+--R     + 
+--R               3        4           2 2       3     2
+--R       ((- 9A b c + 3B b )e + (18A b c  - 9B b c)d)x
+--R     + 
+--R              4         3        4          4
+--R       (- 2A b e + (4A b c - 2B b )d)x - A b d
+--R  /
+--R       5 2 4     6   3     7 2
+--R     2b c x  + 4b c x  + 2b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 278
+
+--S 279 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 1457
+t0:=(A+B*x)/(b*x+c*x^2)^3
+--R 
+--R
+--R                    B x + A
+--R   (1)  -------------------------------
+--R         3 6       2 5     2   4    3 3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 281
+
+--S 282 of 1457
+r0:=-1/2*A/(b^3*x^2)+(-b*B+3*A*c)/(b^4*x)-1/2*c*(b*B-A*c)/(b^3*(b+c*x)^2)-_
+     c*(2*b*B-3*A*c)/(b^4*(b+c*x))-3*c*(b*B-2*A*c)*log(x)/b^5+3*c*(b*B-_
+     2*A*c)*log(b+c*x)/b^5
+--R 
+--R
+--R   (2)
+--R                   4         3  4             3        2 2  3
+--R           (- 12A c  + 6B b c )x  + (- 24A b c  + 12B b c )x
+--R         + 
+--R                   2 2       3   2
+--R           (- 12A b c  + 6B b c)x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                   4         3  4           3        2 2  3
+--R             (12A c  - 6B b c )x  + (24A b c  - 12B b c )x
+--R           + 
+--R                   2 2       3   2
+--R             (12A b c  - 6B b c)x
+--R      *
+--R         log(x)
+--R     + 
+--R             3       2 2  3         2 2       3   2        3        4        4
+--R     (12A b c  - 6B b c )x  + (18A b c  - 9B b c)x  + (4A b c - 2B b )x - A b
+--R  /
+--R       5 2 4     6   3     7 2
+--R     2b c x  + 4b c x  + 2b x
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   4         3  4             3        2 2  3
+--R           (- 12A c  + 6B b c )x  + (- 24A b c  + 12B b c )x
+--R         + 
+--R                   2 2       3   2
+--R           (- 12A b c  + 6B b c)x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                   4         3  4           3        2 2  3
+--R             (12A c  - 6B b c )x  + (24A b c  - 12B b c )x
+--R           + 
+--R                   2 2       3   2
+--R             (12A b c  - 6B b c)x
+--R      *
+--R         log(x)
+--R     + 
+--R             3       2 2  3         2 2       3   2        3        4        4
+--R     (12A b c  - 6B b c )x  + (18A b c  - 9B b c)x  + (4A b c - 2B b )x - A b
+--R  /
+--R       5 2 4     6   3     7 2
+--R     2b c x  + 4b c x  + 2b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 283
+
+--S 284 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 1457
+t0:=(A+B*x)/((d+e*x)*(b*x+c*x^2)^3)
+--R 
+--R
+--R   (1)
+--R                                     B x + A
+--R   ---------------------------------------------------------------------------
+--R    3   7        2     3   6      2          2   5     3      2     4    3   3
+--R   c e x  + (3b c e + c d)x  + (3b c e + 3b c d)x  + (b e + 3b c d)x  + b d x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 286
+
+--S 287 of 1457
+r0:=-1/2*A/(b^3*d*x^2)+(-b*B*d+3*A*c*d+A*b*e)/(b^4*d^2*x)-1/2*c^2*(b*B-_
+     A*c)/(b^3*(c*d-b*e)*(b+c*x)^2)+c^2*(3*A*c^2*d+3*b^2*B*e-2*b*c*(B*d+_
+     2*A*e))/(b^4*(c*d-b*e)^2*(b+c*x))+(6*A*c^2*d^2-3*b*c*d*(B*d-A*e)-_
+     b^2*e*(B*d-A*e))*log(x)/(b^5*d^3)-c^2*(6*A*c^3*d^2-6*b^3*B*e^2-_
+     3*b*c^2*d*(B*d+5*A*e)+2*b^2*c*e*(4*B*d+5*A*e))*log(b+c*x)/(b^5*(c*d-_
+     b*e)^3)-e^4*(B*d-A*e)*log(d+e*x)/(d^3*(c*d-b*e)^3)
+--R 
+--R
+--R   (2)
+--R                  5 2 5       5 2   4  4          6   5       6     4  3
+--R           (- 2A b c e  + 2B b c d e )x  + (- 4A b c e  + 4B b c d e )x
+--R         + 
+--R                  7 5       7   4  2
+--R           (- 2A b e  + 2B b d e )x
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                     2 5        3 4  3 2             6        2 5  4
+--R               (20A b c  - 12B b c )d e  + (- 30A b c  + 16B b c )d e
+--R             + 
+--R                     7         6  5
+--R               (12A c  - 6B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     3 4        4 3  3 2           2 5        3 4  4
+--R               (40A b c  - 24B b c )d e  + (- 60A b c  + 32B b c )d e
+--R             + 
+--R                       6        2 5  5
+--R               (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     4 3        5 2  3 2           3 4        4 3  4
+--R               (20A b c  - 12B b c )d e  + (- 30A b c  + 16B b c )d e
+--R             + 
+--R                     2 5       3 4  5
+--R               (12A b c  - 6B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                   5 2 5       5 2   4           2 5        3 4  3 2
+--R               2A b c e  - 2B b c d e  + (- 20A b c  + 12B b c )d e
+--R             + 
+--R                       6        2 5  4            7         6  5
+--R               (30A b c  - 16B b c )d e + (- 12A c  + 6B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   6   5       6     4           3 4        4 3  3 2
+--R               4A b c e  - 4B b c d e  + (- 40A b c  + 24B b c )d e
+--R             + 
+--R                     2 5        3 4  4              6        2 5  5
+--R               (60A b c  - 32B b c )d e + (- 24A b c  + 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   7 5       7   4           4 3        5 2  3 2
+--R               2A b e  - 2B b d e  + (- 20A b c  + 12B b c )d e
+--R             + 
+--R                     3 4        4 3  4            2 5       3 4  5
+--R               (30A b c  - 16B b c )d e + (- 12A b c  + 6B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R         log(x)
+--R     + 
+--R               5 2   4       5 2 2 3           3 4        4 3  3 2
+--R           2A b c d e  - 2B b c d e  + (- 20A b c  + 12B b c )d e
+--R         + 
+--R                 2 5        3 4  4              6       2 5  5
+--R           (30A b c  - 16B b c )d e + (- 12A b c  + 6B b c )d
+--R      *
+--R          3
+--R         x
+--R     + 
+--R               6     4         5 2       6   2 3           4 3        5 2  3 2
+--R           4A b c d e  + (- A b c  - 4B b c)d e  + (- 30A b c  + 19B b c )d e
+--R         + 
+--R                 3 4        4 3  4            2 5       3 4  5
+--R           (45A b c  - 24B b c )d e + (- 18A b c  + 9B b c )d
+--R      *
+--R          2
+--R         x
+--R     + 
+--R               7   4          6        7  2 3          5 2       6   3 2
+--R           2A b d e  + (- 2A b c - 2B b )d e  + (- 6A b c  + 6B b c)d e
+--R         + 
+--R                 4 3       5 2  4           3 4       4 3  5
+--R           (10A b c  - 6B b c )d e + (- 4A b c  + 2B b c )d
+--R      *
+--R         x
+--R     + 
+--R            7 2 3       6   3 2       5 2 4       4 3 5
+--R       - A b d e  + 3A b c d e  - 3A b c d e + A b c d
+--R  /
+--R          8 2 3 3     7 3 4 2     6 4 5      5 5 6  4
+--R       (2b c d e  - 6b c d e  + 6b c d e - 2b c d )x
+--R     + 
+--R          9   3 3      8 2 4 2      7 3 5      6 4 6  3
+--R       (4b c d e  - 12b c d e  + 12b c d e - 4b c d )x
+--R     + 
+--R          10 3 3     9   4 2     8 2 5      7 3 6  2
+--R       (2b  d e  - 6b c d e  + 6b c d e - 2b c d )x
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 1457
+--a0:=integrate(t0,x)
+--E 288
+
+--S 289 of 1457
+--m0:=a0-r0
+--E 289
+
+--S 290 of 1457
+--d0:=D(m0,x)
+--E 290
+
+)clear all
+
+--S 291 of 1457
+t0:=(A+B*x)/((d+e*x)^2*(b*x+c*x^2)^3)
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R        3 2 8        2 2     3     7      2   2       2       3 2  6
+--R       c e x  + (3b c e  + 2c d e)x  + (3b c e  + 6b c d e + c d )x
+--R     + 
+--R         3 2     2            2 2  5      3        2   2  4    3 2 3
+--R       (b e  + 6b c d e + 3b c d )x  + (2b d e + 3b c d )x  + b d x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 291
+
+--S 292 of 1457
+r0:=-1/2*A/(b^3*d^2*x^2)+(-b*B*d+3*A*c*d+2*A*b*e)/(b^4*d^3*x)-1/2*c^3*(b*B-_
+     A*c)/(b^3*(c*d-b*e)^2*(b+c*x)^2)-c^3*(2*b*B*c*d-3*A*c^2*d-4*b^2*B*e+_
+     5*A*b*c*e)/(b^4*(c*d-b*e)^3*(b+c*x))+e^4*(B*d-A*e)/(d^3*(c*d-b*e)^3*_
+     (d+e*x))+(6*A*c^2*d^2-b^2*e*(2*B*d-3*A*e)-3*b*c*d*(B*d-2*A*e))*_
+     log(x)/(b^5*d^4)-c^3*(6*A*c^3*d^2-10*b^3*B*e^2+5*b^2*c*e*(2*B*d+_
+     3*A*e)-3*b*c^2*d*(B*d+6*A*e))*log(b+c*x)/(b^5*(c*d-b*e)^4)-e^4*_
+     (B*d*(5*c*d-2*b*e)-3*A*e*(2*c*d-b*e))*log(d+e*x)/(d^4*(c*d-b*e)^4)
+--R 
+--R
+--R   (2)
+--R                  6 2 7         5 3       6 2    6        5 3 2 5  5
+--R           (- 6A b c e  + (12A b c  + 4B b c )d e  - 10B b c d e )x
+--R         + 
+--R                      7   7         6 2       7     6
+--R               - 12A b c e  + (18A b c  + 8B b c)d e
+--R             + 
+--R                     5 3        6 2  2 5        5 3 3 4
+--R               (12A b c  - 16B b c )d e  - 10B b c d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                  8 7       8   6         6 2       7   2 5        6 2 3 4  3
+--R           (- 6A b e  + 4B b d e  + (24A b c  - 2B b c)d e  - 20B b c d e )x
+--R         + 
+--R                  8   6         7        8  2 5        7   3 4  2
+--R           (- 6A b d e  + (12A b c + 4B b )d e  - 10B b c d e )x
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                       2 6        3 5  4 3           7        2 6  5 2
+--R               (- 30A b c  + 20B b c )d e  + (36A b c  - 20B b c )d e
+--R             + 
+--R                       8         7  6
+--R               (- 12A c  + 6B b c )d e
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                       3 5        4 4  4 3         2 6        3 5  5 2
+--R               (- 60A b c  + 40B b c )d e  + (42A b c  - 20B b c )d e
+--R             + 
+--R                       7       2 6  6            8         7  7
+--R               (12A b c  - 8B b c )d e + (- 12A c  + 6B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       4 4        5 3  4 3           3 5        4 4  5 2
+--R               (- 30A b c  + 20B b c )d e  + (- 24A b c  + 20B b c )d e
+--R             + 
+--R                     2 6        3 5  6              7        2 6  7
+--R               (60A b c  - 34B b c )d e + (- 24A b c  + 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       4 4        5 3  5 2         3 5        4 4  6
+--R               (- 30A b c  + 20B b c )d e  + (36A b c  - 20B b c )d e
+--R             + 
+--R                       2 6       3 5  7
+--R               (- 12A b c  + 6B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R         log(c x + b)
+--R     + 
+--R                   6 2 7           5 3       6 2    6        5 3 2 5
+--R               6A b c e  + (- 12A b c  - 4B b c )d e  + 10B b c d e
+--R             + 
+--R                     2 6        3 5  4 3             7        2 6  5 2
+--R               (30A b c  - 20B b c )d e  + (- 36A b c  + 20B b c )d e
+--R             + 
+--R                     8         7  6
+--R               (12A c  - 6B b c )d e
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    7   7           6 2       7     6
+--R               12A b c e  + (- 18A b c  - 8B b c)d e
+--R             + 
+--R                       5 3        6 2  2 5        5 3 3 4
+--R               (- 12A b c  + 16B b c )d e  + 10B b c d e
+--R             + 
+--R                     3 5        4 4  4 3           2 6        3 5  5 2
+--R               (60A b c  - 40B b c )d e  + (- 42A b c  + 20B b c )d e
+--R             + 
+--R                         7       2 6  6          8         7  7
+--R               (- 12A b c  + 8B b c )d e + (12A c  - 6B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   8 7       8   6           6 2       7   2 5        6 2 3 4
+--R               6A b e  - 4B b d e  + (- 24A b c  + 2B b c)d e  + 20B b c d e
+--R             + 
+--R                     4 4        5 3  4 3         3 5        4 4  5 2
+--R               (30A b c  - 20B b c )d e  + (24A b c  - 20B b c )d e
+--R             + 
+--R                       2 6        3 5  6            7        2 6  7
+--R               (- 60A b c  + 34B b c )d e + (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   8   6           7        8  2 5        7   3 4
+--R               6A b d e  + (- 12A b c - 4B b )d e  + 10B b c d e
+--R             + 
+--R                     4 4        5 3  5 2           3 5        4 4  6
+--R               (30A b c  - 20B b c )d e  + (- 36A b c  + 20B b c )d e
+--R             + 
+--R                     2 6       3 5  7
+--R               (12A b c  - 6B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R         log(x)
+--R     + 
+--R               6 2   6           5 3       6 2  2 5        5 3 3 4
+--R           6A b c d e  + (- 12A b c  - 4B b c )d e  + 10B b c d e
+--R         + 
+--R                 3 5        4 4  4 3           2 6        3 5  5 2
+--R           (30A b c  - 20B b c )d e  + (- 36A b c  + 20B b c )d e
+--R         + 
+--R                   7       2 6  6
+--R           (12A b c  - 6B b c )d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                7     6           6 2       7   2 5          5 3        6 2  3 4
+--R           12A b c d e  + (- 21A b c  - 8B b c)d e  + (- 6A b c  + 18B b c )d e
+--R         + 
+--R                 4 4        5 3  4 3           3 5        4 4  5 2
+--R           (45A b c  - 25B b c )d e  + (- 24A b c  + 10B b c )d e
+--R         + 
+--R                   2 6        3 5  6            7       2 6  7
+--R           (- 18A b c  + 11B b c )d e + (12A b c  - 6B b c )d
+--R      *
+--R          3
+--R         x
+--R     + 
+--R               8   6          7        8  2 5           6 2       7   3 4
+--R           6A b d e  + (- 6A b c - 4B b )d e  + (- 13A b c  + 6B b c)d e
+--R         + 
+--R                 5 3       6 2  4 3         4 4        5 3  5 2
+--R           (12A b c  + 4B b c )d e  + (33A b c  - 25B b c )d e
+--R         + 
+--R                   3 5        4 4  6          2 6       3 5  7
+--R           (- 50A b c  + 28B b c )d e + (18A b c  - 9B b c )d
+--R      *
+--R          2
+--R         x
+--R     + 
+--R               8 2 5          7        8  3 4        6 2       7   4 3
+--R           3A b d e  + (- 8A b c - 2B b )d e  + (2A b c  + 8B b c)d e
+--R         + 
+--R                 5 3        6 2  5 2           4 4       5 3  6
+--R           (12A b c  - 12B b c )d e  + (- 13A b c  + 8B b c )d e
+--R         + 
+--R                3 5       4 4  7
+--R           (4A b c  - 2B b c )d
+--R      *
+--R         x
+--R     + 
+--R            8 3 4       7   4 3       6 2 5 2       5 3 6       4 4 7
+--R       - A b d e  + 4A b c d e  - 6A b c d e  + 4A b c d e - A b c d
+--R  /
+--R          9 2 4 5     8 3 5 4      7 4 6 3     6 5 7 2     5 6 8   5
+--R       (2b c d e  - 8b c d e  + 12b c d e  - 8b c d e  + 2b c d e)x
+--R     + 
+--R          10   4 5      9 2 5 4      8 3 6 3     7 4 7 2     6 5 8      5 6 9  4
+--R       (4b  c d e  - 14b c d e  + 16b c d e  - 4b c d e  - 4b c d e + 2b c d )x
+--R     + 
+--R          11 4 5     10   5 4     9 2 6 3      8 3 7 2      7 4 8      6 5 9  3
+--R       (2b  d e  - 4b  c d e  - 4b c d e  + 16b c d e  - 14b c d e + 4b c d )x
+--R     + 
+--R          11 5 4     10   6 3      9 2 7 2     8 3 8      7 4 9  2
+--R       (2b  d e  - 8b  c d e  + 12b c d e  - 8b c d e + 2b c d )x
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 1457
+--a0:=integrate(t0,x)
+--E 293
+
+--S 294 of 1457
+--m0:=a0-r0
+--E 294
+
+--S 295 of 1457
+--d0:=D(m0,x)
+--E 295
+
+)clear all
+
+--S 296 of 1457
+t0:=(A+B*x)*(d+e*x)^3*sqrt(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R          3 4       3         2  3          2       2   2        2       3
+--R       B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x
+--R     + 
+--R          3
+--R       A d
+--R  *
+--R      +----------+
+--R      |   2
+--R     \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1457
+r0:=1/960*(4*A*c*e*(132*c^2*d^2-132*b*c*d*e+35*b^2*e^2)+B*(64*c^3*d^3-_
+     360*b*c^2*d^2*e+366*b^2*c*d*e^2-105*b^3*e^3))*(b*x+c*x^2)^(3/2)/c^4+_
+     1/20*(2*B*c*d-3*b*B*e+4*A*c*e)*(d+e*x)^2*(b*x+c*x^2)^(3/2)/c^2+_
+     1/6*B*(d+e*x)^3*(b*x+c*x^2)^(3/2)/c-1/160*e*(d*(16*b*B*c*d-40*A*c^2*d-_
+     9*b^2*B*e+12*A*b*c*e)-(28*A*c*e*(2*c*d-b*e)+B*(8*c^2*d^2-36*b*c*d*e+_
+     21*b^2*e^2))*x)*(b*x+c*x^2)^(3/2)/c^3-1/512*b^2*(128*A*c^4*d^3+_
+     21*b^4*B*e^3+120*b^2*c^2*d*e*(B*d+A*e)-28*b^3*c*e^2*(3*B*d+A*e)-_
+     64*b*c^3*d^2*(B*d+3*A*e))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(11/2)+_
+     1/512*b*(128*A*c^4*d^3+21*b^4*B*e^3+120*b^2*c^2*d*e*(B*d+A*e)-_
+     28*b^3*c*e^2*(3*B*d+A*e)-64*b*c^3*d^2*(B*d+3*A*e))*sqrt(b*x+c*x^2)/c^5+_
+     1/256*(128*A*c^4*d^3+21*b^4*B*e^3+120*b^2*c^2*d*e*(B*d+A*e)-_
+     28*b^3*c*e^2*(3*B*d+A*e)-64*b*c^3*d^2*(B*d+3*A*e))*x*sqrt(b*x+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R                  5          6  3             4 2          5     2
+--R           (420A b c - 315B b )e  + (- 1800A b c  + 1260B b c)d e
+--R         + 
+--R                   3 3          4 2  2              2 4         3 3  3
+--R           (2880A b c  - 1800B b c )d e + (- 1920A b c  + 960B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                  5 3 5            5           4  3          5   2  4
+--R           1280B c e x  + ((1536A c  + 128B b c )e  + 4608B c d e )x
+--R         + 
+--R                        4         2 3  3           5           4    2
+--R               (192A b c  - 144B b c )e  + (5760A c  + 576B b c )d e
+--R             + 
+--R                      5 2
+--R               5760B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                        2 3         3 2  3            4         2 3    2
+--R               (- 224A b c  + 168B b c )e  + (960A b c  - 672B b c )d e
+--R             + 
+--R                       5           4  2           5 3
+--R               (7680A c  + 960B b c )d e + 2560B c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3 2         4   3             2 3         3 2    2
+--R               (280A b c  - 210B b c)e  + (- 1200A b c  + 840B b c )d e
+--R             + 
+--R                         4          2 3  2            5           4  3
+--R               (1920A b c  - 1200B b c )d e + (3840A c  + 640B b c )d
+--R          *
+--R             x
+--R         + 
+--R                    4          5  3           3 2          4     2
+--R           (- 420A b c + 315B b )e  + (1800A b c  - 1260B b c)d e
+--R         + 
+--R                     2 3          3 2  2              4         2 3  3
+--R           (- 2880A b c  + 1800B b c )d e + (1920A b c  - 960B b c )d
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R          5 +-+
+--R     7680c \|c
+--R                                                    Type: Expression(Integer)
+--E 297
+
+--S 298 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    5          6  3             4 2          5     2
+--R             (420A b c - 315B b )e  + (- 1800A b c  + 1260B b c)d e
+--R           + 
+--R                     3 3          4 2  2              2 4         3 3  3
+--R             (2880A b c  - 1800B b c )d e + (- 1920A b c  + 960B b c )d
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                    5 3 5            5           4  3          5   2  4
+--R             2560B c e x  + ((3072A c  + 256B b c )e  + 9216B c d e )x
+--R           + 
+--R                          4         2 3  3            5            4    2
+--R                 (384A b c  - 288B b c )e  + (11520A c  + 1152B b c )d e
+--R               + 
+--R                         5 2
+--R                 11520B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          2 3         3 2  3             4          2 3    2
+--R                 (- 448A b c  + 336B b c )e  + (1920A b c  - 1344B b c )d e
+--R               + 
+--R                          5            4  2           5 3
+--R                 (15360A c  + 1920B b c )d e + 5120B c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2         4   3             2 3          3 2    2
+--R                 (560A b c  - 420B b c)e  + (- 2400A b c  + 1680B b c )d e
+--R               + 
+--R                           4          2 3  2            5            4  3
+--R                 (3840A b c  - 2400B b c )d e + (7680A c  + 1280B b c )d
+--R            *
+--R               x
+--R           + 
+--R                      4          5  3           3 2          4     2
+--R             (- 840A b c + 630B b )e  + (3600A b c  - 2520B b c)d e
+--R           + 
+--R                       2 3          3 2  2              4          2 3  3
+--R             (- 5760A b c  + 3600B b c )d e + (3840A b c  - 1920B b c )d
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R             5 +-+
+--R       15360c \|c
+--R     ,
+--R
+--R                    5          6  3             4 2          5     2
+--R             (420A b c - 315B b )e  + (- 1800A b c  + 1260B b c)d e
+--R           + 
+--R                     3 3          4 2  2              2 4         3 3  3
+--R             (2880A b c  - 1800B b c )d e + (- 1920A b c  + 960B b c )d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                    5 3 5            5           4  3          5   2  4
+--R             1280B c e x  + ((1536A c  + 128B b c )e  + 4608B c d e )x
+--R           + 
+--R                          4         2 3  3           5           4    2
+--R                 (192A b c  - 144B b c )e  + (5760A c  + 576B b c )d e
+--R               + 
+--R                        5 2
+--R                 5760B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          2 3         3 2  3            4         2 3    2
+--R                 (- 224A b c  + 168B b c )e  + (960A b c  - 672B b c )d e
+--R               + 
+--R                         5           4  2           5 3
+--R                 (7680A c  + 960B b c )d e + 2560B c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2         4   3             2 3         3 2    2
+--R                 (280A b c  - 210B b c)e  + (- 1200A b c  + 840B b c )d e
+--R               + 
+--R                           4          2 3  2            5           4  3
+--R                 (1920A b c  - 1200B b c )d e + (3840A c  + 640B b c )d
+--R            *
+--R               x
+--R           + 
+--R                      4          5  3           3 2          4     2
+--R             (- 420A b c + 315B b )e  + (1800A b c  - 1260B b c)d e
+--R           + 
+--R                       2 3          3 2  2              4         2 3  3
+--R             (- 2880A b c  + 1800B b c )d e + (1920A b c  - 960B b c )d
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R            5 +---+
+--R       7680c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 298
+
+--S 299 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 5         6  3            4 2        5     2
+--R           (28A b c - 21B b )e  + (- 120A b c  + 84B b c)d e
+--R         + 
+--R                  3 3         4 2  2             2 4        3 3  3
+--R           (192A b c  - 120B b c )d e + (- 128A b c  + 64B b c )d
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                   5         6  3          4 2         5     2
+--R           (- 56A b c + 42B b )e  + (240A b c  - 168B b c)d e
+--R         + 
+--R                    3 3         4 2  2           2 4         3 3  3
+--R           (- 384A b c  + 240B b c )d e + (256A b c  - 128B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R  /
+--R          5 +-+
+--R     1024c \|c
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+--S 301 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                   5         6  3          4 2        5     2
+--R           (- 28A b c + 21B b )e  + (120A b c  - 84B b c)d e
+--R         + 
+--R                    3 3         4 2  2           2 4        3 3  3
+--R           (- 192A b c  + 120B b c )d e + (128A b c  - 64B b c )d
+--R      *
+--R                           +-+
+--R          +---+          x\|c
+--R         \|- c atanh(-------------)
+--R                      +----------+
+--R                      |   2
+--R                     \|c x  + b x
+--R     + 
+--R                 5         6  3            4 2        5     2
+--R           (28A b c - 21B b )e  + (- 120A b c  + 84B b c)d e
+--R         + 
+--R                  3 3         4 2  2             2 4        3 3  3
+--R           (192A b c  - 120B b c )d e + (- 128A b c  + 64B b c )d
+--R      *
+--R                         +----------+
+--R                   +---+ |   2
+--R          +-+     \|- c \|c x  + b x
+--R         \|c atan(-------------------)
+--R                          c x
+--R  /
+--R         5 +---+ +-+
+--R     512c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 302
+
+)clear all
+
+--S 303 of 1457
+t0:=(A+B*x)*(d+e*x)^2*sqrt(b*x+c*x^2)
+--R 
+--R
+--R                                                               +----------+
+--R            2 3       2           2                2        2  |   2
+--R   (1)  (B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 303
+
+--S 304 of 1457
+r0:=1/240*(50*A*c*e*(2*c*d-b*e)+B*(32*c^2*d^2-82*b*c*d*e+35*b^2*e^2))*_
+     (b*x+c*x^2)^(3/2)/c^3+1/5*B*(d+e*x)^2*(b*x+c*x^2)^(3/2)/c-1/40*e*_
+     ((3*b*B-10*A*c)*d-(4*B*c*d-7*b*B*e+10*A*c*e)*x)*(b*x+c*x^2)^(3/2)/c^2-_
+     1/128*b^2*(32*A*c^3*d^2-7*b^3*B*e^2+10*b^2*c*e*(2*B*d+A*e)-_
+     16*b*c^2*d*(B*d+2*A*e))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(9/2)+_
+     1/128*b*(32*A*c^3*d^2-7*b^3*B*e^2+10*b^2*c*e*(2*B*d+A*e)-16*b*c^2*_
+     d*(B*d+2*A*e))*sqrt(b*x+c*x^2)/c^4+1/64*(32*A*c^3*d^2-7*b^3*B*e^2+_
+     10*b^2*c*e*(2*B*d+A*e)-16*b*c^2*d*(B*d+2*A*e))*x*sqrt(b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                    4          5  2          3 2         4
+--R           (- 150A b c + 105B b )e  + (480A b c  - 300B b c)d e
+--R         + 
+--R                    2 3         3 2  2
+--R           (- 480A b c  + 240B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                 4 2 4           4          3  2         4     3
+--R           384B c e x  + ((480A c  + 48B b c )e  + 960B c d e)x
+--R         + 
+--R                    3        2 2  2           4           3             4 2  2
+--R           ((80A b c  - 56B b c )e  + (1280A c  + 160B b c )d e + 640B c d )x
+--R         + 
+--R                        2 2        3   2            3         2 2
+--R               (- 100A b c  + 70B b c)e  + (320A b c  - 200B b c )d e
+--R             + 
+--R                      4           3  2
+--R               (960A c  + 160B b c )d
+--R          *
+--R             x
+--R         + 
+--R                  3          4  2            2 2         3
+--R           (150A b c - 105B b )e  + (- 480A b c  + 300B b c)d e
+--R         + 
+--R                    3         2 2  2
+--R           (480A b c  - 240B b c )d
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R          4 +-+
+--R     1920c \|c
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    4          5  2            3 2         4
+--R             (150A b c - 105B b )e  + (- 480A b c  + 300B b c)d e
+--R           + 
+--R                    2 3         3 2  2
+--R             (480A b c  - 240B b c )d
+--R        *
+--R                    +----------+
+--R                    |   2                     +-+
+--R           log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                   4 2 4           4          3  2          4     3
+--R             768B c e x  + ((960A c  + 96B b c )e  + 1920B c d e)x
+--R           + 
+--R                          3         2 2  2           4           3
+--R                 (160A b c  - 112B b c )e  + (2560A c  + 320B b c )d e
+--R               + 
+--R                        4 2
+--R                 1280B c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                          2 2         3   2            3         2 2
+--R                 (- 200A b c  + 140B b c)e  + (640A b c  - 400B b c )d e
+--R               + 
+--R                         4           3  2
+--R                 (1920A c  + 320B b c )d
+--R            *
+--R               x
+--R           + 
+--R                    3          4  2            2 2         3
+--R             (300A b c - 210B b )e  + (- 960A b c  + 600B b c)d e
+--R           + 
+--R                      3         2 2  2
+--R             (960A b c  - 480B b c )d
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R            4 +-+
+--R       3840c \|c
+--R     ,
+--R
+--R                      4          5  2          3 2         4
+--R             (- 150A b c + 105B b )e  + (480A b c  - 300B b c)d e
+--R           + 
+--R                      2 3         3 2  2
+--R             (- 480A b c  + 240B b c )d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                   4 2 4           4          3  2         4     3
+--R             384B c e x  + ((480A c  + 48B b c )e  + 960B c d e)x
+--R           + 
+--R                      3        2 2  2           4           3             4 2  2
+--R             ((80A b c  - 56B b c )e  + (1280A c  + 160B b c )d e + 640B c d )x
+--R           + 
+--R                          2 2        3   2            3         2 2
+--R                 (- 100A b c  + 70B b c)e  + (320A b c  - 200B b c )d e
+--R               + 
+--R                        4           3  2
+--R                 (960A c  + 160B b c )d
+--R            *
+--R               x
+--R           + 
+--R                    3          4  2            2 2         3
+--R             (150A b c - 105B b )e  + (- 480A b c  + 300B b c)d e
+--R           + 
+--R                      3         2 2  2
+--R             (480A b c  - 240B b c )d
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R            4 +---+
+--R       1920c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 305
+
+--S 306 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 4        5  2           3 2        4
+--R           (10A b c - 7B b )e  + (- 32A b c  + 20B b c)d e
+--R         + 
+--R                 2 3        3 2  2
+--R           (32A b c  - 16B b c )d
+--R      *
+--R                  +----------+
+--R                  |   2                     +-+
+--R         log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                 4         5  2           3 2        4
+--R           (20A b c - 14B b )e  + (- 64A b c  + 40B b c)d e
+--R         + 
+--R                 2 3        3 2  2
+--R           (64A b c  - 32B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R  /
+--R         4 +-+
+--R     256c \|c
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 4        5  2           3 2        4
+--R           (10A b c - 7B b )e  + (- 32A b c  + 20B b c)d e
+--R         + 
+--R                 2 3        3 2  2
+--R           (32A b c  - 16B b c )d
+--R      *
+--R                           +-+
+--R          +---+          x\|c
+--R         \|- c atanh(-------------)
+--R                      +----------+
+--R                      |   2
+--R                     \|c x  + b x
+--R     + 
+--R                   4        5  2         3 2        4
+--R           (- 10A b c + 7B b )e  + (32A b c  - 20B b c)d e
+--R         + 
+--R                   2 3        3 2  2
+--R           (- 32A b c  + 16B b c )d
+--R      *
+--R                         +----------+
+--R                   +---+ |   2
+--R          +-+     \|- c \|c x  + b x
+--R         \|c atan(-------------------)
+--R                          c x
+--R  /
+--R         4 +---+ +-+
+--R     128c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 1457
+t0:=(A+B*x)*(d+e*x)*sqrt(b*x+c*x^2)
+--R 
+--R
+--R                                      +----------+
+--R              2                       |   2
+--R   (1)  (B e x  + (A e + B d)x + A d)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 1457
+r0:=1/24*(2*B*c*d-5*b*B*e+8*A*c*e)*(b*x+c*x^2)^(3/2)/c^2+1/4*B*(d+e*x)*_
+     (b*x+c*x^2)^(3/2)/c-1/64*b^2*(16*A*c^2*d+5*b^2*B*e-8*b*c*(B*d+A*e))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(7/2)+1/64*b*(16*A*c^2*d+5*b^2*B*e-_
+     8*b*c*(B*d+A*e))*sqrt(b*x+c*x^2)/c^3+1/32*(16*A*c^2*d+5*b^2*B*e-_
+     8*b*c*(B*d+A*e))*x*sqrt(b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R                                                                  +-+
+--R              3         4             2 2        3              x\|c
+--R       ((24A b c - 15B b )e + (- 48A b c  + 24B b c)d)atanh(-------------)
+--R                                                             +----------+
+--R                                                             |   2
+--R                                                            \|c x  + b x
+--R     + 
+--R                3   3          3         2          3   2
+--R           48B c e x  + ((64A c  + 8B b c )e + 64B c d)x
+--R         + 
+--R                    2        2            3          2
+--R           ((16A b c  - 10B b c)e + (96A c  + 16B b c )d)x
+--R         + 
+--R                   2         3             2        2
+--R           (- 24A b c + 15B b )e + (48A b c  - 24B b c)d
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R         3 +-+
+--R     192c \|c
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3         4             2 2        3
+--R           ((24A b c - 15B b )e + (- 48A b c  + 24B b c)d)
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                  3   3           3          2           3   2
+--R             96B c e x  + ((128A c  + 16B b c )e + 128B c d)x
+--R           + 
+--R                      2        2             3          2
+--R             ((32A b c  - 20B b c)e + (192A c  + 32B b c )d)x
+--R           + 
+--R                     2         3             2        2
+--R             (- 48A b c + 30B b )e + (96A b c  - 48B b c)d
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R           3 +-+
+--R       384c \|c
+--R     ,
+--R
+--R                  3         4             2 2        3
+--R           ((24A b c - 15B b )e + (- 48A b c  + 24B b c)d)
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                  3   3          3         2          3   2
+--R             48B c e x  + ((64A c  + 8B b c )e + 64B c d)x
+--R           + 
+--R                      2        2            3          2
+--R             ((16A b c  - 10B b c)e + (96A c  + 16B b c )d)x
+--R           + 
+--R                     2         3             2        2
+--R             (- 24A b c + 15B b )e + (48A b c  - 24B b c)d
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R           3 +---+
+--R       192c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 312
+
+--S 313 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               3        4             2 2       3
+--R         ((8A b c - 5B b )e + (- 16A b c  + 8B b c)d)
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                                                  +-+
+--R                3         4           2 2        3              x\|c
+--R       ((- 16A b c + 10B b )e + (32A b c  - 16B b c)d)atanh(-------------)
+--R                                                             +----------+
+--R                                                             |   2
+--R                                                            \|c x  + b x
+--R  /
+--R         3 +-+
+--R     128c \|c
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                     +-+
+--R               3        4           2 2       3     +---+          x\|c
+--R       ((- 8A b c + 5B b )e + (16A b c  - 8B b c)d)\|- c atanh(-------------)
+--R                                                                +----------+
+--R                                                                |   2
+--R                                                               \|c x  + b x
+--R     + 
+--R                                                                 +----------+
+--R                                                           +---+ |   2
+--R           3        4             2 2       3     +-+     \|- c \|c x  + b x
+--R     ((8A b c - 5B b )e + (- 16A b c  + 8B b c)d)\|c atan(-------------------)
+--R                                                                  c x
+--R  /
+--R        3 +---+ +-+
+--R     64c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 315
+
+--S 316 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 316
+
+)clear all
+
+--S 317 of 1457
+t0:=(A+B*x)*sqrt(b*x+c*x^2)
+--R 
+--R
+--R                  +----------+
+--R                  |   2
+--R   (1)  (B x + A)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 1457
+r0:=1/3*B*(b*x+c*x^2)^(3/2)/c+1/8*b^2*(b*B-2*A*c)*atanh(x*sqrt(c)/_
+     sqrt(b*x+c*x^2))/c^(5/2)-1/8*b*(b*B-2*A*c)*sqrt(b*x+c*x^2)/c^2-_
+     1/4*(b*B-2*A*c)*x*sqrt(b*x+c*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                     +-+
+--R              2        3           x\|c
+--R       (- 6A b c + 3B b )atanh(-------------)
+--R                                +----------+
+--R                                |   2
+--R                               \|c x  + b x
+--R     + 
+--R                                                           +----------+
+--R            2 2         2                           2  +-+ |   2
+--R       (8B c x  + (12A c  + 2B b c)x + 6A b c - 3B b )\|c \|c x  + b x
+--R  /
+--R        2 +-+
+--R     24c \|c
+--R                                                    Type: Expression(Integer)
+--E 318
+
+--S 319 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                  +----------+
+--R              2        3          |   2                     +-+
+--R         (6A b c - 3B b )log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                                                               +----------+
+--R               2 2         2                            2  +-+ |   2
+--R         (16B c x  + (24A c  + 4B b c)x + 12A b c - 6B b )\|c \|c x  + b x
+--R    /
+--R          2 +-+
+--R       48c \|c
+--R     ,
+--R
+--R                                       +----------+
+--R                                 +---+ |   2
+--R                2        3      \|- c \|c x  + b x
+--R         (- 6A b c + 3B b )atan(-------------------)
+--R                                        c x
+--R       + 
+--R                                                               +----------+
+--R              2 2         2                           2  +---+ |   2
+--R         (8B c x  + (12A c  + 2B b c)x + 6A b c - 3B b )\|- c \|c x  + b x
+--R    /
+--R          2 +---+
+--R       24c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 319
+
+--S 320 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                               +----------+
+--R            2       3          |   2                     +-+
+--R       (2A b c - B b )log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                   +-+
+--R            2        3           x\|c
+--R       (4A b c - 2B b )atanh(-------------)
+--R                              +----------+
+--R                              |   2
+--R                             \|c x  + b x
+--R  /
+--R        2 +-+
+--R     16c \|c
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                        +-+
+--R            2       3  +---+          x\|c
+--R       (2A b c - B b )\|- c atanh(-------------)
+--R                                   +----------+
+--R                                   |   2
+--R                                  \|c x  + b x
+--R     + 
+--R                                        +----------+
+--R                                  +---+ |   2
+--R              2       3  +-+     \|- c \|c x  + b x
+--R       (- 2A b c + B b )\|c atan(-------------------)
+--R                                         c x
+--R  /
+--R       2 +---+ +-+
+--R     8c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 323
+
+)clear all
+
+--S 324 of 1457
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)
+--R 
+--R
+--R                  +----------+
+--R                  |   2
+--R        (B x + A)\|c x  + b x
+--R   (1)  ----------------------
+--R                e x + d
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 1457
+r0:=-1/4*(4*A*c*e*(2*c*d-b*e)-B*(8*c^2*d^2-4*b*c*d*e-b^2*e^2))*atanh(x*_
+     sqrt(c)/sqrt(b*x+c*x^2))/(c^(3/2)*e^3)-(B*d-A*e)*atanh(1/2*(b*d+_
+     (2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))*sqrt(d)*_
+     sqrt(c*d-b*e)/e^3-1/4*(4*B*c*d-b*B*e-4*A*c*e-2*B*c*e*x)*sqrt(b*x+_
+     c*x^2)/(c*e^2)
+--R 
+--R
+--R   (2)
+--R                                                                        +-+
+--R                     2  2          2                    2 2           x\|c
+--R       ((4A b c - B b )e  + (- 8A c  - 4B b c)d e + 8B c d )atanh(-------------)
+--R                                                                   +----------+
+--R                                                                   |   2
+--R                                                                  \|c x  + b x
+--R     + 
+--R                             +-----------+ +-+ +-+
+--R         (- 4A c e + 4B c d)\|- b e + c d \|c \|d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                                                  +----------+
+--R              2                 2             +-+ |   2
+--R       (2B c e x + (4A c + B b)e  - 4B c d e)\|c \|c x  + b x
+--R  /
+--R         3 +-+
+--R     4c e \|c
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             +--------------+
+--R                             |             2  +-+
+--R           (8A c e - 8B c d)\|- b d e + c d  \|c
+--R        *
+--R                 +--------------+ +----------+
+--R                 |             2  |   2
+--R               2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R           log(-------------------------------------------------------)
+--R                                       e x + d
+--R       + 
+--R                         2  2          2                    2 2
+--R           ((4A b c - B b )e  + (- 8A c  - 4B b c)d e + 8B c d )
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                                                     +----------+
+--R                2                  2             +-+ |   2
+--R         (4B c e x + (8A c + 2B b)e  - 8B c d e)\|c \|c x  + b x
+--R    /
+--R           3 +-+
+--R       8c e \|c
+--R     ,
+--R
+--R                         2  2          2                    2 2
+--R           ((4A b c - B b )e  + (- 8A c  - 4B b c)d e + 8B c d )
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                                                       +----------+
+--R                                 +------------+        |   2
+--R                             +-+ |           2       d\|c x  + b x
+--R         (16A c e - 16B c d)\|c \|b d e - c d  atan(----------------)
+--R                                                      +------------+
+--R                                                      |           2
+--R                                                    x\|b d e - c d
+--R       + 
+--R                                                     +----------+
+--R                2                  2             +-+ |   2
+--R         (4B c e x + (8A c + 2B b)e  - 8B c d e)\|c \|c x  + b x
+--R    /
+--R           3 +-+
+--R       8c e \|c
+--R     ,
+--R
+--R                             +--------------+
+--R                             |             2  +---+
+--R           (4A c e - 4B c d)\|- b d e + c d  \|- c
+--R        *
+--R                 +--------------+ +----------+
+--R                 |             2  |   2
+--R               2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R           log(-------------------------------------------------------)
+--R                                       e x + d
+--R       + 
+--R                         2  2          2                    2 2
+--R           ((4A b c - B b )e  + (- 8A c  - 4B b c)d e + 8B c d )
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                                                      +----------+
+--R                2                 2             +---+ |   2
+--R         (2B c e x + (4A c + B b)e  - 4B c d e)\|- c \|c x  + b x
+--R    /
+--R           3 +---+
+--R       4c e \|- c
+--R     ,
+--R
+--R                         2  2          2                    2 2
+--R           ((4A b c - B b )e  + (- 8A c  - 4B b c)d e + 8B c d )
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                                                       +----------+
+--R                                 +------------+        |   2
+--R                           +---+ |           2       d\|c x  + b x
+--R         (8A c e - 8B c d)\|- c \|b d e - c d  atan(----------------)
+--R                                                      +------------+
+--R                                                      |           2
+--R                                                    x\|b d e - c d
+--R       + 
+--R                                                      +----------+
+--R                2                 2             +---+ |   2
+--R         (2B c e x + (4A c + B b)e  - 4B c d e)\|- c \|c x  + b x
+--R    /
+--R           3 +---+
+--R       4c e \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 326
+
+--S 327 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           +--------------+
+--R                           |             2  +-+
+--R         (8A c e - 8B c d)\|- b d e + c d  \|c
+--R      *
+--R               +--------------+ +----------+
+--R               |             2  |   2
+--R             2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R         log(-------------------------------------------------------)
+--R                                     e x + d
+--R     + 
+--R                       2  2          2                    2 2
+--R         ((4A b c - B b )e  + (- 8A c  - 4B b c)d e + 8B c d )
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                          2  2         2                     2 2
+--R         ((- 8A b c + 2B b )e  + (16A c  + 8B b c)d e - 16B c d )
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                           +-----------+ +-+ +-+
+--R         (8A c e - 8B c d)\|- b e + c d \|c \|d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R         3 +-+
+--R     8c e \|c
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       2  2          2                    2 2
+--R         ((4A b c - B b )e  + (- 8A c  - 4B b c)d e + 8B c d )
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                          2  2         2                     2 2
+--R         ((- 8A b c + 2B b )e  + (16A c  + 8B b c)d e - 16B c d )
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                           +-----------+ +-+ +-+
+--R         (8A c e - 8B c d)\|- b e + c d \|c \|d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                                                     +----------+
+--R                               +------------+        |   2
+--R                           +-+ |           2       d\|c x  + b x
+--R       (16A c e - 16B c d)\|c \|b d e - c d  atan(----------------)
+--R                                                    +------------+
+--R                                                    |           2
+--R                                                  x\|b d e - c d
+--R  /
+--R         3 +-+
+--R     8c e \|c
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 1457
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^2
+--R 
+--R
+--R                  +----------+
+--R                  |   2
+--R        (B x + A)\|c x  + b x
+--R   (1)  ----------------------
+--R           2 2             2
+--R          e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 1457
+r0:=-(4*B*c*d-b*B*e-2*A*c*e)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(e^3*sqrt(c))+_
+     1/2*(B*d*(4*c*d-3*b*e)-A*e*(2*c*d-b*e))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(e^3*sqrt(d)*sqrt(c*d-b*e))+_
+     (2*B*d-A*e+B*e*x)*sqrt(b*x+c*x^2)/(e^2*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                         2                                         2
+--R         (((4A c + 2B b)e  - 8B c d e)x + (4A c + 2B b)d e - 8B c d )
+--R      *
+--R                                       +-+
+--R          +-----------+ +-+          x\|c
+--R         \|- b e + c d \|d atanh(-------------)
+--R                                  +----------+
+--R                                  |   2
+--R                                 \|c x  + b x
+--R     + 
+--R                   3                   2         2             2
+--R           (- A b e  + (2A c + 3B b)d e  - 4B c d e)x - A b d e
+--R         + 
+--R                         2          3
+--R           (2A c + 3B b)d e - 4B c d
+--R      *
+--R          +-+             (b e - 2c d)x - b d
+--R         \|c atanh(--------------------------------)
+--R                                       +----------+
+--R                     +-----------+ +-+ |   2
+--R                   2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                                                       +----------+
+--R            2        2           +-----------+ +-+ +-+ |   2
+--R       (2B e x - 2A e  + 4B d e)\|- b e + c d \|c \|d \|c x  + b x
+--R  /
+--R        4        3  +-----------+ +-+ +-+
+--R     (2e x + 2d e )\|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          2                                        2
+--R           (((2A c + B b)e  - 4B c d e)x + (2A c + B b)d e - 4B c d )
+--R        *
+--R            +--------------+       +----------+
+--R            |             2        |   2                     +-+
+--R           \|- b d e + c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                   3                     2         2             2
+--R             (A b e  + (- 2A c - 3B b)d e  + 4B c d e)x + A b d e
+--R           + 
+--R                             2          3
+--R             (- 2A c - 3B b)d e + 4B c d
+--R        *
+--R            +-+
+--R           \|c
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                                   +--------------+     +----------+
+--R              2        2           |             2  +-+ |   2
+--R         (2B e x - 2A e  + 4B d e)\|- b d e + c d  \|c \|c x  + b x
+--R    /
+--R                      +--------------+
+--R          4        3  |             2  +-+
+--R       (2e x + 2d e )\|- b d e + c d  \|c
+--R     ,
+--R
+--R                          2                                        2
+--R           (((2A c + B b)e  - 4B c d e)x + (2A c + B b)d e - 4B c d )
+--R        *
+--R            +------------+       +----------+
+--R            |           2        |   2                     +-+
+--R           \|b d e - c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                      3                   2         2              2
+--R             (- 2A b e  + (4A c + 6B b)d e  - 8B c d e)x - 2A b d e
+--R           + 
+--R                           2          3
+--R             (4A c + 6B b)d e - 8B c d
+--R        *
+--R                     +------------+ +----------+
+--R                     |           2  |   2
+--R            +-+     \|b d e - c d  \|c x  + b x
+--R           \|c atan(----------------------------)
+--R                            (b e - c d)x
+--R       + 
+--R                                       +------------+ +----------+
+--R              2        2           +-+ |           2  |   2
+--R         (2B e x - 2A e  + 4B d e)\|c \|b d e - c d  \|c x  + b x
+--R    /
+--R                          +------------+
+--R          4        3  +-+ |           2
+--R       (2e x + 2d e )\|c \|b d e - c d
+--R     ,
+--R
+--R                   3                     2         2             2
+--R             (A b e  + (- 2A c - 3B b)d e  + 4B c d e)x + A b d e
+--R           + 
+--R                             2          3
+--R             (- 2A c - 3B b)d e + 4B c d
+--R        *
+--R            +---+
+--R           \|- c
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                           2                                         2
+--R           (((4A c + 2B b)e  - 8B c d e)x + (4A c + 2B b)d e - 8B c d )
+--R        *
+--R                                        +----------+
+--R            +--------------+      +---+ |   2
+--R            |             2      \|- c \|c x  + b x
+--R           \|- b d e + c d  atan(-------------------)
+--R                                         c x
+--R       + 
+--R                                   +--------------+       +----------+
+--R              2        2           |             2  +---+ |   2
+--R         (2B e x - 2A e  + 4B d e)\|- b d e + c d  \|- c \|c x  + b x
+--R    /
+--R                      +--------------+
+--R          4        3  |             2  +---+
+--R       (2e x + 2d e )\|- b d e + c d  \|- c
+--R     ,
+--R
+--R                     3                   2         2             2
+--R             (- A b e  + (2A c + 3B b)d e  - 4B c d e)x - A b d e
+--R           + 
+--R                           2          3
+--R             (2A c + 3B b)d e - 4B c d
+--R        *
+--R                       +------------+ +----------+
+--R                       |           2  |   2
+--R            +---+     \|b d e - c d  \|c x  + b x
+--R           \|- c atan(----------------------------)
+--R                              (b e - c d)x
+--R       + 
+--R                          2                                        2
+--R           (((2A c + B b)e  - 4B c d e)x + (2A c + B b)d e - 4B c d )
+--R        *
+--R                                      +----------+
+--R            +------------+      +---+ |   2
+--R            |           2      \|- c \|c x  + b x
+--R           \|b d e - c d  atan(-------------------)
+--R                                       c x
+--R       + 
+--R                                       +------------+ +----------+
+--R             2       2           +---+ |           2  |   2
+--R         (B e x - A e  + 2B d e)\|- c \|b d e - c d  \|c x  + b x
+--R    /
+--R                          +------------+
+--R         4       3  +---+ |           2
+--R       (e x + d e )\|- c \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 333
+
+--S 334 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                  +--------------+
+--R                                  |             2  +-----------+ +-+
+--R         ((2A c + B b)e - 4B c d)\|- b d e + c d  \|- b e + c d \|d
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R               2                              2  +-----------+ +-+ +-+
+--R         (A b e  + (- 2A c - 3B b)d e + 4B c d )\|- b e + c d \|c \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                                     +--------------+
+--R                                     |             2  +-----------+ +-+
+--R         ((- 4A c - 2B b)e + 8B c d)\|- b d e + c d  \|- b e + c d \|d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                                                 +--------------+
+--R               2                              2  |             2  +-+
+--R         (A b e  + (- 2A c - 3B b)d e + 4B c d )\|- b d e + c d  \|c
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R         +--------------+
+--R       3 |             2  +-----------+ +-+ +-+
+--R     2e \|- b d e + c d  \|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                    +------------+
+--R                                  +-----------+ +-+ |           2
+--R         ((2A c + B b)e - 4B c d)\|- b e + c d \|d \|b d e - c d
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                                       +------------+
+--R                                     +-----------+ +-+ |           2
+--R         ((- 4A c - 2B b)e + 8B c d)\|- b e + c d \|d \|b d e - c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                                                     +------------+
+--R               2                              2  +-+ |           2
+--R         (A b e  + (- 2A c - 3B b)d e + 4B c d )\|c \|b d e - c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                  2                            2  +-----------+ +-+ +-+
+--R         (- 2A b e  + (4A c + 6B b)d e - 8B c d )\|- b e + c d \|c \|d
+--R      *
+--R               +------------+ +----------+
+--R               |           2  |   2
+--R              \|b d e - c d  \|c x  + b x
+--R         atan(----------------------------)
+--R                      (b e - c d)x
+--R  /
+--R                               +------------+
+--R       3 +-----------+ +-+ +-+ |           2
+--R     2e \|- b e + c d \|c \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 337
+
+)clear all
+
+--S 338 of 1457
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^3
+--R 
+--R
+--R                     +----------+
+--R                     |   2
+--R           (B x + A)\|c x  + b x
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 1457
+r0:=1/2*(B*d-A*e)*(b*x+c*x^2)^(3/2)/(d*(c*d-b*e)*(d+e*x)^2)-1/8*(A*b^2*e^3+_
+     B*d*(8*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(3/2)*e^3*(c*d-b*e)^(3/2))+_
+     2*B*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))*sqrt(c)/e^3+1/4*(A*b*e^2-B*d*_
+     (4*c*d-3*b*e)-2*c*e*(B*d-A*e)*x)*sqrt(b*x+c*x^2)/(d*e^2*(c*d-b*e)*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                     3          2 2  2           2 2          3             3
+--R           (16B b d e  - 16B c d e )x  + (32B b d e  - 32B c d e)x + 16B b d e
+--R         + 
+--R                    4
+--R           - 16B c d
+--R      *
+--R                                           +-+
+--R          +-----------+ +-+ +-+          x\|c
+--R         \|- b e + c d \|c \|d atanh(-------------)
+--R                                      +----------+
+--R                                      |   2
+--R                                     \|c x  + b x
+--R     + 
+--R                 2 5       2   4            2 3       2 3 2  2
+--R           (- A b e  - 3B b d e  + 12B b c d e  - 8B c d e )x
+--R         + 
+--R                  2   4       2 2 3            3 2        2 4         2 2 3
+--R           (- 2A b d e  - 6B b d e  + 24B b c d e  - 16B c d e)x - A b d e
+--R         + 
+--R                 2 3 2            4        2 5
+--R           - 3B b d e  + 12B b c d e - 8B c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                  4                      3          2 2             3
+--R           (2A b e  + (- 4A c - 10B b)d e  + 12B c d e )x - 2A b d e
+--R         + 
+--R                   2 2         3
+--R           - 6B b d e  + 8B c d e
+--R      *
+--R                            +----------+
+--R          +-----------+ +-+ |   2
+--R         \|- b e + c d \|d \|c x  + b x
+--R  /
+--R               6       2 5  2         2 5        3 4         3 4       4 3
+--R       ((8b d e  - 8c d e )x  + (16b d e  - 16c d e )x + 8b d e  - 8c d e )
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3         2 2  2           2 2          3            3
+--R             (8B b d e  - 8B c d e )x  + (16B b d e  - 16B c d e)x + 8B b d e
+--R           + 
+--R                     4
+--R             - 8B c d
+--R        *
+--R            +--------------+              +----------+
+--R            |             2  +-+      +-+ |   2
+--R           \|- b d e + c d  \|c log(2\|c \|c x  + b x  + 2c x + b)
+--R       + 
+--R                 2 5       2   4            2 3       2 3 2  2
+--R             (A b e  + 3B b d e  - 12B b c d e  + 8B c d e )x
+--R           + 
+--R                  2   4       2 2 3            3 2        2 4         2 2 3
+--R             (2A b d e  + 6B b d e  - 24B b c d e  + 16B c d e)x + A b d e
+--R           + 
+--R                 2 3 2            4        2 5
+--R             3B b d e  - 12B b c d e + 8B c d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                    4                      3          2 2             3
+--R             (2A b e  + (- 4A c - 10B b)d e  + 12B c d e )x - 2A b d e
+--R           + 
+--R                     2 2         3
+--R             - 6B b d e  + 8B c d e
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R                 6       2 5  2         2 5        3 4         3 4       4 3
+--R         ((8b d e  - 8c d e )x  + (16b d e  - 16c d e )x + 8b d e  - 8c d e )
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                      3         2 2  2          2 2         3            3
+--R             (4B b d e  - 4B c d e )x  + (8B b d e  - 8B c d e)x + 4B b d e
+--R           + 
+--R                     4
+--R             - 4B c d
+--R        *
+--R                +------------+          +----------+
+--R            +-+ |           2       +-+ |   2
+--R           \|c \|b d e - c d  log(2\|c \|c x  + b x  + 2c x + b)
+--R       + 
+--R                   2 5       2   4            2 3       2 3 2  2
+--R             (- A b e  - 3B b d e  + 12B b c d e  - 8B c d e )x
+--R           + 
+--R                    2   4       2 2 3            3 2        2 4         2 2 3
+--R             (- 2A b d e  - 6B b d e  + 24B b c d e  - 16B c d e)x - A b d e
+--R           + 
+--R                   2 3 2            4        2 5
+--R             - 3B b d e  + 12B b c d e - 8B c d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                   4                     3         2 2            3         2 2
+--R             (A b e  + (- 2A c - 5B b)d e  + 6B c d e )x - A b d e  - 3B b d e
+--R           + 
+--R                   3
+--R             4B c d e
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R                 6       2 5  2        2 5       3 4         3 4       4 3
+--R         ((4b d e  - 4c d e )x  + (8b d e  - 8c d e )x + 4b d e  - 4c d e )
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ,
+--R
+--R                 2 5       2   4            2 3       2 3 2  2
+--R             (A b e  + 3B b d e  - 12B b c d e  + 8B c d e )x
+--R           + 
+--R                  2   4       2 2 3            3 2        2 4         2 2 3
+--R             (2A b d e  + 6B b d e  - 24B b c d e  + 16B c d e)x + A b d e
+--R           + 
+--R                 2 3 2            4        2 5
+--R             3B b d e  - 12B b c d e + 8B c d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                       3          2 2  2           2 2          3             3
+--R             (16B b d e  - 16B c d e )x  + (32B b d e  - 32B c d e)x + 16B b d e
+--R           + 
+--R                      4
+--R             - 16B c d
+--R        *
+--R                                        +----------+
+--R            +--------------+            |   2
+--R            |             2  +---+     \|c x  + b x
+--R           \|- b d e + c d  \|- c atan(-------------)
+--R                                            +---+
+--R                                          x\|- c
+--R       + 
+--R                    4                      3          2 2             3
+--R             (2A b e  + (- 4A c - 10B b)d e  + 12B c d e )x - 2A b d e
+--R           + 
+--R                     2 2         3
+--R             - 6B b d e  + 8B c d e
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R                 6       2 5  2         2 5        3 4         3 4       4 3
+--R         ((8b d e  - 8c d e )x  + (16b d e  - 16c d e )x + 8b d e  - 8c d e )
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                   2 5       2   4            2 3       2 3 2  2
+--R             (- A b e  - 3B b d e  + 12B b c d e  - 8B c d e )x
+--R           + 
+--R                    2   4       2 2 3            3 2        2 4         2 2 3
+--R             (- 2A b d e  - 6B b d e  + 24B b c d e  - 16B c d e)x - A b d e
+--R           + 
+--R                   2 3 2            4        2 5
+--R             - 3B b d e  + 12B b c d e - 8B c d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                      3         2 2  2           2 2          3            3
+--R             (8B b d e  - 8B c d e )x  + (16B b d e  - 16B c d e)x + 8B b d e
+--R           + 
+--R                     4
+--R             - 8B c d
+--R        *
+--R                                      +----------+
+--R                  +------------+      |   2
+--R            +---+ |           2      \|c x  + b x
+--R           \|- c \|b d e - c d  atan(-------------)
+--R                                          +---+
+--R                                        x\|- c
+--R       + 
+--R                   4                     3         2 2            3         2 2
+--R             (A b e  + (- 2A c - 5B b)d e  + 6B c d e )x - A b d e  - 3B b d e
+--R           + 
+--R                   3
+--R             4B c d e
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R                 6       2 5  2        2 5       3 4         3 4       4 3
+--R         ((4b d e  - 4c d e )x  + (8b d e  - 8c d e )x + 4b d e  - 4c d e )
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 340
+
+--S 341 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                              +--------------+
+--R                           2  |             2  +-----------+ +-+ +-+
+--R         (8B b d e - 8B c d )\|- b d e + c d  \|- b e + c d \|c \|d
+--R      *
+--R                   +----------+
+--R               +-+ |   2
+--R         log(2\|c \|c x  + b x  + 2c x + b)
+--R     + 
+--R             2 3       2   2            2        2 3  +-----------+ +-+
+--R         (A b e  + 3B b d e  - 12B b c d e + 8B c d )\|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                                  +--------------+
+--R                               2  |             2  +-----------+ +-+ +-+
+--R         (- 16B b d e + 16B c d )\|- b d e + c d  \|- b e + c d \|c \|d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                                                      +--------------+
+--R             2 3       2   2            2        2 3  |             2
+--R         (A b e  + 3B b d e  - 12B b c d e + 8B c d )\|- b d e + c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                         +--------------+
+--R            4       2 3  |             2  +-----------+ +-+
+--R     (8b d e  - 8c d e )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                    +------------+
+--R                           2  +-----------+ +-+ +-+ |           2
+--R         (8B b d e - 8B c d )\|- b e + c d \|c \|d \|b d e - c d
+--R      *
+--R                   +----------+
+--R               +-+ |   2
+--R         log(2\|c \|c x  + b x  + 2c x + b)
+--R     + 
+--R                                                        +------------+
+--R                               2  +-----------+ +-+ +-+ |           2
+--R         (- 16B b d e + 16B c d )\|- b e + c d \|c \|d \|b d e - c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                                                      +------------+
+--R             2 3       2   2            2        2 3  |           2
+--R         (A b e  + 3B b d e  - 12B b c d e + 8B c d )\|b d e - c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                2 3       2   2            2         2 3  +-----------+ +-+
+--R         (- 2A b e  - 6B b d e  + 24B b c d e - 16B c d )\|- b e + c d \|d
+--R      *
+--R               +------------+ +----------+
+--R               |           2  |   2
+--R              \|b d e - c d  \|c x  + b x
+--R         atan(----------------------------)
+--R                      (b e - c d)x
+--R  /
+--R                                           +------------+
+--R            4       2 3  +-----------+ +-+ |           2
+--R     (8b d e  - 8c d e )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 344
+
+)clear all
+
+--S 345 of 1457
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^4
+--R 
+--R
+--R                          +----------+
+--R                          |   2
+--R                (B x + A)\|c x  + b x
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 345
+
+--S 346 of 1457
+r0:=1/16*b^2*(b*B*d-2*A*c*d+A*b*e)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(5/2)*(c*d-b*e)^(5/2))+1/12*(B*_
+     d*(4*c*d-5*b*e)+A*e*(2*c*d-b*e))*sqrt(b*x+c*x^2)/(d*e^2*(c*d-b*e)*_
+     (d+e*x)^2)+1/24*(B*d*(8*c^2*d^2-14*b*c*d*e+3*b^2*e^2)+A*e*(4*c^2*_
+     d^2-4*b*c*d*e+3*b^2*e^2))*sqrt(b*x+c*x^2)/(d^2*e^2*(c*d-b*e)^2*_
+     (d+e*x))-1/3*(2*B*d+A*e+3*B*e*x)*sqrt(b*x+c*x^2)/(e^2*(d+e*x)^3)
+--R 
+--R
+--R   (2)
+--R                  3 4        2        3    3  3
+--R           (- 3A b e  + (6A b c - 3B b )d e )x
+--R         + 
+--R                  3   3         2        3  2 2  2
+--R           (- 9A b d e  + (18A b c - 9B b )d e )x
+--R         + 
+--R                3 2 2         2        3  3          3 3         2        3  4
+--R         (- 9A b d e  + (18A b c - 9B b )d e)x - 3A b d e + (6A b c - 3B b )d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                     2 3                   2    2        2            2
+--R                 6A b e  + (- 8A b c + 6B b )d e  + (8A c  - 28B b c)d e
+--R               + 
+--R                      2 3
+--R                 16B c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                 2   2                     2  2          2           3
+--R           (16A b d e  + (- 28A b c - 16B b )d e + (24A c  + 4B b c)d )x
+--R         + 
+--R                 2 2                   2  3
+--R           - 6A b d e + (12A b c - 6B b )d
+--R      *
+--R                            +----------+
+--R          +-----------+ +-+ |   2
+--R         \|- b e + c d \|d \|c x  + b x
+--R  /
+--R             2 2 5          3 4      2 4 3  3
+--R         (48b d e  - 96b c d e  + 48c d e )x
+--R       + 
+--R              2 3 4           4 3       2 5 2  2
+--R         (144b d e  - 288b c d e  + 144c d e )x
+--R       + 
+--R              2 4 3           5 2       2 6         2 5 2          6       2 7
+--R         (144b d e  - 288b c d e  + 144c d e)x + 48b d e  - 96b c d e + 48c d
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3 4          2        3    3  3
+--R             (3A b e  + (- 6A b c + 3B b )d e )x
+--R           + 
+--R                  3   3           2        3  2 2  2
+--R             (9A b d e  + (- 18A b c + 9B b )d e )x
+--R           + 
+--R                  3 2 2           2        3  3          3 3
+--R             (9A b d e  + (- 18A b c + 9B b )d e)x + 3A b d e
+--R           + 
+--R                    2        3  4
+--R             (- 6A b c + 3B b )d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                     2 3                   2    2        2            2
+--R                 6A b e  + (- 8A b c + 6B b )d e  + (8A c  - 28B b c)d e
+--R               + 
+--R                      2 3
+--R                 16B c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                   2   2                     2  2          2           3
+--R             (16A b d e  + (- 28A b c - 16B b )d e + (24A c  + 4B b c)d )x
+--R           + 
+--R                   2 2                   2  3
+--R             - 6A b d e + (12A b c - 6B b )d
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R               2 2 5          3 4      2 4 3  3
+--R           (48b d e  - 96b c d e  + 48c d e )x
+--R         + 
+--R                2 3 4           4 3       2 5 2  2
+--R           (144b d e  - 288b c d e  + 144c d e )x
+--R         + 
+--R              2 4 3           5 2       2 6         2 5 2          6       2 7
+--R         (144b d e  - 288b c d e  + 144c d e)x + 48b d e  - 96b c d e + 48c d
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                    3 4        2        3    3  3
+--R             (- 3A b e  + (6A b c - 3B b )d e )x
+--R           + 
+--R                    3   3         2        3  2 2  2
+--R             (- 9A b d e  + (18A b c - 9B b )d e )x
+--R           + 
+--R                  3 2 2         2        3  3          3 3         2        3  4
+--R           (- 9A b d e  + (18A b c - 9B b )d e)x - 3A b d e + (6A b c - 3B b )d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                       2 3                   2    2        2            2
+--R                   3A b e  + (- 4A b c + 3B b )d e  + (4A c  - 14B b c)d e
+--R                 + 
+--R                       2 3
+--R                   8B c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                  2   2                    2  2          2           3
+--R             (8A b d e  + (- 14A b c - 8B b )d e + (12A c  + 2B b c)d )x
+--R           + 
+--R                   2 2                  2  3
+--R             - 3A b d e + (6A b c - 3B b )d
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R               2 2 5          3 4      2 4 3  3
+--R           (24b d e  - 48b c d e  + 24c d e )x
+--R         + 
+--R               2 3 4           4 3      2 5 2  2
+--R           (72b d e  - 144b c d e  + 72c d e )x
+--R         + 
+--R               2 4 3           5 2      2 6         2 5 2          6       2 7
+--R           (72b d e  - 144b c d e  + 72c d e)x + 24b d e  - 48b c d e + 24c d
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 347
+
+--S 348 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             3           2       3    +-----------+ +-+
+--R         (A b e + (- 2A b c + B b )d)\|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                                      +--------------+
+--R             3           2       3    |             2
+--R         (A b e + (- 2A b c + B b )d)\|- b d e + c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                                     +--------------+
+--R         2 2 2          3       2 4  |             2  +-----------+ +-+
+--R     (16b d e  - 32b c d e + 16c d )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 348
+
+--S 349 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                      +------------+
+--R             3           2       3    |           2
+--R         (A b e + (- 2A b c + B b )d)\|b d e - c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                3         2        3    +-----------+ +-+
+--R         (- 2A b e + (4A b c - 2B b )d)\|- b e + c d \|d
+--R      *
+--R               +------------+ +----------+
+--R               |           2  |   2
+--R              \|b d e - c d  \|c x  + b x
+--R         atan(----------------------------)
+--R                      (b e - c d)x
+--R  /
+--R                                                       +------------+
+--R         2 2 2          3       2 4  +-----------+ +-+ |           2
+--R     (16b d e  - 32b c d e + 16c d )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 1457
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^5
+--R 
+--R
+--R                                +----------+
+--R                                |   2
+--R                      (B x + A)\|c x  + b x
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 1457
+r0:=-1/128*b^2*(16*A*c^2*d^2-8*b*c*d*(B*d+2*A*e)+b^2*e*(3*B*d+5*A*e))*_
+     atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+_
+     c*x^2)))/(d^(7/2)*(c*d-b*e)^(7/2))+1/24*(B*d*(2*c*d-3*b*e)+A*e*(2*c*d-_
+     b*e))*sqrt(b*x+c*x^2)/(d*e^2*(c*d-b*e)*(d+e*x)^3)+1/96*(B*d*_
+     (8*c^2*d^2-16*b*c*d*e+3*b^2*e^2)+A*e*(8*c^2*d^2-8*b*c*d*e+_
+     5*b^2*e^2))*sqrt(b*x+c*x^2)/(d^2*e^2*(c*d-b*e)^2*(d+e*x)^2)+_
+     1/192*(A*e*(16*c^3*d^3-24*b*c^2*d^2*e+38*b^2*c*d*e^2-15*b^3*e^3)+_
+     B*d*(16*c^3*d^3-40*b*c^2*d^2*e+18*b^2*c*d*e^2-9*b^3*e^3))*_
+     sqrt(b*x+c*x^2)/(d^3*e^2*(c*d-b*e)^3*(d+e*x))-1/4*(B*d+A*e+_
+     2*B*e*x)*sqrt(b*x+c*x^2)/(e^2*(d+e*x)^4)
+--R 
+--R
+--R   (2)
+--R                   4 6         3        4    5           2 2        3   2 4  4
+--R           (- 15A b e  + (48A b c - 9B b )d e  + (- 48A b c  + 24B b c)d e )x
+--R         + 
+--R                      4   5          3         4  2 4
+--R               - 60A b d e  + (192A b c - 36B b )d e
+--R             + 
+--R                        2 2        3   3 3
+--R               (- 192A b c  + 96B b c)d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      4 2 4          3         4  3 3
+--R               - 90A b d e  + (288A b c - 54B b )d e
+--R             + 
+--R                        2 2         3   4 2
+--R               (- 288A b c  + 144B b c)d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        4 3 3          3         4  4 2
+--R                 - 60A b d e  + (192A b c - 36B b )d e
+--R               + 
+--R                          2 2        3   5
+--R                 (- 192A b c  + 96B b c)d e
+--R          *
+--R             x
+--R         + 
+--R                  4 4 2         3        4  5            2 2        3   6
+--R           - 15A b d e  + (48A b c - 9B b )d e + (- 48A b c  + 24B b c)d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                    3 5           2         3    4           2        2   2 3
+--R               30A b e  + (- 76A b c + 18B b )d e  + (48A b c  - 36B b c)d e
+--R             + 
+--R                       3          2  3 2        3 4
+--R               (- 32A c  + 80B b c )d e  - 32B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     3   4            2         3  2 3
+--R               110A b d e  + (- 280A b c + 66B b )d e
+--R             + 
+--R                      2         2   3 2            3           2  4          3 5
+--R             (208A b c  - 184B b c)d e  + (- 128A c  + 336B b c )d e - 128B c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     3 2 3            2         3  3 2
+--R               146A b d e  + (- 396A b c - 66B b )d e
+--R             + 
+--R                        2         2   4             3          2  5
+--R               (352A b c  + 188B b c)d e + (- 192A c  - 32B b c )d
+--R          *
+--R             x
+--R         + 
+--R                  3 3 2         2         3  4              2        2   5
+--R           - 30A b d e  + (96A b c - 18B b )d e + (- 96A b c  + 48B b c)d
+--R      *
+--R                            +----------+
+--R          +-----------+ +-+ |   2
+--R         \|- b e + c d \|d \|c x  + b x
+--R  /
+--R              3 3 7        2   4 6          2 5 5       3 6 4  4
+--R         (384b d e  - 1152b c d e  + 1152b c d e  - 384c d e )x
+--R       + 
+--R               3 4 6        2   5 5          2 6 4        3 7 3  3
+--R         (1536b d e  - 4608b c d e  + 4608b c d e  - 1536c d e )x
+--R       + 
+--R               3 5 5        2   6 4          2 7 3        3 8 2  2
+--R         (2304b d e  - 6912b c d e  + 6912b c d e  - 2304c d e )x
+--R       + 
+--R               3 6 4        2   7 3          2 8 2        3 9          3 7 3
+--R         (1536b d e  - 4608b c d e  + 4608b c d e  - 1536c d e)x + 384b d e
+--R       + 
+--R                2   8 2          2 9        3 10
+--R         - 1152b c d e  + 1152b c d e - 384c d
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   4 6           3        4    5         2 2        3   2 4  4
+--R             (15A b e  + (- 48A b c + 9B b )d e  + (48A b c  - 24B b c)d e )x
+--R           + 
+--R                      4   5            3         4  2 4
+--R                 60A b d e  + (- 192A b c + 36B b )d e
+--R               + 
+--R                        2 2        3   3 3
+--R                 (192A b c  - 96B b c)d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4 2 4            3         4  3 3
+--R                 90A b d e  + (- 288A b c + 54B b )d e
+--R               + 
+--R                        2 2         3   4 2
+--R                 (288A b c  - 144B b c)d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4 3 3            3         4  4 2
+--R                   60A b d e  + (- 192A b c + 36B b )d e
+--R                 + 
+--R                          2 2        3   5
+--R                   (192A b c  - 96B b c)d e
+--R            *
+--R               x
+--R           + 
+--R                  4 4 2           3        4  5          2 2        3   6
+--R             15A b d e  + (- 48A b c + 9B b )d e + (48A b c  - 24B b c)d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                      3 5           2         3    4           2        2   2 3
+--R                 30A b e  + (- 76A b c + 18B b )d e  + (48A b c  - 36B b c)d e
+--R               + 
+--R                         3          2  3 2        3 4
+--R                 (- 32A c  + 80B b c )d e  - 32B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       3   4            2         3  2 3
+--R                 110A b d e  + (- 280A b c + 66B b )d e
+--R               + 
+--R                          2         2   3 2            3           2  4
+--R                 (208A b c  - 184B b c)d e  + (- 128A c  + 336B b c )d e
+--R               + 
+--R                         3 5
+--R                 - 128B c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       3 2 3            2         3  3 2
+--R                 146A b d e  + (- 396A b c - 66B b )d e
+--R               + 
+--R                          2         2   4             3          2  5
+--R                 (352A b c  + 188B b c)d e + (- 192A c  - 32B b c )d
+--R            *
+--R               x
+--R           + 
+--R                    3 3 2         2         3  4              2        2   5
+--R             - 30A b d e  + (96A b c - 18B b )d e + (- 96A b c  + 48B b c)d
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R                3 3 7        2   4 6          2 5 5       3 6 4  4
+--R           (384b d e  - 1152b c d e  + 1152b c d e  - 384c d e )x
+--R         + 
+--R                 3 4 6        2   5 5          2 6 4        3 7 3  3
+--R           (1536b d e  - 4608b c d e  + 4608b c d e  - 1536c d e )x
+--R         + 
+--R                 3 5 5        2   6 4          2 7 3        3 8 2  2
+--R           (2304b d e  - 6912b c d e  + 6912b c d e  - 2304c d e )x
+--R         + 
+--R                 3 6 4        2   7 3          2 8 2        3 9          3 7 3
+--R           (1536b d e  - 4608b c d e  + 4608b c d e  - 1536c d e)x + 384b d e
+--R         + 
+--R                  2   8 2          2 9        3 10
+--R           - 1152b c d e  + 1152b c d e - 384c d
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                     4 6         3        4    5           2 2        3   2 4  4
+--R             (- 15A b e  + (48A b c - 9B b )d e  + (- 48A b c  + 24B b c)d e )x
+--R           + 
+--R                        4   5          3         4  2 4
+--R                 - 60A b d e  + (192A b c - 36B b )d e
+--R               + 
+--R                          2 2        3   3 3
+--R                 (- 192A b c  + 96B b c)d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4 2 4          3         4  3 3
+--R                 - 90A b d e  + (288A b c - 54B b )d e
+--R               + 
+--R                          2 2         3   4 2
+--R                 (- 288A b c  + 144B b c)d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4 3 3          3         4  4 2
+--R                 - 60A b d e  + (192A b c - 36B b )d e
+--R               + 
+--R                          2 2        3   5
+--R                 (- 192A b c  + 96B b c)d e
+--R            *
+--R               x
+--R           + 
+--R                    4 4 2         3        4  5            2 2        3   6
+--R             - 15A b d e  + (48A b c - 9B b )d e + (- 48A b c  + 24B b c)d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                      3 5           2        3    4           2        2   2 3
+--R                 15A b e  + (- 38A b c + 9B b )d e  + (24A b c  - 18B b c)d e
+--R               + 
+--R                         3          2  3 2        3 4
+--R                 (- 16A c  + 40B b c )d e  - 16B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      3   4            2         3  2 3
+--R                 55A b d e  + (- 140A b c + 33B b )d e
+--R               + 
+--R                        2        2   3 2           3           2  4         3 5
+--R               (104A b c  - 92B b c)d e  + (- 64A c  + 168B b c )d e - 64B c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      3 2 3            2         3  3 2
+--R                 73A b d e  + (- 198A b c - 33B b )d e
+--R               + 
+--R                          2        2   4            3          2  5
+--R                 (176A b c  + 94B b c)d e + (- 96A c  - 16B b c )d
+--R            *
+--R               x
+--R           + 
+--R                    3 3 2         2        3  4              2        2   5
+--R             - 15A b d e  + (48A b c - 9B b )d e + (- 48A b c  + 24B b c)d
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R                3 3 7       2   4 6         2 5 5       3 6 4  4
+--R           (192b d e  - 576b c d e  + 576b c d e  - 192c d e )x
+--R         + 
+--R                3 4 6        2   5 5          2 6 4       3 7 3  3
+--R           (768b d e  - 2304b c d e  + 2304b c d e  - 768c d e )x
+--R         + 
+--R                 3 5 5        2   6 4          2 7 3        3 8 2  2
+--R           (1152b d e  - 3456b c d e  + 3456b c d e  - 1152c d e )x
+--R         + 
+--R                3 6 4        2   7 3          2 8 2       3 9          3 7 3
+--R           (768b d e  - 2304b c d e  + 2304b c d e  - 768c d e)x + 192b d e
+--R         + 
+--R                 2   8 2         2 9        3 10
+--R           - 576b c d e  + 576b c d e - 192c d
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 354
+
+--S 355 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              4 2           3        4             2 2       3   2
+--R         (5A b e  + (- 16A b c + 3B b )d e + (16A b c  - 8B b c)d )
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R              4 2           3        4             2 2       3   2
+--R         (5A b e  + (- 16A b c + 3B b )d e + (16A b c  - 8B b c)d )
+--R      *
+--R          +--------------+
+--R          |             2              (b e - 2c d)x - b d
+--R         \|- b d e + c d  atanh(--------------------------------)
+--R                                                    +----------+
+--R                                  +-----------+ +-+ |   2
+--R                                2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                                                        +--------------+
+--R            3 3 3       2   4 2         2 5        3 6  |             2
+--R       (128b d e  - 384b c d e  + 384b c d e - 128c d )\|- b d e + c d
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              4 2           3        4             2 2       3   2
+--R         (5A b e  + (- 16A b c + 3B b )d e + (16A b c  - 8B b c)d )
+--R      *
+--R          +------------+
+--R          |           2              (b e - 2c d)x - b d
+--R         \|b d e - c d  atanh(--------------------------------)
+--R                                                  +----------+
+--R                                +-----------+ +-+ |   2
+--R                              2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                 4 2         3        4               2 2        3   2
+--R         (- 10A b e  + (32A b c - 6B b )d e + (- 32A b c  + 16B b c)d )
+--R      *
+--R                                 +------------+ +----------+
+--R                                 |           2  |   2
+--R          +-----------+ +-+     \|b d e - c d  \|c x  + b x
+--R         \|- b e + c d \|d atan(----------------------------)
+--R                                        (b e - c d)x
+--R  /
+--R            3 3 3       2   4 2         2 5        3 6  +-----------+ +-+
+--R       (128b d e  - 384b c d e  + 384b c d e - 128c d )\|- b e + c d \|d
+--R    *
+--R        +------------+
+--R        |           2
+--R       \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 358
+
+)clear all
+
+--S 359 of 1457
+t0:=(A+B*x)*(d+e*x)^2*(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R   (1)
+--R            2 5                2             4
+--R       B c e x  + ((A c + B b)e  + 2B c d e)x
+--R     + 
+--R             2                           2  3                           2  2
+--R       (A b e  + (2A c + 2B b)d e + B c d )x  + (2A b d e + (A c + B b)d )x
+--R     + 
+--R            2
+--R       A b d x
+--R  *
+--R      +----------+
+--R      |   2
+--R     \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 1457
+r0:=1/192*(48*A*c^3*d^2-9*b^3*B*e^2+14*b^2*c*e*(2*B*d+A*e)-24*b*c^2*d*(B*d+_
+     2*A*e))*x*(b*x+c*x^2)^(3/2)/c^3+1/840*(98*A*c*e*(2*c*d-b*e)+B*(48*_
+     c^2*d^2-146*b*c*d*e+63*b^2*e^2))*(b*x+c*x^2)^(5/2)/c^3+1/7*B*_
+     (d+e*x)^2*(b*x+c*x^2)^(5/2)/c-1/84*e*((5*b*B-14*A*c)*d-(4*B*c*d-_
+     9*b*B*e+14*A*c*e)*x)*(b*x+c*x^2)^(5/2)/c^2+1/1024*b^4*(48*A*c^3*d^2-_
+     9*b^3*B*e^2+14*b^2*c*e*(2*B*d+A*e)-24*b*c^2*d*(B*d+2*A*e))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(11/2)-1/1024*b^3*(48*A*c^3*d^2-_
+     9*b^3*B*e^2+14*b^2*c*e*(2*B*d+A*e)-24*b*c^2*d*(B*d+2*A*e))*sqrt(b*x+_
+     c*x^2)/c^5+1/1536*b^2*(48*A*c^3*d^2-9*b^3*B*e^2+14*b^2*c*e*(2*B*d+_
+     A*e)-24*b*c^2*d*(B*d+2*A*e))*x*sqrt(b*x+c*x^2)/c^4+1/384*b*_
+     (48*A*c^3*d^2-9*b^3*B*e^2+14*b^2*c*e*(2*B*d+A*e)-24*b*c^2*d*(B*d+_
+     2*A*e))*x^2*sqrt(b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                   6          7  2             5 2          6
+--R           (1470A b c - 945B b )e  + (- 5040A b c  + 2940B b c)d e
+--R         + 
+--R                   4 3          5 2  2
+--R           (5040A b c  - 2520B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                   6 2 6             6             5  2           6     5
+--R           15360B c e x  + ((17920A c  + 19200B b c )e  + 35840B c d e)x
+--R         + 
+--R                          5         2 4  2            6             5
+--R               (23296A b c  + 384B b c )e  + (43008A c  + 46592B b c )d e
+--R             + 
+--R                       6 2
+--R               21504B c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      2 4         3 3  2              5          2 4
+--R               (672A b c  - 432B b c )e  + (59136A b c  + 1344B b c )d e
+--R             + 
+--R                        6             5  2
+--R               (26880A c  + 29568B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                        3 3         4 2  2           2 4          3 3
+--R               (- 784A b c  + 504B b c )e  + (2688A b c  - 1568B b c )d e
+--R             + 
+--R                          5          2 4  2
+--R               (40320A b c  + 1344B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      4 2         5   2             3 3          4 2
+--R               (980A b c  - 630B b c)e  + (- 3360A b c  + 1960B b c )d e
+--R             + 
+--R                       2 4          3 3  2
+--R               (3360A b c  - 1680B b c )d
+--R          *
+--R             x
+--R         + 
+--R                     5          6  2           4 2          5
+--R           (- 1470A b c + 945B b )e  + (5040A b c  - 2940B b c)d e
+--R         + 
+--R                     3 3          4 2  2
+--R           (- 5040A b c  + 2520B b c )d
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R            5 +-+
+--R     107520c \|c
+--R                                                    Type: Expression(Integer)
+--E 360
+
+--S 361 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     6          7  2             5 2          6
+--R             (1470A b c - 945B b )e  + (- 5040A b c  + 2940B b c)d e
+--R           + 
+--R                     4 3          5 2  2
+--R             (5040A b c  - 2520B b c )d
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                     6 2 6             6             5  2           6     5
+--R             30720B c e x  + ((35840A c  + 38400B b c )e  + 71680B c d e)x
+--R           + 
+--R                            5         2 4  2            6             5
+--R                 (46592A b c  + 768B b c )e  + (86016A c  + 93184B b c )d e
+--R               + 
+--R                         6 2
+--R                 43008B c d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         2 4         3 3  2               5          2 4
+--R                 (1344A b c  - 864B b c )e  + (118272A b c  + 2688B b c )d e
+--R               + 
+--R                          6             5  2
+--R                 (53760A c  + 59136B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                           3 3          4 2  2           2 4          3 3
+--R                 (- 1568A b c  + 1008B b c )e  + (5376A b c  - 3136B b c )d e
+--R               + 
+--R                            5          2 4  2
+--R                 (80640A b c  + 2688B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         4 2          5   2             3 3          4 2
+--R                 (1960A b c  - 1260B b c)e  + (- 6720A b c  + 3920B b c )d e
+--R               + 
+--R                         2 4          3 3  2
+--R                 (6720A b c  - 3360B b c )d
+--R            *
+--R               x
+--R           + 
+--R                       5           6  2            4 2          5
+--R             (- 2940A b c + 1890B b )e  + (10080A b c  - 5880B b c)d e
+--R           + 
+--R                        3 3          4 2  2
+--R             (- 10080A b c  + 5040B b c )d
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R              5 +-+
+--R       215040c \|c
+--R     ,
+--R
+--R                     6          7  2             5 2          6
+--R             (1470A b c - 945B b )e  + (- 5040A b c  + 2940B b c)d e
+--R           + 
+--R                     4 3          5 2  2
+--R             (5040A b c  - 2520B b c )d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                     6 2 6             6             5  2           6     5
+--R             15360B c e x  + ((17920A c  + 19200B b c )e  + 35840B c d e)x
+--R           + 
+--R                            5         2 4  2            6             5
+--R                 (23296A b c  + 384B b c )e  + (43008A c  + 46592B b c )d e
+--R               + 
+--R                         6 2
+--R                 21504B c d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        2 4         3 3  2              5          2 4
+--R                 (672A b c  - 432B b c )e  + (59136A b c  + 1344B b c )d e
+--R               + 
+--R                          6             5  2
+--R                 (26880A c  + 29568B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          3 3         4 2  2           2 4          3 3
+--R                 (- 784A b c  + 504B b c )e  + (2688A b c  - 1568B b c )d e
+--R               + 
+--R                            5          2 4  2
+--R                 (40320A b c  + 1344B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4 2         5   2             3 3          4 2
+--R                 (980A b c  - 630B b c)e  + (- 3360A b c  + 1960B b c )d e
+--R               + 
+--R                         2 4          3 3  2
+--R                 (3360A b c  - 1680B b c )d
+--R            *
+--R               x
+--R           + 
+--R                       5          6  2           4 2          5
+--R             (- 1470A b c + 945B b )e  + (5040A b c  - 2940B b c)d e
+--R           + 
+--R                       3 3          4 2  2
+--R             (- 5040A b c  + 2520B b c )d
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R              5 +---+
+--R       107520c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 361
+
+--S 362 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 6        7  2           5 2        6
+--R           (14A b c - 9B b )e  + (- 48A b c  + 28B b c)d e
+--R         + 
+--R                 4 3        5 2  2
+--R           (48A b c  - 24B b c )d
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                   6         7  2         5 2        6
+--R           (- 28A b c + 18B b )e  + (96A b c  - 56B b c)d e
+--R         + 
+--R                   4 3        5 2  2
+--R           (- 96A b c  + 48B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R  /
+--R          5 +-+
+--R     2048c \|c
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+--S 364 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                   6        7  2         5 2        6
+--R           (- 14A b c + 9B b )e  + (48A b c  - 28B b c)d e
+--R         + 
+--R                   4 3        5 2  2
+--R           (- 48A b c  + 24B b c )d
+--R      *
+--R                           +-+
+--R          +---+          x\|c
+--R         \|- c atanh(-------------)
+--R                      +----------+
+--R                      |   2
+--R                     \|c x  + b x
+--R     + 
+--R                 6        7  2           5 2        6
+--R           (14A b c - 9B b )e  + (- 48A b c  + 28B b c)d e
+--R         + 
+--R                 4 3        5 2  2
+--R           (48A b c  - 24B b c )d
+--R      *
+--R                         +----------+
+--R                   +---+ |   2
+--R          +-+     \|- c \|c x  + b x
+--R         \|c atan(-------------------)
+--R                          c x
+--R  /
+--R          5 +---+ +-+
+--R     1024c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 365
+
+)clear all
+
+--S 366 of 1457
+t0:=(A+B*x)*(d+e*x)*(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R   (1)
+--R             4                          3                          2
+--R     (B c e x  + ((A c + B b)e + B c d)x  + (A b e + (A c + B b)d)x  + A b d x)
+--R  *
+--R      +----------+
+--R      |   2
+--R     \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 1457
+r0:=1/96*(24*A*c^2*d+7*b^2*B*e-12*b*c*(B*d+A*e))*x*(b*x+c*x^2)^(3/2)/c^2+_
+     1/60*(2*B*c*d-7*b*B*e+12*A*c*e)*(b*x+c*x^2)^(5/2)/c^2+1/6*B*(d+e*x)*_
+     (b*x+c*x^2)^(5/2)/c+1/512*b^4*(24*A*c^2*d+7*b^2*B*e-12*b*c*(B*d+_
+     A*e))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(9/2)-1/512*b^3*_
+     (24*A*c^2*d+7*b^2*B*e-12*b*c*(B*d+A*e))*sqrt(b*x+c*x^2)/c^4+_
+     1/768*b^2*(24*A*c^2*d+7*b^2*B*e-12*b*c*(B*d+A*e))*x*sqrt(b*x+_
+     c*x^2)/c^3+1/192*b*(24*A*c^2*d+7*b^2*B*e-12*b*c*(B*d+A*e))*x^2*_
+     sqrt(b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R                                                                      +-+
+--R                 5          6            4 2         5              x\|c
+--R       ((- 180A b c + 105B b )e + (360A b c  - 180B b c)d)atanh(-------------)
+--R                                                                 +----------+
+--R                                                                 |   2
+--R                                                                \|c x  + b x
+--R     + 
+--R                  5   5            5            4            5   4
+--R           1280B c e x  + ((1536A c  + 1664B b c )e + 1536B c d)x
+--R         + 
+--R                      4        2 3             5            4    3
+--R           ((2112A b c  + 48B b c )e + (1920A c  + 2112B b c )d)x
+--R         + 
+--R                  2 3        3 2               4        2 3    2
+--R           ((96A b c  - 56B b c )e + (2880A b c  + 96B b c )d)x
+--R         + 
+--R                     3 2        4             2 3         3 2
+--R           ((- 120A b c  + 70B b c)e + (240A b c  - 120B b c )d)x
+--R         + 
+--R                  4          5              3 2         4
+--R           (180A b c - 105B b )e + (- 360A b c  + 180B b c)d
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R          4 +-+
+--R     7680c \|c
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   5          6              4 2         5
+--R           ((180A b c - 105B b )e + (- 360A b c  + 180B b c)d)
+--R        *
+--R                    +----------+
+--R                    |   2                     +-+
+--R           log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                    5   5            5            4            5   4
+--R             2560B c e x  + ((3072A c  + 3328B b c )e + 3072B c d)x
+--R           + 
+--R                        4        2 3             5            4    3
+--R             ((4224A b c  + 96B b c )e + (3840A c  + 4224B b c )d)x
+--R           + 
+--R                     2 3         3 2               4         2 3    2
+--R             ((192A b c  - 112B b c )e + (5760A b c  + 192B b c )d)x
+--R           + 
+--R                       3 2         4             2 3         3 2
+--R             ((- 240A b c  + 140B b c)e + (480A b c  - 240B b c )d)x
+--R           + 
+--R                    4          5              3 2         4
+--R             (360A b c - 210B b )e + (- 720A b c  + 360B b c)d
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R             4 +-+
+--R       15360c \|c
+--R     ,
+--R
+--R                     5          6            4 2         5
+--R           ((- 180A b c + 105B b )e + (360A b c  - 180B b c)d)
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                    5   5            5            4            5   4
+--R             1280B c e x  + ((1536A c  + 1664B b c )e + 1536B c d)x
+--R           + 
+--R                        4        2 3             5            4    3
+--R             ((2112A b c  + 48B b c )e + (1920A c  + 2112B b c )d)x
+--R           + 
+--R                    2 3        3 2               4        2 3    2
+--R             ((96A b c  - 56B b c )e + (2880A b c  + 96B b c )d)x
+--R           + 
+--R                       3 2        4             2 3         3 2
+--R             ((- 120A b c  + 70B b c)e + (240A b c  - 120B b c )d)x
+--R           + 
+--R                    4          5              3 2         4
+--R             (180A b c - 105B b )e + (- 360A b c  + 180B b c)d
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R            4 +---+
+--R       7680c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 368
+
+--S 369 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                5        6             4 2        5
+--R         ((12A b c - 7B b )e + (- 24A b c  + 12B b c)d)
+--R      *
+--R                  +----------+
+--R                  |   2                     +-+
+--R         log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                                                  +-+
+--R              5         6             4 2        5              x\|c
+--R       ((24A b c - 14B b )e + (- 48A b c  + 24B b c)d)atanh(-------------)
+--R                                                             +----------+
+--R                                                             |   2
+--R                                                            \|c x  + b x
+--R  /
+--R          4 +-+
+--R     1024c \|c
+--R                                                    Type: Expression(Integer)
+--E 369
+
+--S 370 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                       +-+
+--R              5        6             4 2        5     +---+          x\|c
+--R       ((12A b c - 7B b )e + (- 24A b c  + 12B b c)d)\|- c atanh(-------------)
+--R                                                                  +----------+
+--R                                                                  |   2
+--R                                                                 \|c x  + b x
+--R     + 
+--R                                                                   +----------+
+--R                                                             +---+ |   2
+--R              5        6           4 2        5     +-+     \|- c \|c x  + b x
+--R     ((- 12A b c + 7B b )e + (24A b c  - 12B b c)d)\|c atan(-------------------)
+--R                                                                    c x
+--R  /
+--R         4 +---+ +-+
+--R     512c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R                                         +----------+
+--R              3               2          |   2
+--R   (1)  (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 1457
+r0:=-1/8*(b*B-2*A*c)*x*(b*x+c*x^2)^(3/2)/c+1/5*B*(b*x+c*x^2)^(5/2)/c-_
+     3/128*b^4*(b*B-2*A*c)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(7/2)+_
+     3/128*b^3*(b*B-2*A*c)*sqrt(b*x+c*x^2)/c^3-1/64*b^2*(b*B-2*A*c)*x*_
+     sqrt(b*x+c*x^2)/c^2-1/16*b*(b*B-2*A*c)*x^2*sqrt(b*x+c*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                     +-+
+--R             4         5           x\|c
+--R       (30A b c - 15B b )atanh(-------------)
+--R                                +----------+
+--R                                |   2
+--R                               \|c x  + b x
+--R     + 
+--R                 4 4          4           3  3            3       2 2  2
+--R           128B c x  + (160A c  + 176B b c )x  + (240A b c  + 8B b c )x
+--R         + 
+--R                 2 2        3           3         4
+--R           (20A b c  - 10B b c)x - 30A b c + 15B b
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R         3 +-+
+--R     640c \|c
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                  +----------+
+--R               4         5        |   2                     +-+
+--R         (30A b c - 15B b )log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                   4 4          4           3  3            3        2 2  2
+--R             256B c x  + (320A c  + 352B b c )x  + (480A b c  + 16B b c )x
+--R           + 
+--R                   2 2        3           3         4
+--R             (40A b c  - 20B b c)x - 60A b c + 30B b
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R            3 +-+
+--R       1280c \|c
+--R     ,
+--R
+--R                                       +----------+
+--R                                 +---+ |   2
+--R               4         5      \|- c \|c x  + b x
+--R         (30A b c - 15B b )atan(-------------------)
+--R                                        c x
+--R       + 
+--R                   4 4          4           3  3            3       2 2  2
+--R             128B c x  + (160A c  + 176B b c )x  + (240A b c  + 8B b c )x
+--R           + 
+--R                   2 2        3           3         4
+--R             (20A b c  - 10B b c)x - 30A b c + 15B b
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R           3 +---+
+--R       640c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 375
+
+--S 376 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                              +----------+
+--R            4        5        |   2                     +-+
+--R       (6A b c - 3B b )log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                      +-+
+--R               4        5           x\|c
+--R       (- 12A b c + 6B b )atanh(-------------)
+--R                                 +----------+
+--R                                 |   2
+--R                                \|c x  + b x
+--R  /
+--R         3 +-+
+--R     256c \|c
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                           +-+
+--R              4        5  +---+          x\|c
+--R       (- 6A b c + 3B b )\|- c atanh(-------------)
+--R                                      +----------+
+--R                                      |   2
+--R                                     \|c x  + b x
+--R     + 
+--R                                       +----------+
+--R                                 +---+ |   2
+--R            4        5  +-+     \|- c \|c x  + b x
+--R       (6A b c - 3B b )\|c atan(-------------------)
+--R                                        c x
+--R  /
+--R         3 +---+ +-+
+--R     128c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 378
+
+--S 379 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 379
+
+)clear all
+
+--S 380 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)
+--R 
+--R
+--R                                         +----------+
+--R              3               2          |   2
+--R        (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  ---------------------------------------------
+--R                           e x + d
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 1457
+r0:=-1/24*(8*B*c*d-3*b*B*e-8*A*c*e-6*B*c*e*x)*(b*x+c*x^2)^(3/2)/(c*e^2)-_
+     1/64*(8*A*c*e*(16*c^3*d^3-24*b*c^2*d^2*e+6*b^2*c*d*e^2+b^3*e^3)-_
+     B*(128*c^4*d^4-192*b*c^3*d^3*e+48*b^2*c^2*d^2*e^2+8*b^3*c*d*e^3+_
+     3*b^4*e^4))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(c^(5/2)*e^5)-d^(3/2)*_
+     (B*d-A*e)*(c*d-b*e)^(3/2)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/e^5+1/64*(8*A*c*e*(8*c^2*d^2-_
+     10*b*c*d*e+b^2*e^2)-B*(64*c^3*d^3-80*b*c^2*d^2*e+8*b^2*c*d*e^2+_
+     3*b^3*e^3)-2*c*e*(8*A*c*e*(2*c*d-b*e)-B*(16*c^2*d^2-8*b*c*d*e-_
+     3*b^2*e^2))*x)*sqrt(b*x+c*x^2)/(c^2*e^4)
+--R 
+--R
+--R   (2)
+--R                   3        4  4            2 2        3     3
+--R           (- 24A b c + 9B b )e  + (- 144A b c  + 24B b c)d e
+--R         + 
+--R                    3         2 2  2 2            4           3  3          4 4
+--R           (576A b c  + 144B b c )d e  + (- 384A c  - 576B b c )d e + 384B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                  2   2            3           2  2          3 3  +-----------+
+--R         (192A b c d e  + (- 192A c  - 192B b c )d e + 192B c d )\|- b e + c d
+--R      *
+--R          +-+ +-+             (b e - 2c d)x - b d
+--R         \|c \|d atanh(--------------------------------)
+--R                                           +----------+
+--R                         +-----------+ +-+ |   2
+--R                       2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                3 4 3          3          2  4        3   3  2
+--R           48B c e x  + ((64A c  + 72B b c )e  - 64B c d e )x
+--R         + 
+--R                     2       2   4           3           2    3        3 2 2
+--R           ((112A b c  + 6B b c)e  + (- 96A c  - 112B b c )d e  + 96B c d e )x
+--R         + 
+--R                 2        3  4              2        2     3
+--R           (24A b c - 9B b )e  + (- 240A b c  - 24B b c)d e
+--R         + 
+--R                  3           2  2 2         3 3
+--R           (192A c  + 240B b c )d e  - 192B c d e
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R         2 5 +-+
+--R     192c e \|c
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      2   2          3           2  2          3 3
+--R           (- 384A b c d e  + (384A c  + 384B b c )d e - 384B c d )
+--R        *
+--R            +--------------+
+--R            |             2  +-+
+--R           \|- b d e + c d  \|c
+--R        *
+--R                 +--------------+ +----------+
+--R                 |             2  |   2
+--R               2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R           log(-------------------------------------------------------)
+--R                                       e x + d
+--R       + 
+--R                   3        4  4          2 2        3     3
+--R             (24A b c - 9B b )e  + (144A b c  - 24B b c)d e
+--R           + 
+--R                      3         2 2  2 2          4           3  3          4 4
+--R           (- 576A b c  - 144B b c )d e  + (384A c  + 576B b c )d e - 384B c d
+--R        *
+--R                    +----------+
+--R                    |   2                     +-+
+--R           log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                  3 4 3           3           2  4         3   3  2
+--R             96B c e x  + ((128A c  + 144B b c )e  - 128B c d e )x
+--R           + 
+--R                          2        2   4            3           2    3
+--R                 (224A b c  + 12B b c)e  + (- 192A c  - 224B b c )d e
+--R               + 
+--R                       3 2 2
+--R                 192B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2         3  4              2        2     3
+--R             (48A b c - 18B b )e  + (- 480A b c  - 48B b c)d e
+--R           + 
+--R                    3           2  2 2         3 3
+--R             (384A c  + 480B b c )d e  - 384B c d e
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R           2 5 +-+
+--R       384c e \|c
+--R     ,
+--R
+--R                   3        4  4          2 2        3     3
+--R             (24A b c - 9B b )e  + (144A b c  - 24B b c)d e
+--R           + 
+--R                      3         2 2  2 2          4           3  3          4 4
+--R           (- 576A b c  - 144B b c )d e  + (384A c  + 576B b c )d e - 384B c d
+--R        *
+--R                    +----------+
+--R                    |   2                     +-+
+--R           log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                      2   2          3           2  2          3 3  +-+
+--R           (- 768A b c d e  + (768A c  + 768B b c )d e - 768B c d )\|c
+--R        *
+--R                                  +----------+
+--R            +------------+        |   2
+--R            |           2       d\|c x  + b x
+--R           \|b d e - c d  atan(----------------)
+--R                                 +------------+
+--R                                 |           2
+--R                               x\|b d e - c d
+--R       + 
+--R                  3 4 3           3           2  4         3   3  2
+--R             96B c e x  + ((128A c  + 144B b c )e  - 128B c d e )x
+--R           + 
+--R                          2        2   4            3           2    3
+--R                 (224A b c  + 12B b c)e  + (- 192A c  - 224B b c )d e
+--R               + 
+--R                       3 2 2
+--R                 192B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2         3  4              2        2     3
+--R             (48A b c - 18B b )e  + (- 480A b c  - 48B b c)d e
+--R           + 
+--R                    3           2  2 2         3 3
+--R             (384A c  + 480B b c )d e  - 384B c d e
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R           2 5 +-+
+--R       384c e \|c
+--R     ,
+--R
+--R                      2   2          3           2  2          3 3
+--R           (- 192A b c d e  + (192A c  + 192B b c )d e - 192B c d )
+--R        *
+--R            +--------------+
+--R            |             2  +---+
+--R           \|- b d e + c d  \|- c
+--R        *
+--R                 +--------------+ +----------+
+--R                 |             2  |   2
+--R               2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R           log(-------------------------------------------------------)
+--R                                       e x + d
+--R       + 
+--R                     3        4  4            2 2        3     3
+--R             (- 24A b c + 9B b )e  + (- 144A b c  + 24B b c)d e
+--R           + 
+--R                    3         2 2  2 2            4           3  3          4 4
+--R           (576A b c  + 144B b c )d e  + (- 384A c  - 576B b c )d e + 384B c d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                  3 4 3          3          2  4        3   3  2
+--R             48B c e x  + ((64A c  + 72B b c )e  - 64B c d e )x
+--R           + 
+--R                       2       2   4           3           2    3        3 2 2
+--R             ((112A b c  + 6B b c)e  + (- 96A c  - 112B b c )d e  + 96B c d e )x
+--R           + 
+--R                   2        3  4              2        2     3
+--R             (24A b c - 9B b )e  + (- 240A b c  - 24B b c)d e
+--R           + 
+--R                    3           2  2 2         3 3
+--R             (192A c  + 240B b c )d e  - 192B c d e
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R           2 5 +---+
+--R       192c e \|- c
+--R     ,
+--R
+--R                     3        4  4            2 2        3     3
+--R             (- 24A b c + 9B b )e  + (- 144A b c  + 24B b c)d e
+--R           + 
+--R                    3         2 2  2 2            4           3  3          4 4
+--R           (576A b c  + 144B b c )d e  + (- 384A c  - 576B b c )d e + 384B c d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                      2   2          3           2  2          3 3  +---+
+--R           (- 384A b c d e  + (384A c  + 384B b c )d e - 384B c d )\|- c
+--R        *
+--R                                  +----------+
+--R            +------------+        |   2
+--R            |           2       d\|c x  + b x
+--R           \|b d e - c d  atan(----------------)
+--R                                 +------------+
+--R                                 |           2
+--R                               x\|b d e - c d
+--R       + 
+--R                  3 4 3          3          2  4        3   3  2
+--R             48B c e x  + ((64A c  + 72B b c )e  - 64B c d e )x
+--R           + 
+--R                       2       2   4           3           2    3        3 2 2
+--R             ((112A b c  + 6B b c)e  + (- 96A c  - 112B b c )d e  + 96B c d e )x
+--R           + 
+--R                   2        3  4              2        2     3
+--R             (24A b c - 9B b )e  + (- 240A b c  - 24B b c)d e
+--R           + 
+--R                    3           2  2 2         3 3
+--R             (192A c  + 240B b c )d e  - 192B c d e
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R           2 5 +---+
+--R       192c e \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 382
+
+--S 383 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    2   2          3           2  2          3 3
+--R         (- 128A b c d e  + (128A c  + 128B b c )d e - 128B c d )
+--R      *
+--R          +--------------+
+--R          |             2  +-+
+--R         \|- b d e + c d  \|c
+--R      *
+--R               +--------------+ +----------+
+--R               |             2  |   2
+--R             2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R         log(-------------------------------------------------------)
+--R                                     e x + d
+--R     + 
+--R                3        4  4         2 2       3     3
+--R           (8A b c - 3B b )e  + (48A b c  - 8B b c)d e
+--R         + 
+--R                      3        2 2  2 2          4           3  3          4 4
+--R           (- 192A b c  - 48B b c )d e  + (128A c  + 192B b c )d e - 128B c d
+--R      *
+--R                  +----------+
+--R                  |   2                     +-+
+--R         log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                 3        4  4         2 2        3     3
+--R           (16A b c - 6B b )e  + (96A b c  - 16B b c)d e
+--R         + 
+--R                      3        2 2  2 2          4           3  3          4 4
+--R           (- 384A b c  - 96B b c )d e  + (256A c  + 384B b c )d e - 256B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                    2   2          3           2  2          3 3  +-----------+
+--R         (- 128A b c d e  + (128A c  + 128B b c )d e - 128B c d )\|- b e + c d
+--R      *
+--R          +-+ +-+             (b e - 2c d)x - b d
+--R         \|c \|d atanh(--------------------------------)
+--R                                           +----------+
+--R                         +-----------+ +-+ |   2
+--R                       2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R         2 5 +-+
+--R     128c e \|c
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 384
+
+--S 385 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                3        4  4         2 2       3     3
+--R           (8A b c - 3B b )e  + (48A b c  - 8B b c)d e
+--R         + 
+--R                      3        2 2  2 2          4           3  3          4 4
+--R           (- 192A b c  - 48B b c )d e  + (128A c  + 192B b c )d e - 128B c d
+--R      *
+--R                  +----------+
+--R                  |   2                     +-+
+--R         log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                 3        4  4         2 2        3     3
+--R           (16A b c - 6B b )e  + (96A b c  - 16B b c)d e
+--R         + 
+--R                      3        2 2  2 2          4           3  3          4 4
+--R           (- 384A b c  - 96B b c )d e  + (256A c  + 384B b c )d e - 256B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                    2   2          3           2  2          3 3  +-----------+
+--R         (- 128A b c d e  + (128A c  + 128B b c )d e - 128B c d )\|- b e + c d
+--R      *
+--R          +-+ +-+             (b e - 2c d)x - b d
+--R         \|c \|d atanh(--------------------------------)
+--R                                           +----------+
+--R                         +-----------+ +-+ |   2
+--R                       2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                    2   2          3           2  2          3 3  +-+
+--R         (- 256A b c d e  + (256A c  + 256B b c )d e - 256B c d )\|c
+--R      *
+--R                                +----------+
+--R          +------------+        |   2
+--R          |           2       d\|c x  + b x
+--R         \|b d e - c d  atan(----------------)
+--R                               +------------+
+--R                               |           2
+--R                             x\|b d e - c d
+--R  /
+--R         2 5 +-+
+--R     128c e \|c
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 386
+
+)clear all
+
+--S 387 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^2
+--R 
+--R
+--R                                         +----------+
+--R              3               2          |   2
+--R        (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  ---------------------------------------------
+--R                       2 2             2
+--R                      e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 1457
+r0:=1/3*(4*B*d-3*A*e+B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*(d+e*x))+1/8*(4*b*c*e*_
+     (4*B*d-3*A*e)*(2*c*d-b*e)-(8*B*c*d-b*B*e-6*A*c*e)*(8*c^2*d^2-_
+     4*b*c*d*e-b^2*e^2))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(c^(3/2)*e^5)+_
+     1/2*(B*d*(8*c*d-5*b*e)-3*A*e*(2*c*d-b*e))*atanh(1/2*(b*d+(2*c*d-_
+     b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))*sqrt(d)*sqrt(c*d-_
+     b*e)/e^5-1/8*(6*A*c*e*(4*c*d-3*b*e)-B*(32*c^2*d^2-28*b*c*d*e+_
+     b^2*e^2)+2*c*e*(8*B*c*d-b*B*e-6*A*c*e)*x)*sqrt(b*x+c*x^2)/(c*e^4)
+--R 
+--R
+--R   (2)
+--R                     2        3  4              2        2     3
+--R               (18A b c - 3B b )e  + (- 144A b c  - 36B b c)d e
+--R             + 
+--R                      3           2  2 2         3 3
+--R               (144A c  + 216B b c )d e  - 192B c d e
+--R          *
+--R             x
+--R         + 
+--R                 2        3    3              2        2   2 2
+--R           (18A b c - 3B b )d e  + (- 144A b c  - 36B b c)d e
+--R         + 
+--R                  3           2  3          3 4
+--R           (144A c  + 216B b c )d e - 192B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                       3         2              2        2 2                 2
+--R           (- 36A b c e  + (72A c  + 60B b c)d e  - 96B c d e)x - 36A b c d e
+--R         + 
+--R                 2            2         2 3
+--R           (72A c  + 60B b c)d e - 96B c d
+--R      *
+--R          +-----------+ +-+ +-+             (b e - 2c d)x - b d
+--R         \|- b e + c d \|c \|d atanh(--------------------------------)
+--R                                                         +----------+
+--R                                       +-----------+ +-+ |   2
+--R                                     2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R               2 4 3          2            4        2   3  2
+--R           8B c e x  + ((12A c  + 14B b c)e  - 16B c d e )x
+--R         + 
+--R                           2  4           2              3        2 2 2
+--R           ((30A b c + 3B b )e  + (- 36A c  - 46B b c)d e  + 48B c d e )x
+--R         + 
+--R                          2    3           2            2 2        2 3
+--R           (54A b c + 3B b )d e  + (- 72A c  - 84B b c)d e  + 96B c d e
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R           6           5  +-+
+--R     (24c e x + 24c d e )\|c
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       3            2               2         2 2
+--R             (72A b c e  + (- 144A c  - 120B b c)d e  + 192B c d e)x
+--R           + 
+--R                        2            2             2          2 3
+--R             72A b c d e  + (- 144A c  - 120B b c)d e + 192B c d
+--R        *
+--R            +--------------+
+--R            |             2  +-+
+--R           \|- b d e + c d  \|c
+--R        *
+--R                 +--------------+ +----------+
+--R                 |             2  |   2
+--R               2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R           log(-------------------------------------------------------)
+--R                                       e x + d
+--R       + 
+--R                       2        3  4              2        2     3
+--R                 (18A b c - 3B b )e  + (- 144A b c  - 36B b c)d e
+--R               + 
+--R                        3           2  2 2         3 3
+--R                 (144A c  + 216B b c )d e  - 192B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2        3    3              2        2   2 2
+--R             (18A b c - 3B b )d e  + (- 144A b c  - 36B b c)d e
+--R           + 
+--R                    3           2  3          3 4
+--R             (144A c  + 216B b c )d e - 192B c d
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                  2 4 3          2            4        2   3  2
+--R             16B c e x  + ((24A c  + 28B b c)e  - 32B c d e )x
+--R           + 
+--R                             2  4           2              3        2 2 2
+--R             ((60A b c + 6B b )e  + (- 72A c  - 92B b c)d e  + 96B c d e )x
+--R           + 
+--R                             2    3            2             2 2         2 3
+--R             (108A b c + 6B b )d e  + (- 144A c  - 168B b c)d e  + 192B c d e
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R             6           5  +-+
+--R       (48c e x + 48c d e )\|c
+--R     ,
+--R
+--R                       2        3  4              2        2     3
+--R                 (18A b c - 3B b )e  + (- 144A b c  - 36B b c)d e
+--R               + 
+--R                        3           2  2 2         3 3
+--R                 (144A c  + 216B b c )d e  - 192B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2        3    3              2        2   2 2
+--R             (18A b c - 3B b )d e  + (- 144A b c  - 36B b c)d e
+--R           + 
+--R                    3           2  3          3 4
+--R             (144A c  + 216B b c )d e - 192B c d
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                        3            2               2         2 2
+--R             (144A b c e  + (- 288A c  - 240B b c)d e  + 384B c d e)x
+--R           + 
+--R                         2            2             2          2 3
+--R             144A b c d e  + (- 288A c  - 240B b c)d e + 384B c d
+--R        *
+--R                                      +----------+
+--R                +------------+        |   2
+--R            +-+ |           2       d\|c x  + b x
+--R           \|c \|b d e - c d  atan(----------------)
+--R                                     +------------+
+--R                                     |           2
+--R                                   x\|b d e - c d
+--R       + 
+--R                  2 4 3          2            4        2   3  2
+--R             16B c e x  + ((24A c  + 28B b c)e  - 32B c d e )x
+--R           + 
+--R                             2  4           2              3        2 2 2
+--R             ((60A b c + 6B b )e  + (- 72A c  - 92B b c)d e  + 96B c d e )x
+--R           + 
+--R                             2    3            2             2 2         2 3
+--R             (108A b c + 6B b )d e  + (- 144A c  - 168B b c)d e  + 192B c d e
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R             6           5  +-+
+--R       (48c e x + 48c d e )\|c
+--R     ,
+--R
+--R                       3           2              2        2 2                 2
+--R             (36A b c e  + (- 72A c  - 60B b c)d e  + 96B c d e)x + 36A b c d e
+--R           + 
+--R                     2            2         2 3
+--R             (- 72A c  - 60B b c)d e + 96B c d
+--R        *
+--R            +--------------+
+--R            |             2  +---+
+--R           \|- b d e + c d  \|- c
+--R        *
+--R                 +--------------+ +----------+
+--R                 |             2  |   2
+--R               2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R           log(-------------------------------------------------------)
+--R                                       e x + d
+--R       + 
+--R                       2        3  4              2        2     3
+--R                 (18A b c - 3B b )e  + (- 144A b c  - 36B b c)d e
+--R               + 
+--R                        3           2  2 2         3 3
+--R                 (144A c  + 216B b c )d e  - 192B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2        3    3              2        2   2 2
+--R             (18A b c - 3B b )d e  + (- 144A b c  - 36B b c)d e
+--R           + 
+--R                    3           2  3          3 4
+--R             (144A c  + 216B b c )d e - 192B c d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                 2 4 3          2            4        2   3  2
+--R             8B c e x  + ((12A c  + 14B b c)e  - 16B c d e )x
+--R           + 
+--R                             2  4           2              3        2 2 2
+--R             ((30A b c + 3B b )e  + (- 36A c  - 46B b c)d e  + 48B c d e )x
+--R           + 
+--R                            2    3           2            2 2        2 3
+--R             (54A b c + 3B b )d e  + (- 72A c  - 84B b c)d e  + 96B c d e
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R             6           5  +---+
+--R       (24c e x + 24c d e )\|- c
+--R     ,
+--R
+--R                       2        3  4              2        2     3
+--R                 (18A b c - 3B b )e  + (- 144A b c  - 36B b c)d e
+--R               + 
+--R                        3           2  2 2         3 3
+--R                 (144A c  + 216B b c )d e  - 192B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2        3    3              2        2   2 2
+--R             (18A b c - 3B b )d e  + (- 144A b c  - 36B b c)d e
+--R           + 
+--R                    3           2  3          3 4
+--R             (144A c  + 216B b c )d e - 192B c d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                       3            2               2         2 2
+--R             (72A b c e  + (- 144A c  - 120B b c)d e  + 192B c d e)x
+--R           + 
+--R                        2            2             2          2 3
+--R             72A b c d e  + (- 144A c  - 120B b c)d e + 192B c d
+--R        *
+--R                                        +----------+
+--R                  +------------+        |   2
+--R            +---+ |           2       d\|c x  + b x
+--R           \|- c \|b d e - c d  atan(----------------)
+--R                                       +------------+
+--R                                       |           2
+--R                                     x\|b d e - c d
+--R       + 
+--R                 2 4 3          2            4        2   3  2
+--R             8B c e x  + ((12A c  + 14B b c)e  - 16B c d e )x
+--R           + 
+--R                             2  4           2              3        2 2 2
+--R             ((30A b c + 3B b )e  + (- 36A c  - 46B b c)d e  + 48B c d e )x
+--R           + 
+--R                            2    3           2            2 2        2 3
+--R             (54A b c + 3B b )d e  + (- 72A c  - 84B b c)d e  + 96B c d e
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R             6           5  +---+
+--R       (24c e x + 24c d e )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 389
+
+--S 390 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                           +--------------+
+--R                   2           2                      2 2  |             2  +-+
+--R         (24A b c e  + (- 48A c  - 40B b c)d e + 64B c d )\|- b d e + c d  \|c
+--R      *
+--R               +--------------+ +----------+
+--R               |             2  |   2
+--R             2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R         log(-------------------------------------------------------)
+--R                                     e x + d
+--R     + 
+--R                2       3  3             2        2     2
+--R           (6A b c - B b )e  + (- 48A b c  - 12B b c)d e
+--R         + 
+--R                 3          2  2         3 3
+--R           (48A c  + 72B b c )d e - 64B c d
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                   2        3  3           2        2     2
+--R           (- 12A b c + 2B b )e  + (96A b c  + 24B b c)d e
+--R         + 
+--R                   3           2  2          3 3
+--R           (- 96A c  - 144B b c )d e + 128B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                   2           2                      2 2  +-----------+ +-+ +-+
+--R         (24A b c e  + (- 48A c  - 40B b c)d e + 64B c d )\|- b e + c d \|c \|d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R          5 +-+
+--R     16c e \|c
+--R                                                    Type: Expression(Integer)
+--E 390
+
+--S 391 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                2       3  3             2        2     2
+--R           (6A b c - B b )e  + (- 48A b c  - 12B b c)d e
+--R         + 
+--R                 3          2  2         3 3
+--R           (48A c  + 72B b c )d e - 64B c d
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                   2        3  3           2        2     2
+--R           (- 12A b c + 2B b )e  + (96A b c  + 24B b c)d e
+--R         + 
+--R                   3           2  2          3 3
+--R           (- 96A c  - 144B b c )d e + 128B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                   2           2                      2 2  +-----------+ +-+ +-+
+--R         (24A b c e  + (- 48A c  - 40B b c)d e + 64B c d )\|- b e + c d \|c \|d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                                                                +------------+
+--R                   2           2                       2 2  +-+ |           2
+--R         (48A b c e  + (- 96A c  - 80B b c)d e + 128B c d )\|c \|b d e - c d
+--R      *
+--R                 +----------+
+--R                 |   2
+--R               d\|c x  + b x
+--R         atan(----------------)
+--R                +------------+
+--R                |           2
+--R              x\|b d e - c d
+--R  /
+--R          5 +-+
+--R     16c e \|c
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^3
+--R 
+--R
+--R                                         +----------+
+--R              3               2          |   2
+--R        (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  ---------------------------------------------
+--R                  3 3       2 2     2       3
+--R                 e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 1457
+r0:=1/2*(2*B*d-A*e+B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*(d+e*x)^2)-3/4*(4*A*c*e*_
+     (2*c*d-b*e)-B*(16*c^2*d^2-12*b*c*d*e+b^2*e^2))*atanh(x*sqrt(c)/_
+     sqrt(b*x+c*x^2))/(e^5*sqrt(c))+3/8*(A*e*(8*c^2*d^2-8*b*c*d*e+_
+     b^2*e^2)-B*d*(16*c^2*d^2-20*b*c*d*e+5*b^2*e^2))*atanh(1/2*(b*d+_
+     (2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(e^5*_
+     sqrt(d)*sqrt(c*d-b*e))-3/4*(4*B*d*(2*c*d-b*e)-A*e*(4*c*d-b*e)+_
+     e*(4*B*c*d-b*B*e-2*A*c*e)*x)*sqrt(b*x+c*x^2)/(e^4*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                           2  4           2              3        2 2 2  2
+--R           ((24A b c + 6B b )e  + (- 48A c  - 72B b c)d e  + 96B c d e )x
+--R         + 
+--R                            2    3           2             2 2         2 3
+--R           ((48A b c + 12B b )d e  + (- 96A c  - 144B b c)d e  + 192B c d e)x
+--R         + 
+--R                          2  2 2           2            3         2 4
+--R           (24A b c + 6B b )d e  + (- 48A c  - 72B b c)d e + 96B c d
+--R      *
+--R                                       +-+
+--R          +-----------+ +-+          x\|c
+--R         \|- b e + c d \|d atanh(-------------)
+--R                                  +----------+
+--R                                  |   2
+--R                                 \|c x  + b x
+--R     + 
+--R                     2 5                   2    4           2            2 3
+--R               - 3A b e  + (24A b c + 15B b )d e  + (- 24A c  - 60B b c)d e
+--R             + 
+--R                    2 3 2
+--R               48B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     2   4                   2  2 3           2             3 2
+--R               - 6A b d e  + (48A b c + 30B b )d e  + (- 48A c  - 120B b c)d e
+--R             + 
+--R                    2 4
+--R               96B c d e
+--R          *
+--R             x
+--R         + 
+--R                 2 2 3                   2  3 2           2            4
+--R           - 3A b d e  + (24A b c + 15B b )d e  + (- 24A c  - 60B b c)d e
+--R         + 
+--R                2 5
+--R           48B c d
+--R      *
+--R          +-+             (b e - 2c d)x - b d
+--R         \|c atanh(--------------------------------)
+--R                                       +----------+
+--R                     +-----------+ +-+ |   2
+--R                   2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                 4 3                   4            3  2
+--R           4B c e x  + ((8A c + 10B b)e  - 16B c d e )x
+--R         + 
+--R                     4                     3          2 2             3
+--R           (- 10A b e  + (36A c + 38B b)d e  - 72B c d e )x - 6A b d e
+--R         + 
+--R                           2 2          3
+--R           (24A c + 24B b)d e  - 48B c d e
+--R      *
+--R                                +----------+
+--R          +-----------+ +-+ +-+ |   2
+--R         \|- b e + c d \|c \|d \|c x  + b x
+--R  /
+--R        7 2        6      2 5  +-----------+ +-+ +-+
+--R     (8e x  + 16d e x + 8d e )\|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             2  4           2              3        2 2 2  2
+--R             ((12A b c + 3B b )e  + (- 24A c  - 36B b c)d e  + 48B c d e )x
+--R           + 
+--R                             2    3           2            2 2        2 3
+--R             ((24A b c + 6B b )d e  + (- 48A c  - 72B b c)d e  + 96B c d e)x
+--R           + 
+--R                            2  2 2           2            3         2 4
+--R             (12A b c + 3B b )d e  + (- 24A c  - 36B b c)d e + 48B c d
+--R        *
+--R            +--------------+       +----------+
+--R            |             2        |   2                     +-+
+--R           \|- b d e + c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                       2 5                   2    4           2            2 3
+--R                 - 3A b e  + (24A b c + 15B b )d e  + (- 24A c  - 60B b c)d e
+--R               + 
+--R                      2 3 2
+--R                 48B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2   4                   2  2 3
+--R                 - 6A b d e  + (48A b c + 30B b )d e
+--R               + 
+--R                         2             3 2        2 4
+--R                 (- 48A c  - 120B b c)d e  + 96B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2 2 3                   2  3 2           2            4
+--R             - 3A b d e  + (24A b c + 15B b )d e  + (- 24A c  - 60B b c)d e
+--R           + 
+--R                  2 5
+--R             48B c d
+--R        *
+--R            +-+
+--R           \|c
+--R        *
+--R           log
+--R                                   +----------+
+--R                                2  |   2
+--R                  (2b d e - 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                   4 3                   4            3  2
+--R             4B c e x  + ((8A c + 10B b)e  - 16B c d e )x
+--R           + 
+--R                       4                     3          2 2             3
+--R             (- 10A b e  + (36A c + 38B b)d e  - 72B c d e )x - 6A b d e
+--R           + 
+--R                             2 2          3
+--R             (24A c + 24B b)d e  - 48B c d e
+--R        *
+--R            +--------------+     +----------+
+--R            |             2  +-+ |   2
+--R           \|- b d e + c d  \|c \|c x  + b x
+--R    /
+--R                                 +--------------+
+--R          7 2        6      2 5  |             2  +-+
+--R       (8e x  + 16d e x + 8d e )\|- b d e + c d  \|c
+--R     ,
+--R
+--R                             2  4           2              3        2 2 2  2
+--R             ((12A b c + 3B b )e  + (- 24A c  - 36B b c)d e  + 48B c d e )x
+--R           + 
+--R                             2    3           2            2 2        2 3
+--R             ((24A b c + 6B b )d e  + (- 48A c  - 72B b c)d e  + 96B c d e)x
+--R           + 
+--R                            2  2 2           2            3         2 4
+--R             (12A b c + 3B b )d e  + (- 24A c  - 36B b c)d e + 48B c d
+--R        *
+--R            +------------+       +----------+
+--R            |           2        |   2                     +-+
+--R           \|b d e - c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                       2 5                   2    4           2             2 3
+--R                 - 6A b e  + (48A b c + 30B b )d e  + (- 48A c  - 120B b c)d e
+--R               + 
+--R                      2 3 2
+--R                 96B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2   4                   2  2 3
+--R                 - 12A b d e  + (96A b c + 60B b )d e
+--R               + 
+--R                         2             3 2         2 4
+--R                 (- 96A c  - 240B b c)d e  + 192B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2 2 3                   2  3 2           2             4
+--R             - 6A b d e  + (48A b c + 30B b )d e  + (- 48A c  - 120B b c)d e
+--R           + 
+--R                  2 5
+--R             96B c d
+--R        *
+--R                     +------------+ +----------+
+--R                     |           2  |   2
+--R            +-+     \|b d e - c d  \|c x  + b x
+--R           \|c atan(----------------------------)
+--R                            (b e - c d)x
+--R       + 
+--R                   4 3                   4            3  2
+--R             4B c e x  + ((8A c + 10B b)e  - 16B c d e )x
+--R           + 
+--R                       4                     3          2 2             3
+--R             (- 10A b e  + (36A c + 38B b)d e  - 72B c d e )x - 6A b d e
+--R           + 
+--R                             2 2          3
+--R             (24A c + 24B b)d e  - 48B c d e
+--R        *
+--R                +------------+ +----------+
+--R            +-+ |           2  |   2
+--R           \|c \|b d e - c d  \|c x  + b x
+--R    /
+--R                                     +------------+
+--R          7 2        6      2 5  +-+ |           2
+--R       (8e x  + 16d e x + 8d e )\|c \|b d e - c d
+--R     ,
+--R
+--R                       2 5                   2    4           2            2 3
+--R                 - 3A b e  + (24A b c + 15B b )d e  + (- 24A c  - 60B b c)d e
+--R               + 
+--R                      2 3 2
+--R                 48B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2   4                   2  2 3
+--R                 - 6A b d e  + (48A b c + 30B b )d e
+--R               + 
+--R                         2             3 2        2 4
+--R                 (- 48A c  - 120B b c)d e  + 96B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2 2 3                   2  3 2           2            4
+--R             - 3A b d e  + (24A b c + 15B b )d e  + (- 24A c  - 60B b c)d e
+--R           + 
+--R                  2 5
+--R             48B c d
+--R        *
+--R            +---+
+--R           \|- c
+--R        *
+--R           log
+--R                                   +----------+
+--R                                2  |   2
+--R                  (2b d e - 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                             2  4           2              3        2 2 2  2
+--R             ((24A b c + 6B b )e  + (- 48A c  - 72B b c)d e  + 96B c d e )x
+--R           + 
+--R                              2    3           2             2 2         2 3
+--R             ((48A b c + 12B b )d e  + (- 96A c  - 144B b c)d e  + 192B c d e)x
+--R           + 
+--R                            2  2 2           2            3         2 4
+--R             (24A b c + 6B b )d e  + (- 48A c  - 72B b c)d e + 96B c d
+--R        *
+--R                                        +----------+
+--R            +--------------+      +---+ |   2
+--R            |             2      \|- c \|c x  + b x
+--R           \|- b d e + c d  atan(-------------------)
+--R                                         c x
+--R       + 
+--R                   4 3                   4            3  2
+--R             4B c e x  + ((8A c + 10B b)e  - 16B c d e )x
+--R           + 
+--R                       4                     3          2 2             3
+--R             (- 10A b e  + (36A c + 38B b)d e  - 72B c d e )x - 6A b d e
+--R           + 
+--R                             2 2          3
+--R             (24A c + 24B b)d e  - 48B c d e
+--R        *
+--R            +--------------+       +----------+
+--R            |             2  +---+ |   2
+--R           \|- b d e + c d  \|- c \|c x  + b x
+--R    /
+--R                                 +--------------+
+--R          7 2        6      2 5  |             2  +---+
+--R       (8e x  + 16d e x + 8d e )\|- b d e + c d  \|- c
+--R     ,
+--R
+--R                       2 5                   2    4           2            2 3
+--R                 - 3A b e  + (24A b c + 15B b )d e  + (- 24A c  - 60B b c)d e
+--R               + 
+--R                      2 3 2
+--R                 48B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2   4                   2  2 3
+--R                 - 6A b d e  + (48A b c + 30B b )d e
+--R               + 
+--R                         2             3 2        2 4
+--R                 (- 48A c  - 120B b c)d e  + 96B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2 2 3                   2  3 2           2            4
+--R             - 3A b d e  + (24A b c + 15B b )d e  + (- 24A c  - 60B b c)d e
+--R           + 
+--R                  2 5
+--R             48B c d
+--R        *
+--R                       +------------+ +----------+
+--R                       |           2  |   2
+--R            +---+     \|b d e - c d  \|c x  + b x
+--R           \|- c atan(----------------------------)
+--R                              (b e - c d)x
+--R       + 
+--R                             2  4           2              3        2 2 2  2
+--R             ((12A b c + 3B b )e  + (- 24A c  - 36B b c)d e  + 48B c d e )x
+--R           + 
+--R                             2    3           2            2 2        2 3
+--R             ((24A b c + 6B b )d e  + (- 48A c  - 72B b c)d e  + 96B c d e)x
+--R           + 
+--R                            2  2 2           2            3         2 4
+--R             (12A b c + 3B b )d e  + (- 24A c  - 36B b c)d e + 48B c d
+--R        *
+--R                                      +----------+
+--R            +------------+      +---+ |   2
+--R            |           2      \|- c \|c x  + b x
+--R           \|b d e - c d  atan(-------------------)
+--R                                       c x
+--R       + 
+--R                   4 3                  4           3  2
+--R             2B c e x  + ((4A c + 5B b)e  - 8B c d e )x
+--R           + 
+--R                      4                     3          2 2             3
+--R             (- 5A b e  + (18A c + 19B b)d e  - 36B c d e )x - 3A b d e
+--R           + 
+--R                             2 2          3
+--R             (12A c + 12B b)d e  - 24B c d e
+--R        *
+--R                  +------------+ +----------+
+--R            +---+ |           2  |   2
+--R           \|- c \|b d e - c d  \|c x  + b x
+--R    /
+--R                                      +------------+
+--R          7 2       6      2 5  +---+ |           2
+--R       (4e x  + 8d e x + 4d e )\|- c \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 396
+
+--S 397 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         2  2           2                      2 2
+--R         ((12A b c + 3B b )e  + (- 24A c  - 36B b c)d e + 48B c d )
+--R      *
+--R        +--------------+                         +----------+
+--R        |             2  +-----------+ +-+       |   2                     +-+
+--R       \|- b d e + c d  \|- b e + c d \|d log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                   2 3                   2    2           2            2
+--R             - 3A b e  + (24A b c + 15B b )d e  + (- 24A c  - 60B b c)d e
+--R           + 
+--R                  2 3
+--R             48B c d
+--R      *
+--R          +-----------+ +-+ +-+
+--R         \|- b e + c d \|c \|d
+--R      *
+--R         log
+--R                                 +----------+
+--R                              2  |   2
+--R                (2b d e - 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                           2  2         2                      2 2
+--R         ((- 24A b c - 6B b )e  + (48A c  + 72B b c)d e - 96B c d )
+--R      *
+--R          +--------------+                              +-+
+--R          |             2  +-----------+ +-+          x\|c
+--R         \|- b d e + c d  \|- b e + c d \|d atanh(-------------)
+--R                                                   +----------+
+--R                                                   |   2
+--R                                                  \|c x  + b x
+--R     + 
+--R              2 3                     2    2         2            2         2 3
+--R         (3A b e  + (- 24A b c - 15B b )d e  + (24A c  + 60B b c)d e - 48B c d )
+--R      *
+--R          +--------------+
+--R          |             2  +-+             (b e - 2c d)x - b d
+--R         \|- b d e + c d  \|c atanh(--------------------------------)
+--R                                                        +----------+
+--R                                      +-----------+ +-+ |   2
+--R                                    2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R         +--------------+
+--R       5 |             2  +-----------+ +-+ +-+
+--R     8e \|- b d e + c d  \|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         2  2           2                      2 2
+--R         ((12A b c + 3B b )e  + (- 24A c  - 36B b c)d e + 48B c d )
+--R      *
+--R                            +------------+       +----------+
+--R          +-----------+ +-+ |           2        |   2                     +-+
+--R         \|- b e + c d \|d \|b d e - c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                           2  2         2                      2 2
+--R         ((- 24A b c - 6B b )e  + (48A c  + 72B b c)d e - 96B c d )
+--R      *
+--R                            +------------+            +-+
+--R          +-----------+ +-+ |           2           x\|c
+--R         \|- b e + c d \|d \|b d e - c d  atanh(-------------)
+--R                                                 +----------+
+--R                                                 |   2
+--R                                                \|c x  + b x
+--R     + 
+--R              2 3                     2    2         2            2         2 3
+--R         (3A b e  + (- 24A b c - 15B b )d e  + (24A c  + 60B b c)d e - 48B c d )
+--R      *
+--R              +------------+
+--R          +-+ |           2              (b e - 2c d)x - b d
+--R         \|c \|b d e - c d  atanh(--------------------------------)
+--R                                                      +----------+
+--R                                    +-----------+ +-+ |   2
+--R                                  2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                 2 3                   2    2           2             2
+--R           - 6A b e  + (48A b c + 30B b )d e  + (- 48A c  - 120B b c)d e
+--R         + 
+--R                2 3
+--R           96B c d
+--R      *
+--R                                     +------------+ +----------+
+--R                                     |           2  |   2
+--R          +-----------+ +-+ +-+     \|b d e - c d  \|c x  + b x
+--R         \|- b e + c d \|c \|d atan(----------------------------)
+--R                                            (b e - c d)x
+--R  /
+--R                               +------------+
+--R       5 +-----------+ +-+ +-+ |           2
+--R     8e \|- b e + c d \|c \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 399
+
+--S 400 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 400
+
+)clear all
+
+--S 401 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^4
+--R 
+--R
+--R                                         +----------+
+--R              3               2          |   2
+--R        (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  ---------------------------------------------
+--R             4 4       3 3     2 2 2     3       4
+--R            e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 1457
+r0:=-1/4*(B*d*(8*c*d-7*b*e)-A*e*(2*c*d-b*e))*(b*x+c*x^2)^(3/2)/(d*e^2*_
+     (c*d-b*e)*(d+e*x)^2)+1/3*(4*B*d-A*e+3*B*e*x)*(b*x+c*x^2)^(3/2)/_
+     (e^2*(d+e*x)^3)+1/16*(B*d*(64*c^3*d^3-120*b*c^2*d^2*e+60*b^2*c*d*e^2-_
+     5*b^3*e^3)-A*e*(16*c^3*d^3-24*b*c^2*d^2*e+6*b^2*c*d*e^2+b^3*e^3))*_
+     atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+_
+     c*x^2)))/(d^(3/2)*e^5*(c*d-b*e)^(3/2))-(8*B*c*d-3*b*B*e-2*A*c*e)*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))*sqrt(c)/e^5-1/8*(A*e*(8*c^2*d^2-_
+     6*b*c*d*e-b^2*e^2)-B*d*(32*c^2*d^2-36*b*c*d*e+5*b^2*e^2)-_
+     2*c*e*(B*d*(8*c*d-7*b*e)-A*e*(2*c*d-b*e))*x)*sqrt(b*x+c*x^2)/_
+     (d*e^4*(c*d-b*e)*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                             2    5           2             2 4         2 3 3  3
+--R           ((96A b c + 144B b )d e  + (- 96A c  - 528B b c)d e  + 384B c d e )x
+--R         + 
+--R                                 2  2 4            2              3 3
+--R               (288A b c + 432B b )d e  + (- 288A c  - 1584B b c)d e
+--R             + 
+--R                      2 4 2
+--R               1152B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                                 2  3 3            2              4 2
+--R               (288A b c + 432B b )d e  + (- 288A c  - 1584B b c)d e
+--R             + 
+--R                      2 5
+--R               1152B c d e
+--R          *
+--R             x
+--R         + 
+--R                            2  4 2           2             5          2 6
+--R           (96A b c + 144B b )d e  + (- 96A c  - 528B b c)d e + 384B c d
+--R      *
+--R                                           +-+
+--R          +-----------+ +-+ +-+          x\|c
+--R         \|- b e + c d \|c \|d atanh(-------------)
+--R                                      +----------+
+--R                                      |   2
+--R                                     \|c x  + b x
+--R     + 
+--R                     3 7           2         3    6           2         2   2 5
+--R               - 3A b e  + (- 18A b c - 15B b )d e  + (72A b c  + 180B b c)d e
+--R             + 
+--R                       3           2  3 4         3 4 3
+--R               (- 48A c  - 360B b c )d e  + 192B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     3   6           2         3  2 5
+--R               - 9A b d e  + (- 54A b c - 45B b )d e
+--R             + 
+--R                        2         2   3 4            3            2  4 3
+--R               (216A b c  + 540B b c)d e  + (- 144A c  - 1080B b c )d e
+--R             + 
+--R                     3 5 2
+--R               576B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     3 2 5           2         3  3 4
+--R               - 9A b d e  + (- 54A b c - 45B b )d e
+--R             + 
+--R                        2         2   4 3            3            2  5 2
+--R               (216A b c  + 540B b c)d e  + (- 144A c  - 1080B b c )d e
+--R             + 
+--R                     3 6
+--R               576B c d e
+--R          *
+--R             x
+--R         + 
+--R                 3 3 4           2         3  4 3           2         2   5 2
+--R           - 3A b d e  + (- 18A b c - 15B b )d e  + (72A b c  + 180B b c)d e
+--R         + 
+--R                   3           2  6          3 7
+--R           (- 48A c  - 360B b c )d e + 192B c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                       5        2 2 4  3
+--R           (48B b c d e  - 48B c d e )x
+--R         + 
+--R                   2 6                     2    5         2             2 4
+--R               6A b e  + (- 88A b c - 66B b )d e  + (88A c  + 412B b c)d e
+--R             + 
+--R                       2 3 3
+--R               - 352B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      2   5                     2  2 4
+--R               - 16A b d e  + (- 92A b c - 80B b )d e
+--R             + 
+--R                      2             3 3         2 4 2
+--R               (120A c  + 548B b c)d e  - 480B c d e
+--R          *
+--R             x
+--R         + 
+--R                 2 2 4                     2  3 3         2             4 2
+--R           - 6A b d e  + (- 36A b c - 30B b )d e  + (48A c  + 216B b c)d e
+--R         + 
+--R                   2 5
+--R           - 192B c d e
+--R      *
+--R                            +----------+
+--R          +-----------+ +-+ |   2
+--R         \|- b e + c d \|d \|c x  + b x
+--R  /
+--R                 9        2 8  3          2 8         3 7  2
+--R         (48b d e  - 48c d e )x  + (144b d e  - 144c d e )x
+--R       + 
+--R                3 7         4 6          4 6        5 5
+--R         (144b d e  - 144c d e )x + 48b d e  - 48c d e
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 402
+
+--S 403 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                   2    5           2             2 4
+--R                   (48A b c + 72B b )d e  + (- 48A c  - 264B b c)d e
+--R                 + 
+--R                         2 3 3
+--R                   192B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                                   2  2 4            2             3 3
+--R                 (144A b c + 216B b )d e  + (- 144A c  - 792B b c)d e
+--R               + 
+--R                       2 4 2
+--R                 576B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                                   2  3 3            2             4 2
+--R                 (144A b c + 216B b )d e  + (- 144A c  - 792B b c)d e
+--R               + 
+--R                       2 5
+--R                 576B c d e
+--R            *
+--R               x
+--R           + 
+--R                             2  4 2           2             5          2 6
+--R             (48A b c + 72B b )d e  + (- 48A c  - 264B b c)d e + 192B c d
+--R        *
+--R            +--------------+              +----------+
+--R            |             2  +-+      +-+ |   2
+--R           \|- b d e + c d  \|c log(2\|c \|c x  + b x  + 2c x + b)
+--R       + 
+--R                     3 7         2         3    6             2         2   2 5
+--R                 3A b e  + (18A b c + 15B b )d e  + (- 72A b c  - 180B b c)d e
+--R               + 
+--R                       3           2  3 4         3 4 3
+--R                 (48A c  + 360B b c )d e  - 192B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     3   6         2         3  2 5
+--R                 9A b d e  + (54A b c + 45B b )d e
+--R               + 
+--R                            2         2   3 4          3            2  4 3
+--R                 (- 216A b c  - 540B b c)d e  + (144A c  + 1080B b c )d e
+--R               + 
+--R                         3 5 2
+--R                 - 576B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     3 2 5         2         3  3 4
+--R                 9A b d e  + (54A b c + 45B b )d e
+--R               + 
+--R                            2         2   4 3          3            2  5 2
+--R                 (- 216A b c  - 540B b c)d e  + (144A c  + 1080B b c )d e
+--R               + 
+--R                         3 6
+--R                 - 576B c d e
+--R            *
+--R               x
+--R           + 
+--R                 3 3 4         2         3  4 3             2         2   5 2
+--R             3A b d e  + (18A b c + 15B b )d e  + (- 72A b c  - 180B b c)d e
+--R           + 
+--R                   3           2  6          3 7
+--R             (48A c  + 360B b c )d e - 192B c d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                         5        2 2 4  3
+--R             (48B b c d e  - 48B c d e )x
+--R           + 
+--R                     2 6                     2    5         2             2 4
+--R                 6A b e  + (- 88A b c - 66B b )d e  + (88A c  + 412B b c)d e
+--R               + 
+--R                         2 3 3
+--R                 - 352B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2   5                     2  2 4
+--R                 - 16A b d e  + (- 92A b c - 80B b )d e
+--R               + 
+--R                        2             3 3         2 4 2
+--R                 (120A c  + 548B b c)d e  - 480B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2 2 4                     2  3 3         2             4 2
+--R             - 6A b d e  + (- 36A b c - 30B b )d e  + (48A c  + 216B b c)d e
+--R           + 
+--R                     2 5
+--R             - 192B c d e
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R                   9        2 8  3          2 8         3 7  2
+--R           (48b d e  - 48c d e )x  + (144b d e  - 144c d e )x
+--R         + 
+--R                  3 7         4 6          4 6        5 5
+--R           (144b d e  - 144c d e )x + 48b d e  - 48c d e
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                              2    5           2             2 4        2 3 3  3
+--R             ((24A b c + 36B b )d e  + (- 24A c  - 132B b c)d e  + 96B c d e )x
+--R           + 
+--R                                    2  2 4           2             3 3
+--R                   (72A b c + 108B b )d e  + (- 72A c  - 396B b c)d e
+--R                 + 
+--R                         2 4 2
+--R                   288B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                               2  3 3           2             4 2         2 5
+--R             ((72A b c + 108B b )d e  + (- 72A c  - 396B b c)d e  + 288B c d e)x
+--R           + 
+--R                             2  4 2           2             5         2 6
+--R             (24A b c + 36B b )d e  + (- 24A c  - 132B b c)d e + 96B c d
+--R        *
+--R                +------------+          +----------+
+--R            +-+ |           2       +-+ |   2
+--R           \|c \|b d e - c d  log(2\|c \|c x  + b x  + 2c x + b)
+--R       + 
+--R                       3 7           2         3    6
+--R                 - 3A b e  + (- 18A b c - 15B b )d e
+--R               + 
+--R                         2         2   2 5           3           2  3 4
+--R                 (72A b c  + 180B b c)d e  + (- 48A c  - 360B b c )d e
+--R               + 
+--R                       3 4 3
+--R                 192B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       3   6           2         3  2 5
+--R                 - 9A b d e  + (- 54A b c - 45B b )d e
+--R               + 
+--R                          2         2   3 4            3            2  4 3
+--R                 (216A b c  + 540B b c)d e  + (- 144A c  - 1080B b c )d e
+--R               + 
+--R                       3 5 2
+--R                 576B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       3 2 5           2         3  3 4
+--R                 - 9A b d e  + (- 54A b c - 45B b )d e
+--R               + 
+--R                          2         2   4 3            3            2  5 2
+--R                 (216A b c  + 540B b c)d e  + (- 144A c  - 1080B b c )d e
+--R               + 
+--R                       3 6
+--R                 576B c d e
+--R            *
+--R               x
+--R           + 
+--R                   3 3 4           2         3  4 3           2         2   5 2
+--R             - 3A b d e  + (- 18A b c - 15B b )d e  + (72A b c  + 180B b c)d e
+--R           + 
+--R                     3           2  6          3 7
+--R             (- 48A c  - 360B b c )d e + 192B c d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                         5        2 2 4  3
+--R             (24B b c d e  - 24B c d e )x
+--R           + 
+--R                     2 6                     2    5         2             2 4
+--R                 3A b e  + (- 44A b c - 33B b )d e  + (44A c  + 206B b c)d e
+--R               + 
+--R                         2 3 3
+--R                 - 176B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2   5                     2  2 4
+--R                 - 8A b d e  + (- 46A b c - 40B b )d e
+--R               + 
+--R                       2             3 3         2 4 2
+--R                 (60A c  + 274B b c)d e  - 240B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2 2 4                     2  3 3         2             4 2
+--R             - 3A b d e  + (- 18A b c - 15B b )d e  + (24A c  + 108B b c)d e
+--R           + 
+--R                    2 5
+--R             - 96B c d e
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R                   9        2 8  3         2 8        3 7  2
+--R           (24b d e  - 24c d e )x  + (72b d e  - 72c d e )x
+--R         + 
+--R                 3 7        4 6          4 6        5 5
+--R           (72b d e  - 72c d e )x + 24b d e  - 24c d e
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ,
+--R
+--R                     3 7         2         3    6             2         2   2 5
+--R                 3A b e  + (18A b c + 15B b )d e  + (- 72A b c  - 180B b c)d e
+--R               + 
+--R                       3           2  3 4         3 4 3
+--R                 (48A c  + 360B b c )d e  - 192B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     3   6         2         3  2 5
+--R                 9A b d e  + (54A b c + 45B b )d e
+--R               + 
+--R                            2         2   3 4          3            2  4 3
+--R                 (- 216A b c  - 540B b c)d e  + (144A c  + 1080B b c )d e
+--R               + 
+--R                         3 5 2
+--R                 - 576B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     3 2 5         2         3  3 4
+--R                 9A b d e  + (54A b c + 45B b )d e
+--R               + 
+--R                            2         2   4 3          3            2  5 2
+--R                 (- 216A b c  - 540B b c)d e  + (144A c  + 1080B b c )d e
+--R               + 
+--R                         3 6
+--R                 - 576B c d e
+--R            *
+--R               x
+--R           + 
+--R                 3 3 4         2         3  4 3             2         2   5 2
+--R             3A b d e  + (18A b c + 15B b )d e  + (- 72A b c  - 180B b c)d e
+--R           + 
+--R                   3           2  6          3 7
+--R             (48A c  + 360B b c )d e - 192B c d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                                    2    5           2             2 4
+--R                   (96A b c + 144B b )d e  + (- 96A c  - 528B b c)d e
+--R                 + 
+--R                         2 3 3
+--R                   384B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                                   2  2 4            2              3 3
+--R                 (288A b c + 432B b )d e  + (- 288A c  - 1584B b c)d e
+--R               + 
+--R                        2 4 2
+--R                 1152B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                                   2  3 3            2              4 2
+--R                 (288A b c + 432B b )d e  + (- 288A c  - 1584B b c)d e
+--R               + 
+--R                        2 5
+--R                 1152B c d e
+--R            *
+--R               x
+--R           + 
+--R                              2  4 2           2             5          2 6
+--R             (96A b c + 144B b )d e  + (- 96A c  - 528B b c)d e + 384B c d
+--R        *
+--R                                        +----------+
+--R            +--------------+            |   2
+--R            |             2  +---+     \|c x  + b x
+--R           \|- b d e + c d  \|- c atan(-------------)
+--R                                            +---+
+--R                                          x\|- c
+--R       + 
+--R                         5        2 2 4  3
+--R             (48B b c d e  - 48B c d e )x
+--R           + 
+--R                     2 6                     2    5         2             2 4
+--R                 6A b e  + (- 88A b c - 66B b )d e  + (88A c  + 412B b c)d e
+--R               + 
+--R                         2 3 3
+--R                 - 352B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2   5                     2  2 4
+--R                 - 16A b d e  + (- 92A b c - 80B b )d e
+--R               + 
+--R                        2             3 3         2 4 2
+--R                 (120A c  + 548B b c)d e  - 480B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2 2 4                     2  3 3         2             4 2
+--R             - 6A b d e  + (- 36A b c - 30B b )d e  + (48A c  + 216B b c)d e
+--R           + 
+--R                     2 5
+--R             - 192B c d e
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R                   9        2 8  3          2 8         3 7  2
+--R           (48b d e  - 48c d e )x  + (144b d e  - 144c d e )x
+--R         + 
+--R                  3 7         4 6          4 6        5 5
+--R           (144b d e  - 144c d e )x + 48b d e  - 48c d e
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                       3 7           2         3    6
+--R                 - 3A b e  + (- 18A b c - 15B b )d e
+--R               + 
+--R                         2         2   2 5           3           2  3 4
+--R                 (72A b c  + 180B b c)d e  + (- 48A c  - 360B b c )d e
+--R               + 
+--R                       3 4 3
+--R                 192B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       3   6           2         3  2 5
+--R                 - 9A b d e  + (- 54A b c - 45B b )d e
+--R               + 
+--R                          2         2   3 4            3            2  4 3
+--R                 (216A b c  + 540B b c)d e  + (- 144A c  - 1080B b c )d e
+--R               + 
+--R                       3 5 2
+--R                 576B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       3 2 5           2         3  3 4
+--R                 - 9A b d e  + (- 54A b c - 45B b )d e
+--R               + 
+--R                          2         2   4 3            3            2  5 2
+--R                 (216A b c  + 540B b c)d e  + (- 144A c  - 1080B b c )d e
+--R               + 
+--R                       3 6
+--R                 576B c d e
+--R            *
+--R               x
+--R           + 
+--R                   3 3 4           2         3  4 3           2         2   5 2
+--R             - 3A b d e  + (- 18A b c - 15B b )d e  + (72A b c  + 180B b c)d e
+--R           + 
+--R                     3           2  6          3 7
+--R             (- 48A c  - 360B b c )d e + 192B c d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                                   2    5           2             2 4
+--R                   (48A b c + 72B b )d e  + (- 48A c  - 264B b c)d e
+--R                 + 
+--R                         2 3 3
+--R                   192B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                                   2  2 4            2             3 3
+--R                 (144A b c + 216B b )d e  + (- 144A c  - 792B b c)d e
+--R               + 
+--R                       2 4 2
+--R                 576B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                                   2  3 3            2             4 2
+--R                 (144A b c + 216B b )d e  + (- 144A c  - 792B b c)d e
+--R               + 
+--R                       2 5
+--R                 576B c d e
+--R            *
+--R               x
+--R           + 
+--R                             2  4 2           2             5          2 6
+--R             (48A b c + 72B b )d e  + (- 48A c  - 264B b c)d e + 192B c d
+--R        *
+--R                                      +----------+
+--R                  +------------+      |   2
+--R            +---+ |           2      \|c x  + b x
+--R           \|- c \|b d e - c d  atan(-------------)
+--R                                          +---+
+--R                                        x\|- c
+--R       + 
+--R                         5        2 2 4  3
+--R             (24B b c d e  - 24B c d e )x
+--R           + 
+--R                     2 6                     2    5         2             2 4
+--R                 3A b e  + (- 44A b c - 33B b )d e  + (44A c  + 206B b c)d e
+--R               + 
+--R                         2 3 3
+--R                 - 176B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2   5                     2  2 4
+--R                 - 8A b d e  + (- 46A b c - 40B b )d e
+--R               + 
+--R                       2             3 3         2 4 2
+--R                 (60A c  + 274B b c)d e  - 240B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2 2 4                     2  3 3         2             4 2
+--R             - 3A b d e  + (- 18A b c - 15B b )d e  + (24A c  + 108B b c)d e
+--R           + 
+--R                    2 5
+--R             - 96B c d e
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R                   9        2 8  3         2 8        3 7  2
+--R           (24b d e  - 24c d e )x  + (72b d e  - 72c d e )x
+--R         + 
+--R                 3 7        4 6          4 6        5 5
+--R           (72b d e  - 72c d e )x + 24b d e  - 24c d e
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 403
+
+--S 404 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          2    2           2            2         2 3
+--R         ((16A b c + 24B b )d e  + (- 16A c  - 88B b c)d e + 64B c d )
+--R      *
+--R        +--------------+                                +----------+
+--R        |             2  +-----------+ +-+ +-+      +-+ |   2
+--R       \|- b d e + c d  \|- b e + c d \|c \|d log(2\|c \|c x  + b x  + 2c x + b)
+--R     + 
+--R              3 4        2        3    3             2        2   2 2
+--R           A b e  + (6A b c + 5B b )d e  + (- 24A b c  - 60B b c)d e
+--R         + 
+--R                 3           2  3         3 4
+--R           (16A c  + 120B b c )d e - 64B c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                            2    2         2             2          2 3
+--R         ((- 32A b c - 48B b )d e  + (32A c  + 176B b c)d e - 128B c d )
+--R      *
+--R          +--------------+                                  +-+
+--R          |             2  +-----------+ +-+ +-+          x\|c
+--R         \|- b d e + c d  \|- b e + c d \|c \|d atanh(-------------)
+--R                                                       +----------+
+--R                                                       |   2
+--R                                                      \|c x  + b x
+--R     + 
+--R              3 4        2        3    3             2        2   2 2
+--R           A b e  + (6A b c + 5B b )d e  + (- 24A b c  - 60B b c)d e
+--R         + 
+--R                 3           2  3         3 4
+--R           (16A c  + 120B b c )d e - 64B c d
+--R      *
+--R          +--------------+
+--R          |             2              (b e - 2c d)x - b d
+--R         \|- b d e + c d  atanh(--------------------------------)
+--R                                                    +----------+
+--R                                  +-----------+ +-+ |   2
+--R                                2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                           +--------------+
+--R             6        2 5  |             2  +-----------+ +-+
+--R     (16b d e  - 16c d e )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+--S 406 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          2    2           2            2         2 3
+--R         ((16A b c + 24B b )d e  + (- 16A c  - 88B b c)d e + 64B c d )
+--R      *
+--R                              +------------+          +----------+
+--R        +-----------+ +-+ +-+ |           2       +-+ |   2
+--R       \|- b e + c d \|c \|d \|b d e - c d  log(2\|c \|c x  + b x  + 2c x + b)
+--R     + 
+--R                            2    2         2             2          2 3
+--R         ((- 32A b c - 48B b )d e  + (32A c  + 176B b c)d e - 128B c d )
+--R      *
+--R                                +------------+            +-+
+--R          +-----------+ +-+ +-+ |           2           x\|c
+--R         \|- b e + c d \|c \|d \|b d e - c d  atanh(-------------)
+--R                                                     +----------+
+--R                                                     |   2
+--R                                                    \|c x  + b x
+--R     + 
+--R              3 4        2        3    3             2        2   2 2
+--R           A b e  + (6A b c + 5B b )d e  + (- 24A b c  - 60B b c)d e
+--R         + 
+--R                 3           2  3         3 4
+--R           (16A c  + 120B b c )d e - 64B c d
+--R      *
+--R          +------------+
+--R          |           2              (b e - 2c d)x - b d
+--R         \|b d e - c d  atanh(--------------------------------)
+--R                                                  +----------+
+--R                                +-----------+ +-+ |   2
+--R                              2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                 3 4           2         3    3           2         2   2 2
+--R           - 2A b e  + (- 12A b c - 10B b )d e  + (48A b c  + 120B b c)d e
+--R         + 
+--R                   3           2  3          3 4
+--R           (- 32A c  - 240B b c )d e + 128B c d
+--R      *
+--R                                 +------------+ +----------+
+--R                                 |           2  |   2
+--R          +-----------+ +-+     \|b d e - c d  \|c x  + b x
+--R         \|- b e + c d \|d atan(----------------------------)
+--R                                        (b e - c d)x
+--R  /
+--R                                             +------------+
+--R             6        2 5  +-----------+ +-+ |           2
+--R     (16b d e  - 16c d e )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 407
+
+)clear all
+
+--S 408 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^5
+--R 
+--R
+--R                                            +----------+
+--R                 3               2          |   2
+--R           (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                                    Type: Expression(Integer)
+--E 408
+
+--S 409 of 1457
+r0:=1/32*(3*A*b^2*e^3+B*d*(16*c^2*d^2-24*b*c*d*e+5*b^2*e^2))*_
+     (b*x+c*x^2)^(3/2)/(d^2*e^2*(c*d-b*e)^2*(d+e*x)^2)+1/24*(3*A*b*e^2-_
+     B*d*(8*c*d-5*b*e)-6*c*e*(B*d-A*e)*x)*(b*x+c*x^2)^(3/2)/(d*e^2*_
+     (c*d-b*e)*(d+e*x)^3)+1/4*(B*d-A*e)*(b*x+c*x^2)^(5/2)/(d*(c*d-b*e)*_
+     (d+e*x)^4)+2*B*c^(3/2)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/e^5+_
+     1/128*(3*A*b^4*e^5-B*d*(128*c^4*d^4-320*b*c^3*d^3*e+240*b^2*c^2*_
+     d^2*e^2-40*b^3*c*d*e^3-5*b^4*e^4))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(5/2)*e^5*_
+     (c*d-b*e)^(5/2))-1/64*(3*A*b^3*e^4+B*d*(64*c^3*d^3-112*b*c^2*_
+     d^2*e+40*b^2*c*d*e^2+5*b^3*e^3)+2*c*e*(3*A*b^2*e^3+B*d*(16*c^2*_
+     d^2-24*b*c*d*e+5*b^2*e^2))*x)*sqrt(b*x+c*x^2)/(d^2*e^4*_
+     (c*d-b*e)^2*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                  2   2 6            2 3 5         3 4 4  4
+--R           (768B b c d e  - 1536B b c d e  + 768B c d e )x
+--R         + 
+--R                   2   3 5            2 4 4          3 5 3  3
+--R           (3072B b c d e  - 6144B b c d e  + 3072B c d e )x
+--R         + 
+--R                   2   4 4            2 5 3          3 6 2  2
+--R           (4608B b c d e  - 9216B b c d e  + 4608B c d e )x
+--R         + 
+--R                   2   5 3            2 6 2          3 7            2   6 2
+--R           (3072B b c d e  - 6144B b c d e  + 3072B c d e)x + 768B b c d e
+--R         + 
+--R                      2 7          3 8
+--R           - 1536B b c d e + 768B c d
+--R      *
+--R                                           +-+
+--R          +-----------+ +-+ +-+          x\|c
+--R         \|- b e + c d \|c \|d atanh(-------------)
+--R                                      +----------+
+--R                                      |   2
+--R                                     \|c x  + b x
+--R     + 
+--R                     4 9        4   8         3   2 7         2 2 3 6
+--R               - 9A b e  - 15B b d e  - 120B b c d e  + 720B b c d e
+--R             + 
+--R                         3 4 5         4 5 4
+--R               - 960B b c d e  + 384B c d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      4   8        4 2 7         3   3 6          2 2 4 5
+--R               - 36A b d e  - 60B b d e  - 480B b c d e  + 2880B b c d e
+--R             + 
+--R                          3 5 4          4 6 3
+--R               - 3840B b c d e  + 1536B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      4 2 7        4 3 6         3   4 5          2 2 5 4
+--R               - 54A b d e  - 90B b d e  - 720B b c d e  + 4320B b c d e
+--R             + 
+--R                          3 6 3          4 7 2
+--R               - 5760B b c d e  + 2304B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      4 3 6        4 4 5         3   5 4          2 2 6 3
+--R               - 36A b d e  - 60B b d e  - 480B b c d e  + 2880B b c d e
+--R             + 
+--R                          3 7 2          4 8
+--R               - 3840B b c d e  + 1536B c d e
+--R          *
+--R             x
+--R         + 
+--R                 4 4 5        4 5 4         3   6 3         2 2 7 2
+--R           - 9A b d e  - 15B b d e  - 120B b c d e  + 720B b c d e
+--R         + 
+--R                     3 8          4 9
+--R           - 960B b c d e + 384B c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                    3 8         2         3    7              2         2   2 6
+--R               18A b e  + (12A b c + 30B b )d e  + (- 144A b c  - 764B b c)d e
+--R             + 
+--R                     3            2  3 5         3 4 4
+--R               (96A c  + 1552B b c )d e  - 800B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    3   7            2          3  2 6
+--R               66A b d e  + (- 264A b c - 146B b )d e
+--R             + 
+--R                        2          2   3 5            2 4 4          3 5 3
+--R               (144A b c  - 1096B b c)d e  + 2960B b c d e  - 1664B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3 2 6         2          3  3 5         2   4 4
+--R               - 66A b d e  + (12A b c - 110B b )d e  - 860B b c d e
+--R             + 
+--R                        2 5 3          3 6 2
+--R               2368B b c d e  - 1344B c d e
+--R          *
+--R             x
+--R         + 
+--R                3 3 5        3 4 4         2   5 3           2 6 2         3 7
+--R         - 18A b d e  - 30B b d e  - 240B b c d e  + 672B b c d e  - 384B c d e
+--R      *
+--R                            +----------+
+--R          +-----------+ +-+ |   2
+--R         \|- b e + c d \|d \|c x  + b x
+--R  /
+--R              2 2 11           3 10       2 4 9  4
+--R         (384b d e   - 768b c d e   + 384c d e )x
+--R       + 
+--R               2 3 10            4 9        2 5 8  3
+--R         (1536b d e   - 3072b c d e  + 1536c d e )x
+--R       + 
+--R               2 4 9            5 8        2 6 7  2
+--R         (2304b d e  - 4608b c d e  + 2304c d e )x
+--R       + 
+--R               2 5 8            6 7        2 7 6         2 6 7           7 6
+--R         (1536b d e  - 3072b c d e  + 1536c d e )x + 384b d e  - 768b c d e
+--R       + 
+--R             2 8 5
+--R         384c d e
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2   2 6           2 3 5         3 4 4  4
+--R             (384B b c d e  - 768B b c d e  + 384B c d e )x
+--R           + 
+--R                     2   3 5            2 4 4          3 5 3  3
+--R             (1536B b c d e  - 3072B b c d e  + 1536B c d e )x
+--R           + 
+--R                     2   4 4            2 5 3          3 6 2  2
+--R             (2304B b c d e  - 4608B b c d e  + 2304B c d e )x
+--R           + 
+--R                     2   5 3            2 6 2          3 7            2   6 2
+--R             (1536B b c d e  - 3072B b c d e  + 1536B c d e)x + 384B b c d e
+--R           + 
+--R                       2 7          3 8
+--R             - 768B b c d e + 384B c d
+--R        *
+--R            +--------------+              +----------+
+--R            |             2  +-+      +-+ |   2
+--R           \|- b d e + c d  \|c log(2\|c \|c x  + b x  + 2c x + b)
+--R       + 
+--R                     4 9        4   8         3   2 7         2 2 3 6
+--R                 9A b e  + 15B b d e  + 120B b c d e  - 720B b c d e
+--R               + 
+--R                         3 4 5         4 5 4
+--R                 960B b c d e  - 384B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      4   8        4 2 7         3   3 6          2 2 4 5
+--R                 36A b d e  + 60B b d e  + 480B b c d e  - 2880B b c d e
+--R               + 
+--R                          3 5 4          4 6 3
+--R                 3840B b c d e  - 1536B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4 2 7        4 3 6         3   4 5          2 2 5 4
+--R                 54A b d e  + 90B b d e  + 720B b c d e  - 4320B b c d e
+--R               + 
+--R                          3 6 3          4 7 2
+--R                 5760B b c d e  - 2304B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      4 3 6        4 4 5         3   5 4          2 2 6 3
+--R                 36A b d e  + 60B b d e  + 480B b c d e  - 2880B b c d e
+--R               + 
+--R                          3 7 2          4 8
+--R                 3840B b c d e  - 1536B c d e
+--R            *
+--R               x
+--R           + 
+--R                 4 4 5        4 5 4         3   6 3         2 2 7 2
+--R             9A b d e  + 15B b d e  + 120B b c d e  - 720B b c d e
+--R           + 
+--R                     3 8          4 9
+--R             960B b c d e - 384B c d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                      3 8         2         3    7
+--R                 18A b e  + (12A b c + 30B b )d e
+--R               + 
+--R                            2         2   2 6         3            2  3 5
+--R                 (- 144A b c  - 764B b c)d e  + (96A c  + 1552B b c )d e
+--R               + 
+--R                         3 4 4
+--R                 - 800B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      3   7            2          3  2 6
+--R                 66A b d e  + (- 264A b c - 146B b )d e
+--R               + 
+--R                          2          2   3 5            2 4 4          3 5 3
+--R                 (144A b c  - 1096B b c)d e  + 2960B b c d e  - 1664B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 6         2          3  3 5         2   4 4
+--R                 - 66A b d e  + (12A b c - 110B b )d e  - 860B b c d e
+--R               + 
+--R                          2 5 3          3 6 2
+--R                 2368B b c d e  - 1344B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 5        3 4 4         2   5 3           2 6 2
+--R             - 18A b d e  - 30B b d e  - 240B b c d e  + 672B b c d e
+--R           + 
+--R                     3 7
+--R             - 384B c d e
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R                2 2 11           3 10       2 4 9  4
+--R           (384b d e   - 768b c d e   + 384c d e )x
+--R         + 
+--R                 2 3 10            4 9        2 5 8  3
+--R           (1536b d e   - 3072b c d e  + 1536c d e )x
+--R         + 
+--R                 2 4 9            5 8        2 6 7  2
+--R           (2304b d e  - 4608b c d e  + 2304c d e )x
+--R         + 
+--R                 2 5 8            6 7        2 7 6         2 6 7           7 6
+--R           (1536b d e  - 3072b c d e  + 1536c d e )x + 384b d e  - 768b c d e
+--R         + 
+--R               2 8 5
+--R           384c d e
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                    2   2 6           2 3 5         3 4 4  4
+--R             (192B b c d e  - 384B b c d e  + 192B c d e )x
+--R           + 
+--R                    2   3 5            2 4 4         3 5 3  3
+--R             (768B b c d e  - 1536B b c d e  + 768B c d e )x
+--R           + 
+--R                     2   4 4            2 5 3          3 6 2  2
+--R             (1152B b c d e  - 2304B b c d e  + 1152B c d e )x
+--R           + 
+--R                    2   5 3            2 6 2         3 7            2   6 2
+--R             (768B b c d e  - 1536B b c d e  + 768B c d e)x + 192B b c d e
+--R           + 
+--R                       2 7          3 8
+--R             - 384B b c d e + 192B c d
+--R        *
+--R                +------------+          +----------+
+--R            +-+ |           2       +-+ |   2
+--R           \|c \|b d e - c d  log(2\|c \|c x  + b x  + 2c x + b)
+--R       + 
+--R                       4 9        4   8         3   2 7         2 2 3 6
+--R                 - 9A b e  - 15B b d e  - 120B b c d e  + 720B b c d e
+--R               + 
+--R                           3 4 5         4 5 4
+--R                 - 960B b c d e  + 384B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        4   8        4 2 7         3   3 6          2 2 4 5
+--R                 - 36A b d e  - 60B b d e  - 480B b c d e  + 2880B b c d e
+--R               + 
+--R                            3 5 4          4 6 3
+--R                 - 3840B b c d e  + 1536B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4 2 7        4 3 6         3   4 5          2 2 5 4
+--R                 - 54A b d e  - 90B b d e  - 720B b c d e  + 4320B b c d e
+--R               + 
+--R                            3 6 3          4 7 2
+--R                 - 5760B b c d e  + 2304B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4 3 6        4 4 5         3   5 4          2 2 6 3
+--R                 - 36A b d e  - 60B b d e  - 480B b c d e  + 2880B b c d e
+--R               + 
+--R                            3 7 2          4 8
+--R                 - 3840B b c d e  + 1536B c d e
+--R            *
+--R               x
+--R           + 
+--R                   4 4 5        4 5 4         3   6 3         2 2 7 2
+--R             - 9A b d e  - 15B b d e  - 120B b c d e  + 720B b c d e
+--R           + 
+--R                       3 8          4 9
+--R             - 960B b c d e + 384B c d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                     3 8        2         3    7             2         2   2 6
+--R                 9A b e  + (6A b c + 15B b )d e  + (- 72A b c  - 382B b c)d e
+--R               + 
+--R                       3           2  3 5         3 4 4
+--R                 (48A c  + 776B b c )d e  - 400B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      3   7            2         3  2 6
+--R                 33A b d e  + (- 132A b c - 73B b )d e
+--R               + 
+--R                         2         2   3 5            2 4 4         3 5 3
+--R                 (72A b c  - 548B b c)d e  + 1480B b c d e  - 832B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 6        2         3  3 5         2   4 4
+--R                 - 33A b d e  + (6A b c - 55B b )d e  - 430B b c d e
+--R               + 
+--R                          2 5 3         3 6 2
+--R                 1184B b c d e  - 672B c d e
+--R            *
+--R               x
+--R           + 
+--R                 3 3 5        3 4 4         2   5 3           2 6 2         3 7
+--R           - 9A b d e  - 15B b d e  - 120B b c d e  + 336B b c d e  - 192B c d e
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R                2 2 11           3 10       2 4 9  4
+--R           (192b d e   - 384b c d e   + 192c d e )x
+--R         + 
+--R                2 3 10            4 9       2 5 8  3
+--R           (768b d e   - 1536b c d e  + 768c d e )x
+--R         + 
+--R                 2 4 9            5 8        2 6 7  2
+--R           (1152b d e  - 2304b c d e  + 1152c d e )x
+--R         + 
+--R                2 5 8            6 7       2 7 6         2 6 7           7 6
+--R           (768b d e  - 1536b c d e  + 768c d e )x + 192b d e  - 384b c d e
+--R         + 
+--R               2 8 5
+--R           192c d e
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ,
+--R
+--R                     4 9        4   8         3   2 7         2 2 3 6
+--R                 9A b e  + 15B b d e  + 120B b c d e  - 720B b c d e
+--R               + 
+--R                         3 4 5         4 5 4
+--R                 960B b c d e  - 384B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      4   8        4 2 7         3   3 6          2 2 4 5
+--R                 36A b d e  + 60B b d e  + 480B b c d e  - 2880B b c d e
+--R               + 
+--R                          3 5 4          4 6 3
+--R                 3840B b c d e  - 1536B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4 2 7        4 3 6         3   4 5          2 2 5 4
+--R                 54A b d e  + 90B b d e  + 720B b c d e  - 4320B b c d e
+--R               + 
+--R                          3 6 3          4 7 2
+--R                 5760B b c d e  - 2304B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      4 3 6        4 4 5         3   5 4          2 2 6 3
+--R                 36A b d e  + 60B b d e  + 480B b c d e  - 2880B b c d e
+--R               + 
+--R                          3 7 2          4 8
+--R                 3840B b c d e  - 1536B c d e
+--R            *
+--R               x
+--R           + 
+--R                 4 4 5        4 5 4         3   6 3         2 2 7 2
+--R             9A b d e  + 15B b d e  + 120B b c d e  - 720B b c d e
+--R           + 
+--R                     3 8          4 9
+--R             960B b c d e - 384B c d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                    2   2 6            2 3 5         3 4 4  4
+--R             (768B b c d e  - 1536B b c d e  + 768B c d e )x
+--R           + 
+--R                     2   3 5            2 4 4          3 5 3  3
+--R             (3072B b c d e  - 6144B b c d e  + 3072B c d e )x
+--R           + 
+--R                     2   4 4            2 5 3          3 6 2  2
+--R             (4608B b c d e  - 9216B b c d e  + 4608B c d e )x
+--R           + 
+--R                     2   5 3            2 6 2          3 7            2   6 2
+--R             (3072B b c d e  - 6144B b c d e  + 3072B c d e)x + 768B b c d e
+--R           + 
+--R                        2 7          3 8
+--R             - 1536B b c d e + 768B c d
+--R        *
+--R                                        +----------+
+--R            +--------------+            |   2
+--R            |             2  +---+     \|c x  + b x
+--R           \|- b d e + c d  \|- c atan(-------------)
+--R                                            +---+
+--R                                          x\|- c
+--R       + 
+--R                      3 8         2         3    7
+--R                 18A b e  + (12A b c + 30B b )d e
+--R               + 
+--R                            2         2   2 6         3            2  3 5
+--R                 (- 144A b c  - 764B b c)d e  + (96A c  + 1552B b c )d e
+--R               + 
+--R                         3 4 4
+--R                 - 800B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      3   7            2          3  2 6
+--R                 66A b d e  + (- 264A b c - 146B b )d e
+--R               + 
+--R                          2          2   3 5            2 4 4          3 5 3
+--R                 (144A b c  - 1096B b c)d e  + 2960B b c d e  - 1664B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 6         2          3  3 5         2   4 4
+--R                 - 66A b d e  + (12A b c - 110B b )d e  - 860B b c d e
+--R               + 
+--R                          2 5 3          3 6 2
+--R                 2368B b c d e  - 1344B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 5        3 4 4         2   5 3           2 6 2
+--R             - 18A b d e  - 30B b d e  - 240B b c d e  + 672B b c d e
+--R           + 
+--R                     3 7
+--R             - 384B c d e
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R                2 2 11           3 10       2 4 9  4
+--R           (384b d e   - 768b c d e   + 384c d e )x
+--R         + 
+--R                 2 3 10            4 9        2 5 8  3
+--R           (1536b d e   - 3072b c d e  + 1536c d e )x
+--R         + 
+--R                 2 4 9            5 8        2 6 7  2
+--R           (2304b d e  - 4608b c d e  + 2304c d e )x
+--R         + 
+--R                 2 5 8            6 7        2 7 6         2 6 7           7 6
+--R           (1536b d e  - 3072b c d e  + 1536c d e )x + 384b d e  - 768b c d e
+--R         + 
+--R               2 8 5
+--R           384c d e
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                       4 9        4   8         3   2 7         2 2 3 6
+--R                 - 9A b e  - 15B b d e  - 120B b c d e  + 720B b c d e
+--R               + 
+--R                           3 4 5         4 5 4
+--R                 - 960B b c d e  + 384B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        4   8        4 2 7         3   3 6          2 2 4 5
+--R                 - 36A b d e  - 60B b d e  - 480B b c d e  + 2880B b c d e
+--R               + 
+--R                            3 5 4          4 6 3
+--R                 - 3840B b c d e  + 1536B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4 2 7        4 3 6         3   4 5          2 2 5 4
+--R                 - 54A b d e  - 90B b d e  - 720B b c d e  + 4320B b c d e
+--R               + 
+--R                            3 6 3          4 7 2
+--R                 - 5760B b c d e  + 2304B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4 3 6        4 4 5         3   5 4          2 2 6 3
+--R                 - 36A b d e  - 60B b d e  - 480B b c d e  + 2880B b c d e
+--R               + 
+--R                            3 7 2          4 8
+--R                 - 3840B b c d e  + 1536B c d e
+--R            *
+--R               x
+--R           + 
+--R                   4 4 5        4 5 4         3   6 3         2 2 7 2
+--R             - 9A b d e  - 15B b d e  - 120B b c d e  + 720B b c d e
+--R           + 
+--R                       3 8          4 9
+--R             - 960B b c d e + 384B c d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                    2   2 6           2 3 5         3 4 4  4
+--R             (384B b c d e  - 768B b c d e  + 384B c d e )x
+--R           + 
+--R                     2   3 5            2 4 4          3 5 3  3
+--R             (1536B b c d e  - 3072B b c d e  + 1536B c d e )x
+--R           + 
+--R                     2   4 4            2 5 3          3 6 2  2
+--R             (2304B b c d e  - 4608B b c d e  + 2304B c d e )x
+--R           + 
+--R                     2   5 3            2 6 2          3 7            2   6 2
+--R             (1536B b c d e  - 3072B b c d e  + 1536B c d e)x + 384B b c d e
+--R           + 
+--R                       2 7          3 8
+--R             - 768B b c d e + 384B c d
+--R        *
+--R                                      +----------+
+--R                  +------------+      |   2
+--R            +---+ |           2      \|c x  + b x
+--R           \|- c \|b d e - c d  atan(-------------)
+--R                                          +---+
+--R                                        x\|- c
+--R       + 
+--R                     3 8        2         3    7             2         2   2 6
+--R                 9A b e  + (6A b c + 15B b )d e  + (- 72A b c  - 382B b c)d e
+--R               + 
+--R                       3           2  3 5         3 4 4
+--R                 (48A c  + 776B b c )d e  - 400B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      3   7            2         3  2 6
+--R                 33A b d e  + (- 132A b c - 73B b )d e
+--R               + 
+--R                         2         2   3 5            2 4 4         3 5 3
+--R                 (72A b c  - 548B b c)d e  + 1480B b c d e  - 832B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 6        2         3  3 5         2   4 4
+--R                 - 33A b d e  + (6A b c - 55B b )d e  - 430B b c d e
+--R               + 
+--R                          2 5 3         3 6 2
+--R                 1184B b c d e  - 672B c d e
+--R            *
+--R               x
+--R           + 
+--R                 3 3 5        3 4 4         2   5 3           2 6 2         3 7
+--R           - 9A b d e  - 15B b d e  - 120B b c d e  + 336B b c d e  - 192B c d e
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R                2 2 11           3 10       2 4 9  4
+--R           (192b d e   - 384b c d e   + 192c d e )x
+--R         + 
+--R                2 3 10            4 9       2 5 8  3
+--R           (768b d e   - 1536b c d e  + 768c d e )x
+--R         + 
+--R                 2 4 9            5 8        2 6 7  2
+--R           (1152b d e  - 2304b c d e  + 1152c d e )x
+--R         + 
+--R                2 5 8            6 7       2 7 6         2 6 7           7 6
+--R           (768b d e  - 1536b c d e  + 768c d e )x + 192b d e  - 384b c d e
+--R         + 
+--R               2 8 5
+--R           192c d e
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 410
+
+--S 411 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                    +--------------+
+--R                2   2 2           2 3          3 4  |             2
+--R         (128B b c d e  - 256B b c d e + 128B c d )\|- b d e + c d
+--R      *
+--R                                         +----------+
+--R          +-----------+ +-+ +-+      +-+ |   2
+--R         \|- b e + c d \|c \|d log(2\|c \|c x  + b x  + 2c x + b)
+--R     + 
+--R               4 5       4   4        3   2 3         2 2 3 2           3 4
+--R           3A b e  + 5B b d e  + 40B b c d e  - 240B b c d e  + 320B b c d e
+--R         + 
+--R                   4 5
+--R           - 128B c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                                                      +--------------+
+--R                  2   2 2           2 3          3 4  |             2
+--R         (- 256B b c d e  + 512B b c d e - 256B c d )\|- b d e + c d
+--R      *
+--R                                           +-+
+--R          +-----------+ +-+ +-+          x\|c
+--R         \|- b e + c d \|c \|d atanh(-------------)
+--R                                      +----------+
+--R                                      |   2
+--R                                     \|c x  + b x
+--R     + 
+--R               4 5       4   4        3   2 3         2 2 3 2           3 4
+--R           3A b e  + 5B b d e  + 40B b c d e  - 240B b c d e  + 320B b c d e
+--R         + 
+--R                   4 5
+--R           - 128B c d
+--R      *
+--R          +--------------+
+--R          |             2              (b e - 2c d)x - b d
+--R         \|- b d e + c d  atanh(--------------------------------)
+--R                                                    +----------+
+--R                                  +-----------+ +-+ |   2
+--R                                2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                                           +--------------+
+--R          2 2 7           3 6       2 4 5  |             2  +-----------+ +-+
+--R     (128b d e  - 256b c d e  + 128c d e )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                2   2 2           2 3          3 4  +-----------+ +-+ +-+
+--R         (128B b c d e  - 256B b c d e + 128B c d )\|- b e + c d \|c \|d
+--R      *
+--R          +------------+          +----------+
+--R          |           2       +-+ |   2
+--R         \|b d e - c d  log(2\|c \|c x  + b x  + 2c x + b)
+--R     + 
+--R                  2   2 2           2 3          3 4  +-----------+ +-+ +-+
+--R         (- 256B b c d e  + 512B b c d e - 256B c d )\|- b e + c d \|c \|d
+--R      *
+--R          +------------+            +-+
+--R          |           2           x\|c
+--R         \|b d e - c d  atanh(-------------)
+--R                               +----------+
+--R                               |   2
+--R                              \|c x  + b x
+--R     + 
+--R               4 5       4   4        3   2 3         2 2 3 2           3 4
+--R           3A b e  + 5B b d e  + 40B b c d e  - 240B b c d e  + 320B b c d e
+--R         + 
+--R                   4 5
+--R           - 128B c d
+--R      *
+--R          +------------+
+--R          |           2              (b e - 2c d)x - b d
+--R         \|b d e - c d  atanh(--------------------------------)
+--R                                                  +----------+
+--R                                +-----------+ +-+ |   2
+--R                              2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                 4 5        4   4        3   2 3         2 2 3 2           3 4
+--R           - 6A b e  - 10B b d e  - 80B b c d e  + 480B b c d e  - 640B b c d e
+--R         + 
+--R                 4 5
+--R           256B c d
+--R      *
+--R                                 +------------+ +----------+
+--R                                 |           2  |   2
+--R          +-----------+ +-+     \|b d e - c d  \|c x  + b x
+--R         \|- b e + c d \|d atan(----------------------------)
+--R                                        (b e - c d)x
+--R  /
+--R                                                             +------------+
+--R          2 2 7           3 6       2 4 5  +-----------+ +-+ |           2
+--R     (128b d e  - 256b c d e  + 128c d e )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^6
+--R 
+--R
+--R                                                 +----------+
+--R                      3               2          |   2
+--R                (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 1457
+r0:=-1/5*(4*B*d+A*e+5*B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*(d+e*x)^5)-_
+     3/256*b^4*(b*B*d-2*A*c*d+A*b*e)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(7/2)*(c*d-b*e)^(7/2))+_
+     1/80*(A*e*(4*c^2*d^2-4*b*c*d*e-b^2*e^2)+B*d*(16*c^2*d^2-26*b*c*d*e+_
+     11*b^2*e^2))*sqrt(b*x+c*x^2)/(d*e^4*(c*d-b*e)*(d+e*x)^3)+1/320*_
+     (A*e*(16*c^3*d^3-24*b*c^2*d^2*e-2*b^2*c*d*e^2+5*b^3*e^3)+B*d*_
+     (64*c^3*d^3-136*b*c^2*d^2*e+72*b^2*c*d*e^2+5*b^3*e^3))*_
+     sqrt(b*x+c*x^2)/(d^2*e^4*(c*d-b*e)^2*(d+e*x)^2)+1/640*(B*d*_
+     (128*c^4*d^4-336*b*c^3*d^3*e+248*b^2*c^2*d^2*e^2-10*b^3*c*d*e^3-_
+     15*b^4*e^4)+A*e*(32*c^4*d^4-64*b*c^3*d^3*e+12*b^2*c^2*d^2*e^2+_
+     20*b^3*c*d*e^3-15*b^4*e^4))*sqrt(b*x+c*x^2)/(d^3*e^4*(c*d-b*e)^3*_
+     (d+e*x))-3/40*(B*d*(8*c*d-b*e)+A*e*(2*c*d+b*e)+2*e*(8*B*c*d-_
+     5*b*B*e+2*A*c*e)*x)*sqrt(b*x+c*x^2)/(e^4*(d+e*x)^4)
+--R 
+--R
+--R   (2)
+--R                   5 6         4         5    5  5
+--R           (- 15A b e  + (30A b c - 15B b )d e )x
+--R         + 
+--R                   5   5          4         5  2 4  4
+--R           (- 75A b d e  + (150A b c - 75B b )d e )x
+--R         + 
+--R                    5 2 4          4          5  3 3  3
+--R           (- 150A b d e  + (300A b c - 150B b )d e )x
+--R         + 
+--R                    5 3 3          4          5  4 2  2
+--R           (- 150A b d e  + (300A b c - 150B b )d e )x
+--R         + 
+--R                   5 4 2          4         5  5           5 5
+--R           (- 75A b d e  + (150A b c - 75B b )d e)x - 15A b d e
+--R         + 
+--R                 4         5  6
+--R           (30A b c - 15B b )d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                    4 5           3         4    4           2 2        3   2 3
+--R               30A b e  + (- 40A b c + 30B b )d e  + (- 24A b c  + 20B b c)d e
+--R             + 
+--R                      3         2 2  3 2           4           3  4          4 5
+--R             (128A b c  - 496B b c )d e  + (- 64A c  + 672B b c )d e - 256B c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     4   4            3          4  2 3
+--R               140A b d e  + (- 188A b c + 140B b )d e
+--R             + 
+--R                        2 2         3   3 2            3          2 2  4
+--R               (- 184A b c  - 932B b c)d e  + (672A b c  + 1024B b c )d e
+--R             + 
+--R                        4           3  5
+--R               (- 320A c  - 352B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     4 2 3            3          4  3 2
+--R               256A b d e  + (- 932A b c - 256B b )d e
+--R             + 
+--R                       2 2        3   4               3        2 2  5
+--R               (1336A b c  + 92B b c)d e + (- 480A b c  - 16B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    4 3 2          3          4  4            2 2        3   5
+--R           (- 140A b d e  + (300A b c - 140B b )d e + (- 40A b c  + 20B b c)d )x
+--R         + 
+--R                  4 4          3         4  5
+--R           - 30A b d e + (60A b c - 30B b )d
+--R      *
+--R                            +----------+
+--R          +-----------+ +-+ |   2
+--R         \|- b e + c d \|d \|c x  + b x
+--R  /
+--R               3 3 8        2   4 7          2 5 6        3 6 5  5
+--R         (1280b d e  - 3840b c d e  + 3840b c d e  - 1280c d e )x
+--R       + 
+--R               3 4 7         2   5 6           2 6 5        3 7 4  4
+--R         (6400b d e  - 19200b c d e  + 19200b c d e  - 6400c d e )x
+--R       + 
+--R                3 5 6         2   6 5           2 7 4         3 8 3  3
+--R         (12800b d e  - 38400b c d e  + 38400b c d e  - 12800c d e )x
+--R       + 
+--R                3 6 5         2   7 4           2 8 3         3 9 2  2
+--R         (12800b d e  - 38400b c d e  + 38400b c d e  - 12800c d e )x
+--R       + 
+--R               3 7 4         2   8 3           2 9 2        3 10           3 8 3
+--R         (6400b d e  - 19200b c d e  + 19200b c d e  - 6400c d  e)x + 1280b d e
+--R       + 
+--R                2   9 2          2 10         3 11
+--R         - 3840b c d e  + 3840b c d  e - 1280c d
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   5 6           4         5    5  5
+--R             (15A b e  + (- 30A b c + 15B b )d e )x
+--R           + 
+--R                   5   5            4         5  2 4  4
+--R             (75A b d e  + (- 150A b c + 75B b )d e )x
+--R           + 
+--R                    5 2 4            4          5  3 3  3
+--R             (150A b d e  + (- 300A b c + 150B b )d e )x
+--R           + 
+--R                    5 3 3            4          5  4 2  2
+--R             (150A b d e  + (- 300A b c + 150B b )d e )x
+--R           + 
+--R                   5 4 2            4         5  5           5 5
+--R             (75A b d e  + (- 150A b c + 75B b )d e)x + 15A b d e
+--R           + 
+--R                     4         5  6
+--R             (- 30A b c + 15B b )d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                      4 5           3         4    4
+--R                 30A b e  + (- 40A b c + 30B b )d e
+--R               + 
+--R                         2 2        3   2 3            3         2 2  3 2
+--R                 (- 24A b c  + 20B b c)d e  + (128A b c  - 496B b c )d e
+--R               + 
+--R                         4           3  4          4 5
+--R                 (- 64A c  + 672B b c )d e - 256B c d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       4   4            3          4  2 3
+--R                 140A b d e  + (- 188A b c + 140B b )d e
+--R               + 
+--R                          2 2         3   3 2            3          2 2  4
+--R                 (- 184A b c  - 932B b c)d e  + (672A b c  + 1024B b c )d e
+--R               + 
+--R                          4           3  5
+--R                 (- 320A c  - 352B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4 2 3            3          4  3 2
+--R                 256A b d e  + (- 932A b c - 256B b )d e
+--R               + 
+--R                         2 2        3   4               3        2 2  5
+--R                 (1336A b c  + 92B b c)d e + (- 480A b c  - 16B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         4 3 2          3          4  4
+--R                 - 140A b d e  + (300A b c - 140B b )d e
+--R               + 
+--R                         2 2        3   5
+--R                 (- 40A b c  + 20B b c)d
+--R            *
+--R               x
+--R           + 
+--R                    4 4          3         4  5
+--R             - 30A b d e + (60A b c - 30B b )d
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R                 3 3 8        2   4 7          2 5 6        3 6 5  5
+--R           (1280b d e  - 3840b c d e  + 3840b c d e  - 1280c d e )x
+--R         + 
+--R                 3 4 7         2   5 6           2 6 5        3 7 4  4
+--R           (6400b d e  - 19200b c d e  + 19200b c d e  - 6400c d e )x
+--R         + 
+--R                  3 5 6         2   6 5           2 7 4         3 8 3  3
+--R           (12800b d e  - 38400b c d e  + 38400b c d e  - 12800c d e )x
+--R         + 
+--R                  3 6 5         2   7 4           2 8 3         3 9 2  2
+--R           (12800b d e  - 38400b c d e  + 38400b c d e  - 12800c d e )x
+--R         + 
+--R                 3 7 4         2   8 3           2 9 2        3 10
+--R           (6400b d e  - 19200b c d e  + 19200b c d e  - 6400c d  e)x
+--R         + 
+--R                3 8 3        2   9 2          2 10         3 11
+--R           1280b d e  - 3840b c d e  + 3840b c d  e - 1280c d
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                     5 6         4         5    5  5
+--R             (- 15A b e  + (30A b c - 15B b )d e )x
+--R           + 
+--R                     5   5          4         5  2 4  4
+--R             (- 75A b d e  + (150A b c - 75B b )d e )x
+--R           + 
+--R                      5 2 4          4          5  3 3  3
+--R             (- 150A b d e  + (300A b c - 150B b )d e )x
+--R           + 
+--R                      5 3 3          4          5  4 2  2
+--R             (- 150A b d e  + (300A b c - 150B b )d e )x
+--R           + 
+--R                     5 4 2          4         5  5           5 5
+--R             (- 75A b d e  + (150A b c - 75B b )d e)x - 15A b d e
+--R           + 
+--R                   4         5  6
+--R             (30A b c - 15B b )d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                      4 5           3         4    4
+--R                 15A b e  + (- 20A b c + 15B b )d e
+--R               + 
+--R                         2 2        3   2 3           3         2 2  3 2
+--R                 (- 12A b c  + 10B b c)d e  + (64A b c  - 248B b c )d e
+--R               + 
+--R                         4           3  4          4 5
+--R                 (- 32A c  + 336B b c )d e - 128B c d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      4   4           3         4  2 3
+--R                 70A b d e  + (- 94A b c + 70B b )d e
+--R               + 
+--R                         2 2         3   3 2            3         2 2  4
+--R                 (- 92A b c  - 466B b c)d e  + (336A b c  + 512B b c )d e
+--R               + 
+--R                          4           3  5
+--R                 (- 160A c  - 176B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4 2 3            3          4  3 2
+--R                 128A b d e  + (- 466A b c - 128B b )d e
+--R               + 
+--R                        2 2        3   4               3       2 2  5
+--R                 (668A b c  + 46B b c)d e + (- 240A b c  - 8B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4 3 2          3         4  4            2 2        3   5
+--R             (- 70A b d e  + (150A b c - 70B b )d e + (- 20A b c  + 10B b c)d )x
+--R           + 
+--R                    4 4          3         4  5
+--R             - 15A b d e + (30A b c - 15B b )d
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R                3 3 8        2   4 7          2 5 6       3 6 5  5
+--R           (640b d e  - 1920b c d e  + 1920b c d e  - 640c d e )x
+--R         + 
+--R                 3 4 7        2   5 6          2 6 5        3 7 4  4
+--R           (3200b d e  - 9600b c d e  + 9600b c d e  - 3200c d e )x
+--R         + 
+--R                 3 5 6         2   6 5           2 7 4        3 8 3  3
+--R           (6400b d e  - 19200b c d e  + 19200b c d e  - 6400c d e )x
+--R         + 
+--R                 3 6 5         2   7 4           2 8 3        3 9 2  2
+--R           (6400b d e  - 19200b c d e  + 19200b c d e  - 6400c d e )x
+--R         + 
+--R                 3 7 4        2   8 3          2 9 2        3 10          3 8 3
+--R           (3200b d e  - 9600b c d e  + 9600b c d e  - 3200c d  e)x + 640b d e
+--R         + 
+--R                  2   9 2          2 10        3 11
+--R           - 1920b c d e  + 1920b c d  e - 640c d
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 417
+
+--S 418 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              5           4        5    +-----------+ +-+
+--R         (3A b e + (- 6A b c + 3B b )d)\|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                                        +--------------+
+--R              5           4        5    |             2
+--R         (3A b e + (- 6A b c + 3B b )d)\|- b d e + c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                                                        +--------------+
+--R            3 3 3       2   4 2         2 5        3 6  |             2
+--R       (256b d e  - 768b c d e  + 768b c d e - 256c d )\|- b d e + c d
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                        +------------+
+--R              5           4        5    |           2
+--R         (3A b e + (- 6A b c + 3B b )d)\|b d e - c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                5          4        5    +-----------+ +-+
+--R         (- 6A b e + (12A b c - 6B b )d)\|- b e + c d \|d
+--R      *
+--R               +------------+ +----------+
+--R               |           2  |   2
+--R              \|b d e - c d  \|c x  + b x
+--R         atan(----------------------------)
+--R                      (b e - c d)x
+--R  /
+--R            3 3 3       2   4 2         2 5        3 6  +-----------+ +-+
+--R       (256b d e  - 768b c d e  + 768b c d e - 256c d )\|- b e + c d \|d
+--R    *
+--R        +------------+
+--R        |           2
+--R       \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 420
+
+--S 421 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 421
+
+)clear all
+
+--S 422 of 1457
+t0:=(A+B*x)*(d+e*x)^2*(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R   (1)
+--R          2 2 7        2           2       2     6
+--R       B c e x  + ((A c  + 2B b c)e  + 2B c d e)x
+--R     + 
+--R                     2  2        2                   2 2  5
+--R       ((2A b c + B b )e  + (2A c  + 4B b c)d e + B c d )x
+--R     + 
+--R           2 2                 2           2           2  4
+--R       (A b e  + (4A b c + 2B b )d e + (A c  + 2B b c)d )x
+--R     + 
+--R            2                   2  2  3      2 2 2
+--R       (2A b d e + (2A b c + B b )d )x  + A b d x
+--R  *
+--R      +----------+
+--R      |   2
+--R     \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 1457
+r0:=1/768*b*(64*A*c^3*d^2-11*b^3*B*e^2+18*b^2*c*e*(2*B*d+A*e)-32*b*c^2*d*_
+     (B*d+2*A*e))*x^2*(b*x+c*x^2)^(3/2)/c^3+1/384*(64*A*c^3*d^2-11*b^3*_
+     B*e^2+18*b^2*c*e*(2*B*d+A*e)-32*b*c^2*d*(B*d+2*A*e))*x*(b*x+_
+     c*x^2)^(5/2)/c^3+1/2016*(162*A*c*e*(2*c*d-b*e)+B*(64*c^2*d^2-_
+     226*b*c*d*e+99*b^2*e^2))*(b*x+c*x^2)^(7/2)/c^3+1/9*B*(d+e*x)^2*_
+     (b*x+c*x^2)^(7/2)/c-1/144*e*((7*b*B-18*A*c)*d-(4*B*c*d-11*b*B*e+_
+     18*A*c*e)*x)*(b*x+c*x^2)^(7/2)/c^2-5/32768*b^6*(64*A*c^3*d^2-_
+     11*b^3*B*e^2+18*b^2*c*e*(2*B*d+A*e)-32*b*c^2*d*(B*d+2*A*e))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(13/2)+5/32768*b^5*(64*A*c^3*_
+     d^2-11*b^3*B*e^2+18*b^2*c*e*(2*B*d+A*e)-32*b*c^2*d*(B*d+2*A*e))*_
+     sqrt(b*x+c*x^2)/c^6-5/49152*b^4*(64*A*c^3*d^2-11*b^3*B*e^2+18*b^2*_
+     c*e*(2*B*d+A*e)-32*b*c^2*d*(B*d+2*A*e))*x*sqrt(b*x+c*x^2)/c^5+_
+     1/12288*b^3*(64*A*c^3*d^2-11*b^3*B*e^2+18*b^2*c*e*(2*B*d+A*e)-_
+     32*b*c^2*d*(B*d+2*A*e))*x^2*sqrt(b*x+c*x^2)/c^4+1/2048*b^2*_
+     (64*A*c^3*d^2-11*b^3*B*e^2+18*b^2*c*e*(2*B*d+A*e)-32*b*c^2*d*_
+     (B*d+2*A*e))*x^3*sqrt(b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                     8           9  2            7 2           8
+--R           (- 5670A b c + 3465B b )e  + (20160A b c  - 11340B b c)d e
+--R         + 
+--R                      6 3           7 2  2
+--R           (- 20160A b c  + 10080B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                    8 2 8              8              7  2            8     7
+--R           229376B c e x  + ((258048A c  + 530432B b c )e  + 516096B c d e)x
+--R         + 
+--R                           7            2 6  2             8               7
+--R               (608256A b c  + 316416B b c )e  + (589824A c  + 1216512B b c )d e
+--R             + 
+--R                        8 2
+--R               294912B c d
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         2 6          3 5  2                7            2 6
+--R               (373248A b c  + 1280B b c )e  + (1425408A b c  + 746496B b c )d e
+--R             + 
+--R                         8              7  2
+--R               (344064A c  + 712704B b c )d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                       3 5          4 4  2             2 6          3 5
+--R               (2304A b c  - 1408B b c )e  + (909312A b c  + 4608B b c )d e
+--R             + 
+--R                           7            2 6  2
+--R               (860160A b c  + 454656B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                         4 4          5 3  2           3 5          4 4
+--R               (- 2592A b c  + 1584B b c )e  + (9216A b c  - 5184B b c )d e
+--R             + 
+--R                         2 6          3 5  2
+--R               (580608A b c  + 4608B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       5 3          6 2  2              4 4          5 3
+--R               (3024A b c  - 1848B b c )e  + (- 10752A b c  + 6048B b c )d e
+--R             + 
+--R                        3 5          4 4  2
+--R               (10752A b c  - 5376B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                         6 2          7   2            5 3          6 2
+--R               (- 3780A b c  + 2310B b c)e  + (13440A b c  - 7560B b c )d e
+--R             + 
+--R                          4 4          5 3  2
+--R               (- 13440A b c  + 6720B b c )d
+--R          *
+--R             x
+--R         + 
+--R                   7           8  2              6 2           7
+--R           (5670A b c - 3465B b )e  + (- 20160A b c  + 11340B b c)d e
+--R         + 
+--R                    5 3           6 2  2
+--R           (20160A b c  - 10080B b c )d
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R             6 +-+
+--R     2064384c \|c
+--R                                                    Type: Expression(Integer)
+--E 423
+
+--S 424 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       8           9  2            7 2           8
+--R             (- 5670A b c + 3465B b )e  + (20160A b c  - 11340B b c)d e
+--R           + 
+--R                        6 3           7 2  2
+--R             (- 20160A b c  + 10080B b c )d
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                      8 2 8
+--R             458752B c e x
+--R           + 
+--R                        8               7  2             8     7
+--R             ((516096A c  + 1060864B b c )e  + 1032192B c d e)x
+--R           + 
+--R                              7            2 6  2
+--R                 (1216512A b c  + 632832B b c )e
+--R               + 
+--R                            8               7                8 2
+--R                 (1179648A c  + 2433024B b c )d e + 589824B c d
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                           2 6          3 5  2
+--R                 (746496A b c  + 2560B b c )e
+--R               + 
+--R                              7             2 6
+--R                 (2850816A b c  + 1492992B b c )d e
+--R               + 
+--R                           8               7  2
+--R                 (688128A c  + 1425408B b c )d
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                         3 5          4 4  2              2 6          3 5
+--R                 (4608A b c  - 2816B b c )e  + (1818624A b c  + 9216B b c )d e
+--R               + 
+--R                              7            2 6  2
+--R                 (1720320A b c  + 909312B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           4 4          5 3  2            3 5           4 4
+--R                 (- 5184A b c  + 3168B b c )e  + (18432A b c  - 10368B b c )d e
+--R               + 
+--R                            2 6          3 5  2
+--R                 (1161216A b c  + 9216B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         5 3          6 2  2              4 4           5 3
+--R                 (6048A b c  - 3696B b c )e  + (- 21504A b c  + 12096B b c )d e
+--R               + 
+--R                          3 5           4 4  2
+--R                 (21504A b c  - 10752B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           6 2          7   2            5 3           6 2
+--R                 (- 7560A b c  + 4620B b c)e  + (26880A b c  - 15120B b c )d e
+--R               + 
+--R                            4 4           5 3  2
+--R                 (- 26880A b c  + 13440B b c )d
+--R            *
+--R               x
+--R           + 
+--R                      7           8  2              6 2           7
+--R             (11340A b c - 6930B b )e  + (- 40320A b c  + 22680B b c)d e
+--R           + 
+--R                      5 3           6 2  2
+--R             (40320A b c  - 20160B b c )d
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R               6 +-+
+--R       4128768c \|c
+--R     ,
+--R
+--R                       8           9  2            7 2           8
+--R             (- 5670A b c + 3465B b )e  + (20160A b c  - 11340B b c)d e
+--R           + 
+--R                        6 3           7 2  2
+--R             (- 20160A b c  + 10080B b c )d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                      8 2 8              8              7  2            8     7
+--R             229376B c e x  + ((258048A c  + 530432B b c )e  + 516096B c d e)x
+--R           + 
+--R                             7            2 6  2
+--R                 (608256A b c  + 316416B b c )e
+--R               + 
+--R                           8               7                8 2
+--R                 (589824A c  + 1216512B b c )d e + 294912B c d
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                           2 6          3 5  2
+--R                 (373248A b c  + 1280B b c )e
+--R               + 
+--R                            7            2 6                 8              7  2
+--R               (1425408A b c  + 746496B b c )d e + (344064A c  + 712704B b c )d
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                         3 5          4 4  2             2 6          3 5
+--R                 (2304A b c  - 1408B b c )e  + (909312A b c  + 4608B b c )d e
+--R               + 
+--R                             7            2 6  2
+--R                 (860160A b c  + 454656B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           4 4          5 3  2           3 5          4 4
+--R                 (- 2592A b c  + 1584B b c )e  + (9216A b c  - 5184B b c )d e
+--R               + 
+--R                           2 6          3 5  2
+--R                 (580608A b c  + 4608B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         5 3          6 2  2              4 4          5 3
+--R                 (3024A b c  - 1848B b c )e  + (- 10752A b c  + 6048B b c )d e
+--R               + 
+--R                          3 5          4 4  2
+--R                 (10752A b c  - 5376B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                           6 2          7   2            5 3          6 2
+--R                 (- 3780A b c  + 2310B b c)e  + (13440A b c  - 7560B b c )d e
+--R               + 
+--R                            4 4          5 3  2
+--R                 (- 13440A b c  + 6720B b c )d
+--R            *
+--R               x
+--R           + 
+--R                     7           8  2              6 2           7
+--R             (5670A b c - 3465B b )e  + (- 20160A b c  + 11340B b c)d e
+--R           + 
+--R                      5 3           6 2  2
+--R             (20160A b c  - 10080B b c )d
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R               6 +---+
+--R       2064384c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 424
+
+--S 425 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                   8         9  2          7 2         8
+--R           (- 90A b c + 55B b )e  + (320A b c  - 180B b c)d e
+--R         + 
+--R                    6 3         7 2  2
+--R           (- 320A b c  + 160B b c )d
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                  8          9  2            7 2         8
+--R           (180A b c - 110B b )e  + (- 640A b c  + 360B b c)d e
+--R         + 
+--R                  6 3         7 2  2
+--R           (640A b c  - 320B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R  /
+--R           6 +-+
+--R     65536c \|c
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 8         9  2            7 2         8
+--R           (90A b c - 55B b )e  + (- 320A b c  + 180B b c)d e
+--R         + 
+--R                  6 3         7 2  2
+--R           (320A b c  - 160B b c )d
+--R      *
+--R                           +-+
+--R          +---+          x\|c
+--R         \|- c atanh(-------------)
+--R                      +----------+
+--R                      |   2
+--R                     \|c x  + b x
+--R     + 
+--R                   8         9  2          7 2         8
+--R           (- 90A b c + 55B b )e  + (320A b c  - 180B b c)d e
+--R         + 
+--R                    6 3         7 2  2
+--R           (- 320A b c  + 160B b c )d
+--R      *
+--R                         +----------+
+--R                   +---+ |   2
+--R          +-+     \|- c \|c x  + b x
+--R         \|c atan(-------------------)
+--R                          c x
+--R  /
+--R           6 +---+ +-+
+--R     32768c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 428
+
+)clear all
+
+--S 429 of 1457
+t0:=(A+B*x)*(d+e*x)*(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R   (1)
+--R          2   6        2                 2   5
+--R       B c e x  + ((A c  + 2B b c)e + B c d)x
+--R     + 
+--R                     2         2             4       2                 2    3
+--R       ((2A b c + B b )e + (A c  + 2B b c)d)x  + (A b e + (2A b c + B b )d)x
+--R     + 
+--R          2   2
+--R       A b d x
+--R  *
+--R      +----------+
+--R      |   2
+--R     \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 429
+
+--S 430 of 1457
+r0:=1/384*b*(32*A*c^2*d+9*b^2*B*e-16*b*c*(B*d+A*e))*x^2*_
+     (b*x+c*x^2)^(3/2)/c^2+1/192*(32*A*c^2*d+9*b^2*B*e-16*b*c*(B*d+A*e))*_
+     x*(b*x+c*x^2)^(5/2)/c^2+1/112*(2*B*c*d-9*b*B*e+16*A*c*e)*_
+     (b*x+c*x^2)^(7/2)/c^2+1/8*B*(d+e*x)*(b*x+c*x^2)^(7/2)/c-_
+     5/16384*b^6*(32*A*c^2*d+9*b^2*B*e-16*b*c*(B*d+A*e))*atanh(x*_
+     sqrt(c)/sqrt(b*x+c*x^2))/c^(11/2)+5/16384*b^5*(32*A*c^2*d+9*b^2*B*e-_
+     16*b*c*(B*d+A*e))*sqrt(b*x+c*x^2)/c^5-5/24576*b^4*(32*A*c^2*d+_
+     9*b^2*B*e-16*b*c*(B*d+A*e))*x*sqrt(b*x+c*x^2)/c^4+1/6144*b^3*_
+     (32*A*c^2*d+9*b^2*B*e-16*b*c*(B*d+A*e))*x^2*sqrt(b*x+c*x^2)/c^3+_
+     1/1024*b^2*(32*A*c^2*d+9*b^2*B*e-16*b*c*(B*d+A*e))*x^3*_
+     sqrt(b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R                  7          8               6 2          7
+--R         ((1680A b c - 945B b )e + (- 3360A b c  + 1680B b c)d)
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                   7   7             7              6             7   6
+--R           43008B c e x  + ((49152A c  + 101376B b c )e + 49152B c d)x
+--R         + 
+--R                        6           2 5              7              6    5
+--R           ((118784A b c  + 62208B b c )e + (57344A c  + 118784B b c )d)x
+--R         + 
+--R                     2 5         3 4                 6           2 5    4
+--R           ((75776A b c  + 384B b c )e + (143360A b c  + 75776B b c )d)x
+--R         + 
+--R                   3 4         4 3              2 5         3 4    3
+--R           ((768A b c  - 432B b c )e + (96768A b c  + 768B b c )d)x
+--R         + 
+--R                     4 3         5 2             3 4         4 3    2
+--R           ((- 896A b c  + 504B b c )e + (1792A b c  - 896B b c )d)x
+--R         + 
+--R                    5 2         6                4 3          5 2
+--R           ((1120A b c  - 630B b c)e + (- 2240A b c  + 1120B b c )d)x
+--R         + 
+--R                     6          7             5 2          6
+--R           (- 1680A b c + 945B b )e + (3360A b c  - 1680B b c)d
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R            5 +-+
+--R     344064c \|c
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    7          8               6 2          7
+--R           ((1680A b c - 945B b )e + (- 3360A b c  + 1680B b c)d)
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                     7   7             7              6             7   6
+--R             86016B c e x  + ((98304A c  + 202752B b c )e + 98304B c d)x
+--R           + 
+--R                          6            2 5               7              6    5
+--R             ((237568A b c  + 124416B b c )e + (114688A c  + 237568B b c )d)x
+--R           + 
+--R                        2 5         3 4                 6            2 5    4
+--R             ((151552A b c  + 768B b c )e + (286720A b c  + 151552B b c )d)x
+--R           + 
+--R                      3 4         4 3               2 5          3 4    3
+--R             ((1536A b c  - 864B b c )e + (193536A b c  + 1536B b c )d)x
+--R           + 
+--R                        4 3          5 2             3 4          4 3    2
+--R             ((- 1792A b c  + 1008B b c )e + (3584A b c  - 1792B b c )d)x
+--R           + 
+--R                      5 2          6                4 3          5 2
+--R             ((2240A b c  - 1260B b c)e + (- 4480A b c  + 2240B b c )d)x
+--R           + 
+--R                       6           7             5 2          6
+--R             (- 3360A b c + 1890B b )e + (6720A b c  - 3360B b c)d
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R              5 +-+
+--R       688128c \|c
+--R     ,
+--R
+--R                    7          8               6 2          7
+--R           ((1680A b c - 945B b )e + (- 3360A b c  + 1680B b c)d)
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                     7   7             7              6             7   6
+--R             43008B c e x  + ((49152A c  + 101376B b c )e + 49152B c d)x
+--R           + 
+--R                          6           2 5              7              6    5
+--R             ((118784A b c  + 62208B b c )e + (57344A c  + 118784B b c )d)x
+--R           + 
+--R                       2 5         3 4                 6           2 5    4
+--R             ((75776A b c  + 384B b c )e + (143360A b c  + 75776B b c )d)x
+--R           + 
+--R                     3 4         4 3              2 5         3 4    3
+--R             ((768A b c  - 432B b c )e + (96768A b c  + 768B b c )d)x
+--R           + 
+--R                       4 3         5 2             3 4         4 3    2
+--R             ((- 896A b c  + 504B b c )e + (1792A b c  - 896B b c )d)x
+--R           + 
+--R                      5 2         6                4 3          5 2
+--R             ((1120A b c  - 630B b c)e + (- 2240A b c  + 1120B b c )d)x
+--R           + 
+--R                       6          7             5 2          6
+--R             (- 1680A b c + 945B b )e + (3360A b c  - 1680B b c)d
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R              5 +---+
+--R       344064c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 431
+
+--S 432 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                7         8              6 2        7
+--R         ((80A b c - 45B b )e + (- 160A b c  + 80B b c)d)
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                                                     +-+
+--R                 7         8            6 2         7              x\|c
+--R       ((- 160A b c + 90B b )e + (320A b c  - 160B b c)d)atanh(-------------)
+--R                                                                +----------+
+--R                                                                |   2
+--R                                                               \|c x  + b x
+--R  /
+--R           5 +-+
+--R     32768c \|c
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                  7         8            6 2        7     +---+
+--R         ((- 80A b c + 45B b )e + (160A b c  - 80B b c)d)\|- c
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                7         8              6 2        7     +-+
+--R         ((80A b c - 45B b )e + (- 160A b c  + 80B b c)d)\|c
+--R      *
+--R                     +----------+
+--R               +---+ |   2
+--R              \|- c \|c x  + b x
+--R         atan(-------------------)
+--R                      c x
+--R  /
+--R           5 +---+ +-+
+--R     16384c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R                                                                  +----------+
+--R            2 5       2           4                2  3      2 2  |   2
+--R   (1)  (B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 1457
+r0:=-1/24*b*(b*B-2*A*c)*x^2*(b*x+c*x^2)^(3/2)/c-1/12*(b*B-2*A*c)*x*_
+     (b*x+c*x^2)^(5/2)/c+1/7*B*(b*x+c*x^2)^(7/2)/c+5/1024*b^6*(b*B-_
+     2*A*c)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(9/2)-5/1024*b^5*(b*B-_
+     2*A*c)*sqrt(b*x+c*x^2)/c^4+5/1536*b^4*(b*B-2*A*c)*x*sqrt(b*x+_
+     c*x^2)/c^3-1/384*b^3*(b*B-2*A*c)*x^2*sqrt(b*x+c*x^2)/c^2-1/64*b^2*_
+     (b*B-2*A*c)*x^3*sqrt(b*x+c*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                         +-+
+--R                6          7           x\|c
+--R       (- 210A b c + 105B b )atanh(-------------)
+--R                                    +----------+
+--R                                    |   2
+--R                                   \|c x  + b x
+--R     + 
+--R                  6 6           6            5  5             5          2 4  4
+--R           3072B c x  + (3584A c  + 7424B b c )x  + (8960A b c  + 4736B b c )x
+--R         + 
+--R                   2 4        3 3  3          3 3        4 2  2
+--R           (6048A b c  + 48B b c )x  + (112A b c  - 56B b c )x
+--R         + 
+--R                    4 2        5            5          6
+--R           (- 140A b c  + 70B b c)x + 210A b c - 105B b
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R           4 +-+
+--R     21504c \|c
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                      +----------+
+--R                6          7          |   2                     +-+
+--R         (210A b c - 105B b )log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                    6 6           6             5  5
+--R             6144B c x  + (7168A c  + 14848B b c )x
+--R           + 
+--R                        5          2 4  4            2 4        3 3  3
+--R             (17920A b c  + 9472B b c )x  + (12096A b c  + 96B b c )x
+--R           + 
+--R                    3 3         4 2  2            4 2         5            5
+--R             (224A b c  - 112B b c )x  + (- 280A b c  + 140B b c)x + 420A b c
+--R           + 
+--R                     6
+--R             - 210B b
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R             4 +-+
+--R       43008c \|c
+--R     ,
+--R
+--R                                           +----------+
+--R                                     +---+ |   2
+--R                  6          7      \|- c \|c x  + b x
+--R         (- 210A b c + 105B b )atan(-------------------)
+--R                                            c x
+--R       + 
+--R                    6 6           6            5  5
+--R             3072B c x  + (3584A c  + 7424B b c )x
+--R           + 
+--R                       5          2 4  4           2 4        3 3  3
+--R             (8960A b c  + 4736B b c )x  + (6048A b c  + 48B b c )x
+--R           + 
+--R                    3 3        4 2  2            4 2        5            5
+--R             (112A b c  - 56B b c )x  + (- 140A b c  + 70B b c)x + 210A b c
+--R           + 
+--R                     6
+--R             - 105B b
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R             4 +---+
+--R       21504c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 438
+
+--S 439 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                 +----------+
+--R             6        7          |   2                     +-+
+--R       (10A b c - 5B b )log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                     +-+
+--R             6         7           x\|c
+--R       (20A b c - 10B b )atanh(-------------)
+--R                                +----------+
+--R                                |   2
+--R                               \|c x  + b x
+--R  /
+--R          4 +-+
+--R     2048c \|c
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                          +-+
+--R             6        7  +---+          x\|c
+--R       (10A b c - 5B b )\|- c atanh(-------------)
+--R                                     +----------+
+--R                                     |   2
+--R                                    \|c x  + b x
+--R     + 
+--R                                          +----------+
+--R                                    +---+ |   2
+--R               6        7  +-+     \|- c \|c x  + b x
+--R       (- 10A b c + 5B b )\|c atan(-------------------)
+--R                                           c x
+--R  /
+--R          4 +---+ +-+
+--R     1024c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 442
+
+)clear all
+
+--S 443 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)/(d+e*x)
+--R 
+--R
+--R                                                                  +----------+
+--R            2 5       2           4                2  3      2 2  |   2
+--R        (B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|c x  + b x
+--R   (1)  ----------------------------------------------------------------------
+--R                                        e x + d
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 1457
+r0:=1/192*(4*A*c*e*(16*c^2*d^2-22*b*c*d*e+3*b^2*e^2)-B*(64*c^3*d^3-_
+     88*b*c^2*d^2*e+12*b^2*c*d*e^2+5*b^3*e^3)-2*c*e*(12*A*c*e*(2*c*d-_
+     b*e)-B*(24*c^2*d^2-12*b*c*d*e-5*b^2*e^2))*x)*(b*x+c*x^2)^(3/2)/_
+     (c^2*e^4)-1/60*(12*B*c*d-5*b*B*e-12*A*c*e-10*B*c*e*x)*(b*x+_
+     c*x^2)^(5/2)/(c*e^2)-1/512*(4*A*c*e*(256*c^5*d^5-640*b*c^4*d^4*e+_
+     480*b^2*c^3*d^3*e^2-80*b^3*c^2*d^2*e^3-10*b^4*c*d*e^4-3*b^5*e^5)-_
+     B*(1024*c^6*d^6-2560*b*c^5*d^5*e+1920*b^2*c^4*d^4*e^2-320*b^3*_
+     c^3*d^3*e^3-40*b^4*c^2*d^2*e^4-12*b^5*c*d*e^5-5*b^6*e^6))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(c^(7/2)*e^7)-d^(5/2)*(B*d-A*e)*_
+     (c*d-b*e)^(5/2)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/e^7+1/1536*(3*(4*A*c*e*(128*c^4*d^4-_
+     288*b*c^3*d^3*e+176*b^2*c^2*d^2*e^2-10*b^3*c*d*e^3-3*b^4*e^4)-_
+     B*(512*c^5*d^5-1152*b*c^4*d^4*e+704*b^2*c^3*d^3*e^2-40*b^3*c^2*_
+     d^2*e^3-12*b^4*c*d*e^4-5*b^5*e^5))-2*c*e*(8*b*c*d*e*(2*c*d-b*e)*_
+     (12*B*c*d-5*b*B*e-12*A*c*e)+(16*c^2*d^2-8*b*c*d*e-3*b^2*e^2)*_
+     (12*A*c*e*(2*c*d-b*e)-B*(24*c^2*d^2-12*b*c*d*e-5*b^2*e^2)))*x)*_
+     sqrt(b*x+c*x^2)/(c^3*e^6)
+--R 
+--R
+--R   (2)
+--R                  5         6  6          4 2         5     5
+--R           (180A b c - 75B b )e  + (600A b c  - 180B b c)d e
+--R         + 
+--R                   3 3         4 2  2 4              2 4          3 3  3 3
+--R           (4800A b c  - 600B b c )d e  + (- 28800A b c  - 4800B b c )d e
+--R         + 
+--R                      5           2 4  4 2              6             5  5
+--R           (38400A b c  + 28800B b c )d e  + (- 15360A c  - 38400B b c )d e
+--R         + 
+--R                   6 6
+--R           15360B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                    2 3 2 3              4          2 3  3 2
+--R           - 7680A b c d e  + (15360A b c  + 7680B b c )d e
+--R         + 
+--R                     5             4  4           5 5
+--R           (- 7680A c  - 15360B b c )d e + 7680B c d
+--R      *
+--R          +-----------+ +-+ +-+             (b e - 2c d)x - b d
+--R         \|- b e + c d \|c \|d atanh(--------------------------------)
+--R                                                         +----------+
+--R                                       +-----------+ +-+ |   2
+--R                                     2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                  5 6 5            5            4  6          5   5  4
+--R           1280B c e x  + ((1536A c  + 3200B b c )e  - 1536B c d e )x
+--R         + 
+--R                         4          2 3  6             5            4    5
+--R               (4032A b c  + 2160B b c )e  + (- 1920A c  - 4032B b c )d e
+--R             + 
+--R                      5 2 4
+--R               1920B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       2 3        3 2  6               4          2 3    5
+--R               (2976A b c  + 40B b c )e  + (- 5440A b c  - 2976B b c )d e
+--R             + 
+--R                       5            4  2 4          5 3 3
+--R               (2560A c  + 5440B b c )d e  - 2560B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3 2        4   6             2 3         3 2    5
+--R               (120A b c  - 50B b c)e  + (- 4720A b c  - 120B b c )d e
+--R             + 
+--R                         4          2 3  2 4             5            4  3 3
+--R               (8320A b c  + 4720B b c )d e  + (- 3840A c  - 8320B b c )d e
+--R             + 
+--R                      5 4 2
+--R               3840B c d e
+--R          *
+--R             x
+--R         + 
+--R                    4         5  6            3 2         4     5
+--R           (- 180A b c + 75B b )e  + (- 600A b c  + 180B b c)d e
+--R         + 
+--R                    2 3         3 2  2 4                4           2 3  3 3
+--R           (10560A b c  + 600B b c )d e  + (- 17280A b c  - 10560B b c )d e
+--R         + 
+--R                   5             4  4 2          5 5
+--R           (7680A c  + 17280B b c )d e  - 7680B c d e
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R          3 7 +-+
+--R     7680c e \|c
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 1457
+--a0:=integrate(t0,x)
+--E 445
+
+--S 446 of 1457
+--m0:=a0-r0
+--E 446
+
+--S 447 of 1457
+--d0:=D(m0,x)
+--E 447
+
+)clear all
+
+--S 448 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)/(d+e*x)^2
+--R 
+--R
+--R                                                                  +----------+
+--R            2 5       2           4                2  3      2 2  |   2
+--R        (B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|c x  + b x
+--R   (1)  ----------------------------------------------------------------------
+--R                                   2 2             2
+--R                                  e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 1457
+r0:=-1/48*(10*A*c*e*(8*c*d-7*b*e)-B*(96*c^2*d^2-92*b*c*d*e+3*b^2*e^2)+_
+     6*c*e*(12*B*c*d-b*B*e-10*A*c*e)*x)*(b*x+c*x^2)^(3/2)/(c*e^4)+_
+     1/5*(6*B*d-5*A*e+B*e*x)*(b*x+c*x^2)^(5/2)/(e^2*(d+e*x))+_
+     1/128*(10*A*c*e*(128*c^4*d^4-256*b*c^3*d^3*e+144*b^2*c^2*d^2*e^2-_
+     16*b^3*c*d*e^3-b^4*e^4)-B*(1536*c^5*d^5-3200*b*c^4*d^4*e+_
+     1920*b^2*c^3*d^3*e^2-240*b^3*c^2*d^2*e^3-20*b^4*c*d*e^4-3*b^5*e^5))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(c^(5/2)*e^7)+1/2*d^(3/2)*_
+     (c*d-b*e)^(3/2)*(B*d*(12*c*d-7*b*e)-5*A*e*(2*c*d-b*e))*atanh(1/2*_
+     (b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/e^7-_
+     1/128*(10*A*c*e*(64*c^3*d^3-112*b*c^2*d^2*e+48*b^2*c*d*e^2-b^3*e^3)-_
+     B*(768*c^4*d^4-1408*b*c^3*d^3*e+656*b^2*c^2*d^2*e^2-20*b^3*c*d*e^3-_
+     3*b^4*e^4)-2*c*e*(8*b*c*e*(6*B*d-5*A*e)*(2*c*d-b*e)-(12*B*c*d-b*B*e-_
+     10*A*c*e)*(16*c^2*d^2-8*b*c*d*e-3*b^2*e^2))*x)*sqrt(b*x+c*x^2)/(c^2*e^6)
+--R 
+--R
+--R   (2)
+--R                        4         5  6             3 2         4     5
+--R               (- 150A b c + 45B b )e  + (- 2400A b c  + 300B b c)d e
+--R             + 
+--R                        2 3          3 2  2 4
+--R               (21600A b c  + 3600B b c )d e
+--R             + 
+--R                            4           2 3  3 3            5             4  4 2
+--R               (- 38400A b c  - 28800B b c )d e  + (19200A c  + 48000B b c )d e
+--R             + 
+--R                         5 5
+--R               - 23040B c d e
+--R          *
+--R             x
+--R         + 
+--R                    4         5    5             3 2         4   2 4
+--R           (- 150A b c + 45B b )d e  + (- 2400A b c  + 300B b c)d e
+--R         + 
+--R                    2 3          3 2  3 3                4           2 3  4 2
+--R           (21600A b c  + 3600B b c )d e  + (- 38400A b c  - 28800B b c )d e
+--R         + 
+--R                    5             4  5            5 6
+--R           (19200A c  + 48000B b c )d e - 23040B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                      2 2   4                3          2 2  2 3
+--R               4800A b c d e  + (- 14400A b c  - 6720B b c )d e
+--R             + 
+--R                       4             3  3 2           4 4
+--R               (9600A c  + 18240B b c )d e  - 11520B c d e
+--R          *
+--R             x
+--R         + 
+--R                  2 2 2 3                3          2 2  3 2
+--R           4800A b c d e  + (- 14400A b c  - 6720B b c )d e
+--R         + 
+--R                   4             3  4            4 5
+--R           (9600A c  + 18240B b c )d e - 11520B c d
+--R      *
+--R          +-----------+ +-+ +-+             (b e - 2c d)x - b d
+--R         \|- b e + c d \|c \|d atanh(--------------------------------)
+--R                                                         +----------+
+--R                                       +-----------+ +-+ |   2
+--R                                     2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                 4 6 5           4            3  6         4   5  4
+--R           384B c e x  + ((480A c  + 1008B b c )e  - 576B c d e )x
+--R         + 
+--R                         3         2 2  6            4            3    5
+--R               (1360A b c  + 744B b c )e  + (- 800A c  - 1712B b c )d e
+--R             + 
+--R                     4 2 4
+--R               960B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       2 2        3   6               3          2 2    5
+--R               (1180A b c  + 30B b c)e  + (- 2800A b c  - 1616B b c )d e
+--R             + 
+--R                       4            3  2 4          4 3 3
+--R               (1600A c  + 3520B b c )d e  - 1920B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3         4  6             2 2         3     5
+--R               (150A b c - 45B b )e  + (- 4100A b c  - 270B b c)d e
+--R             + 
+--R                         3          2 2  2 4             4             3  3 3
+--R               (8800A b c  + 5560B b c )d e  + (- 4800A c  - 11040B b c )d e
+--R             + 
+--R                      4 4 2
+--R               5760B c d e
+--R          *
+--R             x
+--R         + 
+--R                  3         4    5             2 2         3   2 4
+--R           (150A b c - 45B b )d e  + (- 7200A b c  - 300B b c)d e
+--R         + 
+--R                      3          2 2  3 3             4             3  4 2
+--R           (16800A b c  + 9840B b c )d e  + (- 9600A c  - 21120B b c )d e
+--R         + 
+--R                   4 5
+--R           11520B c d e
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R           2 8         2   7  +-+
+--R     (1920c e x + 1920c d e )\|c
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        4         5  6           3 2         4     5
+--R                 (150A b c - 45B b )e  + (2400A b c  - 300B b c)d e
+--R               + 
+--R                            2 3          3 2  2 4
+--R                 (- 21600A b c  - 3600B b c )d e
+--R               + 
+--R                            4           2 3  3 3
+--R                 (38400A b c  + 28800B b c )d e
+--R               + 
+--R                            5             4  4 2           5 5
+--R                 (- 19200A c  - 48000B b c )d e  + 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                    4         5    5           3 2         4   2 4
+--R             (150A b c - 45B b )d e  + (2400A b c  - 300B b c)d e
+--R           + 
+--R                        2 3          3 2  3 3              4           2 3  4 2
+--R             (- 21600A b c  - 3600B b c )d e  + (38400A b c  + 28800B b c )d e
+--R           + 
+--R                        5             4  5            5 6
+--R             (- 19200A c  - 48000B b c )d e + 23040B c d
+--R        *
+--R                    +----------+
+--R                    |   2                     +-+
+--R           log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                        2 2   4                3           2 2  2 3
+--R                 9600A b c d e  + (- 28800A b c  - 13440B b c )d e
+--R               + 
+--R                          4             3  3 2           4 4
+--R                 (19200A c  + 36480B b c )d e  - 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2 2 2 3                3           2 2  3 2
+--R             9600A b c d e  + (- 28800A b c  - 13440B b c )d e
+--R           + 
+--R                      4             3  4            4 5
+--R             (19200A c  + 36480B b c )d e - 23040B c d
+--R        *
+--R            +--------------+
+--R            |             2  +-+
+--R           \|- b d e + c d  \|c
+--R        *
+--R                   +--------------+ +----------+
+--R                   |             2  |   2
+--R               - 2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R           log(---------------------------------------------------------)
+--R                                        e x + d
+--R       + 
+--R                   4 6 5           4            3  6          4   5  4
+--R             768B c e x  + ((960A c  + 2016B b c )e  - 1152B c d e )x
+--R           + 
+--R                           3          2 2  6             4            3    5
+--R                 (2720A b c  + 1488B b c )e  + (- 1600A c  - 3424B b c )d e
+--R               + 
+--R                        4 2 4
+--R                 1920B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         2 2        3   6               3          2 2    5
+--R                 (2360A b c  + 60B b c)e  + (- 5600A b c  - 3232B b c )d e
+--R               + 
+--R                         4            3  2 4          4 3 3
+--R                 (3200A c  + 7040B b c )d e  - 3840B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3         4  6             2 2         3     5
+--R                 (300A b c - 90B b )e  + (- 8200A b c  - 540B b c)d e
+--R               + 
+--R                            3           2 2  2 4
+--R                 (17600A b c  + 11120B b c )d e
+--R               + 
+--R                           4             3  3 3           4 4 2
+--R                 (- 9600A c  - 22080B b c )d e  + 11520B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3         4    5              2 2         3   2 4
+--R             (300A b c - 90B b )d e  + (- 14400A b c  - 600B b c)d e
+--R           + 
+--R                        3           2 2  3 3              4             3  4 2
+--R             (33600A b c  + 19680B b c )d e  + (- 19200A c  - 42240B b c )d e
+--R           + 
+--R                     4 5
+--R             23040B c d e
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R             2 8         2   7  +-+
+--R       (3840c e x + 3840c d e )\|c
+--R     ,
+--R
+--R                        4         5  6           3 2         4     5
+--R                 (150A b c - 45B b )e  + (2400A b c  - 300B b c)d e
+--R               + 
+--R                            2 3          3 2  2 4
+--R                 (- 21600A b c  - 3600B b c )d e
+--R               + 
+--R                            4           2 3  3 3
+--R                 (38400A b c  + 28800B b c )d e
+--R               + 
+--R                            5             4  4 2           5 5
+--R                 (- 19200A c  - 48000B b c )d e  + 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                    4         5    5           3 2         4   2 4
+--R             (150A b c - 45B b )d e  + (2400A b c  - 300B b c)d e
+--R           + 
+--R                        2 3          3 2  3 3              4           2 3  4 2
+--R             (- 21600A b c  - 3600B b c )d e  + (38400A b c  + 28800B b c )d e
+--R           + 
+--R                        5             4  5            5 6
+--R             (- 19200A c  - 48000B b c )d e + 23040B c d
+--R        *
+--R                    +----------+
+--R                    |   2                     +-+
+--R           log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                           2 2   4              3           2 2  2 3
+--R                 - 19200A b c d e  + (57600A b c  + 26880B b c )d e
+--R               + 
+--R                            4             3  3 2           4 4
+--R                 (- 38400A c  - 72960B b c )d e  + 46080B c d e
+--R            *
+--R               x
+--R           + 
+--R                       2 2 2 3              3           2 2  3 2
+--R             - 19200A b c d e  + (57600A b c  + 26880B b c )d e
+--R           + 
+--R                        4             3  4            4 5
+--R             (- 38400A c  - 72960B b c )d e + 46080B c d
+--R        *
+--R                                      +----------+
+--R                +------------+        |   2
+--R            +-+ |           2       d\|c x  + b x
+--R           \|c \|b d e - c d  atan(----------------)
+--R                                     +------------+
+--R                                     |           2
+--R                                   x\|b d e - c d
+--R       + 
+--R                   4 6 5           4            3  6          4   5  4
+--R             768B c e x  + ((960A c  + 2016B b c )e  - 1152B c d e )x
+--R           + 
+--R                           3          2 2  6             4            3    5
+--R                 (2720A b c  + 1488B b c )e  + (- 1600A c  - 3424B b c )d e
+--R               + 
+--R                        4 2 4
+--R                 1920B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         2 2        3   6               3          2 2    5
+--R                 (2360A b c  + 60B b c)e  + (- 5600A b c  - 3232B b c )d e
+--R               + 
+--R                         4            3  2 4          4 3 3
+--R                 (3200A c  + 7040B b c )d e  - 3840B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3         4  6             2 2         3     5
+--R                 (300A b c - 90B b )e  + (- 8200A b c  - 540B b c)d e
+--R               + 
+--R                            3           2 2  2 4
+--R                 (17600A b c  + 11120B b c )d e
+--R               + 
+--R                           4             3  3 3           4 4 2
+--R                 (- 9600A c  - 22080B b c )d e  + 11520B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3         4    5              2 2         3   2 4
+--R             (300A b c - 90B b )d e  + (- 14400A b c  - 600B b c)d e
+--R           + 
+--R                        3           2 2  3 3              4             3  4 2
+--R             (33600A b c  + 19680B b c )d e  + (- 19200A c  - 42240B b c )d e
+--R           + 
+--R                     4 5
+--R             23040B c d e
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R             2 8         2   7  +-+
+--R       (3840c e x + 3840c d e )\|c
+--R     ,
+--R
+--R                        2 2   4                3          2 2  2 3
+--R                 4800A b c d e  + (- 14400A b c  - 6720B b c )d e
+--R               + 
+--R                         4             3  3 2           4 4
+--R                 (9600A c  + 18240B b c )d e  - 11520B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2 2 2 3                3          2 2  3 2
+--R             4800A b c d e  + (- 14400A b c  - 6720B b c )d e
+--R           + 
+--R                     4             3  4            4 5
+--R             (9600A c  + 18240B b c )d e - 11520B c d
+--R        *
+--R            +--------------+
+--R            |             2  +---+
+--R           \|- b d e + c d  \|- c
+--R        *
+--R                   +--------------+ +----------+
+--R                   |             2  |   2
+--R               - 2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R           log(---------------------------------------------------------)
+--R                                        e x + d
+--R       + 
+--R                          4         5  6             3 2         4     5
+--R                 (- 150A b c + 45B b )e  + (- 2400A b c  + 300B b c)d e
+--R               + 
+--R                          2 3          3 2  2 4
+--R                 (21600A b c  + 3600B b c )d e
+--R               + 
+--R                              4           2 3  3 3
+--R                 (- 38400A b c  - 28800B b c )d e
+--R               + 
+--R                          5             4  4 2           5 5
+--R                 (19200A c  + 48000B b c )d e  - 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                      4         5    5             3 2         4   2 4
+--R             (- 150A b c + 45B b )d e  + (- 2400A b c  + 300B b c)d e
+--R           + 
+--R                      2 3          3 2  3 3                4           2 3  4 2
+--R             (21600A b c  + 3600B b c )d e  + (- 38400A b c  - 28800B b c )d e
+--R           + 
+--R                      5             4  5            5 6
+--R             (19200A c  + 48000B b c )d e - 23040B c d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                   4 6 5           4            3  6         4   5  4
+--R             384B c e x  + ((480A c  + 1008B b c )e  - 576B c d e )x
+--R           + 
+--R                           3         2 2  6            4            3    5
+--R                 (1360A b c  + 744B b c )e  + (- 800A c  - 1712B b c )d e
+--R               + 
+--R                       4 2 4
+--R                 960B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         2 2        3   6               3          2 2    5
+--R                 (1180A b c  + 30B b c)e  + (- 2800A b c  - 1616B b c )d e
+--R               + 
+--R                         4            3  2 4          4 3 3
+--R                 (1600A c  + 3520B b c )d e  - 1920B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3         4  6             2 2         3     5
+--R                 (150A b c - 45B b )e  + (- 4100A b c  - 270B b c)d e
+--R               + 
+--R                           3          2 2  2 4             4             3  3 3
+--R                 (8800A b c  + 5560B b c )d e  + (- 4800A c  - 11040B b c )d e
+--R               + 
+--R                        4 4 2
+--R                 5760B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3         4    5             2 2         3   2 4
+--R             (150A b c - 45B b )d e  + (- 7200A b c  - 300B b c)d e
+--R           + 
+--R                        3          2 2  3 3             4             3  4 2
+--R             (16800A b c  + 9840B b c )d e  + (- 9600A c  - 21120B b c )d e
+--R           + 
+--R                     4 5
+--R             11520B c d e
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R             2 8         2   7  +---+
+--R       (1920c e x + 1920c d e )\|- c
+--R     ,
+--R
+--R                          4         5  6             3 2         4     5
+--R                 (- 150A b c + 45B b )e  + (- 2400A b c  + 300B b c)d e
+--R               + 
+--R                          2 3          3 2  2 4
+--R                 (21600A b c  + 3600B b c )d e
+--R               + 
+--R                              4           2 3  3 3
+--R                 (- 38400A b c  - 28800B b c )d e
+--R               + 
+--R                          5             4  4 2           5 5
+--R                 (19200A c  + 48000B b c )d e  - 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                      4         5    5             3 2         4   2 4
+--R             (- 150A b c + 45B b )d e  + (- 2400A b c  + 300B b c)d e
+--R           + 
+--R                      2 3          3 2  3 3                4           2 3  4 2
+--R             (21600A b c  + 3600B b c )d e  + (- 38400A b c  - 28800B b c )d e
+--R           + 
+--R                      5             4  5            5 6
+--R             (19200A c  + 48000B b c )d e - 23040B c d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                          2 2   4              3           2 2  2 3
+--R                 - 9600A b c d e  + (28800A b c  + 13440B b c )d e
+--R               + 
+--R                            4             3  3 2           4 4
+--R                 (- 19200A c  - 36480B b c )d e  + 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                      2 2 2 3              3           2 2  3 2
+--R             - 9600A b c d e  + (28800A b c  + 13440B b c )d e
+--R           + 
+--R                        4             3  4            4 5
+--R             (- 19200A c  - 36480B b c )d e + 23040B c d
+--R        *
+--R                                        +----------+
+--R                  +------------+        |   2
+--R            +---+ |           2       d\|c x  + b x
+--R           \|- c \|b d e - c d  atan(----------------)
+--R                                       +------------+
+--R                                       |           2
+--R                                     x\|b d e - c d
+--R       + 
+--R                   4 6 5           4            3  6         4   5  4
+--R             384B c e x  + ((480A c  + 1008B b c )e  - 576B c d e )x
+--R           + 
+--R                           3         2 2  6            4            3    5
+--R                 (1360A b c  + 744B b c )e  + (- 800A c  - 1712B b c )d e
+--R               + 
+--R                       4 2 4
+--R                 960B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         2 2        3   6               3          2 2    5
+--R                 (1180A b c  + 30B b c)e  + (- 2800A b c  - 1616B b c )d e
+--R               + 
+--R                         4            3  2 4          4 3 3
+--R                 (1600A c  + 3520B b c )d e  - 1920B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3         4  6             2 2         3     5
+--R                 (150A b c - 45B b )e  + (- 4100A b c  - 270B b c)d e
+--R               + 
+--R                           3          2 2  2 4             4             3  3 3
+--R                 (8800A b c  + 5560B b c )d e  + (- 4800A c  - 11040B b c )d e
+--R               + 
+--R                        4 4 2
+--R                 5760B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3         4    5             2 2         3   2 4
+--R             (150A b c - 45B b )d e  + (- 7200A b c  - 300B b c)d e
+--R           + 
+--R                        3          2 2  3 3             4             3  4 2
+--R             (16800A b c  + 9840B b c )d e  + (- 9600A c  - 21120B b c )d e
+--R           + 
+--R                     4 5
+--R             11520B c d e
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R             2 8         2   7  +---+
+--R       (1920c e x + 1920c d e )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 450
+
+--S 451 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 4        5  5          3 2        4     4
+--R           (10A b c - 3B b )e  + (160A b c  - 20B b c)d e
+--R         + 
+--R                     2 3         3 2  2 3             4          2 3  3 2
+--R           (- 1440A b c  - 240B b c )d e  + (2560A b c  + 1920B b c )d e
+--R         + 
+--R                     5            4  4           5 5
+--R           (- 1280A c  - 3200B b c )d e + 1536B c d
+--R      *
+--R                  +----------+
+--R                  |   2                     +-+
+--R         log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                 2 2   3               3         2 2  2 2
+--R           640A b c d e  + (- 1920A b c  - 896B b c )d e
+--R         + 
+--R                   4            3  3           4 4
+--R           (1280A c  + 2432B b c )d e - 1536B c d
+--R      *
+--R          +--------------+
+--R          |             2  +-+
+--R         \|- b d e + c d  \|c
+--R      *
+--R                 +--------------+ +----------+
+--R                 |             2  |   2
+--R             - 2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R         log(---------------------------------------------------------)
+--R                                      e x + d
+--R     + 
+--R                 4        5  5          3 2        4     4
+--R           (20A b c - 6B b )e  + (320A b c  - 40B b c)d e
+--R         + 
+--R                     2 3         3 2  2 3             4          2 3  3 2
+--R           (- 2880A b c  - 480B b c )d e  + (5120A b c  + 3840B b c )d e
+--R         + 
+--R                     5            4  4           5 5
+--R           (- 2560A c  - 6400B b c )d e + 3072B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                   2 2   3             3         2 2  2 2
+--R           - 640A b c d e  + (1920A b c  + 896B b c )d e
+--R         + 
+--R                     4            3  3           4 4
+--R           (- 1280A c  - 2432B b c )d e + 1536B c d
+--R      *
+--R          +-----------+ +-+ +-+             (b e - 2c d)x - b d
+--R         \|- b e + c d \|c \|d atanh(--------------------------------)
+--R                                                         +----------+
+--R                                       +-----------+ +-+ |   2
+--R                                     2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R         2 7 +-+
+--R     256c e \|c
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 4        5  5          3 2        4     4
+--R           (10A b c - 3B b )e  + (160A b c  - 20B b c)d e
+--R         + 
+--R                     2 3         3 2  2 3             4          2 3  3 2
+--R           (- 1440A b c  - 240B b c )d e  + (2560A b c  + 1920B b c )d e
+--R         + 
+--R                     5            4  4           5 5
+--R           (- 1280A c  - 3200B b c )d e + 1536B c d
+--R      *
+--R                  +----------+
+--R                  |   2                     +-+
+--R         log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                 4        5  5          3 2        4     4
+--R           (20A b c - 6B b )e  + (320A b c  - 40B b c)d e
+--R         + 
+--R                     2 3         3 2  2 3             4          2 3  3 2
+--R           (- 2880A b c  - 480B b c )d e  + (5120A b c  + 3840B b c )d e
+--R         + 
+--R                     5            4  4           5 5
+--R           (- 2560A c  - 6400B b c )d e + 3072B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                   2 2   3             3         2 2  2 2
+--R           - 640A b c d e  + (1920A b c  + 896B b c )d e
+--R         + 
+--R                     4            3  3           4 4
+--R           (- 1280A c  - 2432B b c )d e + 1536B c d
+--R      *
+--R          +-----------+ +-+ +-+             (b e - 2c d)x - b d
+--R         \|- b e + c d \|c \|d atanh(--------------------------------)
+--R                                                         +----------+
+--R                                       +-----------+ +-+ |   2
+--R                                     2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                    2 2   3             3          2 2  2 2
+--R           - 1280A b c d e  + (3840A b c  + 1792B b c )d e
+--R         + 
+--R                     4            3  3           4 4
+--R           (- 2560A c  - 4864B b c )d e + 3072B c d
+--R      *
+--R                                    +----------+
+--R              +------------+        |   2
+--R          +-+ |           2       d\|c x  + b x
+--R         \|c \|b d e - c d  atan(----------------)
+--R                                   +------------+
+--R                                   |           2
+--R                                 x\|b d e - c d
+--R  /
+--R         2 7 +-+
+--R     256c e \|c
+--R                                                    Type: Expression(Integer)
+--E 453
+
+--S 454 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 454
+
+)clear all
+
+--S 455 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)/(d+e*x)^3
+--R 
+--R
+--R                                                                  +----------+
+--R            2 5       2           4                2  3      2 2  |   2
+--R        (B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|c x  + b x
+--R   (1)  ----------------------------------------------------------------------
+--R                              3 3       2 2     2       3
+--R                             e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 1457
+r0:=-5/24*(B*d*(24*c*d-13*b*e)-2*A*e*(8*c*d-3*b*e)+e*(6*B*c*d-b*B*e-_
+     4*A*c*e)*x)*(b*x+c*x^2)^(3/2)/(e^4*(d+e*x))+1/4*(3*B*d-2*A*e+B*e*x)*_
+     (b*x+c*x^2)^(5/2)/(e^2*(d+e*x)^2)-5/64*(8*A*c*e*(32*c^3*d^3-48*b*c^2*_
+     d^2*e+18*b^2*c*d*e^2-b^3*e^3)-B*(384*c^4*d^4-640*b*c^3*d^3*e+288*b^2*_
+     c^2*d^2*e^2-24*b^3*c*d*e^3-b^4*e^4))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/_
+     (c^(3/2)*e^7)+5/8*(A*e*(16*c^2*d^2-16*b*c*d*e+3*b^2*e^2)-B*d*(24*c^2*_
+     d^2-28*b*c*d*e+7*b^2*e^2))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))*sqrt(d)*sqrt(c*d-b*e)/e^7+5/64*_
+     (8*A*c*e*(16*c^2*d^2-20*b*c*d*e+5*b^2*e^2)-B*(192*c^3*d^3-272*b*c^2*_
+     d^2*e+88*b^2*c*d*e^2-b^3*e^3)-2*c*e*(16*A*c*e*(2*c*d-b*e)-B*(48*c^2*_
+     d^2-32*b*c*d*e+b^2*e^2))*x)*sqrt(b*x+c*x^2)/(c*e^6)
+--R 
+--R
+--R   (2)
+--R                      3         4  6             2 2         3     5
+--R               (120A b c - 15B b )e  + (- 2160A b c  - 360B b c)d e
+--R             + 
+--R                         3          2 2  2 4             4            3  3 3
+--R               (5760A b c  + 4320B b c )d e  + (- 3840A c  - 9600B b c )d e
+--R             + 
+--R                      4 4 2
+--R               5760B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3         4    5             2 2         3   2 4
+--R               (240A b c - 30B b )d e  + (- 4320A b c  - 720B b c)d e
+--R             + 
+--R                          3          2 2  3 3             4             3  4 2
+--R               (11520A b c  + 8640B b c )d e  + (- 7680A c  - 19200B b c )d e
+--R             + 
+--R                       4 5
+--R               11520B c d e
+--R          *
+--R             x
+--R         + 
+--R                  3         4  2 4             2 2         3   3 3
+--R           (120A b c - 15B b )d e  + (- 2160A b c  - 360B b c)d e
+--R         + 
+--R                     3          2 2  4 2             4            3  5
+--R           (5760A b c  + 4320B b c )d e  + (- 3840A c  - 9600B b c )d e
+--R         + 
+--R                  4 6
+--R           5760B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                       2   5             2         2     4
+--R               - 360A b c e  + (1920A b c  + 840B b c)d e
+--R             + 
+--R                         3            2  2 3          3 3 2
+--R               (- 1920A c  - 3360B b c )d e  + 2880B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       2     4             2          2   2 3
+--R               - 720A b c d e  + (3840A b c  + 1680B b c)d e
+--R             + 
+--R                         3            2  3 2          3 4
+--R               (- 3840A c  - 6720B b c )d e  + 5760B c d e
+--R          *
+--R             x
+--R         + 
+--R                   2   2 3             2         2   3 2
+--R           - 360A b c d e  + (1920A b c  + 840B b c)d e
+--R         + 
+--R                     3            2  4           3 5
+--R           (- 1920A c  - 3360B b c )d e + 2880B c d
+--R      *
+--R          +-----------+ +-+ +-+             (b e - 2c d)x - b d
+--R         \|- b e + c d \|c \|d atanh(--------------------------------)
+--R                                                         +----------+
+--R                                       +-----------+ +-+ |   2
+--R                                     2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                3 6 5          3           2  6        3   5  4
+--R           48B c e x  + ((64A c  + 136B b c )e  - 96B c d e )x
+--R         + 
+--R                        2         2   6            3           2    5
+--R               (208A b c  + 118B b c)e  + (- 160A c  - 352B b c )d e
+--R             + 
+--R                     3 2 4
+--R               240B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      2         3  6              2         2     5
+--R               (264A b c + 15B b )e  + (- 880A b c  - 556B b c)d e
+--R             + 
+--R                      3            2  2 4         3 3 3
+--R               (640A c  + 1480B b c )d e  - 960B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      2         3    5               2          2   2 4
+--R               (960A b c + 30B b )d e  + (- 3680A b c  - 2090B b c)d e
+--R             + 
+--R                       3            2  3 3          3 4 2
+--R               (2880A c  + 6240B b c )d e  - 4320B c d e
+--R          *
+--R             x
+--R         + 
+--R                  2         3  2 4               2          2   3 3
+--R           (600A b c + 15B b )d e  + (- 2400A b c  - 1320B b c)d e
+--R         + 
+--R                   3            2  4 2          3 5
+--R           (1920A c  + 4080B b c )d e  - 2880B c d e
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R            9 2           8          2 7  +-+
+--R     (192c e x  + 384c d e x + 192c d e )\|c
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          3         4  6           2 2         3     5
+--R                 (- 120A b c + 15B b )e  + (2160A b c  + 360B b c)d e
+--R               + 
+--R                             3          2 2  2 4           4            3  3 3
+--R                 (- 5760A b c  - 4320B b c )d e  + (3840A c  + 9600B b c )d e
+--R               + 
+--R                          4 4 2
+--R                 - 5760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                          3         4    5           2 2         3   2 4
+--R                 (- 240A b c + 30B b )d e  + (4320A b c  + 720B b c)d e
+--R               + 
+--R                              3          2 2  3 3           4             3  4 2
+--R                 (- 11520A b c  - 8640B b c )d e  + (7680A c  + 19200B b c )d e
+--R               + 
+--R                           4 5
+--R                 - 11520B c d e
+--R            *
+--R               x
+--R           + 
+--R                      3         4  2 4           2 2         3   3 3
+--R             (- 120A b c + 15B b )d e  + (2160A b c  + 360B b c)d e
+--R           + 
+--R                         3          2 2  4 2           4            3  5
+--R             (- 5760A b c  - 4320B b c )d e  + (3840A c  + 9600B b c )d e
+--R           + 
+--R                      4 6
+--R             - 5760B c d
+--R        *
+--R                    +----------+
+--R                    |   2                     +-+
+--R           log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                         2   5             2          2     4
+--R                 - 720A b c e  + (3840A b c  + 1680B b c)d e
+--R               + 
+--R                           3            2  2 3          3 3 2
+--R                 (- 3840A c  - 6720B b c )d e  + 5760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                          2     4             2          2   2 3
+--R                 - 1440A b c d e  + (7680A b c  + 3360B b c)d e
+--R               + 
+--R                           3             2  3 2           3 4
+--R                 (- 7680A c  - 13440B b c )d e  + 11520B c d e
+--R            *
+--R               x
+--R           + 
+--R                     2   2 3             2          2   3 2
+--R             - 720A b c d e  + (3840A b c  + 1680B b c)d e
+--R           + 
+--R                       3            2  4           3 5
+--R             (- 3840A c  - 6720B b c )d e + 5760B c d
+--R        *
+--R            +--------------+
+--R            |             2  +-+
+--R           \|- b d e + c d  \|c
+--R        *
+--R                   +--------------+ +----------+
+--R                   |             2  |   2
+--R               - 2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R           log(---------------------------------------------------------)
+--R                                        e x + d
+--R       + 
+--R                  3 6 5           3           2  6         3   5  4
+--R             96B c e x  + ((128A c  + 272B b c )e  - 192B c d e )x
+--R           + 
+--R                          2         2   6            3           2    5
+--R                 (416A b c  + 236B b c)e  + (- 320A c  - 704B b c )d e
+--R               + 
+--R                       3 2 4
+--R                 480B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2         3  6               2          2     5
+--R                 (528A b c + 30B b )e  + (- 1760A b c  - 1112B b c)d e
+--R               + 
+--R                         3            2  2 4          3 3 3
+--R                 (1280A c  + 2960B b c )d e  - 1920B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         2         3    5               2          2   2 4
+--R                 (1920A b c + 60B b )d e  + (- 7360A b c  - 4180B b c)d e
+--R               + 
+--R                         3             2  3 3          3 4 2
+--R                 (5760A c  + 12480B b c )d e  - 8640B c d e
+--R            *
+--R               x
+--R           + 
+--R                     2         3  2 4               2          2   3 3
+--R             (1200A b c + 30B b )d e  + (- 4800A b c  - 2640B b c)d e
+--R           + 
+--R                     3            2  4 2          3 5
+--R             (3840A c  + 8160B b c )d e  - 5760B c d e
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R              9 2           8          2 7  +-+
+--R       (384c e x  + 768c d e x + 384c d e )\|c
+--R     ,
+--R
+--R                          3         4  6           2 2         3     5
+--R                 (- 120A b c + 15B b )e  + (2160A b c  + 360B b c)d e
+--R               + 
+--R                             3          2 2  2 4           4            3  3 3
+--R                 (- 5760A b c  - 4320B b c )d e  + (3840A c  + 9600B b c )d e
+--R               + 
+--R                          4 4 2
+--R                 - 5760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                          3         4    5           2 2         3   2 4
+--R                 (- 240A b c + 30B b )d e  + (4320A b c  + 720B b c)d e
+--R               + 
+--R                              3          2 2  3 3           4             3  4 2
+--R                 (- 11520A b c  - 8640B b c )d e  + (7680A c  + 19200B b c )d e
+--R               + 
+--R                           4 5
+--R                 - 11520B c d e
+--R            *
+--R               x
+--R           + 
+--R                      3         4  2 4           2 2         3   3 3
+--R             (- 120A b c + 15B b )d e  + (2160A b c  + 360B b c)d e
+--R           + 
+--R                         3          2 2  4 2           4            3  5
+--R             (- 5760A b c  - 4320B b c )d e  + (3840A c  + 9600B b c )d e
+--R           + 
+--R                      4 6
+--R             - 5760B c d
+--R        *
+--R                    +----------+
+--R                    |   2                     +-+
+--R           log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                        2   5               2          2     4
+--R                 1440A b c e  + (- 7680A b c  - 3360B b c)d e
+--R               + 
+--R                         3             2  2 3           3 3 2
+--R                 (7680A c  + 13440B b c )d e  - 11520B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2     4                2          2   2 3
+--R                 2880A b c d e  + (- 15360A b c  - 6720B b c)d e
+--R               + 
+--R                          3             2  3 2           3 4
+--R                 (15360A c  + 26880B b c )d e  - 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2   2 3               2          2   3 2
+--R             1440A b c d e  + (- 7680A b c  - 3360B b c)d e
+--R           + 
+--R                     3             2  4            3 5
+--R             (7680A c  + 13440B b c )d e - 11520B c d
+--R        *
+--R                                      +----------+
+--R                +------------+        |   2
+--R            +-+ |           2       d\|c x  + b x
+--R           \|c \|b d e - c d  atan(----------------)
+--R                                     +------------+
+--R                                     |           2
+--R                                   x\|b d e - c d
+--R       + 
+--R                  3 6 5           3           2  6         3   5  4
+--R             96B c e x  + ((128A c  + 272B b c )e  - 192B c d e )x
+--R           + 
+--R                          2         2   6            3           2    5
+--R                 (416A b c  + 236B b c)e  + (- 320A c  - 704B b c )d e
+--R               + 
+--R                       3 2 4
+--R                 480B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2         3  6               2          2     5
+--R                 (528A b c + 30B b )e  + (- 1760A b c  - 1112B b c)d e
+--R               + 
+--R                         3            2  2 4          3 3 3
+--R                 (1280A c  + 2960B b c )d e  - 1920B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         2         3    5               2          2   2 4
+--R                 (1920A b c + 60B b )d e  + (- 7360A b c  - 4180B b c)d e
+--R               + 
+--R                         3             2  3 3          3 4 2
+--R                 (5760A c  + 12480B b c )d e  - 8640B c d e
+--R            *
+--R               x
+--R           + 
+--R                     2         3  2 4               2          2   3 3
+--R             (1200A b c + 30B b )d e  + (- 4800A b c  - 2640B b c)d e
+--R           + 
+--R                     3            2  4 2          3 5
+--R             (3840A c  + 8160B b c )d e  - 5760B c d e
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R              9 2           8          2 7  +-+
+--R       (384c e x  + 768c d e x + 384c d e )\|c
+--R     ,
+--R
+--R                         2   5             2         2     4
+--R                 - 360A b c e  + (1920A b c  + 840B b c)d e
+--R               + 
+--R                           3            2  2 3          3 3 2
+--R                 (- 1920A c  - 3360B b c )d e  + 2880B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         2     4             2          2   2 3
+--R                 - 720A b c d e  + (3840A b c  + 1680B b c)d e
+--R               + 
+--R                           3            2  3 2          3 4
+--R                 (- 3840A c  - 6720B b c )d e  + 5760B c d e
+--R            *
+--R               x
+--R           + 
+--R                     2   2 3             2         2   3 2
+--R             - 360A b c d e  + (1920A b c  + 840B b c)d e
+--R           + 
+--R                       3            2  4           3 5
+--R             (- 1920A c  - 3360B b c )d e + 2880B c d
+--R        *
+--R            +--------------+
+--R            |             2  +---+
+--R           \|- b d e + c d  \|- c
+--R        *
+--R                   +--------------+ +----------+
+--R                   |             2  |   2
+--R               - 2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R           log(---------------------------------------------------------)
+--R                                        e x + d
+--R       + 
+--R                        3         4  6             2 2         3     5
+--R                 (120A b c - 15B b )e  + (- 2160A b c  - 360B b c)d e
+--R               + 
+--R                           3          2 2  2 4             4            3  3 3
+--R                 (5760A b c  + 4320B b c )d e  + (- 3840A c  - 9600B b c )d e
+--R               + 
+--R                        4 4 2
+--R                 5760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3         4    5             2 2         3   2 4
+--R                 (240A b c - 30B b )d e  + (- 4320A b c  - 720B b c)d e
+--R               + 
+--R                            3          2 2  3 3             4             3  4 2
+--R                 (11520A b c  + 8640B b c )d e  + (- 7680A c  - 19200B b c )d e
+--R               + 
+--R                         4 5
+--R                 11520B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3         4  2 4             2 2         3   3 3
+--R             (120A b c - 15B b )d e  + (- 2160A b c  - 360B b c)d e
+--R           + 
+--R                       3          2 2  4 2             4            3  5
+--R             (5760A b c  + 4320B b c )d e  + (- 3840A c  - 9600B b c )d e
+--R           + 
+--R                    4 6
+--R             5760B c d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                  3 6 5          3           2  6        3   5  4
+--R             48B c e x  + ((64A c  + 136B b c )e  - 96B c d e )x
+--R           + 
+--R                          2         2   6            3           2    5
+--R                 (208A b c  + 118B b c)e  + (- 160A c  - 352B b c )d e
+--R               + 
+--R                       3 2 4
+--R                 240B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2         3  6              2         2     5
+--R                 (264A b c + 15B b )e  + (- 880A b c  - 556B b c)d e
+--R               + 
+--R                        3            2  2 4         3 3 3
+--R                 (640A c  + 1480B b c )d e  - 960B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2         3    5               2          2   2 4
+--R                 (960A b c + 30B b )d e  + (- 3680A b c  - 2090B b c)d e
+--R               + 
+--R                         3            2  3 3          3 4 2
+--R                 (2880A c  + 6240B b c )d e  - 4320B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2         3  2 4               2          2   3 3
+--R             (600A b c + 15B b )d e  + (- 2400A b c  - 1320B b c)d e
+--R           + 
+--R                     3            2  4 2          3 5
+--R             (1920A c  + 4080B b c )d e  - 2880B c d e
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R              9 2           8          2 7  +---+
+--R       (192c e x  + 384c d e x + 192c d e )\|- c
+--R     ,
+--R
+--R                        3         4  6             2 2         3     5
+--R                 (120A b c - 15B b )e  + (- 2160A b c  - 360B b c)d e
+--R               + 
+--R                           3          2 2  2 4             4            3  3 3
+--R                 (5760A b c  + 4320B b c )d e  + (- 3840A c  - 9600B b c )d e
+--R               + 
+--R                        4 4 2
+--R                 5760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3         4    5             2 2         3   2 4
+--R                 (240A b c - 30B b )d e  + (- 4320A b c  - 720B b c)d e
+--R               + 
+--R                            3          2 2  3 3             4             3  4 2
+--R                 (11520A b c  + 8640B b c )d e  + (- 7680A c  - 19200B b c )d e
+--R               + 
+--R                         4 5
+--R                 11520B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3         4  2 4             2 2         3   3 3
+--R             (120A b c - 15B b )d e  + (- 2160A b c  - 360B b c)d e
+--R           + 
+--R                       3          2 2  4 2             4            3  5
+--R             (5760A b c  + 4320B b c )d e  + (- 3840A c  - 9600B b c )d e
+--R           + 
+--R                    4 6
+--R             5760B c d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                       2   5               2          2     4
+--R                 720A b c e  + (- 3840A b c  - 1680B b c)d e
+--R               + 
+--R                         3            2  2 3          3 3 2
+--R                 (3840A c  + 6720B b c )d e  - 5760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2     4               2          2   2 3
+--R                 1440A b c d e  + (- 7680A b c  - 3360B b c)d e
+--R               + 
+--R                         3             2  3 2           3 4
+--R                 (7680A c  + 13440B b c )d e  - 11520B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2   2 3               2          2   3 2
+--R             720A b c d e  + (- 3840A b c  - 1680B b c)d e
+--R           + 
+--R                     3            2  4           3 5
+--R             (3840A c  + 6720B b c )d e - 5760B c d
+--R        *
+--R                                        +----------+
+--R                  +------------+        |   2
+--R            +---+ |           2       d\|c x  + b x
+--R           \|- c \|b d e - c d  atan(----------------)
+--R                                       +------------+
+--R                                       |           2
+--R                                     x\|b d e - c d
+--R       + 
+--R                  3 6 5          3           2  6        3   5  4
+--R             48B c e x  + ((64A c  + 136B b c )e  - 96B c d e )x
+--R           + 
+--R                          2         2   6            3           2    5
+--R                 (208A b c  + 118B b c)e  + (- 160A c  - 352B b c )d e
+--R               + 
+--R                       3 2 4
+--R                 240B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2         3  6              2         2     5
+--R                 (264A b c + 15B b )e  + (- 880A b c  - 556B b c)d e
+--R               + 
+--R                        3            2  2 4         3 3 3
+--R                 (640A c  + 1480B b c )d e  - 960B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2         3    5               2          2   2 4
+--R                 (960A b c + 30B b )d e  + (- 3680A b c  - 2090B b c)d e
+--R               + 
+--R                         3            2  3 3          3 4 2
+--R                 (2880A c  + 6240B b c )d e  - 4320B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2         3  2 4               2          2   3 3
+--R             (600A b c + 15B b )d e  + (- 2400A b c  - 1320B b c)d e
+--R           + 
+--R                     3            2  4 2          3 5
+--R             (1920A c  + 4080B b c )d e  - 2880B c d e
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R              9 2           8          2 7  +---+
+--R       (192c e x  + 384c d e x + 192c d e )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 457
+
+--S 458 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                   3        4  4          2 2         3     3
+--R           (- 40A b c + 5B b )e  + (720A b c  + 120B b c)d e
+--R         + 
+--R                       3          2 2  2 2           4            3  3
+--R           (- 1920A b c  - 1440B b c )d e  + (1280A c  + 3200B b c )d e
+--R         + 
+--R                    4 4
+--R           - 1920B c d
+--R      *
+--R                  +----------+
+--R                  |   2                     +-+
+--R         log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                   2   3             2         2     2
+--R           - 240A b c e  + (1280A b c  + 560B b c)d e
+--R         + 
+--R                     3            2  2           3 3
+--R           (- 1280A c  - 2240B b c )d e + 1920B c d
+--R      *
+--R          +--------------+
+--R          |             2  +-+
+--R         \|- b d e + c d  \|c
+--R      *
+--R                 +--------------+ +----------+
+--R                 |             2  |   2
+--R             - 2\|- b d e + c d  \|c x  + b x  + (- b e + 2c d)x + b d
+--R         log(---------------------------------------------------------)
+--R                                      e x + d
+--R     + 
+--R                   3         4  4           2 2         3     3
+--R           (- 80A b c + 10B b )e  + (1440A b c  + 240B b c)d e
+--R         + 
+--R                       3          2 2  2 2           4            3  3
+--R           (- 3840A b c  - 2880B b c )d e  + (2560A c  + 6400B b c )d e
+--R         + 
+--R                    4 4
+--R           - 3840B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                 2   3               2         2     2
+--R           240A b c e  + (- 1280A b c  - 560B b c)d e
+--R         + 
+--R                   3            2  2           3 3
+--R           (1280A c  + 2240B b c )d e - 1920B c d
+--R      *
+--R          +-----------+ +-+ +-+             (b e - 2c d)x - b d
+--R         \|- b e + c d \|c \|d atanh(--------------------------------)
+--R                                                         +----------+
+--R                                       +-----------+ +-+ |   2
+--R                                     2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R           7 +-+
+--R     128c e \|c
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                   3        4  4          2 2         3     3
+--R           (- 40A b c + 5B b )e  + (720A b c  + 120B b c)d e
+--R         + 
+--R                       3          2 2  2 2           4            3  3
+--R           (- 1920A b c  - 1440B b c )d e  + (1280A c  + 3200B b c )d e
+--R         + 
+--R                    4 4
+--R           - 1920B c d
+--R      *
+--R                  +----------+
+--R                  |   2                     +-+
+--R         log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                   3         4  4           2 2         3     3
+--R           (- 80A b c + 10B b )e  + (1440A b c  + 240B b c)d e
+--R         + 
+--R                       3          2 2  2 2           4            3  3
+--R           (- 3840A b c  - 2880B b c )d e  + (2560A c  + 6400B b c )d e
+--R         + 
+--R                    4 4
+--R           - 3840B c d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                 2   3               2         2     2
+--R           240A b c e  + (- 1280A b c  - 560B b c)d e
+--R         + 
+--R                   3            2  2           3 3
+--R           (1280A c  + 2240B b c )d e - 1920B c d
+--R      *
+--R          +-----------+ +-+ +-+             (b e - 2c d)x - b d
+--R         \|- b e + c d \|c \|d atanh(--------------------------------)
+--R                                                         +----------+
+--R                                       +-----------+ +-+ |   2
+--R                                     2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                 2   3               2          2     2
+--R           480A b c e  + (- 2560A b c  - 1120B b c)d e
+--R         + 
+--R                   3            2  2           3 3
+--R           (2560A c  + 4480B b c )d e - 3840B c d
+--R      *
+--R                                    +----------+
+--R              +------------+        |   2
+--R          +-+ |           2       d\|c x  + b x
+--R         \|c \|b d e - c d  atan(----------------)
+--R                                   +------------+
+--R                                   |           2
+--R                                 x\|b d e - c d
+--R  /
+--R           7 +-+
+--R     128c e \|c
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 461
+
+)clear all
+
+--S 462 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)/(d+e*x)^4
+--R 
+--R
+--R                                                                  +----------+
+--R            2 5       2           4                2  3      2 2  |   2
+--R        (B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|c x  + b x
+--R   (1)  ----------------------------------------------------------------------
+--R                         4 4       3 3     2 2 2     3       4
+--R                        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 1457
+r0:=-5/12*(4*B*d*(2*c*d-b*e)-A*e*(4*c*d-b*e)+e*(4*B*c*d-b*B*e-2*A*c*e)*x)*_
+     (b*x+c*x^2)^(3/2)/(e^4*(d+e*x)^2)+1/3*(2*B*d-A*e+B*e*x)*_
+     (b*x+c*x^2)^(5/2)/(e^2*(d+e*x)^3)+5/8*(2*A*c*e*(16*c^2*d^2-_
+     16*b*c*d*e+3*b^2*e^2)-B*(64*c^3*d^3-80*b*c^2*d^2*e+24*b^2*c*d*e^2-_
+     b^3*e^3))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(e^7*sqrt(c))+5/16*(B*d*_
+     (64*c^3*d^3-112*b*c^2*d^2*e+56*b^2*c*d*e^2-7*b^3*e^3)-A*e*(32*c^3*d^3-_
+     48*b*c^2*d^2*e+18*b^2*c*d*e^2-b^3*e^3))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(e^7*sqrt(d)*sqrt(c*d-b*e))-_
+     5/8*(A*e*(16*c^2*d^2-12*b*c*d*e+b^2*e^2)-2*B*d*(16*c^2*d^2-_
+     16*b*c*d*e+3*b^2*e^2)+e*(4*A*c*e*(2*c*d-b*e)-B*(16*c^2*d^2-12*b*c*d*e+_
+     b^2*e^2))*x)*sqrt(b*x+c*x^2)/(e^6*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                      2         3  6              2         2     5
+--R               (180A b c + 30B b )e  + (- 960A b c  - 720B b c)d e
+--R             + 
+--R                      3            2  2 4          3 3 3
+--R               (960A c  + 2400B b c )d e  - 1920B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      2         3    5               2          2   2 4
+--R               (540A b c + 90B b )d e  + (- 2880A b c  - 2160B b c)d e
+--R             + 
+--R                       3            2  3 3          3 4 2
+--R               (2880A c  + 7200B b c )d e  - 5760B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      2         3  2 4               2          2   3 3
+--R               (540A b c + 90B b )d e  + (- 2880A b c  - 2160B b c)d e
+--R             + 
+--R                       3            2  4 2          3 5
+--R               (2880A c  + 7200B b c )d e  - 5760B c d e
+--R          *
+--R             x
+--R         + 
+--R                  2         3  3 3              2         2   4 2
+--R           (180A b c + 30B b )d e  + (- 960A b c  - 720B b c)d e
+--R         + 
+--R                  3            2  5           3 6
+--R           (960A c  + 2400B b c )d e - 1920B c d
+--R      *
+--R                                       +-+
+--R          +-----------+ +-+          x\|c
+--R         \|- b e + c d \|d atanh(-------------)
+--R                                  +----------+
+--R                                  |   2
+--R                                 \|c x  + b x
+--R     + 
+--R                      3 7          2          3    6
+--R               - 15A b e  + (270A b c + 105B b )d e
+--R             + 
+--R                          2         2   2 5          3            2  3 4
+--R               (- 720A b c  - 840B b c)d e  + (480A c  + 1680B b c )d e
+--R             + 
+--R                       3 4 3
+--R               - 960B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      3   6          2          3  2 5
+--R               - 45A b d e  + (810A b c + 315B b )d e
+--R             + 
+--R                           2          2   3 4           3            2  4 3
+--R               (- 2160A b c  - 2520B b c)d e  + (1440A c  + 5040B b c )d e
+--R             + 
+--R                        3 5 2
+--R               - 2880B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3 2 5          2          3  3 4
+--R               - 45A b d e  + (810A b c + 315B b )d e
+--R             + 
+--R                           2          2   4 3           3            2  5 2
+--R               (- 2160A b c  - 2520B b c)d e  + (1440A c  + 5040B b c )d e
+--R             + 
+--R                        3 6
+--R               - 2880B c d e
+--R          *
+--R             x
+--R         + 
+--R                  3 3 4          2          3  4 3
+--R           - 15A b d e  + (270A b c + 105B b )d e
+--R         + 
+--R                      2         2   5 2          3            2  6          3 7
+--R           (- 720A b c  - 840B b c)d e  + (480A c  + 1680B b c )d e - 960B c d
+--R      *
+--R          +-+             (b e - 2c d)x - b d
+--R         \|c atanh(--------------------------------)
+--R                                       +----------+
+--R                     +-----------+ +-+ |   2
+--R                   2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                2 6 5          2            6        2   5  4
+--R           16B c e x  + ((24A c  + 52B b c)e  - 48B c d e )x
+--R         + 
+--R                             2  6            2               5         2 2 4  3
+--R           ((108A b c + 66B b )e  + (- 120A c  - 276B b c)d e  + 240B c d e )x
+--R         + 
+--R                      2 6                     2    5
+--R               - 66A b e  + (700A b c + 372B b )d e
+--R             + 
+--R                        2              2 4          2 3 3
+--R               (- 880A c  - 1840B b c)d e  + 1760B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      2   5                     2  2 4
+--R               - 80A b d e  + (920A b c + 470B b )d e
+--R             + 
+--R                         2              3 3          2 4 2
+--R               (- 1200A c  - 2440B b c)d e  + 2400B c d e
+--R          *
+--R             x
+--R         + 
+--R                  2 2 4                     2  3 3            2             4 2
+--R           - 30A b d e  + (360A b c + 180B b )d e  + (- 480A c  - 960B b c)d e
+--R         + 
+--R                 2 5
+--R           960B c d e
+--R      *
+--R                                +----------+
+--R          +-----------+ +-+ +-+ |   2
+--R         \|- b e + c d \|c \|d \|c x  + b x
+--R  /
+--R         10 3         9 2       2 8       3 7  +-----------+ +-+ +-+
+--R     (48e  x  + 144d e x  + 144d e x + 48d e )\|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       2         3  6              2         2     5
+--R                 (90A b c + 15B b )e  + (- 480A b c  - 360B b c)d e
+--R               + 
+--R                        3            2  2 4         3 3 3
+--R                 (480A c  + 1200B b c )d e  - 960B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2         3    5               2          2   2 4
+--R                 (270A b c + 45B b )d e  + (- 1440A b c  - 1080B b c)d e
+--R               + 
+--R                         3            2  3 3          3 4 2
+--R                 (1440A c  + 3600B b c )d e  - 2880B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2         3  2 4               2          2   3 3
+--R                 (270A b c + 45B b )d e  + (- 1440A b c  - 1080B b c)d e
+--R               + 
+--R                         3            2  4 2          3 5
+--R                 (1440A c  + 3600B b c )d e  - 2880B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2         3  3 3              2         2   4 2
+--R             (90A b c + 15B b )d e  + (- 480A b c  - 360B b c)d e
+--R           + 
+--R                    3            2  5          3 6
+--R             (480A c  + 1200B b c )d e - 960B c d
+--R        *
+--R            +--------------+       +----------+
+--R            |             2        |   2                     +-+
+--R           \|- b d e + c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                        3 7          2          3    6
+--R                 - 15A b e  + (270A b c + 105B b )d e
+--R               + 
+--R                            2         2   2 5          3            2  3 4
+--R                 (- 720A b c  - 840B b c)d e  + (480A c  + 1680B b c )d e
+--R               + 
+--R                         3 4 3
+--R                 - 960B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        3   6          2          3  2 5
+--R                 - 45A b d e  + (810A b c + 315B b )d e
+--R               + 
+--R                             2          2   3 4           3            2  4 3
+--R                 (- 2160A b c  - 2520B b c)d e  + (1440A c  + 5040B b c )d e
+--R               + 
+--R                          3 5 2
+--R                 - 2880B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 5          2          3  3 4
+--R                 - 45A b d e  + (810A b c + 315B b )d e
+--R               + 
+--R                             2          2   4 3           3            2  5 2
+--R                 (- 2160A b c  - 2520B b c)d e  + (1440A c  + 5040B b c )d e
+--R               + 
+--R                          3 6
+--R                 - 2880B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 4          2          3  4 3
+--R             - 15A b d e  + (270A b c + 105B b )d e
+--R           + 
+--R                      2         2   5 2          3            2  6          3 7
+--R           (- 720A b c  - 840B b c)d e  + (480A c  + 1680B b c )d e - 960B c d
+--R        *
+--R            +-+
+--R           \|c
+--R        *
+--R           log
+--R                                   +----------+
+--R                                2  |   2
+--R                  (2b d e - 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                  2 6 5          2            6        2   5  4
+--R             16B c e x  + ((24A c  + 52B b c)e  - 48B c d e )x
+--R           + 
+--R                                    2  6            2               5
+--R                   (108A b c + 66B b )e  + (- 120A c  - 276B b c)d e
+--R                 + 
+--R                         2 2 4
+--R                   240B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2 6                     2    5
+--R                 - 66A b e  + (700A b c + 372B b )d e
+--R               + 
+--R                          2              2 4          2 3 3
+--R                 (- 880A c  - 1840B b c)d e  + 1760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2   5                     2  2 4
+--R                 - 80A b d e  + (920A b c + 470B b )d e
+--R               + 
+--R                           2              3 3          2 4 2
+--R                 (- 1200A c  - 2440B b c)d e  + 2400B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2 2 4                     2  3 3
+--R             - 30A b d e  + (360A b c + 180B b )d e
+--R           + 
+--R                      2             4 2         2 5
+--R             (- 480A c  - 960B b c)d e  + 960B c d e
+--R        *
+--R            +--------------+     +----------+
+--R            |             2  +-+ |   2
+--R           \|- b d e + c d  \|c \|c x  + b x
+--R    /
+--R                                                 +--------------+
+--R           10 3         9 2       2 8       3 7  |             2  +-+
+--R       (48e  x  + 144d e x  + 144d e x + 48d e )\|- b d e + c d  \|c
+--R     ,
+--R
+--R                       2         3  6              2         2     5
+--R                 (90A b c + 15B b )e  + (- 480A b c  - 360B b c)d e
+--R               + 
+--R                        3            2  2 4         3 3 3
+--R                 (480A c  + 1200B b c )d e  - 960B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2         3    5               2          2   2 4
+--R                 (270A b c + 45B b )d e  + (- 1440A b c  - 1080B b c)d e
+--R               + 
+--R                         3            2  3 3          3 4 2
+--R                 (1440A c  + 3600B b c )d e  - 2880B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2         3  2 4               2          2   3 3
+--R                 (270A b c + 45B b )d e  + (- 1440A b c  - 1080B b c)d e
+--R               + 
+--R                         3            2  4 2          3 5
+--R                 (1440A c  + 3600B b c )d e  - 2880B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2         3  3 3              2         2   4 2
+--R             (90A b c + 15B b )d e  + (- 480A b c  - 360B b c)d e
+--R           + 
+--R                    3            2  5          3 6
+--R             (480A c  + 1200B b c )d e - 960B c d
+--R        *
+--R            +------------+       +----------+
+--R            |           2        |   2                     +-+
+--R           \|b d e - c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                        3 7          2          3    6
+--R                 - 30A b e  + (540A b c + 210B b )d e
+--R               + 
+--R                             2          2   2 5          3            2  3 4
+--R                 (- 1440A b c  - 1680B b c)d e  + (960A c  + 3360B b c )d e
+--R               + 
+--R                          3 4 3
+--R                 - 1920B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        3   6           2          3  2 5
+--R                 - 90A b d e  + (1620A b c + 630B b )d e
+--R               + 
+--R                             2          2   3 4           3             2  4 3
+--R                 (- 4320A b c  - 5040B b c)d e  + (2880A c  + 10080B b c )d e
+--R               + 
+--R                          3 5 2
+--R                 - 5760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 5           2          3  3 4
+--R                 - 90A b d e  + (1620A b c + 630B b )d e
+--R               + 
+--R                             2          2   4 3           3             2  5 2
+--R                 (- 4320A b c  - 5040B b c)d e  + (2880A c  + 10080B b c )d e
+--R               + 
+--R                          3 6
+--R                 - 5760B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 4          2          3  4 3
+--R             - 30A b d e  + (540A b c + 210B b )d e
+--R           + 
+--R                         2          2   5 2          3            2  6
+--R             (- 1440A b c  - 1680B b c)d e  + (960A c  + 3360B b c )d e
+--R           + 
+--R                      3 7
+--R             - 1920B c d
+--R        *
+--R                     +------------+ +----------+
+--R                     |           2  |   2
+--R            +-+     \|b d e - c d  \|c x  + b x
+--R           \|c atan(----------------------------)
+--R                            (b e - c d)x
+--R       + 
+--R                  2 6 5          2            6        2   5  4
+--R             16B c e x  + ((24A c  + 52B b c)e  - 48B c d e )x
+--R           + 
+--R                                    2  6            2               5
+--R                   (108A b c + 66B b )e  + (- 120A c  - 276B b c)d e
+--R                 + 
+--R                         2 2 4
+--R                   240B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2 6                     2    5
+--R                 - 66A b e  + (700A b c + 372B b )d e
+--R               + 
+--R                          2              2 4          2 3 3
+--R                 (- 880A c  - 1840B b c)d e  + 1760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2   5                     2  2 4
+--R                 - 80A b d e  + (920A b c + 470B b )d e
+--R               + 
+--R                           2              3 3          2 4 2
+--R                 (- 1200A c  - 2440B b c)d e  + 2400B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2 2 4                     2  3 3
+--R             - 30A b d e  + (360A b c + 180B b )d e
+--R           + 
+--R                      2             4 2         2 5
+--R             (- 480A c  - 960B b c)d e  + 960B c d e
+--R        *
+--R                +------------+ +----------+
+--R            +-+ |           2  |   2
+--R           \|c \|b d e - c d  \|c x  + b x
+--R    /
+--R                                                     +------------+
+--R           10 3         9 2       2 8       3 7  +-+ |           2
+--R       (48e  x  + 144d e x  + 144d e x + 48d e )\|c \|b d e - c d
+--R     ,
+--R
+--R                        3 7          2          3    6
+--R                 - 15A b e  + (270A b c + 105B b )d e
+--R               + 
+--R                            2         2   2 5          3            2  3 4
+--R                 (- 720A b c  - 840B b c)d e  + (480A c  + 1680B b c )d e
+--R               + 
+--R                         3 4 3
+--R                 - 960B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        3   6          2          3  2 5
+--R                 - 45A b d e  + (810A b c + 315B b )d e
+--R               + 
+--R                             2          2   3 4           3            2  4 3
+--R                 (- 2160A b c  - 2520B b c)d e  + (1440A c  + 5040B b c )d e
+--R               + 
+--R                          3 5 2
+--R                 - 2880B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 5          2          3  3 4
+--R                 - 45A b d e  + (810A b c + 315B b )d e
+--R               + 
+--R                             2          2   4 3           3            2  5 2
+--R                 (- 2160A b c  - 2520B b c)d e  + (1440A c  + 5040B b c )d e
+--R               + 
+--R                          3 6
+--R                 - 2880B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 4          2          3  4 3
+--R             - 15A b d e  + (270A b c + 105B b )d e
+--R           + 
+--R                      2         2   5 2          3            2  6          3 7
+--R           (- 720A b c  - 840B b c)d e  + (480A c  + 1680B b c )d e - 960B c d
+--R        *
+--R            +---+
+--R           \|- c
+--R        *
+--R           log
+--R                                   +----------+
+--R                                2  |   2
+--R                  (2b d e - 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                        2         3  6              2         2     5
+--R                 (180A b c + 30B b )e  + (- 960A b c  - 720B b c)d e
+--R               + 
+--R                        3            2  2 4          3 3 3
+--R                 (960A c  + 2400B b c )d e  - 1920B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2         3    5               2          2   2 4
+--R                 (540A b c + 90B b )d e  + (- 2880A b c  - 2160B b c)d e
+--R               + 
+--R                         3            2  3 3          3 4 2
+--R                 (2880A c  + 7200B b c )d e  - 5760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2         3  2 4               2          2   3 3
+--R                 (540A b c + 90B b )d e  + (- 2880A b c  - 2160B b c)d e
+--R               + 
+--R                         3            2  4 2          3 5
+--R                 (2880A c  + 7200B b c )d e  - 5760B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2         3  3 3              2         2   4 2
+--R             (180A b c + 30B b )d e  + (- 960A b c  - 720B b c)d e
+--R           + 
+--R                    3            2  5           3 6
+--R             (960A c  + 2400B b c )d e - 1920B c d
+--R        *
+--R                                        +----------+
+--R            +--------------+      +---+ |   2
+--R            |             2      \|- c \|c x  + b x
+--R           \|- b d e + c d  atan(-------------------)
+--R                                         c x
+--R       + 
+--R                  2 6 5          2            6        2   5  4
+--R             16B c e x  + ((24A c  + 52B b c)e  - 48B c d e )x
+--R           + 
+--R                                    2  6            2               5
+--R                   (108A b c + 66B b )e  + (- 120A c  - 276B b c)d e
+--R                 + 
+--R                         2 2 4
+--R                   240B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2 6                     2    5
+--R                 - 66A b e  + (700A b c + 372B b )d e
+--R               + 
+--R                          2              2 4          2 3 3
+--R                 (- 880A c  - 1840B b c)d e  + 1760B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2   5                     2  2 4
+--R                 - 80A b d e  + (920A b c + 470B b )d e
+--R               + 
+--R                           2              3 3          2 4 2
+--R                 (- 1200A c  - 2440B b c)d e  + 2400B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2 2 4                     2  3 3
+--R             - 30A b d e  + (360A b c + 180B b )d e
+--R           + 
+--R                      2             4 2         2 5
+--R             (- 480A c  - 960B b c)d e  + 960B c d e
+--R        *
+--R            +--------------+       +----------+
+--R            |             2  +---+ |   2
+--R           \|- b d e + c d  \|- c \|c x  + b x
+--R    /
+--R                                                 +--------------+
+--R           10 3         9 2       2 8       3 7  |             2  +---+
+--R       (48e  x  + 144d e x  + 144d e x + 48d e )\|- b d e + c d  \|- c
+--R     ,
+--R
+--R                        3 7          2          3    6
+--R                 - 15A b e  + (270A b c + 105B b )d e
+--R               + 
+--R                            2         2   2 5          3            2  3 4
+--R                 (- 720A b c  - 840B b c)d e  + (480A c  + 1680B b c )d e
+--R               + 
+--R                         3 4 3
+--R                 - 960B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        3   6          2          3  2 5
+--R                 - 45A b d e  + (810A b c + 315B b )d e
+--R               + 
+--R                             2          2   3 4           3            2  4 3
+--R                 (- 2160A b c  - 2520B b c)d e  + (1440A c  + 5040B b c )d e
+--R               + 
+--R                          3 5 2
+--R                 - 2880B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 5          2          3  3 4
+--R                 - 45A b d e  + (810A b c + 315B b )d e
+--R               + 
+--R                             2          2   4 3           3            2  5 2
+--R                 (- 2160A b c  - 2520B b c)d e  + (1440A c  + 5040B b c )d e
+--R               + 
+--R                          3 6
+--R                 - 2880B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 4          2          3  4 3
+--R             - 15A b d e  + (270A b c + 105B b )d e
+--R           + 
+--R                      2         2   5 2          3            2  6          3 7
+--R           (- 720A b c  - 840B b c)d e  + (480A c  + 1680B b c )d e - 960B c d
+--R        *
+--R                       +------------+ +----------+
+--R                       |           2  |   2
+--R            +---+     \|b d e - c d  \|c x  + b x
+--R           \|- c atan(----------------------------)
+--R                              (b e - c d)x
+--R       + 
+--R                       2         3  6              2         2     5
+--R                 (90A b c + 15B b )e  + (- 480A b c  - 360B b c)d e
+--R               + 
+--R                        3            2  2 4         3 3 3
+--R                 (480A c  + 1200B b c )d e  - 960B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2         3    5               2          2   2 4
+--R                 (270A b c + 45B b )d e  + (- 1440A b c  - 1080B b c)d e
+--R               + 
+--R                         3            2  3 3          3 4 2
+--R                 (1440A c  + 3600B b c )d e  - 2880B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2         3  2 4               2          2   3 3
+--R                 (270A b c + 45B b )d e  + (- 1440A b c  - 1080B b c)d e
+--R               + 
+--R                         3            2  4 2          3 5
+--R                 (1440A c  + 3600B b c )d e  - 2880B c d e
+--R            *
+--R               x
+--R           + 
+--R                   2         3  3 3              2         2   4 2
+--R             (90A b c + 15B b )d e  + (- 480A b c  - 360B b c)d e
+--R           + 
+--R                    3            2  5          3 6
+--R             (480A c  + 1200B b c )d e - 960B c d
+--R        *
+--R                                      +----------+
+--R            +------------+      +---+ |   2
+--R            |           2      \|- c \|c x  + b x
+--R           \|b d e - c d  atan(-------------------)
+--R                                       c x
+--R       + 
+--R                 2 6 5          2            6        2   5  4
+--R             8B c e x  + ((12A c  + 26B b c)e  - 24B c d e )x
+--R           + 
+--R                              2  6           2               5         2 2 4  3
+--R             ((54A b c + 33B b )e  + (- 60A c  - 138B b c)d e  + 120B c d e )x
+--R           + 
+--R                        2 6                     2    5
+--R                 - 33A b e  + (350A b c + 186B b )d e
+--R               + 
+--R                          2             2 4         2 3 3
+--R                 (- 440A c  - 920B b c)d e  + 880B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        2   5                     2  2 4
+--R                 - 40A b d e  + (460A b c + 235B b )d e
+--R               + 
+--R                          2              3 3          2 4 2
+--R                 (- 600A c  - 1220B b c)d e  + 1200B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2 2 4                    2  3 3            2             4 2
+--R             - 15A b d e  + (180A b c + 90B b )d e  + (- 240A c  - 480B b c)d e
+--R           + 
+--R                   2 5
+--R             480B c d e
+--R        *
+--R                  +------------+ +----------+
+--R            +---+ |           2  |   2
+--R           \|- c \|b d e - c d  \|c x  + b x
+--R    /
+--R                                                     +------------+
+--R           10 3        9 2      2 8       3 7  +---+ |           2
+--R       (24e  x  + 72d e x  + 72d e x + 24d e )\|- c \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 464
+
+--S 465 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 2        3  3              2         2     2
+--R           (30A b c + 5B b )e  + (- 160A b c  - 120B b c)d e
+--R         + 
+--R                  3           2  2          3 3
+--R           (160A c  + 400B b c )d e - 320B c d
+--R      *
+--R        +--------------+                         +----------+
+--R        |             2  +-----------+ +-+       |   2                     +-+
+--R       \|- b d e + c d  \|- b e + c d \|d log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                 3 4         2         3    3              2         2   2 2
+--R           - 5A b e  + (90A b c + 35B b )d e  + (- 240A b c  - 280B b c)d e
+--R         + 
+--R                  3           2  3          3 4
+--R           (160A c  + 560B b c )d e - 320B c d
+--R      *
+--R          +-----------+ +-+ +-+
+--R         \|- b e + c d \|c \|d
+--R      *
+--R         log
+--R                                 +----------+
+--R                              2  |   2
+--R                (2b d e - 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                   2         3  3            2         2     2
+--R           (- 60A b c - 10B b )e  + (320A b c  + 240B b c)d e
+--R         + 
+--R                    3           2  2          3 3
+--R           (- 320A c  - 800B b c )d e + 640B c d
+--R      *
+--R          +--------------+                              +-+
+--R          |             2  +-----------+ +-+          x\|c
+--R         \|- b d e + c d  \|- b e + c d \|d atanh(-------------)
+--R                                                   +----------+
+--R                                                   |   2
+--R                                                  \|c x  + b x
+--R     + 
+--R               3 4           2         3    3            2         2   2 2
+--R           5A b e  + (- 90A b c - 35B b )d e  + (240A b c  + 280B b c)d e
+--R         + 
+--R                    3           2  3          3 4
+--R           (- 160A c  - 560B b c )d e + 320B c d
+--R      *
+--R          +--------------+
+--R          |             2  +-+             (b e - 2c d)x - b d
+--R         \|- b d e + c d  \|c atanh(--------------------------------)
+--R                                                        +----------+
+--R                                      +-----------+ +-+ |   2
+--R                                    2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R          +--------------+
+--R        7 |             2  +-----------+ +-+ +-+
+--R     16e \|- b d e + c d  \|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 2        3  3              2         2     2
+--R           (30A b c + 5B b )e  + (- 160A b c  - 120B b c)d e
+--R         + 
+--R                  3           2  2          3 3
+--R           (160A c  + 400B b c )d e - 320B c d
+--R      *
+--R                            +------------+       +----------+
+--R          +-----------+ +-+ |           2        |   2                     +-+
+--R         \|- b e + c d \|d \|b d e - c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                   2         3  3            2         2     2
+--R           (- 60A b c - 10B b )e  + (320A b c  + 240B b c)d e
+--R         + 
+--R                    3           2  2          3 3
+--R           (- 320A c  - 800B b c )d e + 640B c d
+--R      *
+--R                            +------------+            +-+
+--R          +-----------+ +-+ |           2           x\|c
+--R         \|- b e + c d \|d \|b d e - c d  atanh(-------------)
+--R                                                 +----------+
+--R                                                 |   2
+--R                                                \|c x  + b x
+--R     + 
+--R               3 4           2         3    3            2         2   2 2
+--R           5A b e  + (- 90A b c - 35B b )d e  + (240A b c  + 280B b c)d e
+--R         + 
+--R                    3           2  3          3 4
+--R           (- 160A c  - 560B b c )d e + 320B c d
+--R      *
+--R              +------------+
+--R          +-+ |           2              (b e - 2c d)x - b d
+--R         \|c \|b d e - c d  atanh(--------------------------------)
+--R                                                      +----------+
+--R                                    +-----------+ +-+ |   2
+--R                                  2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                  3 4          2         3    3              2         2   2 2
+--R           - 10A b e  + (180A b c + 70B b )d e  + (- 480A b c  - 560B b c)d e
+--R         + 
+--R                  3            2  3          3 4
+--R           (320A c  + 1120B b c )d e - 640B c d
+--R      *
+--R                                     +------------+ +----------+
+--R                                     |           2  |   2
+--R          +-----------+ +-+ +-+     \|b d e - c d  \|c x  + b x
+--R         \|- b e + c d \|c \|d atan(----------------------------)
+--R                                            (b e - c d)x
+--R  /
+--R                                +------------+
+--R        7 +-----------+ +-+ +-+ |           2
+--R     16e \|- b e + c d \|c \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)/(d+e*x)^5
+--R 
+--R
+--R                                                                  +----------+
+--R            2 5       2           4                2  3      2 2  |   2
+--R        (B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|c x  + b x
+--R   (1)  ----------------------------------------------------------------------
+--R                   5 5       4 4      2 3 3      3 2 2     4       5
+--R                  e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 1457
+r0:=-5/32*(A*e*(16*c^2*d^2-16*b*c*d*e+b^2*e^2)-B*d*(48*c^2*d^2-64*b*c*d*e+_
+     17*b^2*e^2))*(b*x+c*x^2)^(3/2)/(d*e^4*(c*d-b*e)*(d+e*x)^2)-5/24*_
+     (B*d*(24*c*d-11*b*e)-A*e*(8*c*d-b*e)+6*e*(3*B*c*d-b*B*e-A*c*e)*x)*_
+     (b*x+c*x^2)^(3/2)/(e^4*(d+e*x)^3)+1/4*(3*B*d-A*e+2*B*e*x)*(b*x+_
+     c*x^2)^(5/2)/(e^2*(d+e*x)^4)+5/128*(A*e*(128*c^4*d^4-256*b*c^3*d^3*e+_
+     144*b^2*c^2*d^2*e^2-16*b^3*c*d*e^3-b^4*e^4)-B*d*(384*c^4*d^4-_
+     896*b*c^3*d^3*e+672*b^2*c^2*d^2*e^2-168*b^3*c*d*e^3+7*b^4*e^4))*_
+     atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+_
+     c*x^2)))/(d^(3/2)*e^7*(c*d-b*e)^(3/2))-5/4*(4*A*c*e*(2*c*d-b*e)-_
+     B*(24*c^2*d^2-20*b*c*d*e+3*b^2*e^2))*atanh(x*sqrt(c)/sqrt(b*x+_
+     c*x^2))*sqrt(c)/e^7-5/64*(B*d*(192*c^3*d^3-304*b*c^2*d^2*e+120*_
+     b^2*c*d*e^2-7*b^3*e^3)-A*e*(64*c^3*d^3-80*b*c^2*d^2*e+16*b^2*c*d*_
+     e^2+b^3*e^3)-2*c*e*(A*e*(16*c^2*d^2-16*b*c*d*e+b^2*e^2)-B*d*(48*c^2*_
+     d^2-64*b*c*d*e+17*b^2*e^2))*x)*sqrt(b*x+c*x^2)/(d*e^6*(c*d-b*e)*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                       2           3    7               2           2   2 6
+--R               (1920A b c + 1440B b )d e  + (- 5760A b c  - 11040B b c)d e
+--R             + 
+--R                       3             2  3 5           3 4 4
+--R               (3840A c  + 21120B b c )d e  - 11520B c d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       2           3  2 6                2           2   3 5
+--R               (7680A b c + 5760B b )d e  + (- 23040A b c  - 44160B b c)d e
+--R             + 
+--R                        3             2  4 4           3 5 3
+--R               (15360A c  + 84480B b c )d e  - 46080B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                        2           3  3 5                2           2   4 4
+--R               (11520A b c + 8640B b )d e  + (- 34560A b c  - 66240B b c)d e
+--R             + 
+--R                        3              2  5 3           3 6 2
+--R               (23040A c  + 126720B b c )d e  - 69120B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       2           3  4 4                2           2   5 3
+--R               (7680A b c + 5760B b )d e  + (- 23040A b c  - 44160B b c)d e
+--R             + 
+--R                        3             2  6 2           3 7
+--R               (15360A c  + 84480B b c )d e  - 46080B c d e
+--R          *
+--R             x
+--R         + 
+--R                   2           3  5 3               2           2   6 2
+--R           (1920A b c + 1440B b )d e  + (- 5760A b c  - 11040B b c)d e
+--R         + 
+--R                   3             2  7            3 8
+--R           (3840A c  + 21120B b c )d e - 11520B c d
+--R      *
+--R                                           +-+
+--R          +-----------+ +-+ +-+          x\|c
+--R         \|- b e + c d \|c \|d atanh(-------------)
+--R                                      +----------+
+--R                                      |   2
+--R                                     \|c x  + b x
+--R     + 
+--R                      4 9            3          4    8
+--R               - 15A b e  + (- 240A b c - 105B b )d e
+--R             + 
+--R                       2 2          3   2 7               3           2 2  3 6
+--R               (2160A b c  + 2520B b c)d e  + (- 3840A b c  - 10080B b c )d e
+--R             + 
+--R                       4             3  4 5          4 5 4
+--R               (1920A c  + 13440B b c )d e  - 5760B c d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      4   8            3          4  2 7
+--R               - 60A b d e  + (- 960A b c - 420B b )d e
+--R             + 
+--R                       2 2           3   3 6                3           2 2  4 5
+--R               (8640A b c  + 10080B b c)d e  + (- 15360A b c  - 40320B b c )d e
+--R             + 
+--R                       4             3  5 4           4 6 3
+--R               (7680A c  + 53760B b c )d e  - 23040B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      4 2 7             3          4  3 6
+--R               - 90A b d e  + (- 1440A b c - 630B b )d e
+--R             + 
+--R                        2 2           3   4 5
+--R               (12960A b c  + 15120B b c)d e
+--R             + 
+--R                            3           2 2  5 4            4             3  6 3
+--R               (- 23040A b c  - 60480B b c )d e  + (11520A c  + 80640B b c )d e
+--R             + 
+--R                         4 7 2
+--R               - 34560B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      4 3 6            3          4  4 5
+--R               - 60A b d e  + (- 960A b c - 420B b )d e
+--R             + 
+--R                       2 2           3   5 4                3           2 2  6 3
+--R               (8640A b c  + 10080B b c)d e  + (- 15360A b c  - 40320B b c )d e
+--R             + 
+--R                       4             3  7 2           4 8
+--R               (7680A c  + 53760B b c )d e  - 23040B c d e
+--R          *
+--R             x
+--R         + 
+--R                  4 4 5            3          4  5 4
+--R           - 15A b d e  + (- 240A b c - 105B b )d e
+--R         + 
+--R                   2 2          3   6 3               3           2 2  7 2
+--R           (2160A b c  + 2520B b c)d e  + (- 3840A b c  - 10080B b c )d e
+--R         + 
+--R                   4             3  8           4 9
+--R           (1920A c  + 13440B b c )d e - 5760B c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                    2   7         3 2 6  5
+--R           (192B b c d e  - 192B c d e )x
+--R         + 
+--R                        2         2     7            3            2  2 6
+--R               (384A b c  + 864B b c)d e  + (- 384A c  - 2016B b c )d e
+--R             + 
+--R                      3 3 5
+--R               1152B c d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    3 8             2          3    7
+--R               30A b e  + (- 1292A b c - 558B b )d e
+--R             + 
+--R                         2          2   2 6             3             2  3 5
+--R               (5232A b c  + 8284B b c)d e  + (- 4000A c  - 19696B b c )d e
+--R             + 
+--R                       3 4 4
+--R               12000B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       3   7             2           3  2 6
+--R               - 146A b d e  + (- 2264A b c - 1022B b )d e
+--R             + 
+--R                          2           2   3 5             3             2  4 4
+--R               (10640A b c  + 16392B b c)d e  + (- 8320A c  - 40240B b c )d e
+--R             + 
+--R                       3 5 3
+--R               24960B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       3 2 6             2          3  3 5
+--R               - 110A b d e  + (- 1740A b c - 770B b )d e
+--R             + 
+--R                         2           2   4 4             3             2  5 3
+--R               (8480A b c  + 12860B b c)d e  + (- 6720A c  - 32160B b c )d e
+--R             + 
+--R                       3 6 2
+--R               20160B c d e
+--R          *
+--R             x
+--R         + 
+--R                  3 3 5            2          3  4 4
+--R           - 30A b d e  + (- 480A b c - 210B b )d e
+--R         + 
+--R                     2          2   5 3             3            2  6 2
+--R           (2400A b c  + 3600B b c)d e  + (- 1920A c  - 9120B b c )d e
+--R         + 
+--R                  3 7
+--R           5760B c d e
+--R      *
+--R                            +----------+
+--R          +-----------+ +-+ |   2
+--R         \|- b e + c d \|d \|c x  + b x
+--R  /
+--R                  12         2 11  4           2 11          3 10  3
+--R         (384b d e   - 384c d e  )x  + (1536b d e   - 1536c d e  )x
+--R       + 
+--R                 3 10          4 9  2           4 9          5 8           5 8
+--R         (2304b d e   - 2304c d e )x  + (1536b d e  - 1536c d e )x + 384b d e
+--R       + 
+--R                 6 7
+--R         - 384c d e
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        2          3    7               2          2   2 6
+--R                 (960A b c + 720B b )d e  + (- 2880A b c  - 5520B b c)d e
+--R               + 
+--R                         3             2  3 5          3 4 4
+--R                 (1920A c  + 10560B b c )d e  - 5760B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         2           3  2 6                2           2   3 5
+--R                 (3840A b c + 2880B b )d e  + (- 11520A b c  - 22080B b c)d e
+--R               + 
+--R                         3             2  4 4           3 5 3
+--R                 (7680A c  + 42240B b c )d e  - 23040B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         2           3  3 5                2           2   4 4
+--R                 (5760A b c + 4320B b )d e  + (- 17280A b c  - 33120B b c)d e
+--R               + 
+--R                          3             2  5 3           3 6 2
+--R                 (11520A c  + 63360B b c )d e  - 34560B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         2           3  4 4                2           2   5 3
+--R                 (3840A b c + 2880B b )d e  + (- 11520A b c  - 22080B b c)d e
+--R               + 
+--R                         3             2  6 2           3 7
+--R                 (7680A c  + 42240B b c )d e  - 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2          3  5 3               2          2   6 2
+--R             (960A b c + 720B b )d e  + (- 2880A b c  - 5520B b c)d e
+--R           + 
+--R                     3             2  7           3 8
+--R             (1920A c  + 10560B b c )d e - 5760B c d
+--R        *
+--R            +--------------+              +----------+
+--R            |             2  +-+      +-+ |   2
+--R           \|- b d e + c d  \|c log(2\|c \|c x  + b x  + 2c x + b)
+--R       + 
+--R                      4 9          3          4    8
+--R                 15A b e  + (240A b c + 105B b )d e
+--R               + 
+--R                           2 2          3   2 7             3           2 2  3 6
+--R                 (- 2160A b c  - 2520B b c)d e  + (3840A b c  + 10080B b c )d e
+--R               + 
+--R                           4             3  4 5          4 5 4
+--R                 (- 1920A c  - 13440B b c )d e  + 5760B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      4   8          3          4  2 7
+--R                 60A b d e  + (960A b c + 420B b )d e
+--R               + 
+--R                           2 2           3   3 6
+--R                 (- 8640A b c  - 10080B b c)d e
+--R               + 
+--R                            3           2 2  4 5
+--R                 (15360A b c  + 40320B b c )d e
+--R               + 
+--R                           4             3  5 4           4 6 3
+--R                 (- 7680A c  - 53760B b c )d e  + 23040B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4 2 7           3          4  3 6
+--R                 90A b d e  + (1440A b c + 630B b )d e
+--R               + 
+--R                            2 2           3   4 5
+--R                 (- 12960A b c  - 15120B b c)d e
+--R               + 
+--R                            3           2 2  5 4
+--R                 (23040A b c  + 60480B b c )d e
+--R               + 
+--R                            4             3  6 3           4 7 2
+--R                 (- 11520A c  - 80640B b c )d e  + 34560B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      4 3 6          3          4  4 5
+--R                 60A b d e  + (960A b c + 420B b )d e
+--R               + 
+--R                           2 2           3   5 4
+--R                 (- 8640A b c  - 10080B b c)d e
+--R               + 
+--R                            3           2 2  6 3
+--R                 (15360A b c  + 40320B b c )d e
+--R               + 
+--R                           4             3  7 2           4 8
+--R                 (- 7680A c  - 53760B b c )d e  + 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                  4 4 5          3          4  5 4
+--R             15A b d e  + (240A b c + 105B b )d e
+--R           + 
+--R                       2 2          3   6 3             3           2 2  7 2
+--R             (- 2160A b c  - 2520B b c)d e  + (3840A b c  + 10080B b c )d e
+--R           + 
+--R                       4             3  8           4 9
+--R             (- 1920A c  - 13440B b c )d e + 5760B c d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                      2   7         3 2 6  5
+--R             (192B b c d e  - 192B c d e )x
+--R           + 
+--R                          2         2     7            3            2  2 6
+--R                 (384A b c  + 864B b c)d e  + (- 384A c  - 2016B b c )d e
+--R               + 
+--R                        3 3 5
+--R                 1152B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      3 8             2          3    7
+--R                 30A b e  + (- 1292A b c - 558B b )d e
+--R               + 
+--R                           2          2   2 6             3             2  3 5
+--R                 (5232A b c  + 8284B b c)d e  + (- 4000A c  - 19696B b c )d e
+--R               + 
+--R                         3 4 4
+--R                 12000B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         3   7             2           3  2 6
+--R                 - 146A b d e  + (- 2264A b c - 1022B b )d e
+--R               + 
+--R                            2           2   3 5             3             2  4 4
+--R                 (10640A b c  + 16392B b c)d e  + (- 8320A c  - 40240B b c )d e
+--R               + 
+--R                         3 5 3
+--R                 24960B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         3 2 6             2          3  3 5
+--R                 - 110A b d e  + (- 1740A b c - 770B b )d e
+--R               + 
+--R                           2           2   4 4             3             2  5 3
+--R                 (8480A b c  + 12860B b c)d e  + (- 6720A c  - 32160B b c )d e
+--R               + 
+--R                         3 6 2
+--R                 20160B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 5            2          3  4 4
+--R             - 30A b d e  + (- 480A b c - 210B b )d e
+--R           + 
+--R                       2          2   5 3             3            2  6 2
+--R             (2400A b c  + 3600B b c)d e  + (- 1920A c  - 9120B b c )d e
+--R           + 
+--R                    3 7
+--R             5760B c d e
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R                    12         2 11  4           2 11          3 10  3
+--R           (384b d e   - 384c d e  )x  + (1536b d e   - 1536c d e  )x
+--R         + 
+--R                   3 10          4 9  2           4 9          5 8           5 8
+--R           (2304b d e   - 2304c d e )x  + (1536b d e  - 1536c d e )x + 384b d e
+--R         + 
+--R                   6 7
+--R           - 384c d e
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                        2          3    7               2          2   2 6
+--R                 (480A b c + 360B b )d e  + (- 1440A b c  - 2760B b c)d e
+--R               + 
+--R                        3            2  3 5          3 4 4
+--R                 (960A c  + 5280B b c )d e  - 2880B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         2           3  2 6               2           2   3 5
+--R                 (1920A b c + 1440B b )d e  + (- 5760A b c  - 11040B b c)d e
+--R               + 
+--R                         3             2  4 4           3 5 3
+--R                 (3840A c  + 21120B b c )d e  - 11520B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         2           3  3 5               2           2   4 4
+--R                 (2880A b c + 2160B b )d e  + (- 8640A b c  - 16560B b c)d e
+--R               + 
+--R                         3             2  5 3           3 6 2
+--R                 (5760A c  + 31680B b c )d e  - 17280B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         2           3  4 4               2           2   5 3
+--R                 (1920A b c + 1440B b )d e  + (- 5760A b c  - 11040B b c)d e
+--R               + 
+--R                         3             2  6 2           3 7
+--R                 (3840A c  + 21120B b c )d e  - 11520B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2          3  5 3               2          2   6 2
+--R             (480A b c + 360B b )d e  + (- 1440A b c  - 2760B b c)d e
+--R           + 
+--R                    3            2  7           3 8
+--R             (960A c  + 5280B b c )d e - 2880B c d
+--R        *
+--R                +------------+          +----------+
+--R            +-+ |           2       +-+ |   2
+--R           \|c \|b d e - c d  log(2\|c \|c x  + b x  + 2c x + b)
+--R       + 
+--R                        4 9            3          4    8
+--R                 - 15A b e  + (- 240A b c - 105B b )d e
+--R               + 
+--R                         2 2          3   2 7               3           2 2  3 6
+--R                 (2160A b c  + 2520B b c)d e  + (- 3840A b c  - 10080B b c )d e
+--R               + 
+--R                         4             3  4 5          4 5 4
+--R                 (1920A c  + 13440B b c )d e  - 5760B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        4   8            3          4  2 7
+--R                 - 60A b d e  + (- 960A b c - 420B b )d e
+--R               + 
+--R                         2 2           3   3 6
+--R                 (8640A b c  + 10080B b c)d e
+--R               + 
+--R                              3           2 2  4 5
+--R                 (- 15360A b c  - 40320B b c )d e
+--R               + 
+--R                         4             3  5 4           4 6 3
+--R                 (7680A c  + 53760B b c )d e  - 23040B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4 2 7             3          4  3 6
+--R                 - 90A b d e  + (- 1440A b c - 630B b )d e
+--R               + 
+--R                          2 2           3   4 5
+--R                 (12960A b c  + 15120B b c)d e
+--R               + 
+--R                              3           2 2  5 4
+--R                 (- 23040A b c  - 60480B b c )d e
+--R               + 
+--R                          4             3  6 3           4 7 2
+--R                 (11520A c  + 80640B b c )d e  - 34560B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4 3 6            3          4  4 5
+--R                 - 60A b d e  + (- 960A b c - 420B b )d e
+--R               + 
+--R                         2 2           3   5 4
+--R                 (8640A b c  + 10080B b c)d e
+--R               + 
+--R                              3           2 2  6 3
+--R                 (- 15360A b c  - 40320B b c )d e
+--R               + 
+--R                         4             3  7 2           4 8
+--R                 (7680A c  + 53760B b c )d e  - 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                    4 4 5            3          4  5 4
+--R             - 15A b d e  + (- 240A b c - 105B b )d e
+--R           + 
+--R                     2 2          3   6 3               3           2 2  7 2
+--R             (2160A b c  + 2520B b c)d e  + (- 3840A b c  - 10080B b c )d e
+--R           + 
+--R                     4             3  8           4 9
+--R             (1920A c  + 13440B b c )d e - 5760B c d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                     2   7        3 2 6  5
+--R             (96B b c d e  - 96B c d e )x
+--R           + 
+--R                          2         2     7            3            2  2 6
+--R                 (192A b c  + 432B b c)d e  + (- 192A c  - 1008B b c )d e
+--R               + 
+--R                       3 3 5
+--R                 576B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      3 8            2          3    7
+--R                 15A b e  + (- 646A b c - 279B b )d e
+--R               + 
+--R                           2          2   2 6             3            2  3 5
+--R                 (2616A b c  + 4142B b c)d e  + (- 2000A c  - 9848B b c )d e
+--R               + 
+--R                        3 4 4
+--R                 6000B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        3   7             2          3  2 6
+--R                 - 73A b d e  + (- 1132A b c - 511B b )d e
+--R               + 
+--R                           2          2   3 5             3             2  4 4
+--R                 (5320A b c  + 8196B b c)d e  + (- 4160A c  - 20120B b c )d e
+--R               + 
+--R                         3 5 3
+--R                 12480B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 6            2          3  3 5
+--R                 - 55A b d e  + (- 870A b c - 385B b )d e
+--R               + 
+--R                           2          2   4 4             3             2  5 3
+--R                 (4240A b c  + 6430B b c)d e  + (- 3360A c  - 16080B b c )d e
+--R               + 
+--R                         3 6 2
+--R                 10080B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 5            2          3  4 4
+--R             - 15A b d e  + (- 240A b c - 105B b )d e
+--R           + 
+--R                       2          2   5 3            3            2  6 2
+--R             (1200A b c  + 1800B b c)d e  + (- 960A c  - 4560B b c )d e
+--R           + 
+--R                    3 7
+--R             2880B c d e
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R                    12         2 11  4          2 11         3 10  3
+--R           (192b d e   - 192c d e  )x  + (768b d e   - 768c d e  )x
+--R         + 
+--R                   3 10          4 9  2          4 9         5 8           5 8
+--R           (1152b d e   - 1152c d e )x  + (768b d e  - 768c d e )x + 192b d e
+--R         + 
+--R                   6 7
+--R           - 192c d e
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ,
+--R
+--R                      4 9          3          4    8
+--R                 15A b e  + (240A b c + 105B b )d e
+--R               + 
+--R                           2 2          3   2 7             3           2 2  3 6
+--R                 (- 2160A b c  - 2520B b c)d e  + (3840A b c  + 10080B b c )d e
+--R               + 
+--R                           4             3  4 5          4 5 4
+--R                 (- 1920A c  - 13440B b c )d e  + 5760B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      4   8          3          4  2 7
+--R                 60A b d e  + (960A b c + 420B b )d e
+--R               + 
+--R                           2 2           3   3 6
+--R                 (- 8640A b c  - 10080B b c)d e
+--R               + 
+--R                            3           2 2  4 5
+--R                 (15360A b c  + 40320B b c )d e
+--R               + 
+--R                           4             3  5 4           4 6 3
+--R                 (- 7680A c  - 53760B b c )d e  + 23040B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4 2 7           3          4  3 6
+--R                 90A b d e  + (1440A b c + 630B b )d e
+--R               + 
+--R                            2 2           3   4 5
+--R                 (- 12960A b c  - 15120B b c)d e
+--R               + 
+--R                            3           2 2  5 4
+--R                 (23040A b c  + 60480B b c )d e
+--R               + 
+--R                            4             3  6 3           4 7 2
+--R                 (- 11520A c  - 80640B b c )d e  + 34560B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      4 3 6          3          4  4 5
+--R                 60A b d e  + (960A b c + 420B b )d e
+--R               + 
+--R                           2 2           3   5 4
+--R                 (- 8640A b c  - 10080B b c)d e
+--R               + 
+--R                            3           2 2  6 3
+--R                 (15360A b c  + 40320B b c )d e
+--R               + 
+--R                           4             3  7 2           4 8
+--R                 (- 7680A c  - 53760B b c )d e  + 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                  4 4 5          3          4  5 4
+--R             15A b d e  + (240A b c + 105B b )d e
+--R           + 
+--R                       2 2          3   6 3             3           2 2  7 2
+--R             (- 2160A b c  - 2520B b c)d e  + (3840A b c  + 10080B b c )d e
+--R           + 
+--R                       4             3  8           4 9
+--R             (- 1920A c  - 13440B b c )d e + 5760B c d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                         2           3    7               2           2   2 6
+--R                 (1920A b c + 1440B b )d e  + (- 5760A b c  - 11040B b c)d e
+--R               + 
+--R                         3             2  3 5           3 4 4
+--R                 (3840A c  + 21120B b c )d e  - 11520B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         2           3  2 6                2           2   3 5
+--R                 (7680A b c + 5760B b )d e  + (- 23040A b c  - 44160B b c)d e
+--R               + 
+--R                          3             2  4 4           3 5 3
+--R                 (15360A c  + 84480B b c )d e  - 46080B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          2           3  3 5                2           2   4 4
+--R                 (11520A b c + 8640B b )d e  + (- 34560A b c  - 66240B b c)d e
+--R               + 
+--R                          3              2  5 3           3 6 2
+--R                 (23040A c  + 126720B b c )d e  - 69120B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         2           3  4 4                2           2   5 3
+--R                 (7680A b c + 5760B b )d e  + (- 23040A b c  - 44160B b c)d e
+--R               + 
+--R                          3             2  6 2           3 7
+--R                 (15360A c  + 84480B b c )d e  - 46080B c d e
+--R            *
+--R               x
+--R           + 
+--R                     2           3  5 3               2           2   6 2
+--R             (1920A b c + 1440B b )d e  + (- 5760A b c  - 11040B b c)d e
+--R           + 
+--R                     3             2  7            3 8
+--R             (3840A c  + 21120B b c )d e - 11520B c d
+--R        *
+--R                                        +----------+
+--R            +--------------+            |   2
+--R            |             2  +---+     \|c x  + b x
+--R           \|- b d e + c d  \|- c atan(-------------)
+--R                                            +---+
+--R                                          x\|- c
+--R       + 
+--R                      2   7         3 2 6  5
+--R             (192B b c d e  - 192B c d e )x
+--R           + 
+--R                          2         2     7            3            2  2 6
+--R                 (384A b c  + 864B b c)d e  + (- 384A c  - 2016B b c )d e
+--R               + 
+--R                        3 3 5
+--R                 1152B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      3 8             2          3    7
+--R                 30A b e  + (- 1292A b c - 558B b )d e
+--R               + 
+--R                           2          2   2 6             3             2  3 5
+--R                 (5232A b c  + 8284B b c)d e  + (- 4000A c  - 19696B b c )d e
+--R               + 
+--R                         3 4 4
+--R                 12000B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         3   7             2           3  2 6
+--R                 - 146A b d e  + (- 2264A b c - 1022B b )d e
+--R               + 
+--R                            2           2   3 5             3             2  4 4
+--R                 (10640A b c  + 16392B b c)d e  + (- 8320A c  - 40240B b c )d e
+--R               + 
+--R                         3 5 3
+--R                 24960B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         3 2 6             2          3  3 5
+--R                 - 110A b d e  + (- 1740A b c - 770B b )d e
+--R               + 
+--R                           2           2   4 4             3             2  5 3
+--R                 (8480A b c  + 12860B b c)d e  + (- 6720A c  - 32160B b c )d e
+--R               + 
+--R                         3 6 2
+--R                 20160B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 5            2          3  4 4
+--R             - 30A b d e  + (- 480A b c - 210B b )d e
+--R           + 
+--R                       2          2   5 3             3            2  6 2
+--R             (2400A b c  + 3600B b c)d e  + (- 1920A c  - 9120B b c )d e
+--R           + 
+--R                    3 7
+--R             5760B c d e
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R                    12         2 11  4           2 11          3 10  3
+--R           (384b d e   - 384c d e  )x  + (1536b d e   - 1536c d e  )x
+--R         + 
+--R                   3 10          4 9  2           4 9          5 8           5 8
+--R           (2304b d e   - 2304c d e )x  + (1536b d e  - 1536c d e )x + 384b d e
+--R         + 
+--R                   6 7
+--R           - 384c d e
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                        4 9            3          4    8
+--R                 - 15A b e  + (- 240A b c - 105B b )d e
+--R               + 
+--R                         2 2          3   2 7               3           2 2  3 6
+--R                 (2160A b c  + 2520B b c)d e  + (- 3840A b c  - 10080B b c )d e
+--R               + 
+--R                         4             3  4 5          4 5 4
+--R                 (1920A c  + 13440B b c )d e  - 5760B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        4   8            3          4  2 7
+--R                 - 60A b d e  + (- 960A b c - 420B b )d e
+--R               + 
+--R                         2 2           3   3 6
+--R                 (8640A b c  + 10080B b c)d e
+--R               + 
+--R                              3           2 2  4 5
+--R                 (- 15360A b c  - 40320B b c )d e
+--R               + 
+--R                         4             3  5 4           4 6 3
+--R                 (7680A c  + 53760B b c )d e  - 23040B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4 2 7             3          4  3 6
+--R                 - 90A b d e  + (- 1440A b c - 630B b )d e
+--R               + 
+--R                          2 2           3   4 5
+--R                 (12960A b c  + 15120B b c)d e
+--R               + 
+--R                              3           2 2  5 4
+--R                 (- 23040A b c  - 60480B b c )d e
+--R               + 
+--R                          4             3  6 3           4 7 2
+--R                 (11520A c  + 80640B b c )d e  - 34560B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4 3 6            3          4  4 5
+--R                 - 60A b d e  + (- 960A b c - 420B b )d e
+--R               + 
+--R                         2 2           3   5 4
+--R                 (8640A b c  + 10080B b c)d e
+--R               + 
+--R                              3           2 2  6 3
+--R                 (- 15360A b c  - 40320B b c )d e
+--R               + 
+--R                         4             3  7 2           4 8
+--R                 (7680A c  + 53760B b c )d e  - 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                    4 4 5            3          4  5 4
+--R             - 15A b d e  + (- 240A b c - 105B b )d e
+--R           + 
+--R                     2 2          3   6 3               3           2 2  7 2
+--R             (2160A b c  + 2520B b c)d e  + (- 3840A b c  - 10080B b c )d e
+--R           + 
+--R                     4             3  8           4 9
+--R             (1920A c  + 13440B b c )d e - 5760B c d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                        2          3    7               2          2   2 6
+--R                 (960A b c + 720B b )d e  + (- 2880A b c  - 5520B b c)d e
+--R               + 
+--R                         3             2  3 5          3 4 4
+--R                 (1920A c  + 10560B b c )d e  - 5760B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         2           3  2 6                2           2   3 5
+--R                 (3840A b c + 2880B b )d e  + (- 11520A b c  - 22080B b c)d e
+--R               + 
+--R                         3             2  4 4           3 5 3
+--R                 (7680A c  + 42240B b c )d e  - 23040B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         2           3  3 5                2           2   4 4
+--R                 (5760A b c + 4320B b )d e  + (- 17280A b c  - 33120B b c)d e
+--R               + 
+--R                          3             2  5 3           3 6 2
+--R                 (11520A c  + 63360B b c )d e  - 34560B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         2           3  4 4                2           2   5 3
+--R                 (3840A b c + 2880B b )d e  + (- 11520A b c  - 22080B b c)d e
+--R               + 
+--R                         3             2  6 2           3 7
+--R                 (7680A c  + 42240B b c )d e  - 23040B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2          3  5 3               2          2   6 2
+--R             (960A b c + 720B b )d e  + (- 2880A b c  - 5520B b c)d e
+--R           + 
+--R                     3             2  7           3 8
+--R             (1920A c  + 10560B b c )d e - 5760B c d
+--R        *
+--R                                      +----------+
+--R                  +------------+      |   2
+--R            +---+ |           2      \|c x  + b x
+--R           \|- c \|b d e - c d  atan(-------------)
+--R                                          +---+
+--R                                        x\|- c
+--R       + 
+--R                     2   7        3 2 6  5
+--R             (96B b c d e  - 96B c d e )x
+--R           + 
+--R                          2         2     7            3            2  2 6
+--R                 (192A b c  + 432B b c)d e  + (- 192A c  - 1008B b c )d e
+--R               + 
+--R                       3 3 5
+--R                 576B c d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      3 8            2          3    7
+--R                 15A b e  + (- 646A b c - 279B b )d e
+--R               + 
+--R                           2          2   2 6             3            2  3 5
+--R                 (2616A b c  + 4142B b c)d e  + (- 2000A c  - 9848B b c )d e
+--R               + 
+--R                        3 4 4
+--R                 6000B c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        3   7             2          3  2 6
+--R                 - 73A b d e  + (- 1132A b c - 511B b )d e
+--R               + 
+--R                           2          2   3 5             3             2  4 4
+--R                 (5320A b c  + 8196B b c)d e  + (- 4160A c  - 20120B b c )d e
+--R               + 
+--R                         3 5 3
+--R                 12480B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 6            2          3  3 5
+--R                 - 55A b d e  + (- 870A b c - 385B b )d e
+--R               + 
+--R                           2          2   4 4             3             2  5 3
+--R                 (4240A b c  + 6430B b c)d e  + (- 3360A c  - 16080B b c )d e
+--R               + 
+--R                         3 6 2
+--R                 10080B c d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 5            2          3  4 4
+--R             - 15A b d e  + (- 240A b c - 105B b )d e
+--R           + 
+--R                       2          2   5 3            3            2  6 2
+--R             (1200A b c  + 1800B b c)d e  + (- 960A c  - 4560B b c )d e
+--R           + 
+--R                    3 7
+--R             2880B c d e
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R                    12         2 11  4          2 11         3 10  3
+--R           (192b d e   - 192c d e  )x  + (768b d e   - 768c d e  )x
+--R         + 
+--R                   3 10          4 9  2          4 9         5 8           5 8
+--R           (1152b d e   - 1152c d e )x  + (768b d e  - 768c d e )x + 192b d e
+--R         + 
+--R                   6 7
+--R           - 192c d e
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 471
+
+--S 472 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2          3    3              2          2   2 2
+--R           (320A b c + 240B b )d e  + (- 960A b c  - 1840B b c)d e
+--R         + 
+--R                  3            2  3           3 4
+--R           (640A c  + 3520B b c )d e - 1920B c d
+--R      *
+--R        +--------------+                                +----------+
+--R        |             2  +-----------+ +-+ +-+      +-+ |   2
+--R       \|- b d e + c d  \|- b e + c d \|c \|d log(2\|c \|c x  + b x  + 2c x + b)
+--R     + 
+--R               4 5         3         4    4            2 2         3   2 3
+--R           5A b e  + (80A b c + 35B b )d e  + (- 720A b c  - 840B b c)d e
+--R         + 
+--R                     3          2 2  3 2            4            3  4
+--R           (1280A b c  + 3360B b c )d e  + (- 640A c  - 4480B b c )d e
+--R         + 
+--R                  4 5
+--R           1920B c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                    2          3    3             2          2   2 2
+--R           (- 640A b c - 480B b )d e  + (1920A b c  + 3680B b c)d e
+--R         + 
+--R                     3            2  3           3 4
+--R           (- 1280A c  - 7040B b c )d e + 3840B c d
+--R      *
+--R          +--------------+                                  +-+
+--R          |             2  +-----------+ +-+ +-+          x\|c
+--R         \|- b d e + c d  \|- b e + c d \|c \|d atanh(-------------)
+--R                                                       +----------+
+--R                                                       |   2
+--R                                                      \|c x  + b x
+--R     + 
+--R               4 5         3         4    4            2 2         3   2 3
+--R           5A b e  + (80A b c + 35B b )d e  + (- 720A b c  - 840B b c)d e
+--R         + 
+--R                     3          2 2  3 2            4            3  4
+--R           (1280A b c  + 3360B b c )d e  + (- 640A c  - 4480B b c )d e
+--R         + 
+--R                  4 5
+--R           1920B c d
+--R      *
+--R          +--------------+
+--R          |             2              (b e - 2c d)x - b d
+--R         \|- b d e + c d  atanh(--------------------------------)
+--R                                                    +----------+
+--R                                  +-----------+ +-+ |   2
+--R                                2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                             +--------------+
+--R              8         2 7  |             2  +-----------+ +-+
+--R     (128b d e  - 128c d e )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                  2          3    3              2          2   2 2
+--R           (320A b c + 240B b )d e  + (- 960A b c  - 1840B b c)d e
+--R         + 
+--R                  3            2  3           3 4
+--R           (640A c  + 3520B b c )d e - 1920B c d
+--R      *
+--R                              +------------+          +----------+
+--R        +-----------+ +-+ +-+ |           2       +-+ |   2
+--R       \|- b e + c d \|c \|d \|b d e - c d  log(2\|c \|c x  + b x  + 2c x + b)
+--R     + 
+--R                    2          3    3             2          2   2 2
+--R           (- 640A b c - 480B b )d e  + (1920A b c  + 3680B b c)d e
+--R         + 
+--R                     3            2  3           3 4
+--R           (- 1280A c  - 7040B b c )d e + 3840B c d
+--R      *
+--R                                +------------+            +-+
+--R          +-----------+ +-+ +-+ |           2           x\|c
+--R         \|- b e + c d \|c \|d \|b d e - c d  atanh(-------------)
+--R                                                     +----------+
+--R                                                     |   2
+--R                                                    \|c x  + b x
+--R     + 
+--R               4 5         3         4    4            2 2         3   2 3
+--R           5A b e  + (80A b c + 35B b )d e  + (- 720A b c  - 840B b c)d e
+--R         + 
+--R                     3          2 2  3 2            4            3  4
+--R           (1280A b c  + 3360B b c )d e  + (- 640A c  - 4480B b c )d e
+--R         + 
+--R                  4 5
+--R           1920B c d
+--R      *
+--R          +------------+
+--R          |           2              (b e - 2c d)x - b d
+--R         \|b d e - c d  atanh(--------------------------------)
+--R                                                  +----------+
+--R                                +-----------+ +-+ |   2
+--R                              2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                  4 5            3         4    4           2 2          3   2 3
+--R           - 10A b e  + (- 160A b c - 70B b )d e  + (1440A b c  + 1680B b c)d e
+--R         + 
+--R                       3          2 2  3 2           4            3  4
+--R           (- 2560A b c  - 6720B b c )d e  + (1280A c  + 8960B b c )d e
+--R         + 
+--R                    4 5
+--R           - 3840B c d
+--R      *
+--R                                 +------------+ +----------+
+--R                                 |           2  |   2
+--R          +-----------+ +-+     \|b d e - c d  \|c x  + b x
+--R         \|- b e + c d \|d atan(----------------------------)
+--R                                        (b e - c d)x
+--R  /
+--R                                               +------------+
+--R              8         2 7  +-----------+ +-+ |           2
+--R     (128b d e  - 128c d e )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 474
+
+--S 475 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 475
+
+)clear all
+
+--S 476 of 1457
+t0:=(A+B*x)*(d+e*x)^3/sqrt(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R      3 4       3         2  3          2       2   2        2       3        3
+--R   B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x + A d
+--R   ----------------------------------------------------------------------------
+--R                                    +----------+
+--R                                    |   2
+--R                                   \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 1457
+r0:=1/64*(128*A*c^4*d^3+35*b^4*B*e^3+144*b^2*c^2*d*e*(B*d+A*e)-40*b^3*_
+     c*e^2*(3*B*d+A*e)-64*b*c^3*d^2*(B*d+3*A*e))*atanh(x*sqrt(c)/_
+     sqrt(b*x+c*x^2))/c^(9/2)+1/192*(8*A*c*e*(52*c^2*d^2-52*b*c*d*e+_
+     15*b^2*e^2)+B*(96*c^3*d^3-352*b*c^2*d^2*e+346*b^2*c*d*e^2-105*_
+     b^3*e^3))*sqrt(b*x+c*x^2)/c^4+1/24*(6*B*c*d-7*b*B*e+8*A*c*e)*_
+     (d+e*x)^2*sqrt(b*x+c*x^2)/c^2+1/4*B*(d+e*x)^3*sqrt(b*x+c*x^2)/c-_
+     1/96*e*(d*(12*b*B*c*d-48*A*c^2*d-7*b^2*B*e+8*A*b*c*e)-(40*A*c*e*_
+     (2*c*d-b*e)+B*(24*c^2*d^2-64*b*c*d*e+35*b^2*e^2))*x)*sqrt(b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                    3          4  3          2 2         3     2
+--R           (- 120A b c + 105B b )e  + (432A b c  - 360B b c)d e
+--R         + 
+--R                      3         2 2  2           4           3  3
+--R           (- 576A b c  + 432B b c )d e + (384A c  - 192B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                3 3 3          3          2  3         3   2  2
+--R           48B c e x  + ((64A c  - 56B b c )e  + 192B c d e )x
+--R         + 
+--R                      2        2   3          3           2    2         3 2
+--R           ((- 80A b c  + 70B b c)e  + (288A c  - 240B b c )d e  + 288B c d e)x
+--R         + 
+--R                  2          3  3              2         2     2
+--R           (120A b c - 105B b )e  + (- 432A b c  + 360B b c)d e
+--R         + 
+--R                  3           2  2          3 3
+--R           (576A c  - 432B b c )d e + 192B c d
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R         4 +-+
+--R     192c \|c
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    3          4  3            2 2         3     2
+--R             (120A b c - 105B b )e  + (- 432A b c  + 360B b c)d e
+--R           + 
+--R                      3         2 2  2             4           3  3
+--R             (576A b c  - 432B b c )d e + (- 384A c  + 192B b c )d
+--R        *
+--R                    +----------+
+--R                    |   2                     +-+
+--R           log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                  3 3 3           3           2  3         3   2  2
+--R             96B c e x  + ((128A c  - 112B b c )e  + 384B c d e )x
+--R           + 
+--R                            2         2   3          3           2    2
+--R                 (- 160A b c  + 140B b c)e  + (576A c  - 480B b c )d e
+--R               + 
+--R                       3 2
+--R                 576B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2          3  3              2         2     2
+--R             (240A b c - 210B b )e  + (- 864A b c  + 720B b c)d e
+--R           + 
+--R                     3           2  2          3 3
+--R             (1152A c  - 864B b c )d e + 384B c d
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R           4 +-+
+--R       384c \|c
+--R     ,
+--R
+--R                      3          4  3          2 2         3     2
+--R             (- 120A b c + 105B b )e  + (432A b c  - 360B b c)d e
+--R           + 
+--R                        3         2 2  2           4           3  3
+--R             (- 576A b c  + 432B b c )d e + (384A c  - 192B b c )d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                  3 3 3          3          2  3         3   2  2
+--R             48B c e x  + ((64A c  - 56B b c )e  + 192B c d e )x
+--R           + 
+--R                             2        2   3          3           2    2
+--R                   (- 80A b c  + 70B b c)e  + (288A c  - 240B b c )d e
+--R                 + 
+--R                         3 2
+--R                   288B c d e
+--R            *
+--R               x
+--R           + 
+--R                    2          3  3              2         2     2
+--R             (120A b c - 105B b )e  + (- 432A b c  + 360B b c)d e
+--R           + 
+--R                    3           2  2          3 3
+--R             (576A c  - 432B b c )d e + 192B c d
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R           4 +---+
+--R       192c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 478
+
+--S 479 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 3         4  3            2 2         3     2
+--R           (40A b c - 35B b )e  + (- 144A b c  + 120B b c)d e
+--R         + 
+--R                    3         2 2  2             4          3  3
+--R           (192A b c  - 144B b c )d e + (- 128A c  + 64B b c )d
+--R      *
+--R                  +----------+
+--R                  |   2                     +-+
+--R         log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                 3         4  3            2 2         3     2
+--R           (80A b c - 70B b )e  + (- 288A b c  + 240B b c)d e
+--R         + 
+--R                    3         2 2  2             4           3  3
+--R           (384A b c  - 288B b c )d e + (- 256A c  + 128B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R  /
+--R         4 +-+
+--R     128c \|c
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+--S 481 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 3         4  3            2 2         3     2
+--R           (40A b c - 35B b )e  + (- 144A b c  + 120B b c)d e
+--R         + 
+--R                    3         2 2  2             4          3  3
+--R           (192A b c  - 144B b c )d e + (- 128A c  + 64B b c )d
+--R      *
+--R                           +-+
+--R          +---+          x\|c
+--R         \|- c atanh(-------------)
+--R                      +----------+
+--R                      |   2
+--R                     \|c x  + b x
+--R     + 
+--R                   3         4  3          2 2         3     2
+--R           (- 40A b c + 35B b )e  + (144A b c  - 120B b c)d e
+--R         + 
+--R                      3         2 2  2           4          3  3
+--R           (- 192A b c  + 144B b c )d e + (128A c  - 64B b c )d
+--R      *
+--R                         +----------+
+--R                   +---+ |   2
+--R          +-+     \|- c \|c x  + b x
+--R         \|c atan(-------------------)
+--R                          c x
+--R  /
+--R        4 +---+ +-+
+--R     64c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 482
+
+)clear all
+
+--S 483 of 1457
+t0:=(A+B*x)*(d+e*x)^2/sqrt(b*x+c*x^2)
+--R 
+--R
+--R           2 3       2           2                2        2
+--R        B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d
+--R   (1)  ----------------------------------------------------
+--R                             +----------+
+--R                             |   2
+--R                            \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 1457
+r0:=1/8*(16*A*c^3*d^2-5*b^3*B*e^2+6*b^2*c*e*(2*B*d+A*e)-8*b*c^2*d*_
+     (B*d+2*A*e))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(7/2)+1/24*(18*A*c*_
+     e*(2*c*d-b*e)+B*(16*c^2*d^2-34*b*c*d*e+15*b^2*e^2))*sqrt(b*x+_
+     c*x^2)/c^3+1/3*B*(d+e*x)^2*sqrt(b*x+c*x^2)/c-1/12*e*((b*B-6*A*c)*_
+     d-(4*B*c*d-5*b*B*e+6*A*c*e)*x)*sqrt(b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R                 2         3  2             2        2
+--R           (18A b c - 15B b )e  + (- 48A b c  + 36B b c)d e
+--R         + 
+--R                 3          2  2
+--R           (48A c  - 24B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R               2 2 2          2            2        2
+--R           8B c e x  + ((12A c  - 10B b c)e  + 24B c d e)x
+--R         + 
+--R                             2  2         2                      2 2
+--R           (- 18A b c + 15B b )e  + (48A c  - 36B b c)d e + 24B c d
+--R      *
+--R              +----------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x
+--R  /
+--R        3 +-+
+--R     24c \|c
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2         3  2             2        2
+--R             (18A b c - 15B b )e  + (- 48A b c  + 36B b c)d e
+--R           + 
+--R                   3          2  2
+--R             (48A c  - 24B b c )d
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                  2 2 2          2            2        2
+--R             16B c e x  + ((24A c  - 20B b c)e  + 48B c d e)x
+--R           + 
+--R                               2  2         2                      2 2
+--R             (- 36A b c + 30B b )e  + (96A c  - 72B b c)d e + 48B c d
+--R        *
+--R                +----------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x
+--R    /
+--R          3 +-+
+--R       48c \|c
+--R     ,
+--R
+--R                   2         3  2             2        2
+--R             (18A b c - 15B b )e  + (- 48A b c  + 36B b c)d e
+--R           + 
+--R                   3          2  2
+--R             (48A c  - 24B b c )d
+--R        *
+--R                       +----------+
+--R                 +---+ |   2
+--R                \|- c \|c x  + b x
+--R           atan(-------------------)
+--R                        c x
+--R       + 
+--R                 2 2 2          2            2        2
+--R             8B c e x  + ((12A c  - 10B b c)e  + 24B c d e)x
+--R           + 
+--R                               2  2         2                      2 2
+--R             (- 18A b c + 15B b )e  + (48A c  - 36B b c)d e + 24B c d
+--R        *
+--R                  +----------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x
+--R    /
+--R          3 +---+
+--R       24c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 485
+
+--S 486 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               2        3  2             2        2              3         2  2
+--R         ((6A b c - 5B b )e  + (- 16A b c  + 12B b c)d e + (16A c  - 8B b c )d )
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                   2         3  2           2        2
+--R           (- 12A b c + 10B b )e  + (32A b c  - 24B b c)d e
+--R         + 
+--R                   3          2  2
+--R           (- 32A c  + 16B b c )d
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R  /
+--R        3 +-+
+--R     16c \|c
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    2        3  2           2        2
+--R             (- 6A b c + 5B b )e  + (16A b c  - 12B b c)d e
+--R           + 
+--R                     3         2  2
+--R             (- 16A c  + 8B b c )d
+--R      *
+--R                           +-+
+--R          +---+          x\|c
+--R         \|- c atanh(-------------)
+--R                      +----------+
+--R                      |   2
+--R                     \|c x  + b x
+--R     + 
+--R               2        3  2             2        2              3         2  2
+--R         ((6A b c - 5B b )e  + (- 16A b c  + 12B b c)d e + (16A c  - 8B b c )d )
+--R      *
+--R                         +----------+
+--R                   +---+ |   2
+--R          +-+     \|- c \|c x  + b x
+--R         \|c atan(-------------------)
+--R                          c x
+--R  /
+--R       3 +---+ +-+
+--R     8c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 1457
+t0:=(A+B*x)*(d+e*x)/sqrt(b*x+c*x^2)
+--R 
+--R
+--R             2
+--R        B e x  + (A e + B d)x + A d
+--R   (1)  ---------------------------
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 1457
+r0:=1/4*(8*A*c^2*d+3*b^2*B*e-4*b*c*(B*d+A*e))*atanh(x*sqrt(c)/sqrt(b*x+_
+     c*x^2))/c^(5/2)+1/4*(2*B*c*d-3*b*B*e+4*A*c*e)*sqrt(b*x+c*x^2)/c^2+_
+     1/2*B*(d+e*x)*sqrt(b*x+c*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                                            +-+
+--R                        2          2                      x\|c
+--R       ((- 4A b c + 3B b )e + (8A c  - 4B b c)d)atanh(-------------)
+--R                                                       +----------+
+--R                                                       |   2
+--R                                                      \|c x  + b x
+--R     + 
+--R                                                +----------+
+--R                                            +-+ |   2
+--R       (2B c e x + (4A c - 3B b)e + 4B c d)\|c \|c x  + b x
+--R  /
+--R       2 +-+
+--R     4c \|c
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          2            2
+--R           ((4A b c - 3B b )e + (- 8A c  + 4B b c)d)
+--R        *
+--R                    +----------+
+--R                    |   2                     +-+
+--R           log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                                                  +----------+
+--R                                              +-+ |   2
+--R         (4B c e x + (8A c - 6B b)e + 8B c d)\|c \|c x  + b x
+--R    /
+--R         2 +-+
+--R       8c \|c
+--R     ,
+--R
+--R                                                              +----------+
+--R                                                        +---+ |   2
+--R                          2          2                 \|- c \|c x  + b x
+--R         ((- 4A b c + 3B b )e + (8A c  - 4B b c)d)atan(-------------------)
+--R                                                               c x
+--R       + 
+--R                                                    +----------+
+--R                                              +---+ |   2
+--R         (2B c e x + (4A c - 3B b)e + 4B c d)\|- c \|c x  + b x
+--R    /
+--R         2 +---+
+--R       4c \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 492
+
+--S 493 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        2            2
+--R         ((4A b c - 3B b )e + (- 8A c  + 4B b c)d)
+--R      *
+--R                  +----------+
+--R                  |   2                     +-+
+--R         log(- 2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                                             +-+
+--R                      2             2                      x\|c
+--R       ((8A b c - 6B b )e + (- 16A c  + 8B b c)d)atanh(-------------)
+--R                                                        +----------+
+--R                                                        |   2
+--R                                                       \|c x  + b x
+--R  /
+--R       2 +-+
+--R     8c \|c
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                  +-+
+--R                      2            2             +---+          x\|c
+--R       ((4A b c - 3B b )e + (- 8A c  + 4B b c)d)\|- c atanh(-------------)
+--R                                                             +----------+
+--R                                                             |   2
+--R                                                            \|c x  + b x
+--R     + 
+--R                                                                +----------+
+--R                                                          +---+ |   2
+--R                        2          2             +-+     \|- c \|c x  + b x
+--R       ((- 4A b c + 3B b )e + (8A c  - 4B b c)d)\|c atan(-------------------)
+--R                                                                 c x
+--R  /
+--R       2 +---+ +-+
+--R     4c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 495
+
+--S 496 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 496
+
+)clear all
+
+--S 497 of 1457
+t0:=(A+B*x)/sqrt(b*x+c*x^2)
+--R 
+--R
+--R           B x + A
+--R   (1)  -------------
+--R         +----------+
+--R         |   2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 1457
+r0:=-(b*B-2*A*c)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(3/2)+B*sqrt(b*x+c*x^2)/c
+--R 
+--R
+--R                                +-+              +----------+
+--R                              x\|c           +-+ |   2
+--R        (2A c - B b)atanh(-------------) + B\|c \|c x  + b x
+--R                           +----------+
+--R                           |   2
+--R                          \|c x  + b x
+--R   (2)  -----------------------------------------------------
+--R                                  +-+
+--R                                c\|c
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       +----------+                            +----------+
+--R                       |   2                     +-+       +-+ |   2
+--R    (2A c - B b)log(2c\|c x  + b x  + (2c x + b)\|c ) + 2B\|c \|c x  + b x
+--R   [-----------------------------------------------------------------------,
+--R                                        +-+
+--R                                     2c\|c
+--R                            +----------+
+--R                      +---+ |   2                   +----------+
+--R                     \|- c \|c x  + b x       +---+ |   2
+--R    (2A c - B b)atan(-------------------) + B\|- c \|c x  + b x
+--R                             c x
+--R    ------------------------------------------------------------]
+--R                                 +---+
+--R                               c\|- c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 499
+
+--S 500 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          +----------+
+--R                          |   2                     +-+
+--R       (2A c - B b)log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                  +-+
+--R                                x\|c
+--R       (- 4A c + 2B b)atanh(-------------)
+--R                             +----------+
+--R                             |   2
+--R                            \|c x  + b x
+--R  /
+--R        +-+
+--R     2c\|c
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                       +-+
+--R                      +---+          x\|c
+--R       (- 2A c + B b)\|- c atanh(-------------)
+--R                                  +----------+
+--R                                  |   2
+--R                                 \|c x  + b x
+--R     + 
+--R                                   +----------+
+--R                             +---+ |   2
+--R                    +-+     \|- c \|c x  + b x
+--R       (2A c - B b)\|c atan(-------------------)
+--R                                    c x
+--R  /
+--R       +---+ +-+
+--R     c\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 503
+
+)clear all
+
+--S 504 of 1457
+t0:=(A+B*x)/((d+e*x)*sqrt(b*x+c*x^2))
+--R 
+--R
+--R                B x + A
+--R   (1)  ----------------------
+--R                  +----------+
+--R                  |   2
+--R        (e x + d)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 504
+
+--S 505 of 1457
+r0:=2*B*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(e*sqrt(c))-(B*d-A*e)*atanh(1/2*_
+     (b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/_
+     (e*sqrt(d)*sqrt(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                                       +-+
+--R          +-----------+ +-+          x\|c
+--R       2B\|- b e + c d \|d atanh(-------------)
+--R                                  +----------+
+--R                                  |   2
+--R                                 \|c x  + b x
+--R     + 
+--R                     +-+             (b e - 2c d)x - b d
+--R       (- A e + B d)\|c atanh(--------------------------------)
+--R                                                  +----------+
+--R                                +-----------+ +-+ |   2
+--R                              2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R       +-----------+ +-+ +-+
+--R     e\|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           +--------------+       +----------+
+--R           |             2        |   2                     +-+
+--R         B\|- b d e + c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                       +-+
+--R           (A e - B d)\|c
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R    /
+--R         +--------------+
+--R         |             2  +-+
+--R       e\|- b d e + c d  \|c
+--R     ,
+--R
+--R           +------------+       +----------+
+--R           |           2        |   2                     +-+
+--R         B\|b d e - c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                                  +------------+ +----------+
+--R                                  |           2  |   2
+--R                         +-+     \|b d e - c d  \|c x  + b x
+--R         (- 2A e + 2B d)\|c atan(----------------------------)
+--R                                         (b e - c d)x
+--R    /
+--R             +------------+
+--R         +-+ |           2
+--R       e\|c \|b d e - c d
+--R     ,
+--R
+--R                       +---+
+--R           (A e - B d)\|- c
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                                        +----------+
+--R            +--------------+      +---+ |   2
+--R            |             2      \|- c \|c x  + b x
+--R         2B\|- b d e + c d  atan(-------------------)
+--R                                         c x
+--R    /
+--R         +--------------+
+--R         |             2  +---+
+--R       e\|- b d e + c d  \|- c
+--R     ,
+--R
+--R                                    +------------+ +----------+
+--R                                    |           2  |   2
+--R                         +---+     \|b d e - c d  \|c x  + b x
+--R         (- 2A e + 2B d)\|- c atan(----------------------------)
+--R                                           (b e - c d)x
+--R       + 
+--R                                      +----------+
+--R            +------------+      +---+ |   2
+--R            |           2      \|- c \|c x  + b x
+--R         2B\|b d e - c d  atan(-------------------)
+--R                                       c x
+--R    /
+--R               +------------+
+--R         +---+ |           2
+--R       e\|- c \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 506
+
+--S 507 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         +--------------+                         +----------+
+--R         |             2  +-----------+ +-+       |   2                     +-+
+--R       B\|- b d e + c d  \|- b e + c d \|d log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                     +-----------+ +-+ +-+
+--R         (A e - B d)\|- b e + c d \|c \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R            +--------------+                              +-+
+--R            |             2  +-----------+ +-+          x\|c
+--R       - 2B\|- b d e + c d  \|- b e + c d \|d atanh(-------------)
+--R                                                     +----------+
+--R                                                     |   2
+--R                                                    \|c x  + b x
+--R     + 
+--R                   +--------------+
+--R                   |             2  +-+             (b e - 2c d)x - b d
+--R       (A e - B d)\|- b d e + c d  \|c atanh(--------------------------------)
+--R                                                                 +----------+
+--R                                               +-----------+ +-+ |   2
+--R                                             2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R       +--------------+
+--R       |             2  +-----------+ +-+ +-+
+--R     e\|- b d e + c d  \|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                           +------------+       +----------+
+--R         +-----------+ +-+ |           2        |   2                     +-+
+--R       B\|- b e + c d \|d \|b d e - c d  log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                              +------------+            +-+
+--R            +-----------+ +-+ |           2           x\|c
+--R       - 2B\|- b e + c d \|d \|b d e - c d  atanh(-------------)
+--R                                                   +----------+
+--R                                                   |   2
+--R                                                  \|c x  + b x
+--R     + 
+--R                       +------------+
+--R                   +-+ |           2              (b e - 2c d)x - b d
+--R       (A e - B d)\|c \|b d e - c d  atanh(--------------------------------)
+--R                                                               +----------+
+--R                                             +-----------+ +-+ |   2
+--R                                           2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                                                  +------------+ +----------+
+--R                                                  |           2  |   2
+--R                       +-----------+ +-+ +-+     \|b d e - c d  \|c x  + b x
+--R       (- 2A e + 2B d)\|- b e + c d \|c \|d atan(----------------------------)
+--R                                                         (b e - c d)x
+--R  /
+--R                             +------------+
+--R       +-----------+ +-+ +-+ |           2
+--R     e\|- b e + c d \|c \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 1457
+t0:=(A+B*x)/((d+e*x)^2*sqrt(b*x+c*x^2))
+--R 
+--R
+--R                     B x + A
+--R   (1)  ---------------------------------
+--R                             +----------+
+--R          2 2             2  |   2
+--R        (e x  + 2d e x + d )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 1457
+r0:=-1/2*(b*B*d-2*A*c*d+A*b*e)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(3/2)*(c*d-b*e)^(3/2))+(B*d-A*e)*_
+     sqrt(b*x+c*x^2)/(d*(c*d-b*e)*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                  2                                              2
+--R         ((- A b e  + (2A c - B b)d e)x - A b d e + (2A c - B b)d )
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                                       +----------+
+--R                     +-----------+ +-+ |   2
+--R       (2A e - 2B d)\|- b e + c d \|d \|c x  + b x
+--R  /
+--R             2       2          2        3  +-----------+ +-+
+--R     ((2b d e  - 2c d e)x + 2b d e - 2c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2                                                  2
+--R           ((A b e  + (- 2A c + B b)d e)x + A b d e + (- 2A c + B b)d )
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                       +--------------+ +----------+
+--R                       |             2  |   2
+--R         (2A e - 2B d)\|- b d e + c d  \|c x  + b x
+--R    /
+--R                                              +--------------+
+--R               2       2          2        3  |             2
+--R       ((2b d e  - 2c d e)x + 2b d e - 2c d )\|- b d e + c d
+--R     ,
+--R
+--R                    2                                              2
+--R           ((- A b e  + (2A c - B b)d e)x - A b d e + (2A c - B b)d )
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                     +------------+ +----------+
+--R                     |           2  |   2
+--R         (A e - B d)\|b d e - c d  \|c x  + b x
+--R    /
+--R                                          +------------+
+--R              2      2         2       3  |           2
+--R       ((b d e  - c d e)x + b d e - c d )\|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 513
+
+--S 514 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                   +-----------+ +-+
+--R         (A b e + (- 2A c + B b)d)\|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                                   +--------------+
+--R                                   |             2
+--R         (A b e + (- 2A c + B b)d)\|- b d e + c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                      +--------------+
+--R                   2  |             2  +-----------+ +-+
+--R     (2b d e - 2c d )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                   +------------+
+--R                                   |           2
+--R         (A b e + (- 2A c + B b)d)\|b d e - c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                                     +-----------+ +-+
+--R         (- 2A b e + (4A c - 2B b)d)\|- b e + c d \|d
+--R      *
+--R               +------------+ +----------+
+--R               |           2  |   2
+--R              \|b d e - c d  \|c x  + b x
+--R         atan(----------------------------)
+--R                      (b e - c d)x
+--R  /
+--R                                        +------------+
+--R                   2  +-----------+ +-+ |           2
+--R     (2b d e - 2c d )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 517
+
+)clear all
+
+--S 518 of 1457
+t0:=(A+B*x)/((d+e*x)^3*sqrt(b*x+c*x^2))
+--R 
+--R
+--R                          B x + A
+--R   (1)  -------------------------------------------
+--R                                       +----------+
+--R          3 3       2 2     2       3  |   2
+--R        (e x  + 3d e x  + 3d e x + d )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 1457
+r0:=1/8*(8*A*c^2*d^2-4*b*c*d*(B*d+2*A*e)+b^2*e*(B*d+3*A*e))*atanh(1/2*(b*d+_
+     (2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(5/2)*_
+     (c*d-b*e)^(5/2))+1/2*(B*d-A*e)*sqrt(b*x+c*x^2)/(d*(c*d-b*e)*_
+     (d+e*x)^2)-1/4*(3*A*e*(2*c*d-b*e)-B*d*(2*c*d+b*e))*sqrt(b*x+c*x^2)/_
+     (d^2*(c*d-b*e)^2*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                  2 4                2    3          2           2 2  2
+--R           (- 3A b e  + (8A b c - B b )d e  + (- 8A c  + 4B b c)d e )x
+--R         + 
+--R                  2   3                  2  2 2           2           3
+--R           (- 6A b d e  + (16A b c - 2B b )d e  + (- 16A c  + 8B b c)d e)x
+--R         + 
+--R                 2 2 2                2  3           2           4
+--R           - 3A b d e  + (8A b c - B b )d e + (- 8A c  + 4B b c)d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                  3                      2         2               2
+--R           (6A b e  + (- 12A c + 2B b)d e  + 4B c d e)x + 10A b d e
+--R         + 
+--R                            2          3
+--R           (- 16A c - 2B b)d e + 8B c d
+--R      *
+--R                            +----------+
+--R          +-----------+ +-+ |   2
+--R         \|- b e + c d \|d \|c x  + b x
+--R  /
+--R            2 2 4          3 3     2 4 2  2       2 3 3          4 2      2 5
+--R         (8b d e  - 16b c d e  + 8c d e )x  + (16b d e  - 32b c d e  + 16c d e)x
+--R       + 
+--R           2 4 2          5      2 6
+--R         8b d e  - 16b c d e + 8c d
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2 4                  2    3        2           2 2  2
+--R             (3A b e  + (- 8A b c + B b )d e  + (8A c  - 4B b c)d e )x
+--R           + 
+--R                  2   3                    2  2 2         2           3
+--R             (6A b d e  + (- 16A b c + 2B b )d e  + (16A c  - 8B b c)d e)x
+--R           + 
+--R                 2 2 2                  2  3         2           4
+--R             3A b d e  + (- 8A b c + B b )d e + (8A c  - 4B b c)d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                    3                      2         2               2
+--R             (6A b e  + (- 12A c + 2B b)d e  + 4B c d e)x + 10A b d e
+--R           + 
+--R                              2          3
+--R             (- 16A c - 2B b)d e + 8B c d
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R              2 2 4          3 3     2 4 2  2
+--R           (8b d e  - 16b c d e  + 8c d e )x
+--R         + 
+--R               2 3 3          4 2      2 5        2 4 2          5      2 6
+--R           (16b d e  - 32b c d e  + 16c d e)x + 8b d e  - 16b c d e + 8c d
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                    2 4                2    3          2           2 2  2
+--R             (- 3A b e  + (8A b c - B b )d e  + (- 8A c  + 4B b c)d e )x
+--R           + 
+--R                    2   3                  2  2 2           2           3
+--R             (- 6A b d e  + (16A b c - 2B b )d e  + (- 16A c  + 8B b c)d e)x
+--R           + 
+--R                   2 2 2                2  3           2           4
+--R             - 3A b d e  + (8A b c - B b )d e + (- 8A c  + 4B b c)d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                    3                    2         2              2
+--R             (3A b e  + (- 6A c + B b)d e  + 2B c d e)x + 5A b d e
+--R           + 
+--R                            2          3
+--R             (- 8A c - B b)d e + 4B c d
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R              2 2 4         3 3     2 4 2  2      2 3 3          4 2     2 5
+--R           (4b d e  - 8b c d e  + 4c d e )x  + (8b d e  - 16b c d e  + 8c d e)x
+--R         + 
+--R             2 4 2         5      2 6
+--R           4b d e  - 8b c d e + 4c d
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 520
+
+--S 521 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2 2                  2            2           2  +-----------+ +-+
+--R         (3A b e  + (- 8A b c + B b )d e + (8A c  - 4B b c)d )\|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                                                               +--------------+
+--R              2 2                  2            2           2  |             2
+--R         (3A b e  + (- 8A b c + B b )d e + (8A c  - 4B b c)d )\|- b d e + c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                                   +--------------+
+--R        2 2 2          3      2 4  |             2  +-----------+ +-+
+--R     (8b d e  - 16b c d e + 8c d )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                               +------------+
+--R              2 2                  2            2           2  |           2
+--R         (3A b e  + (- 8A b c + B b )d e + (8A c  - 4B b c)d )\|b d e - c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                2 2                  2               2           2
+--R         (- 6A b e  + (16A b c - 2B b )d e + (- 16A c  + 8B b c)d )
+--R      *
+--R                                 +------------+ +----------+
+--R                                 |           2  |   2
+--R          +-----------+ +-+     \|b d e - c d  \|c x  + b x
+--R         \|- b e + c d \|d atan(----------------------------)
+--R                                        (b e - c d)x
+--R  /
+--R                                                     +------------+
+--R        2 2 2          3      2 4  +-----------+ +-+ |           2
+--R     (8b d e  - 16b c d e + 8c d )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 524
+
+)clear all
+
+--S 525 of 1457
+t0:=(A+B*x)/((d+e*x)^4*sqrt(b*x+c*x^2))
+--R 
+--R
+--R                               B x + A
+--R   (1)  -----------------------------------------------------
+--R                                                 +----------+
+--R          4 4       3 3     2 2 2     3       4  |   2
+--R        (e x  + 4d e x  + 6d e x  + 4d e x + d )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 1457
+r0:=1/16*(16*A*c^3*d^3-8*b*c^2*d^2*(B*d+3*A*e)-b^3*e^2*(B*d+5*A*e)+_
+     2*b^2*c*d*e*(2*B*d+9*A*e))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(7/2)*(c*d-b*e)^(7/2))+_
+     1/3*(B*d-A*e)*sqrt(b*x+c*x^2)/(d*(c*d-b*e)*(d+e*x)^3)-_
+     1/12*(5*A*e*(2*c*d-b*e)-B*d*(4*c*d+b*e))*sqrt(b*x+c*x^2)/(d^2*_
+     (c*d-b*e)^2*(d+e*x)^2)+1/24*(B*d*(8*c^2*d^2+10*b*c*d*e-3*b^2*e^2)-_
+     A*e*(44*c^2*d^2-44*b*c*d*e+15*b^2*e^2))*sqrt(b*x+c*x^2)/(d^3*_
+     (c*d-b*e)^3*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                      3 6         2        3    5             2        2   2 4
+--R               - 15A b e  + (54A b c - 3B b )d e  + (- 72A b c  + 12B b c)d e
+--R             + 
+--R                     3          2  3 3
+--R               (48A c  - 24B b c )d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      3   5          2        3  2 4
+--R               - 45A b d e  + (162A b c - 9B b )d e
+--R             + 
+--R                          2        2   3 3          3          2  4 2
+--R               (- 216A b c  + 36B b c)d e  + (144A c  - 72B b c )d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3 2 4          2        3  3 3
+--R               - 45A b d e  + (162A b c - 9B b )d e
+--R             + 
+--R                          2        2   4 2          3          2  5
+--R               (- 216A b c  + 36B b c)d e  + (144A c  - 72B b c )d e
+--R          *
+--R             x
+--R         + 
+--R                  3 3 3         2        3  4 2             2        2   5
+--R           - 15A b d e  + (54A b c - 3B b )d e  + (- 72A b c  + 12B b c)d e
+--R         + 
+--R                 3          2  6
+--R           (48A c  - 24B b c )d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                    2 5                    2    4         2            2 3
+--R               30A b e  + (- 88A b c + 6B b )d e  + (88A c  - 20B b c)d e
+--R             + 
+--R                      2 3 2
+--R               - 16B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    2   4                      2  2 3          2            3 2
+--R               80A b d e  + (- 236A b c + 16B b )d e  + (216A c  - 28B b c)d e
+--R             + 
+--R                      2 4
+--R               - 48B c d e
+--R          *
+--R             x
+--R         + 
+--R                2 2 3                     2  3 2          2            4
+--R           66A b d e  + (- 180A b c - 6B b )d e  + (144A c  + 24B b c)d e
+--R         + 
+--R                  2 5
+--R           - 48B c d
+--R      *
+--R                            +----------+
+--R          +-----------+ +-+ |   2
+--R         \|- b e + c d \|d \|c x  + b x
+--R  /
+--R             3 3 6       2   4 5         2 5 4      3 6 3  3
+--R         (48b d e  - 144b c d e  + 144b c d e  - 48c d e )x
+--R       + 
+--R              3 4 5       2   5 4         2 6 3       3 7 2  2
+--R         (144b d e  - 432b c d e  + 432b c d e  - 144c d e )x
+--R       + 
+--R              3 5 4       2   6 3         2 7 2       3 8         3 6 3
+--R         (144b d e  - 432b c d e  + 432b c d e  - 144c d e)x + 48b d e
+--R       + 
+--R               2   7 2         2 8       3 9
+--R         - 144b c d e  + 144b c d e - 48c d
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3 6           2        3    5           2        2   2 4
+--R                 15A b e  + (- 54A b c + 3B b )d e  + (72A b c  - 12B b c)d e
+--R               + 
+--R                         3          2  3 3
+--R                 (- 48A c  + 24B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      3   5            2        3  2 4
+--R                 45A b d e  + (- 162A b c + 9B b )d e
+--R               + 
+--R                          2        2   3 3            3          2  4 2
+--R                 (216A b c  - 36B b c)d e  + (- 144A c  + 72B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      3 2 4            2        3  3 3
+--R                 45A b d e  + (- 162A b c + 9B b )d e
+--R               + 
+--R                          2        2   4 2            3          2  5
+--R                 (216A b c  - 36B b c)d e  + (- 144A c  + 72B b c )d e
+--R            *
+--R               x
+--R           + 
+--R                  3 3 3           2        3  4 2           2        2   5
+--R             15A b d e  + (- 54A b c + 3B b )d e  + (72A b c  - 12B b c)d e
+--R           + 
+--R                     3          2  6
+--R             (- 48A c  + 24B b c )d
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                      2 5                    2    4         2            2 3
+--R                 30A b e  + (- 88A b c + 6B b )d e  + (88A c  - 20B b c)d e
+--R               + 
+--R                        2 3 2
+--R                 - 16B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      2   4                      2  2 3
+--R                 80A b d e  + (- 236A b c + 16B b )d e
+--R               + 
+--R                        2            3 2        2 4
+--R                 (216A c  - 28B b c)d e  - 48B c d e
+--R            *
+--R               x
+--R           + 
+--R                  2 2 3                     2  3 2          2            4
+--R             66A b d e  + (- 180A b c - 6B b )d e  + (144A c  + 24B b c)d e
+--R           + 
+--R                    2 5
+--R             - 48B c d
+--R        *
+--R            +--------------+ +----------+
+--R            |             2  |   2
+--R           \|- b d e + c d  \|c x  + b x
+--R    /
+--R               3 3 6       2   4 5         2 5 4      3 6 3  3
+--R           (48b d e  - 144b c d e  + 144b c d e  - 48c d e )x
+--R         + 
+--R                3 4 5       2   5 4         2 6 3       3 7 2  2
+--R           (144b d e  - 432b c d e  + 432b c d e  - 144c d e )x
+--R         + 
+--R                3 5 4       2   6 3         2 7 2       3 8         3 6 3
+--R           (144b d e  - 432b c d e  + 432b c d e  - 144c d e)x + 48b d e
+--R         + 
+--R                 2   7 2         2 8       3 9
+--R           - 144b c d e  + 144b c d e - 48c d
+--R      *
+--R          +--------------+
+--R          |             2
+--R         \|- b d e + c d
+--R     ,
+--R
+--R                        3 6         2        3    5             2        2   2 4
+--R                 - 15A b e  + (54A b c - 3B b )d e  + (- 72A b c  + 12B b c)d e
+--R               + 
+--R                       3          2  3 3
+--R                 (48A c  - 24B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        3   5          2        3  2 4
+--R                 - 45A b d e  + (162A b c - 9B b )d e
+--R               + 
+--R                            2        2   3 3          3          2  4 2
+--R                 (- 216A b c  + 36B b c)d e  + (144A c  - 72B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        3 2 4          2        3  3 3
+--R                 - 45A b d e  + (162A b c - 9B b )d e
+--R               + 
+--R                            2        2   4 2          3          2  5
+--R                 (- 216A b c  + 36B b c)d e  + (144A c  - 72B b c )d e
+--R            *
+--R               x
+--R           + 
+--R                    3 3 3         2        3  4 2             2        2   5
+--R             - 15A b d e  + (54A b c - 3B b )d e  + (- 72A b c  + 12B b c)d e
+--R           + 
+--R                   3          2  6
+--R             (48A c  - 24B b c )d
+--R        *
+--R                 +------------+ +----------+
+--R                 |           2  |   2
+--R                \|b d e - c d  \|c x  + b x
+--R           atan(----------------------------)
+--R                        (b e - c d)x
+--R       + 
+--R                      2 5                    2    4         2            2 3
+--R                 15A b e  + (- 44A b c + 3B b )d e  + (44A c  - 10B b c)d e
+--R               + 
+--R                       2 3 2
+--R                 - 8B c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      2   4                     2  2 3          2            3 2
+--R                 40A b d e  + (- 118A b c + 8B b )d e  + (108A c  - 14B b c)d e
+--R               + 
+--R                        2 4
+--R                 - 24B c d e
+--R            *
+--R               x
+--R           + 
+--R                  2 2 3                    2  3 2         2            4
+--R             33A b d e  + (- 90A b c - 3B b )d e  + (72A c  + 12B b c)d e
+--R           + 
+--R                    2 5
+--R             - 24B c d
+--R        *
+--R            +------------+ +----------+
+--R            |           2  |   2
+--R           \|b d e - c d  \|c x  + b x
+--R    /
+--R               3 3 6      2   4 5        2 5 4      3 6 3  3
+--R           (24b d e  - 72b c d e  + 72b c d e  - 24c d e )x
+--R         + 
+--R               3 4 5       2   5 4         2 6 3      3 7 2  2
+--R           (72b d e  - 216b c d e  + 216b c d e  - 72c d e )x
+--R         + 
+--R               3 5 4       2   6 3         2 7 2      3 8         3 6 3
+--R           (72b d e  - 216b c d e  + 216b c d e  - 72c d e)x + 24b d e
+--R         + 
+--R                2   7 2        2 8       3 9
+--R           - 72b c d e  + 72b c d e - 24c d
+--R      *
+--R          +------------+
+--R          |           2
+--R         \|b d e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 527
+
+--S 528 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               3 3           2       3    2           2       2   2
+--R           5A b e  + (- 18A b c + B b )d e  + (24A b c  - 4B b c)d e
+--R         + 
+--R                   3         2  3
+--R           (- 16A c  + 8B b c )d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R               3 3           2       3    2           2       2   2
+--R           5A b e  + (- 18A b c + B b )d e  + (24A b c  - 4B b c)d e
+--R         + 
+--R                   3         2  3
+--R           (- 16A c  + 8B b c )d
+--R      *
+--R          +--------------+
+--R          |             2              (b e - 2c d)x - b d
+--R         \|- b d e + c d  atanh(--------------------------------)
+--R                                                    +----------+
+--R                                  +-----------+ +-+ |   2
+--R                                2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                                                    +--------------+
+--R           3 3 3      2   4 2        2 5       3 6  |             2
+--R       (16b d e  - 48b c d e  + 48b c d e - 16c d )\|- b d e + c d
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 528
+
+--S 529 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               3 3           2       3    2           2       2   2
+--R           5A b e  + (- 18A b c + B b )d e  + (24A b c  - 4B b c)d e
+--R         + 
+--R                   3         2  3
+--R           (- 16A c  + 8B b c )d
+--R      *
+--R          +------------+
+--R          |           2              (b e - 2c d)x - b d
+--R         \|b d e - c d  atanh(--------------------------------)
+--R                                                  +----------+
+--R                                +-----------+ +-+ |   2
+--R                              2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                  3 3         2        3    2             2       2   2
+--R           - 10A b e  + (36A b c - 2B b )d e  + (- 48A b c  + 8B b c)d e
+--R         + 
+--R                 3          2  3
+--R           (32A c  - 16B b c )d
+--R      *
+--R                                 +------------+ +----------+
+--R                                 |           2  |   2
+--R          +-----------+ +-+     \|b d e - c d  \|c x  + b x
+--R         \|- b e + c d \|d atan(----------------------------)
+--R                                        (b e - c d)x
+--R  /
+--R           3 3 3      2   4 2        2 5       3 6  +-----------+ +-+
+--R       (16b d e  - 48b c d e  + 48b c d e - 16c d )\|- b e + c d \|d
+--R    *
+--R        +------------+
+--R        |           2
+--R       \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 531
+
+)clear all
+
+--S 532 of 1457
+t0:=(A+B*x)*(d+e*x)^3/(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R   (1)
+--R      3 4       3         2  3          2       2   2        2       3        3
+--R   B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x + A d
+--R   ----------------------------------------------------------------------------
+--R                                          +----------+
+--R                                 2        |   2
+--R                             (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 1457
+r0:=3/4*e*(4*A*c*e*(2*c*d-b*e)+B*(8*c^2*d^2-12*b*c*d*e+5*b^2*e^2))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(7/2)-2*(A*b-(b*B-2*A*c)*x)*_
+     (d+e*x)^3/(b^2*sqrt(b*x+c*x^2))+1/4*e*(32*A*c^3*d^2-15*b^3*B*e^2-_
+     16*b*c^2*d*(B*d+2*A*e)+2*b^2*c*e*(17*B*d+6*A*e))*sqrt(b*x+c*x^2)/_
+     (b^2*c^3)-2*(b*B-2*A*c)*e*(d+e*x)^2*sqrt(b*x+c*x^2)/(b^2*c)+_
+     1/2*e^2*(b*(b*B+4*A*c)*d+(8*A*c^2*d+5*b^2*B*e-4*b*c*(B*d+A*e))*x)*_
+     sqrt(b*x+c*x^2)/(b^2*c^2)
+--R 
+--R
+--R   (2)
+--R                  3         4  3         2 2        3     2        2 2 2
+--R         ((- 12A b c + 15B b )e  + (24A b c  - 36B b c)d e  + 24B b c d e)
+--R      *
+--R          +----------+            +-+
+--R          |   2                 x\|c
+--R         \|c x  + b x atanh(-------------)
+--R                             +----------+
+--R                             |   2
+--R                            \|c x  + b x
+--R     + 
+--R               2 2 3 3         2 2       3   3        2 2   2  2
+--R           2B b c e x  + ((4A b c  - 5B b c)e  + 12B b c d e )x
+--R         + 
+--R                     3         4  3           2 2        3     2
+--R               (12A b c - 15B b )e  + (- 24A b c  + 36B b c)d e
+--R             + 
+--R                       3        2 2  2            4         3  3
+--R               (24A b c  - 24B b c )d e + (- 16A c  + 8B b c )d
+--R          *
+--R             x
+--R         + 
+--R                   3 3
+--R           - 8A b c d
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R               +----------+
+--R       2 3 +-+ |   2
+--R     4b c \|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    3         4  3         2 2        3     2        2 2 2
+--R           ((- 12A b c + 15B b )e  + (24A b c  - 36B b c)d e  + 24B b c d e)
+--R        *
+--R            +----------+       +----------+
+--R            |   2              |   2                     +-+
+--R           \|c x  + b x log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                 2 2 3 3         2 2        3   3        2 2   2  2
+--R             4B b c e x  + ((8A b c  - 10B b c)e  + 24B b c d e )x
+--R           + 
+--R                       3         4  3           2 2        3     2
+--R                 (24A b c - 30B b )e  + (- 48A b c  + 72B b c)d e
+--R               + 
+--R                         3        2 2  2            4          3  3
+--R                 (48A b c  - 48B b c )d e + (- 32A c  + 16B b c )d
+--R            *
+--R               x
+--R           + 
+--R                      3 3
+--R             - 16A b c d
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                 +----------+
+--R         2 3 +-+ |   2
+--R       8b c \|c \|c x  + b x
+--R     ,
+--R
+--R                    3         4  3         2 2        3     2        2 2 2
+--R           ((- 12A b c + 15B b )e  + (24A b c  - 36B b c)d e  + 24B b c d e)
+--R        *
+--R                                    +----------+
+--R            +----------+      +---+ |   2
+--R            |   2            \|- c \|c x  + b x
+--R           \|c x  + b x atan(-------------------)
+--R                                     c x
+--R       + 
+--R                 2 2 3 3         2 2       3   3        2 2   2  2
+--R             2B b c e x  + ((4A b c  - 5B b c)e  + 12B b c d e )x
+--R           + 
+--R                       3         4  3           2 2        3     2
+--R                 (12A b c - 15B b )e  + (- 24A b c  + 36B b c)d e
+--R               + 
+--R                         3        2 2  2            4         3  3
+--R                 (24A b c  - 24B b c )d e + (- 16A c  + 8B b c )d
+--R            *
+--R               x
+--R           + 
+--R                     3 3
+--R             - 8A b c d
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                   +----------+
+--R         2 3 +---+ |   2
+--R       4b c \|- c \|c x  + b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 534
+
+--S 535 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            2  3         2              2        2 2
+--R         ((- 12A b c + 15B b )e  + (24A c  - 36B b c)d e  + 24B c d e)
+--R      *
+--R                +----------+
+--R                |   2                     +-+
+--R         log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                          2  3           2              2        2 2
+--R         ((24A b c - 30B b )e  + (- 48A c  + 72B b c)d e  - 48B c d e)
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R  /
+--R       3 +-+
+--R     8c \|c
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          2  3           2              2        2 2   +---+
+--R         ((12A b c - 15B b )e  + (- 24A c  + 36B b c)d e  - 24B c d e)\|- c
+--R      *
+--R                     +-+
+--R                   x\|c
+--R         atanh(-------------)
+--R                +----------+
+--R                |   2
+--R               \|c x  + b x
+--R     + 
+--R                            2  3         2              2        2 2   +-+
+--R         ((- 12A b c + 15B b )e  + (24A c  - 36B b c)d e  + 24B c d e)\|c
+--R      *
+--R                     +----------+
+--R               +---+ |   2
+--R              \|- c \|c x  + b x
+--R         atan(-------------------)
+--R                      c x
+--R  /
+--R       3 +---+ +-+
+--R     4c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 538
+
+)clear all
+
+--S 539 of 1457
+t0:=(A+B*x)*(d+e*x)^2/(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R           2 3       2           2                2        2
+--R        B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d
+--R   (1)  ----------------------------------------------------
+--R                                   +----------+
+--R                          2        |   2
+--R                      (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 1457
+r0:=e*(4*B*c*d-3*b*B*e+2*A*c*e)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(5/2)-_
+     2*(A*b-(b*B-2*A*c)*x)*(d+e*x)^2/(b^2*sqrt(b*x+c*x^2))+e*(8*A*c^2*d+_
+     3*b^2*B*e-4*b*c*(B*d+A*e))*sqrt(b*x+c*x^2)/(b^2*c^2)+2*e^2*(A*b-_
+     (b*B-2*A*c)*x)*sqrt(b*x+c*x^2)/(b^2*c)
+--R 
+--R
+--R   (2)
+--R                                         +----------+            +-+
+--R             2        3  2       2       |   2                 x\|c
+--R       ((2A b c - 3B b )e  + 4B b c d e)\|c x  + b x atanh(-------------)
+--R                                                            +----------+
+--R                                                            |   2
+--R                                                           \|c x  + b x
+--R     + 
+--R              2   2 2
+--R           B b c e x
+--R         + 
+--R                      2        3  2          2       2
+--R               (- 2A b c + 3B b )e  + (4A b c  - 4B b c)d e
+--R             + 
+--R                      3         2  2
+--R               (- 4A c  + 2B b c )d
+--R          *
+--R             x
+--R         + 
+--R                   2 2
+--R           - 2A b c d
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R              +----------+
+--R      2 2 +-+ |   2
+--R     b c \|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 540
+
+--S 541 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                             +----------+
+--R                 2        3  2       2       |   2
+--R           ((2A b c - 3B b )e  + 4B b c d e)\|c x  + b x
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                 2   2 2
+--R             2B b c e x
+--R           + 
+--R                        2        3  2          2       2
+--R                 (- 4A b c + 6B b )e  + (8A b c  - 8B b c)d e
+--R               + 
+--R                        3         2  2
+--R                 (- 8A c  + 4B b c )d
+--R            *
+--R               x
+--R           + 
+--R                     2 2
+--R             - 4A b c d
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                 +----------+
+--R         2 2 +-+ |   2
+--R       2b c \|c \|c x  + b x
+--R     ,
+--R
+--R                                                                   +----------+
+--R                                           +----------+      +---+ |   2
+--R               2        3  2       2       |   2            \|- c \|c x  + b x
+--R         ((2A b c - 3B b )e  + 4B b c d e)\|c x  + b x atan(-------------------)
+--R                                                                    c x
+--R       + 
+--R                2   2 2
+--R             B b c e x
+--R           + 
+--R                        2        3  2          2       2
+--R                 (- 2A b c + 3B b )e  + (4A b c  - 4B b c)d e
+--R               + 
+--R                        3         2  2
+--R                 (- 4A c  + 2B b c )d
+--R            *
+--R               x
+--R           + 
+--R                     2 2
+--R             - 2A b c d
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                  +----------+
+--R        2 2 +---+ |   2
+--R       b c \|- c \|c x  + b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 541
+
+--S 542 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                          +----------+
+--R                      2                   |   2                     +-+
+--R       ((2A c - 3B b)e  + 4B c d e)log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                                 +-+
+--R                        2                      x\|c
+--R       ((- 4A c + 6B b)e  - 8B c d e)atanh(-------------)
+--R                                            +----------+
+--R                                            |   2
+--R                                           \|c x  + b x
+--R  /
+--R       2 +-+
+--R     2c \|c
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                       +-+
+--R                        2             +---+          x\|c
+--R       ((- 2A c + 3B b)e  - 4B c d e)\|- c atanh(-------------)
+--R                                                  +----------+
+--R                                                  |   2
+--R                                                 \|c x  + b x
+--R     + 
+--R                                                   +----------+
+--R                                             +---+ |   2
+--R                      2             +-+     \|- c \|c x  + b x
+--R       ((2A c - 3B b)e  + 4B c d e)\|c atan(-------------------)
+--R                                                    c x
+--R  /
+--R      2 +---+ +-+
+--R     c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 545
+
+)clear all
+
+--S 546 of 1457
+t0:=(A+B*x)*(d+e*x)/(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R             2
+--R        B e x  + (A e + B d)x + A d
+--R   (1)  ---------------------------
+--R                      +----------+
+--R             2        |   2
+--R         (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 1457
+r0:=2*B*e*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(3/2)-2*(A*b-(b*B-2*A*c)*x)*_
+     (d+e*x)/(b^2*sqrt(b*x+c*x^2))-2*(b*B-2*A*c)*e*sqrt(b*x+c*x^2)/(b^2*c)
+--R 
+--R
+--R   (2)
+--R              +----------+            +-+
+--R           2  |   2                 x\|c
+--R       2B b e\|c x  + b x atanh(-------------)
+--R                                 +----------+
+--R                                 |   2
+--R                                \|c x  + b x
+--R     + 
+--R                       2            2                          +-+
+--R       (((2A b c - 2B b )e + (- 4A c  + 2B b c)d)x - 2A b c d)\|c
+--R  /
+--R             +----------+
+--R      2  +-+ |   2
+--R     b c\|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               +----------+       +----------+
+--R            2  |   2              |   2                     +-+
+--R         B b e\|c x  + b x log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                         2            2                          +-+
+--R         (((2A b c - 2B b )e + (- 4A c  + 2B b c)d)x - 2A b c d)\|c
+--R    /
+--R               +----------+
+--R        2  +-+ |   2
+--R       b c\|c \|c x  + b x
+--R     ,
+--R
+--R                                        +----------+
+--R                +----------+      +---+ |   2
+--R             2  |   2            \|- c \|c x  + b x
+--R         2B b e\|c x  + b x atan(-------------------)
+--R                                         c x
+--R       + 
+--R                         2            2                          +---+
+--R         (((2A b c - 2B b )e + (- 4A c  + 2B b c)d)x - 2A b c d)\|- c
+--R    /
+--R                 +----------+
+--R        2  +---+ |   2
+--R       b c\|- c \|c x  + b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 548
+
+--S 549 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R                   +----------+                                      +-+
+--R                   |   2                     +-+                   x\|c
+--R        B e log(2c\|c x  + b x  + (2c x + b)\|c ) - 2B e atanh(-------------)
+--R                                                                +----------+
+--R                                                                |   2
+--R                                                               \|c x  + b x
+--R   (4)  ---------------------------------------------------------------------
+--R                                          +-+
+--R                                        c\|c
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                               +----------+
+--R                                +-+                      +---+ |   2
+--R               +---+          x\|c              +-+     \|- c \|c x  + b x
+--R        - 2B e\|- c atanh(-------------) + 2B e\|c atan(-------------------)
+--R                           +----------+                         c x
+--R                           |   2
+--R                          \|c x  + b x
+--R   (6)  --------------------------------------------------------------------
+--R                                       +---+ +-+
+--R                                     c\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 1457
+t0:=(A+B*x)/(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R                 B x + A
+--R   (1)  -------------------------
+--R                     +----------+
+--R            2        |   2
+--R        (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 1457
+r0:=-2*(A*b-(b*B-2*A*c)*x)/(b^2*sqrt(b*x+c*x^2))
+--R 
+--R
+--R        (- 4A c + 2B b)x - 2A b
+--R   (2)  -----------------------
+--R               +----------+
+--R             2 |   2
+--R            b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (- 4A c + 2B b)x - 2A b
+--R   (3)  -----------------------
+--R               +----------+
+--R             2 |   2
+--R            b \|c x  + b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 555
+
+--S 556 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 557
+
+)clear all
+
+--S 558 of 1457
+t0:=(A+B*x)/((d+e*x)*(b*x+c*x^2)^(3/2))
+--R 
+--R
+--R                           B x + A
+--R   (1)  ---------------------------------------------
+--R                                         +----------+
+--R              3               2          |   2
+--R        (c e x  + (b e + c d)x  + b d x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 1457
+r0:=-e*(B*d-A*e)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*_
+     sqrt(b*x+c*x^2)))/(d^(3/2)*(c*d-b*e)^(3/2))-2*(A*b*(c*d-b*e)+_
+     c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*sqrt(b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                          +----------+
+--R           2 2      2     |   2                    (b e - 2c d)x - b d
+--R       (A b e  - B b d e)\|c x  + b x atanh(--------------------------------)
+--R                                                                +----------+
+--R                                              +-----------+ +-+ |   2
+--R                                            2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                         2                    2              +-----------+ +-+
+--R     ((- 2A b c e + (4A c  - 2B b c)d)x - 2A b e + 2A b c d)\|- b e + c d \|d
+--R  /
+--R                                        +----------+
+--R       3       2   2  +-----------+ +-+ |   2
+--R     (b d e - b c d )\|- b e + c d \|d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                              +----------+
+--R               2 2      2     |   2
+--R           (A b e  - B b d e)\|c x  + b x
+--R        *
+--R           log
+--R                                   +----------+
+--R                                2  |   2
+--R                  (2b d e - 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                                                               +--------------+
+--R                           2                    2              |             2
+--R       ((- 2A b c e + (4A c  - 2B b c)d)x - 2A b e + 2A b c d)\|- b d e + c d
+--R    /
+--R                        +--------------+ +----------+
+--R         3       2   2  |             2  |   2
+--R       (b d e - b c d )\|- b d e + c d  \|c x  + b x
+--R     ,
+--R
+--R                                                +------------+ +----------+
+--R                              +----------+      |           2  |   2
+--R              2 2       2     |   2            \|b d e - c d  \|c x  + b x
+--R         (2A b e  - 2B b d e)\|c x  + b x atan(----------------------------)
+--R                                                       (b e - c d)x
+--R       + 
+--R                                                                 +------------+
+--R                             2                    2              |           2
+--R         ((- 2A b c e + (4A c  - 2B b c)d)x - 2A b e + 2A b c d)\|b d e - c d
+--R    /
+--R                        +------------+ +----------+
+--R         3       2   2  |           2  |   2
+--R       (b d e - b c d )\|b d e - c d  \|c x  + b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 560
+
+--S 561 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2          +-----------+ +-+
+--R         (A e  - B d e)\|- b e + c d \|d
+--R      *
+--R         log
+--R                                 +----------+
+--R                              2  |   2
+--R                (2b d e - 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                        +--------------+
+--R             2          |             2              (b e - 2c d)x - b d
+--R       (- A e  + B d e)\|- b d e + c d  atanh(--------------------------------)
+--R                                                                  +----------+
+--R                                                +-----------+ +-+ |   2
+--R                                              2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                    +--------------+
+--R                 2  |             2  +-----------+ +-+
+--R     (b d e - c d )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        +------------+
+--R             2          |           2              (b e - 2c d)x - b d
+--R       (- A e  + B d e)\|b d e - c d  atanh(--------------------------------)
+--R                                                                +----------+
+--R                                              +-----------+ +-+ |   2
+--R                                            2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                                               +------------+ +----------+
+--R                                               |           2  |   2
+--R            2           +-----------+ +-+     \|b d e - c d  \|c x  + b x
+--R       (2A e  - 2B d e)\|- b e + c d \|d atan(----------------------------)
+--R                                                      (b e - c d)x
+--R  /
+--R                                      +------------+
+--R                 2  +-----------+ +-+ |           2
+--R     (b d e - c d )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 1457
+t0:=(A+B*x)/((d+e*x)^2*(b*x+c*x^2)^(3/2))
+--R 
+--R
+--R                                       B x + A
+--R   (1)  ---------------------------------------------------------------------
+--R                                                                 +----------+
+--R            2 4       2           3                2  2      2   |   2
+--R        (c e x  + (b e  + 2c d e)x  + (2b d e + c d )x  + b d x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 1457
+r0:=1/2*e*(3*A*e*(2*c*d-b*e)-B*d*(4*c*d-b*e))*atanh(1/2*(b*d+(2*c*d-_
+     b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(5/2)*(c*d-_
+     b*e)^(5/2))-2*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*_
+     (c*d-b*e)*(d+e*x)*sqrt(b*x+c*x^2))-e*(4*A*c^2*d^2-b^2*e*(B*d-_
+     3*A*e)-2*b*c*d*(B*d+2*A*e))*sqrt(b*x+c*x^2)/(b^2*d^2*(c*d-b*e)^2*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                3 4          2       3    3       2   2 2         3   3
+--R           (3A b e  + (- 6A b c - B b )d e  + 4B b c d e )x + 3A b d e
+--R         + 
+--R                  2       3  2 2       2   3
+--R           (- 6A b c - B b )d e  + 4B b c d e
+--R      *
+--R          +----------+
+--R          |   2                    (b e - 2c d)x - b d
+--R         \|c x  + b x atanh(--------------------------------)
+--R                                                +----------+
+--R                              +-----------+ +-+ |   2
+--R                            2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                  2   3          2       2     2          3         2  2   2
+--R           (- 6A b c e  + (8A b c  + 2B b c)d e  + (- 8A c  + 4B b c )d e)x
+--R         + 
+--R                     3 3        2        3    2         2 2
+--R               - 6A b e  + (4A b c + 2B b )d e  + 4A b c d e
+--R             + 
+--R                      3         2  3
+--R               (- 8A c  + 4B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 3   2       2   2          2 3
+--R           - 4A b d e  + 8A b c d e - 4A b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R           4 2 3     3   3 2     2 2 4        4 3 2     3   4      2 2 5
+--R       ((2b d e  - 4b c d e  + 2b c d e)x + 2b d e  - 4b c d e + 2b c d )
+--R    *
+--R                          +----------+
+--R        +-----------+ +-+ |   2
+--R       \|- b e + c d \|d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3 4          2       3    3       2   2 2         3   3
+--R             (3A b e  + (- 6A b c - B b )d e  + 4B b c d e )x + 3A b d e
+--R           + 
+--R                    2       3  2 2       2   3
+--R             (- 6A b c - B b )d e  + 4B b c d e
+--R        *
+--R            +----------+
+--R            |   2
+--R           \|c x  + b x
+--R        *
+--R           log
+--R                                   +----------+
+--R                                2  |   2
+--R                  (2b d e - 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                    2   3          2       2     2          3         2  2   2
+--R             (- 6A b c e  + (8A b c  + 2B b c)d e  + (- 8A c  + 4B b c )d e)x
+--R           + 
+--R                       3 3        2        3    2         2 2
+--R                 - 6A b e  + (4A b c + 2B b )d e  + 4A b c d e
+--R               + 
+--R                        3         2  3
+--R                 (- 8A c  + 4B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   3   2       2   2          2 3
+--R             - 4A b d e  + 8A b c d e - 4A b c d
+--R        *
+--R            +--------------+
+--R            |             2
+--R           \|- b d e + c d
+--R    /
+--R             4 2 3     3   3 2     2 2 4        4 3 2     3   4      2 2 5
+--R         ((2b d e  - 4b c d e  + 2b c d e)x + 2b d e  - 4b c d e + 2b c d )
+--R      *
+--R          +--------------+ +----------+
+--R          |             2  |   2
+--R         \|- b d e + c d  \|c x  + b x
+--R     ,
+--R
+--R                  3 4          2       3    3       2   2 2         3   3
+--R             (3A b e  + (- 6A b c - B b )d e  + 4B b c d e )x + 3A b d e
+--R           + 
+--R                    2       3  2 2       2   3
+--R             (- 6A b c - B b )d e  + 4B b c d e
+--R        *
+--R                              +------------+ +----------+
+--R            +----------+      |           2  |   2
+--R            |   2            \|b d e - c d  \|c x  + b x
+--R           \|c x  + b x atan(----------------------------)
+--R                                     (b e - c d)x
+--R       + 
+--R                    2   3          2      2     2          3         2  2   2
+--R             (- 3A b c e  + (4A b c  + B b c)d e  + (- 4A c  + 2B b c )d e)x
+--R           + 
+--R                       3 3        2       3    2         2 2
+--R                 - 3A b e  + (2A b c + B b )d e  + 2A b c d e
+--R               + 
+--R                        3         2  3
+--R                 (- 4A c  + 2B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   3   2       2   2          2 3
+--R             - 2A b d e  + 4A b c d e - 2A b c d
+--R        *
+--R            +------------+
+--R            |           2
+--R           \|b d e - c d
+--R    /
+--R            4 2 3     3   3 2    2 2 4       4 3 2     3   4     2 2 5
+--R         ((b d e  - 2b c d e  + b c d e)x + b d e  - 2b c d e + b c d )
+--R      *
+--R          +------------+ +----------+
+--R          |           2  |   2
+--R         \|b d e - c d  \|c x  + b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 567
+
+--S 568 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                3                    2         2   +-----------+ +-+
+--R         (3A b e  + (- 6A c - B b)d e  + 4B c d e)\|- b e + c d \|d
+--R      *
+--R         log
+--R                                 +----------+
+--R                              2  |   2
+--R                (2b d e - 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                                                   +--------------+
+--R                  3                  2         2   |             2
+--R         (- 3A b e  + (6A c + B b)d e  - 4B c d e)\|- b d e + c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                                  +--------------+
+--R        2 2 2         3      2 4  |             2  +-----------+ +-+
+--R     (2b d e  - 4b c d e + 2c d )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                   +------------+
+--R                  3                  2         2   |           2
+--R         (- 3A b e  + (6A c + B b)d e  - 4B c d e)\|b d e - c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                3                      2         2   +-----------+ +-+
+--R         (6A b e  + (- 12A c - 2B b)d e  + 8B c d e)\|- b e + c d \|d
+--R      *
+--R               +------------+ +----------+
+--R               |           2  |   2
+--R              \|b d e - c d  \|c x  + b x
+--R         atan(----------------------------)
+--R                      (b e - c d)x
+--R  /
+--R                                                    +------------+
+--R        2 2 2         3      2 4  +-----------+ +-+ |           2
+--R     (2b d e  - 4b c d e + 2c d )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 571
+
+)clear all
+
+--S 572 of 1457
+t0:=(A+B*x)/((d+e*x)^3*(b*x+c*x^2)^(3/2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R            3 5       3         2  4          2       2   3        2       3  2
+--R         c e x  + (b e  + 3c d e )x  + (3b d e  + 3c d e)x  + (3b d e + c d )x
+--R       + 
+--R            3
+--R         b d x
+--R    *
+--R        +----------+
+--R        |   2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 1457
+r0:=-3/8*e*(B*d*(8*c^2*d^2-4*b*c*d*e+b^2*e^2)-A*e*(16*c^2*d^2-16*b*c*d*e+_
+     5*b^2*e^2))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*_
+     sqrt(b*x+c*x^2)))/(d^(7/2)*(c*d-b*e)^(7/2))-2*(A*b*(c*d-b*e)+_
+     c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*(d+e*x)^2*sqrt(b*x+_
+     c*x^2))-1/2*e*(8*A*c^2*d^2-b^2*e*(B*d-5*A*e)-4*b*c*d*(B*d+2*A*e))*_
+     sqrt(b*x+c*x^2)/(b^2*d^2*(c*d-b*e)^2*(d+e*x)^2)-1/4*e*(16*A*c^3*d^3-_
+     2*b^2*c*d*e*(5*B*d-19*A*e)+3*b^3*e^2*(B*d-5*A*e)-8*b*c^2*d^2*_
+     (B*d+3*A*e))*sqrt(b*x+c*x^2)/(b^2*d^3*(c*d-b*e)^3*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                    4 6           3        4    5         2 2        3   2 4
+--R               15A b e  + (- 48A b c - 3B b )d e  + (48A b c  + 12B b c)d e
+--R             + 
+--R                      2 2 3 3
+--R               - 24B b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    4   5           3        4  2 4         2 2        3   3 3
+--R               30A b d e  + (- 96A b c - 6B b )d e  + (96A b c  + 24B b c)d e
+--R             + 
+--R                      2 2 4 2
+--R               - 48B b c d e
+--R          *
+--R             x
+--R         + 
+--R                4 2 4           3        4  3 3         2 2        3   4 2
+--R           15A b d e  + (- 48A b c - 3B b )d e  + (48A b c  + 12B b c)d e
+--R         + 
+--R                  2 2 5
+--R           - 24B b c d e
+--R      *
+--R          +----------+
+--R          |   2                    (b e - 2c d)x - b d
+--R         \|c x  + b x atanh(--------------------------------)
+--R                                                +----------+
+--R                              +-----------+ +-+ |   2
+--R                            2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                      3   5         2 2       3     4
+--R               - 30A b c e  + (76A b c  + 6B b c)d e
+--R             + 
+--R                         3        2 2  2 3         4          3  3 2
+--R               (- 48A b c  - 20B b c )d e  + (32A c  - 16B b c )d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      4 5         3        4    4         2 2        3   2 3
+--R               - 30A b e  + (26A b c + 6B b )d e  + (80A b c  - 10B b c)d e
+--R             + 
+--R                         3        2 2  3 2         4          3  4
+--R               (- 80A b c  - 24B b c )d e  + (64A c  - 32B b c )d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      4   4          3         4  2 3
+--R               - 50A b d e  + (112A b c + 10B b )d e
+--R             + 
+--R                       2 2        3   3 2          3 4          4          3  5
+--R               (- 48A b c  - 24B b c)d e  - 16A b c d e + (32A c  - 16B b c )d
+--R          *
+--R             x
+--R         + 
+--R                  4 2 3        3   3 2        2 2 4           3 5
+--R           - 16A b d e  + 48A b c d e  - 48A b c d e + 16A b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R            5 3 5      4   4 4      3 2 5 3     2 3 6 2  2
+--R         (8b d e  - 24b c d e  + 24b c d e  - 8b c d e )x
+--R       + 
+--R             5 4 4      4   5 3      3 2 6 2      2 3 7        5 5 3
+--R         (16b d e  - 48b c d e  + 48b c d e  - 16b c d e)x + 8b d e
+--R       + 
+--R              4   6 2      3 2 7      2 3 8
+--R         - 24b c d e  + 24b c d e - 8b c d
+--R    *
+--R                          +----------+
+--R        +-----------+ +-+ |   2
+--R       \|- b e + c d \|d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        4 6         3        4    5           2 2        3   2 4
+--R                 - 15A b e  + (48A b c + 3B b )d e  + (- 48A b c  - 12B b c)d e
+--R               + 
+--R                      2 2 3 3
+--R                 24B b c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4   5         3        4  2 4
+--R                 - 30A b d e  + (96A b c + 6B b )d e
+--R               + 
+--R                         2 2        3   3 3        2 2 4 2
+--R                 (- 96A b c  - 24B b c)d e  + 48B b c d e
+--R            *
+--R               x
+--R           + 
+--R                    4 2 4         3        4  3 3           2 2        3   4 2
+--R             - 15A b d e  + (48A b c + 3B b )d e  + (- 48A b c  - 12B b c)d e
+--R           + 
+--R                  2 2 5
+--R             24B b c d e
+--R        *
+--R            +----------+
+--R            |   2
+--R           \|c x  + b x
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                        3   5         2 2       3     4
+--R                 - 30A b c e  + (76A b c  + 6B b c)d e
+--R               + 
+--R                           3        2 2  2 3         4          3  3 2
+--R                 (- 48A b c  - 20B b c )d e  + (32A c  - 16B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4 5         3        4    4         2 2        3   2 3
+--R                 - 30A b e  + (26A b c + 6B b )d e  + (80A b c  - 10B b c)d e
+--R               + 
+--R                           3        2 2  3 2         4          3  4
+--R                 (- 80A b c  - 24B b c )d e  + (64A c  - 32B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4   4          3         4  2 3
+--R                 - 50A b d e  + (112A b c + 10B b )d e
+--R               + 
+--R                       2 2        3   3 2          3 4          4          3  5
+--R               (- 48A b c  - 24B b c)d e  - 16A b c d e + (32A c  - 16B b c )d
+--R            *
+--R               x
+--R           + 
+--R                    4 2 3        3   3 2        2 2 4           3 5
+--R             - 16A b d e  + 48A b c d e  - 48A b c d e + 16A b c d
+--R        *
+--R            +--------------+
+--R            |             2
+--R           \|- b d e + c d
+--R    /
+--R              5 3 5      4   4 4      3 2 5 3     2 3 6 2  2
+--R           (8b d e  - 24b c d e  + 24b c d e  - 8b c d e )x
+--R         + 
+--R               5 4 4      4   5 3      3 2 6 2      2 3 7        5 5 3
+--R           (16b d e  - 48b c d e  + 48b c d e  - 16b c d e)x + 8b d e
+--R         + 
+--R                4   6 2      3 2 7      2 3 8
+--R           - 24b c d e  + 24b c d e - 8b c d
+--R      *
+--R          +--------------+ +----------+
+--R          |             2  |   2
+--R         \|- b d e + c d  \|c x  + b x
+--R     ,
+--R
+--R                      4 6           3        4    5         2 2        3   2 4
+--R                 15A b e  + (- 48A b c - 3B b )d e  + (48A b c  + 12B b c)d e
+--R               + 
+--R                        2 2 3 3
+--R                 - 24B b c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      4   5           3        4  2 4         2 2        3   3 3
+--R                 30A b d e  + (- 96A b c - 6B b )d e  + (96A b c  + 24B b c)d e
+--R               + 
+--R                        2 2 4 2
+--R                 - 48B b c d e
+--R            *
+--R               x
+--R           + 
+--R                  4 2 4           3        4  3 3         2 2        3   4 2
+--R             15A b d e  + (- 48A b c - 3B b )d e  + (48A b c  + 12B b c)d e
+--R           + 
+--R                    2 2 5
+--R             - 24B b c d e
+--R        *
+--R                              +------------+ +----------+
+--R            +----------+      |           2  |   2
+--R            |   2            \|b d e - c d  \|c x  + b x
+--R           \|c x  + b x atan(----------------------------)
+--R                                     (b e - c d)x
+--R       + 
+--R                        3   5         2 2       3     4
+--R                 - 15A b c e  + (38A b c  + 3B b c)d e
+--R               + 
+--R                           3        2 2  2 3         4         3  3 2
+--R                 (- 24A b c  - 10B b c )d e  + (16A c  - 8B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4 5         3        4    4         2 2       3   2 3
+--R                 - 15A b e  + (13A b c + 3B b )d e  + (40A b c  - 5B b c)d e
+--R               + 
+--R                           3        2 2  3 2         4          3  4
+--R                 (- 40A b c  - 12B b c )d e  + (32A c  - 16B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4   4         3        4  2 3
+--R                 - 25A b d e  + (56A b c + 5B b )d e
+--R               + 
+--R                         2 2        3   3 2         3 4          4         3  5
+--R                 (- 24A b c  - 12B b c)d e  - 8A b c d e + (16A c  - 8B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   4 2 3        3   3 2        2 2 4          3 5
+--R             - 8A b d e  + 24A b c d e  - 24A b c d e + 8A b c d
+--R        *
+--R            +------------+
+--R            |           2
+--R           \|b d e - c d
+--R    /
+--R              5 3 5      4   4 4      3 2 5 3     2 3 6 2  2
+--R           (4b d e  - 12b c d e  + 12b c d e  - 4b c d e )x
+--R         + 
+--R              5 4 4      4   5 3      3 2 6 2     2 3 7        5 5 3
+--R           (8b d e  - 24b c d e  + 24b c d e  - 8b c d e)x + 4b d e
+--R         + 
+--R                4   6 2      3 2 7      2 3 8
+--R           - 12b c d e  + 12b c d e - 4b c d
+--R      *
+--R          +------------+ +----------+
+--R          |           2  |   2
+--R         \|b d e - c d  \|c x  + b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 574
+
+--S 575 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2 4                  2    3           2            2 2
+--R           - 15A b e  + (48A b c + 3B b )d e  + (- 48A c  - 12B b c)d e
+--R         + 
+--R                2 3
+--R           24B c d e
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                  2 4                  2    3           2            2 2
+--R           - 15A b e  + (48A b c + 3B b )d e  + (- 48A c  - 12B b c)d e
+--R         + 
+--R                2 3
+--R           24B c d e
+--R      *
+--R          +--------------+
+--R          |             2              (b e - 2c d)x - b d
+--R         \|- b d e + c d  atanh(--------------------------------)
+--R                                                    +----------+
+--R                                  +-----------+ +-+ |   2
+--R                                2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                                                  +--------------+
+--R          3 3 3      2   4 2        2 5      3 6  |             2  +-----------+
+--R       (8b d e  - 24b c d e  + 24b c d e - 8c d )\|- b d e + c d  \|- b e + c d
+--R    *
+--R        +-+
+--R       \|d
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                  2 4                  2    3           2            2 2
+--R           - 15A b e  + (48A b c + 3B b )d e  + (- 48A c  - 12B b c)d e
+--R         + 
+--R                2 3
+--R           24B c d e
+--R      *
+--R          +------------+
+--R          |           2              (b e - 2c d)x - b d
+--R         \|b d e - c d  atanh(--------------------------------)
+--R                                                  +----------+
+--R                                +-----------+ +-+ |   2
+--R                              2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                  2 4                    2    3         2            2 2
+--R             30A b e  + (- 96A b c - 6B b )d e  + (96A c  + 24B b c)d e
+--R           + 
+--R                    2 3
+--R             - 48B c d e
+--R      *
+--R                                 +------------+ +----------+
+--R                                 |           2  |   2
+--R          +-----------+ +-+     \|b d e - c d  \|c x  + b x
+--R         \|- b e + c d \|d atan(----------------------------)
+--R                                        (b e - c d)x
+--R  /
+--R                                                                  +------------+
+--R        3 3 3      2   4 2        2 5      3 6  +-----------+ +-+ |           2
+--R     (8b d e  - 24b c d e  + 24b c d e - 8c d )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 578
+
+)clear all
+
+--S 579 of 1457
+t0:=(A+B*x)*(d+e*x)^4/(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R   (1)
+--R          4 5       4         3  4          3       2 2  3
+--R       B e x  + (A e  + 4B d e )x  + (4A d e  + 6B d e )x
+--R     + 
+--R            2 2       3   2        3       4        4
+--R       (6A d e  + 4B d e)x  + (4A d e + B d )x + A d
+--R  /
+--R                             +----------+
+--R       2 4         3    2 2  |   2
+--R     (c x  + 2b c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 1457
+r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^4/(b^2*(b*x+c*x^2)^(3/2))+e^3*(8*B*c*d-_
+     5*b*B*e+2*A*c*e)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(7/2)-8/3*_
+     (d+e*x)^3*(b*(b*B*d-2*A*c*d+2*A*b*e)-(4*A*c^2*d-b^2*B*e-2*b*c*(B*d+_
+     A*e))*x)/(b^4*sqrt(b*x+c*x^2))-1/3*e*(64*A*c^4*d^3-15*b^4*B*e^3-_
+     32*b*c^3*d^2*(B*d+3*A*e)+2*b^3*c*e^2*(11*B*d+3*A*e)+4*b^2*c^2*d*_
+     e*(4*B*d+5*A*e))*sqrt(b*x+c*x^2)/(b^4*c^3)-8/3*e*(4*A*c^2*d-b^2*B*e-_
+     2*b*c*(B*d+A*e))*(d+e*x)^2*sqrt(b*x+c*x^2)/(b^4*c)+2/3*e^2*(b*d*_
+     (4*b*B*c*d-8*A*c^2*d-b^2*B*e+10*A*b*c*e)-(16*A*c^3*d^2+5*b^3*B*e^2-_
+     2*A*b^2*c*e^2-8*b*c^2*d*(B*d+2*A*e))*x)*sqrt(b*x+c*x^2)/(b^4*c^2)
+--R 
+--R
+--R   (2)
+--R                 4 2        5   4        4 2   3  2
+--R           ((6A b c  - 15B b c)e  + 24B b c d e )x
+--R         + 
+--R                 5         6  4        5     3
+--R           ((6A b c - 15B b )e  + 24B b c d e )x
+--R      *
+--R          +----------+            +-+
+--R          |   2                 x\|c
+--R         \|c x  + b x atanh(-------------)
+--R                             +----------+
+--R                             |   2
+--R                            \|c x  + b x
+--R     + 
+--R               4 2 4 4
+--R           3B b c e x
+--R         + 
+--R                      4 2        5   4        3 3        4 2    3
+--R               (- 8A b c  + 20B b c)e  + (8A b c  - 32B b c )d e
+--R             + 
+--R                     2 4        3 3  2 2             5        2 4  3
+--R               (24A b c  + 12B b c )d e  + (- 64A b c  + 16B b c )d e
+--R             + 
+--R                     6          5  4
+--R               (32A c  - 16B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      5         6  4        5     3        3 3 2 2
+--R               (- 6A b c + 15B b )e  - 24B b c d e  + 36A b c d e
+--R             + 
+--R                       2 4        3 3  3            5        2 4  4
+--R               (- 96A b c  + 24B b c )d e + (48A b c  - 24B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   3 3 3          2 4       3 3  4         3 3 4
+--R           (- 24A b c d e + (12A b c  - 6B b c )d )x - 2A b c d
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                            +----------+
+--R        4 4 2     5 3   +-+ |   2
+--R     (3b c x  + 3b c x)\|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   4 2        5   4        4 2   3  2
+--R             ((6A b c  - 15B b c)e  + 24B b c d e )x
+--R           + 
+--R                   5         6  4        5     3
+--R             ((6A b c - 15B b )e  + 24B b c d e )x
+--R        *
+--R            +----------+       +----------+
+--R            |   2              |   2                     +-+
+--R           \|c x  + b x log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                 4 2 4 4
+--R             6B b c e x
+--R           + 
+--R                         4 2        5   4         3 3        4 2    3
+--R                 (- 16A b c  + 40B b c)e  + (16A b c  - 64B b c )d e
+--R               + 
+--R                       2 4        3 3  2 2              5        2 4  3
+--R                 (48A b c  + 24B b c )d e  + (- 128A b c  + 32B b c )d e
+--R               + 
+--R                       6          5  4
+--R                 (64A c  - 32B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         5         6  4        5     3        3 3 2 2
+--R                 (- 12A b c + 30B b )e  - 48B b c d e  + 72A b c d e
+--R               + 
+--R                          2 4        3 3  3            5        2 4  4
+--R                 (- 192A b c  + 48B b c )d e + (96A b c  - 48B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     3 3 3          2 4        3 3  4         3 3 4
+--R             (- 48A b c d e + (24A b c  - 12B b c )d )x - 4A b c d
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                              +----------+
+--R          4 4 2     5 3   +-+ |   2
+--R       (6b c x  + 6b c x)\|c \|c x  + b x
+--R     ,
+--R
+--R                   4 2        5   4        4 2   3  2
+--R             ((6A b c  - 15B b c)e  + 24B b c d e )x
+--R           + 
+--R                   5         6  4        5     3
+--R             ((6A b c - 15B b )e  + 24B b c d e )x
+--R        *
+--R                                    +----------+
+--R            +----------+      +---+ |   2
+--R            |   2            \|- c \|c x  + b x
+--R           \|c x  + b x atan(-------------------)
+--R                                     c x
+--R       + 
+--R                 4 2 4 4
+--R             3B b c e x
+--R           + 
+--R                        4 2        5   4        3 3        4 2    3
+--R                 (- 8A b c  + 20B b c)e  + (8A b c  - 32B b c )d e
+--R               + 
+--R                       2 4        3 3  2 2             5        2 4  3
+--R                 (24A b c  + 12B b c )d e  + (- 64A b c  + 16B b c )d e
+--R               + 
+--R                       6          5  4
+--R                 (32A c  - 16B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        5         6  4        5     3        3 3 2 2
+--R                 (- 6A b c + 15B b )e  - 24B b c d e  + 36A b c d e
+--R               + 
+--R                         2 4        3 3  3            5        2 4  4
+--R                 (- 96A b c  + 24B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     3 3 3          2 4       3 3  4         3 3 4
+--R             (- 24A b c d e + (12A b c  - 6B b c )d )x - 2A b c d
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                                +----------+
+--R          4 4 2     5 3   +---+ |   2
+--R       (3b c x  + 3b c x)\|- c \|c x  + b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 581
+
+--S 582 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                           +----------+
+--R                      4           3        |   2                     +-+
+--R       ((2A c - 5B b)e  + 8B c d e )log(2c\|c x  + b x  + (2c x + b)\|c )
+--R     + 
+--R                                                    +-+
+--R                         4            3           x\|c
+--R       ((- 4A c + 10B b)e  - 16B c d e )atanh(-------------)
+--R                                               +----------+
+--R                                               |   2
+--R                                              \|c x  + b x
+--R  /
+--R       3 +-+
+--R     2c \|c
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                        +-+
+--R                        4           3  +---+          x\|c
+--R       ((- 2A c + 5B b)e  - 8B c d e )\|- c atanh(-------------)
+--R                                                   +----------+
+--R                                                   |   2
+--R                                                  \|c x  + b x
+--R     + 
+--R                                                    +----------+
+--R                                              +---+ |   2
+--R                      4           3  +-+     \|- c \|c x  + b x
+--R       ((2A c - 5B b)e  + 8B c d e )\|c atan(-------------------)
+--R                                                     c x
+--R  /
+--R      3 +---+ +-+
+--R     c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 1457
+t0:=(A+B*x)*(d+e*x)^3/(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R   (1)
+--R      3 4       3         2  3          2       2   2        2       3        3
+--R   B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x + A d
+--R   ----------------------------------------------------------------------------
+--R                                               +----------+
+--R                         2 4         3    2 2  |   2
+--R                       (c x  + 2b c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 1457
+r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^3/(b^2*(b*x+c*x^2)^(3/2))+2*B*e^3*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(5/2)-4/3*(d+e*x)^2*(b*(2*b*B*d-_
+     4*A*c*d+3*A*b*e)-(8*A*c^2*d-b^2*B*e-4*b*c*(B*d+A*e))*x)/(b^4*_
+     sqrt(b*x+c*x^2))-2/3*e*(32*A*c^3*d^2+3*b^3*B*e^2-16*b*c^2*d*(B*d+_
+     2*A*e)+2*b^2*c*e*(2*B*d+3*A*e))*sqrt(b*x+c*x^2)/(b^4*c^2)+4/3*e^2*_
+     (b*(2*b*B*d-4*A*c*d+3*A*b*e)-(8*A*c^2*d-b^2*B*e-4*b*c*(B*d+A*e))*x)*_
+     sqrt(b*x+c*x^2)/(b^4*c)
+--R 
+--R
+--R   (2)
+--R                                +----------+            +-+
+--R            4   3 2       5 3   |   2                 x\|c
+--R       (6B b c e x  + 6B b e x)\|c x  + b x atanh(-------------)
+--R                                                   +----------+
+--R                                                   |   2
+--R                                                  \|c x  + b x
+--R     + 
+--R                    3 2       4   3         2 3       3 2    2
+--R               (2A b c  - 8B b c)e  + (12A b c  + 6B b c )d e
+--R             + 
+--R                         4        2 3  2          5          4  3
+--R               (- 48A b c  + 12B b c )d e + (32A c  - 16B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     5 3        3 2   2           2 3        3 2  2
+--R               - 6B b e  + 18A b c d e  + (- 72A b c  + 18B b c )d e
+--R             + 
+--R                       4        2 3  3
+--R               (48A b c  - 24B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   3 2 2          2 3       3 2  3         3 2 3
+--R           (- 18A b c d e + (12A b c  - 6B b c )d )x - 2A b c d
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                            +----------+
+--R        4 3 2     5 2   +-+ |   2
+--R     (3b c x  + 3b c x)\|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                    +----------+
+--R                4   3 2       5 3   |   2
+--R           (3B b c e x  + 3B b e x)\|c x  + b x
+--R        *
+--R                  +----------+
+--R                  |   2                     +-+
+--R           log(2c\|c x  + b x  + (2c x + b)\|c )
+--R       + 
+--R                      3 2       4   3         2 3       3 2    2
+--R                 (2A b c  - 8B b c)e  + (12A b c  + 6B b c )d e
+--R               + 
+--R                           4        2 3  2          5          4  3
+--R                 (- 48A b c  + 12B b c )d e + (32A c  - 16B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       5 3        3 2   2           2 3        3 2  2
+--R                 - 6B b e  + 18A b c d e  + (- 72A b c  + 18B b c )d e
+--R               + 
+--R                         4        2 3  3
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     3 2 2          2 3       3 2  3         3 2 3
+--R             (- 18A b c d e + (12A b c  - 6B b c )d )x - 2A b c d
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                              +----------+
+--R          4 3 2     5 2   +-+ |   2
+--R       (3b c x  + 3b c x)\|c \|c x  + b x
+--R     ,
+--R
+--R                                                          +----------+
+--R                                  +----------+      +---+ |   2
+--R              4   3 2       5 3   |   2            \|- c \|c x  + b x
+--R         (6B b c e x  + 6B b e x)\|c x  + b x atan(-------------------)
+--R                                                           c x
+--R       + 
+--R                      3 2       4   3         2 3       3 2    2
+--R                 (2A b c  - 8B b c)e  + (12A b c  + 6B b c )d e
+--R               + 
+--R                           4        2 3  2          5          4  3
+--R                 (- 48A b c  + 12B b c )d e + (32A c  - 16B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       5 3        3 2   2           2 3        3 2  2
+--R                 - 6B b e  + 18A b c d e  + (- 72A b c  + 18B b c )d e
+--R               + 
+--R                         4        2 3  3
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     3 2 2          2 3       3 2  3         3 2 3
+--R             (- 18A b c d e + (12A b c  - 6B b c )d )x - 2A b c d
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                                +----------+
+--R          4 3 2     5 2   +---+ |   2
+--R       (3b c x  + 3b c x)\|- c \|c x  + b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 588
+
+--S 589 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R                   +----------+                                      +-+
+--R           3       |   2                     +-+        3          x\|c
+--R        B e log(2c\|c x  + b x  + (2c x + b)\|c ) - 2B e atanh(-------------)
+--R                                                                +----------+
+--R                                                                |   2
+--R                                                               \|c x  + b x
+--R   (4)  ---------------------------------------------------------------------
+--R                                         2 +-+
+--R                                        c \|c
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                                 +----------+
+--R                                 +-+                       +---+ |   2
+--R              3 +---+          x\|c             3 +-+     \|- c \|c x  + b x
+--R        - 2B e \|- c atanh(-------------) + 2B e \|c atan(-------------------)
+--R                            +----------+                          c x
+--R                            |   2
+--R                           \|c x  + b x
+--R   (6)  ----------------------------------------------------------------------
+--R                                      2 +---+ +-+
+--R                                     c \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 592
+
+)clear all
+
+--S 593 of 1457
+t0:=(A+B*x)*(d+e*x)^2/(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R           2 3       2           2                2        2
+--R        B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d
+--R   (1)  ----------------------------------------------------
+--R                                        +----------+
+--R                  2 4         3    2 2  |   2
+--R                (c x  + 2b c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 1457
+r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^2/(b^2*(b*x+c*x^2)^(3/2))-_
+     8/3*(b*B*d-2*A*c*d+A*b*e)*(b*d+(2*c*d-b*e)*x)/(b^4*sqrt(b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R             2        3  2             2       2              3          2  2  3
+--R       ((4A b c + 2B b )e  + (- 32A b c  + 8B b c)d e + (32A c  - 16B b c )d )x
+--R     + 
+--R            3 2           2         3               2        2   2  2
+--R       (6A b e  + (- 48A b c + 12B b )d e + (48A b c  - 24B b c)d )x
+--R     + 
+--R               3            2        3  2         3 2
+--R       (- 12A b d e + (12A b c - 6B b )d )x - 2A b d
+--R  /
+--R                      +----------+
+--R        4   2     5   |   2
+--R     (3b c x  + 3b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2        3  2             2       2              3          2  2  3
+--R       ((4A b c + 2B b )e  + (- 32A b c  + 8B b c)d e + (32A c  - 16B b c )d )x
+--R     + 
+--R            3 2           2         3               2        2   2  2
+--R       (6A b e  + (- 48A b c + 12B b )d e + (48A b c  - 24B b c)d )x
+--R     + 
+--R               3            2        3  2         3 2
+--R       (- 12A b d e + (12A b c - 6B b )d )x - 2A b d
+--R  /
+--R                      +----------+
+--R        4   2     5   |   2
+--R     (3b c x  + 3b x)\|c x  + b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 595
+
+--S 596 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 597
+
+)clear all
+
+--S 598 of 1457
+t0:=(A+B*x)*(d+e*x)/(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R                  2
+--R             B e x  + (A e + B d)x + A d
+--R   (1)  ------------------------------------
+--R                                +----------+
+--R          2 4         3    2 2  |   2
+--R        (c x  + 2b c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 1457
+r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)/(b^2*(b*x+c*x^2)^(3/2))-_
+     4/3*(b*(2*b*B*d-4*A*c*d+A*b*e)-(8*A*c^2*d+b^2*B*e-_
+     4*b*c*(B*d+A*e))*x)/(b^4*sqrt(b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                  2       2            3          2    3
+--R       ((- 16A b c  + 4B b c)e + (32A c  - 16B b c )d)x
+--R     + 
+--R                2        3             2        2     2
+--R       ((- 24A b c + 6B b )e + (48A b c  - 24B b c)d)x
+--R     + 
+--R              3          2        3           3
+--R       (- 6A b e + (12A b c - 6B b )d)x - 2A b d
+--R  /
+--R                      +----------+
+--R        4   2     5   |   2
+--R     (3b c x  + 3b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2       2            3          2    3
+--R       ((- 16A b c  + 4B b c)e + (32A c  - 16B b c )d)x
+--R     + 
+--R                2        3             2        2     2
+--R       ((- 24A b c + 6B b )e + (48A b c  - 24B b c)d)x
+--R     + 
+--R              3          2        3           3
+--R       (- 6A b e + (12A b c - 6B b )d)x - 2A b d
+--R  /
+--R                      +----------+
+--R        4   2     5   |   2
+--R     (3b c x  + 3b x)\|c x  + b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 600
+
+--S 601 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 602
+
+)clear all
+
+--S 603 of 1457
+t0:=(A+B*x)/(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R                       B x + A
+--R   (1)  ------------------------------------
+--R                                +----------+
+--R          2 4         3    2 2  |   2
+--R        (c x  + 2b c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 1457
+r0:=-2/3*(A*b-(b*B-2*A*c)*x)/(b^2*(b*x+c*x^2)^(3/2))+8/3*(b*B-2*A*c)/_
+     (b^3*sqrt(b*x+c*x^2))-16/3*(b*B-2*A*c)*sqrt(b*x+c*x^2)/(b^4*x)
+--R 
+--R
+--R   (2)
+--R         3          2  3           2        2   2         2        3         3
+--R   (32A c  - 16B b c )x  + (48A b c  - 24B b c)x  + (12A b c - 6B b )x - 2A b
+--R   ---------------------------------------------------------------------------
+--R                                           +----------+
+--R                             4   2     5   |   2
+--R                          (3b c x  + 3b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3          2  3           2        2   2         2        3         3
+--R   (32A c  - 16B b c )x  + (48A b c  - 24B b c)x  + (12A b c - 6B b )x - 2A b
+--R   ---------------------------------------------------------------------------
+--R                                           +----------+
+--R                             4   2     5   |   2
+--R                          (3b c x  + 3b x)\|c x  + b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 605
+
+--S 606 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 607
+
+)clear all
+
+--S 608 of 1457
+t0:=(A+B*x)/((d+e*x)*(b*x+c*x^2)^(5/2))
+--R 
+--R
+--R                                       B x + A
+--R   (1)  --------------------------------------------------------------------
+--R                                                                +----------+
+--R          2   5              2   4     2            3    2   2  |   2
+--R        (c e x  + (2b c e + c d)x  + (b e + 2b c d)x  + b d x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 1457
+r0:=-2/3*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*_
+     (b*x+c*x^2)^(3/2))-e^3*(B*d-A*e)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(5/2)*(c*d-b*e)^(5/2))+_
+     2/3*(b*(c*d-b*e)*(8*A*c^2*d^2+3*b^2*e*(B*d-A*e)-4*b*c*d*(B*d+A*e))+_
+     c*(16*A*c^3*d^3-3*b^3*e^2*(B*d-A*e)+2*b^2*c*d*e*(7*B*d+A*e)-_
+     8*b*c^2*d^2*(B*d+3*A*e))*x)/(b^4*d^2*(c*d-b*e)^2*sqrt(b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                                                                    +----------+
+--R                 4   4       4     3  2          5 4       5   3    |   2
+--R         ((- 3A b c e  + 3B b c d e )x  + (- 3A b e  + 3B b d e )x)\|c x  + b x
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                   3 2 3        2 3       3 2    2             4        2 3  2
+--R               6A b c e  + (4A b c  - 6B b c )d e  + (- 48A b c  + 28B b c )d e
+--R             + 
+--R                     5          4  3
+--R               (32A c  - 16B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    4   3        3 2        4     2           2 3        3 2  2
+--R               12A b c e  + (6A b c  - 12B b c)d e  + (- 72A b c  + 42B b c )d e
+--R             + 
+--R                       4        2 3  3
+--R               (48A b c  - 24B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   5 3       5   2           3 2        4   2
+--R               6A b e  - 6B b d e  + (- 18A b c  + 12B b c)d e
+--R             + 
+--R                     2 3       3 2  3
+--R               (12A b c  - 6B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 5   2       4   2        3 2 3
+--R           - 2A b d e  + 4A b c d e - 2A b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R           6   2 2     5 2 3      4 3 4  2      7 2 2     6   3      5 2 4
+--R       ((3b c d e  - 6b c d e + 3b c d )x  + (3b d e  - 6b c d e + 3b c d )x)
+--R    *
+--R                          +----------+
+--R        +-----------+ +-+ |   2
+--R       \|- b e + c d \|d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                                  +----------+
+--R                 4   4       4     3  2        5 4       5   3    |   2
+--R           ((3A b c e  - 3B b c d e )x  + (3A b e  - 3B b d e )x)\|c x  + b x
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                     3 2 3        2 3       3 2    2
+--R                 6A b c e  + (4A b c  - 6B b c )d e
+--R               + 
+--R                           4        2 3  2          5          4  3
+--R                 (- 48A b c  + 28B b c )d e + (32A c  - 16B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4   3        3 2        4     2
+--R                 12A b c e  + (6A b c  - 12B b c)d e
+--R               + 
+--R                         2 3        3 2  2            4        2 3  3
+--R                 (- 72A b c  + 42B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     5 3       5   2           3 2        4   2
+--R                 6A b e  - 6B b d e  + (- 18A b c  + 12B b c)d e
+--R               + 
+--R                       2 3       3 2  3
+--R                 (12A b c  - 6B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   5   2       4   2        3 2 3
+--R             - 2A b d e  + 4A b c d e - 2A b c d
+--R        *
+--R            +--------------+
+--R            |             2
+--R           \|- b d e + c d
+--R    /
+--R             6   2 2     5 2 3      4 3 4  2      7 2 2     6   3      5 2 4
+--R         ((3b c d e  - 6b c d e + 3b c d )x  + (3b d e  - 6b c d e + 3b c d )x)
+--R      *
+--R          +--------------+ +----------+
+--R          |             2  |   2
+--R         \|- b d e + c d  \|c x  + b x
+--R     ,
+--R
+--R                   4   4       4     3  2          5 4       5   3
+--R           ((- 6A b c e  + 6B b c d e )x  + (- 6A b e  + 6B b d e )x)
+--R        *
+--R                              +------------+ +----------+
+--R            +----------+      |           2  |   2
+--R            |   2            \|b d e - c d  \|c x  + b x
+--R           \|c x  + b x atan(----------------------------)
+--R                                     (b e - c d)x
+--R       + 
+--R                     3 2 3        2 3       3 2    2
+--R                 6A b c e  + (4A b c  - 6B b c )d e
+--R               + 
+--R                           4        2 3  2          5          4  3
+--R                 (- 48A b c  + 28B b c )d e + (32A c  - 16B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4   3        3 2        4     2
+--R                 12A b c e  + (6A b c  - 12B b c)d e
+--R               + 
+--R                         2 3        3 2  2            4        2 3  3
+--R                 (- 72A b c  + 42B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     5 3       5   2           3 2        4   2
+--R                 6A b e  - 6B b d e  + (- 18A b c  + 12B b c)d e
+--R               + 
+--R                       2 3       3 2  3
+--R                 (12A b c  - 6B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   5   2       4   2        3 2 3
+--R             - 2A b d e  + 4A b c d e - 2A b c d
+--R        *
+--R            +------------+
+--R            |           2
+--R           \|b d e - c d
+--R    /
+--R             6   2 2     5 2 3      4 3 4  2      7 2 2     6   3      5 2 4
+--R         ((3b c d e  - 6b c d e + 3b c d )x  + (3b d e  - 6b c d e + 3b c d )x)
+--R      *
+--R          +------------+ +----------+
+--R          |           2  |   2
+--R         \|b d e - c d  \|c x  + b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 610
+
+--S 611 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             4        3  +-----------+ +-+
+--R         (A e  - B d e )\|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                       +--------------+
+--R           4        3  |             2              (b e - 2c d)x - b d
+--R       (A e  - B d e )\|- b d e + c d  atanh(--------------------------------)
+--R                                                                 +----------+
+--R                                               +-----------+ +-+ |   2
+--R                                             2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                                +--------------+
+--R       2 2 2         3     2 4  |             2  +-----------+ +-+
+--R     (b d e  - 2b c d e + c d )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 612
+
+--S 613 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +------------+
+--R           4        3  |           2              (b e - 2c d)x - b d
+--R       (A e  - B d e )\|b d e - c d  atanh(--------------------------------)
+--R                                                               +----------+
+--R                                             +-----------+ +-+ |   2
+--R                                           2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                                                  +------------+ +----------+
+--R                                                  |           2  |   2
+--R              4         3  +-----------+ +-+     \|b d e - c d  \|c x  + b x
+--R       (- 2A e  + 2B d e )\|- b e + c d \|d atan(----------------------------)
+--R                                                         (b e - c d)x
+--R  /
+--R                                                  +------------+
+--R       2 2 2         3     2 4  +-----------+ +-+ |           2
+--R     (b d e  - 2b c d e + c d )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 614
+
+)clear all
+
+--S 615 of 1457
+t0:=(A+B*x)/((d+e*x)^2*(b*x+c*x^2)^(5/2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R          2 2 6          2     2     5     2 2               2 2  4
+--R         c e x  + (2b c e  + 2c d e)x  + (b e  + 4b c d e + c d )x
+--R       + 
+--R            2            2  3    2 2 2
+--R         (2b d e + 2b c d )x  + b d x
+--R    *
+--R        +----------+
+--R        |   2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 1457
+r0:=-2/3*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*_
+     (d+e*x)*(b*x+c*x^2)^(3/2))-1/2*e^3*(B*d*(8*c*d-3*b*e)-5*A*e*_
+     (2*c*d-b*e))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*_
+     sqrt(b*x+c*x^2)))/(d^(7/2)*(c*d-b*e)^(7/2))+2/3*(b*(c*d-b*e)*_
+     (8*A*c^2*d^2+b^2*e*(3*B*d-5*A*e)-2*b*c*d*(2*B*d+A*e))+c*(16*A*c^3*d^3-_
+     b^3*e^2*(3*B*d-5*A*e)+2*b^2*c*d*e*(8*B*d-A*e)-8*b*c^2*d^2*(B*d+_
+     3*A*e))*x)/(b^4*d^2*(c*d-b*e)^2*(d+e*x)*sqrt(b*x+c*x^2))+1/3*e*_
+     (32*A*c^4*d^4-2*b^3*c*d*e^2*(9*B*d-10*A*e)+3*b^4*e^3*(3*B*d-5*A*e)+_
+     4*b^2*c^2*d^2*e*(10*B*d+3*A*e)-16*b*c^3*d^3*(B*d+4*A*e))*sqrt(b*x+_
+     c*x^2)/(b^4*d^3*(c*d-b*e)^3*(d+e*x))
+--R 
+--R
+--R   (2)
+--R                   5   6         4 2       5     5        4 2 2 4  3
+--R           (- 15A b c e  + (30A b c  + 9B b c)d e  - 24B b c d e )x
+--R         + 
+--R                      6 6         5        6    5         4 2        5   2 4
+--R               - 15A b e  + (15A b c + 9B b )d e  + (30A b c  - 15B b c)d e
+--R             + 
+--R                      4 2 3 3
+--R               - 24B b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   6   5         5        6  2 4        5   3 3
+--R           (- 15A b d e  + (30A b c + 9B b )d e  - 24B b c d e )x
+--R      *
+--R          +----------+
+--R          |   2                    (b e - 2c d)x - b d
+--R         \|c x  + b x atanh(--------------------------------)
+--R                                                +----------+
+--R                              +-----------+ +-+ |   2
+--R                            2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                    4 2 5           3 3        4 2    4
+--R               30A b c e  + (- 40A b c  - 18B b c )d e
+--R             + 
+--R                       2 4        3 3  2 3            5        2 4  3 2
+--R               (- 24A b c  + 36B b c )d e  + (128A b c  - 80B b c )d e
+--R             + 
+--R                       6          5  4
+--R               (- 64A c  + 32B b c )d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    5   5           4 2        5     4
+--R               60A b c e  + (- 60A b c  - 36B b c)d e
+--R             + 
+--R                       3 3        4 2  2 3          2 4        3 3  3 2
+--R               (- 76A b c  + 60B b c )d e  + (168A b c  - 84B b c )d e
+--R             + 
+--R                       5        2 4  4            6          5  5
+--R               (32A b c  - 32B b c )d e + (- 64A c  + 32B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    6 5        6   4           4 2        5   2 3
+--R               30A b e  - 18B b d e  + (- 84A b c  + 12B b c)d e
+--R             + 
+--R                     3 3        4 2  3 2          2 4         3 3  4
+--R               (12A b c  + 36B b c )d e  + (168A b c  - 108B b c )d e
+--R             + 
+--R                         5        2 4  5
+--R               (- 96A b c  + 48B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    6   4           5         6  2 3
+--R               20A b d e  + (- 36A b c - 12B b )d e
+--R             + 
+--R                       4 2        5   3 2         3 3        4 2  4
+--R               (- 12A b c  + 36B b c)d e  + (52A b c  - 36B b c )d e
+--R             + 
+--R                       2 4        3 3  5
+--R               (- 24A b c  + 12B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 6 2 3        5   3 2        4 2 4        3 3 5
+--R           - 4A b d e  + 12A b c d e  - 12A b c d e + 4A b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R            7   3 4      6 2 4 3      5 3 5 2     4 4 6   3
+--R         (6b c d e  - 18b c d e  + 18b c d e  - 6b c d e)x
+--R       + 
+--R            8 3 4      7   4 3      5 3 6      4 4 7  2
+--R         (6b d e  - 12b c d e  + 12b c d e - 6b c d )x
+--R       + 
+--R            8 4 3      7   5 2      6 2 6      5 3 7
+--R         (6b d e  - 18b c d e  + 18b c d e - 6b c d )x
+--R    *
+--R                          +----------+
+--R        +-----------+ +-+ |   2
+--R       \|- b e + c d \|d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   5   6           4 2       5     5        4 2 2 4  3
+--R             (15A b c e  + (- 30A b c  - 9B b c)d e  + 24B b c d e )x
+--R           + 
+--R                      6 6           5        6    5           4 2        5   2 4
+--R                 15A b e  + (- 15A b c - 9B b )d e  + (- 30A b c  + 15B b c)d e
+--R               + 
+--R                      4 2 3 3
+--R                 24B b c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                   6   5           5        6  2 4        5   3 3
+--R             (15A b d e  + (- 30A b c - 9B b )d e  + 24B b c d e )x
+--R        *
+--R            +----------+
+--R            |   2
+--R           \|c x  + b x
+--R        *
+--R           log
+--R                                     +----------+
+--R                                  2  |   2
+--R                  (- 2b d e + 2c d )\|c x  + b x
+--R                + 
+--R                                          +--------------+
+--R                                          |             2
+--R                  ((- b e + 2c d)x + b d)\|- b d e + c d
+--R             /
+--R                e x + d
+--R       + 
+--R                      4 2 5           3 3        4 2    4
+--R                 30A b c e  + (- 40A b c  - 18B b c )d e
+--R               + 
+--R                         2 4        3 3  2 3            5        2 4  3 2
+--R                 (- 24A b c  + 36B b c )d e  + (128A b c  - 80B b c )d e
+--R               + 
+--R                         6          5  4
+--R                 (- 64A c  + 32B b c )d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      5   5           4 2        5     4
+--R                 60A b c e  + (- 60A b c  - 36B b c)d e
+--R               + 
+--R                         3 3        4 2  2 3          2 4        3 3  3 2
+--R                 (- 76A b c  + 60B b c )d e  + (168A b c  - 84B b c )d e
+--R               + 
+--R                         5        2 4  4            6          5  5
+--R                 (32A b c  - 32B b c )d e + (- 64A c  + 32B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      6 5        6   4           4 2        5   2 3
+--R                 30A b e  - 18B b d e  + (- 84A b c  + 12B b c)d e
+--R               + 
+--R                       3 3        4 2  3 2          2 4         3 3  4
+--R                 (12A b c  + 36B b c )d e  + (168A b c  - 108B b c )d e
+--R               + 
+--R                           5        2 4  5
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      6   4           5         6  2 3
+--R                 20A b d e  + (- 36A b c - 12B b )d e
+--R               + 
+--R                         4 2        5   3 2         3 3        4 2  4
+--R                 (- 12A b c  + 36B b c)d e  + (52A b c  - 36B b c )d e
+--R               + 
+--R                         2 4        3 3  5
+--R                 (- 24A b c  + 12B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   6 2 3        5   3 2        4 2 4        3 3 5
+--R             - 4A b d e  + 12A b c d e  - 12A b c d e + 4A b c d
+--R        *
+--R            +--------------+
+--R            |             2
+--R           \|- b d e + c d
+--R    /
+--R              7   3 4      6 2 4 3      5 3 5 2     4 4 6   3
+--R           (6b c d e  - 18b c d e  + 18b c d e  - 6b c d e)x
+--R         + 
+--R              8 3 4      7   4 3      5 3 6      4 4 7  2
+--R           (6b d e  - 12b c d e  + 12b c d e - 6b c d )x
+--R         + 
+--R              8 4 3      7   5 2      6 2 6      5 3 7
+--R           (6b d e  - 18b c d e  + 18b c d e - 6b c d )x
+--R      *
+--R          +--------------+ +----------+
+--R          |             2  |   2
+--R         \|- b d e + c d  \|c x  + b x
+--R     ,
+--R
+--R                     5   6         4 2       5     5        4 2 2 4  3
+--R             (- 15A b c e  + (30A b c  + 9B b c)d e  - 24B b c d e )x
+--R           + 
+--R                        6 6         5        6    5         4 2        5   2 4
+--R                 - 15A b e  + (15A b c + 9B b )d e  + (30A b c  - 15B b c)d e
+--R               + 
+--R                        4 2 3 3
+--R                 - 24B b c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     6   5         5        6  2 4        5   3 3
+--R             (- 15A b d e  + (30A b c + 9B b )d e  - 24B b c d e )x
+--R        *
+--R                              +------------+ +----------+
+--R            +----------+      |           2  |   2
+--R            |   2            \|b d e - c d  \|c x  + b x
+--R           \|c x  + b x atan(----------------------------)
+--R                                     (b e - c d)x
+--R       + 
+--R                      4 2 5           3 3       4 2    4
+--R                 15A b c e  + (- 20A b c  - 9B b c )d e
+--R               + 
+--R                         2 4        3 3  2 3           5        2 4  3 2
+--R                 (- 12A b c  + 18B b c )d e  + (64A b c  - 40B b c )d e
+--R               + 
+--R                         6          5  4
+--R                 (- 32A c  + 16B b c )d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      5   5           4 2        5     4
+--R                 30A b c e  + (- 30A b c  - 18B b c)d e
+--R               + 
+--R                         3 3        4 2  2 3         2 4        3 3  3 2
+--R                 (- 38A b c  + 30B b c )d e  + (84A b c  - 42B b c )d e
+--R               + 
+--R                         5        2 4  4            6          5  5
+--R                 (16A b c  - 16B b c )d e + (- 32A c  + 16B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      6 5       6   4           4 2       5   2 3
+--R                 15A b e  - 9B b d e  + (- 42A b c  + 6B b c)d e
+--R               + 
+--R                      3 3        4 2  3 2         2 4        3 3  4
+--R                 (6A b c  + 18B b c )d e  + (84A b c  - 54B b c )d e
+--R               + 
+--R                           5        2 4  5
+--R                 (- 48A b c  + 24B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      6   4           5        6  2 3
+--R                 10A b d e  + (- 18A b c - 6B b )d e
+--R               + 
+--R                        4 2        5   3 2         3 3        4 2  4
+--R                 (- 6A b c  + 18B b c)d e  + (26A b c  - 18B b c )d e
+--R               + 
+--R                         2 4       3 3  5
+--R                 (- 12A b c  + 6B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   6 2 3       5   3 2       4 2 4        3 3 5
+--R             - 2A b d e  + 6A b c d e  - 6A b c d e + 2A b c d
+--R        *
+--R            +------------+
+--R            |           2
+--R           \|b d e - c d
+--R    /
+--R              7   3 4     6 2 4 3     5 3 5 2     4 4 6   3
+--R           (3b c d e  - 9b c d e  + 9b c d e  - 3b c d e)x
+--R         + 
+--R              8 3 4     7   4 3     5 3 6      4 4 7  2
+--R           (3b d e  - 6b c d e  + 6b c d e - 3b c d )x
+--R         + 
+--R              8 4 3     7   5 2     6 2 6      5 3 7
+--R           (3b d e  - 9b c d e  + 9b c d e - 3b c d )x
+--R      *
+--R          +------------+ +----------+
+--R          |           2  |   2
+--R         \|b d e - c d  \|c x  + b x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 617
+
+--S 618 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                5                      4         2 3  +-----------+ +-+
+--R         (5A b e  + (- 10A c - 3B b)d e  + 8B c d e )\|- b e + c d \|d
+--R      *
+--R         log
+--R                                   +----------+
+--R                                2  |   2
+--R                (- 2b d e + 2c d )\|c x  + b x
+--R              + 
+--R                                        +--------------+
+--R                                        |             2
+--R                ((- b e + 2c d)x + b d)\|- b d e + c d
+--R           /
+--R              e x + d
+--R     + 
+--R                                                      +--------------+
+--R                5                      4         2 3  |             2
+--R         (5A b e  + (- 10A c - 3B b)d e  + 8B c d e )\|- b d e + c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R  /
+--R                                              +--------------+
+--R        3 3 3     2   4 2       2 5      3 6  |             2  +-----------+ +-+
+--R     (2b d e  - 6b c d e  + 6b c d e - 2c d )\|- b d e + c d  \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 619
+
+--S 620 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                      +------------+
+--R                5                      4         2 3  |           2
+--R         (5A b e  + (- 10A c - 3B b)d e  + 8B c d e )\|b d e - c d
+--R      *
+--R                      (b e - 2c d)x - b d
+--R         atanh(--------------------------------)
+--R                                   +----------+
+--R                 +-----------+ +-+ |   2
+--R               2\|- b e + c d \|d \|c x  + b x
+--R     + 
+--R                   5                    4          2 3  +-----------+ +-+
+--R         (- 10A b e  + (20A c + 6B b)d e  - 16B c d e )\|- b e + c d \|d
+--R      *
+--R               +------------+ +----------+
+--R               |           2  |   2
+--R              \|b d e - c d  \|c x  + b x
+--R         atan(----------------------------)
+--R                      (b e - c d)x
+--R  /
+--R                                                                +------------+
+--R        3 3 3     2   4 2       2 5      3 6  +-----------+ +-+ |           2
+--R     (2b d e  - 6b c d e  + 6b c d e - 2c d )\|- b e + c d \|d \|b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 621
+
+)clear all
+
+--S 622 of 1457
+t0:=(A+B*x)*(d+e*x)^(7/2)*(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R            3 6                3           2  5
+--R       B c e x  + ((A c + B b)e  + 3B c d e )x
+--R     + 
+--R             3                   2         2   4
+--R       (A b e  + (3A c + 3B b)d e  + 3B c d e)x
+--R     + 
+--R                2                 2         3  3          2                3  2
+--R       (3A b d e  + (3A c + 3B b)d e + B c d )x  + (3A b d e + (A c + B b)d )x
+--R     + 
+--R            3
+--R       A b d x
+--R  *
+--R      +-------+
+--R     \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 1457
+r0:=-2/9*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^(9/2)/e^4+2/11*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^(11/2)/e^4-2/13*(3*B*c*d-b*B*e-A*c*e)*_
+     (d+e*x)^(13/2)/e^4+2/15*B*c*(d+e*x)^(15/2)/e^4
+--R 
+--R
+--R   (2)
+--R                 7 7                      7              6  6
+--R         858B c e x  + ((990A c + 990B b)e  + 3036B c d e )x
+--R       + 
+--R                   7                         6            2 5  5
+--R         (1170A b e  + (3600A c + 3600B b)d e  + 3708B c d e )x
+--R       + 
+--R                     6                       2 5            3 4  4
+--R         (4420A b d e  + (4580A c + 4580B b)d e  + 1600B c d e )x
+--R       + 
+--R                   2 5                       3 4          4 3  3
+--R         (5980A b d e  + (2120A c + 2120B b)d e  + 10B c d e )x
+--R       + 
+--R                   3 4                   4 3          5 2  2
+--R         (3120A b d e  + (30A c + 30B b)d e  - 12B c d e )x
+--R       + 
+--R                  4 3                     5 2          6              5 2
+--R         (130A b d e  + (- 40A c - 40B b)d e  + 16B c d e)x - 260A b d e
+--R       + 
+--R                         6           7
+--R         (80A c + 80B b)d e - 32B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R          4
+--R     6435e
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 7 7                      7              6  6
+--R         858B c e x  + ((990A c + 990B b)e  + 3036B c d e )x
+--R       + 
+--R                   7                         6            2 5  5
+--R         (1170A b e  + (3600A c + 3600B b)d e  + 3708B c d e )x
+--R       + 
+--R                     6                       2 5            3 4  4
+--R         (4420A b d e  + (4580A c + 4580B b)d e  + 1600B c d e )x
+--R       + 
+--R                   2 5                       3 4          4 3  3
+--R         (5980A b d e  + (2120A c + 2120B b)d e  + 10B c d e )x
+--R       + 
+--R                   3 4                   4 3          5 2  2
+--R         (3120A b d e  + (30A c + 30B b)d e  - 12B c d e )x
+--R       + 
+--R                  4 3                     5 2          6              5 2
+--R         (130A b d e  + (- 40A c - 40B b)d e  + 16B c d e)x - 260A b d e
+--R       + 
+--R                         6           7
+--R         (80A c + 80B b)d e - 32B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R          4
+--R     6435e
+--R                                         Type: Union(Expression(Integer),...)
+--E 624
+
+--S 625 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 626
+
+)clear all
+
+--S 627 of 1457
+t0:=(A+B*x)*(d+e*x)^(5/2)*(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R            2 5                2             4
+--R       B c e x  + ((A c + B b)e  + 2B c d e)x
+--R     + 
+--R             2                           2  3                           2  2
+--R       (A b e  + (2A c + 2B b)d e + B c d )x  + (2A b d e + (A c + B b)d )x
+--R     + 
+--R            2
+--R       A b d x
+--R  *
+--R      +-------+
+--R     \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 1457
+r0:=-2/7*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^(7/2)/e^4+2/9*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^(9/2)/e^4-2/11*(3*B*c*d-b*B*e-A*c*e)*_
+     (d+e*x)^(11/2)/e^4+2/13*B*c*(d+e*x)^(13/2)/e^4
+--R 
+--R
+--R   (2)
+--R                  6 6                        6              5  5
+--R         1386B c e x  + ((1638A c + 1638B b)e  + 3402B c d e )x
+--R       + 
+--R                   6                         5            2 4  4
+--R         (2002A b e  + (4186A c + 4186B b)d e  + 2226B c d e )x
+--R       + 
+--R                     5                       2 4          3 3  3
+--R         (5434A b d e  + (2938A c + 2938B b)d e  + 30B c d e )x
+--R       + 
+--R                   2 4                   3 3          4 2  2
+--R         (4290A b d e  + (78A c + 78B b)d e  - 36B c d e )x
+--R       + 
+--R                  3 3                       4 2          5              4 2
+--R         (286A b d e  + (- 104A c - 104B b)d e  + 48B c d e)x - 572A b d e
+--R       + 
+--R                           5           6
+--R         (208A c + 208B b)d e - 96B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R          4
+--R     9009e
+--R                                                    Type: Expression(Integer)
+--E 628
+
+--S 629 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  6 6                        6              5  5
+--R         1386B c e x  + ((1638A c + 1638B b)e  + 3402B c d e )x
+--R       + 
+--R                   6                         5            2 4  4
+--R         (2002A b e  + (4186A c + 4186B b)d e  + 2226B c d e )x
+--R       + 
+--R                     5                       2 4          3 3  3
+--R         (5434A b d e  + (2938A c + 2938B b)d e  + 30B c d e )x
+--R       + 
+--R                   2 4                   3 3          4 2  2
+--R         (4290A b d e  + (78A c + 78B b)d e  - 36B c d e )x
+--R       + 
+--R                  3 3                       4 2          5              4 2
+--R         (286A b d e  + (- 104A c - 104B b)d e  + 48B c d e)x - 572A b d e
+--R       + 
+--R                           5           6
+--R         (208A c + 208B b)d e - 96B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R          4
+--R     9009e
+--R                                         Type: Union(Expression(Integer),...)
+--E 629
+
+--S 630 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 631
+
+)clear all
+
+--S 632 of 1457
+t0:=(A+B*x)*(d+e*x)^(3/2)*(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R             4                          3                          2
+--R     (B c e x  + ((A c + B b)e + B c d)x  + (A b e + (A c + B b)d)x  + A b d x)
+--R  *
+--R      +-------+
+--R     \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 1457
+r0:=-2/5*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^(5/2)/e^4+2/7*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^(7/2)/e^4-2/9*(3*B*c*d-b*B*e-A*c*e)*_
+     (d+e*x)^(9/2)/e^4+2/11*B*c*(d+e*x)^(11/2)/e^4
+--R 
+--R
+--R   (2)
+--R                 5 5                      5             4  4
+--R         630B c e x  + ((770A c + 770B b)e  + 840B c d e )x
+--R       + 
+--R                  5                         4          2 3  3
+--R         (990A b e  + (1100A c + 1100B b)d e  + 30B c d e )x
+--R       + 
+--R                     4                   2 3          3 2  2
+--R         (1584A b d e  + (66A c + 66B b)d e  - 36B c d e )x
+--R       + 
+--R                  2 3                     3 2          4              3 2
+--R         (198A b d e  + (- 88A c - 88B b)d e  + 48B c d e)x - 396A b d e
+--R       + 
+--R                           4           5
+--R         (176A c + 176B b)d e - 96B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R          4
+--R     3465e
+--R                                                    Type: Expression(Integer)
+--E 633
+
+--S 634 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 5 5                      5             4  4
+--R         630B c e x  + ((770A c + 770B b)e  + 840B c d e )x
+--R       + 
+--R                  5                         4          2 3  3
+--R         (990A b e  + (1100A c + 1100B b)d e  + 30B c d e )x
+--R       + 
+--R                     4                   2 3          3 2  2
+--R         (1584A b d e  + (66A c + 66B b)d e  - 36B c d e )x
+--R       + 
+--R                  2 3                     3 2          4              3 2
+--R         (198A b d e  + (- 88A c - 88B b)d e  + 48B c d e)x - 396A b d e
+--R       + 
+--R                           4           5
+--R         (176A c + 176B b)d e - 96B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R          4
+--R     3465e
+--R                                         Type: Union(Expression(Integer),...)
+--E 634
+
+--S 635 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 636
+
+)clear all
+
+--S 637 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)*sqrt(d+e*x)
+--R 
+--R
+--R              3               2          +-------+
+--R   (1)  (B c x  + (A c + B b)x  + A b x)\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 1457
+r0:=-2/3*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^(3/2)/e^4+2/5*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^(5/2)/e^4-2/7*(3*B*c*d-b*B*e-A*c*e)*_
+     (d+e*x)^(7/2)/e^4+2/9*B*c*(d+e*x)^(9/2)/e^4
+--R 
+--R
+--R   (2)
+--R                4 4                    4            3  3
+--R         70B c e x  + ((90A c + 90B b)e  + 10B c d e )x
+--R       + 
+--R                  4                     3          2 2  2
+--R         (126A b e  + (18A c + 18B b)d e  - 12B c d e )x
+--R       + 
+--R                   3                     2 2          3             2 2
+--R         (42A b d e  + (- 24A c - 24B b)d e  + 16B c d e)x - 84A b d e
+--R       + 
+--R                         3           4
+--R         (48A c + 48B b)d e - 32B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R         4
+--R     315e
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4 4                    4            3  3
+--R         70B c e x  + ((90A c + 90B b)e  + 10B c d e )x
+--R       + 
+--R                  4                     3          2 2  2
+--R         (126A b e  + (18A c + 18B b)d e  - 12B c d e )x
+--R       + 
+--R                   3                     2 2          3             2 2
+--R         (42A b d e  + (- 24A c - 24B b)d e  + 16B c d e)x - 84A b d e
+--R       + 
+--R                         3           4
+--R         (48A c + 48B b)d e - 32B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R         4
+--R     315e
+--R                                         Type: Union(Expression(Integer),...)
+--E 639
+
+--S 640 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 641
+
+)clear all
+
+--S 642 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/sqrt(d+e*x)
+--R 
+--R
+--R             3               2
+--R        B c x  + (A c + B b)x  + A b x
+--R   (1)  ------------------------------
+--R                   +-------+
+--R                  \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 642
+
+--S 643 of 1457
+r0:=2/3*(B*d*(3*c*d-2*b*e)-A*e*(2*c*d-b*e))*(d+e*x)^(3/2)/e^4-2/5*(3*B*c*d-_
+     b*B*e-A*c*e)*(d+e*x)^(5/2)/e^4+2/7*B*c*(d+e*x)^(7/2)/e^4-2*d*_
+     (B*d-A*e)*(c*d-b*e)*sqrt(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R                3 3                    3            2  2
+--R         30B c e x  + ((42A c + 42B b)e  - 36B c d e )x
+--R       + 
+--R                 3                       2          2                2
+--R         (70A b e  + (- 56A c - 56B b)d e  + 48B c d e)x - 140A b d e
+--R       + 
+--R                           2           3
+--R         (112A c + 112B b)d e - 96B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R         4
+--R     105e
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 3                    3            2  2
+--R         30B c e x  + ((42A c + 42B b)e  - 36B c d e )x
+--R       + 
+--R                 3                       2          2                2
+--R         (70A b e  + (- 56A c - 56B b)d e  + 48B c d e)x - 140A b d e
+--R       + 
+--R                           2           3
+--R         (112A c + 112B b)d e - 96B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R         4
+--R     105e
+--R                                         Type: Union(Expression(Integer),...)
+--E 644
+
+--S 645 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 645
+
+--S 646 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 646
+
+)clear all
+
+--S 647 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^(3/2)
+--R 
+--R
+--R             3               2
+--R        B c x  + (A c + B b)x  + A b x
+--R   (1)  ------------------------------
+--R                        +-------+
+--R              (e x + d)\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 1457
+r0:=-2/3*(3*B*c*d-b*B*e-A*c*e)*(d+e*x)^(3/2)/e^4+2/5*B*c*(d+e*x)^(5/2)/e^4+_
+     2*d*(B*d-A*e)*(c*d-b*e)/(e^4*sqrt(d+e*x))+2*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*sqrt(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R             3 3                    3            2  2
+--R       6B c e x  + ((10A c + 10B b)e  - 12B c d e )x
+--R     + 
+--R               3                       2          2               2
+--R       (30A b e  + (- 40A c - 40B b)d e  + 48B c d e)x + 60A b d e
+--R     + 
+--R                         2           3
+--R       (- 80A c - 80B b)d e + 96B c d
+--R  /
+--R        4 +-------+
+--R     15e \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3 3                    3            2  2
+--R       6B c e x  + ((10A c + 10B b)e  - 12B c d e )x
+--R     + 
+--R               3                       2          2               2
+--R       (30A b e  + (- 40A c - 40B b)d e  + 48B c d e)x + 60A b d e
+--R     + 
+--R                         2           3
+--R       (- 80A c - 80B b)d e + 96B c d
+--R  /
+--R        4 +-------+
+--R     15e \|e x + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 649
+
+--S 650 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 651
+
+)clear all
+
+--S 652 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^(5/2)
+--R 
+--R
+--R             3               2
+--R        B c x  + (A c + B b)x  + A b x
+--R   (1)  ------------------------------
+--R          2 2             2  +-------+
+--R        (e x  + 2d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 1457
+r0:=2/3*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^(3/2))+2/3*B*c*(d+e*x)^(3/2)/e^4-_
+     2*(B*d*(3*c*d-2*b*e)-A*e*(2*c*d-b*e))/(e^4*sqrt(d+e*x))-_
+     2*(3*B*c*d-b*B*e-A*c*e)*sqrt(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R             3 3                  3            2  2
+--R       2B c e x  + ((6A c + 6B b)e  - 12B c d e )x
+--R     + 
+--R                3                     2          2              2
+--R       (- 6A b e  + (24A c + 24B b)d e  - 48B c d e)x - 4A b d e
+--R     + 
+--R                       2           3
+--R       (16A c + 16B b)d e - 32B c d
+--R  /
+--R        5        4  +-------+
+--R     (3e x + 3d e )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 653
+
+--S 654 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3 3                  3            2  2
+--R       2B c e x  + ((6A c + 6B b)e  - 12B c d e )x
+--R     + 
+--R                3                     2          2              2
+--R       (- 6A b e  + (24A c + 24B b)d e  - 48B c d e)x - 4A b d e
+--R     + 
+--R                       2           3
+--R       (16A c + 16B b)d e - 32B c d
+--R  /
+--R        5        4  +-------+
+--R     (3e x + 3d e )\|e x + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 654
+
+--S 655 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 656
+
+)clear all
+
+--S 657 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^(7/2)
+--R 
+--R
+--R                  3               2
+--R             B c x  + (A c + B b)x  + A b x
+--R   (1)  ----------------------------------------
+--R          3 3       2 2     2       3  +-------+
+--R        (e x  + 3d e x  + 3d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 657
+
+--S 658 of 1457
+r0:=2/5*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^(5/2))-2/3*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))/(e^4*(d+e*x)^(3/2))+2*(3*B*c*d-b*B*e-A*c*e)/_
+     (e^4*sqrt(d+e*x))+2*B*c*sqrt(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R              3 3                      3             2  2
+--R       30B c e x  + ((- 30A c - 30B b)e  + 180B c d e )x
+--R     + 
+--R                 3                       2           2              2
+--R       (- 10A b e  + (- 40A c - 40B b)d e  + 240B c d e)x - 4A b d e
+--R     + 
+--R                         2           3
+--R       (- 16A c - 16B b)d e + 96B c d
+--R  /
+--R         6 2        5       2 4  +-------+
+--R     (15e x  + 30d e x + 15d e )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 658
+
+--S 659 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 3                      3             2  2
+--R       30B c e x  + ((- 30A c - 30B b)e  + 180B c d e )x
+--R     + 
+--R                 3                       2           2              2
+--R       (- 10A b e  + (- 40A c - 40B b)d e  + 240B c d e)x - 4A b d e
+--R     + 
+--R                         2           3
+--R       (- 16A c - 16B b)d e + 96B c d
+--R  /
+--R         6 2        5       2 4  +-------+
+--R     (15e x  + 30d e x + 15d e )\|e x + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 659
+
+--S 660 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 661
+
+)clear all
+
+--S 662 of 1457
+t0:=(A+B*x)*(d+e*x)^(7/2)*(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R          2 3 8        2           3       2   2  7
+--R       B c e x  + ((A c  + 2B b c)e  + 3B c d e )x
+--R     + 
+--R                     2  3        2             2       2 2   6
+--R       ((2A b c + B b )e  + (3A c  + 6B b c)d e  + 3B c d e)x
+--R     + 
+--R           2 3                 2    2        2           2       2 3  5
+--R       (A b e  + (6A b c + 3B b )d e  + (3A c  + 6B b c)d e + B c d )x
+--R     + 
+--R            2   2                 2  2        2           3  4
+--R       (3A b d e  + (6A b c + 3B b )d e + (A c  + 2B b c)d )x
+--R     + 
+--R            2 2                 2  3  3      2 3 2
+--R       (3A b d e + (2A b c + B b )d )x  + A b d x
+--R  *
+--R      +-------+
+--R     \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 1457
+r0:=-2/9*d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^(9/2)/e^6+2/11*d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(11/2)/e^6+_
+     2/13*(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*(d+e*x)^(13/2)/e^6-2/15*(2*A*c*e*(2*c*d-b*e)-_
+     B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*(d+e*x)^(15/2)/e^6-2/17*c*_
+     (5*B*c*d-2*b*B*e-A*c*e)*(d+e*x)^(17/2)/e^6+2/19*B*c^2*(d+e*x)^(19/2)/e^6
+--R 
+--R
+--R   (2)
+--R                  2 9 9              2                9            2   8  8
+--R         218790B c e x  + ((244530A c  + 489060B b c)e  + 746460B c d e )x
+--R       + 
+--R                                     2  9             2                   8
+--R             (554268A b c + 277134B b )e  + (847704A c  + 1695408B b c)d e
+--R           + 
+--R                      2 2 7
+--R             866580B c d e
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                      2 9                            2    8
+--R             319770A b e  + (1961256A b c + 980628B b )d e
+--R           + 
+--R                        2                 2 7            2 3 6
+--R             (1005708A c  + 2011416B b c)d e  + 345840B c d e
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                       2   8                             2  2 7
+--R             1162800A b d e  + (2395368A b c + 1197684B b )d e
+--R           + 
+--R                       2                3 6         2 4 5
+--R             (414504A c  + 829008B b c)d e  + 630B c d e
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                       2 2 7                            2  3 6
+--R             1479340A b d e  + (1033600A b c + 516800B b )d e
+--R           + 
+--R                     2              4 5         2 5 4
+--R             (1330A c  + 2660B b c)d e  - 700B c d e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                      2 3 6                       2  4 5
+--R             684760A b d e  + (6460A b c + 3230B b )d e
+--R           + 
+--R                       2              5 4         2 6 3
+--R             (- 1520A c  - 3040B b c)d e  + 800B c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                    2 4 5                         2  5 4
+--R             9690A b d e  + (- 7752A b c - 3876B b )d e
+--R           + 
+--R                     2              6 3         2 7 2
+--R             (1824A c  + 3648B b c)d e  - 960B c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                       2 5 4                        2  6 3
+--R             - 12920A b d e  + (10336A b c + 5168B b )d e
+--R           + 
+--R                       2              7 2          2 8
+--R             (- 2432A c  - 4864B b c)d e  + 1280B c d e
+--R        *
+--R           x
+--R       + 
+--R                 2 6 3                           2  7 2
+--R         25840A b d e  + (- 20672A b c - 10336B b )d e
+--R       + 
+--R                 2              8           2 9
+--R         (4864A c  + 9728B b c)d e - 2560B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R             6
+--R     2078505e
+--R                                                    Type: Expression(Integer)
+--E 663
+
+--S 664 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2 9 9              2                9            2   8  8
+--R         218790B c e x  + ((244530A c  + 489060B b c)e  + 746460B c d e )x
+--R       + 
+--R                                     2  9             2                   8
+--R             (554268A b c + 277134B b )e  + (847704A c  + 1695408B b c)d e
+--R           + 
+--R                      2 2 7
+--R             866580B c d e
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                      2 9                            2    8
+--R             319770A b e  + (1961256A b c + 980628B b )d e
+--R           + 
+--R                        2                 2 7            2 3 6
+--R             (1005708A c  + 2011416B b c)d e  + 345840B c d e
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                       2   8                             2  2 7
+--R             1162800A b d e  + (2395368A b c + 1197684B b )d e
+--R           + 
+--R                       2                3 6         2 4 5
+--R             (414504A c  + 829008B b c)d e  + 630B c d e
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                       2 2 7                            2  3 6
+--R             1479340A b d e  + (1033600A b c + 516800B b )d e
+--R           + 
+--R                     2              4 5         2 5 4
+--R             (1330A c  + 2660B b c)d e  - 700B c d e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                      2 3 6                       2  4 5
+--R             684760A b d e  + (6460A b c + 3230B b )d e
+--R           + 
+--R                       2              5 4         2 6 3
+--R             (- 1520A c  - 3040B b c)d e  + 800B c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                    2 4 5                         2  5 4
+--R             9690A b d e  + (- 7752A b c - 3876B b )d e
+--R           + 
+--R                     2              6 3         2 7 2
+--R             (1824A c  + 3648B b c)d e  - 960B c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                       2 5 4                        2  6 3
+--R             - 12920A b d e  + (10336A b c + 5168B b )d e
+--R           + 
+--R                       2              7 2          2 8
+--R             (- 2432A c  - 4864B b c)d e  + 1280B c d e
+--R        *
+--R           x
+--R       + 
+--R                 2 6 3                           2  7 2
+--R         25840A b d e  + (- 20672A b c - 10336B b )d e
+--R       + 
+--R                 2              8           2 9
+--R         (4864A c  + 9728B b c)d e - 2560B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R             6
+--R     2078505e
+--R                                         Type: Union(Expression(Integer),...)
+--E 664
+
+--S 665 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 666
+
+)clear all
+
+--S 667 of 1457
+t0:=(A+B*x)*(d+e*x)^(5/2)*(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R          2 2 7        2           2       2     6
+--R       B c e x  + ((A c  + 2B b c)e  + 2B c d e)x
+--R     + 
+--R                     2  2        2                   2 2  5
+--R       ((2A b c + B b )e  + (2A c  + 4B b c)d e + B c d )x
+--R     + 
+--R           2 2                 2           2           2  4
+--R       (A b e  + (4A b c + 2B b )d e + (A c  + 2B b c)d )x
+--R     + 
+--R            2                   2  2  3      2 2 2
+--R       (2A b d e + (2A b c + B b )d )x  + A b d x
+--R  *
+--R      +-------+
+--R     \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 1457
+r0:=-2/7*d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^(7/2)/e^6+2/9*d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(9/2)/e^6+2/11*_
+     (A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*(d+e*x)^(11/2)/e^6-2/13*(2*A*c*e*(2*c*d-b*e)-_
+     B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*(d+e*x)^(13/2)/e^6-2/15*c*_
+     (5*B*c*d-2*b*B*e-A*c*e)*(d+e*x)^(15/2)/e^6+2/17*B*c^2*(d+e*x)^(17/2)/e^6
+--R 
+--R
+--R   (2)
+--R                 2 8 8              2                8            2   7  7
+--R         90090B c e x  + ((102102A c  + 204204B b c)e  + 210210B c d e )x
+--R       + 
+--R                                     2  8             2                  7
+--R             (235620A b c + 117810B b )e  + (243474A c  + 486948B b c)d e
+--R           + 
+--R                      2 2 6
+--R             127050B c d e
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                      2 8                           2    7
+--R             139230A b e  + (578340A b c + 289170B b )d e
+--R           + 
+--R                       2                2 6         2 3 5
+--R             (152082A c  + 304164B b c)d e  + 630B c d e
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                      2   7                           2  2 6
+--R             355810A b d e  + (378420A b c + 189210B b )d e
+--R           + 
+--R                     2              3 5         2 4 4
+--R             (1190A c  + 2380B b c)d e  - 700B c d e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                      2 2 6                       2  3 5
+--R             249730A b d e  + (5100A b c + 2550B b )d e
+--R           + 
+--R                       2              4 4         2 5 3
+--R             (- 1360A c  - 2720B b c)d e  + 800B c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                    2 3 5                         2  4 4
+--R             6630A b d e  + (- 6120A b c - 3060B b )d e
+--R           + 
+--R                     2              5 3         2 6 2
+--R             (1632A c  + 3264B b c)d e  - 960B c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                      2 4 4                       2  5 3
+--R             - 8840A b d e  + (8160A b c + 4080B b )d e
+--R           + 
+--R                       2              6 2          2 7
+--R             (- 2176A c  - 4352B b c)d e  + 1280B c d e
+--R        *
+--R           x
+--R       + 
+--R                 2 5 3                          2  6 2
+--R         17680A b d e  + (- 16320A b c - 8160B b )d e
+--R       + 
+--R                 2              7           2 8
+--R         (4352A c  + 8704B b c)d e - 2560B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R            6
+--R     765765e
+--R                                                    Type: Expression(Integer)
+--E 668
+
+--S 669 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2 8 8              2                8            2   7  7
+--R         90090B c e x  + ((102102A c  + 204204B b c)e  + 210210B c d e )x
+--R       + 
+--R                                     2  8             2                  7
+--R             (235620A b c + 117810B b )e  + (243474A c  + 486948B b c)d e
+--R           + 
+--R                      2 2 6
+--R             127050B c d e
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                      2 8                           2    7
+--R             139230A b e  + (578340A b c + 289170B b )d e
+--R           + 
+--R                       2                2 6         2 3 5
+--R             (152082A c  + 304164B b c)d e  + 630B c d e
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                      2   7                           2  2 6
+--R             355810A b d e  + (378420A b c + 189210B b )d e
+--R           + 
+--R                     2              3 5         2 4 4
+--R             (1190A c  + 2380B b c)d e  - 700B c d e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                      2 2 6                       2  3 5
+--R             249730A b d e  + (5100A b c + 2550B b )d e
+--R           + 
+--R                       2              4 4         2 5 3
+--R             (- 1360A c  - 2720B b c)d e  + 800B c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                    2 3 5                         2  4 4
+--R             6630A b d e  + (- 6120A b c - 3060B b )d e
+--R           + 
+--R                     2              5 3         2 6 2
+--R             (1632A c  + 3264B b c)d e  - 960B c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                      2 4 4                       2  5 3
+--R             - 8840A b d e  + (8160A b c + 4080B b )d e
+--R           + 
+--R                       2              6 2          2 7
+--R             (- 2176A c  - 4352B b c)d e  + 1280B c d e
+--R        *
+--R           x
+--R       + 
+--R                 2 5 3                          2  6 2
+--R         17680A b d e  + (- 16320A b c - 8160B b )d e
+--R       + 
+--R                 2              7           2 8
+--R         (4352A c  + 8704B b c)d e - 2560B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R            6
+--R     765765e
+--R                                         Type: Union(Expression(Integer),...)
+--E 669
+
+--S 670 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 671
+
+)clear all
+
+--S 672 of 1457
+t0:=(A+B*x)*(d+e*x)^(3/2)*(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R          2   6        2                 2   5
+--R       B c e x  + ((A c  + 2B b c)e + B c d)x
+--R     + 
+--R                     2         2             4       2                 2    3
+--R       ((2A b c + B b )e + (A c  + 2B b c)d)x  + (A b e + (2A b c + B b )d)x
+--R     + 
+--R          2   2
+--R       A b d x
+--R  *
+--R      +-------+
+--R     \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 1457
+r0:=-2/5*d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^(5/2)/e^6+2/7*d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(7/2)/e^6+2/9*(A*e*_
+     (6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*_
+     (d+e*x)^(9/2)/e^6-2/11*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-8*b*c*d*e+_
+     b^2*e^2))*(d+e*x)^(11/2)/e^6-2/13*c*(5*B*c*d-2*b*B*e-A*c*e)*_
+     (d+e*x)^(13/2)/e^6+2/15*B*c^2*(d+e*x)^(15/2)/e^6
+--R 
+--R
+--R   (2)
+--R                2 7 7            2               7          2   6  6
+--R         6006B c e x  + ((6930A c  + 13860B b c)e  + 7392B c d e )x
+--R       + 
+--R                                    2  7           2                 6
+--R               (16380A b c + 8190B b )e  + (8820A c  + 17640B b c)d e
+--R             + 
+--R                     2 2 5
+--R               126B c d e
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                     2 7                         2    6
+--R             10010A b e  + (21840A b c + 10920B b )d e
+--R           + 
+--R                    2             2 5         2 3 4
+--R             (210A c  + 420B b c)d e  - 140B c d e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                     2   6                     2  2 5
+--R             14300A b d e  + (780A b c + 390B b )d e
+--R           + 
+--R                      2             3 4         2 4 3
+--R             (- 240A c  - 480B b c)d e  + 160B c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                   2 2 5                       2  3 4          2             4 3
+--R             858A b d e  + (- 936A b c - 468B b )d e  + (288A c  + 576B b c)d e
+--R           + 
+--R                     2 5 2
+--R             - 192B c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                      2 3 4                      2  4 3
+--R             - 1144A b d e  + (1248A b c + 624B b )d e
+--R           + 
+--R                      2             5 2         2 6
+--R             (- 384A c  - 768B b c)d e  + 256B c d e
+--R        *
+--R           x
+--R       + 
+--R                2 4 3                         2  5 2          2              6
+--R         2288A b d e  + (- 2496A b c - 1248B b )d e  + (768A c  + 1536B b c)d e
+--R       + 
+--R                 2 7
+--R         - 512B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R           6
+--R     45045e
+--R                                                    Type: Expression(Integer)
+--E 673
+
+--S 674 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 7 7            2               7          2   6  6
+--R         6006B c e x  + ((6930A c  + 13860B b c)e  + 7392B c d e )x
+--R       + 
+--R                                    2  7           2                 6
+--R               (16380A b c + 8190B b )e  + (8820A c  + 17640B b c)d e
+--R             + 
+--R                     2 2 5
+--R               126B c d e
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                     2 7                         2    6
+--R             10010A b e  + (21840A b c + 10920B b )d e
+--R           + 
+--R                    2             2 5         2 3 4
+--R             (210A c  + 420B b c)d e  - 140B c d e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                     2   6                     2  2 5
+--R             14300A b d e  + (780A b c + 390B b )d e
+--R           + 
+--R                      2             3 4         2 4 3
+--R             (- 240A c  - 480B b c)d e  + 160B c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                   2 2 5                       2  3 4          2             4 3
+--R             858A b d e  + (- 936A b c - 468B b )d e  + (288A c  + 576B b c)d e
+--R           + 
+--R                     2 5 2
+--R             - 192B c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                      2 3 4                      2  4 3
+--R             - 1144A b d e  + (1248A b c + 624B b )d e
+--R           + 
+--R                      2             5 2         2 6
+--R             (- 384A c  - 768B b c)d e  + 256B c d e
+--R        *
+--R           x
+--R       + 
+--R                2 4 3                         2  5 2          2              6
+--R         2288A b d e  + (- 2496A b c - 1248B b )d e  + (768A c  + 1536B b c)d e
+--R       + 
+--R                 2 7
+--R         - 512B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R           6
+--R     45045e
+--R                                         Type: Union(Expression(Integer),...)
+--E 674
+
+--S 675 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 676
+
+)clear all
+
+--S 677 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^2*sqrt(d+e*x)
+--R 
+--R
+--R            2 5       2           4                2  3      2 2  +-------+
+--R   (1)  (B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 1457
+r0:=-2/3*d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^(3/2)/e^6+2/5*d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(5/2)/e^6+2/7*(A*e*_
+     (6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*_
+     (d+e*x)^(7/2)/e^6-2/9*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-_
+     8*b*c*d*e+b^2*e^2))*(d+e*x)^(9/2)/e^6-2/11*c*(5*B*c*d-2*b*B*e-A*c*e)*_
+     (d+e*x)^(11/2)/e^6+2/13*B*c^2*(d+e*x)^(13/2)/e^6
+--R 
+--R
+--R   (2)
+--R                2 6 6            2               6         2   5  5
+--R         6930B c e x  + ((8190A c  + 16380B b c)e  + 630B c d e )x
+--R       + 
+--R                                     2  6          2                5
+--R               (20020A b c + 10010B b )e  + (910A c  + 1820B b c)d e
+--R             + 
+--R                       2 2 4
+--R               - 700B c d e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                     2 6                       2    5
+--R             12870A b e  + (2860A b c + 1430B b )d e
+--R           + 
+--R                       2              2 4         2 3 3
+--R             (- 1040A c  - 2080B b c)d e  + 800B c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                    2   5                         2  2 4
+--R             2574A b d e  + (- 3432A b c - 1716B b )d e
+--R           + 
+--R                     2              3 3         2 4 2
+--R             (1248A c  + 2496B b c)d e  - 960B c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                      2 2 4                       2  3 3
+--R             - 3432A b d e  + (4576A b c + 2288B b )d e
+--R           + 
+--R                       2              4 2          2 5
+--R             (- 1664A c  - 3328B b c)d e  + 1280B c d e
+--R        *
+--R           x
+--R       + 
+--R                2 3 3                         2  4 2           2              5
+--R         6864A b d e  + (- 9152A b c - 4576B b )d e  + (3328A c  + 6656B b c)d e
+--R       + 
+--R                  2 6
+--R         - 2560B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R           6
+--R     45045e
+--R                                                    Type: Expression(Integer)
+--E 678
+
+--S 679 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 6 6            2               6         2   5  5
+--R         6930B c e x  + ((8190A c  + 16380B b c)e  + 630B c d e )x
+--R       + 
+--R                                     2  6          2                5
+--R               (20020A b c + 10010B b )e  + (910A c  + 1820B b c)d e
+--R             + 
+--R                       2 2 4
+--R               - 700B c d e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                     2 6                       2    5
+--R             12870A b e  + (2860A b c + 1430B b )d e
+--R           + 
+--R                       2              2 4         2 3 3
+--R             (- 1040A c  - 2080B b c)d e  + 800B c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                    2   5                         2  2 4
+--R             2574A b d e  + (- 3432A b c - 1716B b )d e
+--R           + 
+--R                     2              3 3         2 4 2
+--R             (1248A c  + 2496B b c)d e  - 960B c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                      2 2 4                       2  3 3
+--R             - 3432A b d e  + (4576A b c + 2288B b )d e
+--R           + 
+--R                       2              4 2          2 5
+--R             (- 1664A c  - 3328B b c)d e  + 1280B c d e
+--R        *
+--R           x
+--R       + 
+--R                2 3 3                         2  4 2           2              5
+--R         6864A b d e  + (- 9152A b c - 4576B b )d e  + (3328A c  + 6656B b c)d e
+--R       + 
+--R                  2 6
+--R         - 2560B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R           6
+--R     45045e
+--R                                         Type: Union(Expression(Integer),...)
+--E 679
+
+--S 680 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 681
+
+)clear all
+
+--S 682 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^2/sqrt(d+e*x)
+--R 
+--R
+--R           2 5       2           4                2  3      2 2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                                +-------+
+--R                               \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1457
+r0:=2/3*d*(c*d-b*e)*(B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(3/2)/e^6+_
+     2/5*(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*(d+e*x)^(5/2)/e^6-2/7*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-_
+     8*b*c*d*e+b^2*e^2))*(d+e*x)^(7/2)/e^6-2/9*c*(5*B*c*d-2*b*B*e-A*c*e)*_
+     (d+e*x)^(9/2)/e^6+2/11*B*c^2*(d+e*x)^(11/2)/e^6-2*d^2*(B*d-A*e)*_
+     (c*d-b*e)^2*sqrt(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R               2 5 5           2              5         2   4  4
+--R         630B c e x  + ((770A c  + 1540B b c)e  - 700B c d e )x
+--R       + 
+--R                             2  5            2                4         2 2 3  3
+--R         ((1980A b c + 990B b )e  + (- 880A c  - 1760B b c)d e  + 800B c d e )x
+--R       + 
+--R                    2 5                         2    4
+--R             1386A b e  + (- 2376A b c - 1188B b )d e
+--R           + 
+--R                     2              2 3         2 3 2
+--R             (1056A c  + 2112B b c)d e  - 960B c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                      2   4                       2  2 3
+--R             - 1848A b d e  + (3168A b c + 1584B b )d e
+--R           + 
+--R                       2              3 2          2 4
+--R             (- 1408A c  - 2816B b c)d e  + 1280B c d e
+--R        *
+--R           x
+--R       + 
+--R                2 2 3                         2  3 2           2              4
+--R         3696A b d e  + (- 6336A b c - 3168B b )d e  + (2816A c  + 5632B b c)d e
+--R       + 
+--R                  2 5
+--R         - 2560B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R          6
+--R     3465e
+--R                                                    Type: Expression(Integer)
+--E 683
+
+--S 684 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 5 5           2              5         2   4  4
+--R         630B c e x  + ((770A c  + 1540B b c)e  - 700B c d e )x
+--R       + 
+--R                             2  5            2                4         2 2 3  3
+--R         ((1980A b c + 990B b )e  + (- 880A c  - 1760B b c)d e  + 800B c d e )x
+--R       + 
+--R                    2 5                         2    4
+--R             1386A b e  + (- 2376A b c - 1188B b )d e
+--R           + 
+--R                     2              2 3         2 3 2
+--R             (1056A c  + 2112B b c)d e  - 960B c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                      2   4                       2  2 3
+--R             - 1848A b d e  + (3168A b c + 1584B b )d e
+--R           + 
+--R                       2              3 2          2 4
+--R             (- 1408A c  - 2816B b c)d e  + 1280B c d e
+--R        *
+--R           x
+--R       + 
+--R                2 2 3                         2  3 2           2              4
+--R         3696A b d e  + (- 6336A b c - 3168B b )d e  + (2816A c  + 5632B b c)d e
+--R       + 
+--R                  2 5
+--R         - 2560B c d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R          6
+--R     3465e
+--R                                         Type: Union(Expression(Integer),...)
+--E 684
+
+--S 685 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 685
+
+--S 686 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 686
+
+)clear all
+
+--S 687 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^(3/2)
+--R 
+--R
+--R           2 5       2           4                2  3      2 2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                                    +-------+
+--R                          (e x + d)\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 1457
+r0:=2/3*(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*(d+e*x)^(3/2)/e^6-2/5*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-_
+     8*b*c*d*e+b^2*e^2))*(d+e*x)^(5/2)/e^6-2/7*c*(5*B*c*d-2*b*B*e-A*c*e)*_
+     (d+e*x)^(7/2)/e^6+2/9*B*c^2*(d+e*x)^(9/2)/e^6+2*d^2*(B*d-A*e)*_
+     (c*d-b*e)^2/(e^6*sqrt(d+e*x))+2*d*(c*d-b*e)*(B*d*(5*c*d-3*b*e)-_
+     2*A*e*(2*c*d-b*e))*sqrt(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R            2 5 5          2             5         2   4  4
+--R       70B c e x  + ((90A c  + 180B b c)e  - 100B c d e )x
+--R     + 
+--R                          2  5            2               4         2 2 3  3
+--R       ((252A b c + 126B b )e  + (- 144A c  - 288B b c)d e  + 160B c d e )x
+--R     + 
+--R                 2 5                       2    4          2             2 3
+--R           210A b e  + (- 504A b c - 252B b )d e  + (288A c  + 576B b c)d e
+--R         + 
+--R                   2 3 2
+--R           - 320B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                   2   4                       2  2 3
+--R           - 840A b d e  + (2016A b c + 1008B b )d e
+--R         + 
+--R                     2              3 2          2 4
+--R           (- 1152A c  - 2304B b c)d e  + 1280B c d e
+--R      *
+--R         x
+--R     + 
+--R                2 2 3                       2  3 2             2              4
+--R       - 1680A b d e  + (4032A b c + 2016B b )d e  + (- 2304A c  - 4608B b c)d e
+--R     + 
+--R              2 5
+--R       2560B c d
+--R  /
+--R         6 +-------+
+--R     315e \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 688
+
+--S 689 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2 5 5          2             5         2   4  4
+--R       70B c e x  + ((90A c  + 180B b c)e  - 100B c d e )x
+--R     + 
+--R                          2  5            2               4         2 2 3  3
+--R       ((252A b c + 126B b )e  + (- 144A c  - 288B b c)d e  + 160B c d e )x
+--R     + 
+--R                 2 5                       2    4          2             2 3
+--R           210A b e  + (- 504A b c - 252B b )d e  + (288A c  + 576B b c)d e
+--R         + 
+--R                   2 3 2
+--R           - 320B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                   2   4                       2  2 3
+--R           - 840A b d e  + (2016A b c + 1008B b )d e
+--R         + 
+--R                     2              3 2          2 4
+--R           (- 1152A c  - 2304B b c)d e  + 1280B c d e
+--R      *
+--R         x
+--R     + 
+--R                2 2 3                       2  3 2             2              4
+--R       - 1680A b d e  + (4032A b c + 2016B b )d e  + (- 2304A c  - 4608B b c)d e
+--R     + 
+--R              2 5
+--R       2560B c d
+--R  /
+--R         6 +-------+
+--R     315e \|e x + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 689
+
+--S 690 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 690
+
+--S 691 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 691
+
+)clear all
+
+--S 692 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^(5/2)
+--R 
+--R
+--R           2 5       2           4                2  3      2 2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                       2 2             2  +-------+
+--R                     (e x  + 2d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 1457
+r0:=2/3*d^2*(B*d-A*e)*(c*d-b*e)^2/(e^6*(d+e*x)^(3/2))-2/3*(2*A*c*e*(2*c*d-_
+     b*e)-B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*(d+e*x)^(3/2)/e^6-2/5*c*_
+     (5*B*c*d-2*b*B*e-A*c*e)*(d+e*x)^(5/2)/e^6+2/7*B*c^2*(d+e*x)^(7/2)/e^6-_
+     2*d*(c*d-b*e)*(B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))/(e^6*sqrt(d+e*x))+_
+     2*(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*sqrt(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R            2 5 5          2            5        2   4  4
+--R       30B c e x  + ((42A c  + 84B b c)e  - 60B c d e )x
+--R     + 
+--R                         2  5            2               4         2 2 3  3
+--R       ((140A b c + 70B b )e  + (- 112A c  - 224B b c)d e  + 160B c d e )x
+--R     + 
+--R                 2 5                       2    4          2              2 3
+--R           210A b e  + (- 840A b c - 420B b )d e  + (672A c  + 1344B b c)d e
+--R         + 
+--R                   2 3 2
+--R           - 960B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 2   4                         2  2 3
+--R           840A b d e  + (- 3360A b c - 1680B b )d e
+--R         + 
+--R                   2              3 2          2 4
+--R           (2688A c  + 5376B b c)d e  - 3840B c d e
+--R      *
+--R         x
+--R     + 
+--R             2 2 3                         2  3 2           2              4
+--R       560A b d e  + (- 2240A b c - 1120B b )d e  + (1792A c  + 3584B b c)d e
+--R     + 
+--R                2 5
+--R       - 2560B c d
+--R  /
+--R          7          6  +-------+
+--R     (105e x + 105d e )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 693
+
+--S 694 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2 5 5          2            5        2   4  4
+--R       30B c e x  + ((42A c  + 84B b c)e  - 60B c d e )x
+--R     + 
+--R                         2  5            2               4         2 2 3  3
+--R       ((140A b c + 70B b )e  + (- 112A c  - 224B b c)d e  + 160B c d e )x
+--R     + 
+--R                 2 5                       2    4          2              2 3
+--R           210A b e  + (- 840A b c - 420B b )d e  + (672A c  + 1344B b c)d e
+--R         + 
+--R                   2 3 2
+--R           - 960B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 2   4                         2  2 3
+--R           840A b d e  + (- 3360A b c - 1680B b )d e
+--R         + 
+--R                   2              3 2          2 4
+--R           (2688A c  + 5376B b c)d e  - 3840B c d e
+--R      *
+--R         x
+--R     + 
+--R             2 2 3                         2  3 2           2              4
+--R       560A b d e  + (- 2240A b c - 1120B b )d e  + (1792A c  + 3584B b c)d e
+--R     + 
+--R                2 5
+--R       - 2560B c d
+--R  /
+--R          7          6  +-------+
+--R     (105e x + 105d e )\|e x + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 694
+
+--S 695 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 696
+
+)clear all
+
+--S 697 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^(7/2)
+--R 
+--R
+--R           2 5       2           4                2  3      2 2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                  3 3       2 2     2       3  +-------+
+--R                (e x  + 3d e x  + 3d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 1457
+r0:=2/5*d^2*(B*d-A*e)*(c*d-b*e)^2/(e^6*(d+e*x)^(5/2))-2/3*d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))/(e^6*(d+e*x)^(3/2))-2/3*c*_
+     (5*B*c*d-2*b*B*e-A*c*e)*(d+e*x)^(3/2)/e^6+2/5*B*c^2*(d+e*x)^(5/2)/e^6-_
+     2*(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))/(e^6*sqrt(d+e*x))-2*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-_
+     8*b*c*d*e+b^2*e^2))*sqrt(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R           2 5 5          2            5        2   4  4
+--R       6B c e x  + ((10A c  + 20B b c)e  - 20B c d e )x
+--R     + 
+--R                        2  5           2               4         2 2 3  3
+--R       ((60A b c + 30B b )e  + (- 80A c  - 160B b c)d e  + 160B c d e )x
+--R     + 
+--R                  2 5                     2    4            2             2 3
+--R           - 30A b e  + (360A b c + 180B b )d e  + (- 480A c  - 960B b c)d e
+--R         + 
+--R                 2 3 2
+--R           960B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  2   4                     2  2 3            2              3 2
+--R           - 40A b d e  + (480A b c + 240B b )d e  + (- 640A c  - 1280B b c)d e
+--R         + 
+--R                  2 4
+--R           1280B c d e
+--R      *
+--R         x
+--R     + 
+--R              2 2 3                    2  3 2            2             4
+--R       - 16A b d e  + (192A b c + 96B b )d e  + (- 256A c  - 512B b c)d e
+--R     + 
+--R             2 5
+--R       512B c d
+--R  /
+--R         8 2        7       2 6  +-------+
+--R     (15e x  + 30d e x + 15d e )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 698
+
+--S 699 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 5 5          2            5        2   4  4
+--R       6B c e x  + ((10A c  + 20B b c)e  - 20B c d e )x
+--R     + 
+--R                        2  5           2               4         2 2 3  3
+--R       ((60A b c + 30B b )e  + (- 80A c  - 160B b c)d e  + 160B c d e )x
+--R     + 
+--R                  2 5                     2    4            2             2 3
+--R           - 30A b e  + (360A b c + 180B b )d e  + (- 480A c  - 960B b c)d e
+--R         + 
+--R                 2 3 2
+--R           960B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  2   4                     2  2 3            2              3 2
+--R           - 40A b d e  + (480A b c + 240B b )d e  + (- 640A c  - 1280B b c)d e
+--R         + 
+--R                  2 4
+--R           1280B c d e
+--R      *
+--R         x
+--R     + 
+--R              2 2 3                    2  3 2            2             4
+--R       - 16A b d e  + (192A b c + 96B b )d e  + (- 256A c  - 512B b c)d e
+--R     + 
+--R             2 5
+--R       512B c d
+--R  /
+--R         8 2        7       2 6  +-------+
+--R     (15e x  + 30d e x + 15d e )\|e x + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 699
+
+--S 700 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 700
+
+--S 701 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 701
+
+)clear all
+
+--S 702 of 1457
+t0:=(A+B*x)*(d+e*x)^(7/2)/(b*x+c*x^2)
+--R 
+--R
+--R   (1)
+--R            3 4       3         2  3          2       2   2        2       3
+--R         B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x
+--R       + 
+--R            3
+--R         A d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R        2
+--R     c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 1457
+r0:=2/3*(B*(c*d-b*e)^2+A*c*e*(2*c*d-b*e))*(d+e*x)^(3/2)/c^3+2/5*_
+     (B*c*d-b*B*e+A*c*e)*(d+e*x)^(5/2)/c^2+2/7*B*(d+e*x)^(7/2)/c-_
+     2*A*d^(7/2)*atanh(sqrt(d+e*x)/sqrt(d))/b-2*(b*B-A*c)*(c*d-b*e)^(7/2)*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b*c^(9/2))+2*(B*(c*d-b*e)^3+_
+     A*c*e*(3*c^2*d^2-3*b*c*d*e+b^2*e^2))*sqrt(d+e*x)/c^4
+--R 
+--R
+--R   (2)
+--R                    3          4  3          2 2         3     2
+--R           (- 210A b c + 210B b )e  + (630A b c  - 630B b c)d e
+--R         + 
+--R                      3         2 2  2           4           3  3
+--R           (- 630A b c  + 630B b c )d e + (210A c  - 210B b c )d
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                                 +-------+
+--R               4 3 +-+ +-+      \|e x + d
+--R       - 210A c d \|c \|d atanh(----------)
+--R                                    +-+
+--R                                   \|d
+--R     + 
+--R                  3 3 3            3        2 2  3           3   2  2
+--R           30B b c e x  + ((42A b c  - 42B b c )e  + 132B b c d e )x
+--R         + 
+--R                       2 2        3   3            3         2 2    2
+--R               (- 70A b c  + 70B b c)e  + (224A b c  - 224B b c )d e
+--R             + 
+--R                       3 2
+--R               244B b c d e
+--R          *
+--R             x
+--R         + 
+--R                  3          4  3            2 2         3     2
+--R           (210A b c - 210B b )e  + (- 700A b c  + 700B b c)d e
+--R         + 
+--R                    3         2 2  2            3 3
+--R           (812A b c  - 812B b c )d e + 352B b c d
+--R      *
+--R          +-+ +-------+
+--R         \|c \|e x + d
+--R  /
+--R           4 +-+
+--R     105b c \|c
+--R                                                    Type: Expression(Integer)
+--E 703
+
+--S 704 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3          4  3          2 2         3     2
+--R             (- 105A b c + 105B b )e  + (315A b c  - 315B b c)d e
+--R           + 
+--R                        3         2 2  2           4           3  3
+--R             (- 315A b c  + 315B b c )d e + (105A c  - 105B b c )d
+--R        *
+--R                                +-----------+
+--R                                |- b e + c d  +-------+
+--R            +-----------+    2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d       \|     c
+--R            |----------- log(-----------------------------------------------)
+--R           \|     c                              c x + b
+--R       + 
+--R                              +-+ +-------+
+--R               4 3 +-+    - 2\|d \|e x + d  + e x + 2d
+--R         105A c d \|d log(----------------------------)
+--R                                        x
+--R       + 
+--R                    3 3 3            3        2 2  3           3   2  2
+--R             30B b c e x  + ((42A b c  - 42B b c )e  + 132B b c d e )x
+--R           + 
+--R                         2 2        3   3            3         2 2    2
+--R                 (- 70A b c  + 70B b c)e  + (224A b c  - 224B b c )d e
+--R               + 
+--R                         3 2
+--R                 244B b c d e
+--R            *
+--R               x
+--R           + 
+--R                    3          4  3            2 2         3     2
+--R             (210A b c - 210B b )e  + (- 700A b c  + 700B b c)d e
+--R           + 
+--R                      3         2 2  2            3 3
+--R             (812A b c  - 812B b c )d e + 352B b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R             4
+--R       105b c
+--R     ,
+--R
+--R                              +-+ +-------+
+--R               4 3 +-+    - 2\|d \|e x + d  + e x + 2d
+--R         105A c d \|d log(----------------------------)
+--R                                        x
+--R       + 
+--R                      3          4  3          2 2         3     2
+--R             (- 210A b c + 210B b )e  + (630A b c  - 630B b c)d e
+--R           + 
+--R                        3         2 2  2           4           3  3
+--R             (- 630A b c  + 630B b c )d e + (210A c  - 210B b c )d
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                    3 3 3            3        2 2  3           3   2  2
+--R             30B b c e x  + ((42A b c  - 42B b c )e  + 132B b c d e )x
+--R           + 
+--R                         2 2        3   3            3         2 2    2
+--R                 (- 70A b c  + 70B b c)e  + (224A b c  - 224B b c )d e
+--R               + 
+--R                         3 2
+--R                 244B b c d e
+--R            *
+--R               x
+--R           + 
+--R                    3          4  3            2 2         3     2
+--R             (210A b c - 210B b )e  + (- 700A b c  + 700B b c)d e
+--R           + 
+--R                      3         2 2  2            3 3
+--R             (812A b c  - 812B b c )d e + 352B b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R             4
+--R       105b c
+--R     ,
+--R
+--R                      3          4  3          2 2         3     2
+--R             (- 105A b c + 105B b )e  + (315A b c  - 315B b c)d e
+--R           + 
+--R                        3         2 2  2           4           3  3
+--R             (- 315A b c  + 315B b c )d e + (105A c  - 105B b c )d
+--R        *
+--R                                +-----------+
+--R                                |- b e + c d  +-------+
+--R            +-----------+    2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d       \|     c
+--R            |----------- log(-----------------------------------------------)
+--R           \|     c                              c x + b
+--R       + 
+--R                                +-------+
+--R                 4 3 +---+     \|e x + d
+--R         - 210A c d \|- d atan(----------)
+--R                                  +---+
+--R                                 \|- d
+--R       + 
+--R                    3 3 3            3        2 2  3           3   2  2
+--R             30B b c e x  + ((42A b c  - 42B b c )e  + 132B b c d e )x
+--R           + 
+--R                         2 2        3   3            3         2 2    2
+--R                 (- 70A b c  + 70B b c)e  + (224A b c  - 224B b c )d e
+--R               + 
+--R                         3 2
+--R                 244B b c d e
+--R            *
+--R               x
+--R           + 
+--R                    3          4  3            2 2         3     2
+--R             (210A b c - 210B b )e  + (- 700A b c  + 700B b c)d e
+--R           + 
+--R                      3         2 2  2            3 3
+--R             (812A b c  - 812B b c )d e + 352B b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R             4
+--R       105b c
+--R     ,
+--R
+--R                                +-------+
+--R                 4 3 +---+     \|e x + d
+--R         - 210A c d \|- d atan(----------)
+--R                                  +---+
+--R                                 \|- d
+--R       + 
+--R                      3          4  3          2 2         3     2
+--R             (- 210A b c + 210B b )e  + (630A b c  - 630B b c)d e
+--R           + 
+--R                        3         2 2  2           4           3  3
+--R             (- 630A b c  + 630B b c )d e + (210A c  - 210B b c )d
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                    3 3 3            3        2 2  3           3   2  2
+--R             30B b c e x  + ((42A b c  - 42B b c )e  + 132B b c d e )x
+--R           + 
+--R                         2 2        3   3            3         2 2    2
+--R                 (- 70A b c  + 70B b c)e  + (224A b c  - 224B b c )d e
+--R               + 
+--R                         3 2
+--R                 244B b c d e
+--R            *
+--R               x
+--R           + 
+--R                    3          4  3            2 2         3     2
+--R             (210A b c - 210B b )e  + (- 700A b c  + 700B b c)d e
+--R           + 
+--R                      3         2 2  2            3 3
+--R             (812A b c  - 812B b c )d e + 352B b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R             4
+--R       105b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 704
+
+--S 705 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 3       4  3        2 2       3     2
+--R           (- A b c + B b )e  + (3A b c  - 3B b c)d e
+--R         + 
+--R                    3       2 2  2        4        3  3
+--R           (- 3A b c  + 3B b c )d e + (A c  - B b c )d
+--R      *
+--R                                  +-----------+
+--R                                  |- b e + c d  +-------+
+--R          +-----------+        2c |----------- \|e x + d  + c e x - b e + 2c d
+--R          |- b e + c d  +-+      \|     c
+--R          |----------- \|c log(-----------------------------------------------)
+--R         \|     c                                  c x + b
+--R     + 
+--R                             +-+ +-------+
+--R          4 3 +-+ +-+    - 2\|d \|e x + d  + e x + 2d
+--R       A c d \|c \|d log(----------------------------)
+--R                                       x
+--R     + 
+--R                3        4  3          2 2       3     2
+--R           (2A b c - 2B b )e  + (- 6A b c  + 6B b c)d e
+--R         + 
+--R                  3       2 2  2           4         3  3
+--R           (6A b c  - 6B b c )d e + (- 2A c  + 2B b c )d
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                             +-------+
+--R           4 3 +-+ +-+      \|e x + d
+--R       2A c d \|c \|d atanh(----------)
+--R                                +-+
+--R                               \|d
+--R  /
+--R        4 +-+
+--R     b c \|c
+--R                                                    Type: Expression(Integer)
+--E 705
+
+--S 706 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             +-+ +-------+
+--R          4 3 +-+ +-+    - 2\|d \|e x + d  + e x + 2d
+--R       A c d \|c \|d log(----------------------------)
+--R                                       x
+--R     + 
+--R                3        4  3          2 2       3     2
+--R           (2A b c - 2B b )e  + (- 6A b c  + 6B b c)d e
+--R         + 
+--R                  3       2 2  2           4         3  3
+--R           (6A b c  - 6B b c )d e + (- 2A c  + 2B b c )d
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                             +-------+
+--R           4 3 +-+ +-+      \|e x + d
+--R       2A c d \|c \|d atanh(----------)
+--R                                +-+
+--R                               \|d
+--R     + 
+--R                  3        4  3        2 2       3     2
+--R           (- 2A b c + 2B b )e  + (6A b c  - 6B b c)d e
+--R         + 
+--R                    3       2 2  2         4         3  3
+--R           (- 6A b c  + 6B b c )d e + (2A c  - 2B b c )d
+--R      *
+--R              +---------+       +-------+
+--R          +-+ |b e - c d       \|e x + d
+--R         \|c  |--------- atan(------------)
+--R             \|    c           +---------+
+--R                               |b e - c d
+--R                               |---------
+--R                              \|    c
+--R  /
+--R        4 +-+
+--R     b c \|c
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 708
+
+)clear all
+
+--S 709 of 1457
+t0:=(A+B*x)*(d+e*x)^(5/2)/(b*x+c*x^2)
+--R 
+--R
+--R            2 3       2           2                2        2  +-------+
+--R        (B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d )\|e x + d
+--R   (1)  ----------------------------------------------------------------
+--R                                      2
+--R                                   c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 1457
+r0:=2/3*(B*c*d-b*B*e+A*c*e)*(d+e*x)^(3/2)/c^2+2/5*B*(d+e*x)^(5/2)/c-_
+     2*A*d^(5/2)*atanh(sqrt(d+e*x)/sqrt(d))/b-2*(b*B-A*c)*(c*d-b*e)^(5/2)*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b*c^(7/2))+2*(B*(c*d-b*e)^2+_
+     A*c*e*(2*c*d-b*e))*sqrt(d+e*x)/c^3
+--R 
+--R
+--R   (2)
+--R                 2         3  2             2        2
+--R           (30A b c - 30B b )e  + (- 60A b c  + 60B b c)d e
+--R         + 
+--R                 3          2  2
+--R           (30A c  - 30B b c )d
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                                +-------+
+--R              3 2 +-+ +-+      \|e x + d
+--R       - 30A c d \|c \|d atanh(----------)
+--R                                   +-+
+--R                                  \|d
+--R     + 
+--R                 2 2 2            2        2   2          2
+--R           6B b c e x  + ((10A b c  - 10B b c)e  + 22B b c d e)x
+--R         + 
+--R                   2         3  2           2        2               2 2
+--R           (- 30A b c + 30B b )e  + (70A b c  - 70B b c)d e + 46B b c d
+--R      *
+--R          +-+ +-------+
+--R         \|c \|e x + d
+--R  /
+--R          3 +-+
+--R     15b c \|c
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     2         3  2           2        2
+--R             (- 15A b c + 15B b )e  + (30A b c  - 30B b c)d e
+--R           + 
+--R                     3          2  2
+--R             (- 15A c  + 15B b c )d
+--R        *
+--R                                  +-----------+
+--R                                  |- b e + c d  +-------+
+--R            +-----------+    - 2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d         \|     c
+--R            |----------- log(-------------------------------------------------)
+--R           \|     c                               c x + b
+--R       + 
+--R                             +-+ +-------+
+--R              3 2 +-+    - 2\|d \|e x + d  + e x + 2d
+--R         15A c d \|d log(----------------------------)
+--R                                       x
+--R       + 
+--R                   2 2 2            2        2   2          2
+--R             6B b c e x  + ((10A b c  - 10B b c)e  + 22B b c d e)x
+--R           + 
+--R                     2         3  2           2        2               2 2
+--R             (- 30A b c + 30B b )e  + (70A b c  - 70B b c)d e + 46B b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R            3
+--R       15b c
+--R     ,
+--R
+--R                             +-+ +-------+
+--R              3 2 +-+    - 2\|d \|e x + d  + e x + 2d
+--R         15A c d \|d log(----------------------------)
+--R                                       x
+--R       + 
+--R                   2         3  2             2        2
+--R             (30A b c - 30B b )e  + (- 60A b c  + 60B b c)d e
+--R           + 
+--R                   3          2  2
+--R             (30A c  - 30B b c )d
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                   2 2 2            2        2   2          2
+--R             6B b c e x  + ((10A b c  - 10B b c)e  + 22B b c d e)x
+--R           + 
+--R                     2         3  2           2        2               2 2
+--R             (- 30A b c + 30B b )e  + (70A b c  - 70B b c)d e + 46B b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R            3
+--R       15b c
+--R     ,
+--R
+--R                     2         3  2           2        2
+--R             (- 15A b c + 15B b )e  + (30A b c  - 30B b c)d e
+--R           + 
+--R                     3          2  2
+--R             (- 15A c  + 15B b c )d
+--R        *
+--R                                  +-----------+
+--R                                  |- b e + c d  +-------+
+--R            +-----------+    - 2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d         \|     c
+--R            |----------- log(-------------------------------------------------)
+--R           \|     c                               c x + b
+--R       + 
+--R                               +-------+
+--R                3 2 +---+     \|e x + d
+--R         - 30A c d \|- d atan(----------)
+--R                                 +---+
+--R                                \|- d
+--R       + 
+--R                   2 2 2            2        2   2          2
+--R             6B b c e x  + ((10A b c  - 10B b c)e  + 22B b c d e)x
+--R           + 
+--R                     2         3  2           2        2               2 2
+--R             (- 30A b c + 30B b )e  + (70A b c  - 70B b c)d e + 46B b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R            3
+--R       15b c
+--R     ,
+--R
+--R                               +-------+
+--R                3 2 +---+     \|e x + d
+--R         - 30A c d \|- d atan(----------)
+--R                                 +---+
+--R                                \|- d
+--R       + 
+--R                   2         3  2             2        2
+--R             (30A b c - 30B b )e  + (- 60A b c  + 60B b c)d e
+--R           + 
+--R                   3          2  2
+--R             (30A c  - 30B b c )d
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                   2 2 2            2        2   2          2
+--R             6B b c e x  + ((10A b c  - 10B b c)e  + 22B b c d e)x
+--R           + 
+--R                     2         3  2           2        2               2 2
+--R             (- 30A b c + 30B b )e  + (70A b c  - 70B b c)d e + 46B b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R            3
+--R       15b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 711
+
+--S 712 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                2       3  2          2       2              3        2  2
+--R         ((- A b c + B b )e  + (2A b c  - 2B b c)d e + (- A c  + B b c )d )
+--R      *
+--R                                  +-----------+
+--R                                  |- b e + c d  +-------+
+--R        +-----------+        - 2c |----------- \|e x + d  + c e x - b e + 2c d
+--R        |- b e + c d  +-+        \|     c
+--R        |----------- \|c log(-------------------------------------------------)
+--R       \|     c                                   c x + b
+--R     + 
+--R                             +-+ +-------+
+--R          3 2 +-+ +-+    - 2\|d \|e x + d  + e x + 2d
+--R       A c d \|c \|d log(----------------------------)
+--R                                       x
+--R     + 
+--R                 2        3  2          2       2               3         2  2
+--R         ((- 2A b c + 2B b )e  + (4A b c  - 4B b c)d e + (- 2A c  + 2B b c )d )
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                             +-------+
+--R           3 2 +-+ +-+      \|e x + d
+--R       2A c d \|c \|d atanh(----------)
+--R                                +-+
+--R                               \|d
+--R  /
+--R        3 +-+
+--R     b c \|c
+--R                                                    Type: Expression(Integer)
+--E 712
+
+--S 713 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             +-+ +-------+
+--R          3 2 +-+ +-+    - 2\|d \|e x + d  + e x + 2d
+--R       A c d \|c \|d log(----------------------------)
+--R                                       x
+--R     + 
+--R                 2        3  2          2       2               3         2  2
+--R         ((- 2A b c + 2B b )e  + (4A b c  - 4B b c)d e + (- 2A c  + 2B b c )d )
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                             +-------+
+--R           3 2 +-+ +-+      \|e x + d
+--R       2A c d \|c \|d atanh(----------)
+--R                                +-+
+--R                               \|d
+--R     + 
+--R               2        3  2            2       2             3         2  2
+--R         ((2A b c - 2B b )e  + (- 4A b c  + 4B b c)d e + (2A c  - 2B b c )d )
+--R      *
+--R              +---------+       +-------+
+--R          +-+ |b e - c d       \|e x + d
+--R         \|c  |--------- atan(------------)
+--R             \|    c           +---------+
+--R                               |b e - c d
+--R                               |---------
+--R                              \|    c
+--R  /
+--R        3 +-+
+--R     b c \|c
+--R                                                    Type: Expression(Integer)
+--E 714
+
+--S 715 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 715
+
+)clear all
+
+--S 716 of 1457
+t0:=(A+B*x)*(d+e*x)^(3/2)/(b*x+c*x^2)
+--R 
+--R
+--R              2                       +-------+
+--R        (B e x  + (A e + B d)x + A d)\|e x + d
+--R   (1)  ---------------------------------------
+--R                          2
+--R                       c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1457
+r0:=2/3*B*(d+e*x)^(3/2)/c-2*A*d^(3/2)*atanh(sqrt(d+e*x)/sqrt(d))/b-_
+     2*(b*B-A*c)*(c*d-b*e)^(3/2)*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))/(b*c^(5/2))+2*(B*c*d-b*B*e+A*c*e)*sqrt(d+e*x)/c^2
+--R 
+--R
+--R   (2)
+--R                          2          2             +-----------+
+--R         ((- 6A b c + 6B b )e + (6A c  - 6B b c)d)\|- b e + c d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                              +-------+
+--R             2  +-+ +-+      \|e x + d
+--R       - 6A c d\|c \|d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R     + 
+--R                                   2               +-+ +-------+
+--R       (2B b c e x + (6A b c - 6B b )e + 8B b c d)\|c \|e x + d
+--R  /
+--R         2 +-+
+--R     3b c \|c
+--R                                                    Type: Expression(Integer)
+--E 717
+
+--S 718 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                     +-----------+
+--R                            2          2             |- b e + c d
+--R           ((- 3A b c + 3B b )e + (3A c  - 3B b c)d) |-----------
+--R                                                    \|     c
+--R        *
+--R                  +-----------+
+--R                  |- b e + c d  +-------+
+--R               2c |----------- \|e x + d  + c e x - b e + 2c d
+--R                 \|     c
+--R           log(-----------------------------------------------)
+--R                                   c x + b
+--R       + 
+--R                           +-+ +-------+
+--R             2  +-+    - 2\|d \|e x + d  + e x + 2d
+--R         3A c d\|d log(----------------------------)
+--R                                     x
+--R       + 
+--R                                     2               +-------+
+--R         (2B b c e x + (6A b c - 6B b )e + 8B b c d)\|e x + d
+--R    /
+--R           2
+--R       3b c
+--R     ,
+--R
+--R                           +-+ +-------+
+--R             2  +-+    - 2\|d \|e x + d  + e x + 2d
+--R         3A c d\|d log(----------------------------)
+--R                                     x
+--R       + 
+--R                                                   +---------+       +-------+
+--R                          2          2             |b e - c d       \|e x + d
+--R         ((- 6A b c + 6B b )e + (6A c  - 6B b c)d) |--------- atan(------------)
+--R                                                  \|    c           +---------+
+--R                                                                    |b e - c d
+--R                                                                    |---------
+--R                                                                   \|    c
+--R       + 
+--R                                     2               +-------+
+--R         (2B b c e x + (6A b c - 6B b )e + 8B b c d)\|e x + d
+--R    /
+--R           2
+--R       3b c
+--R     ,
+--R
+--R                                                     +-----------+
+--R                            2          2             |- b e + c d
+--R           ((- 3A b c + 3B b )e + (3A c  - 3B b c)d) |-----------
+--R                                                    \|     c
+--R        *
+--R                  +-----------+
+--R                  |- b e + c d  +-------+
+--R               2c |----------- \|e x + d  + c e x - b e + 2c d
+--R                 \|     c
+--R           log(-----------------------------------------------)
+--R                                   c x + b
+--R       + 
+--R                             +-------+
+--R               2  +---+     \|e x + d
+--R         - 6A c d\|- d atan(----------)
+--R                               +---+
+--R                              \|- d
+--R       + 
+--R                                     2               +-------+
+--R         (2B b c e x + (6A b c - 6B b )e + 8B b c d)\|e x + d
+--R    /
+--R           2
+--R       3b c
+--R     ,
+--R
+--R                             +-------+
+--R               2  +---+     \|e x + d
+--R         - 6A c d\|- d atan(----------)
+--R                               +---+
+--R                              \|- d
+--R       + 
+--R                                                   +---------+       +-------+
+--R                          2          2             |b e - c d       \|e x + d
+--R         ((- 6A b c + 6B b )e + (6A c  - 6B b c)d) |--------- atan(------------)
+--R                                                  \|    c           +---------+
+--R                                                                    |b e - c d
+--R                                                                    |---------
+--R                                                                   \|    c
+--R       + 
+--R                                     2               +-------+
+--R         (2B b c e x + (6A b c - 6B b )e + 8B b c d)\|e x + d
+--R    /
+--R           2
+--R       3b c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 718
+
+--S 719 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                               +-----------+
+--R                        2         2            |- b e + c d  +-+
+--R         ((- A b c + B b )e + (A c  - B b c)d) |----------- \|c
+--R                                              \|     c
+--R      *
+--R                +-----------+
+--R                |- b e + c d  +-------+
+--R             2c |----------- \|e x + d  + c e x - b e + 2c d
+--R               \|     c
+--R         log(-----------------------------------------------)
+--R                                 c x + b
+--R     + 
+--R                            +-+ +-------+
+--R          2  +-+ +-+    - 2\|d \|e x + d  + e x + 2d
+--R       A c d\|c \|d log(----------------------------)
+--R                                      x
+--R     + 
+--R                        2            2             +-----------+
+--R         ((2A b c - 2B b )e + (- 2A c  + 2B b c)d)\|- b e + c d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                            +-------+
+--R           2  +-+ +-+      \|e x + d
+--R       2A c d\|c \|d atanh(----------)
+--R                               +-+
+--R                              \|d
+--R  /
+--R        2 +-+
+--R     b c \|c
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 720
+
+--S 721 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                            +-+ +-------+
+--R          2  +-+ +-+    - 2\|d \|e x + d  + e x + 2d
+--R       A c d\|c \|d log(----------------------------)
+--R                                      x
+--R     + 
+--R                        2            2             +-----------+
+--R         ((2A b c - 2B b )e + (- 2A c  + 2B b c)d)\|- b e + c d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                            +-------+
+--R           2  +-+ +-+      \|e x + d
+--R       2A c d\|c \|d atanh(----------)
+--R                               +-+
+--R                              \|d
+--R     + 
+--R                                                   +---------+       +-------+
+--R                      2          2             +-+ |b e - c d       \|e x + d
+--R     ((- 2A b c + 2B b )e + (2A c  - 2B b c)d)\|c  |--------- atan(------------)
+--R                                                  \|    c           +---------+
+--R                                                                    |b e - c d
+--R                                                                    |---------
+--R                                                                   \|    c
+--R  /
+--R        2 +-+
+--R     b c \|c
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 722
+
+)clear all
+
+--S 723 of 1457
+t0:=(A+B*x)*sqrt(d+e*x)/(b*x+c*x^2)
+--R 
+--R
+--R                  +-------+
+--R        (B x + A)\|e x + d
+--R   (1)  -------------------
+--R                2
+--R             c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 723
+
+--S 724 of 1457
+r0:=-2*A*atanh(sqrt(d+e*x)/sqrt(d))*sqrt(d)/b-2*(b*B-A*c)*atanh(sqrt(c)*_
+     sqrt(d+e*x)/sqrt(c*d-b*e))*sqrt(c*d-b*e)/(b*c^(3/2))+2*B*sqrt(d+e*x)/c
+--R 
+--R
+--R   (2)
+--R                                         +-+ +-------+
+--R                     +-----------+      \|c \|e x + d
+--R       (2A c - 2B b)\|- b e + c d atanh(--------------)
+--R                                         +-----------+
+--R                                        \|- b e + c d
+--R     + 
+--R                            +-------+
+--R              +-+ +-+      \|e x + d          +-+ +-------+
+--R       - 2A c\|c \|d atanh(----------) + 2B b\|c \|e x + d
+--R                               +-+
+--R                              \|d
+--R  /
+--R         +-+
+--R     b c\|c
+--R                                                    Type: Expression(Integer)
+--E 724
+
+--S 725 of 1457
+--a0:=integrate(t0,x)
+--E 725
+
+--S 726 of 1457
+--m0a:=a0.1-r0
+--E 726
+
+--S 727 of 1457
+--d0a:=D(m0a,x)
+--E 727
+
+--S 728 of 1457
+--m0b:=a0.2-r0
+--E 728
+
+--S 729 of 1457
+--d0b:=D(m0b,x)
+--E 729
+
+)clear all
+
+--S 730 of 1457
+t0:=(A+B*x)/((b*x+c*x^2)*sqrt(d+e*x))
+--R 
+--R
+--R                B x + A
+--R   (1)  ----------------------
+--R            2        +-------+
+--R        (c x  + b x)\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 730
+
+--S 731 of 1457
+r0:=-2*A*atanh(sqrt(d+e*x)/sqrt(d))/(b*sqrt(d))-2*(b*B-A*c)*atanh(sqrt(c)*_
+     sqrt(d+e*x)/sqrt(c*d-b*e))/(b*sqrt(c)*sqrt(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                               +-+ +-------+
+--R                     +-+      \|c \|e x + d
+--R       (2A c - 2B b)\|d atanh(--------------)
+--R                               +-----------+
+--R                              \|- b e + c d
+--R     + 
+--R                                    +-------+
+--R            +-----------+ +-+      \|e x + d
+--R       - 2A\|- b e + c d \|c atanh(----------)
+--R                                       +-+
+--R                                      \|d
+--R  /
+--R       +-----------+ +-+ +-+
+--R     b\|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           +-------------+         +-------+              +-+
+--R           |           2      - 2d\|e x + d  + (e x + 2d)\|d
+--R         A\|- b c e + c d log(-------------------------------)
+--R                                             x
+--R       + 
+--R                       +-+
+--R           (A c - B b)\|d
+--R        *
+--R                                                                +-------------+
+--R                           2   +-------+                        |           2
+--R             (- 2b c e + 2c d)\|e x + d  + (c e x - b e + 2c d)\|- b c e + c d
+--R         log(------------------------------------------------------------------)
+--R                                           c x + b
+--R    /
+--R         +-------------+
+--R         |           2   +-+
+--R       b\|- b c e + c d \|d
+--R     ,
+--R
+--R           +-----------+         +-------+              +-+
+--R           |         2      - 2d\|e x + d  + (e x + 2d)\|d
+--R         A\|b c e - c d log(-------------------------------)
+--R                                           x
+--R       + 
+--R                                  +-----------+
+--R                                  |         2   +-------+
+--R                         +-+     \|b c e - c d \|e x + d
+--R         (- 2A c + 2B b)\|d atan(------------------------)
+--R                                         b e - c d
+--R    /
+--R             +-----------+
+--R         +-+ |         2
+--R       b\|d \|b c e - c d
+--R     ,
+--R
+--R                       +---+
+--R           (A c - B b)\|- d
+--R        *
+--R                                                                +-------------+
+--R                           2   +-------+                        |           2
+--R             (- 2b c e + 2c d)\|e x + d  + (c e x - b e + 2c d)\|- b c e + c d
+--R         log(------------------------------------------------------------------)
+--R                                           c x + b
+--R       + 
+--R              +-------------+      +---+ +-------+
+--R              |           2       \|- d \|e x + d
+--R         - 2A\|- b c e + c d atan(----------------)
+--R                                          d
+--R    /
+--R         +-------------+
+--R         |           2   +---+
+--R       b\|- b c e + c d \|- d
+--R     ,
+--R
+--R                                    +-----------+
+--R                                    |         2   +-------+
+--R                         +---+     \|b c e - c d \|e x + d
+--R         (- 2A c + 2B b)\|- d atan(------------------------)
+--R                                           b e - c d
+--R       + 
+--R              +-----------+      +---+ +-------+
+--R              |         2       \|- d \|e x + d
+--R         - 2A\|b c e - c d atan(----------------)
+--R                                        d
+--R    /
+--R               +-----------+
+--R         +---+ |         2
+--R       b\|- d \|b c e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 732
+
+--S 733 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         +-------------+                           +-------+              +-+
+--R         |           2   +-----------+ +-+    - 2d\|e x + d  + (e x + 2d)\|d
+--R       A\|- b c e + c d \|- b e + c d \|c log(-------------------------------)
+--R                                                             x
+--R     + 
+--R                     +-----------+ +-+ +-+
+--R         (A c - B b)\|- b e + c d \|c \|d
+--R      *
+--R                                                              +-------------+
+--R                         2   +-------+                        |           2
+--R           (- 2b c e + 2c d)\|e x + d  + (c e x - b e + 2c d)\|- b c e + c d
+--R       log(------------------------------------------------------------------)
+--R                                         c x + b
+--R     + 
+--R                       +-------------+           +-+ +-------+
+--R                       |           2   +-+      \|c \|e x + d
+--R       (- 2A c + 2B b)\|- b c e + c d \|d atanh(--------------)
+--R                                                 +-----------+
+--R                                                \|- b e + c d
+--R     + 
+--R          +-------------+                         +-------+
+--R          |           2   +-----------+ +-+      \|e x + d
+--R       2A\|- b c e + c d \|- b e + c d \|c atanh(----------)
+--R                                                     +-+
+--R                                                    \|d
+--R  /
+--R       +-------------+
+--R       |           2   +-----------+ +-+ +-+
+--R     b\|- b c e + c d \|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 733
+
+--S 734 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 734
+
+--S 735 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                           +-----------+         +-------+              +-+
+--R         +-----------+ +-+ |         2      - 2d\|e x + d  + (e x + 2d)\|d
+--R       A\|- b e + c d \|c \|b c e - c d log(-------------------------------)
+--R                                                           x
+--R     + 
+--R                           +-----------+       +-+ +-------+
+--R                       +-+ |         2        \|c \|e x + d
+--R       (- 2A c + 2B b)\|d \|b c e - c d atanh(--------------)
+--R                                               +-----------+
+--R                                              \|- b e + c d
+--R     + 
+--R                            +-----------+       +-------+
+--R          +-----------+ +-+ |         2        \|e x + d
+--R       2A\|- b e + c d \|c \|b c e - c d atanh(----------)
+--R                                                   +-+
+--R                                                  \|d
+--R     + 
+--R                                                  +-----------+
+--R                                                  |         2   +-------+
+--R                       +-----------+ +-+ +-+     \|b c e - c d \|e x + d
+--R       (- 2A c + 2B b)\|- b e + c d \|c \|d atan(------------------------)
+--R                                                         b e - c d
+--R  /
+--R                             +-----------+
+--R       +-----------+ +-+ +-+ |         2
+--R     b\|- b e + c d \|c \|d \|b c e - c d
+--R                                                    Type: Expression(Integer)
+--E 735
+
+--S 736 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 736
+
+)clear all
+
+--S 737 of 1457
+t0:=(A+B*x)/((d+e*x)^(3/2)*(b*x+c*x^2))
+--R 
+--R
+--R                          B x + A
+--R   (1)  ------------------------------------------
+--R              3               2          +-------+
+--R        (c e x  + (b e + c d)x  + b d x)\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 1457
+r0:=-2*A*atanh(sqrt(d+e*x)/sqrt(d))/(b*d^(3/2))-2*(b*B-A*c)*atanh(sqrt(c)*_
+     sqrt(d+e*x)/sqrt(c*d-b*e))*sqrt(c)/(b*(c*d-b*e)^(3/2))+_
+     2*(B*d-A*e)/(d*(c*d-b*e)*sqrt(d+e*x))
+--R 
+--R
+--R   (2)
+--R                                                +-+ +-------+
+--R                        +-+ +-+ +-------+      \|c \|e x + d
+--R       (- 2A c + 2B b)d\|c \|d \|e x + d atanh(--------------)
+--R                                                +-----------+
+--R                                               \|- b e + c d
+--R     + 
+--R                                                         +-------+
+--R                           +-----------+ +-------+      \|e x + d
+--R       (- 2A b e + 2A c d)\|- b e + c d \|e x + d atanh(----------)
+--R                                                            +-+
+--R                                                           \|d
+--R     + 
+--R                         +-----------+ +-+
+--R       (2A b e - 2B b d)\|- b e + c d \|d
+--R  /
+--R       2           2  +-----------+ +-+ +-------+
+--R     (b d e - b c d )\|- b e + c d \|d \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 738
+
+--S 739 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        +-----------+
+--R                        |      c      +-+ +-------+
+--R           (A c - B b)d |- --------- \|d \|e x + d
+--R                       \|  b e - c d
+--R        *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R               (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R           log(----------------------------------------------------------)
+--R                                         c x + b
+--R       + 
+--R                                           +-------+              +-+
+--R                         +-------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R         (A b e - A c d)\|e x + d log(-------------------------------)
+--R                                                     x
+--R       + 
+--R                           +-+
+--R         (2A b e - 2B b d)\|d
+--R    /
+--R         2           2  +-+ +-------+
+--R       (b d e - b c d )\|d \|e x + d
+--R     ,
+--R
+--R                                           +-------+              +-+
+--R                         +-------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R         (A b e - A c d)\|e x + d log(-------------------------------)
+--R                                                     x
+--R       + 
+--R                        +---------+                           +-------+
+--R                        |    c      +-+ +-------+           c\|e x + d
+--R         (2A c - 2B b)d |--------- \|d \|e x + d atan(-----------------------)
+--R                       \|b e - c d                                +---------+
+--R                                                                  |    c
+--R                                                      (b e - c d) |---------
+--R                                                                 \|b e - c d
+--R       + 
+--R                           +-+
+--R         (2A b e - 2B b d)\|d
+--R    /
+--R         2           2  +-+ +-------+
+--R       (b d e - b c d )\|d \|e x + d
+--R     ,
+--R
+--R                              +-----------+
+--R                        +---+ |      c      +-------+
+--R           (A c - B b)d\|- d  |- --------- \|e x + d
+--R                             \|  b e - c d
+--R        *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R               (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R           log(----------------------------------------------------------)
+--R                                         c x + b
+--R       + 
+--R                                            +---+ +-------+
+--R                             +-------+     \|- d \|e x + d
+--R         (- 2A b e + 2A c d)\|e x + d atan(----------------)
+--R                                                   d
+--R       + 
+--R                           +---+
+--R         (2A b e - 2B b d)\|- d
+--R    /
+--R         2           2  +---+ +-------+
+--R       (b d e - b c d )\|- d \|e x + d
+--R     ,
+--R
+--R                                            +---+ +-------+
+--R                             +-------+     \|- d \|e x + d
+--R         (- 2A b e + 2A c d)\|e x + d atan(----------------)
+--R                                                   d
+--R       + 
+--R                              +---------+                       +-------+
+--R                        +---+ |    c      +-------+           c\|e x + d
+--R         (2A c - 2B b)d\|- d  |--------- \|e x + d atan(-----------------------)
+--R                             \|b e - c d                            +---------+
+--R                                                                    |    c
+--R                                                        (b e - c d) |---------
+--R                                                                   \|b e - c d
+--R       + 
+--R                           +---+
+--R         (2A b e - 2B b d)\|- d
+--R    /
+--R         2           2  +---+ +-------+
+--R       (b d e - b c d )\|- d \|e x + d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 739
+
+--S 740 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                    +-----------+
+--R                      +-----------+ |      c      +-+
+--R         (A c - B b)d\|- b e + c d  |- --------- \|d
+--R                                   \|  b e - c d
+--R      *
+--R                           +-----------+
+--R                           |      c      +-------+
+--R             (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                          \|  b e - c d
+--R         log(----------------------------------------------------------)
+--R                                       c x + b
+--R     + 
+--R                                             +-------+              +-+
+--R                       +-----------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R       (A b e - A c d)\|- b e + c d log(-------------------------------)
+--R                                                       x
+--R     + 
+--R                                    +-+ +-------+
+--R                      +-+ +-+      \|c \|e x + d
+--R       (2A c - 2B b)d\|c \|d atanh(--------------)
+--R                                    +-----------+
+--R                                   \|- b e + c d
+--R     + 
+--R                                             +-------+
+--R                         +-----------+      \|e x + d
+--R       (2A b e - 2A c d)\|- b e + c d atanh(----------)
+--R                                                +-+
+--R                                               \|d
+--R  /
+--R       2           2  +-----------+ +-+
+--R     (b d e - b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 741
+
+--S 742 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                             +-------+              +-+
+--R                       +-----------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R       (A b e - A c d)\|- b e + c d log(-------------------------------)
+--R                                                       x
+--R     + 
+--R                                    +-+ +-------+
+--R                      +-+ +-+      \|c \|e x + d
+--R       (2A c - 2B b)d\|c \|d atanh(--------------)
+--R                                    +-----------+
+--R                                   \|- b e + c d
+--R     + 
+--R                                             +-------+
+--R                         +-----------+      \|e x + d
+--R       (2A b e - 2A c d)\|- b e + c d atanh(----------)
+--R                                                +-+
+--R                                               \|d
+--R     + 
+--R                                  +---------+                 +-------+
+--R                    +-----------+ |    c      +-+           c\|e x + d
+--R     (2A c - 2B b)d\|- b e + c d  |--------- \|d atan(-----------------------)
+--R                                 \|b e - c d                      +---------+
+--R                                                                  |    c
+--R                                                      (b e - c d) |---------
+--R                                                                 \|b e - c d
+--R  /
+--R       2           2  +-----------+ +-+
+--R     (b d e - b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 743
+
+)clear all
+
+--S 744 of 1457
+t0:=(A+B*x)/((d+e*x)^(5/2)*(b*x+c*x^2))
+--R 
+--R
+--R                                      B x + A
+--R   (1)  ------------------------------------------------------------------
+--R            2 4       2           3                2  2      2   +-------+
+--R        (c e x  + (b e  + 2c d e)x  + (2b d e + c d )x  + b d x)\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 1457
+r0:=2/3*(B*d-A*e)/(d*(c*d-b*e)*(d+e*x)^(3/2))-2*A*atanh(sqrt(d+e*x)/_
+     sqrt(d))/(b*d^(5/2))-2*c^(3/2)*(b*B-A*c)*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))/(b*(c*d-b*e)^(5/2))+2*(B*c*d^2-A*e*(2*c*d-b*e))/(d^2*_
+     (c*d-b*e)^2*sqrt(d+e*x))
+--R 
+--R
+--R   (2)
+--R               2           2           2           3  +-+ +-+ +-------+
+--R         ((6A c  - 6B b c)d e x + (6A c  - 6B b c)d )\|c \|d \|e x + d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                  2 3              2       2 2          2   2            2
+--R           (- 6A b e  + 12A b c d e  - 6A c d e)x - 6A b d e  + 12A b c d e
+--R         + 
+--R                 2 3
+--R           - 6A c d
+--R      *
+--R                                        +-------+
+--R          +-----------+ +-------+      \|e x + d
+--R         \|- b e + c d \|e x + d atanh(----------)
+--R                                           +-+
+--R                                          \|d
+--R     + 
+--R                2 3              2           2          2   2
+--R           (6A b e  - 12A b c d e  + 6B b c d e)x + 8A b d e
+--R         + 
+--R                            2  2            3
+--R           (- 14A b c - 2B b )d e + 8B b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R           3 2 3     2   3 2       2 4        3 3 2     2   4        2 5
+--R       ((3b d e  - 6b c d e  + 3b c d e)x + 3b d e  - 6b c d e + 3b c d )
+--R    *
+--R        +-----------+ +-+ +-------+
+--R       \|- b e + c d \|d \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 745
+
+--S 746 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2 3             2       2 2          2   2           2
+--R             (3A b e  - 6A b c d e  + 3A c d e)x + 3A b d e  - 6A b c d e
+--R           + 
+--R                 2 3
+--R             3A c d
+--R        *
+--R                              +-------+              +-+
+--R            +-------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-------------------------------)
+--R                                        x
+--R       + 
+--R                                                        +-----------+
+--R                 2           2           2           3  |      c      +-+
+--R           ((3A c  - 3B b c)d e x + (3A c  - 3B b c)d ) |- --------- \|d
+--R                                                       \|  b e - c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R        *
+--R                               +-----------+
+--R                               |      c      +-------+
+--R               (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                              \|  b e - c d
+--R           log(------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                  2 3              2           2          2   2
+--R             (6A b e  - 12A b c d e  + 6B b c d e)x + 8A b d e
+--R           + 
+--R                              2  2            3
+--R             (- 14A b c - 2B b )d e + 8B b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R             3 2 3     2   3 2       2 4        3 3 2     2   4        2 5  +-+
+--R         ((3b d e  - 6b c d e  + 3b c d e)x + 3b d e  - 6b c d e + 3b c d )\|d
+--R      *
+--R          +-------+
+--R         \|e x + d
+--R     ,
+--R
+--R                  2 3             2       2 2          2   2           2
+--R             (3A b e  - 6A b c d e  + 3A c d e)x + 3A b d e  - 6A b c d e
+--R           + 
+--R                 2 3
+--R             3A c d
+--R        *
+--R                              +-------+              +-+
+--R            +-------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-------------------------------)
+--R                                        x
+--R       + 
+--R                                                            +---------+
+--R                   2           2             2           3  |    c      +-+
+--R           ((- 6A c  + 6B b c)d e x + (- 6A c  + 6B b c)d ) |--------- \|d
+--R                                                           \|b e - c d
+--R        *
+--R                                  +-------+
+--R            +-------+           c\|e x + d
+--R           \|e x + d atan(-----------------------)
+--R                                      +---------+
+--R                                      |    c
+--R                          (b e - c d) |---------
+--R                                     \|b e - c d
+--R       + 
+--R                  2 3              2           2          2   2
+--R             (6A b e  - 12A b c d e  + 6B b c d e)x + 8A b d e
+--R           + 
+--R                              2  2            3
+--R             (- 14A b c - 2B b )d e + 8B b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R             3 2 3     2   3 2       2 4        3 3 2     2   4        2 5  +-+
+--R         ((3b d e  - 6b c d e  + 3b c d e)x + 3b d e  - 6b c d e + 3b c d )\|d
+--R      *
+--R          +-------+
+--R         \|e x + d
+--R     ,
+--R
+--R                                                              +-----------+
+--R                 2           2           2           3  +---+ |      c
+--R           ((3A c  - 3B b c)d e x + (3A c  - 3B b c)d )\|- d  |- ---------
+--R                                                             \|  b e - c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R        *
+--R                               +-----------+
+--R                               |      c      +-------+
+--R               (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                              \|  b e - c d
+--R           log(------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                    2 3              2       2 2          2   2            2
+--R             (- 6A b e  + 12A b c d e  - 6A c d e)x - 6A b d e  + 12A b c d e
+--R           + 
+--R                   2 3
+--R             - 6A c d
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                  2 3              2           2          2   2
+--R             (6A b e  - 12A b c d e  + 6B b c d e)x + 8A b d e
+--R           + 
+--R                              2  2            3
+--R             (- 14A b c - 2B b )d e + 8B b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R             3 2 3     2   3 2       2 4        3 3 2     2   4        2 5
+--R         ((3b d e  - 6b c d e  + 3b c d e)x + 3b d e  - 6b c d e + 3b c d )
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ,
+--R
+--R                    2 3              2       2 2          2   2            2
+--R             (- 6A b e  + 12A b c d e  - 6A c d e)x - 6A b d e  + 12A b c d e
+--R           + 
+--R                   2 3
+--R             - 6A c d
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                                                                  +---------+
+--R                   2           2             2           3  +---+ |    c
+--R           ((- 6A c  + 6B b c)d e x + (- 6A c  + 6B b c)d )\|- d  |---------
+--R                                                                 \|b e - c d
+--R        *
+--R                                  +-------+
+--R            +-------+           c\|e x + d
+--R           \|e x + d atan(-----------------------)
+--R                                      +---------+
+--R                                      |    c
+--R                          (b e - c d) |---------
+--R                                     \|b e - c d
+--R       + 
+--R                  2 3              2           2          2   2
+--R             (6A b e  - 12A b c d e  + 6B b c d e)x + 8A b d e
+--R           + 
+--R                              2  2            3
+--R             (- 14A b c - 2B b )d e + 8B b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R             3 2 3     2   3 2       2 4        3 3 2     2   4        2 5
+--R         ((3b d e  - 6b c d e  + 3b c d e)x + 3b d e  - 6b c d e + 3b c d )
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 746
+
+--S 747 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2 2                   2 2  +-----------+
+--R         (A b e  - 2A b c d e + A c d )\|- b e + c d
+--R      *
+--R                  +-------+              +-+
+--R             - 2d\|e x + d  + (e x + 2d)\|d
+--R         log(-------------------------------)
+--R                            x
+--R     + 
+--R                                        +-----------+
+--R             2          2 +-----------+ |      c      +-+
+--R         (A c  - B b c)d \|- b e + c d  |- --------- \|d
+--R                                       \|  b e - c d
+--R      *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R             (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R         log(------------------------------------------------------------)
+--R                                        c x + b
+--R     + 
+--R                                          +-+ +-------+
+--R              2           2 +-+ +-+      \|c \|e x + d
+--R       (- 2A c  + 2B b c)d \|c \|d atanh(--------------)
+--R                                          +-----------+
+--R                                         \|- b e + c d
+--R     + 
+--R                                                            +-------+
+--R            2 2                    2 2  +-----------+      \|e x + d
+--R       (2A b e  - 4A b c d e + 2A c d )\|- b e + c d atanh(----------)
+--R                                                               +-+
+--R                                                              \|d
+--R  /
+--R       3 2 2     2   3       2 4  +-----------+ +-+
+--R     (b d e  - 2b c d e + b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 747
+
+--S 748 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 748
+
+--S 749 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             2 2                   2 2  +-----------+
+--R         (A b e  - 2A b c d e + A c d )\|- b e + c d
+--R      *
+--R                  +-------+              +-+
+--R             - 2d\|e x + d  + (e x + 2d)\|d
+--R         log(-------------------------------)
+--R                            x
+--R     + 
+--R                                          +-+ +-------+
+--R              2           2 +-+ +-+      \|c \|e x + d
+--R       (- 2A c  + 2B b c)d \|c \|d atanh(--------------)
+--R                                          +-----------+
+--R                                         \|- b e + c d
+--R     + 
+--R                                                            +-------+
+--R            2 2                    2 2  +-----------+      \|e x + d
+--R       (2A b e  - 4A b c d e + 2A c d )\|- b e + c d atanh(----------)
+--R                                                               +-+
+--R                                                              \|d
+--R     + 
+--R                                            +---------+
+--R                2           2 +-----------+ |    c      +-+
+--R         (- 2A c  + 2B b c)d \|- b e + c d  |--------- \|d
+--R                                           \|b e - c d
+--R      *
+--R                      +-------+
+--R                    c\|e x + d
+--R         atan(-----------------------)
+--R                          +---------+
+--R                          |    c
+--R              (b e - c d) |---------
+--R                         \|b e - c d
+--R  /
+--R       3 2 2     2   3       2 4  +-----------+ +-+
+--R     (b d e  - 2b c d e + b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 750
+
+)clear all
+
+--S 751 of 1457
+t0:=(A+B*x)/((d+e*x)^(7/2)*(b*x+c*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R            3 5       3         2  4          2       2   3        2       3  2
+--R         c e x  + (b e  + 3c d e )x  + (3b d e  + 3c d e)x  + (3b d e + c d )x
+--R       + 
+--R            3
+--R         b d x
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 1457
+r0:=2/5*(B*d-A*e)/(d*(c*d-b*e)*(d+e*x)^(5/2))+2/3*(B*c*d^2-A*e*(2*c*d-_
+     b*e))/(d^2*(c*d-b*e)^2*(d+e*x)^(3/2))-2*A*atanh(sqrt(d+e*x)/_
+     sqrt(d))/(b*d^(7/2))-2*c^(5/2)*(b*B-A*c)*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))/(b*(c*d-b*e)^(7/2))+2*(B*c^2*d^3-A*e*(3*c^2*d^2-_
+     3*b*c*d*e+b^2*e^2))/(d^3*(c*d-b*e)^3*sqrt(d+e*x))
+--R 
+--R
+--R   (2)
+--R                   3          2  3 2 2           3          2  4
+--R           (- 30A c  + 30B b c )d e x  + (- 60A c  + 60B b c )d e x
+--R         + 
+--R                   3          2  5
+--R           (- 30A c  + 30B b c )d
+--R      *
+--R                                  +-+ +-------+
+--R          +-+ +-+ +-------+      \|c \|e x + d
+--R         \|c \|d \|e x + d atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- b e + c d
+--R     + 
+--R                   3 5        2     4          2 2 3        3 3 2  2
+--R           (- 30A b e  + 90A b c d e  - 90A b c d e  + 30A c d e )x
+--R         + 
+--R                   3   4         2   2 3           2 3 2        3 4
+--R           (- 60A b d e  + 180A b c d e  - 180A b c d e  + 60A c d e)x
+--R         + 
+--R                  3 2 3        2   3 2          2 4         3 5
+--R           - 30A b d e  + 90A b c d e  - 90A b c d e + 30A c d
+--R      *
+--R                                        +-------+
+--R          +-----------+ +-------+      \|e x + d
+--R         \|- b e + c d \|e x + d atanh(----------)
+--R                                           +-+
+--R                                          \|d
+--R     + 
+--R                 3 5        2     4          2 2 3          2 3 2  2
+--R           (30A b e  - 90A b c d e  + 90A b c d e  - 30B b c d e )x
+--R         + 
+--R                    3   4         2   2 3            2        2   3 2
+--R               70A b d e  - 210A b c d e  + (200A b c  + 10B b c)d e
+--R             + 
+--R                        2 4
+--R               - 70B b c d e
+--R          *
+--R             x
+--R         + 
+--R                3 2 3            2        3  3 2            2        2   4
+--R           46A b d e  + (- 132A b c - 6B b )d e  + (116A b c  + 22B b c)d e
+--R         + 
+--R                    2 5
+--R           - 46B b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R             4 3 5      3   4 4      2 2 5 3        3 6 2  2
+--R         (15b d e  - 45b c d e  + 45b c d e  - 15b c d e )x
+--R       + 
+--R             4 4 4      3   5 3      2 2 6 2        3 7         4 5 3
+--R         (30b d e  - 90b c d e  + 90b c d e  - 30b c d e)x + 15b d e
+--R       + 
+--R              3   6 2      2 2 7         3 8
+--R         - 45b c d e  + 45b c d e - 15b c d
+--R    *
+--R        +-----------+ +-+ +-------+
+--R       \|- b e + c d \|d \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   3          2  3 2 2         3          2  4
+--R             (15A c  - 15B b c )d e x  + (30A c  - 30B b c )d e x
+--R           + 
+--R                   3          2  5
+--R             (15A c  - 15B b c )d
+--R        *
+--R            +-----------+
+--R            |      c      +-+ +-------+
+--R            |- --------- \|d \|e x + d
+--R           \|  b e - c d
+--R        *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R               (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R           log(----------------------------------------------------------)
+--R                                         c x + b
+--R       + 
+--R                   3 5        2     4          2 2 3        3 3 2  2
+--R             (15A b e  - 45A b c d e  + 45A b c d e  - 15A c d e )x
+--R           + 
+--R                   3   4        2   2 3          2 3 2        3 4
+--R             (30A b d e  - 90A b c d e  + 90A b c d e  - 30A c d e)x
+--R           + 
+--R                  3 2 3        2   3 2          2 4         3 5
+--R             15A b d e  - 45A b c d e  + 45A b c d e - 15A c d
+--R        *
+--R                              +-------+              +-+
+--R            +-------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-------------------------------)
+--R                                        x
+--R       + 
+--R                   3 5        2     4          2 2 3          2 3 2  2
+--R             (30A b e  - 90A b c d e  + 90A b c d e  - 30B b c d e )x
+--R           + 
+--R                      3   4         2   2 3            2        2   3 2
+--R                 70A b d e  - 210A b c d e  + (200A b c  + 10B b c)d e
+--R               + 
+--R                          2 4
+--R                 - 70B b c d e
+--R            *
+--R               x
+--R           + 
+--R                  3 2 3            2        3  3 2            2        2   4
+--R             46A b d e  + (- 132A b c - 6B b )d e  + (116A b c  + 22B b c)d e
+--R           + 
+--R                      2 5
+--R             - 46B b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R               4 3 5      3   4 4      2 2 5 3        3 6 2  2
+--R           (15b d e  - 45b c d e  + 45b c d e  - 15b c d e )x
+--R         + 
+--R               4 4 4      3   5 3      2 2 6 2        3 7         4 5 3
+--R           (30b d e  - 90b c d e  + 90b c d e  - 30b c d e)x + 15b d e
+--R         + 
+--R                3   6 2      2 2 7         3 8
+--R           - 45b c d e  + 45b c d e - 15b c d
+--R      *
+--R          +-+ +-------+
+--R         \|d \|e x + d
+--R     ,
+--R
+--R                   3 5        2     4          2 2 3        3 3 2  2
+--R             (15A b e  - 45A b c d e  + 45A b c d e  - 15A c d e )x
+--R           + 
+--R                   3   4        2   2 3          2 3 2        3 4
+--R             (30A b d e  - 90A b c d e  + 90A b c d e  - 30A c d e)x
+--R           + 
+--R                  3 2 3        2   3 2          2 4         3 5
+--R             15A b d e  - 45A b c d e  + 45A b c d e - 15A c d
+--R        *
+--R                              +-------+              +-+
+--R            +-------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-------------------------------)
+--R                                        x
+--R       + 
+--R                   3          2  3 2 2         3          2  4
+--R             (30A c  - 30B b c )d e x  + (60A c  - 60B b c )d e x
+--R           + 
+--R                   3          2  5
+--R             (30A c  - 30B b c )d
+--R        *
+--R            +---------+                           +-------+
+--R            |    c      +-+ +-------+           c\|e x + d
+--R            |--------- \|d \|e x + d atan(-----------------------)
+--R           \|b e - c d                                +---------+
+--R                                                      |    c
+--R                                          (b e - c d) |---------
+--R                                                     \|b e - c d
+--R       + 
+--R                   3 5        2     4          2 2 3          2 3 2  2
+--R             (30A b e  - 90A b c d e  + 90A b c d e  - 30B b c d e )x
+--R           + 
+--R                      3   4         2   2 3            2        2   3 2
+--R                 70A b d e  - 210A b c d e  + (200A b c  + 10B b c)d e
+--R               + 
+--R                          2 4
+--R                 - 70B b c d e
+--R            *
+--R               x
+--R           + 
+--R                  3 2 3            2        3  3 2            2        2   4
+--R             46A b d e  + (- 132A b c - 6B b )d e  + (116A b c  + 22B b c)d e
+--R           + 
+--R                      2 5
+--R             - 46B b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R               4 3 5      3   4 4      2 2 5 3        3 6 2  2
+--R           (15b d e  - 45b c d e  + 45b c d e  - 15b c d e )x
+--R         + 
+--R               4 4 4      3   5 3      2 2 6 2        3 7         4 5 3
+--R           (30b d e  - 90b c d e  + 90b c d e  - 30b c d e)x + 15b d e
+--R         + 
+--R                3   6 2      2 2 7         3 8
+--R           - 45b c d e  + 45b c d e - 15b c d
+--R      *
+--R          +-+ +-------+
+--R         \|d \|e x + d
+--R     ,
+--R
+--R                   3          2  3 2 2         3          2  4
+--R             (15A c  - 15B b c )d e x  + (30A c  - 30B b c )d e x
+--R           + 
+--R                   3          2  5
+--R             (15A c  - 15B b c )d
+--R        *
+--R                  +-----------+
+--R            +---+ |      c      +-------+
+--R           \|- d  |- --------- \|e x + d
+--R                 \|  b e - c d
+--R        *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R               (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R           log(----------------------------------------------------------)
+--R                                         c x + b
+--R       + 
+--R                     3 5        2     4          2 2 3        3 3 2  2
+--R             (- 30A b e  + 90A b c d e  - 90A b c d e  + 30A c d e )x
+--R           + 
+--R                     3   4         2   2 3           2 3 2        3 4
+--R             (- 60A b d e  + 180A b c d e  - 180A b c d e  + 60A c d e)x
+--R           + 
+--R                    3 2 3        2   3 2          2 4         3 5
+--R             - 30A b d e  + 90A b c d e  - 90A b c d e + 30A c d
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                   3 5        2     4          2 2 3          2 3 2  2
+--R             (30A b e  - 90A b c d e  + 90A b c d e  - 30B b c d e )x
+--R           + 
+--R                      3   4         2   2 3            2        2   3 2
+--R                 70A b d e  - 210A b c d e  + (200A b c  + 10B b c)d e
+--R               + 
+--R                          2 4
+--R                 - 70B b c d e
+--R            *
+--R               x
+--R           + 
+--R                  3 2 3            2        3  3 2            2        2   4
+--R             46A b d e  + (- 132A b c - 6B b )d e  + (116A b c  + 22B b c)d e
+--R           + 
+--R                      2 5
+--R             - 46B b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R               4 3 5      3   4 4      2 2 5 3        3 6 2  2
+--R           (15b d e  - 45b c d e  + 45b c d e  - 15b c d e )x
+--R         + 
+--R               4 4 4      3   5 3      2 2 6 2        3 7         4 5 3
+--R           (30b d e  - 90b c d e  + 90b c d e  - 30b c d e)x + 15b d e
+--R         + 
+--R                3   6 2      2 2 7         3 8
+--R           - 45b c d e  + 45b c d e - 15b c d
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ,
+--R
+--R                     3 5        2     4          2 2 3        3 3 2  2
+--R             (- 30A b e  + 90A b c d e  - 90A b c d e  + 30A c d e )x
+--R           + 
+--R                     3   4         2   2 3           2 3 2        3 4
+--R             (- 60A b d e  + 180A b c d e  - 180A b c d e  + 60A c d e)x
+--R           + 
+--R                    3 2 3        2   3 2          2 4         3 5
+--R             - 30A b d e  + 90A b c d e  - 90A b c d e + 30A c d
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                   3          2  3 2 2         3          2  4
+--R             (30A c  - 30B b c )d e x  + (60A c  - 60B b c )d e x
+--R           + 
+--R                   3          2  5
+--R             (30A c  - 30B b c )d
+--R        *
+--R                  +---------+                       +-------+
+--R            +---+ |    c      +-------+           c\|e x + d
+--R           \|- d  |--------- \|e x + d atan(-----------------------)
+--R                 \|b e - c d                            +---------+
+--R                                                        |    c
+--R                                            (b e - c d) |---------
+--R                                                       \|b e - c d
+--R       + 
+--R                   3 5        2     4          2 2 3          2 3 2  2
+--R             (30A b e  - 90A b c d e  + 90A b c d e  - 30B b c d e )x
+--R           + 
+--R                      3   4         2   2 3            2        2   3 2
+--R                 70A b d e  - 210A b c d e  + (200A b c  + 10B b c)d e
+--R               + 
+--R                          2 4
+--R                 - 70B b c d e
+--R            *
+--R               x
+--R           + 
+--R                  3 2 3            2        3  3 2            2        2   4
+--R             46A b d e  + (- 132A b c - 6B b )d e  + (116A b c  + 22B b c)d e
+--R           + 
+--R                      2 5
+--R             - 46B b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R               4 3 5      3   4 4      2 2 5 3        3 6 2  2
+--R           (15b d e  - 45b c d e  + 45b c d e  - 15b c d e )x
+--R         + 
+--R               4 4 4      3   5 3      2 2 6 2        3 7         4 5 3
+--R           (30b d e  - 90b c d e  + 90b c d e  - 30b c d e)x + 15b d e
+--R         + 
+--R                3   6 2      2 2 7         3 8
+--R           - 45b c d e  + 45b c d e - 15b c d
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 753
+
+--S 754 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                         +-----------+
+--R             3        2  3 +-----------+ |      c      +-+
+--R         (A c  - B b c )d \|- b e + c d  |- --------- \|d
+--R                                        \|  b e - c d
+--R      *
+--R                           +-----------+
+--R                           |      c      +-------+
+--R             (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                          \|  b e - c d
+--R         log(----------------------------------------------------------)
+--R                                       c x + b
+--R     + 
+--R             3 3       2     2         2 2       3 3  +-----------+
+--R         (A b e  - 3A b c d e  + 3A b c d e - A c d )\|- b e + c d
+--R      *
+--R                  +-------+              +-+
+--R             - 2d\|e x + d  + (e x + 2d)\|d
+--R         log(-------------------------------)
+--R                            x
+--R     + 
+--R                                         +-+ +-------+
+--R            3         2  3 +-+ +-+      \|c \|e x + d
+--R       (2A c  - 2B b c )d \|c \|d atanh(--------------)
+--R                                         +-----------+
+--R                                        \|- b e + c d
+--R     + 
+--R              3 3       2     2         2 2        3 3  +-----------+
+--R         (2A b e  - 6A b c d e  + 6A b c d e - 2A c d )\|- b e + c d
+--R      *
+--R                +-------+
+--R               \|e x + d
+--R         atanh(----------)
+--R                   +-+
+--R                  \|d
+--R  /
+--R       4 3 3     3   4 2     2 2 5       3 6  +-----------+ +-+
+--R     (b d e  - 3b c d e  + 3b c d e - b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 755
+
+--S 756 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             3 3       2     2         2 2       3 3  +-----------+
+--R         (A b e  - 3A b c d e  + 3A b c d e - A c d )\|- b e + c d
+--R      *
+--R                  +-------+              +-+
+--R             - 2d\|e x + d  + (e x + 2d)\|d
+--R         log(-------------------------------)
+--R                            x
+--R     + 
+--R                                         +-+ +-------+
+--R            3         2  3 +-+ +-+      \|c \|e x + d
+--R       (2A c  - 2B b c )d \|c \|d atanh(--------------)
+--R                                         +-----------+
+--R                                        \|- b e + c d
+--R     + 
+--R              3 3       2     2         2 2        3 3  +-----------+
+--R         (2A b e  - 6A b c d e  + 6A b c d e - 2A c d )\|- b e + c d
+--R      *
+--R                +-------+
+--R               \|e x + d
+--R         atanh(----------)
+--R                   +-+
+--R                  \|d
+--R     + 
+--R                                           +---------+
+--R              3         2  3 +-----------+ |    c      +-+
+--R         (2A c  - 2B b c )d \|- b e + c d  |--------- \|d
+--R                                          \|b e - c d
+--R      *
+--R                      +-------+
+--R                    c\|e x + d
+--R         atan(-----------------------)
+--R                          +---------+
+--R                          |    c
+--R              (b e - c d) |---------
+--R                         \|b e - c d
+--R  /
+--R       4 3 3     3   4 2     2 2 5       3 6  +-----------+ +-+
+--R     (b d e  - 3b c d e  + 3b c d e - b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 757
+
+)clear all
+
+--S 758 of 1457
+t0:=(A+B*x)/((d+e*x)^(9/2)*(b*x+c*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R            4 6       4         3  5          3       2 2  4
+--R         c e x  + (b e  + 4c d e )x  + (4b d e  + 6c d e )x
+--R       + 
+--R              2 2       3   3        3       4  2      4
+--R         (6b d e  + 4c d e)x  + (4b d e + c d )x  + b d x
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 758
+
+--S 759 of 1457
+r0:=2/7*(B*d-A*e)/(d*(c*d-b*e)*(d+e*x)^(7/2))+2/5*(B*c*d^2-A*e*(2*c*d-b*e))/_
+     (d^2*(c*d-b*e)^2*(d+e*x)^(5/2))+2/3*(B*c^2*d^3-A*e*(3*c^2*d^2-_
+     3*b*c*d*e+b^2*e^2))/(d^3*(c*d-b*e)^3*(d+e*x)^(3/2))-_
+     2*A*atanh(sqrt(d+e*x)/sqrt(d))/(b*d^(9/2))-2*c^(7/2)*(b*B-A*c)*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b*(c*d-b*e)^(9/2))+_
+     2*(B*c^3*d^4-A*e*(4*c^3*d^3-6*b*c^2*d^2*e+4*b^2*c*d*e^2-b^3*e^3))/_
+     (d^4*(c*d-b*e)^4*sqrt(d+e*x))
+--R 
+--R
+--R   (2)
+--R                  4           3  4 3 3          4           3  5 2 2
+--R           (210A c  - 210B b c )d e x  + (630A c  - 630B b c )d e x
+--R         + 
+--R                  4           3  6             4           3  7
+--R           (630A c  - 630B b c )d e x + (210A c  - 210B b c )d
+--R      *
+--R                                  +-+ +-------+
+--R          +-+ +-+ +-------+      \|c \|e x + d
+--R         \|c \|d \|e x + d atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- b e + c d
+--R     + 
+--R                       4 7         3     6          2 2 2 5           3 3 4
+--R               - 210A b e  + 840A b c d e  - 1260A b c d e  + 840A b c d e
+--R             + 
+--R                       4 4 3
+--R               - 210A c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       4   6          3   2 5          2 2 3 4            3 4 3
+--R               - 630A b d e  + 2520A b c d e  - 3780A b c d e  + 2520A b c d e
+--R             + 
+--R                       4 5 2
+--R               - 630A c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       4 2 5          3   3 4          2 2 4 3            3 5 2
+--R               - 630A b d e  + 2520A b c d e  - 3780A b c d e  + 2520A b c d e
+--R             + 
+--R                       4 6
+--R               - 630A c d e
+--R          *
+--R             x
+--R         + 
+--R                   4 3 4         3   4 3          2 2 5 2           3 6
+--R           - 210A b d e  + 840A b c d e  - 1260A b c d e  + 840A b c d e
+--R         + 
+--R                   4 7
+--R           - 210A c d
+--R      *
+--R                                        +-------+
+--R          +-----------+ +-------+      \|e x + d
+--R         \|- b e + c d \|e x + d atanh(----------)
+--R                                           +-+
+--R                                          \|d
+--R     + 
+--R                     4 7         3     6          2 2 2 5           3 3 4
+--R               210A b e  - 840A b c d e  + 1260A b c d e  - 840A b c d e
+--R             + 
+--R                       3 4 3
+--R               210B b c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     4   6          3   2 5          2 2 3 4
+--R               700A b d e  - 2800A b c d e  + 4200A b c d e
+--R             + 
+--R                           3        2 2  4 3           3 5 2
+--R               (- 2730A b c  - 70B b c )d e  + 700B b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     4 2 5          3   3 4           2 2        3   4 3
+--R               812A b d e  - 3248A b c d e  + (4830A b c  + 42B b c)d e
+--R             + 
+--R                           3         2 2  5 2           3 6
+--R               (- 3024A b c  - 224B b c )d e  + 812B b c d e
+--R          *
+--R             x
+--R         + 
+--R                 4 3 4             3         4  4 3
+--R           352A b d e  + (- 1378A b c - 30B b )d e
+--R         + 
+--R                   2 2         3   5 2               3         2 2  6
+--R           (1980A b c  + 132B b c)d e  + (- 1164A b c  - 244B b c )d e
+--R         + 
+--R                   3 7
+--R           352B b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R              5 4 7       4   5 6       3 2 6 5       2 3 7 4         4 8 3  3
+--R         (105b d e  - 420b c d e  + 630b c d e  - 420b c d e  + 105b c d e )x
+--R       + 
+--R                   5 5 6        4   6 5        3 2 7 4        2 3 8 3
+--R               315b d e  - 1260b c d e  + 1890b c d e  - 1260b c d e
+--R             + 
+--R                     4 9 2
+--R               315b c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R              5 6 5        4   7 4        3 2 8 3        2 3 9 2         4 10
+--R         (315b d e  - 1260b c d e  + 1890b c d e  - 1260b c d e  + 315b c d  e)x
+--R       + 
+--R             5 7 4       4   8 3       3 2 9 2       2 3 10          4 11
+--R         105b d e  - 420b c d e  + 630b c d e  - 420b c d  e + 105b c d
+--R    *
+--R        +-----------+ +-+ +-------+
+--R       \|- b e + c d \|d \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       4 7         3     6         2 2 2 5           3 3 4
+--R                 105A b e  - 420A b c d e  + 630A b c d e  - 420A b c d e
+--R               + 
+--R                       4 4 3
+--R                 105A c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4   6          3   2 5          2 2 3 4            3 4 3
+--R                 315A b d e  - 1260A b c d e  + 1890A b c d e  - 1260A b c d e
+--R               + 
+--R                       4 5 2
+--R                 315A c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       4 2 5          3   3 4          2 2 4 3            3 5 2
+--R                 315A b d e  - 1260A b c d e  + 1890A b c d e  - 1260A b c d e
+--R               + 
+--R                       4 6
+--R                 315A c d e
+--R            *
+--R               x
+--R           + 
+--R                   4 3 4         3   4 3         2 2 5 2           3 6
+--R             105A b d e  - 420A b c d e  + 630A b c d e  - 420A b c d e
+--R           + 
+--R                   4 7
+--R             105A c d
+--R        *
+--R                              +-------+              +-+
+--R            +-------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-------------------------------)
+--R                                        x
+--R       + 
+--R                    4           3  4 3 3          4           3  5 2 2
+--R             (105A c  - 105B b c )d e x  + (315A c  - 315B b c )d e x
+--R           + 
+--R                    4           3  6             4           3  7
+--R             (315A c  - 315B b c )d e x + (105A c  - 105B b c )d
+--R        *
+--R            +-----------+
+--R            |      c      +-+ +-------+
+--R            |- --------- \|d \|e x + d
+--R           \|  b e - c d
+--R        *
+--R                               +-----------+
+--R                               |      c      +-------+
+--R               (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                              \|  b e - c d
+--R           log(------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                       4 7         3     6          2 2 2 5           3 3 4
+--R                 210A b e  - 840A b c d e  + 1260A b c d e  - 840A b c d e
+--R               + 
+--R                         3 4 3
+--R                 210B b c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4   6          3   2 5          2 2 3 4
+--R                 700A b d e  - 2800A b c d e  + 4200A b c d e
+--R               + 
+--R                             3        2 2  4 3           3 5 2
+--R                 (- 2730A b c  - 70B b c )d e  + 700B b c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       4 2 5          3   3 4           2 2        3   4 3
+--R                 812A b d e  - 3248A b c d e  + (4830A b c  + 42B b c)d e
+--R               + 
+--R                             3         2 2  5 2           3 6
+--R                 (- 3024A b c  - 224B b c )d e  + 812B b c d e
+--R            *
+--R               x
+--R           + 
+--R                   4 3 4             3         4  4 3
+--R             352A b d e  + (- 1378A b c - 30B b )d e
+--R           + 
+--R                     2 2         3   5 2               3         2 2  6
+--R             (1980A b c  + 132B b c)d e  + (- 1164A b c  - 244B b c )d e
+--R           + 
+--R                     3 7
+--R             352B b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R                5 4 7       4   5 6       3 2 6 5       2 3 7 4         4 8 3  3
+--R           (105b d e  - 420b c d e  + 630b c d e  - 420b c d e  + 105b c d e )x
+--R         + 
+--R                   5 5 6        4   6 5        3 2 7 4        2 3 8 3
+--R               315b d e  - 1260b c d e  + 1890b c d e  - 1260b c d e
+--R             + 
+--R                     4 9 2
+--R               315b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   5 6 5        4   7 4        3 2 8 3        2 3 9 2
+--R               315b d e  - 1260b c d e  + 1890b c d e  - 1260b c d e
+--R             + 
+--R                     4 10
+--R               315b c d  e
+--R          *
+--R             x
+--R         + 
+--R               5 7 4       4   8 3       3 2 9 2       2 3 10          4 11
+--R           105b d e  - 420b c d e  + 630b c d e  - 420b c d  e + 105b c d
+--R      *
+--R          +-+ +-------+
+--R         \|d \|e x + d
+--R     ,
+--R
+--R                       4 7         3     6         2 2 2 5           3 3 4
+--R                 105A b e  - 420A b c d e  + 630A b c d e  - 420A b c d e
+--R               + 
+--R                       4 4 3
+--R                 105A c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4   6          3   2 5          2 2 3 4            3 4 3
+--R                 315A b d e  - 1260A b c d e  + 1890A b c d e  - 1260A b c d e
+--R               + 
+--R                       4 5 2
+--R                 315A c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       4 2 5          3   3 4          2 2 4 3            3 5 2
+--R                 315A b d e  - 1260A b c d e  + 1890A b c d e  - 1260A b c d e
+--R               + 
+--R                       4 6
+--R                 315A c d e
+--R            *
+--R               x
+--R           + 
+--R                   4 3 4         3   4 3         2 2 5 2           3 6
+--R             105A b d e  - 420A b c d e  + 630A b c d e  - 420A b c d e
+--R           + 
+--R                   4 7
+--R             105A c d
+--R        *
+--R                              +-------+              +-+
+--R            +-------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-------------------------------)
+--R                                        x
+--R       + 
+--R                      4           3  4 3 3            4           3  5 2 2
+--R             (- 210A c  + 210B b c )d e x  + (- 630A c  + 630B b c )d e x
+--R           + 
+--R                      4           3  6               4           3  7
+--R             (- 630A c  + 630B b c )d e x + (- 210A c  + 210B b c )d
+--R        *
+--R            +---------+                           +-------+
+--R            |    c      +-+ +-------+           c\|e x + d
+--R            |--------- \|d \|e x + d atan(-----------------------)
+--R           \|b e - c d                                +---------+
+--R                                                      |    c
+--R                                          (b e - c d) |---------
+--R                                                     \|b e - c d
+--R       + 
+--R                       4 7         3     6          2 2 2 5           3 3 4
+--R                 210A b e  - 840A b c d e  + 1260A b c d e  - 840A b c d e
+--R               + 
+--R                         3 4 3
+--R                 210B b c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4   6          3   2 5          2 2 3 4
+--R                 700A b d e  - 2800A b c d e  + 4200A b c d e
+--R               + 
+--R                             3        2 2  4 3           3 5 2
+--R                 (- 2730A b c  - 70B b c )d e  + 700B b c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       4 2 5          3   3 4           2 2        3   4 3
+--R                 812A b d e  - 3248A b c d e  + (4830A b c  + 42B b c)d e
+--R               + 
+--R                             3         2 2  5 2           3 6
+--R                 (- 3024A b c  - 224B b c )d e  + 812B b c d e
+--R            *
+--R               x
+--R           + 
+--R                   4 3 4             3         4  4 3
+--R             352A b d e  + (- 1378A b c - 30B b )d e
+--R           + 
+--R                     2 2         3   5 2               3         2 2  6
+--R             (1980A b c  + 132B b c)d e  + (- 1164A b c  - 244B b c )d e
+--R           + 
+--R                     3 7
+--R             352B b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R                5 4 7       4   5 6       3 2 6 5       2 3 7 4         4 8 3  3
+--R           (105b d e  - 420b c d e  + 630b c d e  - 420b c d e  + 105b c d e )x
+--R         + 
+--R                   5 5 6        4   6 5        3 2 7 4        2 3 8 3
+--R               315b d e  - 1260b c d e  + 1890b c d e  - 1260b c d e
+--R             + 
+--R                     4 9 2
+--R               315b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   5 6 5        4   7 4        3 2 8 3        2 3 9 2
+--R               315b d e  - 1260b c d e  + 1890b c d e  - 1260b c d e
+--R             + 
+--R                     4 10
+--R               315b c d  e
+--R          *
+--R             x
+--R         + 
+--R               5 7 4       4   8 3       3 2 9 2       2 3 10          4 11
+--R           105b d e  - 420b c d e  + 630b c d e  - 420b c d  e + 105b c d
+--R      *
+--R          +-+ +-------+
+--R         \|d \|e x + d
+--R     ,
+--R
+--R                    4           3  4 3 3          4           3  5 2 2
+--R             (105A c  - 105B b c )d e x  + (315A c  - 315B b c )d e x
+--R           + 
+--R                    4           3  6             4           3  7
+--R             (315A c  - 315B b c )d e x + (105A c  - 105B b c )d
+--R        *
+--R                  +-----------+
+--R            +---+ |      c      +-------+
+--R           \|- d  |- --------- \|e x + d
+--R                 \|  b e - c d
+--R        *
+--R                               +-----------+
+--R                               |      c      +-------+
+--R               (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                              \|  b e - c d
+--R           log(------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                         4 7         3     6          2 2 2 5           3 3 4
+--R                 - 210A b e  + 840A b c d e  - 1260A b c d e  + 840A b c d e
+--R               + 
+--R                         4 4 3
+--R                 - 210A c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4   6          3   2 5          2 2 3 4
+--R                 - 630A b d e  + 2520A b c d e  - 3780A b c d e
+--R               + 
+--R                          3 4 3         4 5 2
+--R                 2520A b c d e  - 630A c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         4 2 5          3   3 4          2 2 4 3
+--R                 - 630A b d e  + 2520A b c d e  - 3780A b c d e
+--R               + 
+--R                          3 5 2         4 6
+--R                 2520A b c d e  - 630A c d e
+--R            *
+--R               x
+--R           + 
+--R                     4 3 4         3   4 3          2 2 5 2           3 6
+--R             - 210A b d e  + 840A b c d e  - 1260A b c d e  + 840A b c d e
+--R           + 
+--R                     4 7
+--R             - 210A c d
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                       4 7         3     6          2 2 2 5           3 3 4
+--R                 210A b e  - 840A b c d e  + 1260A b c d e  - 840A b c d e
+--R               + 
+--R                         3 4 3
+--R                 210B b c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4   6          3   2 5          2 2 3 4
+--R                 700A b d e  - 2800A b c d e  + 4200A b c d e
+--R               + 
+--R                             3        2 2  4 3           3 5 2
+--R                 (- 2730A b c  - 70B b c )d e  + 700B b c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       4 2 5          3   3 4           2 2        3   4 3
+--R                 812A b d e  - 3248A b c d e  + (4830A b c  + 42B b c)d e
+--R               + 
+--R                             3         2 2  5 2           3 6
+--R                 (- 3024A b c  - 224B b c )d e  + 812B b c d e
+--R            *
+--R               x
+--R           + 
+--R                   4 3 4             3         4  4 3
+--R             352A b d e  + (- 1378A b c - 30B b )d e
+--R           + 
+--R                     2 2         3   5 2               3         2 2  6
+--R             (1980A b c  + 132B b c)d e  + (- 1164A b c  - 244B b c )d e
+--R           + 
+--R                     3 7
+--R             352B b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R                5 4 7       4   5 6       3 2 6 5       2 3 7 4         4 8 3  3
+--R           (105b d e  - 420b c d e  + 630b c d e  - 420b c d e  + 105b c d e )x
+--R         + 
+--R                   5 5 6        4   6 5        3 2 7 4        2 3 8 3
+--R               315b d e  - 1260b c d e  + 1890b c d e  - 1260b c d e
+--R             + 
+--R                     4 9 2
+--R               315b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   5 6 5        4   7 4        3 2 8 3        2 3 9 2
+--R               315b d e  - 1260b c d e  + 1890b c d e  - 1260b c d e
+--R             + 
+--R                     4 10
+--R               315b c d  e
+--R          *
+--R             x
+--R         + 
+--R               5 7 4       4   8 3       3 2 9 2       2 3 10          4 11
+--R           105b d e  - 420b c d e  + 630b c d e  - 420b c d  e + 105b c d
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ,
+--R
+--R                         4 7         3     6          2 2 2 5           3 3 4
+--R                 - 210A b e  + 840A b c d e  - 1260A b c d e  + 840A b c d e
+--R               + 
+--R                         4 4 3
+--R                 - 210A c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4   6          3   2 5          2 2 3 4
+--R                 - 630A b d e  + 2520A b c d e  - 3780A b c d e
+--R               + 
+--R                          3 4 3         4 5 2
+--R                 2520A b c d e  - 630A c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         4 2 5          3   3 4          2 2 4 3
+--R                 - 630A b d e  + 2520A b c d e  - 3780A b c d e
+--R               + 
+--R                          3 5 2         4 6
+--R                 2520A b c d e  - 630A c d e
+--R            *
+--R               x
+--R           + 
+--R                     4 3 4         3   4 3          2 2 5 2           3 6
+--R             - 210A b d e  + 840A b c d e  - 1260A b c d e  + 840A b c d e
+--R           + 
+--R                     4 7
+--R             - 210A c d
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                      4           3  4 3 3            4           3  5 2 2
+--R             (- 210A c  + 210B b c )d e x  + (- 630A c  + 630B b c )d e x
+--R           + 
+--R                      4           3  6               4           3  7
+--R             (- 630A c  + 630B b c )d e x + (- 210A c  + 210B b c )d
+--R        *
+--R                  +---------+                       +-------+
+--R            +---+ |    c      +-------+           c\|e x + d
+--R           \|- d  |--------- \|e x + d atan(-----------------------)
+--R                 \|b e - c d                            +---------+
+--R                                                        |    c
+--R                                            (b e - c d) |---------
+--R                                                       \|b e - c d
+--R       + 
+--R                       4 7         3     6          2 2 2 5           3 3 4
+--R                 210A b e  - 840A b c d e  + 1260A b c d e  - 840A b c d e
+--R               + 
+--R                         3 4 3
+--R                 210B b c d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4   6          3   2 5          2 2 3 4
+--R                 700A b d e  - 2800A b c d e  + 4200A b c d e
+--R               + 
+--R                             3        2 2  4 3           3 5 2
+--R                 (- 2730A b c  - 70B b c )d e  + 700B b c d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       4 2 5          3   3 4           2 2        3   4 3
+--R                 812A b d e  - 3248A b c d e  + (4830A b c  + 42B b c)d e
+--R               + 
+--R                             3         2 2  5 2           3 6
+--R                 (- 3024A b c  - 224B b c )d e  + 812B b c d e
+--R            *
+--R               x
+--R           + 
+--R                   4 3 4             3         4  4 3
+--R             352A b d e  + (- 1378A b c - 30B b )d e
+--R           + 
+--R                     2 2         3   5 2               3         2 2  6
+--R             (1980A b c  + 132B b c)d e  + (- 1164A b c  - 244B b c )d e
+--R           + 
+--R                     3 7
+--R             352B b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R                5 4 7       4   5 6       3 2 6 5       2 3 7 4         4 8 3  3
+--R           (105b d e  - 420b c d e  + 630b c d e  - 420b c d e  + 105b c d e )x
+--R         + 
+--R                   5 5 6        4   6 5        3 2 7 4        2 3 8 3
+--R               315b d e  - 1260b c d e  + 1890b c d e  - 1260b c d e
+--R             + 
+--R                     4 9 2
+--R               315b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   5 6 5        4   7 4        3 2 8 3        2 3 9 2
+--R               315b d e  - 1260b c d e  + 1890b c d e  - 1260b c d e
+--R             + 
+--R                     4 10
+--R               315b c d  e
+--R          *
+--R             x
+--R         + 
+--R               5 7 4       4   8 3       3 2 9 2       2 3 10          4 11
+--R           105b d e  - 420b c d e  + 630b c d e  - 420b c d  e + 105b c d
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 760
+
+--S 761 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             4 4       3     3       2 2 2 2         3 3       4 4
+--R         (A b e  - 4A b c d e  + 6A b c d e  - 4A b c d e + A c d )
+--R      *
+--R                                +-------+              +-+
+--R          +-----------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-------------------------------)
+--R                                          x
+--R     + 
+--R                                         +-----------+
+--R             4        3  4 +-----------+ |      c      +-+
+--R         (A c  - B b c )d \|- b e + c d  |- --------- \|d
+--R                                        \|  b e - c d
+--R      *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R             (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R         log(------------------------------------------------------------)
+--R                                        c x + b
+--R     + 
+--R                                           +-+ +-------+
+--R              4         3  4 +-+ +-+      \|c \|e x + d
+--R       (- 2A c  + 2B b c )d \|c \|d atanh(--------------)
+--R                                           +-----------+
+--R                                          \|- b e + c d
+--R     + 
+--R              4 4       3     3        2 2 2 2         3 3        4 4
+--R         (2A b e  - 8A b c d e  + 12A b c d e  - 8A b c d e + 2A c d )
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R  /
+--R       5 4 4     4   5 3     3 2 6 2     2 3 7       4 8  +-----------+ +-+
+--R     (b d e  - 4b c d e  + 6b c d e  - 4b c d e + b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             4 4       3     3       2 2 2 2         3 3       4 4
+--R         (A b e  - 4A b c d e  + 6A b c d e  - 4A b c d e + A c d )
+--R      *
+--R                                +-------+              +-+
+--R          +-----------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-------------------------------)
+--R                                          x
+--R     + 
+--R                                           +-+ +-------+
+--R              4         3  4 +-+ +-+      \|c \|e x + d
+--R       (- 2A c  + 2B b c )d \|c \|d atanh(--------------)
+--R                                           +-----------+
+--R                                          \|- b e + c d
+--R     + 
+--R              4 4       3     3        2 2 2 2         3 3        4 4
+--R         (2A b e  - 8A b c d e  + 12A b c d e  - 8A b c d e + 2A c d )
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R     + 
+--R                                             +---------+
+--R                4         3  4 +-----------+ |    c      +-+
+--R         (- 2A c  + 2B b c )d \|- b e + c d  |--------- \|d
+--R                                            \|b e - c d
+--R      *
+--R                      +-------+
+--R                    c\|e x + d
+--R         atan(-----------------------)
+--R                          +---------+
+--R                          |    c
+--R              (b e - c d) |---------
+--R                         \|b e - c d
+--R  /
+--R       5 4 4     4   5 3     3 2 6 2     2 3 7       4 8  +-----------+ +-+
+--R     (b d e  - 4b c d e  + 6b c d e  - 4b c d e + b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 763
+
+--S 764 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 764
+
+)clear all
+
+--S 765 of 1457
+t0:=(A+B*x)*(d+e*x)^(9/2)/(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R            4 5       4         3  4          3       2 2  3
+--R         B e x  + (A e  + 4B d e )x  + (4A d e  + 6B d e )x
+--R       + 
+--R              2 2       3   2        3       4        4
+--R         (6A d e  + 4B d e)x  + (4A d e + B d )x + A d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R      2 4         3    2 2
+--R     c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 765
+
+--S 766 of 1457
+r0:=1/3*e*(6*A*c^3*d^2-7*b^3*B*e^2-3*b*c^2*d*(B*d+2*A*e)+b^2*c*e*_
+     (12*B*d+5*A*e))*(d+e*x)^(3/2)/(b^2*c^3)+1/5*e*(10*A*c^2*d+7*b^2*B*e-_
+     5*b*c*(B*d+A*e))*(d+e*x)^(5/2)/(b^2*c^2)+(b*B-2*A*c)*(c*d-b*e)*_
+     (d+e*x)^(7/2)/(b^2*c*(b+c*x))-A*(d+e*x)^(9/2)/(b*x*(b+c*x))-_
+     d^(7/2)*(2*b*B*d-4*A*c*d+9*A*b*e)*atanh(sqrt(d+e*x)/sqrt(d))/b^3-_
+     (c*d-b*e)^(7/2)*(4*A*c^2*d-7*b^2*B*e-b*c*(2*B*d-5*A*e))*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^3*c^(9/2))+_
+     e*(2*A*c^4*d^3+7*b^4*B*e^3-b*c^3*d^2*(B*d+3*A*e)-b^3*c*e^2*_
+     (19*B*d+5*A*e)+b^2*c^2*d*e*(15*B*d+11*A*e))*sqrt(d+e*x)/(b^2*c^4)
+--R 
+--R
+--R   (2)
+--R                     4 2         5   4            3 3         4 2    3
+--R               (75A b c  - 105B b c)e  + (- 165A b c  + 285B b c )d e
+--R             + 
+--R                     2 4         3 3  2 2            5        2 4  3
+--R               (45A b c  - 225B b c )d e  + (105A b c  + 15B b c )d e
+--R             + 
+--R                       6          5  4
+--R               (- 60A c  + 30B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     5          6  4            4 2         5     3
+--R               (75A b c - 105B b )e  + (- 165A b c  + 285B b c)d e
+--R             + 
+--R                     3 3         4 2  2 2          2 4        3 3  3
+--R               (45A b c  - 225B b c )d e  + (105A b c  + 15B b c )d e
+--R             + 
+--R                         5        2 4  4
+--R               (- 60A b c  + 30B b c )d
+--R          *
+--R             x
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                      5 3          6          5  4  2
+--R           (- 135A b c d e + (60A c  - 30B b c )d )x
+--R         + 
+--R                    2 4 3            5        2 4  4
+--R           (- 135A b c d e + (60A b c  - 30B b c )d )x
+--R      *
+--R                        +-------+
+--R          +-+ +-+      \|e x + d
+--R         \|c \|d atanh(----------)
+--R                           +-+
+--R                          \|d
+--R     + 
+--R               3 3 4 4          3 3        4 2  4        3 3   3  3
+--R           6B b c e x  + ((10A b c  - 14B b c )e  + 42B b c d e )x
+--R         + 
+--R                       4 2        5   4          3 3         4 2    3
+--R               (- 50A b c  + 70B b c)e  + (130A b c  - 218B b c )d e
+--R             + 
+--R                     3 3 2 2
+--R               216B b c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       5          6  4          4 2         5     3
+--R               (- 75A b c + 105B b )e  + (190A b c  - 320B b c)d e
+--R             + 
+--R                       3 3         4 2  2 2         2 4        3 3  3
+--R               (- 90A b c  + 306B b c )d e  + (60A b c  - 60B b c )d e
+--R             + 
+--R                         5        2 4  4
+--R               (- 30A b c  + 15B b c )d
+--R          *
+--R             x
+--R         + 
+--R                  2 4 4
+--R           - 15A b c d
+--R      *
+--R          +-+ +-------+
+--R         \|c \|e x + d
+--R  /
+--R         3 5 2      4 4   +-+
+--R     (15b c x  + 15b c x)\|c
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 1457
+--a0:=integrate(t0,x)
+--E 767
+
+--S 768 of 1457
+--m0a:=a0.1-r0
+--E 768
+
+--S 769 of 1457
+--d0a:=D(m0a,x)
+--E 769
+
+--S 770 of 1457
+--m0b:=a0.2-r0
+--E 770
+
+--S 771 of 1457
+--d0b:=D(m0b,x)
+--E 771
+
+)clear all
+
+--S 772 of 1457
+t0:=(A+B*x)*(d+e*x)^(7/2)/(b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R            3 4       3         2  3          2       2   2        2       3
+--R         B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x
+--R       + 
+--R            3
+--R         A d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R      2 4         3    2 2
+--R     c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1457
+r0:=1/3*e*(6*A*c^2*d+5*b^2*B*e-3*b*c*(B*d+A*e))*(d+e*x)^(3/2)/(b^2*c^2)+_
+     (b*B-2*A*c)*(c*d-b*e)*(d+e*x)^(5/2)/(b^2*c*(b+c*x))-A*(d+e*x)^(7/2)/_
+     (b*x*(b+c*x))-d^(5/2)*(2*b*B*d-4*A*c*d+7*A*b*e)*atanh(sqrt(d+e*x)/_
+     sqrt(d))/b^3+(c*d-b*e)^(5/2)*(2*b*B*c*d-4*A*c^2*d+5*b^2*B*e-_
+     3*A*b*c*e)*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^3*c^(7/2))+_
+     e*(2*A*c^3*d^2-5*b^3*B*e^2-b*c^2*d*(B*d+2*A*e)+b^2*c*e*(8*B*d+_
+     3*A*e))*sqrt(d+e*x)/(b^2*c^3)
+--R 
+--R
+--R   (2)
+--R                      3 2        4   3        2 3        3 2    2
+--R               (- 9A b c  + 15B b c)e  + (6A b c  - 24B b c )d e
+--R             + 
+--R                       4       2 3  2            5         4  3
+--R               (15A b c  + 3B b c )d e + (- 12A c  + 6B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      4         5  3        3 2        4     2
+--R               (- 9A b c + 15B b )e  + (6A b c  - 24B b c)d e
+--R             + 
+--R                     2 3       3 2  2              4       2 3  3
+--R               (15A b c  + 3B b c )d e + (- 12A b c  + 6B b c )d
+--R          *
+--R             x
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                     4 2          5         4  3  2
+--R           (- 21A b c d e + (12A c  - 6B b c )d )x
+--R         + 
+--R                   2 3 2            4       2 3  3
+--R           (- 21A b c d e + (12A b c  - 6B b c )d )x
+--R      *
+--R                        +-------+
+--R          +-+ +-+      \|e x + d
+--R         \|c \|d atanh(----------)
+--R                           +-+
+--R                          \|d
+--R     + 
+--R               3 2 3 3         3 2        4   3        3 2   2  2
+--R           2B b c e x  + ((6A b c  - 10B b c)e  + 20B b c d e )x
+--R         + 
+--R                    4         5  3          3 2        4     2
+--R               (9A b c - 15B b )e  + (- 9A b c  + 29B b c)d e
+--R             + 
+--R                    2 3       3 2  2             4       2 3  3
+--R               (9A b c  - 9B b c )d e + (- 6A b c  + 3B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 2 3 3
+--R           - 3A b c d
+--R      *
+--R          +-+ +-------+
+--R         \|c \|e x + d
+--R  /
+--R        3 4 2     4 3   +-+
+--R     (3b c x  + 3b c x)\|c
+--R                                                    Type: Expression(Integer)
+--E 773
+
+--S 774 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3 2        4   3          2 3        3 2    2
+--R                 (9A b c  - 15B b c)e  + (- 6A b c  + 24B b c )d e
+--R               + 
+--R                           4       2 3  2          5         4  3
+--R                 (- 15A b c  - 3B b c )d e + (12A c  - 6B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      4         5  3          3 2        4     2
+--R                 (9A b c - 15B b )e  + (- 6A b c  + 24B b c)d e
+--R               + 
+--R                         2 3       3 2  2            4       2 3  3
+--R                 (- 15A b c  - 3B b c )d e + (12A b c  - 6B b c )d
+--R            *
+--R               x
+--R        *
+--R                                  +-----------+
+--R                                  |- b e + c d  +-------+
+--R            +-----------+    - 2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d         \|     c
+--R            |----------- log(-------------------------------------------------)
+--R           \|     c                               c x + b
+--R       + 
+--R                     4 2            5         4  3  2
+--R             (21A b c d e + (- 12A c  + 6B b c )d )x
+--R           + 
+--R                   2 3 2              4       2 3  3
+--R             (21A b c d e + (- 12A b c  + 6B b c )d )x
+--R        *
+--R                       +-+ +-------+
+--R            +-+    - 2\|d \|e x + d  + e x + 2d
+--R           \|d log(----------------------------)
+--R                                 x
+--R       + 
+--R                 3 2 3 3          3 2        4   3        3 2   2  2
+--R             4B b c e x  + ((12A b c  - 20B b c)e  + 40B b c d e )x
+--R           + 
+--R                       4         5  3           3 2        4     2
+--R                 (18A b c - 30B b )e  + (- 18A b c  + 58B b c)d e
+--R               + 
+--R                       2 3        3 2  2              4       2 3  3
+--R                 (18A b c  - 18B b c )d e + (- 12A b c  + 6B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   2 3 3
+--R             - 6A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         3 4 2     4 3
+--R       6b c x  + 6b c x
+--R     ,
+--R
+--R                     4 2            5         4  3  2
+--R             (21A b c d e + (- 12A c  + 6B b c )d )x
+--R           + 
+--R                   2 3 2              4       2 3  3
+--R             (21A b c d e + (- 12A b c  + 6B b c )d )x
+--R        *
+--R                       +-+ +-------+
+--R            +-+    - 2\|d \|e x + d  + e x + 2d
+--R           \|d log(----------------------------)
+--R                                 x
+--R       + 
+--R                         3 2        4   3         2 3        3 2    2
+--R                 (- 18A b c  + 30B b c)e  + (12A b c  - 48B b c )d e
+--R               + 
+--R                         4       2 3  2            5          4  3
+--R                 (30A b c  + 6B b c )d e + (- 24A c  + 12B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         4         5  3         3 2        4     2
+--R                 (- 18A b c + 30B b )e  + (12A b c  - 48B b c)d e
+--R               + 
+--R                       2 3       3 2  2              4        2 3  3
+--R                 (30A b c  + 6B b c )d e + (- 24A b c  + 12B b c )d
+--R            *
+--R               x
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                 3 2 3 3          3 2        4   3        3 2   2  2
+--R             4B b c e x  + ((12A b c  - 20B b c)e  + 40B b c d e )x
+--R           + 
+--R                       4         5  3           3 2        4     2
+--R                 (18A b c - 30B b )e  + (- 18A b c  + 58B b c)d e
+--R               + 
+--R                       2 3        3 2  2              4       2 3  3
+--R                 (18A b c  - 18B b c )d e + (- 12A b c  + 6B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   2 3 3
+--R             - 6A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         3 4 2     4 3
+--R       6b c x  + 6b c x
+--R     ,
+--R
+--R                      3 2        4   3          2 3        3 2    2
+--R                 (9A b c  - 15B b c)e  + (- 6A b c  + 24B b c )d e
+--R               + 
+--R                           4       2 3  2          5         4  3
+--R                 (- 15A b c  - 3B b c )d e + (12A c  - 6B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      4         5  3          3 2        4     2
+--R                 (9A b c - 15B b )e  + (- 6A b c  + 24B b c)d e
+--R               + 
+--R                         2 3       3 2  2            4       2 3  3
+--R                 (- 15A b c  - 3B b c )d e + (12A b c  - 6B b c )d
+--R            *
+--R               x
+--R        *
+--R                                  +-----------+
+--R                                  |- b e + c d  +-------+
+--R            +-----------+    - 2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d         \|     c
+--R            |----------- log(-------------------------------------------------)
+--R           \|     c                               c x + b
+--R       + 
+--R                       4 2          5          4  3  2
+--R             (- 42A b c d e + (24A c  - 12B b c )d )x
+--R           + 
+--R                     2 3 2            4        2 3  3
+--R             (- 42A b c d e + (24A b c  - 12B b c )d )x
+--R        *
+--R                       +-------+
+--R            +---+     \|e x + d
+--R           \|- d atan(----------)
+--R                         +---+
+--R                        \|- d
+--R       + 
+--R                 3 2 3 3          3 2        4   3        3 2   2  2
+--R             4B b c e x  + ((12A b c  - 20B b c)e  + 40B b c d e )x
+--R           + 
+--R                       4         5  3           3 2        4     2
+--R                 (18A b c - 30B b )e  + (- 18A b c  + 58B b c)d e
+--R               + 
+--R                       2 3        3 2  2              4       2 3  3
+--R                 (18A b c  - 18B b c )d e + (- 12A b c  + 6B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   2 3 3
+--R             - 6A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         3 4 2     4 3
+--R       6b c x  + 6b c x
+--R     ,
+--R
+--R                       4 2          5         4  3  2
+--R             (- 21A b c d e + (12A c  - 6B b c )d )x
+--R           + 
+--R                     2 3 2            4       2 3  3
+--R             (- 21A b c d e + (12A b c  - 6B b c )d )x
+--R        *
+--R                       +-------+
+--R            +---+     \|e x + d
+--R           \|- d atan(----------)
+--R                         +---+
+--R                        \|- d
+--R       + 
+--R                        3 2        4   3        2 3        3 2    2
+--R                 (- 9A b c  + 15B b c)e  + (6A b c  - 24B b c )d e
+--R               + 
+--R                         4       2 3  2            5         4  3
+--R                 (15A b c  + 3B b c )d e + (- 12A c  + 6B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        4         5  3        3 2        4     2
+--R                 (- 9A b c + 15B b )e  + (6A b c  - 24B b c)d e
+--R               + 
+--R                       2 3       3 2  2              4       2 3  3
+--R                 (15A b c  + 3B b c )d e + (- 12A b c  + 6B b c )d
+--R            *
+--R               x
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                 3 2 3 3         3 2        4   3        3 2   2  2
+--R             2B b c e x  + ((6A b c  - 10B b c)e  + 20B b c d e )x
+--R           + 
+--R                      4         5  3          3 2        4     2
+--R                 (9A b c - 15B b )e  + (- 9A b c  + 29B b c)d e
+--R               + 
+--R                      2 3       3 2  2             4       2 3  3
+--R                 (9A b c  - 9B b c )d e + (- 6A b c  + 3B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   2 3 3
+--R             - 3A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         3 4 2     4 3
+--R       3b c x  + 3b c x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 774
+
+--S 775 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                3        4  3          2 2       3     2
+--R           (3A b c - 5B b )e  + (- 2A b c  + 8B b c)d e
+--R         + 
+--R                    3      2 2  2         4         3  3
+--R           (- 5A b c  - B b c )d e + (4A c  - 2B b c )d
+--R      *
+--R                                  +-----------+
+--R                                  |- b e + c d  +-------+
+--R        +-----------+        - 2c |----------- \|e x + d  + c e x - b e + 2c d
+--R        |- b e + c d  +-+        \|     c
+--R        |----------- \|c log(-------------------------------------------------)
+--R       \|     c                                   c x + b
+--R     + 
+--R                3 2           4         3  3  +-+ +-+
+--R         (7A b c d e + (- 4A c  + 2B b c )d )\|c \|d
+--R      *
+--R                 +-+ +-------+
+--R             - 2\|d \|e x + d  + e x + 2d
+--R         log(----------------------------)
+--R                           x
+--R     + 
+--R                3         4  3          2 2        3     2
+--R           (6A b c - 10B b )e  + (- 4A b c  + 16B b c)d e
+--R         + 
+--R                     3       2 2  2         4         3  3
+--R           (- 10A b c  - 2B b c )d e + (8A c  - 4B b c )d
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                                                           +-------+
+--R               3 2           4         3  3  +-+ +-+      \|e x + d
+--R       (14A b c d e + (- 8A c  + 4B b c )d )\|c \|d atanh(----------)
+--R                                                              +-+
+--R                                                             \|d
+--R  /
+--R       3 3 +-+
+--R     2b c \|c
+--R                                                    Type: Expression(Integer)
+--E 775
+
+--S 776 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                3 2           4         3  3  +-+ +-+
+--R         (7A b c d e + (- 4A c  + 2B b c )d )\|c \|d
+--R      *
+--R                 +-+ +-------+
+--R             - 2\|d \|e x + d  + e x + 2d
+--R         log(----------------------------)
+--R                           x
+--R     + 
+--R                3         4  3          2 2        3     2
+--R           (6A b c - 10B b )e  + (- 4A b c  + 16B b c)d e
+--R         + 
+--R                     3       2 2  2         4         3  3
+--R           (- 10A b c  - 2B b c )d e + (8A c  - 4B b c )d
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                                                           +-------+
+--R               3 2           4         3  3  +-+ +-+      \|e x + d
+--R       (14A b c d e + (- 8A c  + 4B b c )d )\|c \|d atanh(----------)
+--R                                                              +-+
+--R                                                             \|d
+--R     + 
+--R                  3         4  3        2 2        3     2
+--R           (- 6A b c + 10B b )e  + (4A b c  - 16B b c)d e
+--R         + 
+--R                   3       2 2  2           4         3  3
+--R           (10A b c  + 2B b c )d e + (- 8A c  + 4B b c )d
+--R      *
+--R              +---------+       +-------+
+--R          +-+ |b e - c d       \|e x + d
+--R         \|c  |--------- atan(------------)
+--R             \|    c           +---------+
+--R                               |b e - c d
+--R                               |---------
+--R                              \|    c
+--R  /
+--R       3 3 +-+
+--R     2b c \|c
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 778
+
+)clear all
+
+--S 779 of 1457
+t0:=(A+B*x)*(d+e*x)^(5/2)/(b*x+c*x^2)^2
+--R 
+--R
+--R            2 3       2           2                2        2  +-------+
+--R        (B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d )\|e x + d
+--R   (1)  ----------------------------------------------------------------
+--R                               2 4         3    2 2
+--R                              c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 1457
+r0:=(b*B-2*A*c)*(c*d-b*e)*(d+e*x)^(3/2)/(b^2*c*(b+c*x))-A*(d+e*x)^(5/2)/_
+     (b*x*(b+c*x))-d^(3/2)*(2*b*B*d-4*A*c*d+5*A*b*e)*atanh(sqrt(d+e*x)/_
+     sqrt(d))/b^3-(c*d-b*e)^(3/2)*(4*A*c^2*d-3*b^2*B*e-b*c*(2*B*d-A*e))*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^3*c^(5/2))+e*(2*A*c^2*d+_
+     3*b^2*B*e-b*c*(B*d+A*e))*sqrt(d+e*x)/(b^2*c^2)
+--R 
+--R
+--R   (2)
+--R                     2 2       3   2          3      2 2
+--R                 (A b c  - 3B b c)e  + (3A b c  + B b c )d e
+--R               + 
+--R                        4         3  2
+--R                 (- 4A c  + 2B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R              3        4  2        2 2      3                 3       2 2  2
+--R         ((A b c - 3B b )e  + (3A b c  + B b c)d e + (- 4A b c  + 2B b c )d )x
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                    3           4         3  2  2
+--R           (- 5A b c d e + (4A c  - 2B b c )d )x
+--R         + 
+--R                  2 2             3       2 2  2
+--R           (- 5A b c d e + (4A b c  - 2B b c )d )x
+--R      *
+--R                        +-------+
+--R          +-+ +-+      \|e x + d
+--R         \|c \|d atanh(----------)
+--R                           +-+
+--R                          \|d
+--R     + 
+--R               3   2 2
+--R           2B b c e x
+--R         + 
+--R                     3        4  2        2 2       3
+--R               (- A b c + 3B b )e  + (2A b c  - 2B b c)d e
+--R             + 
+--R                        3      2 2  2
+--R               (- 2A b c  + B b c )d
+--R          *
+--R             x
+--R         + 
+--R                2 2 2
+--R           - A b c d
+--R      *
+--R          +-+ +-------+
+--R         \|c \|e x + d
+--R  /
+--R       3 3 2    4 2   +-+
+--R     (b c x  + b c x)\|c
+--R                                                    Type: Expression(Integer)
+--E 780
+
+--S 781 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     2 2       3   2          3      2 2
+--R                 (A b c  - 3B b c)e  + (3A b c  + B b c )d e
+--R               + 
+--R                        4         3  2
+--R                 (- 4A c  + 2B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                3        4  2        2 2      3                 3       2 2  2
+--R           ((A b c - 3B b )e  + (3A b c  + B b c)d e + (- 4A b c  + 2B b c )d )x
+--R        *
+--R                                +-----------+
+--R                                |- b e + c d  +-------+
+--R            +-----------+    2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d       \|     c
+--R            |----------- log(-----------------------------------------------)
+--R           \|     c                              c x + b
+--R       + 
+--R                    3             4         3  2  2
+--R             (5A b c d e + (- 4A c  + 2B b c )d )x
+--R           + 
+--R                  2 2               3       2 2  2
+--R             (5A b c d e + (- 4A b c  + 2B b c )d )x
+--R        *
+--R                       +-+ +-------+
+--R            +-+    - 2\|d \|e x + d  + e x + 2d
+--R           \|d log(----------------------------)
+--R                                 x
+--R       + 
+--R                 3   2 2
+--R             4B b c e x
+--R           + 
+--R                        3        4  2        2 2       3
+--R                 (- 2A b c + 6B b )e  + (4A b c  - 4B b c)d e
+--R               + 
+--R                          3       2 2  2
+--R                 (- 4A b c  + 2B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   2 2 2
+--R             - 2A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         3 3 2     4 2
+--R       2b c x  + 2b c x
+--R     ,
+--R
+--R                    3             4         3  2  2
+--R             (5A b c d e + (- 4A c  + 2B b c )d )x
+--R           + 
+--R                  2 2               3       2 2  2
+--R             (5A b c d e + (- 4A b c  + 2B b c )d )x
+--R        *
+--R                       +-+ +-------+
+--R            +-+    - 2\|d \|e x + d  + e x + 2d
+--R           \|d log(----------------------------)
+--R                                 x
+--R       + 
+--R                      2 2       3   2          3       2 2
+--R                 (2A b c  - 6B b c)e  + (6A b c  + 2B b c )d e
+--R               + 
+--R                        4         3  2
+--R                 (- 8A c  + 4B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      3        4  2        2 2       3
+--R                 (2A b c - 6B b )e  + (6A b c  + 2B b c)d e
+--R               + 
+--R                          3       2 2  2
+--R                 (- 8A b c  + 4B b c )d
+--R            *
+--R               x
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                 3   2 2
+--R             4B b c e x
+--R           + 
+--R                        3        4  2        2 2       3
+--R                 (- 2A b c + 6B b )e  + (4A b c  - 4B b c)d e
+--R               + 
+--R                          3       2 2  2
+--R                 (- 4A b c  + 2B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   2 2 2
+--R             - 2A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         3 3 2     4 2
+--R       2b c x  + 2b c x
+--R     ,
+--R
+--R                     2 2       3   2          3      2 2
+--R                 (A b c  - 3B b c)e  + (3A b c  + B b c )d e
+--R               + 
+--R                        4         3  2
+--R                 (- 4A c  + 2B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                3        4  2        2 2      3                 3       2 2  2
+--R           ((A b c - 3B b )e  + (3A b c  + B b c)d e + (- 4A b c  + 2B b c )d )x
+--R        *
+--R                                +-----------+
+--R                                |- b e + c d  +-------+
+--R            +-----------+    2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d       \|     c
+--R            |----------- log(-----------------------------------------------)
+--R           \|     c                              c x + b
+--R       + 
+--R                       3           4         3  2  2
+--R             (- 10A b c d e + (8A c  - 4B b c )d )x
+--R           + 
+--R                     2 2             3       2 2  2
+--R             (- 10A b c d e + (8A b c  - 4B b c )d )x
+--R        *
+--R                       +-------+
+--R            +---+     \|e x + d
+--R           \|- d atan(----------)
+--R                         +---+
+--R                        \|- d
+--R       + 
+--R                 3   2 2
+--R             4B b c e x
+--R           + 
+--R                        3        4  2        2 2       3
+--R                 (- 2A b c + 6B b )e  + (4A b c  - 4B b c)d e
+--R               + 
+--R                          3       2 2  2
+--R                 (- 4A b c  + 2B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   2 2 2
+--R             - 2A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         3 3 2     4 2
+--R       2b c x  + 2b c x
+--R     ,
+--R
+--R                      3           4         3  2  2
+--R             (- 5A b c d e + (4A c  - 2B b c )d )x
+--R           + 
+--R                    2 2             3       2 2  2
+--R             (- 5A b c d e + (4A b c  - 2B b c )d )x
+--R        *
+--R                       +-------+
+--R            +---+     \|e x + d
+--R           \|- d atan(----------)
+--R                         +---+
+--R                        \|- d
+--R       + 
+--R                     2 2       3   2          3      2 2
+--R                 (A b c  - 3B b c)e  + (3A b c  + B b c )d e
+--R               + 
+--R                        4         3  2
+--R                 (- 4A c  + 2B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                3        4  2        2 2      3                 3       2 2  2
+--R           ((A b c - 3B b )e  + (3A b c  + B b c)d e + (- 4A b c  + 2B b c )d )x
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                 3   2 2
+--R             2B b c e x
+--R           + 
+--R                       3        4  2        2 2       3
+--R                 (- A b c + 3B b )e  + (2A b c  - 2B b c)d e
+--R               + 
+--R                          3      2 2  2
+--R                 (- 2A b c  + B b c )d
+--R            *
+--R               x
+--R           + 
+--R                  2 2 2
+--R             - A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R        3 3 2    4 2
+--R       b c x  + b c x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 781
+
+--S 782 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2        3  2          2      2               3         2  2
+--R         ((A b c - 3B b )e  + (3A b c  + B b c)d e + (- 4A c  + 2B b c )d )
+--R      *
+--R                                  +-----------+
+--R                                  |- b e + c d  +-------+
+--R          +-----------+        2c |----------- \|e x + d  + c e x - b e + 2c d
+--R          |- b e + c d  +-+      \|     c
+--R          |----------- \|c log(-----------------------------------------------)
+--R         \|     c                                  c x + b
+--R     + 
+--R                2             3         2  2  +-+ +-+
+--R         (5A b c d e + (- 4A c  + 2B b c )d )\|c \|d
+--R      *
+--R                 +-+ +-------+
+--R             - 2\|d \|e x + d  + e x + 2d
+--R         log(----------------------------)
+--R                           x
+--R     + 
+--R                 2        3  2            2       2             3         2  2
+--R         ((- 2A b c + 6B b )e  + (- 6A b c  - 2B b c)d e + (8A c  - 4B b c )d )
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                                                           +-------+
+--R               2             3         2  2  +-+ +-+      \|e x + d
+--R       (10A b c d e + (- 8A c  + 4B b c )d )\|c \|d atanh(----------)
+--R                                                              +-+
+--R                                                             \|d
+--R  /
+--R       3 2 +-+
+--R     2b c \|c
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 783
+
+--S 784 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                2             3         2  2  +-+ +-+
+--R         (5A b c d e + (- 4A c  + 2B b c )d )\|c \|d
+--R      *
+--R                 +-+ +-------+
+--R             - 2\|d \|e x + d  + e x + 2d
+--R         log(----------------------------)
+--R                           x
+--R     + 
+--R                 2        3  2            2       2             3         2  2
+--R         ((- 2A b c + 6B b )e  + (- 6A b c  - 2B b c)d e + (8A c  - 4B b c )d )
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                                                           +-------+
+--R               2             3         2  2  +-+ +-+      \|e x + d
+--R       (10A b c d e + (- 8A c  + 4B b c )d )\|c \|d atanh(----------)
+--R                                                              +-+
+--R                                                             \|d
+--R     + 
+--R               2        3  2          2       2               3         2  2
+--R         ((2A b c - 6B b )e  + (6A b c  + 2B b c)d e + (- 8A c  + 4B b c )d )
+--R      *
+--R              +---------+       +-------+
+--R          +-+ |b e - c d       \|e x + d
+--R         \|c  |--------- atan(------------)
+--R             \|    c           +---------+
+--R                               |b e - c d
+--R                               |---------
+--R                              \|    c
+--R  /
+--R       3 2 +-+
+--R     2b c \|c
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 785
+
+)clear all
+
+--S 786 of 1457
+t0:=(A+B*x)*(d+e*x)^(3/2)/(b*x+c*x^2)^2
+--R 
+--R
+--R              2                       +-------+
+--R        (B e x  + (A e + B d)x + A d)\|e x + d
+--R   (1)  ---------------------------------------
+--R                  2 4         3    2 2
+--R                 c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 1457
+r0:=-A*(d+e*x)^(3/2)/(b*x*(b+c*x))-(2*b*B*d-4*A*c*d+3*A*b*e)*_
+     atanh(sqrt(d+e*x)/sqrt(d))*sqrt(d)/b^3-(4*A*c^2*d-b^2*B*e-_
+     b*c*(2*B*d+A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))*_
+     sqrt(c*d-b*e)/(b^3*c^(3/2))+(b*B-2*A*c)*(c*d-b*e)*sqrt(d+e*x)/_
+     (b^2*c*(b+c*x))
+--R 
+--R
+--R   (2)
+--R                  2      2             3         2    2
+--R           ((A b c  + B b c)e + (- 4A c  + 2B b c )d)x
+--R         + 
+--R                2       3              2       2
+--R           ((A b c + B b )e + (- 4A b c  + 2B b c)d)x
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                    2         3         2    2
+--R           (- 3A b c e + (4A c  - 2B b c )d)x
+--R         + 
+--R                  2             2       2
+--R           (- 3A b c e + (4A b c  - 2B b c)d)x
+--R      *
+--R                        +-------+
+--R          +-+ +-+      \|e x + d
+--R         \|c \|d atanh(----------)
+--R                           +-+
+--R                          \|d
+--R     + 
+--R             2       3              2      2           2     +-+ +-------+
+--R       (((A b c - B b )e + (- 2A b c  + B b c)d)x - A b c d)\|c \|e x + d
+--R  /
+--R       3 2 2    4     +-+
+--R     (b c x  + b c x)\|c
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2      2             3         2    2
+--R             ((A b c  + B b c)e + (- 4A c  + 2B b c )d)x
+--R           + 
+--R                  2       3              2       2
+--R             ((A b c + B b )e + (- 4A b c  + 2B b c)d)x
+--R        *
+--R                                +-----------+
+--R                                |- b e + c d  +-------+
+--R            +-----------+    2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d       \|     c
+--R            |----------- log(-----------------------------------------------)
+--R           \|     c                              c x + b
+--R       + 
+--R                    2           3         2    2
+--R             (3A b c e + (- 4A c  + 2B b c )d)x
+--R           + 
+--R                  2               2       2
+--R             (3A b c e + (- 4A b c  + 2B b c)d)x
+--R        *
+--R                       +-+ +-------+
+--R            +-+    - 2\|d \|e x + d  + e x + 2d
+--R           \|d log(----------------------------)
+--R                                 x
+--R       + 
+--R                2        3              2       2            2     +-------+
+--R         (((2A b c - 2B b )e + (- 4A b c  + 2B b c)d)x - 2A b c d)\|e x + d
+--R    /
+--R         3 2 2     4
+--R       2b c x  + 2b c x
+--R     ,
+--R
+--R                    2           3         2    2
+--R             (3A b c e + (- 4A c  + 2B b c )d)x
+--R           + 
+--R                  2               2       2
+--R             (3A b c e + (- 4A b c  + 2B b c)d)x
+--R        *
+--R                       +-+ +-------+
+--R            +-+    - 2\|d \|e x + d  + e x + 2d
+--R           \|d log(----------------------------)
+--R                                 x
+--R       + 
+--R                     2       2             3         2    2
+--R             ((2A b c  + 2B b c)e + (- 8A c  + 4B b c )d)x
+--R           + 
+--R                   2        3              2       2
+--R             ((2A b c + 2B b )e + (- 8A b c  + 4B b c)d)x
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                2        3              2       2            2     +-------+
+--R         (((2A b c - 2B b )e + (- 4A b c  + 2B b c)d)x - 2A b c d)\|e x + d
+--R    /
+--R         3 2 2     4
+--R       2b c x  + 2b c x
+--R     ,
+--R
+--R                    2      2             3         2    2
+--R             ((A b c  + B b c)e + (- 4A c  + 2B b c )d)x
+--R           + 
+--R                  2       3              2       2
+--R             ((A b c + B b )e + (- 4A b c  + 2B b c)d)x
+--R        *
+--R                                +-----------+
+--R                                |- b e + c d  +-------+
+--R            +-----------+    2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d       \|     c
+--R            |----------- log(-----------------------------------------------)
+--R           \|     c                              c x + b
+--R       + 
+--R                      2         3         2    2
+--R             (- 6A b c e + (8A c  - 4B b c )d)x
+--R           + 
+--R                    2             2       2
+--R             (- 6A b c e + (8A b c  - 4B b c)d)x
+--R        *
+--R                       +-------+
+--R            +---+     \|e x + d
+--R           \|- d atan(----------)
+--R                         +---+
+--R                        \|- d
+--R       + 
+--R                2        3              2       2            2     +-------+
+--R         (((2A b c - 2B b )e + (- 4A b c  + 2B b c)d)x - 2A b c d)\|e x + d
+--R    /
+--R         3 2 2     4
+--R       2b c x  + 2b c x
+--R     ,
+--R
+--R                      2         3         2    2
+--R             (- 3A b c e + (4A c  - 2B b c )d)x
+--R           + 
+--R                    2             2       2
+--R             (- 3A b c e + (4A b c  - 2B b c)d)x
+--R        *
+--R                       +-------+
+--R            +---+     \|e x + d
+--R           \|- d atan(----------)
+--R                         +---+
+--R                        \|- d
+--R       + 
+--R                    2      2             3         2    2
+--R             ((A b c  + B b c)e + (- 4A c  + 2B b c )d)x
+--R           + 
+--R                  2       3              2       2
+--R             ((A b c + B b )e + (- 4A b c  + 2B b c)d)x
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R               2       3              2      2           2     +-------+
+--R         (((A b c - B b )e + (- 2A b c  + B b c)d)x - A b c d)\|e x + d
+--R    /
+--R        3 2 2    4
+--R       b c x  + b c x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 788
+
+--S 789 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                 +-----------+
+--R                      2            2             |- b e + c d  +-+
+--R         ((A b c + B b )e + (- 4A c  + 2B b c)d) |----------- \|c
+--R                                                \|     c
+--R      *
+--R                +-----------+
+--R                |- b e + c d  +-------+
+--R             2c |----------- \|e x + d  + c e x - b e + 2c d
+--R               \|     c
+--R         log(-----------------------------------------------)
+--R                                 c x + b
+--R     + 
+--R                                                       +-+ +-------+
+--R                          2             +-+ +-+    - 2\|d \|e x + d  + e x + 2d
+--R       (3A b c e + (- 4A c  + 2B b c)d)\|c \|d log(----------------------------)
+--R                                                                 x
+--R     + 
+--R                          2          2             +-----------+
+--R         ((- 2A b c - 2B b )e + (8A c  - 4B b c)d)\|- b e + c d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                                                      +-------+
+--R                          2             +-+ +-+      \|e x + d
+--R       (6A b c e + (- 8A c  + 4B b c)d)\|c \|d atanh(----------)
+--R                                                         +-+
+--R                                                        \|d
+--R  /
+--R       3  +-+
+--R     2b c\|c
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 790
+
+--S 791 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                       +-+ +-------+
+--R                          2             +-+ +-+    - 2\|d \|e x + d  + e x + 2d
+--R       (3A b c e + (- 4A c  + 2B b c)d)\|c \|d log(----------------------------)
+--R                                                                 x
+--R     + 
+--R                          2          2             +-----------+
+--R         ((- 2A b c - 2B b )e + (8A c  - 4B b c)d)\|- b e + c d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                                                      +-------+
+--R                          2             +-+ +-+      \|e x + d
+--R       (6A b c e + (- 8A c  + 4B b c)d)\|c \|d atanh(----------)
+--R                                                         +-+
+--R                                                        \|d
+--R     + 
+--R                                                   +---------+       +-------+
+--R                    2            2             +-+ |b e - c d       \|e x + d
+--R     ((2A b c + 2B b )e + (- 8A c  + 4B b c)d)\|c  |--------- atan(------------)
+--R                                                  \|    c           +---------+
+--R                                                                    |b e - c d
+--R                                                                    |---------
+--R                                                                   \|    c
+--R  /
+--R       3  +-+
+--R     2b c\|c
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 792
+
+)clear all
+
+--S 793 of 1457
+t0:=(A+B*x)*sqrt(d+e*x)/(b*x+c*x^2)^2
+--R 
+--R
+--R                   +-------+
+--R         (B x + A)\|e x + d
+--R   (1)  ---------------------
+--R         2 4         3    2 2
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 793
+
+--S 794 of 1457
+r0:=-(2*b*B*d-4*A*c*d+A*b*e)*atanh(sqrt(d+e*x)/sqrt(d))/(b^3*sqrt(d))+_
+     (2*b*B*c*d-4*A*c^2*d-b^2*B*e+3*A*b*c*e)*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))/(b^3*sqrt(c)*sqrt(c*d-b*e))+(b*B-2*A*c)*sqrt(d+e*x)/_
+     (b^2*(b+c*x))-A*sqrt(d+e*x)/(b*x*(b+c*x))
+--R 
+--R
+--R   (2)
+--R                   2      2             3         2    2
+--R           ((3A b c  - B b c)e + (- 4A c  + 2B b c )d)x
+--R         + 
+--R                 2       3              2       2
+--R           ((3A b c - B b )e + (- 4A b c  + 2B b c)d)x
+--R      *
+--R                    +-+ +-------+
+--R          +-+      \|c \|e x + d
+--R         \|d atanh(--------------)
+--R                    +-----------+
+--R                   \|- b e + c d
+--R     + 
+--R                            2             2         2                  2
+--R         ((- A b c e + (4A c  - 2B b c)d)x  + (- A b e + (4A b c - 2B b )d)x)
+--R      *
+--R                                  +-------+
+--R          +-----------+ +-+      \|e x + d
+--R         \|- b e + c d \|c atanh(----------)
+--R                                     +-+
+--R                                    \|d
+--R     + 
+--R                       2        2  +-----------+ +-+ +-+ +-------+
+--R       ((- 2A b c + B b )x - A b )\|- b e + c d \|c \|d \|e x + d
+--R  /
+--R       3   2    4   +-----------+ +-+ +-+
+--R     (b c x  + b x)\|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                              2             2       2                    2
+--R           ((A b c e + (- 4A c  + 2B b c)d)x  + (A b e + (- 4A b c + 2B b )d)x)
+--R        *
+--R            +-------------+         +-------+              +-+
+--R            |           2      - 2d\|e x + d  + (e x + 2d)\|d
+--R           \|- b c e + c d log(-------------------------------)
+--R                                              x
+--R       + 
+--R                     2      2             3         2    2
+--R             ((3A b c  - B b c)e + (- 4A c  + 2B b c )d)x
+--R           + 
+--R                   2       3              2       2
+--R             ((3A b c - B b )e + (- 4A b c  + 2B b c)d)x
+--R        *
+--R            +-+
+--R           \|d
+--R        *
+--R                                                                +-------------+
+--R                           2   +-------+                        |           2
+--R             (- 2b c e + 2c d)\|e x + d  + (c e x - b e + 2c d)\|- b c e + c d
+--R         log(------------------------------------------------------------------)
+--R                                           c x + b
+--R       + 
+--R                                       +-------------+
+--R                          2         2  |           2   +-+ +-------+
+--R         ((- 4A b c + 2B b )x - 2A b )\|- b c e + c d \|d \|e x + d
+--R    /
+--R                        +-------------+
+--R          3   2     4   |           2   +-+
+--R       (2b c x  + 2b x)\|- b c e + c d \|d
+--R     ,
+--R
+--R                              2             2       2                    2
+--R           ((A b c e + (- 4A c  + 2B b c)d)x  + (A b e + (- 4A b c + 2B b )d)x)
+--R        *
+--R            +-----------+         +-------+              +-+
+--R            |         2      - 2d\|e x + d  + (e x + 2d)\|d
+--R           \|b c e - c d log(-------------------------------)
+--R                                            x
+--R       + 
+--R                       2       2           3         2    2
+--R             ((- 6A b c  + 2B b c)e + (8A c  - 4B b c )d)x
+--R           + 
+--R                     2        3            2       2
+--R             ((- 6A b c + 2B b )e + (8A b c  - 4B b c)d)x
+--R        *
+--R                     +-----------+
+--R                     |         2   +-------+
+--R            +-+     \|b c e - c d \|e x + d
+--R           \|d atan(------------------------)
+--R                            b e - c d
+--R       + 
+--R                                           +-----------+
+--R                          2         2  +-+ |         2   +-------+
+--R         ((- 4A b c + 2B b )x - 2A b )\|d \|b c e - c d \|e x + d
+--R    /
+--R                            +-----------+
+--R          3   2     4   +-+ |         2
+--R       (2b c x  + 2b x)\|d \|b c e - c d
+--R     ,
+--R
+--R                     2      2             3         2    2
+--R             ((3A b c  - B b c)e + (- 4A c  + 2B b c )d)x
+--R           + 
+--R                   2       3              2       2
+--R             ((3A b c - B b )e + (- 4A b c  + 2B b c)d)x
+--R        *
+--R            +---+
+--R           \|- d
+--R        *
+--R                                                                +-------------+
+--R                           2   +-------+                        |           2
+--R             (- 2b c e + 2c d)\|e x + d  + (c e x - b e + 2c d)\|- b c e + c d
+--R         log(------------------------------------------------------------------)
+--R                                           c x + b
+--R       + 
+--R                                  2             2
+--R               (- 2A b c e + (8A c  - 4B b c)d)x
+--R             + 
+--R                      2                  2
+--R               (- 2A b e + (8A b c - 4B b )d)x
+--R        *
+--R            +-------------+      +---+ +-------+
+--R            |           2       \|- d \|e x + d
+--R           \|- b c e + c d atan(----------------)
+--R                                        d
+--R       + 
+--R                                       +-------------+
+--R                          2         2  |           2   +---+ +-------+
+--R         ((- 4A b c + 2B b )x - 2A b )\|- b c e + c d \|- d \|e x + d
+--R    /
+--R                        +-------------+
+--R          3   2     4   |           2   +---+
+--R       (2b c x  + 2b x)\|- b c e + c d \|- d
+--R     ,
+--R
+--R                       2      2           3         2    2
+--R             ((- 3A b c  + B b c)e + (4A c  - 2B b c )d)x
+--R           + 
+--R                     2       3            2       2
+--R             ((- 3A b c + B b )e + (4A b c  - 2B b c)d)x
+--R        *
+--R                       +-----------+
+--R                       |         2   +-------+
+--R            +---+     \|b c e - c d \|e x + d
+--R           \|- d atan(------------------------)
+--R                              b e - c d
+--R       + 
+--R                              2             2         2                  2
+--R           ((- A b c e + (4A c  - 2B b c)d)x  + (- A b e + (4A b c - 2B b )d)x)
+--R        *
+--R            +-----------+      +---+ +-------+
+--R            |         2       \|- d \|e x + d
+--R           \|b c e - c d atan(----------------)
+--R                                      d
+--R       + 
+--R                                           +-----------+
+--R                         2        2  +---+ |         2   +-------+
+--R         ((- 2A b c + B b )x - A b )\|- d \|b c e - c d \|e x + d
+--R    /
+--R                            +-----------+
+--R         3   2    4   +---+ |         2
+--R       (b c x  + b x)\|- d \|b c e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 795
+
+--S 796 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                    +-------------+
+--R                                    |           2   +-----------+ +-+
+--R         (A b e + (- 4A c + 2B b)d)\|- b c e + c d \|- b e + c d \|c
+--R      *
+--R                  +-------+              +-+
+--R             - 2d\|e x + d  + (e x + 2d)\|d
+--R         log(-------------------------------)
+--R                            x
+--R     + 
+--R                       2            2             +-----------+ +-+ +-+
+--R         ((3A b c - B b )e + (- 4A c  + 2B b c)d)\|- b e + c d \|c \|d
+--R      *
+--R                                                              +-------------+
+--R                         2   +-------+                        |           2
+--R           (- 2b c e + 2c d)\|e x + d  + (c e x - b e + 2c d)\|- b c e + c d
+--R       log(------------------------------------------------------------------)
+--R                                         c x + b
+--R     + 
+--R                                                   +-------------+
+--R                          2          2             |           2   +-+
+--R         ((- 6A b c + 2B b )e + (8A c  - 4B b c)d)\|- b c e + c d \|d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                                     +-------------+
+--R                                     |           2   +-----------+ +-+
+--R         (2A b e + (- 8A c + 4B b)d)\|- b c e + c d \|- b e + c d \|c
+--R      *
+--R                +-------+
+--R               \|e x + d
+--R         atanh(----------)
+--R                   +-+
+--R                  \|d
+--R  /
+--R         +-------------+
+--R       3 |           2   +-----------+ +-+ +-+
+--R     2b \|- b c e + c d \|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 797
+
+--S 798 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                      +-----------+
+--R                                    +-----------+ +-+ |         2
+--R         (A b e + (- 4A c + 2B b)d)\|- b e + c d \|c \|b c e - c d
+--R      *
+--R                  +-------+              +-+
+--R             - 2d\|e x + d  + (e x + 2d)\|d
+--R         log(-------------------------------)
+--R                            x
+--R     + 
+--R                                                       +-----------+
+--R                          2          2             +-+ |         2
+--R         ((- 6A b c + 2B b )e + (8A c  - 4B b c)d)\|d \|b c e - c d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                                                       +-----------+
+--R                                     +-----------+ +-+ |         2
+--R         (2A b e + (- 8A c + 4B b)d)\|- b e + c d \|c \|b c e - c d
+--R      *
+--R                +-------+
+--R               \|e x + d
+--R         atanh(----------)
+--R                   +-+
+--R                  \|d
+--R     + 
+--R                          2          2             +-----------+ +-+ +-+
+--R         ((- 6A b c + 2B b )e + (8A c  - 4B b c)d)\|- b e + c d \|c \|d
+--R      *
+--R               +-----------+
+--R               |         2   +-------+
+--R              \|b c e - c d \|e x + d
+--R         atan(------------------------)
+--R                      b e - c d
+--R  /
+--R                               +-----------+
+--R       3 +-----------+ +-+ +-+ |         2
+--R     2b \|- b e + c d \|c \|d \|b c e - c d
+--R                                                    Type: Expression(Integer)
+--E 798
+
+--S 799 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 799
+
+)clear all
+
+--S 800 of 1457
+t0:=(A+B*x)/((b*x+c*x^2)^2*sqrt(d+e*x))
+--R 
+--R
+--R                     B x + A
+--R   (1)  ---------------------------------
+--R          2 4         3    2 2  +-------+
+--R        (c x  + 2b c x  + b x )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 800
+
+--S 801 of 1457
+r0:=-(2*b*B*d-4*A*c*d-A*b*e)*atanh(sqrt(d+e*x)/sqrt(d))/(b^3*d^(3/2))+_
+     (2*b*B*c*d-4*A*c^2*d-3*b^2*B*e+5*A*b*c*e)*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))*sqrt(c)/(b^3*(c*d-b*e)^(3/2))+c*(b*B*d-2*A*c*d+A*b*e)*_
+     sqrt(d+e*x)/(b^2*d*(c*d-b*e)*(b+c*x))-A*sqrt(d+e*x)/(b*d*x*(b+c*x))
+--R 
+--R
+--R   (2)
+--R                     2       2             3         2  2  2
+--R           ((- 5A b c  + 3B b c)d e + (4A c  - 2B b c )d )x
+--R         + 
+--R                   2        3              2       2   2
+--R           ((- 5A b c + 3B b )d e + (4A b c  - 2B b c)d )x
+--R      *
+--R                        +-+ +-------+
+--R          +-+ +-+      \|c \|e x + d
+--R         \|c \|d atanh(--------------)
+--R                        +-----------+
+--R                       \|- b e + c d
+--R     + 
+--R               2   2          2       2               3         2  2  2
+--R           (A b c e  + (3A b c  - 2B b c)d e + (- 4A c  + 2B b c )d )x
+--R         + 
+--R               3 2        2        3                2       2   2
+--R           (A b e  + (3A b c - 2B b )d e + (- 4A b c  + 2B b c)d )x
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R     + 
+--R                2             2      2           3       2     +-----------+ +-+
+--R         ((- A b c e + (2A b c  - B b c)d)x - A b e + A b c d)\|- b e + c d \|d
+--R      *
+--R          +-------+
+--R         \|e x + d
+--R  /
+--R        4         3 2 2  2     5       4   2    +-----------+ +-+
+--R     ((b c d e - b c d )x  + (b d e - b c d )x)\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 801
+
+--S 802 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     2       2               3         2  2  2
+--R             ((5A b c  - 3B b c)d e + (- 4A c  + 2B b c )d )x
+--R           + 
+--R                   2        3                2       2   2
+--R             ((5A b c - 3B b )d e + (- 4A b c  + 2B b c)d )x
+--R        *
+--R            +-----------+
+--R            |      c      +-+
+--R            |- --------- \|d
+--R           \|  b e - c d
+--R        *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R               (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R           log(----------------------------------------------------------)
+--R                                         c x + b
+--R       + 
+--R                 2   2          2       2               3         2  2  2
+--R             (A b c e  + (3A b c  - 2B b c)d e + (- 4A c  + 2B b c )d )x
+--R           + 
+--R                 3 2        2        3                2       2   2
+--R             (A b e  + (3A b c - 2B b )d e + (- 4A b c  + 2B b c)d )x
+--R        *
+--R                  +-------+              +-+
+--R               2d\|e x + d  + (e x + 2d)\|d
+--R           log(-----------------------------)
+--R                             x
+--R       + 
+--R               2             2       2            3        2     +-+ +-------+
+--R       ((- 2A b c e + (4A b c  - 2B b c)d)x - 2A b e + 2A b c d)\|d \|e x + d
+--R    /
+--R           4          3 2 2  2      5        4   2    +-+
+--R       ((2b c d e - 2b c d )x  + (2b d e - 2b c d )x)\|d
+--R     ,
+--R
+--R                 2   2          2       2               3         2  2  2
+--R             (A b c e  + (3A b c  - 2B b c)d e + (- 4A c  + 2B b c )d )x
+--R           + 
+--R                 3 2        2        3                2       2   2
+--R             (A b e  + (3A b c - 2B b )d e + (- 4A b c  + 2B b c)d )x
+--R        *
+--R                  +-------+              +-+
+--R               2d\|e x + d  + (e x + 2d)\|d
+--R           log(-----------------------------)
+--R                             x
+--R       + 
+--R                      2       2               3         2  2  2
+--R             ((10A b c  - 6B b c)d e + (- 8A c  + 4B b c )d )x
+--R           + 
+--R                    2        3                2       2   2
+--R             ((10A b c - 6B b )d e + (- 8A b c  + 4B b c)d )x
+--R        *
+--R            +---------+                 +-------+
+--R            |    c      +-+           c\|e x + d
+--R            |--------- \|d atan(-----------------------)
+--R           \|b e - c d                      +---------+
+--R                                            |    c
+--R                                (b e - c d) |---------
+--R                                           \|b e - c d
+--R       + 
+--R               2             2       2            3        2     +-+ +-------+
+--R       ((- 2A b c e + (4A b c  - 2B b c)d)x - 2A b e + 2A b c d)\|d \|e x + d
+--R    /
+--R           4          3 2 2  2      5        4   2    +-+
+--R       ((2b c d e - 2b c d )x  + (2b d e - 2b c d )x)\|d
+--R     ,
+--R
+--R                     2       2               3         2  2  2
+--R             ((5A b c  - 3B b c)d e + (- 4A c  + 2B b c )d )x
+--R           + 
+--R                   2        3                2       2   2
+--R             ((5A b c - 3B b )d e + (- 4A b c  + 2B b c)d )x
+--R        *
+--R                  +-----------+
+--R            +---+ |      c
+--R           \|- d  |- ---------
+--R                 \|  b e - c d
+--R        *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R               (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R           log(----------------------------------------------------------)
+--R                                         c x + b
+--R       + 
+--R                  2   2          2       2               3         2  2  2
+--R             (2A b c e  + (6A b c  - 4B b c)d e + (- 8A c  + 4B b c )d )x
+--R           + 
+--R                  3 2        2        3                2       2   2
+--R             (2A b e  + (6A b c - 4B b )d e + (- 8A b c  + 4B b c)d )x
+--R        *
+--R                 +---+ +-------+
+--R                \|- d \|e x + d
+--R           atan(----------------)
+--R                        d
+--R       + 
+--R               2             2       2            3        2     +---+ +-------+
+--R       ((- 2A b c e + (4A b c  - 2B b c)d)x - 2A b e + 2A b c d)\|- d \|e x + d
+--R    /
+--R           4          3 2 2  2      5        4   2    +---+
+--R       ((2b c d e - 2b c d )x  + (2b d e - 2b c d )x)\|- d
+--R     ,
+--R
+--R                 2   2          2       2               3         2  2  2
+--R             (A b c e  + (3A b c  - 2B b c)d e + (- 4A c  + 2B b c )d )x
+--R           + 
+--R                 3 2        2        3                2       2   2
+--R             (A b e  + (3A b c - 2B b )d e + (- 4A b c  + 2B b c)d )x
+--R        *
+--R                 +---+ +-------+
+--R                \|- d \|e x + d
+--R           atan(----------------)
+--R                        d
+--R       + 
+--R                     2       2               3         2  2  2
+--R             ((5A b c  - 3B b c)d e + (- 4A c  + 2B b c )d )x
+--R           + 
+--R                   2        3                2       2   2
+--R             ((5A b c - 3B b )d e + (- 4A b c  + 2B b c)d )x
+--R        *
+--R                  +---------+             +-------+
+--R            +---+ |    c                c\|e x + d
+--R           \|- d  |--------- atan(-----------------------)
+--R                 \|b e - c d                  +---------+
+--R                                              |    c
+--R                                  (b e - c d) |---------
+--R                                             \|b e - c d
+--R       + 
+--R                2             2      2           3       2     +---+ +-------+
+--R         ((- A b c e + (2A b c  - B b c)d)x - A b e + A b c d)\|- d \|e x + d
+--R    /
+--R          4         3 2 2  2     5       4   2    +---+
+--R       ((b c d e - b c d )x  + (b d e - b c d )x)\|- d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 802
+
+--S 803 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        2              2           2  +-----------+
+--R         ((5A b c - 3B b )d e + (- 4A c  + 2B b c)d )\|- b e + c d
+--R      *
+--R          +-----------+
+--R          |      c      +-+
+--R          |- --------- \|d
+--R         \|  b e - c d
+--R      *
+--R                           +-----------+
+--R                           |      c      +-------+
+--R             (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                          \|  b e - c d
+--R         log(----------------------------------------------------------)
+--R                                       c x + b
+--R     + 
+--R             2 2                 2              2           2  +-----------+
+--R         (A b e  + (3A b c - 2B b )d e + (- 4A c  + 2B b c)d )\|- b e + c d
+--R      *
+--R                +-------+              +-+
+--R             2d\|e x + d  + (e x + 2d)\|d
+--R         log(-----------------------------)
+--R                           x
+--R     + 
+--R                         2              2           2  +-+ +-+
+--R         ((10A b c - 6B b )d e + (- 8A c  + 4B b c)d )\|c \|d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                2 2                   2            2           2  +-----------+
+--R         (- 2A b e  + (- 6A b c + 4B b )d e + (8A c  - 4B b c)d )\|- b e + c d
+--R      *
+--R                +-------+
+--R               \|e x + d
+--R         atanh(----------)
+--R                   +-+
+--R                  \|d
+--R  /
+--R        4        3   2  +-----------+ +-+
+--R     (2b d e - 2b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 803
+
+--S 804 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             2 2                 2              2           2  +-----------+
+--R         (A b e  + (3A b c - 2B b )d e + (- 4A c  + 2B b c)d )\|- b e + c d
+--R      *
+--R                +-------+              +-+
+--R             2d\|e x + d  + (e x + 2d)\|d
+--R         log(-----------------------------)
+--R                           x
+--R     + 
+--R                         2              2           2  +-+ +-+
+--R         ((10A b c - 6B b )d e + (- 8A c  + 4B b c)d )\|c \|d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                2 2                   2            2           2  +-----------+
+--R         (- 2A b e  + (- 6A b c + 4B b )d e + (8A c  - 4B b c)d )\|- b e + c d
+--R      *
+--R                +-------+
+--R               \|e x + d
+--R         atanh(----------)
+--R                   +-+
+--R                  \|d
+--R     + 
+--R                                                                     +---------+
+--R                         2              2           2  +-----------+ |    c
+--R         ((10A b c - 6B b )d e + (- 8A c  + 4B b c)d )\|- b e + c d  |---------
+--R                                                                    \|b e - c d
+--R      *
+--R                          +-------+
+--R          +-+           c\|e x + d
+--R         \|d atan(-----------------------)
+--R                              +---------+
+--R                              |    c
+--R                  (b e - c d) |---------
+--R                             \|b e - c d
+--R  /
+--R        4        3   2  +-----------+ +-+
+--R     (2b d e - 2b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 805
+
+--S 806 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 806
+
+)clear all
+
+--S 807 of 1457
+t0:=(A+B*x)/((d+e*x)^(3/2)*(b*x+c*x^2)^2)
+--R 
+--R
+--R                                     B x + A
+--R   (1)  -----------------------------------------------------------------
+--R          2   5              2   4     2            3    2   2  +-------+
+--R        (c e x  + (2b c e + c d)x  + (b e + 2b c d)x  + b d x )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 1457
+r0:=-(2*b*B*d-4*A*c*d-3*A*b*e)*atanh(sqrt(d+e*x)/sqrt(d))/(b^3*d^(5/2))-_
+     c^(3/2)*(4*A*c^2*d+5*b^2*B*e-b*c*(2*B*d+7*A*e))*atanh(sqrt(c)*_
+     sqrt(d+e*x)/sqrt(c*d-b*e))/(b^3*(c*d-b*e)^(5/2))-e*(2*A*c^2*d^2-_
+     b^2*e*(2*B*d-3*A*e)-b*c*d*(B*d+2*A*e))/(b^2*d^2*(c*d-b*e)^2*_
+     sqrt(d+e*x))+c*(b*B*d-2*A*c*d+A*b*e)/(b^2*d*(c*d-b*e)*(b+c*x)*_
+     sqrt(d+e*x))-A/(b*d*x*(b+c*x)*sqrt(d+e*x))
+--R 
+--R
+--R   (2)
+--R                   3       2 2  2           4         3  3  2
+--R           ((7A b c  - 5B b c )d e + (- 4A c  + 2B b c )d )x
+--R         + 
+--R                 2 2       3   2             3       2 2  3
+--R           ((7A b c  - 5B b c)d e + (- 4A b c  + 2B b c )d )x
+--R      *
+--R                                  +-+ +-------+
+--R          +-+ +-+ +-------+      \|c \|e x + d
+--R         \|c \|d \|e x + d atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- b e + c d
+--R     + 
+--R                   3   3          2 2       3     2            3       2 2  2
+--R               3A b c e  + (- 2A b c  - 2B b c)d e  + (- 5A b c  + 4B b c )d e
+--R             + 
+--R                    4         3  3
+--R               (4A c  - 2B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   4 3          3        4    2          2 2       3   2
+--R               3A b e  + (- 2A b c - 2B b )d e  + (- 5A b c  + 4B b c)d e
+--R             + 
+--R                      3       2 2  3
+--R               (4A b c  - 2B b c )d
+--R          *
+--R             x
+--R      *
+--R                                        +-------+
+--R          +-----------+ +-------+      \|e x + d
+--R         \|- b e + c d \|e x + d atanh(----------)
+--R                                           +-+
+--R                                          \|d
+--R     + 
+--R                  3   3        2 2       3     2            3      2 2  2   2
+--R           (- 3A b c e  + (2A b c  + 2B b c)d e  + (- 2A b c  + B b c )d e)x
+--R         + 
+--R                     4 3       3        4    2      2 2 2
+--R               - 3A b e  + (A b c + 2B b )d e  + A b c d e
+--R             + 
+--R                        3      2 2  3
+--R               (- 2A b c  + B b c )d
+--R          *
+--R             x
+--R         + 
+--R                4   2       3   2       2 2 3
+--R           - A b d e  + 2A b c d e - A b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R          5   2 2     4 2 3     3 3 4  2     6 2 2     5   3     4 2 4
+--R       ((b c d e  - 2b c d e + b c d )x  + (b d e  - 2b c d e + b c d )x)
+--R    *
+--R        +-----------+ +-+ +-------+
+--R       \|- b e + c d \|d \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 808
+
+--S 809 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     3   3          2 2       3     2            3       2 2  2
+--R                 3A b c e  + (- 2A b c  - 2B b c)d e  + (- 5A b c  + 4B b c )d e
+--R               + 
+--R                      4         3  3
+--R                 (4A c  - 2B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4 3          3        4    2          2 2       3   2
+--R                 3A b e  + (- 2A b c - 2B b )d e  + (- 5A b c  + 4B b c)d e
+--R               + 
+--R                        3       2 2  3
+--R                 (4A b c  - 2B b c )d
+--R            *
+--R               x
+--R        *
+--R                            +-------+              +-+
+--R            +-------+    2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-----------------------------)
+--R                                       x
+--R       + 
+--R                     3       2 2  2           4         3  3  2
+--R             ((7A b c  - 5B b c )d e + (- 4A c  + 2B b c )d )x
+--R           + 
+--R                   2 2       3   2             3       2 2  3
+--R             ((7A b c  - 5B b c)d e + (- 4A b c  + 2B b c )d )x
+--R        *
+--R            +-----------+
+--R            |      c      +-+ +-------+
+--R            |- --------- \|d \|e x + d
+--R           \|  b e - c d
+--R        *
+--R                               +-----------+
+--R                               |      c      +-------+
+--R               (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                              \|  b e - c d
+--R           log(------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                    3   3        2 2       3     2            3       2 2  2   2
+--R             (- 6A b c e  + (4A b c  + 4B b c)d e  + (- 4A b c  + 2B b c )d e)x
+--R           + 
+--R                       4 3        3        4    2       2 2 2
+--R                 - 6A b e  + (2A b c + 4B b )d e  + 2A b c d e
+--R               + 
+--R                          3       2 2  3
+--R                 (- 4A b c  + 2B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   4   2       3   2        2 2 3
+--R             - 2A b d e  + 4A b c d e - 2A b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R             5   2 2     4 2 3      3 3 4  2      6 2 2     5   3      4 2 4
+--R         ((2b c d e  - 4b c d e + 2b c d )x  + (2b d e  - 4b c d e + 2b c d )x)
+--R      *
+--R          +-+ +-------+
+--R         \|d \|e x + d
+--R     ,
+--R
+--R                     3   3          2 2       3     2            3       2 2  2
+--R                 3A b c e  + (- 2A b c  - 2B b c)d e  + (- 5A b c  + 4B b c )d e
+--R               + 
+--R                      4         3  3
+--R                 (4A c  - 2B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4 3          3        4    2          2 2       3   2
+--R                 3A b e  + (- 2A b c - 2B b )d e  + (- 5A b c  + 4B b c)d e
+--R               + 
+--R                        3       2 2  3
+--R                 (4A b c  - 2B b c )d
+--R            *
+--R               x
+--R        *
+--R                            +-------+              +-+
+--R            +-------+    2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-----------------------------)
+--R                                       x
+--R       + 
+--R                        3        2 2  2         4         3  3  2
+--R             ((- 14A b c  + 10B b c )d e + (8A c  - 4B b c )d )x
+--R           + 
+--R                      2 2        3   2           3       2 2  3
+--R             ((- 14A b c  + 10B b c)d e + (8A b c  - 4B b c )d )x
+--R        *
+--R            +---------+                           +-------+
+--R            |    c      +-+ +-------+           c\|e x + d
+--R            |--------- \|d \|e x + d atan(-----------------------)
+--R           \|b e - c d                                +---------+
+--R                                                      |    c
+--R                                          (b e - c d) |---------
+--R                                                     \|b e - c d
+--R       + 
+--R                    3   3        2 2       3     2            3       2 2  2   2
+--R             (- 6A b c e  + (4A b c  + 4B b c)d e  + (- 4A b c  + 2B b c )d e)x
+--R           + 
+--R                       4 3        3        4    2       2 2 2
+--R                 - 6A b e  + (2A b c + 4B b )d e  + 2A b c d e
+--R               + 
+--R                          3       2 2  3
+--R                 (- 4A b c  + 2B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   4   2       3   2        2 2 3
+--R             - 2A b d e  + 4A b c d e - 2A b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R             5   2 2     4 2 3      3 3 4  2      6 2 2     5   3      4 2 4
+--R         ((2b c d e  - 4b c d e + 2b c d )x  + (2b d e  - 4b c d e + 2b c d )x)
+--R      *
+--R          +-+ +-------+
+--R         \|d \|e x + d
+--R     ,
+--R
+--R                     3       2 2  2           4         3  3  2
+--R             ((7A b c  - 5B b c )d e + (- 4A c  + 2B b c )d )x
+--R           + 
+--R                   2 2       3   2             3       2 2  3
+--R             ((7A b c  - 5B b c)d e + (- 4A b c  + 2B b c )d )x
+--R        *
+--R                  +-----------+
+--R            +---+ |      c      +-------+
+--R           \|- d  |- --------- \|e x + d
+--R                 \|  b e - c d
+--R        *
+--R                               +-----------+
+--R                               |      c      +-------+
+--R               (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                              \|  b e - c d
+--R           log(------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                     3   3          2 2       3     2
+--R                 6A b c e  + (- 4A b c  - 4B b c)d e
+--R               + 
+--R                           3       2 2  2         4         3  3
+--R                 (- 10A b c  + 8B b c )d e + (8A c  - 4B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4 3          3        4    2           2 2       3   2
+--R                 6A b e  + (- 4A b c - 4B b )d e  + (- 10A b c  + 8B b c)d e
+--R               + 
+--R                        3       2 2  3
+--R                 (8A b c  - 4B b c )d
+--R            *
+--R               x
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                    3   3        2 2       3     2            3       2 2  2   2
+--R             (- 6A b c e  + (4A b c  + 4B b c)d e  + (- 4A b c  + 2B b c )d e)x
+--R           + 
+--R                       4 3        3        4    2       2 2 2
+--R                 - 6A b e  + (2A b c + 4B b )d e  + 2A b c d e
+--R               + 
+--R                          3       2 2  3
+--R                 (- 4A b c  + 2B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   4   2       3   2        2 2 3
+--R             - 2A b d e  + 4A b c d e - 2A b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R             5   2 2     4 2 3      3 3 4  2      6 2 2     5   3      4 2 4
+--R         ((2b c d e  - 4b c d e + 2b c d )x  + (2b d e  - 4b c d e + 2b c d )x)
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ,
+--R
+--R                     3   3          2 2       3     2            3       2 2  2
+--R                 3A b c e  + (- 2A b c  - 2B b c)d e  + (- 5A b c  + 4B b c )d e
+--R               + 
+--R                      4         3  3
+--R                 (4A c  - 2B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4 3          3        4    2          2 2       3   2
+--R                 3A b e  + (- 2A b c - 2B b )d e  + (- 5A b c  + 4B b c)d e
+--R               + 
+--R                        3       2 2  3
+--R                 (4A b c  - 2B b c )d
+--R            *
+--R               x
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                       3       2 2  2         4         3  3  2
+--R             ((- 7A b c  + 5B b c )d e + (4A c  - 2B b c )d )x
+--R           + 
+--R                     2 2       3   2           3       2 2  3
+--R             ((- 7A b c  + 5B b c)d e + (4A b c  - 2B b c )d )x
+--R        *
+--R                  +---------+                       +-------+
+--R            +---+ |    c      +-------+           c\|e x + d
+--R           \|- d  |--------- \|e x + d atan(-----------------------)
+--R                 \|b e - c d                            +---------+
+--R                                                        |    c
+--R                                            (b e - c d) |---------
+--R                                                       \|b e - c d
+--R       + 
+--R                    3   3        2 2       3     2            3      2 2  2   2
+--R             (- 3A b c e  + (2A b c  + 2B b c)d e  + (- 2A b c  + B b c )d e)x
+--R           + 
+--R                       4 3       3        4    2      2 2 2
+--R                 - 3A b e  + (A b c + 2B b )d e  + A b c d e
+--R               + 
+--R                          3      2 2  3
+--R                 (- 2A b c  + B b c )d
+--R            *
+--R               x
+--R           + 
+--R                  4   2       3   2       2 2 3
+--R             - A b d e  + 2A b c d e - A b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R            5   2 2     4 2 3     3 3 4  2     6 2 2     5   3     4 2 4
+--R         ((b c d e  - 2b c d e + b c d )x  + (b d e  - 2b c d e + b c d )x)
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 809
+
+--S 810 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               3 3          2        3    2            2       2   2
+--R           3A b e  + (- 2A b c - 2B b )d e  + (- 5A b c  + 4B b c)d e
+--R         + 
+--R                3         2  3
+--R           (4A c  - 2B b c )d
+--R      *
+--R                              +-------+              +-+
+--R          +-----------+    2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-----------------------------)
+--R                                         x
+--R     + 
+--R                 2       2   2           3         2  3  +-----------+
+--R         ((7A b c  - 5B b c)d e + (- 4A c  + 2B b c )d )\|- b e + c d
+--R      *
+--R          +-----------+
+--R          |      c      +-+
+--R          |- --------- \|d
+--R         \|  b e - c d
+--R      *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R             (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R         log(------------------------------------------------------------)
+--R                                        c x + b
+--R     + 
+--R                    2        2   2         3         2  3  +-+ +-+
+--R         ((- 14A b c  + 10B b c)d e + (8A c  - 4B b c )d )\|c \|d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                 3 3        2        3    2           2       2   2
+--R           - 6A b e  + (4A b c + 4B b )d e  + (10A b c  - 8B b c)d e
+--R         + 
+--R                  3         2  3
+--R           (- 8A c  + 4B b c )d
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R  /
+--R        5 2 2     4   3      3 2 4  +-----------+ +-+
+--R     (2b d e  - 4b c d e + 2b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 810
+
+--S 811 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               3 3          2        3    2            2       2   2
+--R           3A b e  + (- 2A b c - 2B b )d e  + (- 5A b c  + 4B b c)d e
+--R         + 
+--R                3         2  3
+--R           (4A c  - 2B b c )d
+--R      *
+--R                              +-------+              +-+
+--R          +-----------+    2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-----------------------------)
+--R                                         x
+--R     + 
+--R                    2        2   2         3         2  3  +-+ +-+
+--R         ((- 14A b c  + 10B b c)d e + (8A c  - 4B b c )d )\|c \|d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                 3 3        2        3    2           2       2   2
+--R           - 6A b e  + (4A b c + 4B b )d e  + (10A b c  - 8B b c)d e
+--R         + 
+--R                  3         2  3
+--R           (- 8A c  + 4B b c )d
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R     + 
+--R                    2        2   2         3         2  3  +-----------+
+--R         ((- 14A b c  + 10B b c)d e + (8A c  - 4B b c )d )\|- b e + c d
+--R      *
+--R          +---------+                 +-------+
+--R          |    c      +-+           c\|e x + d
+--R          |--------- \|d atan(-----------------------)
+--R         \|b e - c d                      +---------+
+--R                                          |    c
+--R                              (b e - c d) |---------
+--R                                         \|b e - c d
+--R  /
+--R        5 2 2     4   3      3 2 4  +-----------+ +-+
+--R     (2b d e  - 4b c d e + 2b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 813
+
+)clear all
+
+--S 814 of 1457
+t0:=(A+B*x)/((d+e*x)^(5/2)*(b*x+c*x^2)^2)
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R          2 2 6          2     2     5     2 2               2 2  4
+--R         c e x  + (2b c e  + 2c d e)x  + (b e  + 4b c d e + c d )x
+--R       + 
+--R            2            2  3    2 2 2
+--R         (2b d e + 2b c d )x  + b d x
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 1457
+r0:=-1/3*e*(6*A*c^2*d^2-b^2*e*(2*B*d-5*A*e)-3*b*c*d*(B*d+2*A*e))/_
+     (b^2*d^2*(c*d-b*e)^2*(d+e*x)^(3/2))+c*(b*B*d-2*A*c*d+A*b*e)/_
+     (b^2*d*(c*d-b*e)*(b+c*x)*(d+e*x)^(3/2))-A/(b*d*x*(b+c*x)*_
+     (d+e*x)^(3/2))-(2*b*B*d-4*A*c*d-5*A*b*e)*atanh(sqrt(d+e*x)/sqrt(d))/_
+     (b^3*d^(7/2))+c^(5/2)*(2*b*B*c*d-4*A*c^2*d-7*b^2*B*e+9*A*b*c*e)*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^3*(c*d-b*e)^(7/2))-_
+     e*(2*A*c^3*d^3-b^2*c*d*e*(6*B*d-11*A*e)+b^3*e^2*(2*B*d-5*A*e)-_
+     b*c^2*d^2*(B*d+3*A*e))/(b^2*d^3*(c*d-b*e)^3*sqrt(d+e*x))
+--R 
+--R
+--R   (2)
+--R                      4        2 3  3 2         5         4  4   3
+--R           ((- 27A b c  + 21B b c )d e  + (12A c  - 6B b c )d e)x
+--R         + 
+--R                       2 3        3 2  3 2             4        2 3  4
+--R               (- 27A b c  + 21B b c )d e  + (- 15A b c  + 15B b c )d e
+--R             + 
+--R                     5         4  5
+--R               (12A c  - 6B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    2 3        3 2  4            4       2 3  5
+--R           ((- 27A b c  + 21B b c )d e + (12A b c  - 6B b c )d )x
+--R      *
+--R                                  +-+ +-------+
+--R          +-+ +-+ +-------+      \|c \|e x + d
+--R         \|c \|d \|e x + d atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- b e + c d
+--R     + 
+--R                    4   5           3 2       4     4        2 3        3 2  2 3
+--R               15A b c e  + (- 33A b c  - 6B b c)d e  + (9A b c  + 18B b c )d e
+--R             + 
+--R                       4        2 3  3 2           5         4  4
+--R               (21A b c  - 18B b c )d e  + (- 12A c  + 6B b c )d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    5 5           4        5    4           3 2        4   2 3
+--R               15A b e  + (- 18A b c - 6B b )d e  + (- 24A b c  + 12B b c)d e
+--R             + 
+--R                    2 3 3 2          4        2 3  4            5         4  5
+--R               30A b c d e  + (9A b c  - 12B b c )d e + (- 12A c  + 6B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    5   4           4        5  2 3        3 2        4   3 2
+--R               15A b d e  + (- 33A b c - 6B b )d e  + (9A b c  + 18B b c)d e
+--R             + 
+--R                     2 3        3 2  4              4       2 3  5
+--R               (21A b c  - 18B b c )d e + (- 12A b c  + 6B b c )d
+--R          *
+--R             x
+--R      *
+--R                                        +-------+
+--R          +-----------+ +-------+      \|e x + d
+--R         \|- b e + c d \|e x + d atanh(----------)
+--R                                           +-+
+--R                                          \|d
+--R     + 
+--R                      4   5         3 2       4     4
+--R               - 15A b c e  + (33A b c  + 6B b c)d e
+--R             + 
+--R                      2 3        3 2  2 3          4       2 3  3 2
+--R               (- 9A b c  - 18B b c )d e  + (6A b c  - 3B b c )d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      5 5         4        5    4         3 2        4   2 3
+--R               - 15A b e  + (13A b c + 6B b )d e  + (35A b c  - 10B b c)d e
+--R             + 
+--R                       2 3        3 2  3 2           4       2 3  4
+--R               (- 15A b c  - 20B b c )d e  + (12A b c  - 6B b c )d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      5   4         4        5  2 3          3 2        4   3 2
+--R               - 20A b d e  + (41A b c + 8B b )d e  + (- 9A b c  - 20B b c)d e
+--R             + 
+--R                     2 3 4           4       2 3  5
+--R               - 3A b c d e + (6A b c  - 3B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 5 2 3       4   3 2       3 2 4        2 3 5
+--R           - 3A b d e  + 9A b c d e  - 9A b c d e + 3A b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R            6   3 4     5 2 4 3     4 3 5 2     3 4 6   3
+--R         (3b c d e  - 9b c d e  + 9b c d e  - 3b c d e)x
+--R       + 
+--R            7 3 4     6   4 3     4 3 6      3 4 7  2
+--R         (3b d e  - 6b c d e  + 6b c d e - 3b c d )x
+--R       + 
+--R            7 4 3     6   5 2     5 2 6      4 3 7
+--R         (3b d e  - 9b c d e  + 9b c d e - 3b c d )x
+--R    *
+--R        +-----------+ +-+ +-------+
+--R       \|- b e + c d \|d \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 815
+
+--S 816 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      4        2 3  3 2           5         4  4   3
+--R             ((27A b c  - 21B b c )d e  + (- 12A c  + 6B b c )d e)x
+--R           + 
+--R                       2 3        3 2  3 2           4        2 3  4
+--R                 (27A b c  - 21B b c )d e  + (15A b c  - 15B b c )d e
+--R               + 
+--R                         5         4  5
+--R                 (- 12A c  + 6B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    2 3        3 2  4              4       2 3  5
+--R             ((27A b c  - 21B b c )d e + (- 12A b c  + 6B b c )d )x
+--R        *
+--R            +-----------+
+--R            |      c      +-+ +-------+
+--R            |- --------- \|d \|e x + d
+--R           \|  b e - c d
+--R        *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R               (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R           log(----------------------------------------------------------)
+--R                                         c x + b
+--R       + 
+--R                      4   5           3 2       4     4
+--R                 15A b c e  + (- 33A b c  - 6B b c)d e
+--R               + 
+--R                      2 3        3 2  2 3           4        2 3  3 2
+--R                 (9A b c  + 18B b c )d e  + (21A b c  - 18B b c )d e
+--R               + 
+--R                         5         4  4
+--R                 (- 12A c  + 6B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      5 5           4        5    4           3 2        4   2 3
+--R                 15A b e  + (- 18A b c - 6B b )d e  + (- 24A b c  + 12B b c)d e
+--R               + 
+--R                    2 3 3 2          4        2 3  4            5         4  5
+--R               30A b c d e  + (9A b c  - 12B b c )d e + (- 12A c  + 6B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      5   4           4        5  2 3        3 2        4   3 2
+--R                 15A b d e  + (- 33A b c - 6B b )d e  + (9A b c  + 18B b c)d e
+--R               + 
+--R                       2 3        3 2  4              4       2 3  5
+--R                 (21A b c  - 18B b c )d e + (- 12A b c  + 6B b c )d
+--R            *
+--R               x
+--R        *
+--R                            +-------+              +-+
+--R            +-------+    2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-----------------------------)
+--R                                       x
+--R       + 
+--R                        4   5         3 2        4     4
+--R                 - 30A b c e  + (66A b c  + 12B b c)d e
+--R               + 
+--R                         2 3        3 2  2 3           4       2 3  3 2
+--R                 (- 18A b c  - 36B b c )d e  + (12A b c  - 6B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        5 5         4         5    4         3 2        4   2 3
+--R                 - 30A b e  + (26A b c + 12B b )d e  + (70A b c  - 20B b c)d e
+--R               + 
+--R                         2 3        3 2  3 2           4        2 3  4
+--R                 (- 30A b c  - 40B b c )d e  + (24A b c  - 12B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        5   4         4         5  2 3
+--R                 - 40A b d e  + (82A b c + 16B b )d e
+--R               + 
+--R                       3 2        4   3 2       2 3 4            4       2 3  5
+--R               (- 18A b c  - 40B b c)d e  - 6A b c d e + (12A b c  - 6B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   5 2 3        4   3 2        3 2 4        2 3 5
+--R             - 6A b d e  + 18A b c d e  - 18A b c d e + 6A b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R              6   3 4      5 2 4 3      4 3 5 2     3 4 6   3
+--R           (6b c d e  - 18b c d e  + 18b c d e  - 6b c d e)x
+--R         + 
+--R              7 3 4      6   4 3      4 3 6      3 4 7  2
+--R           (6b d e  - 12b c d e  + 12b c d e - 6b c d )x
+--R         + 
+--R              7 4 3      6   5 2      5 2 6      4 3 7
+--R           (6b d e  - 18b c d e  + 18b c d e - 6b c d )x
+--R      *
+--R          +-+ +-------+
+--R         \|d \|e x + d
+--R     ,
+--R
+--R                      4   5           3 2       4     4
+--R                 15A b c e  + (- 33A b c  - 6B b c)d e
+--R               + 
+--R                      2 3        3 2  2 3           4        2 3  3 2
+--R                 (9A b c  + 18B b c )d e  + (21A b c  - 18B b c )d e
+--R               + 
+--R                         5         4  4
+--R                 (- 12A c  + 6B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      5 5           4        5    4           3 2        4   2 3
+--R                 15A b e  + (- 18A b c - 6B b )d e  + (- 24A b c  + 12B b c)d e
+--R               + 
+--R                    2 3 3 2          4        2 3  4            5         4  5
+--R               30A b c d e  + (9A b c  - 12B b c )d e + (- 12A c  + 6B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      5   4           4        5  2 3        3 2        4   3 2
+--R                 15A b d e  + (- 33A b c - 6B b )d e  + (9A b c  + 18B b c)d e
+--R               + 
+--R                       2 3        3 2  4              4       2 3  5
+--R                 (21A b c  - 18B b c )d e + (- 12A b c  + 6B b c )d
+--R            *
+--R               x
+--R        *
+--R                            +-------+              +-+
+--R            +-------+    2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-----------------------------)
+--R                                       x
+--R       + 
+--R                      4        2 3  3 2           5          4  4   3
+--R             ((54A b c  - 42B b c )d e  + (- 24A c  + 12B b c )d e)x
+--R           + 
+--R                       2 3        3 2  3 2           4        2 3  4
+--R                 (54A b c  - 42B b c )d e  + (30A b c  - 30B b c )d e
+--R               + 
+--R                         5          4  5
+--R                 (- 24A c  + 12B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    2 3        3 2  4              4        2 3  5
+--R             ((54A b c  - 42B b c )d e + (- 24A b c  + 12B b c )d )x
+--R        *
+--R            +---------+                           +-------+
+--R            |    c      +-+ +-------+           c\|e x + d
+--R            |--------- \|d \|e x + d atan(-----------------------)
+--R           \|b e - c d                                +---------+
+--R                                                      |    c
+--R                                          (b e - c d) |---------
+--R                                                     \|b e - c d
+--R       + 
+--R                        4   5         3 2        4     4
+--R                 - 30A b c e  + (66A b c  + 12B b c)d e
+--R               + 
+--R                         2 3        3 2  2 3           4       2 3  3 2
+--R                 (- 18A b c  - 36B b c )d e  + (12A b c  - 6B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        5 5         4         5    4         3 2        4   2 3
+--R                 - 30A b e  + (26A b c + 12B b )d e  + (70A b c  - 20B b c)d e
+--R               + 
+--R                         2 3        3 2  3 2           4        2 3  4
+--R                 (- 30A b c  - 40B b c )d e  + (24A b c  - 12B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        5   4         4         5  2 3
+--R                 - 40A b d e  + (82A b c + 16B b )d e
+--R               + 
+--R                       3 2        4   3 2       2 3 4            4       2 3  5
+--R               (- 18A b c  - 40B b c)d e  - 6A b c d e + (12A b c  - 6B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   5 2 3        4   3 2        3 2 4        2 3 5
+--R             - 6A b d e  + 18A b c d e  - 18A b c d e + 6A b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R              6   3 4      5 2 4 3      4 3 5 2     3 4 6   3
+--R           (6b c d e  - 18b c d e  + 18b c d e  - 6b c d e)x
+--R         + 
+--R              7 3 4      6   4 3      4 3 6      3 4 7  2
+--R           (6b d e  - 12b c d e  + 12b c d e - 6b c d )x
+--R         + 
+--R              7 4 3      6   5 2      5 2 6      4 3 7
+--R           (6b d e  - 18b c d e  + 18b c d e - 6b c d )x
+--R      *
+--R          +-+ +-------+
+--R         \|d \|e x + d
+--R     ,
+--R
+--R                      4        2 3  3 2           5         4  4   3
+--R             ((27A b c  - 21B b c )d e  + (- 12A c  + 6B b c )d e)x
+--R           + 
+--R                       2 3        3 2  3 2           4        2 3  4
+--R                 (27A b c  - 21B b c )d e  + (15A b c  - 15B b c )d e
+--R               + 
+--R                         5         4  5
+--R                 (- 12A c  + 6B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    2 3        3 2  4              4       2 3  5
+--R             ((27A b c  - 21B b c )d e + (- 12A b c  + 6B b c )d )x
+--R        *
+--R                  +-----------+
+--R            +---+ |      c      +-------+
+--R           \|- d  |- --------- \|e x + d
+--R                 \|  b e - c d
+--R        *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R               (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R           log(----------------------------------------------------------)
+--R                                         c x + b
+--R       + 
+--R                      4   5           3 2        4     4
+--R                 30A b c e  + (- 66A b c  - 12B b c)d e
+--R               + 
+--R                       2 3        3 2  2 3           4        2 3  3 2
+--R                 (18A b c  + 36B b c )d e  + (42A b c  - 36B b c )d e
+--R               + 
+--R                         5          4  4
+--R                 (- 24A c  + 12B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      5 5           4         5    4
+--R                 30A b e  + (- 36A b c - 12B b )d e
+--R               + 
+--R                         3 2        4   2 3        2 3 3 2
+--R                 (- 48A b c  + 24B b c)d e  + 60A b c d e
+--R               + 
+--R                         4        2 3  4            5          4  5
+--R                 (18A b c  - 24B b c )d e + (- 24A c  + 12B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      5   4           4         5  2 3
+--R                 30A b d e  + (- 66A b c - 12B b )d e
+--R               + 
+--R                       3 2        4   3 2         2 3        3 2  4
+--R                 (18A b c  + 36B b c)d e  + (42A b c  - 36B b c )d e
+--R               + 
+--R                           4        2 3  5
+--R                 (- 24A b c  + 12B b c )d
+--R            *
+--R               x
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                        4   5         3 2        4     4
+--R                 - 30A b c e  + (66A b c  + 12B b c)d e
+--R               + 
+--R                         2 3        3 2  2 3           4       2 3  3 2
+--R                 (- 18A b c  - 36B b c )d e  + (12A b c  - 6B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        5 5         4         5    4         3 2        4   2 3
+--R                 - 30A b e  + (26A b c + 12B b )d e  + (70A b c  - 20B b c)d e
+--R               + 
+--R                         2 3        3 2  3 2           4        2 3  4
+--R                 (- 30A b c  - 40B b c )d e  + (24A b c  - 12B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        5   4         4         5  2 3
+--R                 - 40A b d e  + (82A b c + 16B b )d e
+--R               + 
+--R                       3 2        4   3 2       2 3 4            4       2 3  5
+--R               (- 18A b c  - 40B b c)d e  - 6A b c d e + (12A b c  - 6B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   5 2 3        4   3 2        3 2 4        2 3 5
+--R             - 6A b d e  + 18A b c d e  - 18A b c d e + 6A b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R              6   3 4      5 2 4 3      4 3 5 2     3 4 6   3
+--R           (6b c d e  - 18b c d e  + 18b c d e  - 6b c d e)x
+--R         + 
+--R              7 3 4      6   4 3      4 3 6      3 4 7  2
+--R           (6b d e  - 12b c d e  + 12b c d e - 6b c d )x
+--R         + 
+--R              7 4 3      6   5 2      5 2 6      4 3 7
+--R           (6b d e  - 18b c d e  + 18b c d e - 6b c d )x
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ,
+--R
+--R                      4   5           3 2       4     4
+--R                 15A b c e  + (- 33A b c  - 6B b c)d e
+--R               + 
+--R                      2 3        3 2  2 3           4        2 3  3 2
+--R                 (9A b c  + 18B b c )d e  + (21A b c  - 18B b c )d e
+--R               + 
+--R                         5         4  4
+--R                 (- 12A c  + 6B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      5 5           4        5    4           3 2        4   2 3
+--R                 15A b e  + (- 18A b c - 6B b )d e  + (- 24A b c  + 12B b c)d e
+--R               + 
+--R                    2 3 3 2          4        2 3  4            5         4  5
+--R               30A b c d e  + (9A b c  - 12B b c )d e + (- 12A c  + 6B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                      5   4           4        5  2 3        3 2        4   3 2
+--R                 15A b d e  + (- 33A b c - 6B b )d e  + (9A b c  + 18B b c)d e
+--R               + 
+--R                       2 3        3 2  4              4       2 3  5
+--R                 (21A b c  - 18B b c )d e + (- 12A b c  + 6B b c )d
+--R            *
+--R               x
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                      4        2 3  3 2           5         4  4   3
+--R             ((27A b c  - 21B b c )d e  + (- 12A c  + 6B b c )d e)x
+--R           + 
+--R                       2 3        3 2  3 2           4        2 3  4
+--R                 (27A b c  - 21B b c )d e  + (15A b c  - 15B b c )d e
+--R               + 
+--R                         5         4  5
+--R                 (- 12A c  + 6B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    2 3        3 2  4              4       2 3  5
+--R             ((27A b c  - 21B b c )d e + (- 12A b c  + 6B b c )d )x
+--R        *
+--R                  +---------+                       +-------+
+--R            +---+ |    c      +-------+           c\|e x + d
+--R           \|- d  |--------- \|e x + d atan(-----------------------)
+--R                 \|b e - c d                            +---------+
+--R                                                        |    c
+--R                                            (b e - c d) |---------
+--R                                                       \|b e - c d
+--R       + 
+--R                        4   5         3 2       4     4
+--R                 - 15A b c e  + (33A b c  + 6B b c)d e
+--R               + 
+--R                        2 3        3 2  2 3          4       2 3  3 2
+--R                 (- 9A b c  - 18B b c )d e  + (6A b c  - 3B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        5 5         4        5    4         3 2        4   2 3
+--R                 - 15A b e  + (13A b c + 6B b )d e  + (35A b c  - 10B b c)d e
+--R               + 
+--R                         2 3        3 2  3 2           4       2 3  4
+--R                 (- 15A b c  - 20B b c )d e  + (12A b c  - 6B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        5   4         4        5  2 3
+--R                 - 20A b d e  + (41A b c + 8B b )d e
+--R               + 
+--R                        3 2        4   3 2       2 3 4           4       2 3  5
+--R                 (- 9A b c  - 20B b c)d e  - 3A b c d e + (6A b c  - 3B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   5 2 3       4   3 2       3 2 4        2 3 5
+--R             - 3A b d e  + 9A b c d e  - 9A b c d e + 3A b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R              6   3 4     5 2 4 3     4 3 5 2     3 4 6   3
+--R           (3b c d e  - 9b c d e  + 9b c d e  - 3b c d e)x
+--R         + 
+--R              7 3 4     6   4 3     4 3 6      3 4 7  2
+--R           (3b d e  - 6b c d e  + 6b c d e - 3b c d )x
+--R         + 
+--R              7 4 3     6   5 2     5 2 6      4 3 7
+--R           (3b d e  - 9b c d e  + 9b c d e - 3b c d )x
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 816
+
+--S 817 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 3       2 2  3           4         3  4  +-----------+
+--R         ((9A b c  - 7B b c )d e + (- 4A c  + 2B b c )d )\|- b e + c d
+--R      *
+--R          +-----------+
+--R          |      c      +-+
+--R          |- --------- \|d
+--R         \|  b e - c d
+--R      *
+--R                           +-----------+
+--R                           |      c      +-------+
+--R             (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                          \|  b e - c d
+--R         log(----------------------------------------------------------)
+--R                                       c x + b
+--R     + 
+--R               4 4           3        4    3        2 2       3   2 2
+--R           5A b e  + (- 11A b c - 2B b )d e  + (3A b c  + 6B b c)d e
+--R         + 
+--R                  3       2 2  3           4         3  4
+--R           (7A b c  - 6B b c )d e + (- 4A c  + 2B b c )d
+--R      *
+--R                              +-------+              +-+
+--R          +-----------+    2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-----------------------------)
+--R                                         x
+--R     + 
+--R                  3        2 2  3           4         3  4  +-+ +-+
+--R         ((18A b c  - 14B b c )d e + (- 8A c  + 4B b c )d )\|c \|d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                  4 4         3        4    3          2 2        3   2 2
+--R           - 10A b e  + (22A b c + 4B b )d e  + (- 6A b c  - 12B b c)d e
+--R         + 
+--R                     3        2 2  3         4         3  4
+--R           (- 14A b c  + 12B b c )d e + (8A c  - 4B b c )d
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R  /
+--R        6 3 3     5   4 2     4 2 5      3 3 6  +-----------+ +-+
+--R     (2b d e  - 6b c d e  + 6b c d e - 2b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 818
+
+--S 819 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               4 4           3        4    3        2 2       3   2 2
+--R           5A b e  + (- 11A b c - 2B b )d e  + (3A b c  + 6B b c)d e
+--R         + 
+--R                  3       2 2  3           4         3  4
+--R           (7A b c  - 6B b c )d e + (- 4A c  + 2B b c )d
+--R      *
+--R                              +-------+              +-+
+--R          +-----------+    2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-----------------------------)
+--R                                         x
+--R     + 
+--R                  3        2 2  3           4         3  4  +-+ +-+
+--R         ((18A b c  - 14B b c )d e + (- 8A c  + 4B b c )d )\|c \|d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                  4 4         3        4    3          2 2        3   2 2
+--R           - 10A b e  + (22A b c + 4B b )d e  + (- 6A b c  - 12B b c)d e
+--R         + 
+--R                     3        2 2  3         4         3  4
+--R           (- 14A b c  + 12B b c )d e + (8A c  - 4B b c )d
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R     + 
+--R                  3        2 2  3           4         3  4  +-----------+
+--R         ((18A b c  - 14B b c )d e + (- 8A c  + 4B b c )d )\|- b e + c d
+--R      *
+--R          +---------+                 +-------+
+--R          |    c      +-+           c\|e x + d
+--R          |--------- \|d atan(-----------------------)
+--R         \|b e - c d                      +---------+
+--R                                          |    c
+--R                              (b e - c d) |---------
+--R                                         \|b e - c d
+--R  /
+--R        6 3 3     5   4 2     4 2 5      3 3 6  +-----------+ +-+
+--R     (2b d e  - 6b c d e  + 6b c d e - 2b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 820
+
+)clear all
+
+--S 821 of 1457
+t0:=(A+B*x)/((d+e*x)^(7/2)*(b*x+c*x^2)^2)
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R          2 3 7          3     2   2  6     2 3           2     2 2   5
+--R         c e x  + (2b c e  + 3c d e )x  + (b e  + 6b c d e  + 3c d e)x
+--R       + 
+--R            2   2         2     2 3  4      2 2          3  3    2 3 2
+--R         (3b d e  + 6b c d e + c d )x  + (3b d e + 2b c d )x  + b d x
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 1457
+r0:=-1/5*e*(10*A*c^2*d^2-b^2*e*(2*B*d-7*A*e)-5*b*c*d*(B*d+2*A*e))/_
+     (b^2*d^2*(c*d-b*e)^2*(d+e*x)^(5/2))+c*(b*B*d-2*A*c*d+A*b*e)/_
+     (b^2*d*(c*d-b*e)*(b+c*x)*(d+e*x)^(5/2))-A/(b*d*x*(b+c*x)*_
+     (d+e*x)^(5/2))-1/3*e*(6*A*c^3*d^3-b^2*c*d*e*(6*B*d-17*A*e)+_
+     b^3*e^2*(2*B*d-7*A*e)-3*b*c^2*d^2*(B*d+3*A*e))/(b^2*d^3*_
+     (c*d-b*e)^3*(d+e*x)^(3/2))-(2*b*B*d-4*A*c*d-7*A*b*e)*_
+     atanh(sqrt(d+e*x)/sqrt(d))/(b^3*d^(9/2))-c^(7/2)*(4*A*c^2*d+9*b^2*B*e-_
+     b*c*(2*B*d+11*A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/_
+     (b^3*(c*d-b*e)^(9/2))-e*(2*A*c^4*d^4-2*b^2*c^2*d^2*e*(6*B*d-13*A*e)-_
+     b^4*e^3*(2*B*d-7*A*e)+8*b^3*c*d*e^2*(B*d-3*A*e)-b*c^3*d^3*_
+     (B*d+4*A*e))/(b^2*d^4*(c*d-b*e)^4*sqrt(d+e*x))
+--R 
+--R
+--R   (2)
+--R                     5         2 4  4 3           6          5  5 2  4
+--R           ((165A b c  - 135B b c )d e  + (- 60A c  + 30B b c )d e )x
+--R         + 
+--R                      2 4         3 3  4 3            5         2 4  5 2
+--R               (165A b c  - 135B b c )d e  + (270A b c  - 240B b c )d e
+--R             + 
+--R                        6          5  6
+--R               (- 120A c  + 60B b c )d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      2 4         3 3  5 2           5        2 4  6
+--R               (330A b c  - 270B b c )d e  + (45A b c  - 75B b c )d e
+--R             + 
+--R                       6          5  7
+--R               (- 60A c  + 30B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   2 4         3 3  6              5        2 4  7
+--R           ((165A b c  - 135B b c )d e + (- 60A b c  + 30B b c )d )x
+--R      *
+--R                                  +-+ +-------+
+--R          +-+ +-+ +-------+      \|c \|e x + d
+--R         \|c \|d \|e x + d atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- b e + c d
+--R     + 
+--R                     5   7            4 2        5     6
+--R               105A b c e  + (- 360A b c  - 30B b c)d e
+--R             + 
+--R                      3 3         4 2  2 5           2 4         3 3  3 4
+--R               (390A b c  + 120B b c )d e  + (- 60A b c  - 180B b c )d e
+--R             + 
+--R                          5         2 4  4 3         6          5  5 2
+--R               (- 135A b c  + 120B b c )d e  + (60A c  - 30B b c )d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     6 7            5         6    6
+--R               105A b e  + (- 150A b c - 30B b )d e
+--R             + 
+--R                        4 2        5   2 5          3 3        4 2  3 4
+--R               (- 330A b c  + 60B b c)d e  + (720A b c  + 60B b c )d e
+--R             + 
+--R                        2 4         3 3  4 3              5         2 4  5 2
+--R               (- 255A b c  - 240B b c )d e  + (- 210A b c  + 210B b c )d e
+--R             + 
+--R                      6          5  6
+--R               (120A c  - 60B b c )d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     6   6            5         6  2 5
+--R               210A b d e  + (- 615A b c - 60B b )d e
+--R             + 
+--R                      4 2         5   3 4          3 3         4 2  4 3
+--R               (420A b c  + 210B b c)d e  + (270A b c  - 240B b c )d e
+--R             + 
+--R                        2 4        3 3  5 2             5        2 4  6
+--R               (- 330A b c  + 60B b c )d e  + (- 15A b c  + 60B b c )d e
+--R             + 
+--R                     6          5  7
+--R               (60A c  - 30B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     6 2 5            5         6  3 4
+--R               105A b d e  + (- 360A b c - 30B b )d e
+--R             + 
+--R                      4 2         5   4 3           3 3         4 2  5 2
+--R               (390A b c  + 120B b c)d e  + (- 60A b c  - 180B b c )d e
+--R             + 
+--R                        2 4         3 3  6            5        2 4  7
+--R               (- 135A b c  + 120B b c )d e + (60A b c  - 30B b c )d
+--R          *
+--R             x
+--R      *
+--R                                        +-------+
+--R          +-----------+ +-------+      \|e x + d
+--R         \|- b e + c d \|e x + d atanh(----------)
+--R                                           +-+
+--R                                          \|d
+--R     + 
+--R                       5   7          4 2        5     6
+--R               - 105A b c e  + (360A b c  + 30B b c)d e
+--R             + 
+--R                        3 3         4 2  2 5         2 4         3 3  3 4
+--R               (- 390A b c  - 120B b c )d e  + (60A b c  + 180B b c )d e
+--R             + 
+--R                         5        2 4  4 3
+--R               (- 30A b c  + 15B b c )d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       6 7          5         6    6          4 2        5   2 5
+--R               - 105A b e  + (115A b c + 30B b )d e  + (450A b c  - 50B b c)d e
+--R             + 
+--R                        3 3         4 2  3 4          2 4         3 3  4 3
+--R               (- 850A b c  - 100B b c )d e  + (165A b c  + 390B b c )d e
+--R             + 
+--R                         5        2 4  5 2
+--R               (- 90A b c  + 45B b c )d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       6   6          5         6  2 5
+--R               - 245A b d e  + (679A b c + 70B b )d e
+--R             + 
+--R                        4 2         5   3 4            3 3         4 2  4 3
+--R               (- 358A b c  - 234B b c)d e  + (- 436A b c  + 218B b c )d e
+--R             + 
+--R                      2 4         3 3  5 2             5        2 4  6
+--R               (135A b c  + 216B b c )d e  + (- 90A b c  + 45B b c )d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       6 2 5          5         6  3 4
+--R               - 161A b d e  + (537A b c + 46B b )d e
+--R             + 
+--R                        4 2         5   4 3         3 3         4 2  5 2
+--R               (- 556A b c  - 172B b c)d e  + (90A b c  + 216B b c )d e
+--R             + 
+--R                    2 4 6              5        2 4  7
+--R               15A b c d e + (- 30A b c  + 15B b c )d
+--R          *
+--R             x
+--R         + 
+--R                6 3 4        5   4 3        4 2 5 2        3 3 6         2 4 7
+--R         - 15A b d e  + 60A b c d e  - 90A b c d e  + 60A b c d e - 15A b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R             7   4 6      6 2 5 5      5 3 6 4      4 4 7 3      3 5 8 2  4
+--R         (15b c d e  - 60b c d e  + 90b c d e  - 60b c d e  + 15b c d e )x
+--R       + 
+--R                8 4 6      7   5 5      6 2 6 4       5 3 7 3       4 4 8 2
+--R             15b d e  - 30b c d e  - 30b c d e  + 120b c d e  - 105b c d e
+--R           + 
+--R                3 5 9
+--R             30b c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                8 5 5       7   6 4       6 2 7 3      5 3 8 2      4 4 9
+--R             30b d e  - 105b c d e  + 120b c d e  - 30b c d e  - 30b c d e
+--R           + 
+--R                3 5 10
+--R             15b c d
+--R        *
+--R            2
+--R           x
+--R       + 
+--R             8 6 4      7   7 3      6 2 8 2      5 3 9       4 4 10
+--R         (15b d e  - 60b c d e  + 90b c d e  - 60b c d e + 15b c d  )x
+--R    *
+--R        +-----------+ +-+ +-------+
+--R       \|- b e + c d \|d \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 822
+
+--S 823 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       5   7            4 2        5     6
+--R                 105A b c e  + (- 360A b c  - 30B b c)d e
+--R               + 
+--R                        3 3         4 2  2 5           2 4         3 3  3 4
+--R                 (390A b c  + 120B b c )d e  + (- 60A b c  - 180B b c )d e
+--R               + 
+--R                            5         2 4  4 3         6          5  5 2
+--R                 (- 135A b c  + 120B b c )d e  + (60A c  - 30B b c )d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       6 7            5         6    6
+--R                 105A b e  + (- 150A b c - 30B b )d e
+--R               + 
+--R                          4 2        5   2 5          3 3        4 2  3 4
+--R                 (- 330A b c  + 60B b c)d e  + (720A b c  + 60B b c )d e
+--R               + 
+--R                          2 4         3 3  4 3              5         2 4  5 2
+--R                 (- 255A b c  - 240B b c )d e  + (- 210A b c  + 210B b c )d e
+--R               + 
+--R                        6          5  6
+--R                 (120A c  - 60B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       6   6            5         6  2 5
+--R                 210A b d e  + (- 615A b c - 60B b )d e
+--R               + 
+--R                        4 2         5   3 4          3 3         4 2  4 3
+--R                 (420A b c  + 210B b c)d e  + (270A b c  - 240B b c )d e
+--R               + 
+--R                          2 4        3 3  5 2             5        2 4  6
+--R                 (- 330A b c  + 60B b c )d e  + (- 15A b c  + 60B b c )d e
+--R               + 
+--R                       6          5  7
+--R                 (60A c  - 30B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       6 2 5            5         6  3 4
+--R                 105A b d e  + (- 360A b c - 30B b )d e
+--R               + 
+--R                        4 2         5   4 3           3 3         4 2  5 2
+--R                 (390A b c  + 120B b c)d e  + (- 60A b c  - 180B b c )d e
+--R               + 
+--R                          2 4         3 3  6            5        2 4  7
+--R                 (- 135A b c  + 120B b c )d e + (60A b c  - 30B b c )d
+--R            *
+--R               x
+--R        *
+--R                            +-------+              +-+
+--R            +-------+    2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-----------------------------)
+--R                                       x
+--R       + 
+--R                       5         2 4  4 3           6          5  5 2  4
+--R             ((165A b c  - 135B b c )d e  + (- 60A c  + 30B b c )d e )x
+--R           + 
+--R                        2 4         3 3  4 3            5         2 4  5 2
+--R                 (165A b c  - 135B b c )d e  + (270A b c  - 240B b c )d e
+--R               + 
+--R                          6          5  6
+--R                 (- 120A c  + 60B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2 4         3 3  5 2           5        2 4  6
+--R                 (330A b c  - 270B b c )d e  + (45A b c  - 75B b c )d e
+--R               + 
+--R                         6          5  7
+--R                 (- 60A c  + 30B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     2 4         3 3  6              5        2 4  7
+--R             ((165A b c  - 135B b c )d e + (- 60A b c  + 30B b c )d )x
+--R        *
+--R            +-----------+
+--R            |      c      +-+ +-------+
+--R            |- --------- \|d \|e x + d
+--R           \|  b e - c d
+--R        *
+--R                               +-----------+
+--R                               |      c      +-------+
+--R               (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                              \|  b e - c d
+--R           log(------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                         5   7          4 2        5     6
+--R                 - 210A b c e  + (720A b c  + 60B b c)d e
+--R               + 
+--R                          3 3         4 2  2 5          2 4         3 3  3 4
+--R                 (- 780A b c  - 240B b c )d e  + (120A b c  + 360B b c )d e
+--R               + 
+--R                           5        2 4  4 3
+--R                 (- 60A b c  + 30B b c )d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         6 7          5         6    6
+--R                 - 210A b e  + (230A b c + 60B b )d e
+--R               + 
+--R                        4 2         5   2 5             3 3         4 2  3 4
+--R                 (900A b c  - 100B b c)d e  + (- 1700A b c  - 200B b c )d e
+--R               + 
+--R                        2 4         3 3  4 3              5        2 4  5 2
+--R                 (330A b c  + 780B b c )d e  + (- 180A b c  + 90B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         6   6           5          6  2 5
+--R                 - 490A b d e  + (1358A b c + 140B b )d e
+--R               + 
+--R                          4 2         5   3 4            3 3         4 2  4 3
+--R                 (- 716A b c  - 468B b c)d e  + (- 872A b c  + 436B b c )d e
+--R               + 
+--R                        2 4         3 3  5 2              5        2 4  6
+--R                 (270A b c  + 432B b c )d e  + (- 180A b c  + 90B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         6 2 5           5         6  3 4
+--R                 - 322A b d e  + (1074A b c + 92B b )d e
+--R               + 
+--R                           4 2         5   4 3          3 3         4 2  5 2
+--R                 (- 1112A b c  - 344B b c)d e  + (180A b c  + 432B b c )d e
+--R               + 
+--R                      2 4 6              5        2 4  7
+--R                 30A b c d e + (- 60A b c  + 30B b c )d
+--R            *
+--R               x
+--R           + 
+--R                    6 3 4         5   4 3         4 2 5 2         3 3 6
+--R             - 30A b d e  + 120A b c d e  - 180A b c d e  + 120A b c d e
+--R           + 
+--R                    2 4 7
+--R             - 30A b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R               7   4 6       6 2 5 5       5 3 6 4       4 4 7 3      3 5 8 2  4
+--R           (30b c d e  - 120b c d e  + 180b c d e  - 120b c d e  + 30b c d e )x
+--R         + 
+--R                  8 4 6      7   5 5      6 2 6 4       5 3 7 3       4 4 8 2
+--R               30b d e  - 60b c d e  - 60b c d e  + 240b c d e  - 210b c d e
+--R             + 
+--R                  3 5 9
+--R               60b c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  8 5 5       7   6 4       6 2 7 3      5 3 8 2      4 4 9
+--R               60b d e  - 210b c d e  + 240b c d e  - 60b c d e  - 60b c d e
+--R             + 
+--R                  3 5 10
+--R               30b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R               8 6 4       7   7 3       6 2 8 2       5 3 9       4 4 10
+--R           (30b d e  - 120b c d e  + 180b c d e  - 120b c d e + 30b c d  )x
+--R      *
+--R          +-+ +-------+
+--R         \|d \|e x + d
+--R     ,
+--R
+--R                       5   7            4 2        5     6
+--R                 105A b c e  + (- 360A b c  - 30B b c)d e
+--R               + 
+--R                        3 3         4 2  2 5           2 4         3 3  3 4
+--R                 (390A b c  + 120B b c )d e  + (- 60A b c  - 180B b c )d e
+--R               + 
+--R                            5         2 4  4 3         6          5  5 2
+--R                 (- 135A b c  + 120B b c )d e  + (60A c  - 30B b c )d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       6 7            5         6    6
+--R                 105A b e  + (- 150A b c - 30B b )d e
+--R               + 
+--R                          4 2        5   2 5          3 3        4 2  3 4
+--R                 (- 330A b c  + 60B b c)d e  + (720A b c  + 60B b c )d e
+--R               + 
+--R                          2 4         3 3  4 3              5         2 4  5 2
+--R                 (- 255A b c  - 240B b c )d e  + (- 210A b c  + 210B b c )d e
+--R               + 
+--R                        6          5  6
+--R                 (120A c  - 60B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       6   6            5         6  2 5
+--R                 210A b d e  + (- 615A b c - 60B b )d e
+--R               + 
+--R                        4 2         5   3 4          3 3         4 2  4 3
+--R                 (420A b c  + 210B b c)d e  + (270A b c  - 240B b c )d e
+--R               + 
+--R                          2 4        3 3  5 2             5        2 4  6
+--R                 (- 330A b c  + 60B b c )d e  + (- 15A b c  + 60B b c )d e
+--R               + 
+--R                       6          5  7
+--R                 (60A c  - 30B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       6 2 5            5         6  3 4
+--R                 105A b d e  + (- 360A b c - 30B b )d e
+--R               + 
+--R                        4 2         5   4 3           3 3         4 2  5 2
+--R                 (390A b c  + 120B b c)d e  + (- 60A b c  - 180B b c )d e
+--R               + 
+--R                          2 4         3 3  6            5        2 4  7
+--R                 (- 135A b c  + 120B b c )d e + (60A b c  - 30B b c )d
+--R            *
+--R               x
+--R        *
+--R                            +-------+              +-+
+--R            +-------+    2d\|e x + d  + (e x + 2d)\|d
+--R           \|e x + d log(-----------------------------)
+--R                                       x
+--R       + 
+--R                         5         2 4  4 3          6          5  5 2  4
+--R             ((- 330A b c  + 270B b c )d e  + (120A c  - 60B b c )d e )x
+--R           + 
+--R                          2 4         3 3  4 3              5         2 4  5 2
+--R                 (- 330A b c  + 270B b c )d e  + (- 540A b c  + 480B b c )d e
+--R               + 
+--R                        6           5  6
+--R                 (240A c  - 120B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          2 4         3 3  5 2             5         2 4  6
+--R                 (- 660A b c  + 540B b c )d e  + (- 90A b c  + 150B b c )d e
+--R               + 
+--R                        6          5  7
+--R                 (120A c  - 60B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2 4         3 3  6             5        2 4  7
+--R             ((- 330A b c  + 270B b c )d e + (120A b c  - 60B b c )d )x
+--R        *
+--R            +---------+                           +-------+
+--R            |    c      +-+ +-------+           c\|e x + d
+--R            |--------- \|d \|e x + d atan(-----------------------)
+--R           \|b e - c d                                +---------+
+--R                                                      |    c
+--R                                          (b e - c d) |---------
+--R                                                     \|b e - c d
+--R       + 
+--R                         5   7          4 2        5     6
+--R                 - 210A b c e  + (720A b c  + 60B b c)d e
+--R               + 
+--R                          3 3         4 2  2 5          2 4         3 3  3 4
+--R                 (- 780A b c  - 240B b c )d e  + (120A b c  + 360B b c )d e
+--R               + 
+--R                           5        2 4  4 3
+--R                 (- 60A b c  + 30B b c )d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         6 7          5         6    6
+--R                 - 210A b e  + (230A b c + 60B b )d e
+--R               + 
+--R                        4 2         5   2 5             3 3         4 2  3 4
+--R                 (900A b c  - 100B b c)d e  + (- 1700A b c  - 200B b c )d e
+--R               + 
+--R                        2 4         3 3  4 3              5        2 4  5 2
+--R                 (330A b c  + 780B b c )d e  + (- 180A b c  + 90B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         6   6           5          6  2 5
+--R                 - 490A b d e  + (1358A b c + 140B b )d e
+--R               + 
+--R                          4 2         5   3 4            3 3         4 2  4 3
+--R                 (- 716A b c  - 468B b c)d e  + (- 872A b c  + 436B b c )d e
+--R               + 
+--R                        2 4         3 3  5 2              5        2 4  6
+--R                 (270A b c  + 432B b c )d e  + (- 180A b c  + 90B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         6 2 5           5         6  3 4
+--R                 - 322A b d e  + (1074A b c + 92B b )d e
+--R               + 
+--R                           4 2         5   4 3          3 3         4 2  5 2
+--R                 (- 1112A b c  - 344B b c)d e  + (180A b c  + 432B b c )d e
+--R               + 
+--R                      2 4 6              5        2 4  7
+--R                 30A b c d e + (- 60A b c  + 30B b c )d
+--R            *
+--R               x
+--R           + 
+--R                    6 3 4         5   4 3         4 2 5 2         3 3 6
+--R             - 30A b d e  + 120A b c d e  - 180A b c d e  + 120A b c d e
+--R           + 
+--R                    2 4 7
+--R             - 30A b c d
+--R        *
+--R            +-+
+--R           \|d
+--R    /
+--R               7   4 6       6 2 5 5       5 3 6 4       4 4 7 3      3 5 8 2  4
+--R           (30b c d e  - 120b c d e  + 180b c d e  - 120b c d e  + 30b c d e )x
+--R         + 
+--R                  8 4 6      7   5 5      6 2 6 4       5 3 7 3       4 4 8 2
+--R               30b d e  - 60b c d e  - 60b c d e  + 240b c d e  - 210b c d e
+--R             + 
+--R                  3 5 9
+--R               60b c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  8 5 5       7   6 4       6 2 7 3      5 3 8 2      4 4 9
+--R               60b d e  - 210b c d e  + 240b c d e  - 60b c d e  - 60b c d e
+--R             + 
+--R                  3 5 10
+--R               30b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R               8 6 4       7   7 3       6 2 8 2       5 3 9       4 4 10
+--R           (30b d e  - 120b c d e  + 180b c d e  - 120b c d e + 30b c d  )x
+--R      *
+--R          +-+ +-------+
+--R         \|d \|e x + d
+--R     ,
+--R
+--R                       5         2 4  4 3           6          5  5 2  4
+--R             ((165A b c  - 135B b c )d e  + (- 60A c  + 30B b c )d e )x
+--R           + 
+--R                        2 4         3 3  4 3            5         2 4  5 2
+--R                 (165A b c  - 135B b c )d e  + (270A b c  - 240B b c )d e
+--R               + 
+--R                          6          5  6
+--R                 (- 120A c  + 60B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        2 4         3 3  5 2           5        2 4  6
+--R                 (330A b c  - 270B b c )d e  + (45A b c  - 75B b c )d e
+--R               + 
+--R                         6          5  7
+--R                 (- 60A c  + 30B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     2 4         3 3  6              5        2 4  7
+--R             ((165A b c  - 135B b c )d e + (- 60A b c  + 30B b c )d )x
+--R        *
+--R                  +-----------+
+--R            +---+ |      c      +-------+
+--R           \|- d  |- --------- \|e x + d
+--R                 \|  b e - c d
+--R        *
+--R                               +-----------+
+--R                               |      c      +-------+
+--R               (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                              \|  b e - c d
+--R           log(------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                       5   7            4 2        5     6
+--R                 210A b c e  + (- 720A b c  - 60B b c)d e
+--R               + 
+--R                        3 3         4 2  2 5            2 4         3 3  3 4
+--R                 (780A b c  + 240B b c )d e  + (- 120A b c  - 360B b c )d e
+--R               + 
+--R                            5         2 4  4 3          6          5  5 2
+--R                 (- 270A b c  + 240B b c )d e  + (120A c  - 60B b c )d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       6 7            5         6    6
+--R                 210A b e  + (- 300A b c - 60B b )d e
+--R               + 
+--R                          4 2         5   2 5           3 3         4 2  3 4
+--R                 (- 660A b c  + 120B b c)d e  + (1440A b c  + 120B b c )d e
+--R               + 
+--R                          2 4         3 3  4 3              5         2 4  5 2
+--R                 (- 510A b c  - 480B b c )d e  + (- 420A b c  + 420B b c )d e
+--R               + 
+--R                        6           5  6
+--R                 (240A c  - 120B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       6   6             5          6  2 5
+--R                 420A b d e  + (- 1230A b c - 120B b )d e
+--R               + 
+--R                        4 2         5   3 4          3 3         4 2  4 3
+--R                 (840A b c  + 420B b c)d e  + (540A b c  - 480B b c )d e
+--R               + 
+--R                          2 4         3 3  5 2             5         2 4  6
+--R                 (- 660A b c  + 120B b c )d e  + (- 30A b c  + 120B b c )d e
+--R               + 
+--R                        6          5  7
+--R                 (120A c  - 60B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       6 2 5            5         6  3 4
+--R                 210A b d e  + (- 720A b c - 60B b )d e
+--R               + 
+--R                        4 2         5   4 3            3 3         4 2  5 2
+--R                 (780A b c  + 240B b c)d e  + (- 120A b c  - 360B b c )d e
+--R               + 
+--R                          2 4         3 3  6             5        2 4  7
+--R                 (- 270A b c  + 240B b c )d e + (120A b c  - 60B b c )d
+--R            *
+--R               x
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                         5   7          4 2        5     6
+--R                 - 210A b c e  + (720A b c  + 60B b c)d e
+--R               + 
+--R                          3 3         4 2  2 5          2 4         3 3  3 4
+--R                 (- 780A b c  - 240B b c )d e  + (120A b c  + 360B b c )d e
+--R               + 
+--R                           5        2 4  4 3
+--R                 (- 60A b c  + 30B b c )d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         6 7          5         6    6
+--R                 - 210A b e  + (230A b c + 60B b )d e
+--R               + 
+--R                        4 2         5   2 5             3 3         4 2  3 4
+--R                 (900A b c  - 100B b c)d e  + (- 1700A b c  - 200B b c )d e
+--R               + 
+--R                        2 4         3 3  4 3              5        2 4  5 2
+--R                 (330A b c  + 780B b c )d e  + (- 180A b c  + 90B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         6   6           5          6  2 5
+--R                 - 490A b d e  + (1358A b c + 140B b )d e
+--R               + 
+--R                          4 2         5   3 4            3 3         4 2  4 3
+--R                 (- 716A b c  - 468B b c)d e  + (- 872A b c  + 436B b c )d e
+--R               + 
+--R                        2 4         3 3  5 2              5        2 4  6
+--R                 (270A b c  + 432B b c )d e  + (- 180A b c  + 90B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         6 2 5           5         6  3 4
+--R                 - 322A b d e  + (1074A b c + 92B b )d e
+--R               + 
+--R                           4 2         5   4 3          3 3         4 2  5 2
+--R                 (- 1112A b c  - 344B b c)d e  + (180A b c  + 432B b c )d e
+--R               + 
+--R                      2 4 6              5        2 4  7
+--R                 30A b c d e + (- 60A b c  + 30B b c )d
+--R            *
+--R               x
+--R           + 
+--R                    6 3 4         5   4 3         4 2 5 2         3 3 6
+--R             - 30A b d e  + 120A b c d e  - 180A b c d e  + 120A b c d e
+--R           + 
+--R                    2 4 7
+--R             - 30A b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R               7   4 6       6 2 5 5       5 3 6 4       4 4 7 3      3 5 8 2  4
+--R           (30b c d e  - 120b c d e  + 180b c d e  - 120b c d e  + 30b c d e )x
+--R         + 
+--R                  8 4 6      7   5 5      6 2 6 4       5 3 7 3       4 4 8 2
+--R               30b d e  - 60b c d e  - 60b c d e  + 240b c d e  - 210b c d e
+--R             + 
+--R                  3 5 9
+--R               60b c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  8 5 5       7   6 4       6 2 7 3      5 3 8 2      4 4 9
+--R               60b d e  - 210b c d e  + 240b c d e  - 60b c d e  - 60b c d e
+--R             + 
+--R                  3 5 10
+--R               30b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R               8 6 4       7   7 3       6 2 8 2       5 3 9       4 4 10
+--R           (30b d e  - 120b c d e  + 180b c d e  - 120b c d e + 30b c d  )x
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ,
+--R
+--R                       5   7            4 2        5     6
+--R                 105A b c e  + (- 360A b c  - 30B b c)d e
+--R               + 
+--R                        3 3         4 2  2 5           2 4         3 3  3 4
+--R                 (390A b c  + 120B b c )d e  + (- 60A b c  - 180B b c )d e
+--R               + 
+--R                            5         2 4  4 3         6          5  5 2
+--R                 (- 135A b c  + 120B b c )d e  + (60A c  - 30B b c )d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       6 7            5         6    6
+--R                 105A b e  + (- 150A b c - 30B b )d e
+--R               + 
+--R                          4 2        5   2 5          3 3        4 2  3 4
+--R                 (- 330A b c  + 60B b c)d e  + (720A b c  + 60B b c )d e
+--R               + 
+--R                          2 4         3 3  4 3              5         2 4  5 2
+--R                 (- 255A b c  - 240B b c )d e  + (- 210A b c  + 210B b c )d e
+--R               + 
+--R                        6          5  6
+--R                 (120A c  - 60B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       6   6            5         6  2 5
+--R                 210A b d e  + (- 615A b c - 60B b )d e
+--R               + 
+--R                        4 2         5   3 4          3 3         4 2  4 3
+--R                 (420A b c  + 210B b c)d e  + (270A b c  - 240B b c )d e
+--R               + 
+--R                          2 4        3 3  5 2             5        2 4  6
+--R                 (- 330A b c  + 60B b c )d e  + (- 15A b c  + 60B b c )d e
+--R               + 
+--R                       6          5  7
+--R                 (60A c  - 30B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       6 2 5            5         6  3 4
+--R                 105A b d e  + (- 360A b c - 30B b )d e
+--R               + 
+--R                        4 2         5   4 3           3 3         4 2  5 2
+--R                 (390A b c  + 120B b c)d e  + (- 60A b c  - 180B b c )d e
+--R               + 
+--R                          2 4         3 3  6            5        2 4  7
+--R                 (- 135A b c  + 120B b c )d e + (60A b c  - 30B b c )d
+--R            *
+--R               x
+--R        *
+--R                           +---+ +-------+
+--R            +-------+     \|- d \|e x + d
+--R           \|e x + d atan(----------------)
+--R                                  d
+--R       + 
+--R                         5         2 4  4 3         6          5  5 2  4
+--R             ((- 165A b c  + 135B b c )d e  + (60A c  - 30B b c )d e )x
+--R           + 
+--R                          2 4         3 3  4 3              5         2 4  5 2
+--R                 (- 165A b c  + 135B b c )d e  + (- 270A b c  + 240B b c )d e
+--R               + 
+--R                        6          5  6
+--R                 (120A c  - 60B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          2 4         3 3  5 2             5        2 4  6
+--R                 (- 330A b c  + 270B b c )d e  + (- 45A b c  + 75B b c )d e
+--R               + 
+--R                       6          5  7
+--R                 (60A c  - 30B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                       2 4         3 3  6            5        2 4  7
+--R             ((- 165A b c  + 135B b c )d e + (60A b c  - 30B b c )d )x
+--R        *
+--R                  +---------+                       +-------+
+--R            +---+ |    c      +-------+           c\|e x + d
+--R           \|- d  |--------- \|e x + d atan(-----------------------)
+--R                 \|b e - c d                            +---------+
+--R                                                        |    c
+--R                                            (b e - c d) |---------
+--R                                                       \|b e - c d
+--R       + 
+--R                         5   7          4 2        5     6
+--R                 - 105A b c e  + (360A b c  + 30B b c)d e
+--R               + 
+--R                          3 3         4 2  2 5         2 4         3 3  3 4
+--R                 (- 390A b c  - 120B b c )d e  + (60A b c  + 180B b c )d e
+--R               + 
+--R                           5        2 4  4 3
+--R                 (- 30A b c  + 15B b c )d e
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         6 7          5         6    6
+--R                 - 105A b e  + (115A b c + 30B b )d e
+--R               + 
+--R                        4 2        5   2 5            3 3         4 2  3 4
+--R                 (450A b c  - 50B b c)d e  + (- 850A b c  - 100B b c )d e
+--R               + 
+--R                        2 4         3 3  4 3             5        2 4  5 2
+--R                 (165A b c  + 390B b c )d e  + (- 90A b c  + 45B b c )d e
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         6   6          5         6  2 5
+--R                 - 245A b d e  + (679A b c + 70B b )d e
+--R               + 
+--R                          4 2         5   3 4            3 3         4 2  4 3
+--R                 (- 358A b c  - 234B b c)d e  + (- 436A b c  + 218B b c )d e
+--R               + 
+--R                        2 4         3 3  5 2             5        2 4  6
+--R                 (135A b c  + 216B b c )d e  + (- 90A b c  + 45B b c )d e
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         6 2 5          5         6  3 4
+--R                 - 161A b d e  + (537A b c + 46B b )d e
+--R               + 
+--R                          4 2         5   4 3         3 3         4 2  5 2
+--R                 (- 556A b c  - 172B b c)d e  + (90A b c  + 216B b c )d e
+--R               + 
+--R                      2 4 6              5        2 4  7
+--R                 15A b c d e + (- 30A b c  + 15B b c )d
+--R            *
+--R               x
+--R           + 
+--R                  6 3 4        5   4 3        4 2 5 2        3 3 6         2 4 7
+--R           - 15A b d e  + 60A b c d e  - 90A b c d e  + 60A b c d e - 15A b c d
+--R        *
+--R            +---+
+--R           \|- d
+--R    /
+--R               7   4 6      6 2 5 5      5 3 6 4      4 4 7 3      3 5 8 2  4
+--R           (15b c d e  - 60b c d e  + 90b c d e  - 60b c d e  + 15b c d e )x
+--R         + 
+--R                  8 4 6      7   5 5      6 2 6 4       5 3 7 3       4 4 8 2
+--R               15b d e  - 30b c d e  - 30b c d e  + 120b c d e  - 105b c d e
+--R             + 
+--R                  3 5 9
+--R               30b c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  8 5 5       7   6 4       6 2 7 3      5 3 8 2      4 4 9
+--R               30b d e  - 105b c d e  + 120b c d e  - 30b c d e  - 30b c d e
+--R             + 
+--R                  3 5 10
+--R               15b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R               8 6 4      7   7 3      6 2 8 2      5 3 9       4 4 10
+--R           (15b d e  - 60b c d e  + 90b c d e  - 60b c d e + 15b c d  )x
+--R      *
+--R          +---+ +-------+
+--R         \|- d \|e x + d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 823
+
+--S 824 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               5 5           4        5    4         3 2       4   2 3
+--R           7A b e  + (- 24A b c - 2B b )d e  + (26A b c  + 8B b c)d e
+--R         + 
+--R                  2 3        3 2  3 2            4       2 3  4
+--R           (- 4A b c  - 12B b c )d e  + (- 9A b c  + 8B b c )d e
+--R         + 
+--R                5         4  5
+--R           (4A c  - 2B b c )d
+--R      *
+--R                              +-------+              +-+
+--R          +-----------+    2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-----------------------------)
+--R                                         x
+--R     + 
+--R                  4       2 3  4           5         4  5  +-----------+
+--R         ((11A b c  - 9B b c )d e + (- 4A c  + 2B b c )d )\|- b e + c d
+--R      *
+--R          +-----------+
+--R          |      c      +-+
+--R          |- --------- \|d
+--R         \|  b e - c d
+--R      *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R             (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R         log(------------------------------------------------------------)
+--R                                        c x + b
+--R     + 
+--R                    4        2 3  4         5         4  5  +-+ +-+
+--R         ((- 22A b c  + 18B b c )d e + (8A c  - 4B b c )d )\|c \|d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                  5 5         4        5    4           3 2        4   2 3
+--R           - 14A b e  + (48A b c + 4B b )d e  + (- 52A b c  - 16B b c)d e
+--R         + 
+--R                2 3        3 2  3 2           4        2 3  4
+--R           (8A b c  + 24B b c )d e  + (18A b c  - 16B b c )d e
+--R         + 
+--R                  5         4  5
+--R           (- 8A c  + 4B b c )d
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R  /
+--R        7 4 4     6   5 3      5 2 6 2     4 3 7      3 4 8  +-----------+ +-+
+--R     (2b d e  - 8b c d e  + 12b c d e  - 8b c d e + 2b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 824
+
+--S 825 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 825
+
+--S 826 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               5 5           4        5    4         3 2       4   2 3
+--R           7A b e  + (- 24A b c - 2B b )d e  + (26A b c  + 8B b c)d e
+--R         + 
+--R                  2 3        3 2  3 2            4       2 3  4
+--R           (- 4A b c  - 12B b c )d e  + (- 9A b c  + 8B b c )d e
+--R         + 
+--R                5         4  5
+--R           (4A c  - 2B b c )d
+--R      *
+--R                              +-------+              +-+
+--R          +-----------+    2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-----------------------------)
+--R                                         x
+--R     + 
+--R                    4        2 3  4         5         4  5  +-+ +-+
+--R         ((- 22A b c  + 18B b c )d e + (8A c  - 4B b c )d )\|c \|d
+--R      *
+--R                +-+ +-------+
+--R               \|c \|e x + d
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- b e + c d
+--R     + 
+--R                  5 5         4        5    4           3 2        4   2 3
+--R           - 14A b e  + (48A b c + 4B b )d e  + (- 52A b c  - 16B b c)d e
+--R         + 
+--R                2 3        3 2  3 2           4        2 3  4
+--R           (8A b c  + 24B b c )d e  + (18A b c  - 16B b c )d e
+--R         + 
+--R                  5         4  5
+--R           (- 8A c  + 4B b c )d
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R     + 
+--R                    4        2 3  4         5         4  5  +-----------+
+--R         ((- 22A b c  + 18B b c )d e + (8A c  - 4B b c )d )\|- b e + c d
+--R      *
+--R          +---------+                 +-------+
+--R          |    c      +-+           c\|e x + d
+--R          |--------- \|d atan(-----------------------)
+--R         \|b e - c d                      +---------+
+--R                                          |    c
+--R                              (b e - c d) |---------
+--R                                         \|b e - c d
+--R  /
+--R        7 4 4     6   5 3      5 2 6 2     4 3 7      3 4 8  +-----------+ +-+
+--R     (2b d e  - 8b c d e  + 12b c d e  - 8b c d e + 2b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 827
+
+)clear all
+
+--S 828 of 1457
+t0:=(A+B*x)*(d+e*x)^(9/2)/(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R            4 5       4         3  4          3       2 2  3
+--R         B e x  + (A e  + 4B d e )x  + (4A d e  + 6B d e )x
+--R       + 
+--R              2 2       3   2        3       4        4
+--R         (6A d e  + 4B d e)x  + (4A d e + B d )x + A d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R      3 6       2 5     2   4    3 3
+--R     c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 828
+
+--S 829 of 1457
+r0:=1/4*(c*d-b*e)*(24*A*c^3*d^2+5*b^3*B*e^2+b^2*c*e*(3*B*d-A*e)-_
+     12*b*c^2*d*(B*d+2*A*e))*(d+e*x)^(3/2)/(b^4*c^2*(b+c*x))-_
+     1/4*(c*d-b*e)*(6*b*B*c*d-12*A*c^2*d-2*b^2*B*e+13*A*b*c*e)*_
+     (d+e*x)^(5/2)/(b^3*c*(b+c*x)^2)-1/4*(4*b*B*d-8*A*c*d+9*A*b*e)*_
+     (d+e*x)^(7/2)/(b^2*x*(b+c*x)^2)-1/2*A*(d+e*x)^(9/2)/(b*x^2*_
+     (b+c*x)^2)-3/4*d^(5/2)*(16*A*c^2*d^2+3*b^2*e*(4*B*d+7*A*e)-_
+     4*b*c*d*(2*B*d+9*A*e))*atanh(sqrt(d+e*x)/sqrt(d))/b^5+_
+     3/4*(c*d-b*e)^(5/2)*(16*A*c^3*d^2-5*b^3*B*e^2-4*b*c^2*d*_
+     (2*B*d-A*e)-b^2*c*e*(8*B*d-A*e))*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))/(b^5*c^(7/2))-3/4*e*(8*A*c^4*d^3-5*b^4*B*e^3+_
+     b^3*c*e^2*(2*B*d+A*e)+b^2*c^2*d*e*(3*B*d+2*A*e)-4*b*c^3*d^2*_
+     (B*d+3*A*e))*sqrt(d+e*x)/(b^4*c^3)
+--R 
+--R
+--R   (2)
+--R                    4 3        5 2  4        3 4       4 3    3
+--R               (3A b c  - 15B b c )e  + (6A b c  + 6B b c )d e
+--R             + 
+--R                     2 5       3 4  2 2             6        2 5  3
+--R               (27A b c  + 9B b c )d e  + (- 84A b c  + 24B b c )d e
+--R             + 
+--R                     7          6  4
+--R               (48A c  - 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    5 2        6   4         4 3        5 2    3
+--R               (6A b c  - 30B b c)e  + (12A b c  + 12B b c )d e
+--R             + 
+--R                     3 4        4 3  2 2            2 5        3 4  3
+--R               (54A b c  + 18B b c )d e  + (- 168A b c  + 48B b c )d e
+--R             + 
+--R                       6        2 5  4
+--R               (96A b c  - 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    6         7  4        5 2       6     3
+--R               (3A b c - 15B b )e  + (6A b c  + 6B b c)d e
+--R             + 
+--R                     4 3       5 2  2 2           3 4        4 3  3
+--R               (27A b c  + 9B b c )d e  + (- 84A b c  + 24B b c )d e
+--R             + 
+--R                     2 5        3 4  4
+--R               (48A b c  - 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                      2 5 2 2            6        2 5  3
+--R               - 63A b c d e  + (108A b c  - 36B b c )d e
+--R             + 
+--R                       7          6  4
+--R               (- 48A c  + 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       3 4 2 2          2 5        3 4  3
+--R               - 126A b c d e  + (216A b c  - 72B b c )d e
+--R             + 
+--R                         6        2 5  4
+--R               (- 96A b c  + 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      4 3 2 2          3 4        4 3  3
+--R               - 63A b c d e  + (108A b c  - 36B b c )d e
+--R             + 
+--R                       2 5        3 4  4
+--R               (- 48A b c  + 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                        +-------+
+--R          +-+ +-+      \|e x + d
+--R         \|c \|d atanh(----------)
+--R                           +-+
+--R                          \|d
+--R     + 
+--R               5 2 4 4
+--R           8B b c e x
+--R         + 
+--R                      5 2        6   4        4 3        5 2    3
+--R               (- 5A b c  + 25B b c)e  + (3A b c  - 19B b c )d e
+--R             + 
+--R                     3 4       4 3  2 2           2 5        3 4  3
+--R               (21A b c  + 3B b c )d e  + (- 48A b c  + 15B b c )d e
+--R             + 
+--R                       6        2 5  4
+--R               (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      6         7  4          5 2        6     3
+--R               (- 3A b c + 15B b )e  + (- 5A b c  - 11B b c)d e
+--R             + 
+--R                     4 3       5 2  2 2           3 4        4 3  3
+--R               (33A b c  - 9B b c )d e  + (- 73A b c  + 23B b c )d e
+--R             + 
+--R                     2 5        3 4  4
+--R               (36A b c  - 18B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   4 3 3         3 4       4 3  4         4 3 4
+--R           (- 17A b c d e + (8A b c  - 4B b c )d )x - 2A b c d
+--R      *
+--R          +-+ +-------+
+--R         \|c \|e x + d
+--R  /
+--R        5 5 4     6 4 3     7 3 2  +-+
+--R     (4b c x  + 8b c x  + 4b c x )\|c
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 1457
+--a0:=integrate(t0,x)
+--E 830
+
+--S 831 of 1457
+--m0:=a0-r0
+--E 831
+
+--S 832 of 1457
+--d0:=D(m0,x)
+--E 832
+
+)clear all
+
+--S 833 of 1457
+t0:=(A+B*x)*(d+e*x)^(7/2)/(b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R            3 4       3         2  3          2       2   2        2       3
+--R         B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x
+--R       + 
+--R            3
+--R         A d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R      3 6       2 5     2   4    3 3
+--R     c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 833
+
+--S 834 of 1457
+r0:=-1/4*(c*d-b*e)*(6*b*B*c*d-12*A*c^2*d-2*b^2*B*e+11*A*b*c*e)*_
+     (d+e*x)^(3/2)/(b^3*c*(b+c*x)^2)-1/4*(4*b*B*d-8*A*c*d+7*A*b*e)*_
+     (d+e*x)^(5/2)/(b^2*x*(b+c*x)^2)-1/2*A*(d+e*x)^(7/2)/(b*x^2*_
+     (b+c*x)^2)-1/4*d^(3/2)*(48*A*c^2*d^2+7*b^2*e*(4*B*d+5*A*e)-_
+     12*b*c*d*(2*B*d+7*A*e))*atanh(sqrt(d+e*x)/sqrt(d))/b^5+1/4*_
+     (c*d-b*e)^(3/2)*(48*A*c^3*d^2-3*b^3*B*e^2-12*b*c^2*d*(2*B*d+A*e)-_
+     b^2*c*e*(8*B*d+A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/_
+     (b^5*c^(5/2))+1/4*(c*d-b*e)*(24*A*c^3*d^2+3*b^3*B*e^2+b^2*c*e*_
+     (5*B*d+A*e)-12*b*c^2*d*(B*d+2*A*e))*sqrt(d+e*x)/(b^4*c^2*(b+c*x))
+--R 
+--R
+--R   (2)
+--R                   3 3       4 2  3         2 4       3 3    2
+--R               (A b c  + 3B b c )e  + (11A b c  + 5B b c )d e
+--R             + 
+--R                         5        2 4  2          6          5  3
+--R               (- 60A b c  + 16B b c )d e + (48A c  - 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    4 2       5   3         3 3        4 2    2
+--R               (2A b c  + 6B b c)e  + (22A b c  + 10B b c )d e
+--R             + 
+--R                        2 4        3 3  2            5        2 4  3
+--R               (- 120A b c  + 32B b c )d e + (96A b c  - 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   5        6  3         4 2       5     2
+--R               (A b c + 3B b )e  + (11A b c  + 5B b c)d e
+--R             + 
+--R                       3 3        4 2  2          2 4        3 3  3
+--R               (- 60A b c  + 16B b c )d e + (48A b c  - 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                        2 4   2           5        2 4  2
+--R                 - 35A b c d e  + (84A b c  - 28B b c )d e
+--R               + 
+--R                         6          5  3
+--R                 (- 48A c  + 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      3 3   2          2 4        3 3  2
+--R               - 70A b c d e  + (168A b c  - 56B b c )d e
+--R             + 
+--R                         5        2 4  3
+--R               (- 96A b c  + 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      4 2   2         3 3        4 2  2
+--R               - 35A b c d e  + (84A b c  - 28B b c )d e
+--R             + 
+--R                       2 4        3 3  3
+--R               (- 48A b c  + 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                        +-------+
+--R          +-+ +-+      \|e x + d
+--R         \|c \|d atanh(----------)
+--R                           +-+
+--R                          \|d
+--R     + 
+--R                   4 2       5   3         3 3       4 2    2
+--R               (A b c  - 5B b c)e  + (10A b c  + 2B b c )d e
+--R             + 
+--R                       2 4        3 3  2            5        2 4  3
+--R               (- 36A b c  + 11B b c )d e + (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     5        6  3         4 2       5     2
+--R               (- A b c - 3B b )e  + (16A b c  - 4B b c)d e
+--R             + 
+--R                       3 3        4 2  2          2 4        3 3  3
+--R               (- 55A b c  + 17B b c )d e + (36A b c  - 18B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   4 2 2         3 3       4 2  3         4 2 3
+--R           (- 13A b c d e + (8A b c  - 4B b c )d )x - 2A b c d
+--R      *
+--R          +-+ +-------+
+--R         \|c \|e x + d
+--R  /
+--R        5 4 4     6 3 3     7 2 2  +-+
+--R     (4b c x  + 8b c x  + 4b c x )\|c
+--R                                                    Type: Expression(Integer)
+--E 834
+
+--S 835 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     3 3       4 2  3         2 4       3 3    2
+--R                 (A b c  + 3B b c )e  + (11A b c  + 5B b c )d e
+--R               + 
+--R                           5        2 4  2          6          5  3
+--R                 (- 60A b c  + 16B b c )d e + (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      4 2       5   3         3 3        4 2    2
+--R                 (2A b c  + 6B b c)e  + (22A b c  + 10B b c )d e
+--R               + 
+--R                          2 4        3 3  2            5        2 4  3
+--R                 (- 120A b c  + 32B b c )d e + (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     5        6  3         4 2       5     2
+--R                 (A b c + 3B b )e  + (11A b c  + 5B b c)d e
+--R               + 
+--R                         3 3        4 2  2          2 4        3 3  3
+--R                 (- 60A b c  + 16B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                                +-----------+
+--R                                |- b e + c d  +-------+
+--R            +-----------+    2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d       \|     c
+--R            |----------- log(-----------------------------------------------)
+--R           \|     c                              c x + b
+--R       + 
+--R                        2 4   2             5        2 4  2
+--R                   35A b c d e  + (- 84A b c  + 28B b c )d e
+--R                 + 
+--R                         6          5  3
+--R                   (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      3 3   2            2 4        3 3  2
+--R                 70A b c d e  + (- 168A b c  + 56B b c )d e
+--R               + 
+--R                         5        2 4  3
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4 2   2           3 3        4 2  2
+--R                 35A b c d e  + (- 84A b c  + 28B b c )d e
+--R               + 
+--R                       2 4        3 3  3
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                       +-+ +-------+
+--R            +-+    - 2\|d \|e x + d  + e x + 2d
+--R           \|d log(----------------------------)
+--R                                 x
+--R       + 
+--R                      4 2        5   3         3 3       4 2    2
+--R                 (2A b c  - 10B b c)e  + (20A b c  + 4B b c )d e
+--R               + 
+--R                         2 4        3 3  2            5        2 4  3
+--R                 (- 72A b c  + 22B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        5        6  3         4 2       5     2
+--R                 (- 2A b c - 6B b )e  + (32A b c  - 8B b c)d e
+--R               + 
+--R                          3 3        4 2  2          2 4        3 3  3
+--R                 (- 110A b c  + 34B b c )d e + (72A b c  - 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4 2 2          3 3       4 2  3         4 2 3
+--R             (- 26A b c d e + (16A b c  - 8B b c )d )x - 4A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         5 4 4      6 3 3     7 2 2
+--R       8b c x  + 16b c x  + 8b c x
+--R     ,
+--R
+--R                        2 4   2             5        2 4  2
+--R                   35A b c d e  + (- 84A b c  + 28B b c )d e
+--R                 + 
+--R                         6          5  3
+--R                   (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      3 3   2            2 4        3 3  2
+--R                 70A b c d e  + (- 168A b c  + 56B b c )d e
+--R               + 
+--R                         5        2 4  3
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4 2   2           3 3        4 2  2
+--R                 35A b c d e  + (- 84A b c  + 28B b c )d e
+--R               + 
+--R                       2 4        3 3  3
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                       +-+ +-------+
+--R            +-+    - 2\|d \|e x + d  + e x + 2d
+--R           \|d log(----------------------------)
+--R                                 x
+--R       + 
+--R                      3 3       4 2  3         2 4        3 3    2
+--R                 (2A b c  + 6B b c )e  + (22A b c  + 10B b c )d e
+--R               + 
+--R                            5        2 4  2          6          5  3
+--R                 (- 120A b c  + 32B b c )d e + (96A c  - 48B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      4 2        5   3         3 3        4 2    2
+--R                 (4A b c  + 12B b c)e  + (44A b c  + 20B b c )d e
+--R               + 
+--R                          2 4        3 3  2             5        2 4  3
+--R                 (- 240A b c  + 64B b c )d e + (192A b c  - 96B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      5        6  3         4 2        5     2
+--R                 (2A b c + 6B b )e  + (22A b c  + 10B b c)d e
+--R               + 
+--R                          3 3        4 2  2          2 4        3 3  3
+--R                 (- 120A b c  + 32B b c )d e + (96A b c  - 48B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                      4 2        5   3         3 3       4 2    2
+--R                 (2A b c  - 10B b c)e  + (20A b c  + 4B b c )d e
+--R               + 
+--R                         2 4        3 3  2            5        2 4  3
+--R                 (- 72A b c  + 22B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        5        6  3         4 2       5     2
+--R                 (- 2A b c - 6B b )e  + (32A b c  - 8B b c)d e
+--R               + 
+--R                          3 3        4 2  2          2 4        3 3  3
+--R                 (- 110A b c  + 34B b c )d e + (72A b c  - 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4 2 2          3 3       4 2  3         4 2 3
+--R             (- 26A b c d e + (16A b c  - 8B b c )d )x - 4A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         5 4 4      6 3 3     7 2 2
+--R       8b c x  + 16b c x  + 8b c x
+--R     ,
+--R
+--R                     3 3       4 2  3         2 4       3 3    2
+--R                 (A b c  + 3B b c )e  + (11A b c  + 5B b c )d e
+--R               + 
+--R                           5        2 4  2          6          5  3
+--R                 (- 60A b c  + 16B b c )d e + (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      4 2       5   3         3 3        4 2    2
+--R                 (2A b c  + 6B b c)e  + (22A b c  + 10B b c )d e
+--R               + 
+--R                          2 4        3 3  2            5        2 4  3
+--R                 (- 120A b c  + 32B b c )d e + (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     5        6  3         4 2       5     2
+--R                 (A b c + 3B b )e  + (11A b c  + 5B b c)d e
+--R               + 
+--R                         3 3        4 2  2          2 4        3 3  3
+--R                 (- 60A b c  + 16B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                                +-----------+
+--R                                |- b e + c d  +-------+
+--R            +-----------+    2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d       \|     c
+--R            |----------- log(-----------------------------------------------)
+--R           \|     c                              c x + b
+--R       + 
+--R                        2 4   2            5        2 4  2
+--R                 - 70A b c d e  + (168A b c  - 56B b c )d e
+--R               + 
+--R                         6          5  3
+--R                 (- 96A c  + 48B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         3 3   2          2 4         3 3  2
+--R                 - 140A b c d e  + (336A b c  - 112B b c )d e
+--R               + 
+--R                            5        2 4  3
+--R                 (- 192A b c  + 96B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4 2   2          3 3        4 2  2
+--R                 - 70A b c d e  + (168A b c  - 56B b c )d e
+--R               + 
+--R                         2 4        3 3  3
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                       +-------+
+--R            +---+     \|e x + d
+--R           \|- d atan(----------)
+--R                         +---+
+--R                        \|- d
+--R       + 
+--R                      4 2        5   3         3 3       4 2    2
+--R                 (2A b c  - 10B b c)e  + (20A b c  + 4B b c )d e
+--R               + 
+--R                         2 4        3 3  2            5        2 4  3
+--R                 (- 72A b c  + 22B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        5        6  3         4 2       5     2
+--R                 (- 2A b c - 6B b )e  + (32A b c  - 8B b c)d e
+--R               + 
+--R                          3 3        4 2  2          2 4        3 3  3
+--R                 (- 110A b c  + 34B b c )d e + (72A b c  - 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4 2 2          3 3       4 2  3         4 2 3
+--R             (- 26A b c d e + (16A b c  - 8B b c )d )x - 4A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         5 4 4      6 3 3     7 2 2
+--R       8b c x  + 16b c x  + 8b c x
+--R     ,
+--R
+--R                        2 4   2           5        2 4  2
+--R                 - 35A b c d e  + (84A b c  - 28B b c )d e
+--R               + 
+--R                         6          5  3
+--R                 (- 48A c  + 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        3 3   2          2 4        3 3  2
+--R                 - 70A b c d e  + (168A b c  - 56B b c )d e
+--R               + 
+--R                           5        2 4  3
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4 2   2         3 3        4 2  2
+--R                 - 35A b c d e  + (84A b c  - 28B b c )d e
+--R               + 
+--R                         2 4        3 3  3
+--R                 (- 48A b c  + 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                       +-------+
+--R            +---+     \|e x + d
+--R           \|- d atan(----------)
+--R                         +---+
+--R                        \|- d
+--R       + 
+--R                     3 3       4 2  3         2 4       3 3    2
+--R                 (A b c  + 3B b c )e  + (11A b c  + 5B b c )d e
+--R               + 
+--R                           5        2 4  2          6          5  3
+--R                 (- 60A b c  + 16B b c )d e + (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      4 2       5   3         3 3        4 2    2
+--R                 (2A b c  + 6B b c)e  + (22A b c  + 10B b c )d e
+--R               + 
+--R                          2 4        3 3  2            5        2 4  3
+--R                 (- 120A b c  + 32B b c )d e + (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     5        6  3         4 2       5     2
+--R                 (A b c + 3B b )e  + (11A b c  + 5B b c)d e
+--R               + 
+--R                         3 3        4 2  2          2 4        3 3  3
+--R                 (- 60A b c  + 16B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                     4 2       5   3         3 3       4 2    2
+--R                 (A b c  - 5B b c)e  + (10A b c  + 2B b c )d e
+--R               + 
+--R                         2 4        3 3  2            5        2 4  3
+--R                 (- 36A b c  + 11B b c )d e + (24A b c  - 12B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       5        6  3         4 2       5     2
+--R                 (- A b c - 3B b )e  + (16A b c  - 4B b c)d e
+--R               + 
+--R                         3 3        4 2  2          2 4        3 3  3
+--R                 (- 55A b c  + 17B b c )d e + (36A b c  - 18B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4 2 2         3 3       4 2  3         4 2 3
+--R             (- 13A b c d e + (8A b c  - 4B b c )d )x - 2A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         5 4 4     6 3 3     7 2 2
+--R       4b c x  + 8b c x  + 4b c x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 835
+
+--S 836 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               3        4  3         2 2       3     2
+--R           (A b c + 3B b )e  + (11A b c  + 5B b c)d e
+--R         + 
+--R                     3        2 2  2          4          3  3
+--R           (- 60A b c  + 16B b c )d e + (48A c  - 24B b c )d
+--R      *
+--R                                  +-----------+
+--R                                  |- b e + c d  +-------+
+--R          +-----------+        2c |----------- \|e x + d  + c e x - b e + 2c d
+--R          |- b e + c d  +-+      \|     c
+--R          |----------- \|c log(-----------------------------------------------)
+--R         \|     c                                  c x + b
+--R     + 
+--R               2 2   2             3        2 2  2          4          3  3  +-+
+--R         (35A b c d e  + (- 84A b c  + 28B b c )d e + (48A c  - 24B b c )d )\|c
+--R      *
+--R                     +-+ +-------+
+--R          +-+    - 2\|d \|e x + d  + e x + 2d
+--R         \|d log(----------------------------)
+--R                               x
+--R     + 
+--R                  3        4  3           2 2        3     2
+--R           (- 2A b c - 6B b )e  + (- 22A b c  - 10B b c)d e
+--R         + 
+--R                    3        2 2  2            4          3  3
+--R           (120A b c  - 32B b c )d e + (- 96A c  + 48B b c )d
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R               2 2   2              3        2 2  2          4          3  3
+--R         (70A b c d e  + (- 168A b c  + 56B b c )d e + (96A c  - 48B b c )d )
+--R      *
+--R                        +-------+
+--R          +-+ +-+      \|e x + d
+--R         \|c \|d atanh(----------)
+--R                           +-+
+--R                          \|d
+--R  /
+--R       5 2 +-+
+--R     8b c \|c
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               2 2   2             3        2 2  2          4          3  3  +-+
+--R         (35A b c d e  + (- 84A b c  + 28B b c )d e + (48A c  - 24B b c )d )\|c
+--R      *
+--R                     +-+ +-------+
+--R          +-+    - 2\|d \|e x + d  + e x + 2d
+--R         \|d log(----------------------------)
+--R                               x
+--R     + 
+--R                  3        4  3           2 2        3     2
+--R           (- 2A b c - 6B b )e  + (- 22A b c  - 10B b c)d e
+--R         + 
+--R                    3        2 2  2            4          3  3
+--R           (120A b c  - 32B b c )d e + (- 96A c  + 48B b c )d
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R               2 2   2              3        2 2  2          4          3  3
+--R         (70A b c d e  + (- 168A b c  + 56B b c )d e + (96A c  - 48B b c )d )
+--R      *
+--R                        +-------+
+--R          +-+ +-+      \|e x + d
+--R         \|c \|d atanh(----------)
+--R                           +-+
+--R                          \|d
+--R     + 
+--R                3        4  3         2 2        3     2
+--R           (2A b c + 6B b )e  + (22A b c  + 10B b c)d e
+--R         + 
+--R                      3        2 2  2          4          3  3
+--R           (- 120A b c  + 32B b c )d e + (96A c  - 48B b c )d
+--R      *
+--R              +---------+       +-------+
+--R          +-+ |b e - c d       \|e x + d
+--R         \|c  |--------- atan(------------)
+--R             \|    c           +---------+
+--R                               |b e - c d
+--R                               |---------
+--R                              \|    c
+--R  /
+--R       5 2 +-+
+--R     8b c \|c
+--R                                                    Type: Expression(Integer)
+--E 838
+
+--S 839 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 839
+
+)clear all
+
+--S 840 of 1457
+t0:=(A+B*x)*(d+e*x)^(5/2)/(b*x+c*x^2)^3
+--R 
+--R
+--R            2 3       2           2                2        2  +-------+
+--R        (B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d )\|e x + d
+--R   (1)  ----------------------------------------------------------------
+--R                          3 6       2 5     2   4    3 3
+--R                         c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 840
+
+--S 841 of 1457
+r0:=-1/4*(4*b*B*d-8*A*c*d+5*A*b*e)*(d+e*x)^(3/2)/(b^2*x*(b+c*x)^2)-_
+     1/2*A*(d+e*x)^(5/2)/(b*x^2*(b+c*x)^2)-1/4*(48*A*c^2*d^2+5*b^2*e*_
+     (4*B*d+3*A*e)-12*b*c*d*(2*B*d+5*A*e))*atanh(sqrt(d+e*x)/sqrt(d))*_
+     sqrt(d)/b^5+1/4*(48*A*c^3*d^2+b^3*B*e^2-12*b*c^2*d*(2*B*d+3*A*e)+_
+     b^2*c*e*(8*B*d+3*A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))*_
+     sqrt(c*d-b*e)/(b^5*c^(3/2))-1/4*(c*d-b*e)*(6*b*B*c*d-12*A*c^2*d-_
+     2*b^2*B*e+9*A*b*c*e)*sqrt(d+e*x)/(b^3*c*(b+c*x)^2)+1/4*_
+     (24*A*c^3*d^2+b^3*B*e^2-12*b*c^2*d*(B*d+2*A*e)+b^2*c*e*_
+     (7*B*d+3*A*e))*sqrt(d+e*x)/(b^4*c*(b+c*x))
+--R 
+--R
+--R   (2)
+--R                    2 3      3 2  2             4       2 3
+--R               (3A b c  + B b c )e  + (- 36A b c  + 8B b c )d e
+--R             + 
+--R                     5          4  2
+--R               (48A c  - 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    3 2       4   2           2 3        3 2
+--R               (6A b c  + 2B b c)e  + (- 72A b c  + 16B b c )d e
+--R             + 
+--R                       4        2 3  2
+--R               (96A b c  - 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    4       5  2           3 2       4
+--R               (3A b c + B b )e  + (- 36A b c  + 8B b c)d e
+--R             + 
+--R                     2 3        3 2  2
+--R               (48A b c  - 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R                   2 3 2           4        2 3               5          4  2  4
+--R           (- 15A b c e  + (60A b c  - 20B b c )d e + (- 48A c  + 24B b c )d )x
+--R         + 
+--R                      3 2 2          2 3        3 2
+--R               - 30A b c e  + (120A b c  - 40B b c )d e
+--R             + 
+--R                         4        2 3  2
+--R               (- 96A b c  + 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                 4   2         3 2        4                2 3        3 2  2  2
+--R         (- 15A b c e  + (60A b c  - 20B b c)d e + (- 48A b c  + 24B b c )d )x
+--R      *
+--R                        +-------+
+--R          +-+ +-+      \|e x + d
+--R         \|c \|d atanh(----------)
+--R                           +-+
+--R                          \|d
+--R     + 
+--R                    3 2      4   2           2 3       3 2
+--R               (3A b c  + B b c)e  + (- 24A b c  + 7B b c )d e
+--R             + 
+--R                       4        2 3  2
+--R               (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    4       5  2           3 2        4
+--R               (5A b c - B b )e  + (- 37A b c  + 11B b c)d e
+--R             + 
+--R                     2 3        3 2  2
+--R               (36A b c  - 18B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                  4             3 2       4   2         4   2
+--R           (- 9A b c d e + (8A b c  - 4B b c)d )x - 2A b c d
+--R      *
+--R          +-+ +-------+
+--R         \|c \|e x + d
+--R  /
+--R        5 3 4     6 2 3     7   2  +-+
+--R     (4b c x  + 8b c x  + 4b c x )\|c
+--R                                                    Type: Expression(Integer)
+--E 841
+
+--S 842 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      2 3      3 2  2             4       2 3
+--R                 (3A b c  + B b c )e  + (- 36A b c  + 8B b c )d e
+--R               + 
+--R                       5          4  2
+--R                 (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      3 2       4   2           2 3        3 2
+--R                 (6A b c  + 2B b c)e  + (- 72A b c  + 16B b c )d e
+--R               + 
+--R                         4        2 3  2
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4       5  2           3 2       4
+--R                 (3A b c + B b )e  + (- 36A b c  + 8B b c)d e
+--R               + 
+--R                       2 3        3 2  2
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                                +-----------+
+--R                                |- b e + c d  +-------+
+--R            +-----------+    2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d       \|     c
+--R            |----------- log(-----------------------------------------------)
+--R           \|     c                              c x + b
+--R       + 
+--R                   2 3 2             4        2 3             5          4  2  4
+--R             (15A b c e  + (- 60A b c  + 20B b c )d e + (48A c  - 24B b c )d )x
+--R           + 
+--R                      3 2 2            2 3        3 2
+--R                 30A b c e  + (- 120A b c  + 40B b c )d e
+--R               + 
+--R                         4        2 3  2
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                 4   2           3 2        4              2 3        3 2  2  2
+--R           (15A b c e  + (- 60A b c  + 20B b c)d e + (48A b c  - 24B b c )d )x
+--R        *
+--R                       +-+ +-------+
+--R            +-+    - 2\|d \|e x + d  + e x + 2d
+--R           \|d log(----------------------------)
+--R                                 x
+--R       + 
+--R                      3 2       4   2           2 3        3 2
+--R                 (6A b c  + 2B b c)e  + (- 48A b c  + 14B b c )d e
+--R               + 
+--R                         4        2 3  2
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4        5  2           3 2        4
+--R                 (10A b c - 2B b )e  + (- 74A b c  + 22B b c)d e
+--R               + 
+--R                       2 3        3 2  2
+--R                 (72A b c  - 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4              3 2       4   2         4   2
+--R             (- 18A b c d e + (16A b c  - 8B b c)d )x - 4A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         5 3 4      6 2 3     7   2
+--R       8b c x  + 16b c x  + 8b c x
+--R     ,
+--R
+--R                   2 3 2             4        2 3             5          4  2  4
+--R             (15A b c e  + (- 60A b c  + 20B b c )d e + (48A c  - 24B b c )d )x
+--R           + 
+--R                      3 2 2            2 3        3 2
+--R                 30A b c e  + (- 120A b c  + 40B b c )d e
+--R               + 
+--R                         4        2 3  2
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                 4   2           3 2        4              2 3        3 2  2  2
+--R           (15A b c e  + (- 60A b c  + 20B b c)d e + (48A b c  - 24B b c )d )x
+--R        *
+--R                       +-+ +-------+
+--R            +-+    - 2\|d \|e x + d  + e x + 2d
+--R           \|d log(----------------------------)
+--R                                 x
+--R       + 
+--R                      2 3       3 2  2             4        2 3
+--R                 (6A b c  + 2B b c )e  + (- 72A b c  + 16B b c )d e
+--R               + 
+--R                       5          4  2
+--R                 (96A c  - 48B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       3 2       4   2            2 3        3 2
+--R                 (12A b c  + 4B b c)e  + (- 144A b c  + 32B b c )d e
+--R               + 
+--R                          4        2 3  2
+--R                 (192A b c  - 96B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4        5  2           3 2        4
+--R                 (6A b c + 2B b )e  + (- 72A b c  + 16B b c)d e
+--R               + 
+--R                       2 3        3 2  2
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                      3 2       4   2           2 3        3 2
+--R                 (6A b c  + 2B b c)e  + (- 48A b c  + 14B b c )d e
+--R               + 
+--R                         4        2 3  2
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4        5  2           3 2        4
+--R                 (10A b c - 2B b )e  + (- 74A b c  + 22B b c)d e
+--R               + 
+--R                       2 3        3 2  2
+--R                 (72A b c  - 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4              3 2       4   2         4   2
+--R             (- 18A b c d e + (16A b c  - 8B b c)d )x - 4A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         5 3 4      6 2 3     7   2
+--R       8b c x  + 16b c x  + 8b c x
+--R     ,
+--R
+--R                      2 3      3 2  2             4       2 3
+--R                 (3A b c  + B b c )e  + (- 36A b c  + 8B b c )d e
+--R               + 
+--R                       5          4  2
+--R                 (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      3 2       4   2           2 3        3 2
+--R                 (6A b c  + 2B b c)e  + (- 72A b c  + 16B b c )d e
+--R               + 
+--R                         4        2 3  2
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4       5  2           3 2       4
+--R                 (3A b c + B b )e  + (- 36A b c  + 8B b c)d e
+--R               + 
+--R                       2 3        3 2  2
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                                +-----------+
+--R                                |- b e + c d  +-------+
+--R            +-----------+    2c |----------- \|e x + d  + c e x - b e + 2c d
+--R            |- b e + c d       \|     c
+--R            |----------- log(-----------------------------------------------)
+--R           \|     c                              c x + b
+--R       + 
+--R                        2 3 2            4        2 3
+--R                 - 30A b c e  + (120A b c  - 40B b c )d e
+--R               + 
+--R                         5          4  2
+--R                 (- 96A c  + 48B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        3 2 2          2 3        3 2
+--R                 - 60A b c e  + (240A b c  - 80B b c )d e
+--R               + 
+--R                            4        2 3  2
+--R                 (- 192A b c  + 96B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4   2          3 2        4
+--R                 - 30A b c e  + (120A b c  - 40B b c)d e
+--R               + 
+--R                         2 3        3 2  2
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                       +-------+
+--R            +---+     \|e x + d
+--R           \|- d atan(----------)
+--R                         +---+
+--R                        \|- d
+--R       + 
+--R                      3 2       4   2           2 3        3 2
+--R                 (6A b c  + 2B b c)e  + (- 48A b c  + 14B b c )d e
+--R               + 
+--R                         4        2 3  2
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4        5  2           3 2        4
+--R                 (10A b c - 2B b )e  + (- 74A b c  + 22B b c)d e
+--R               + 
+--R                       2 3        3 2  2
+--R                 (72A b c  - 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     4              3 2       4   2         4   2
+--R             (- 18A b c d e + (16A b c  - 8B b c)d )x - 4A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         5 3 4      6 2 3     7   2
+--R       8b c x  + 16b c x  + 8b c x
+--R     ,
+--R
+--R                          2 3 2           4        2 3
+--R                   - 15A b c e  + (60A b c  - 20B b c )d e
+--R                 + 
+--R                           5          4  2
+--R                   (- 48A c  + 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        3 2 2          2 3        3 2
+--R                 - 30A b c e  + (120A b c  - 40B b c )d e
+--R               + 
+--R                           4        2 3  2
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        4   2         3 2        4
+--R                 - 15A b c e  + (60A b c  - 20B b c)d e
+--R               + 
+--R                         2 3        3 2  2
+--R                 (- 48A b c  + 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                       +-------+
+--R            +---+     \|e x + d
+--R           \|- d atan(----------)
+--R                         +---+
+--R                        \|- d
+--R       + 
+--R                      2 3      3 2  2             4       2 3
+--R                 (3A b c  + B b c )e  + (- 36A b c  + 8B b c )d e
+--R               + 
+--R                       5          4  2
+--R                 (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      3 2       4   2           2 3        3 2
+--R                 (6A b c  + 2B b c)e  + (- 72A b c  + 16B b c )d e
+--R               + 
+--R                         4        2 3  2
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4       5  2           3 2       4
+--R                 (3A b c + B b )e  + (- 36A b c  + 8B b c)d e
+--R               + 
+--R                       2 3        3 2  2
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +---------+       +-------+
+--R            |b e - c d       \|e x + d
+--R            |--------- atan(------------)
+--R           \|    c           +---------+
+--R                             |b e - c d
+--R                             |---------
+--R                            \|    c
+--R       + 
+--R                      3 2      4   2           2 3       3 2
+--R                 (3A b c  + B b c)e  + (- 24A b c  + 7B b c )d e
+--R               + 
+--R                         4        2 3  2
+--R                 (24A b c  - 12B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      4       5  2           3 2        4
+--R                 (5A b c - B b )e  + (- 37A b c  + 11B b c)d e
+--R               + 
+--R                       2 3        3 2  2
+--R                 (36A b c  - 18B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    4             3 2       4   2         4   2
+--R             (- 9A b c d e + (8A b c  - 4B b c)d )x - 2A b c d
+--R        *
+--R            +-------+
+--R           \|e x + d
+--R    /
+--R         5 3 4     6 2 3     7   2
+--R       4b c x  + 8b c x  + 4b c x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 842
+
+--S 843 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               2       3  2             2       2              3          2  2
+--R         ((3A b c + B b )e  + (- 36A b c  + 8B b c)d e + (48A c  - 24B b c )d )
+--R      *
+--R                                  +-----------+
+--R                                  |- b e + c d  +-------+
+--R          +-----------+        2c |----------- \|e x + d  + c e x - b e + 2c d
+--R          |- b e + c d  +-+      \|     c
+--R          |----------- \|c log(-----------------------------------------------)
+--R         \|     c                                  c x + b
+--R     + 
+--R               2   2             2        2              3          2  2  +-+
+--R         (15A b c e  + (- 60A b c  + 20B b c)d e + (48A c  - 24B b c )d )\|c
+--R      *
+--R                     +-+ +-------+
+--R          +-+    - 2\|d \|e x + d  + e x + 2d
+--R         \|d log(----------------------------)
+--R                               x
+--R     + 
+--R                  2        3  2           2        2
+--R           (- 6A b c - 2B b )e  + (72A b c  - 16B b c)d e
+--R         + 
+--R                   3          2  2
+--R           (- 96A c  + 48B b c )d
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R               2   2              2        2              3          2  2  +-+
+--R         (30A b c e  + (- 120A b c  + 40B b c)d e + (96A c  - 48B b c )d )\|c
+--R      *
+--R                    +-------+
+--R          +-+      \|e x + d
+--R         \|d atanh(----------)
+--R                       +-+
+--R                      \|d
+--R  /
+--R       5  +-+
+--R     8b c\|c
+--R                                                    Type: Expression(Integer)
+--E 843
+
+--S 844 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 844
+
+--S 845 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               2   2             2        2              3          2  2  +-+
+--R         (15A b c e  + (- 60A b c  + 20B b c)d e + (48A c  - 24B b c )d )\|c
+--R      *
+--R                     +-+ +-------+
+--R          +-+    - 2\|d \|e x + d  + e x + 2d
+--R         \|d log(----------------------------)
+--R                               x
+--R     + 
+--R                  2        3  2           2        2
+--R           (- 6A b c - 2B b )e  + (72A b c  - 16B b c)d e
+--R         + 
+--R                   3          2  2
+--R           (- 96A c  + 48B b c )d
+--R      *
+--R                              +-+ +-------+
+--R          +-----------+      \|c \|e x + d
+--R         \|- b e + c d atanh(--------------)
+--R                              +-----------+
+--R                             \|- b e + c d
+--R     + 
+--R               2   2              2        2              3          2  2  +-+
+--R         (30A b c e  + (- 120A b c  + 40B b c)d e + (96A c  - 48B b c )d )\|c
+--R      *
+--R                    +-------+
+--R          +-+      \|e x + d
+--R         \|d atanh(----------)
+--R                       +-+
+--R                      \|d
+--R     + 
+--R                  2        3  2             2        2
+--R             (6A b c + 2B b )e  + (- 72A b c  + 16B b c)d e
+--R           + 
+--R                   3          2  2
+--R             (96A c  - 48B b c )d
+--R      *
+--R              +---------+       +-------+
+--R          +-+ |b e - c d       \|e x + d
+--R         \|c  |--------- atan(------------)
+--R             \|    c           +---------+
+--R                               |b e - c d
+--R                               |---------
+--R                              \|    c
+--R  /
+--R       5  +-+
+--R     8b c\|c
+--R                                                    Type: Expression(Integer)
+--E 845
+
+--S 846 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 846
+
+)clear all
+
+--S 847 of 1457
+t0:=(A+B*x)*(d+e*x)^(3/2)/(b*x+c*x^2)^3
+--R 
+--R
+--R              2                       +-------+
+--R        (B e x  + (A e + B d)x + A d)\|e x + d
+--R   (1)  ---------------------------------------
+--R             3 6       2 5     2   4    3 3
+--R            c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1457
+r0:=-1/2*A*(d+e*x)^(3/2)/(b*x^2*(b+c*x)^2)-3/4*(16*A*c^2*d^2+b^2*e*_
+     (4*B*d+A*e)-4*b*c*d*(2*B*d+3*A*e))*atanh(sqrt(d+e*x)/sqrt(d))/_
+     (b^5*sqrt(d))+3/4*(16*A*c^3*d^2-b^3*B*e^2-4*b*c^2*d*(2*B*d+5*A*e)+_
+     b^2*c*e*(8*B*d+5*A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/_
+     (b^5*sqrt(c)*sqrt(c*d-b*e))-1/4*(6*b*B*c*d-12*A*c^2*d-2*b^2*B*e+_
+     7*A*b*c*e)*sqrt(d+e*x)/(b^3*(b+c*x)^2)-1/4*(4*b*B*d-8*A*c*d+3*A*b*e)*_
+     sqrt(d+e*x)/(b^2*x*(b+c*x)^2)+3/4*(8*A*c^2*d+b^2*B*e-4*b*c*(B*d+A*e))*_
+     sqrt(d+e*x)/(b^4*(b+c*x))
+--R 
+--R
+--R   (2)
+--R                     2 3       3 2  2             4        2 3
+--R               (15A b c  - 3B b c )e  + (- 60A b c  + 24B b c )d e
+--R             + 
+--R                     5          4  2
+--R               (48A c  - 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     3 2       4   2            2 3        3 2
+--R               (30A b c  - 6B b c)e  + (- 120A b c  + 48B b c )d e
+--R             + 
+--R                       4        2 3  2
+--R               (96A b c  - 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     4        5  2           3 2        4
+--R               (15A b c - 3B b )e  + (- 60A b c  + 24B b c)d e
+--R             + 
+--R                     2 3        3 2  2
+--R               (48A b c  - 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                    +-+ +-------+
+--R          +-+      \|c \|e x + d
+--R         \|d atanh(--------------)
+--R                    +-----------+
+--R                   \|- b e + c d
+--R     + 
+--R                  2 2 2           3        2 2               4          3  2  4
+--R           (- 3A b c e  + (36A b c  - 12B b c )d e + (- 48A c  + 24B b c )d )x
+--R         + 
+--R                  3   2         2 2        3                  3        2 2  2  3
+--R           (- 6A b c e  + (72A b c  - 24B b c)d e + (- 96A b c  + 48B b c )d )x
+--R         + 
+--R                  4 2         3         4               2 2        3   2  2
+--R           (- 3A b e  + (36A b c - 12B b )d e + (- 48A b c  + 24B b c)d )x
+--R      *
+--R                                  +-------+
+--R          +-----------+ +-+      \|e x + d
+--R         \|- b e + c d \|c atanh(----------)
+--R                                     +-+
+--R                                    \|d
+--R     + 
+--R                    2 2       3              3        2 2    3
+--R           ((- 12A b c  + 3B b c)e + (24A b c  - 12B b c )d)x
+--R         + 
+--R                    3        4           2 2        3     2
+--R           ((- 19A b c + 5B b )e + (36A b c  - 18B b c)d)x
+--R         + 
+--R                  4         3        4           4
+--R           (- 5A b e + (8A b c - 4B b )d)x - 2A b d
+--R      *
+--R          +-----------+ +-+ +-+ +-------+
+--R         \|- b e + c d \|c \|d \|e x + d
+--R  /
+--R        5 2 4     6   3     7 2  +-----------+ +-+ +-+
+--R     (4b c x  + 8b c x  + 4b x )\|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 848
+
+--S 849 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         2 3       3 2  2           4        2 3
+--R                 (- 15A b c  + 3B b c )e  + (60A b c  - 24B b c )d e
+--R               + 
+--R                         5          4  2
+--R                 (- 48A c  + 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         3 2       4   2          2 3        3 2
+--R                 (- 30A b c  + 6B b c)e  + (120A b c  - 48B b c )d e
+--R               + 
+--R                           4        2 3  2
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4        5  2         3 2        4
+--R                 (- 15A b c + 3B b )e  + (60A b c  - 24B b c)d e
+--R               + 
+--R                         2 3        3 2  2
+--R                 (- 48A b c  + 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +-+
+--R           \|d
+--R        *
+--R                                                              +-------------+
+--R                         2   +-------+                        |           2
+--R             (2b c e - 2c d)\|e x + d  + (c e x - b e + 2c d)\|- b c e + c d
+--R         log(----------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                  2 2 2             3        2 2             4          3  2  4
+--R             (3A b c e  + (- 36A b c  + 12B b c )d e + (48A c  - 24B b c )d )x
+--R           + 
+--R                  3   2           2 2        3                3        2 2  2  3
+--R             (6A b c e  + (- 72A b c  + 24B b c)d e + (96A b c  - 48B b c )d )x
+--R           + 
+--R                  4 2           3         4             2 2        3   2  2
+--R             (3A b e  + (- 36A b c + 12B b )d e + (48A b c  - 24B b c)d )x
+--R        *
+--R            +-------------+         +-------+              +-+
+--R            |           2      - 2d\|e x + d  + (e x + 2d)\|d
+--R           \|- b c e + c d log(-------------------------------)
+--R                                              x
+--R       + 
+--R                      2 2       3              3        2 2    3
+--R             ((- 24A b c  + 6B b c)e + (48A b c  - 24B b c )d)x
+--R           + 
+--R                      3         4           2 2        3     2
+--R             ((- 38A b c + 10B b )e + (72A b c  - 36B b c)d)x
+--R           + 
+--R                     4          3        4           4
+--R             (- 10A b e + (16A b c - 8B b )d)x - 4A b d
+--R        *
+--R            +-------------+
+--R            |           2   +-+ +-------+
+--R           \|- b c e + c d \|d \|e x + d
+--R    /
+--R                                    +-------------+
+--R          5 2 4      6   3     7 2  |           2   +-+
+--R       (8b c x  + 16b c x  + 8b x )\|- b c e + c d \|d
+--R     ,
+--R
+--R                  2 2 2             3        2 2             4          3  2  4
+--R             (3A b c e  + (- 36A b c  + 12B b c )d e + (48A c  - 24B b c )d )x
+--R           + 
+--R                  3   2           2 2        3                3        2 2  2  3
+--R             (6A b c e  + (- 72A b c  + 24B b c)d e + (96A b c  - 48B b c )d )x
+--R           + 
+--R                  4 2           3         4             2 2        3   2  2
+--R             (3A b e  + (- 36A b c + 12B b )d e + (48A b c  - 24B b c)d )x
+--R        *
+--R            +-----------+         +-------+              +-+
+--R            |         2      - 2d\|e x + d  + (e x + 2d)\|d
+--R           \|b c e - c d log(-------------------------------)
+--R                                            x
+--R       + 
+--R                         2 3       3 2  2            4        2 3
+--R                 (- 30A b c  + 6B b c )e  + (120A b c  - 48B b c )d e
+--R               + 
+--R                         5          4  2
+--R                 (- 96A c  + 48B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         3 2        4   2          2 3        3 2
+--R                 (- 60A b c  + 12B b c)e  + (240A b c  - 96B b c )d e
+--R               + 
+--R                            4        2 3  2
+--R                 (- 192A b c  + 96B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4        5  2          3 2        4
+--R                 (- 30A b c + 6B b )e  + (120A b c  - 48B b c)d e
+--R               + 
+--R                         2 3        3 2  2
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                     +-----------+
+--R                     |         2   +-------+
+--R            +-+     \|b c e - c d \|e x + d
+--R           \|d atan(------------------------)
+--R                            b e - c d
+--R       + 
+--R                      2 2       3              3        2 2    3
+--R             ((- 24A b c  + 6B b c)e + (48A b c  - 24B b c )d)x
+--R           + 
+--R                      3         4           2 2        3     2
+--R             ((- 38A b c + 10B b )e + (72A b c  - 36B b c)d)x
+--R           + 
+--R                     4          3        4           4
+--R             (- 10A b e + (16A b c - 8B b )d)x - 4A b d
+--R        *
+--R                +-----------+
+--R            +-+ |         2   +-------+
+--R           \|d \|b c e - c d \|e x + d
+--R    /
+--R                                        +-----------+
+--R          5 2 4      6   3     7 2  +-+ |         2
+--R       (8b c x  + 16b c x  + 8b x )\|d \|b c e - c d
+--R     ,
+--R
+--R                         2 3       3 2  2           4        2 3
+--R                 (- 15A b c  + 3B b c )e  + (60A b c  - 24B b c )d e
+--R               + 
+--R                         5          4  2
+--R                 (- 48A c  + 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         3 2       4   2          2 3        3 2
+--R                 (- 30A b c  + 6B b c)e  + (120A b c  - 48B b c )d e
+--R               + 
+--R                           4        2 3  2
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4        5  2         3 2        4
+--R                 (- 15A b c + 3B b )e  + (60A b c  - 24B b c)d e
+--R               + 
+--R                         2 3        3 2  2
+--R                 (- 48A b c  + 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +---+
+--R           \|- d
+--R        *
+--R                                                              +-------------+
+--R                         2   +-------+                        |           2
+--R             (2b c e - 2c d)\|e x + d  + (c e x - b e + 2c d)\|- b c e + c d
+--R         log(----------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                         2 2 2           3        2 2
+--R                   - 6A b c e  + (72A b c  - 24B b c )d e
+--R                 + 
+--R                           4          3  2
+--R                   (- 96A c  + 48B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        3   2          2 2        3
+--R                 - 12A b c e  + (144A b c  - 48B b c)d e
+--R               + 
+--R                            3        2 2  2
+--R                 (- 192A b c  + 96B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                    4 2         3         4               2 2        3   2  2
+--R             (- 6A b e  + (72A b c - 24B b )d e + (- 96A b c  + 48B b c)d )x
+--R        *
+--R            +-------------+      +---+ +-------+
+--R            |           2       \|- d \|e x + d
+--R           \|- b c e + c d atan(----------------)
+--R                                        d
+--R       + 
+--R                      2 2       3              3        2 2    3
+--R             ((- 24A b c  + 6B b c)e + (48A b c  - 24B b c )d)x
+--R           + 
+--R                      3         4           2 2        3     2
+--R             ((- 38A b c + 10B b )e + (72A b c  - 36B b c)d)x
+--R           + 
+--R                     4          3        4           4
+--R             (- 10A b e + (16A b c - 8B b )d)x - 4A b d
+--R        *
+--R            +-------------+
+--R            |           2   +---+ +-------+
+--R           \|- b c e + c d \|- d \|e x + d
+--R    /
+--R                                    +-------------+
+--R          5 2 4      6   3     7 2  |           2   +---+
+--R       (8b c x  + 16b c x  + 8b x )\|- b c e + c d \|- d
+--R     ,
+--R
+--R                         2 3       3 2  2           4        2 3
+--R                 (- 15A b c  + 3B b c )e  + (60A b c  - 24B b c )d e
+--R               + 
+--R                         5          4  2
+--R                 (- 48A c  + 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         3 2       4   2          2 3        3 2
+--R                 (- 30A b c  + 6B b c)e  + (120A b c  - 48B b c )d e
+--R               + 
+--R                           4        2 3  2
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4        5  2         3 2        4
+--R                 (- 15A b c + 3B b )e  + (60A b c  - 24B b c)d e
+--R               + 
+--R                         2 3        3 2  2
+--R                 (- 48A b c  + 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                       +-----------+
+--R                       |         2   +-------+
+--R            +---+     \|b c e - c d \|e x + d
+--R           \|- d atan(------------------------)
+--R                              b e - c d
+--R       + 
+--R                         2 2 2           3        2 2
+--R                   - 3A b c e  + (36A b c  - 12B b c )d e
+--R                 + 
+--R                           4          3  2
+--R                   (- 48A c  + 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         3   2         2 2        3
+--R                   - 6A b c e  + (72A b c  - 24B b c)d e
+--R                 + 
+--R                             3        2 2  2
+--R                   (- 96A b c  + 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                    4 2         3         4               2 2        3   2  2
+--R             (- 3A b e  + (36A b c - 12B b )d e + (- 48A b c  + 24B b c)d )x
+--R        *
+--R            +-----------+      +---+ +-------+
+--R            |         2       \|- d \|e x + d
+--R           \|b c e - c d atan(----------------)
+--R                                      d
+--R       + 
+--R                      2 2       3              3        2 2    3
+--R             ((- 12A b c  + 3B b c)e + (24A b c  - 12B b c )d)x
+--R           + 
+--R                      3        4           2 2        3     2
+--R             ((- 19A b c + 5B b )e + (36A b c  - 18B b c)d)x
+--R           + 
+--R                    4         3        4           4
+--R             (- 5A b e + (8A b c - 4B b )d)x - 2A b d
+--R        *
+--R                  +-----------+
+--R            +---+ |         2   +-------+
+--R           \|- d \|b c e - c d \|e x + d
+--R    /
+--R                                         +-----------+
+--R          5 2 4     6   3     7 2  +---+ |         2
+--R       (4b c x  + 8b c x  + 4b x )\|- d \|b c e - c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 849
+
+--S 850 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                   2        3  2           2        2
+--R           (- 15A b c + 3B b )e  + (60A b c  - 24B b c)d e
+--R         + 
+--R                   3          2  2
+--R           (- 48A c  + 24B b c )d
+--R      *
+--R          +-----------+ +-+ +-+
+--R         \|- b e + c d \|c \|d
+--R      *
+--R                                                              +-------------+
+--R                         2   +-------+                        |           2
+--R             (2b c e - 2c d)\|e x + d  + (c e x - b e + 2c d)\|- b c e + c d
+--R         log(----------------------------------------------------------------)
+--R                                          c x + b
+--R     + 
+--R              2 2                     2             2            2
+--R         (3A b e  + (- 36A b c + 12B b )d e + (48A c  - 24B b c)d )
+--R      *
+--R          +-------------+                           +-------+              +-+
+--R          |           2   +-----------+ +-+    - 2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b c e + c d \|- b e + c d \|c log(-------------------------------)
+--R                                                              x
+--R     + 
+--R                   2        3  2            2        2
+--R           (- 30A b c + 6B b )e  + (120A b c  - 48B b c)d e
+--R         + 
+--R                   3          2  2
+--R           (- 96A c  + 48B b c )d
+--R      *
+--R          +-------------+           +-+ +-------+
+--R          |           2   +-+      \|c \|e x + d
+--R         \|- b c e + c d \|d atanh(--------------)
+--R                                    +-----------+
+--R                                   \|- b e + c d
+--R     + 
+--R              2 2                     2             2            2
+--R         (6A b e  + (- 72A b c + 24B b )d e + (96A c  - 48B b c)d )
+--R      *
+--R          +-------------+                         +-------+
+--R          |           2   +-----------+ +-+      \|e x + d
+--R         \|- b c e + c d \|- b e + c d \|c atanh(----------)
+--R                                                     +-+
+--R                                                    \|d
+--R  /
+--R         +-------------+
+--R       5 |           2   +-----------+ +-+ +-+
+--R     8b \|- b c e + c d \|- b e + c d \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 850
+
+--S 851 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              2 2                     2             2            2
+--R         (3A b e  + (- 36A b c + 12B b )d e + (48A c  - 24B b c)d )
+--R      *
+--R                            +-----------+         +-------+              +-+
+--R          +-----------+ +-+ |         2      - 2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d \|c \|b c e - c d log(-------------------------------)
+--R                                                            x
+--R     + 
+--R                   2        3  2            2        2
+--R           (- 30A b c + 6B b )e  + (120A b c  - 48B b c)d e
+--R         + 
+--R                   3          2  2
+--R           (- 96A c  + 48B b c )d
+--R      *
+--R              +-----------+       +-+ +-------+
+--R          +-+ |         2        \|c \|e x + d
+--R         \|d \|b c e - c d atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- b e + c d
+--R     + 
+--R              2 2                     2             2            2
+--R         (6A b e  + (- 72A b c + 24B b )d e + (96A c  - 48B b c)d )
+--R      *
+--R                            +-----------+       +-------+
+--R          +-----------+ +-+ |         2        \|e x + d
+--R         \|- b e + c d \|c \|b c e - c d atanh(----------)
+--R                                                   +-+
+--R                                                  \|d
+--R     + 
+--R                   2        3  2            2        2
+--R           (- 30A b c + 6B b )e  + (120A b c  - 48B b c)d e
+--R         + 
+--R                   3          2  2
+--R           (- 96A c  + 48B b c )d
+--R      *
+--R                                     +-----------+
+--R                                     |         2   +-------+
+--R          +-----------+ +-+ +-+     \|b c e - c d \|e x + d
+--R         \|- b e + c d \|c \|d atan(------------------------)
+--R                                            b e - c d
+--R  /
+--R                               +-----------+
+--R       5 +-----------+ +-+ +-+ |         2
+--R     8b \|- b e + c d \|c \|d \|b c e - c d
+--R                                                    Type: Expression(Integer)
+--E 852
+
+--S 853 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 853
+
+)clear all
+
+--S 854 of 1457
+t0:=(A+B*x)*sqrt(d+e*x)/(b*x+c*x^2)^3
+--R 
+--R
+--R                        +-------+
+--R              (B x + A)\|e x + d
+--R   (1)  -------------------------------
+--R         3 6       2 5     2   4    3 3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 854
+
+--S 855 of 1457
+r0:=-1/4*(48*A*c^2*d^2+b^2*e*(4*B*d-A*e)-12*b*c*d*(2*B*d+A*e))*_
+     atanh(sqrt(d+e*x)/sqrt(d))/(b^5*d^(3/2))+1/4*(48*A*c^3*d^2-_
+     15*b^3*B*e^2-12*b*c^2*d*(2*B*d+7*A*e)+5*b^2*c*e*(8*B*d+7*A*e))*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))*sqrt(c)/(b^5*_
+     (c*d-b*e)^(3/2))-1/4*c*(6*b*B*d-12*A*c*d+A*b*e)*sqrt(d+e*x)/_
+     (b^3*d*(b+c*x)^2)-1/2*A*sqrt(d+e*x)/(b*x^2*(b+c*x)^2)-_
+     1/4*(4*b*B*d-8*A*c*d+A*b*e)*sqrt(d+e*x)/(b^2*d*x*(b+c*x)^2)+_
+     1/4*c*(24*A*c^2*d^2+b^2*e*(11*B*d+A*e)-12*b*c*d*(B*d+2*A*e))*_
+     sqrt(d+e*x)/(b^4*d*(c*d-b*e)*(b+c*x))
+--R 
+--R
+--R   (2)
+--R                       2 3        3 2    2           4        2 3  2
+--R               (- 35A b c  + 15B b c )d e  + (84A b c  - 40B b c )d e
+--R             + 
+--R                       5          4  3
+--R               (- 48A c  + 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       3 2        4     2          2 3        3 2  2
+--R               (- 70A b c  + 30B b c)d e  + (168A b c  - 80B b c )d e
+--R             + 
+--R                         4        2 3  3
+--R               (- 96A b c  + 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       4         5    2         3 2        4   2
+--R               (- 35A b c + 15B b )d e  + (84A b c  - 40B b c)d e
+--R             + 
+--R                       2 3        3 2  3
+--R               (- 48A b c  + 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                        +-+ +-------+
+--R          +-+ +-+      \|c \|e x + d
+--R         \|c \|d atanh(--------------)
+--R                        +-----------+
+--R                       \|- b e + c d
+--R     + 
+--R                  3 2 3         2 3       3 2    2             4        2 3  2
+--R               A b c e  + (11A b c  - 4B b c )d e  + (- 60A b c  + 28B b c )d e
+--R             + 
+--R                     5          4  3
+--R               (48A c  - 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   4   3         3 2       4     2            2 3        3 2  2
+--R               2A b c e  + (22A b c  - 8B b c)d e  + (- 120A b c  + 56B b c )d e
+--R             + 
+--R                       4        2 3  3
+--R               (96A b c  - 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  5 3         4        5    2           3 2        4   2
+--R               A b e  + (11A b c - 4B b )d e  + (- 60A b c  + 28B b c)d e
+--R             + 
+--R                     2 3        3 2  3
+--R               (48A b c  - 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R     + 
+--R                 3 2 2         2 3        3 2                 4        2 3  2  3
+--R           (- A b c e  + (24A b c  - 11B b c )d e + (- 24A b c  + 12B b c )d )x
+--R         + 
+--R                  4   2         3 2        4                2 3        3 2  2  2
+--R           (- 2A b c e  + (37A b c  - 17B b c)d e + (- 36A b c  + 18B b c )d )x
+--R         + 
+--R                 5 2        4        5              3 2       4   2         5
+--R           (- A b e  + (9A b c - 4B b )d e + (- 8A b c  + 4B b c)d )x - 2A b d e
+--R         + 
+--R               4   2
+--R           2A b c d
+--R      *
+--R          +-----------+ +-+ +-------+
+--R         \|- b e + c d \|d \|e x + d
+--R  /
+--R           6 2        5 3 2  4      7          6 2 2  3      8        7   2  2
+--R       ((4b c d e - 4b c d )x  + (8b c d e - 8b c d )x  + (4b d e - 4b c d )x )
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 855
+
+--S 856 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       2 3        3 2    2             4        2 3  2
+--R                 (35A b c  - 15B b c )d e  + (- 84A b c  + 40B b c )d e
+--R               + 
+--R                       5          4  3
+--R                 (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       3 2        4     2            2 3        3 2  2
+--R                 (70A b c  - 30B b c)d e  + (- 168A b c  + 80B b c )d e
+--R               + 
+--R                         4        2 3  3
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4         5    2           3 2        4   2
+--R                 (35A b c - 15B b )d e  + (- 84A b c  + 40B b c)d e
+--R               + 
+--R                       2 3        3 2  3
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +-----------+
+--R            |      c      +-+
+--R            |- --------- \|d
+--R           \|  b e - c d
+--R        *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R               (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R           log(----------------------------------------------------------)
+--R                                         c x + b
+--R       + 
+--R                    3 2 3         2 3       3 2    2
+--R                 A b c e  + (11A b c  - 4B b c )d e
+--R               + 
+--R                           4        2 3  2          5          4  3
+--R                 (- 60A b c  + 28B b c )d e + (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                     4   3         3 2       4     2
+--R                 2A b c e  + (22A b c  - 8B b c)d e
+--R               + 
+--R                          2 3        3 2  2            4        2 3  3
+--R                 (- 120A b c  + 56B b c )d e + (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                    5 3         4        5    2           3 2        4   2
+--R                 A b e  + (11A b c - 4B b )d e  + (- 60A b c  + 28B b c)d e
+--R               + 
+--R                       2 3        3 2  3
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                  +-------+              +-+
+--R               2d\|e x + d  + (e x + 2d)\|d
+--R           log(-----------------------------)
+--R                             x
+--R       + 
+--R                       3 2 2         2 3        3 2
+--R                 - 2A b c e  + (48A b c  - 22B b c )d e
+--R               + 
+--R                           4        2 3  2
+--R                 (- 48A b c  + 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4   2         3 2        4
+--R                   - 4A b c e  + (74A b c  - 34B b c)d e
+--R                 + 
+--R                           2 3        3 2  2
+--R                   (- 72A b c  + 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    5 2         4        5               3 2       4   2
+--R             (- 2A b e  + (18A b c - 8B b )d e + (- 16A b c  + 8B b c)d )x
+--R           + 
+--R                   5          4   2
+--R             - 4A b d e + 4A b c d
+--R        *
+--R            +-+ +-------+
+--R           \|d \|e x + d
+--R    /
+--R              6 2        5 3 2  4       7           6 2 2  3
+--R           (8b c d e - 8b c d )x  + (16b c d e - 16b c d )x
+--R         + 
+--R              8        7   2  2
+--R           (8b d e - 8b c d )x
+--R      *
+--R          +-+
+--R         \|d
+--R     ,
+--R
+--R                    3 2 3         2 3       3 2    2
+--R                 A b c e  + (11A b c  - 4B b c )d e
+--R               + 
+--R                           4        2 3  2          5          4  3
+--R                 (- 60A b c  + 28B b c )d e + (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                     4   3         3 2       4     2
+--R                 2A b c e  + (22A b c  - 8B b c)d e
+--R               + 
+--R                          2 3        3 2  2            4        2 3  3
+--R                 (- 120A b c  + 56B b c )d e + (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                    5 3         4        5    2           3 2        4   2
+--R                 A b e  + (11A b c - 4B b )d e  + (- 60A b c  + 28B b c)d e
+--R               + 
+--R                       2 3        3 2  3
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                  +-------+              +-+
+--R               2d\|e x + d  + (e x + 2d)\|d
+--R           log(-----------------------------)
+--R                             x
+--R       + 
+--R                       2 3        3 2    2              4        2 3  2
+--R                 (70A b c  - 30B b c )d e  + (- 168A b c  + 80B b c )d e
+--R               + 
+--R                       5          4  3
+--R                 (96A c  - 48B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        3 2        4     2            2 3         3 2  2
+--R                 (140A b c  - 60B b c)d e  + (- 336A b c  + 160B b c )d e
+--R               + 
+--R                          4        2 3  3
+--R                 (192A b c  - 96B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4         5    2            3 2        4   2
+--R                 (70A b c - 30B b )d e  + (- 168A b c  + 80B b c)d e
+--R               + 
+--R                       2 3        3 2  3
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +---------+                 +-------+
+--R            |    c      +-+           c\|e x + d
+--R            |--------- \|d atan(-----------------------)
+--R           \|b e - c d                      +---------+
+--R                                            |    c
+--R                                (b e - c d) |---------
+--R                                           \|b e - c d
+--R       + 
+--R                       3 2 2         2 3        3 2
+--R                 - 2A b c e  + (48A b c  - 22B b c )d e
+--R               + 
+--R                           4        2 3  2
+--R                 (- 48A b c  + 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4   2         3 2        4
+--R                   - 4A b c e  + (74A b c  - 34B b c)d e
+--R                 + 
+--R                           2 3        3 2  2
+--R                   (- 72A b c  + 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    5 2         4        5               3 2       4   2
+--R             (- 2A b e  + (18A b c - 8B b )d e + (- 16A b c  + 8B b c)d )x
+--R           + 
+--R                   5          4   2
+--R             - 4A b d e + 4A b c d
+--R        *
+--R            +-+ +-------+
+--R           \|d \|e x + d
+--R    /
+--R              6 2        5 3 2  4       7           6 2 2  3
+--R           (8b c d e - 8b c d )x  + (16b c d e - 16b c d )x
+--R         + 
+--R              8        7   2  2
+--R           (8b d e - 8b c d )x
+--R      *
+--R          +-+
+--R         \|d
+--R     ,
+--R
+--R                       2 3        3 2    2             4        2 3  2
+--R                 (35A b c  - 15B b c )d e  + (- 84A b c  + 40B b c )d e
+--R               + 
+--R                       5          4  3
+--R                 (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       3 2        4     2            2 3        3 2  2
+--R                 (70A b c  - 30B b c)d e  + (- 168A b c  + 80B b c )d e
+--R               + 
+--R                         4        2 3  3
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4         5    2           3 2        4   2
+--R                 (35A b c - 15B b )d e  + (- 84A b c  + 40B b c)d e
+--R               + 
+--R                       2 3        3 2  3
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                  +-----------+
+--R            +---+ |      c
+--R           \|- d  |- ---------
+--R                 \|  b e - c d
+--R        *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R               (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R           log(----------------------------------------------------------)
+--R                                         c x + b
+--R       + 
+--R                     3 2 3         2 3       3 2    2
+--R                 2A b c e  + (22A b c  - 8B b c )d e
+--R               + 
+--R                            4        2 3  2          5          4  3
+--R                 (- 120A b c  + 56B b c )d e + (96A c  - 48B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                     4   3         3 2        4     2
+--R                 4A b c e  + (44A b c  - 16B b c)d e
+--R               + 
+--R                          2 3         3 2  2             4        2 3  3
+--R                 (- 240A b c  + 112B b c )d e + (192A b c  - 96B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     5 3         4        5    2            3 2        4   2
+--R                 2A b e  + (22A b c - 8B b )d e  + (- 120A b c  + 56B b c)d e
+--R               + 
+--R                       2 3        3 2  3
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                 +---+ +-------+
+--R                \|- d \|e x + d
+--R           atan(----------------)
+--R                        d
+--R       + 
+--R                       3 2 2         2 3        3 2
+--R                 - 2A b c e  + (48A b c  - 22B b c )d e
+--R               + 
+--R                           4        2 3  2
+--R                 (- 48A b c  + 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4   2         3 2        4
+--R                   - 4A b c e  + (74A b c  - 34B b c)d e
+--R                 + 
+--R                           2 3        3 2  2
+--R                   (- 72A b c  + 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    5 2         4        5               3 2       4   2
+--R             (- 2A b e  + (18A b c - 8B b )d e + (- 16A b c  + 8B b c)d )x
+--R           + 
+--R                   5          4   2
+--R             - 4A b d e + 4A b c d
+--R        *
+--R            +---+ +-------+
+--R           \|- d \|e x + d
+--R    /
+--R              6 2        5 3 2  4       7           6 2 2  3
+--R           (8b c d e - 8b c d )x  + (16b c d e - 16b c d )x
+--R         + 
+--R              8        7   2  2
+--R           (8b d e - 8b c d )x
+--R      *
+--R          +---+
+--R         \|- d
+--R     ,
+--R
+--R                    3 2 3         2 3       3 2    2
+--R                 A b c e  + (11A b c  - 4B b c )d e
+--R               + 
+--R                           4        2 3  2          5          4  3
+--R                 (- 60A b c  + 28B b c )d e + (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                     4   3         3 2       4     2
+--R                 2A b c e  + (22A b c  - 8B b c)d e
+--R               + 
+--R                          2 3        3 2  2            4        2 3  3
+--R                 (- 120A b c  + 56B b c )d e + (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                    5 3         4        5    2           3 2        4   2
+--R                 A b e  + (11A b c - 4B b )d e  + (- 60A b c  + 28B b c)d e
+--R               + 
+--R                       2 3        3 2  3
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                 +---+ +-------+
+--R                \|- d \|e x + d
+--R           atan(----------------)
+--R                        d
+--R       + 
+--R                       2 3        3 2    2             4        2 3  2
+--R                 (35A b c  - 15B b c )d e  + (- 84A b c  + 40B b c )d e
+--R               + 
+--R                       5          4  3
+--R                 (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       3 2        4     2            2 3        3 2  2
+--R                 (70A b c  - 30B b c)d e  + (- 168A b c  + 80B b c )d e
+--R               + 
+--R                         4        2 3  3
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4         5    2           3 2        4   2
+--R                 (35A b c - 15B b )d e  + (- 84A b c  + 40B b c)d e
+--R               + 
+--R                       2 3        3 2  3
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                  +---------+             +-------+
+--R            +---+ |    c                c\|e x + d
+--R           \|- d  |--------- atan(-----------------------)
+--R                 \|b e - c d                  +---------+
+--R                                              |    c
+--R                                  (b e - c d) |---------
+--R                                             \|b e - c d
+--R       + 
+--R                        3 2 2         2 3        3 2
+--R                   - A b c e  + (24A b c  - 11B b c )d e
+--R                 + 
+--R                             4        2 3  2
+--R                   (- 24A b c  + 12B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4   2         3 2        4
+--R                   - 2A b c e  + (37A b c  - 17B b c)d e
+--R                 + 
+--R                           2 3        3 2  2
+--R                   (- 36A b c  + 18B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                   5 2        4        5              3 2       4   2
+--R             (- A b e  + (9A b c - 4B b )d e + (- 8A b c  + 4B b c)d )x
+--R           + 
+--R                   5          4   2
+--R             - 2A b d e + 2A b c d
+--R        *
+--R            +---+ +-------+
+--R           \|- d \|e x + d
+--R    /
+--R                6 2        5 3 2  4      7          6 2 2  3
+--R             (4b c d e - 4b c d )x  + (8b c d e - 8b c d )x
+--R           + 
+--R                8        7   2  2
+--R             (4b d e - 4b c d )x
+--R      *
+--R          +---+
+--R         \|- d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 856
+
+--S 857 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 2         3    2             2        2   2
+--R           (35A b c - 15B b )d e  + (- 84A b c  + 40B b c)d e
+--R         + 
+--R                 3          2  3
+--R           (48A c  - 24B b c )d
+--R      *
+--R                        +-----------+
+--R          +-----------+ |      c      +-+
+--R         \|- b e + c d  |- --------- \|d
+--R                       \|  b e - c d
+--R      *
+--R                           +-----------+
+--R                           |      c      +-------+
+--R             (2b e - 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                          \|  b e - c d
+--R         log(----------------------------------------------------------)
+--R                                       c x + b
+--R     + 
+--R              3 3         2        3    2             2        2   2
+--R           A b e  + (11A b c - 4B b )d e  + (- 60A b c  + 28B b c)d e
+--R         + 
+--R                 3          2  3
+--R           (48A c  - 24B b c )d
+--R      *
+--R                              +-------+              +-+
+--R          +-----------+    2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-----------------------------)
+--R                                         x
+--R     + 
+--R                 2         3    2              2        2   2
+--R           (70A b c - 30B b )d e  + (- 168A b c  + 80B b c)d e
+--R         + 
+--R                 3          2  3
+--R           (96A c  - 48B b c )d
+--R      *
+--R                        +-+ +-------+
+--R          +-+ +-+      \|c \|e x + d
+--R         \|c \|d atanh(--------------)
+--R                        +-----------+
+--R                       \|- b e + c d
+--R     + 
+--R                 3 3           2        3    2            2        2   2
+--R           - 2A b e  + (- 22A b c + 8B b )d e  + (120A b c  - 56B b c)d e
+--R         + 
+--R                   3          2  3
+--R           (- 96A c  + 48B b c )d
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R  /
+--R        6        5   2  +-----------+ +-+
+--R     (8b d e - 8b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 858
+
+--S 859 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              3 3         2        3    2             2        2   2
+--R           A b e  + (11A b c - 4B b )d e  + (- 60A b c  + 28B b c)d e
+--R         + 
+--R                 3          2  3
+--R           (48A c  - 24B b c )d
+--R      *
+--R                              +-------+              +-+
+--R          +-----------+    2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-----------------------------)
+--R                                         x
+--R     + 
+--R                 2         3    2              2        2   2
+--R           (70A b c - 30B b )d e  + (- 168A b c  + 80B b c)d e
+--R         + 
+--R                 3          2  3
+--R           (96A c  - 48B b c )d
+--R      *
+--R                        +-+ +-------+
+--R          +-+ +-+      \|c \|e x + d
+--R         \|c \|d atanh(--------------)
+--R                        +-----------+
+--R                       \|- b e + c d
+--R     + 
+--R                 3 3           2        3    2            2        2   2
+--R           - 2A b e  + (- 22A b c + 8B b )d e  + (120A b c  - 56B b c)d e
+--R         + 
+--R                   3          2  3
+--R           (- 96A c  + 48B b c )d
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R     + 
+--R                 2         3    2              2        2   2
+--R           (70A b c - 30B b )d e  + (- 168A b c  + 80B b c)d e
+--R         + 
+--R                 3          2  3
+--R           (96A c  - 48B b c )d
+--R      *
+--R                        +---------+                 +-------+
+--R          +-----------+ |    c      +-+           c\|e x + d
+--R         \|- b e + c d  |--------- \|d atan(-----------------------)
+--R                       \|b e - c d                      +---------+
+--R                                                        |    c
+--R                                            (b e - c d) |---------
+--R                                                       \|b e - c d
+--R  /
+--R        6        5   2  +-----------+ +-+
+--R     (8b d e - 8b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 859
+
+--S 860 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 860
+
+)clear all
+
+--S 861 of 1457
+t0:=(A+B*x)/((b*x+c*x^2)^3*sqrt(d+e*x))
+--R 
+--R
+--R                          B x + A
+--R   (1)  -------------------------------------------
+--R          3 6       2 5     2   4    3 3  +-------+
+--R        (c x  + 3b c x  + 3b c x  + b x )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 861
+
+--S 862 of 1457
+r0:=-1/4*(48*A*c^2*d^2-b^2*e*(4*B*d-3*A*e)-12*b*c*d*(2*B*d-A*e))*_
+     atanh(sqrt(d+e*x)/sqrt(d))/(b^5*d^(5/2))+1/4*c^(3/2)*_
+     (48*A*c^3*d^2-35*b^3*B*e^2-12*b*c^2*d*(2*B*d+9*A*e)+7*b^2*c*e*_
+     (8*B*d+9*A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^5*_
+     (c*d-b*e)^(5/2))+1/4*c*(12*A*c^2*d^2+b^2*e*(4*B*d-3*A*e)-b*c*d*_
+     (6*B*d+7*A*e))*sqrt(d+e*x)/(b^3*d^2*(c*d-b*e)*(b+c*x)^2)-1/2*A*_
+     sqrt(d+e*x)/(b*d*x^2*(b+c*x)^2)-1/4*(4*b*B*d-8*A*c*d-3*A*b*e)*_
+     sqrt(d+e*x)/(b^2*d^2*x*(b+c*x)^2)+1/4*c*(24*A*c^3*d^3-b^3*e^2*_
+     (4*B*d-3*A*e)-12*b*c^2*d^2*(B*d+3*A*e)+b^2*c*d*e*(19*B*d+6*A*e))*_
+     sqrt(d+e*x)/(b^4*d^2*(c*d-b*e)^2*(b+c*x))
+--R 
+--R
+--R   (2)
+--R                     2 4        3 3  2 2              5        2 4  3
+--R               (63A b c  - 35B b c )d e  + (- 108A b c  + 56B b c )d e
+--R             + 
+--R                     6          5  4
+--R               (48A c  - 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      3 3        4 2  2 2            2 4         3 3  3
+--R               (126A b c  - 70B b c )d e  + (- 216A b c  + 112B b c )d e
+--R             + 
+--R                       5        2 4  4
+--R               (96A b c  - 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     4 2        5   2 2            3 3        4 2  3
+--R               (63A b c  - 35B b c)d e  + (- 108A b c  + 56B b c )d e
+--R             + 
+--R                     2 4        3 3  4
+--R               (48A b c  - 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                        +-+ +-------+
+--R          +-+ +-+      \|c \|e x + d
+--R         \|c \|d atanh(--------------)
+--R                        +-----------+
+--R                       \|- b e + c d
+--R     + 
+--R                     4 2 4          3 3       4 2    3
+--R               - 3A b c e  + (- 6A b c  + 4B b c )d e
+--R             + 
+--R                       2 4        3 3  2 2           5        2 4  3
+--R               (- 27A b c  + 16B b c )d e  + (84A b c  - 44B b c )d e
+--R             + 
+--R                       6          5  4
+--R               (- 48A c  + 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     5   4           4 2       5     3
+--R               - 6A b c e  + (- 12A b c  + 8B b c)d e
+--R             + 
+--R                       3 3        4 2  2 2          2 4        3 3  3
+--R               (- 54A b c  + 32B b c )d e  + (168A b c  - 88B b c )d e
+--R             + 
+--R                         5        2 4  4
+--R               (- 96A b c  + 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     6 4          5        6    3           4 2        5   2 2
+--R               - 3A b e  + (- 6A b c + 4B b )d e  + (- 27A b c  + 16B b c)d e
+--R             + 
+--R                     3 3        4 2  3            2 4        3 3  4
+--R               (84A b c  - 44B b c )d e + (- 48A b c  + 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R     + 
+--R                   4 2 3        3 3       4 2    2           2 4        3 3  2
+--R               3A b c e  + (6A b c  - 4B b c )d e  + (- 36A b c  + 19B b c )d e
+--R             + 
+--R                       5        2 4  3
+--R               (24A b c  - 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   5   3         4 2       5     2           3 3        4 2  2
+--R               6A b c e  + (10A b c  - 8B b c)d e  + (- 55A b c  + 29B b c )d e
+--R             + 
+--R                     2 4        3 3  3
+--R               (36A b c  - 18B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   6 3        5        6    2           4 2       5   2
+--R               3A b e  + (2A b c - 4B b )d e  + (- 13A b c  + 8B b c)d e
+--R             + 
+--R                    3 3       4 2  3
+--R               (8A b c  - 4B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 6   2       5   2        4 2 3
+--R           - 2A b d e  + 4A b c d e - 2A b c d
+--R      *
+--R          +-----------+ +-+ +-------+
+--R         \|- b e + c d \|d \|e x + d
+--R  /
+--R            7 2 2 2     6 3 3      5 4 4  4
+--R         (4b c d e  - 8b c d e + 4b c d )x
+--R       + 
+--R            8   2 2      7 2 3      6 3 4  3      9 2 2     8   3      7 2 4  2
+--R         (8b c d e  - 16b c d e + 8b c d )x  + (4b d e  - 8b c d e + 4b c d )x
+--R    *
+--R        +-----------+ +-+
+--R       \|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 862
+
+--S 863 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     4 2 4        3 3       4 2    3         2 4        3 3  2 2
+--R                 3A b c e  + (6A b c  - 4B b c )d e  + (27A b c  - 16B b c )d e
+--R               + 
+--R                           5        2 4  3          6          5  4
+--R                 (- 84A b c  + 44B b c )d e + (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                     5   4         4 2       5     3         3 3        4 2  2 2
+--R                 6A b c e  + (12A b c  - 8B b c)d e  + (54A b c  - 32B b c )d e
+--R               + 
+--R                          2 4        3 3  3            5        2 4  4
+--R                 (- 168A b c  + 88B b c )d e + (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     6 4        5        6    3         4 2        5   2 2
+--R                 3A b e  + (6A b c - 4B b )d e  + (27A b c  - 16B b c)d e
+--R               + 
+--R                         3 3        4 2  3          2 4        3 3  4
+--R                 (- 84A b c  + 44B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                    +-------+              +-+
+--R               - 2d\|e x + d  + (e x + 2d)\|d
+--R           log(-------------------------------)
+--R                              x
+--R       + 
+--R                       2 4        3 3  2 2              5        2 4  3
+--R                 (63A b c  - 35B b c )d e  + (- 108A b c  + 56B b c )d e
+--R               + 
+--R                       6          5  4
+--R                 (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        3 3        4 2  2 2            2 4         3 3  3
+--R                 (126A b c  - 70B b c )d e  + (- 216A b c  + 112B b c )d e
+--R               + 
+--R                         5        2 4  4
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4 2        5   2 2            3 3        4 2  3
+--R                 (63A b c  - 35B b c)d e  + (- 108A b c  + 56B b c )d e
+--R               + 
+--R                       2 4        3 3  4
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +-----------+
+--R            |      c      +-+
+--R            |- --------- \|d
+--R           \|  b e - c d
+--R        *
+--R                               +-----------+
+--R                               |      c      +-------+
+--R               (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                              \|  b e - c d
+--R           log(------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                     4 2 3         3 3       4 2    2
+--R                 6A b c e  + (12A b c  - 8B b c )d e
+--R               + 
+--R                         2 4        3 3  2            5        2 4  3
+--R                 (- 72A b c  + 38B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      5   3         4 2        5     2
+--R                 12A b c e  + (20A b c  - 16B b c)d e
+--R               + 
+--R                          3 3        4 2  2          2 4        3 3  3
+--R                 (- 110A b c  + 58B b c )d e + (72A b c  - 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     6 3        5        6    2           4 2        5   2
+--R                 6A b e  + (4A b c - 8B b )d e  + (- 26A b c  + 16B b c)d e
+--R               + 
+--R                       3 3       4 2  3
+--R                 (16A b c  - 8B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   6   2       5   2        4 2 3
+--R             - 4A b d e  + 8A b c d e - 4A b c d
+--R        *
+--R            +-+ +-------+
+--R           \|d \|e x + d
+--R    /
+--R              7 2 2 2      6 3 3      5 4 4  4
+--R           (8b c d e  - 16b c d e + 8b c d )x
+--R         + 
+--R               8   2 2      7 2 3       6 3 4  3
+--R           (16b c d e  - 32b c d e + 16b c d )x
+--R         + 
+--R              9 2 2      8   3      7 2 4  2
+--R           (8b d e  - 16b c d e + 8b c d )x
+--R      *
+--R          +-+
+--R         \|d
+--R     ,
+--R
+--R                     4 2 4        3 3       4 2    3         2 4        3 3  2 2
+--R                 3A b c e  + (6A b c  - 4B b c )d e  + (27A b c  - 16B b c )d e
+--R               + 
+--R                           5        2 4  3          6          5  4
+--R                 (- 84A b c  + 44B b c )d e + (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                     5   4         4 2       5     3         3 3        4 2  2 2
+--R                 6A b c e  + (12A b c  - 8B b c)d e  + (54A b c  - 32B b c )d e
+--R               + 
+--R                          2 4        3 3  3            5        2 4  4
+--R                 (- 168A b c  + 88B b c )d e + (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     6 4        5        6    3         4 2        5   2 2
+--R                 3A b e  + (6A b c - 4B b )d e  + (27A b c  - 16B b c)d e
+--R               + 
+--R                         3 3        4 2  3          2 4        3 3  4
+--R                 (- 84A b c  + 44B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                    +-------+              +-+
+--R               - 2d\|e x + d  + (e x + 2d)\|d
+--R           log(-------------------------------)
+--R                              x
+--R       + 
+--R                          2 4        3 3  2 2            5         2 4  3
+--R                 (- 126A b c  + 70B b c )d e  + (216A b c  - 112B b c )d e
+--R               + 
+--R                         6          5  4
+--R                 (- 96A c  + 48B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          3 3         4 2  2 2          2 4         3 3  3
+--R                 (- 252A b c  + 140B b c )d e  + (432A b c  - 224B b c )d e
+--R               + 
+--R                            5        2 4  4
+--R                 (- 192A b c  + 96B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                          4 2        5   2 2          3 3         4 2  3
+--R                 (- 126A b c  + 70B b c)d e  + (216A b c  - 112B b c )d e
+--R               + 
+--R                         2 4        3 3  4
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R            +---------+                 +-------+
+--R            |    c      +-+           c\|e x + d
+--R            |--------- \|d atan(-----------------------)
+--R           \|b e - c d                      +---------+
+--R                                            |    c
+--R                                (b e - c d) |---------
+--R                                           \|b e - c d
+--R       + 
+--R                     4 2 3         3 3       4 2    2
+--R                 6A b c e  + (12A b c  - 8B b c )d e
+--R               + 
+--R                         2 4        3 3  2            5        2 4  3
+--R                 (- 72A b c  + 38B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      5   3         4 2        5     2
+--R                 12A b c e  + (20A b c  - 16B b c)d e
+--R               + 
+--R                          3 3        4 2  2          2 4        3 3  3
+--R                 (- 110A b c  + 58B b c )d e + (72A b c  - 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     6 3        5        6    2           4 2        5   2
+--R                 6A b e  + (4A b c - 8B b )d e  + (- 26A b c  + 16B b c)d e
+--R               + 
+--R                       3 3       4 2  3
+--R                 (16A b c  - 8B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   6   2       5   2        4 2 3
+--R             - 4A b d e  + 8A b c d e - 4A b c d
+--R        *
+--R            +-+ +-------+
+--R           \|d \|e x + d
+--R    /
+--R              7 2 2 2      6 3 3      5 4 4  4
+--R           (8b c d e  - 16b c d e + 8b c d )x
+--R         + 
+--R               8   2 2      7 2 3       6 3 4  3
+--R           (16b c d e  - 32b c d e + 16b c d )x
+--R         + 
+--R              9 2 2      8   3      7 2 4  2
+--R           (8b d e  - 16b c d e + 8b c d )x
+--R      *
+--R          +-+
+--R         \|d
+--R     ,
+--R
+--R                       2 4        3 3  2 2              5        2 4  3
+--R                 (63A b c  - 35B b c )d e  + (- 108A b c  + 56B b c )d e
+--R               + 
+--R                       6          5  4
+--R                 (48A c  - 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        3 3        4 2  2 2            2 4         3 3  3
+--R                 (126A b c  - 70B b c )d e  + (- 216A b c  + 112B b c )d e
+--R               + 
+--R                         5        2 4  4
+--R                 (96A b c  - 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       4 2        5   2 2            3 3        4 2  3
+--R                 (63A b c  - 35B b c)d e  + (- 108A b c  + 56B b c )d e
+--R               + 
+--R                       2 4        3 3  4
+--R                 (48A b c  - 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                  +-----------+
+--R            +---+ |      c
+--R           \|- d  |- ---------
+--R                 \|  b e - c d
+--R        *
+--R                               +-----------+
+--R                               |      c      +-------+
+--R               (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                              \|  b e - c d
+--R           log(------------------------------------------------------------)
+--R                                          c x + b
+--R       + 
+--R                       4 2 4           3 3       4 2    3
+--R                 - 6A b c e  + (- 12A b c  + 8B b c )d e
+--R               + 
+--R                         2 4        3 3  2 2            5        2 4  3
+--R                 (- 54A b c  + 32B b c )d e  + (168A b c  - 88B b c )d e
+--R               + 
+--R                         6          5  4
+--R                 (- 96A c  + 48B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        5   4           4 2        5     3
+--R                 - 12A b c e  + (- 24A b c  + 16B b c)d e
+--R               + 
+--R                          3 3        4 2  2 2          2 4         3 3  3
+--R                 (- 108A b c  + 64B b c )d e  + (336A b c  - 176B b c )d e
+--R               + 
+--R                            5        2 4  4
+--R                 (- 192A b c  + 96B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       6 4           5        6    3
+--R                 - 6A b e  + (- 12A b c + 8B b )d e
+--R               + 
+--R                         4 2        5   2 2          3 3        4 2  3
+--R                 (- 54A b c  + 32B b c)d e  + (168A b c  - 88B b c )d e
+--R               + 
+--R                         2 4        3 3  4
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                 +---+ +-------+
+--R                \|- d \|e x + d
+--R           atan(----------------)
+--R                        d
+--R       + 
+--R                     4 2 3         3 3       4 2    2
+--R                 6A b c e  + (12A b c  - 8B b c )d e
+--R               + 
+--R                         2 4        3 3  2            5        2 4  3
+--R                 (- 72A b c  + 38B b c )d e + (48A b c  - 24B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      5   3         4 2        5     2
+--R                 12A b c e  + (20A b c  - 16B b c)d e
+--R               + 
+--R                          3 3        4 2  2          2 4        3 3  3
+--R                 (- 110A b c  + 58B b c )d e + (72A b c  - 36B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     6 3        5        6    2           4 2        5   2
+--R                 6A b e  + (4A b c - 8B b )d e  + (- 26A b c  + 16B b c)d e
+--R               + 
+--R                       3 3       4 2  3
+--R                 (16A b c  - 8B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   6   2       5   2        4 2 3
+--R             - 4A b d e  + 8A b c d e - 4A b c d
+--R        *
+--R            +---+ +-------+
+--R           \|- d \|e x + d
+--R    /
+--R              7 2 2 2      6 3 3      5 4 4  4
+--R           (8b c d e  - 16b c d e + 8b c d )x
+--R         + 
+--R               8   2 2      7 2 3       6 3 4  3
+--R           (16b c d e  - 32b c d e + 16b c d )x
+--R         + 
+--R              9 2 2      8   3      7 2 4  2
+--R           (8b d e  - 16b c d e + 8b c d )x
+--R      *
+--R          +---+
+--R         \|- d
+--R     ,
+--R
+--R                       4 2 4          3 3       4 2    3
+--R                 - 3A b c e  + (- 6A b c  + 4B b c )d e
+--R               + 
+--R                         2 4        3 3  2 2           5        2 4  3
+--R                 (- 27A b c  + 16B b c )d e  + (84A b c  - 44B b c )d e
+--R               + 
+--R                         6          5  4
+--R                 (- 48A c  + 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       5   4           4 2       5     3
+--R                 - 6A b c e  + (- 12A b c  + 8B b c)d e
+--R               + 
+--R                         3 3        4 2  2 2          2 4        3 3  3
+--R                 (- 54A b c  + 32B b c )d e  + (168A b c  - 88B b c )d e
+--R               + 
+--R                           5        2 4  4
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       6 4          5        6    3           4 2        5   2 2
+--R                 - 3A b e  + (- 6A b c + 4B b )d e  + (- 27A b c  + 16B b c)d e
+--R               + 
+--R                       3 3        4 2  3            2 4        3 3  4
+--R                 (84A b c  - 44B b c )d e + (- 48A b c  + 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                 +---+ +-------+
+--R                \|- d \|e x + d
+--R           atan(----------------)
+--R                        d
+--R       + 
+--R                         2 4        3 3  2 2            5        2 4  3
+--R                 (- 63A b c  + 35B b c )d e  + (108A b c  - 56B b c )d e
+--R               + 
+--R                         6          5  4
+--R                 (- 48A c  + 24B b c )d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          3 3        4 2  2 2          2 4         3 3  3
+--R                 (- 126A b c  + 70B b c )d e  + (216A b c  - 112B b c )d e
+--R               + 
+--R                           5        2 4  4
+--R                 (- 96A b c  + 48B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                         4 2        5   2 2          3 3        4 2  3
+--R                 (- 63A b c  + 35B b c)d e  + (108A b c  - 56B b c )d e
+--R               + 
+--R                         2 4        3 3  4
+--R                 (- 48A b c  + 24B b c )d
+--R            *
+--R                2
+--R               x
+--R        *
+--R                  +---------+             +-------+
+--R            +---+ |    c                c\|e x + d
+--R           \|- d  |--------- atan(-----------------------)
+--R                 \|b e - c d                  +---------+
+--R                                              |    c
+--R                                  (b e - c d) |---------
+--R                                             \|b e - c d
+--R       + 
+--R                     4 2 3        3 3       4 2    2
+--R                 3A b c e  + (6A b c  - 4B b c )d e
+--R               + 
+--R                         2 4        3 3  2            5        2 4  3
+--R                 (- 36A b c  + 19B b c )d e + (24A b c  - 12B b c )d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                     5   3         4 2       5     2
+--R                 6A b c e  + (10A b c  - 8B b c)d e
+--R               + 
+--R                         3 3        4 2  2          2 4        3 3  3
+--R                 (- 55A b c  + 29B b c )d e + (36A b c  - 18B b c )d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                     6 3        5        6    2           4 2       5   2
+--R                 3A b e  + (2A b c - 4B b )d e  + (- 13A b c  + 8B b c)d e
+--R               + 
+--R                      3 3       4 2  3
+--R                 (8A b c  - 4B b c )d
+--R            *
+--R               x
+--R           + 
+--R                   6   2       5   2        4 2 3
+--R             - 2A b d e  + 4A b c d e - 2A b c d
+--R        *
+--R            +---+ +-------+
+--R           \|- d \|e x + d
+--R    /
+--R              7 2 2 2     6 3 3      5 4 4  4
+--R           (4b c d e  - 8b c d e + 4b c d )x
+--R         + 
+--R            8   2 2      7 2 3      6 3 4  3      9 2 2     8   3      7 2 4  2
+--R         (8b c d e  - 16b c d e + 8b c d )x  + (4b d e  - 8b c d e + 4b c d )x
+--R      *
+--R          +---+
+--R         \|- d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 863
+
+--S 864 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               4 4        3        4    3         2 2        3   2 2
+--R           3A b e  + (6A b c - 4B b )d e  + (27A b c  - 16B b c)d e
+--R         + 
+--R                     3        2 2  3          4          3  4
+--R           (- 84A b c  + 44B b c )d e + (48A c  - 24B b c )d
+--R      *
+--R                                +-------+              +-+
+--R          +-----------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-------------------------------)
+--R                                          x
+--R     + 
+--R                 2 2        3   2 2              3        2 2  3
+--R           (63A b c  - 35B b c)d e  + (- 108A b c  + 56B b c )d e
+--R         + 
+--R                 4          3  4
+--R           (48A c  - 24B b c )d
+--R      *
+--R                        +-----------+
+--R          +-----------+ |      c      +-+
+--R         \|- b e + c d  |- --------- \|d
+--R                       \|  b e - c d
+--R      *
+--R                             +-----------+
+--R                             |      c      +-------+
+--R             (- 2b e + 2c d) |- --------- \|e x + d  + c e x - b e + 2c d
+--R                            \|  b e - c d
+--R         log(------------------------------------------------------------)
+--R                                        c x + b
+--R     + 
+--R                    2 2        3   2 2            3         2 2  3
+--R           (- 126A b c  + 70B b c)d e  + (216A b c  - 112B b c )d e
+--R         + 
+--R                   4          3  4
+--R           (- 96A c  + 48B b c )d
+--R      *
+--R                        +-+ +-------+
+--R          +-+ +-+      \|c \|e x + d
+--R         \|c \|d atanh(--------------)
+--R                        +-----------+
+--R                       \|- b e + c d
+--R     + 
+--R               4 4         3        4    3         2 2        3   2 2
+--R           6A b e  + (12A b c - 8B b )d e  + (54A b c  - 32B b c)d e
+--R         + 
+--R                      3        2 2  3          4          3  4
+--R           (- 168A b c  + 88B b c )d e + (96A c  - 48B b c )d
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R  /
+--R        7 2 2      6   3      5 2 4  +-----------+ +-+
+--R     (8b d e  - 16b c d e + 8b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 864
+
+--S 865 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 865
+
+--S 866 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               4 4        3        4    3         2 2        3   2 2
+--R           3A b e  + (6A b c - 4B b )d e  + (27A b c  - 16B b c)d e
+--R         + 
+--R                     3        2 2  3          4          3  4
+--R           (- 84A b c  + 44B b c )d e + (48A c  - 24B b c )d
+--R      *
+--R                                +-------+              +-+
+--R          +-----------+    - 2d\|e x + d  + (e x + 2d)\|d
+--R         \|- b e + c d log(-------------------------------)
+--R                                          x
+--R     + 
+--R                    2 2        3   2 2            3         2 2  3
+--R           (- 126A b c  + 70B b c)d e  + (216A b c  - 112B b c )d e
+--R         + 
+--R                   4          3  4
+--R           (- 96A c  + 48B b c )d
+--R      *
+--R                        +-+ +-------+
+--R          +-+ +-+      \|c \|e x + d
+--R         \|c \|d atanh(--------------)
+--R                        +-----------+
+--R                       \|- b e + c d
+--R     + 
+--R               4 4         3        4    3         2 2        3   2 2
+--R           6A b e  + (12A b c - 8B b )d e  + (54A b c  - 32B b c)d e
+--R         + 
+--R                      3        2 2  3          4          3  4
+--R           (- 168A b c  + 88B b c )d e + (96A c  - 48B b c )d
+--R      *
+--R                              +-------+
+--R          +-----------+      \|e x + d
+--R         \|- b e + c d atanh(----------)
+--R                                 +-+
+--R                                \|d
+--R     + 
+--R                    2 2        3   2 2            3         2 2  3
+--R           (- 126A b c  + 70B b c)d e  + (216A b c  - 112B b c )d e
+--R         + 
+--R                   4          3  4
+--R           (- 96A c  + 48B b c )d
+--R      *
+--R                        +---------+                 +-------+
+--R          +-----------+ |    c      +-+           c\|e x + d
+--R         \|- b e + c d  |--------- \|d atan(-----------------------)
+--R                       \|b e - c d                      +---------+
+--R                                                        |    c
+--R                                            (b e - c d) |---------
+--R                                                       \|b e - c d
+--R  /
+--R        7 2 2      6   3      5 2 4  +-----------+ +-+
+--R     (8b d e  - 16b c d e + 8b c d )\|- b e + c d \|d
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 867
+
+)clear all
+
+--S 868 of 1457
+t0:=(A+B*x)/((d+e*x)^(3/2)*(b*x+c*x^2)^3)
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R          3   7        2     3   6      2          2   5     3      2     4
+--R         c e x  + (3b c e + c d)x  + (3b c e + 3b c d)x  + (b e + 3b c d)x
+--R       + 
+--R          3   3
+--R         b d x
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 868
+
+--S 869 of 1457
+r0:=-3/4*(16*A*c^2*d^2-b^2*e*(4*B*d-5*A*e)-4*b*c*d*(2*B*d-3*A*e))*_
+     atanh(sqrt(d+e*x)/sqrt(d))/(b^5*d^(7/2))+3/4*c^(5/2)*(16*A*c^3*d^2-_
+     21*b^3*B*e^2-4*b*c^2*d*(2*B*d+11*A*e)+3*b^2*c*e*(8*B*d+11*A*e))*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^5*(c*d-b*e)^(7/2))+_
+     3/4*e*(8*A*c^4*d^4+b^4*e^3*(4*B*d-5*A*e)-b^3*c*d*e^2*(4*B*d-3*A*e)-_
+     4*b*c^3*d^3*(B*d+4*A*e)+b^2*c^2*d^2*e*(9*B*d+5*A*e))/(b^4*d^3*_
+     (c*d-b*e)^3*sqrt(d+e*x))+1/4*c*(12*A*c^2*d^2+b^2*e*(4*B*d-5*A*e)-_
+     b*c*d*(6*B*d+5*A*e))/(b^3*d^2*(c*d-b*e)*(b+c*x)^2*sqrt(d+e*x))-_
+     1/2*A/(b*d*x^2*(b+c*x)^2*sqrt(d+e*x))+1/4*(-4*b*B*d+8*A*c*d+_
+     5*A*b*e)/(b^2*d^2*x*(b+c*x)^2*sqrt(d+e*x))+1/4*c*(24*A*c^3*d^3-_
+     b^3*e^2*(4*B*d-5*A*e)+b^2*c*d*e*(21*B*d+2*A*e)-12*b*c^2*d^2*(B*d+_
+     3*A*e))/(b^4*d^2*(c*d-b*e)^2*(b+c*x)*sqrt(d+e*x))
+--R 
+--R
+--R   (2)
+--R                       2 5        3 4  3 2            6        2 5  4
+--R               (- 99A b c  + 63B b c )d e  + (132A b c  - 72B b c )d e
+--R             + 
+--R                       7          6  5
+--R               (- 48A c  + 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        3 4         4 3  3 2          2 5         3 4  4
+--R               (- 198A b c  + 126B b c )d e  + (264A b c  - 144B b c )d e
+--R             + 
+--R                         6        2 5  5
+--R               (- 96A b c  + 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       4 3        5 2  3 2          3 4        4 3  4
+--R               (- 99A b c  + 63B b c )d e  + (132A b c  - 72B b c )d e
+--R             + 
+--R                       2 5        3 4  5
+--R               (- 48A b c  + 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                                  +-+ +-------+
+--R          +-+ +-+ +-------+      \|c \|e x + d
+--R         \|c \|d \|e x + d atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- b e + c d
+--R     + 
+--R                      5 2 5        4 3        5 2    4
+--R               - 15A b c e  + (9A b c  + 12B b c )d e
+--R             + 
+--R                     3 4        4 3  2 3         2 5        3 4  3 2
+--R               (15A b c  - 12B b c )d e  + (51A b c  - 36B b c )d e
+--R             + 
+--R                          6        2 5  4          7          6  5
+--R               (- 108A b c  + 60B b c )d e + (48A c  - 24B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      6   5         5 2        6     4
+--R               - 30A b c e  + (18A b c  + 24B b c)d e
+--R             + 
+--R                     4 3        5 2  2 3          3 4        4 3  3 2
+--R               (30A b c  - 24B b c )d e  + (102A b c  - 72B b c )d e
+--R             + 
+--R                        2 5         3 4  4            6        2 5  5
+--R               (- 216A b c  + 120B b c )d e + (96A b c  - 48B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      7 5        6         7    4         5 2        6   2 3
+--R               - 15A b e  + (9A b c + 12B b )d e  + (15A b c  - 12B b c)d e
+--R             + 
+--R                     4 3        5 2  3 2            3 4        4 3  4
+--R               (51A b c  - 36B b c )d e  + (- 108A b c  + 60B b c )d e
+--R             + 
+--R                     2 5        3 4  5
+--R               (48A b c  - 24B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                                        +-------+
+--R          +-----------+ +-------+      \|e x + d
+--R         \|- b e + c d \|e x + d atanh(----------)
+--R                                           +-+
+--R                                          \|d
+--R     + 
+--R                    5 2 5          4 3        5 2    4
+--R               15A b c e  + (- 9A b c  - 12B b c )d e
+--R             + 
+--R                       3 4        4 3  2 3         2 5        3 4  3 2
+--R               (- 15A b c  + 12B b c )d e  + (48A b c  - 27B b c )d e
+--R             + 
+--R                         6        2 5  4
+--R               (- 24A b c  + 12B b c )d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    6   5           5 2        6     4
+--R               30A b c e  + (- 13A b c  - 24B b c)d e
+--R             + 
+--R                       4 3        5 2  2 3         3 4        4 3  3 2
+--R               (- 33A b c  + 20B b c )d e  + (58A b c  - 29B b c )d e
+--R             + 
+--R                     2 5       3 4  4              6        2 5  5
+--R               (12A b c  - 9B b c )d e + (- 24A b c  + 12B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    7 5       6         7    4           5 2       6   2 3
+--R               15A b e  + (A b c - 12B b )d e  + (- 23A b c  + 4B b c)d e
+--R             + 
+--R                      4 3        5 2  3 2         3 4        4 3  4
+--R               (- 7A b c  + 12B b c )d e  + (65A b c  - 37B b c )d e
+--R             + 
+--R                       2 5        3 4  5
+--R               (- 36A b c  + 18B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   7   4          6        7  2 3          5 2        6   3 2
+--R               5A b d e  + (- 7A b c - 4B b )d e  + (- 9A b c  + 12B b c)d e
+--R             + 
+--R                     4 3        5 2  4           3 4       4 3  5
+--R               (19A b c  - 12B b c )d e + (- 8A b c  + 4B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 7 2 3       6   3 2       5 2 4        4 3 5
+--R           - 2A b d e  + 6A b c d e  - 6A b c d e + 2A b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R            8 2 3 3      7 3 4 2      6 4 5      5 5 6  4
+--R         (4b c d e  - 12b c d e  + 12b c d e - 4b c d )x
+--R       + 
+--R            9   3 3      8 2 4 2      7 3 5      6 4 6  3
+--R         (8b c d e  - 24b c d e  + 24b c d e - 8b c d )x
+--R       + 
+--R            10 3 3      9   4 2      8 2 5      7 3 6  2
+--R         (4b  d e  - 12b c d e  + 12b c d e - 4b c d )x
+--R    *
+--R        +-----------+ +-+ +-------+
+--R       \|- b e + c d \|d \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 869
+
+--S 870 of 1457
+--a0:=integrate(t0,x)
+--E 870
+
+--S 871 of 1457
+--m0a:=a0.1-r0
+--E 871
+
+--S 872 of 1457
+--d0a:=D(m0a,x)
+--E 872
+
+--S 873 of 1457
+--m0b:=a0.2-r0
+--E 873
+
+--S 874 of 1457
+--d0b:=D(m0b,x)
+--E 874
+
+)clear all
+
+--S 875 of 1457
+t0:=(A+B*x)/((d+e*x)^(5/2)*(b*x+c*x^2)^3)
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R          3 2 8        2 2     3     7      2   2       2       3 2  6
+--R         c e x  + (3b c e  + 2c d e)x  + (3b c e  + 6b c d e + c d )x
+--R       + 
+--R           3 2     2            2 2  5      3        2   2  4    3 2 3
+--R         (b e  + 6b c d e + 3b c d )x  + (2b d e + 3b c d )x  + b d x
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 875
+
+--S 876 of 1457
+r0:=1/12*e*(72*A*c^4*d^4+5*b^4*e^3*(4*B*d-7*A*e)-9*b^3*c*d*e^2*(4*B*d-_
+   5*A*e)-36*b*c^3*d^3*(B*d+4*A*e)+3*b^2*c^2*d^2*e*(29*B*d+9*A*e))/(b^4*_
+   d^3*(c*d-b*e)^3*(d+e*x)^(3/2))+1/4*c*(12*A*c^2*d^2+b^2*e*(4*B*d-7*A*e)-_
+   3*b*c*d*(2*B*d+A*e))/(b^3*d^2*(c*d-b*e)*(b+c*x)^2*(d+e*x)^(3/2))-_
+   1/2*A/(b*d*x^2*(b+c*x)^2*(d+e*x)^(3/2))+1/4*(-4*b*B*d+8*A*c*d+7*A*b*e)/_
+   (b^2*d^2*x*(b+c*x)^2*(d+e*x)^(3/2))+1/4*c*(24*A*c^3*d^3-b^3*e^2*_
+   (4*B*d-7*A*e)+b^2*c*d*e*(23*B*d-2*A*e)-12*b*c^2*d^2*(B*d+3*A*e))/_
+   (b^4*d^2*(c*d-b*e)^2*(b+c*x)*(d+e*x)^(3/2))-1/4*(48*A*c^2*d^2-_
+   5*b^2*e*(4*B*d-7*A*e)-12*b*c*d*(2*B*d-5*A*e))*atanh(sqrt(d+e*x)/_
+   sqrt(d))/(b^5*d^(9/2))+1/4*c^(7/2)*(48*A*c^3*d^2-99*b^3*B*e^2-_
+   12*b*c^2*d*(2*B*d+13*A*e)+11*b^2*c*e*(8*B*d+13*A*e))*atanh(sqrt(c)*_
+   sqrt(d+e*x)/sqrt(c*d-b*e))/(b^5*(c*d-b*e)^(9/2))+1/4*e*(24*A*c^5*d^5+_
+   8*b^4*c*d*e^3*(7*B*d-10*A*e)-5*b^5*e^4*(4*B*d-7*A*e)-6*b^3*_
+   c^2*d^2*e^2*(4*B*d-3*A*e)+7*b^2*c^3*d^3*e*(5*B*d+4*A*e)-12*b*c^4*d^4*_
+   (B*d+5*A*e))/(b^4*d^4*(c*d-b*e)^4*sqrt(d+e*x))
+--R 
+--R
+--R   (2)
+--R                      2 6         3 5  4 3              7         2 6  5 2
+--R               (429A b c  - 297B b c )d e  + (- 468A b c  + 264B b c )d e
+--R             + 
+--R                      8          7  6
+--R               (144A c  - 72B b c )d e
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                      3 5         4 4  4 3            2 6         3 5  5 2
+--R               (858A b c  - 594B b c )d e  + (- 507A b c  + 231B b c )d e
+--R             + 
+--R                          7         2 6  6           8          7  7
+--R               (- 180A b c  + 120B b c )d e + (144A c  - 72B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      4 4         5 3  4 3          3 5         4 4  5 2
+--R               (429A b c  - 297B b c )d e  + (390A b c  - 330B b c )d e
+--R             + 
+--R                        2 6         3 5  6             7         2 6  7
+--R               (- 792A b c  + 456B b c )d e + (288A b c  - 144B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      4 4         5 3  5 2            3 5         4 4  6
+--R               (429A b c  - 297B b c )d e  + (- 468A b c  + 264B b c )d e
+--R             + 
+--R                      2 6        3 5  7
+--R               (144A b c  - 72B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                                  +-+ +-------+
+--R          +-+ +-+ +-------+      \|c \|e x + d
+--R         \|c \|d \|e x + d atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- b e + c d
+--R     + 
+--R                       6 2 7          5 3        6 2    6
+--R               - 105A b c e  + (240A b c  + 60B b c )d e
+--R             + 
+--R                       4 4         5 3  2 5           3 5        4 4  3 4
+--R               (- 54A b c  - 168B b c )d e  + (- 84A b c  + 72B b c )d e
+--R             + 
+--R                        2 6         3 5  4 3            7         2 6  5 2
+--R               (- 249A b c  + 192B b c )d e  + (396A b c  - 228B b c )d e
+--R             + 
+--R                        8          7  6
+--R               (- 144A c  + 72B b c )d e
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                       7   7          6 2         7     6
+--R               - 210A b c e  + (375A b c  + 120B b c)d e
+--R             + 
+--R                      5 3         6 2  2 5            4 4        5 3  3 4
+--R               (132A b c  - 276B b c )d e  + (- 222A b c  - 24B b c )d e
+--R             + 
+--R                        3 5         4 4  4 3          2 6         3 5  5 2
+--R               (- 582A b c  + 456B b c )d e  + (543A b c  - 264B b c )d e
+--R             + 
+--R                        7        2 6  6             8          7  7
+--R               (108A b c  - 84B b c )d e + (- 144A c  + 72B b c )d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                       8 7         7         8    6          6 2        7   2 5
+--R               - 105A b e  + (30A b c + 60B b )d e  + (426A b c  - 48B b c)d e
+--R             + 
+--R                        5 3         6 2  3 4            4 4         5 3  4 3
+--R               (- 192A b c  - 264B b c )d e  + (- 417A b c  + 336B b c )d e
+--R             + 
+--R                        3 5         4 4  5 2          2 6         3 5  6
+--R               (- 102A b c  + 156B b c )d e  + (648A b c  - 384B b c )d e
+--R             + 
+--R                          7         2 6  7
+--R               (- 288A b c  + 144B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       8   6          7         8  2 5
+--R               - 105A b d e  + (240A b c + 60B b )d e
+--R             + 
+--R                       6 2         7   3 4           5 3        6 2  4 3
+--R               (- 54A b c  - 168B b c)d e  + (- 84A b c  + 72B b c )d e
+--R             + 
+--R                        4 4         5 3  5 2          3 5         4 4  6
+--R               (- 249A b c  + 192B b c )d e  + (396A b c  - 228B b c )d e
+--R             + 
+--R                        2 6        3 5  7
+--R               (- 144A b c  + 72B b c )d
+--R          *
+--R              2
+--R             x
+--R      *
+--R                                        +-------+
+--R          +-----------+ +-------+      \|e x + d
+--R         \|- b e + c d \|e x + d atanh(----------)
+--R                                           +-+
+--R                                          \|d
+--R     + 
+--R                     6 2 7            5 3        6 2    6
+--R               105A b c e  + (- 240A b c  - 60B b c )d e
+--R             + 
+--R                     4 4         5 3  2 5         3 5        4 4  3 4
+--R               (54A b c  + 168B b c )d e  + (84A b c  - 72B b c )d e
+--R             + 
+--R                        2 6         3 5  4 3           7        2 6  5 2
+--R               (- 180A b c  + 105B b c )d e  + (72A b c  - 36B b c )d e
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                     7   7            6 2         7     6
+--R               210A b c e  + (- 340A b c  - 120B b c)d e
+--R             + 
+--R                        5 3         6 2  2 5          4 4        5 3  3 4
+--R               (- 212A b c  + 256B b c )d e  + (240A b c  + 80B b c )d e
+--R             + 
+--R                        3 5        4 4  4 3            2 6         3 5  5 2
+--R               (- 105A b c  + 15B b c )d e  + (- 252A b c  + 156B b c )d e
+--R             + 
+--R                        7        2 6  6
+--R               (144A b c  - 72B b c )d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     8 7         7         8    6            6 2       7   2 5
+--R               105A b e  + (40A b c - 60B b )d e  + (- 565A b c  + 8B b c)d e
+--R             + 
+--R                      5 3         6 2  3 4          4 4         5 3  4 3
+--R               (180A b c  + 364B b c )d e  + (255A b c  - 192B b c )d e
+--R             + 
+--R                        3 5         4 4  5 2         2 6       3 5  6
+--R               (- 438A b c  + 234B b c )d e  + (36A b c  - 3B b c )d e
+--R             + 
+--R                       7        2 6  7
+--R               (72A b c  - 36B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     8   6            7         8  2 5
+--R               140A b d e  + (- 278A b c - 80B b )d e
+--R             + 
+--R                       6 2         7   3 4          5 3        6 2  4 3
+--R               (- 30A b c  + 200B b c)d e  + (180A b c  - 48B b c )d e
+--R             + 
+--R                      5 3 5 2            3 5         4 4  6
+--R               - 48B b c d e  + (- 225A b c  + 135B b c )d e
+--R             + 
+--R                      2 6        3 5  7
+--R               (108A b c  - 54B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    8 2 5           7         8  3 4         6 2        7   4 3
+--R               21A b d e  + (- 60A b c - 12B b )d e  + (30A b c  + 48B b c)d e
+--R             + 
+--R                     5 3        6 2  5 2           4 4        5 3  6
+--R               (60A b c  - 72B b c )d e  + (- 75A b c  + 48B b c )d e
+--R             + 
+--R                     3 5        4 4  7
+--R               (24A b c  - 12B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 8 3 4        7   4 3        6 2 5 2        5 3 6        4 4 7
+--R           - 6A b d e  + 24A b c d e  - 36A b c d e  + 24A b c d e - 6A b c d
+--R      *
+--R          +-----------+ +-+
+--R         \|- b e + c d \|d
+--R  /
+--R             9 2 4 5      8 3 5 4      7 4 6 3      6 5 7 2      5 6 8   5
+--R         (12b c d e  - 48b c d e  + 72b c d e  - 48b c d e  + 12b c d e)x
+--R       + 
+--R                10   4 5      9 2 5 4      8 3 6 3      7 4 7 2      6 5 8
+--R             24b  c d e  - 84b c d e  + 96b c d e  - 24b c d e  - 24b c d e
+--R           + 
+--R                5 6 9
+--R             12b c d
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                11 4 5      10   5 4      9 2 6 3      8 3 7 2      7 4 8
+--R             12b  d e  - 24b  c d e  - 24b c d e  + 96b c d e  - 84b c d e
+--R           + 
+--R                6 5 9
+--R             24b c d
+--R        *
+--R            3
+--R           x
+--R       + 
+--R             11 5 4      10   6 3      9 2 7 2      8 3 8       7 4 9  2
+--R         (12b  d e  - 48b  c d e  + 72b c d e  - 48b c d e + 12b c d )x
+--R    *
+--R        +-----------+ +-+ +-------+
+--R       \|- b e + c d \|d \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 876
+
+--S 877 of 1457
+--a0:=integrate(t0,x)
+--E 877
+
+--S 878 of 1457
+--m0a:=a0.1-r0
+--E 878
+
+--S 879 of 1457
+--d0a:=D(m0a,x)
+--E 879
+
+--S 880 of 1457
+--m0b:=a0.2-r0
+--E 880
+
+--S 881 of 1457
+--d0b:=D(m0b,x)
+--E 881
+
+)clear all
+
+--S 882 of 1457
+t0:=(A+B*x)*(d+e*x)^(1/2)*sqrt(b*x+c*x^2)
+--R 
+--R
+--R                            +----------+
+--R                  +-------+ |   2
+--R   (1)  (B x + A)\|e x + d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 1457
+--r0:=2/7*B*(b*x+c*x^2)^(3/2)*sqrt(d+e*x)/c-2/105*(14*A*c*e*(c^2*d^2-_
+--     b*c*d*e+b^2*e^2)-B*(8*c^3*d^3-5*b*c^2*d^2*e-5*b^2*c*d*e^2+8*_
+--     b^3*e^3))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c^3*e^(5/2)*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/105*(-b)^(3/2)*_
+--     (c*d-b*e)*(7*A*c*e*(c*d-2*b*e)-B*(4*c^2*d^2+b*c*d*e-8*b^2*e^2))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(7/2)*e^2*sqrt(d+e*x)*sqrt(b*x+_
+--     c*x^2))+2/105*(7*A*c*e*(c*d+b*e)-B*(4*c^2*d^2-2*b*c*d*e+4*b^2*e^2)+_
+--     3*c*e*(B*c*d-4*b*B*e+7*A*c*e)*x)*sqrt(d+e*x)*sqrt(b*x+c*x^2)/(c^2*e^2)
+--E 883
+
+--S 884 of 1457
+--a0:=integrate(t0,x)
+--E 884
+
+--S 885 of 1457
+--m0:=a0-r0
+--E 885
+
+--S 886 of 1457
+--d0:=D(m0,x)
+--E 886
+
+)clear all
+
+--S 887 of 1457
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^(1/2)
+--R 
+--R
+--R                  +----------+
+--R                  |   2
+--R        (B x + A)\|c x  + b x
+--R   (1)  ----------------------
+--R               +-------+
+--R              \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 1457
+--r0:=-2/15*(5*A*c*e*(2*c*d-b*e)-B*(8*c^2*d^2-3*b*c*d*e-2*b^2*e^2))*_
+--     (b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*_
+--     sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c^2*e^(5/2)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/15*(-b)^(3/2)*(c*d-b*e)*(4*B*c*d+_
+--     2*b*B*e-5*A*c*e)*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),_
+--     b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(5/2)*e^2*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/15*(4*B*c*d-b*B*e-5*A*c*e-3*B*c*e*x)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2)/(c*e^2)
+--E 888
+
+--S 889 of 1457
+--a0:=integrate(t0,x)
+--E 889
+
+--S 890 of 1457
+--m0:=a0-r0
+--E 890
+
+--S 891 of 1457
+--d0:=D(m0,x)
+--E 891
+
+)clear all
+
+--S 892 of 1457
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^(3/2)
+--R 
+--R
+--R                  +----------+
+--R                  |   2
+--R        (B x + A)\|c x  + b x
+--R   (1)  ----------------------
+--R                    +-------+
+--R          (e x + d)\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 892
+
+--S 893 of 1457
+--r0:=-2/3*(8*B*c*d-b*B*e-6*A*c*e)*(b+c*x)*elliptic_e(asin(sqrt(e)*_
+--     sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/_
+--     (c*e^(5/2)*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2/3*(-b)^(3/2)*(4*B*c*d-b*B*e-3*A*c*e)*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+_
+--     e*x)/d)/(c^(3/2)*e^2*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*(4*B*d-_
+--     3*A*e+B*e*x)*sqrt(b*x+c*x^2)/(e^2*sqrt(d+e*x))
+--E 893
+
+--S 894 of 1457
+--a0:=integrate(t0,x)
+--E 894
+
+--S 895 of 1457
+--m0:=a0-r0
+--E 895
+
+--S 896 of 1457
+--d0:=D(m0,x)
+--E 896
+
+)clear all
+
+--S 897 of 1457
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^(5/2)
+--R 
+--R
+--R                      +----------+
+--R                      |   2
+--R            (B x + A)\|c x  + b x
+--R   (1)  ------------------------------
+--R          2 2             2  +-------+
+--R        (e x  + 2d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 897
+
+--S 898 of 1457
+--r0:=-2/3*(B*d*(8*c*d-7*b*e)-A*e*(2*c*d-b*e))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(x)*_
+--     sqrt((d+e*x)/d)/(e^(5/2)*(c*d-b*e)*sqrt(-d)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*(-b)^(3/2)*(4*B*d-A*e)*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d*e^2*sqrt(c)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/3*(4*B*d-A*e+3*B*e*x)*sqrt(b*x+c*x^2)/(e^2*_
+--     (d+e*x)^(3/2))-2/3*(B*d*(8*c*d-7*b*e)-A*e*(2*c*d-b*e))*_
+--     sqrt(b*x+c*x^2)/(d*e^2*(c*d-b*e)*sqrt(d+e*x))
+--E 898
+
+--S 899 of 1457
+--a0:=integrate(t0,x)
+--E 899
+
+--S 900 of 1457
+--m0:=a0-r0
+--E 900
+
+--S 901 of 1457
+--d0:=D(m0,x)
+--E 901
+
+)clear all
+
+--S 902 of 1457
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^(7/2)
+--R 
+--R
+--R                           +----------+
+--R                           |   2
+--R                 (B x + A)\|c x  + b x
+--R   (1)  ----------------------------------------
+--R          3 3       2 2     2       3  +-------+
+--R        (e x  + 3d e x  + 3d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 902
+
+--S 903 of 1457
+--r0:=-2/15*(2*A*e*(c^2*d^2-b*c*d*e+b^2*e^2)+B*d*(8*c^2*d^2-13*b*c*d*e+_
+--     3*b^2*e^2))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(x)*sqrt((d+e*x)/d)/((-d)^(3/2)*e^(5/2)*(c*d-b*e)^2*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/15*(-b)^(3/2)*(B*d*_
+--     (4*c*d-3*b*e)+A*e*(c*d-2*b*e))*elliptic_f(asin(sqrt(c)*sqrt(x)/_
+--     sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d^2*_
+--     e^2*(c*d-b*e)*sqrt(c)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/15*(B*d*(8*c*d-_
+--     9*b*e)+A*e*(2*c*d-b*e))*sqrt(b*x+c*x^2)/(d*e^2*(c*d-b*e)*(d+_
+--     e*x)^(3/2))-2/5*(4*B*d+A*e+5*B*e*x)*sqrt(b*x+c*x^2)/(e^2*(d+_
+--     e*x)^(5/2))+2/15*(2*A*e*(c^2*d^2-b*c*d*e+b^2*e^2)+B*d*(8*c^2*d^2-_
+--     13*b*c*d*e+3*b^2*e^2))*sqrt(b*x+c*x^2)/(d^2*e^2*(c*d-b*e)^2*sqrt(d+e*x))
+--E 903
+
+--S 904 of 1457
+--a0:=integrate(t0,x)
+--E 904
+
+--S 905 of 1457
+--m0:=a0-r0
+--E 905
+
+--S 906 of 1457
+--d0:=D(m0,x)
+--E 906
+
+)clear all
+
+--S 907 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^(1/2)
+--R 
+--R
+--R                                         +----------+
+--R              3               2          |   2
+--R        (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  ---------------------------------------------
+--R                           +-------+
+--R                          \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 907
+
+--S 908 of 1457
+--r0:=-2/63*(8*B*c*d-3*b*B*e-9*A*c*e-7*B*c*e*x)*(b*x+c*x^2)^(3/2)*_
+--     sqrt(d+e*x)/(c*e^2)-2/315*(18*A*c*e*(8*c^3*d^3-12*b*c^2*d^2*e+_
+--     2*b^2*c*d*e^2+b^3*e^3)-B*(128*c^4*d^4-184*b*c^3*d^3*e+27*_
+--     b^2*c^2*d^2*e^2+11*b^3*c*d*e^3+8*b^4*e^4))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*_
+--     sqrt(x)*sqrt((d+e*x)/d)/(c^3*e^(9/2)*sqrt((b+c*x)/b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2/315*(-b)^(3/2)*(c*d-b*e)*(9*A*c*e*(8*c^2*d^2-_
+--     5*b*c*d*e-2*b^2*e^2)-B*(64*c^3*d^3-36*b*c^2*d^2*e-15*b^2*c*d*e^2-_
+--     8*b^3*e^3))*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(7/2)*e^4*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/315*(9*A*c*e*(8*c^2*d^2-11*b*c*d*e+b^2*e^2)-_
+--     2*B*(32*c^3*d^3-42*b*c^2*d^2*e+3*b^2*c*d*e^2+2*b^3*e^3)-3*c*e*_
+--     (9*A*c*e*(2*c*d-b*e)-B*(16*c^2*d^2-7*b*c*d*e-4*b^2*e^2))*x)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2)/(c^2*e^4)
+--E 908
+
+--S 909 of 1457
+--a0:=integrate(t0,x)
+--E 909
+
+--S 910 of 1457
+--m0:=a0-r0
+--E 910
+
+--S 911 of 1457
+--d0:=D(m0,x)
+--E 911
+
+)clear all
+
+--S 912 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^(3/2)
+--R 
+--R
+--R                                         +----------+
+--R              3               2          |   2
+--R        (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  ---------------------------------------------
+--R                               +-------+
+--R                     (e x + d)\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 912
+
+--S 913 of 1457
+--r0:=2/7*(8*B*d-7*A*e+B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*sqrt(d+e*x))+2/35*_
+--     (5*b*c*e*(8*B*d-7*A*e)*(2*c*d-b*e)-(16*B*c*d-b*B*e-14*A*c*e)*_
+--     (8*c^2*d^2-3*b*c*d*e-2*b^2*e^2))*(b+c*x)*elliptic_e(asin(sqrt(e)*_
+--     sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/_
+--     (c^2*e^(9/2)*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/35*_
+--     (-b)^(3/2)*(c*d-b*e)*(7*A*c*e*(8*c*d-b*e)-2*B*(32*c^2*d^2-6*b*c*d*e-_
+--     b^2*e^2))*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(5/2)*e^4*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2/35*(7*A*c*e*(8*c*d-7*b*e)-B*(64*c^2*d^2-60*b*c*_
+--     d*e+b^2*e^2)+3*c*e*(16*B*c*d-b*B*e-14*A*c*e)*x)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2)/(c*e^4)
+--E 913
+
+--S 914 of 1457
+--a0:=integrate(t0,x)
+--E 914
+
+--S 915 of 1457
+--m0:=a0-r0
+--E 915
+
+--S 916 of 1457
+--d0:=D(m0,x)
+--E 916
+
+)clear all
+
+--S 917 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^(5/2)
+--R 
+--R
+--R                                         +----------+
+--R              3               2          |   2
+--R        (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  ---------------------------------------------
+--R                  2 2             2  +-------+
+--R                (e x  + 2d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 917
+
+--S 918 of 1457
+--r0:=2/15*(8*B*d-5*A*e+3*B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*(d+e*x)^(3/2))-_
+--     2/15*(40*A*c*e*(2*c*d-b*e)-B*(128*c^2*d^2-88*b*c*d*e+3*b^2*e^2))*_
+--     (b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*_
+--     sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c*e^(9/2)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/15*(-b)^(3/2)*(5*A*c*e*(8*c*d-5*b*e)-_
+--     B*(64*c^2*d^2-52*b*c*d*e+3*b^2*e^2))*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/(c^(3/2)*e^4*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2/15*(4*B*d*(16*c*d-9*b*e)-5*A*e*(8*c*d-3*b*e)+e*(16*B*c*d-_
+--     3*b*B*e-10*A*c*e)*x)*sqrt(b*x+c*x^2)/(e^4*sqrt(d+e*x))
+--E 918
+
+--S 919 of 1457
+--a0:=integrate(t0,x)
+--E 919
+
+--S 920 of 1457
+--m0:=a0-r0
+--E 920
+
+--S 921 of 1457
+--d0:=D(m0,x)
+--E 921
+
+)clear all
+
+--S 922 of 1457
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^(7/2)
+--R 
+--R
+--R                                         +----------+
+--R              3               2          |   2
+--R        (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  ---------------------------------------------
+--R             3 3       2 2     2       3  +-------+
+--R           (e x  + 3d e x  + 3d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 1457
+--r0:=2/15*(8*B*d-3*A*e+5*B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*(d+e*x)^(5/2))-_
+--     2/15*(3*A*e*(16*c^2*d^2-16*b*c*d*e+b^2*e^2)-B*d*(128*c^2*d^2-_
+--     168*b*c*d*e+43*b^2*e^2))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/_
+--     sqrt(-d)),c*d/(b*e))*sqrt(x)*sqrt((d+e*x)/d)/(e^(9/2)*(c*d-b*e)*_
+--     sqrt(-d)*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2/15*(-b)^(3/2)*(4*B*d*(16*c*d-7*b*e)-3*A*e*(8*c*d-b*e))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d*e^4*sqrt(c)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2/15*(4*B*d*(16*c*d-7*b*e)-3*A*e*(8*c*d-b*e)+_
+--     3*e*(16*B*c*d-5*b*B*e-6*A*c*e)*x)*sqrt(b*x+c*x^2)/(e^4*_
+--     (d+e*x)^(3/2))-2/15*(3*A*e*(16*c^2*d^2-16*b*c*d*e+b^2*e^2)-B*d*_
+--     (128*c^2*d^2-168*b*c*d*e+43*b^2*e^2))*sqrt(b*x+c*x^2)/(d*e^4*_
+--     (c*d-b*e)*sqrt(d+e*x))
+--E 923
+
+--S 924 of 1457
+--a0:=integrate(t0,x)
+--E 924
+
+--S 925 of 1457
+--m0:=a0-r0
+--E 925
+
+--S 926 of 1457
+--d0:=D(m0,x)
+--E 926
+
+)clear all
+
+--S 927 of 1457
+t0:=(A+B*x)*(d+e*x)^(5/2)/sqrt(b*x+c*x^2)
+--R 
+--R
+--R            2 3       2           2                2        2  +-------+
+--R        (B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d )\|e x + d
+--R   (1)  ----------------------------------------------------------------
+--R                                   +----------+
+--R                                   |   2
+--R                                  \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 927
+
+--S 928 of 1457
+--r0:=2/105*(7*A*c*e*(23*c^2*d^2-23*b*c*d*e+8*b^2*e^2)+B*(15*c^3*d^3-_
+--     103*b*c^2*d^2*e+128*b^2*c*d*e^2-48*b^3*e^3))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*_
+--     sqrt(x)*sqrt((d+e*x)/d)/(c^4*sqrt(e)*sqrt((b+c*x)/b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/105*(c*d-b*e)*(105*A*c^3*d^2-48*b^3*B*e^2+_
+--     8*b^2*c*e*(13*B*d+7*A*e)-b*c^2*d*(60*B*d+133*A*e))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(-b)*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(9/2)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/35*(5*B*c*d-6*b*B*e+7*A*c*e)*(d+e*x)^(3/2)*_
+--     sqrt(b*x+c*x^2)/c^2+2/7*B*(d+e*x)^(5/2)*sqrt(b*x+c*x^2)/c+2/105*_
+--     (28*A*c*e*(2*c*d-b*e)+B*(15*c^2*d^2-43*b*c*d*e+24*b^2*e^2))*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2)/c^3
+--E 928
+
+--S 929 of 1457
+--a0:=integrate(t0,x)
+--E 929
+
+--S 930 of 1457
+--m0:=a0-r0
+--E 930
+
+--S 931 of 1457
+--d0:=D(m0,x)
+--E 931
+
+)clear all
+
+--S 932 of 1457
+t0:=(A+B*x)*(d+e*x)^(3/2)/sqrt(b*x+c*x^2)
+--R 
+--R
+--R              2                       +-------+
+--R        (B e x  + (A e + B d)x + A d)\|e x + d
+--R   (1)  ---------------------------------------
+--R                      +----------+
+--R                      |   2
+--R                     \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 932
+
+--S 933 of 1457
+--r0:=2/15*(10*A*c*e*(2*c*d-b*e)+B*(3*c^2*d^2-13*b*c*d*e+8*b^2*e^2))*_
+--     (b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*_
+--     sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c^3*sqrt(e)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/15*(c*d-b*e)*(9*b*B*c*d-15*A*c^2*d-_
+--     8*b^2*B*e+10*A*b*c*e)*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),_
+--     b*e/(c*d))*sqrt(-b)*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/_
+--     (c^(7/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/5*B*(d+e*x)^(3/2)*_
+--     sqrt(b*x+c*x^2)/c+2/15*(3*B*c*d-4*b*B*e+5*A*c*e)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2)/c^2
+--E 933
+
+--S 934 of 1457
+--a0:=integrate(t0,x)
+--E 934
+
+--S 935 of 1457
+--m0:=a0-r0
+--E 935
+
+--S 936 of 1457
+--d0:=D(m0,x)
+--E 936
+
+)clear all
+
+--S 937 of 1457
+t0:=(A+B*x)*sqrt(d+e*x)/sqrt(b*x+c*x^2)
+--R 
+--R
+--R                  +-------+
+--R        (B x + A)\|e x + d
+--R   (1)  -------------------
+--R            +----------+
+--R            |   2
+--R           \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 937
+
+--S 938 of 1457
+--r0:=2/3*(B*c*d-2*b*B*e+3*A*c*e)*(b+c*x)*elliptic_e(asin(sqrt(e)*_
+--     sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c^2*_
+--     sqrt(e)*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*(2*b*B-_
+--     3*A*c)*(c*d-b*e)*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),_
+--     b*e/(c*d))*sqrt(-b)*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/_
+--     (c^(5/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*B*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2)/c
+--E 938
+
+--S 939 of 1457
+--a0:=integrate(t0,x)
+--E 939
+
+--S 940 of 1457
+--m0:=a0-r0
+--E 940
+
+--S 941 of 1457
+--d0:=D(m0,x)
+--E 941
+
+)clear all
+
+--S 942 of 1457
+t0:=(A+B*x)/(sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--R 
+--R
+--R                B x + A
+--R   (1)  -----------------------
+--R                   +----------+
+--R         +-------+ |   2
+--R        \|e x + d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 942
+
+--S 943 of 1457
+--r0:=2*B*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*_
+--     sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c*sqrt(e)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2*(b*B-A*c)*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(-b)*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/(c^(3/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 943
+
+--S 944 of 1457
+--a0:=integrate(t0,x)
+--E 944
+
+--S 945 of 1457
+--m0:=a0-r0
+--E 945
+
+--S 946 of 1457
+--d0:=D(m0,x)
+--E 946
+
+)clear all
+
+--S 947 of 1457
+t0:=(A+B*x)/((d+e*x)^(3/2)*sqrt(b*x+c*x^2))
+--R 
+--R
+--R                     B x + A
+--R   (1)  --------------------------------
+--R                            +----------+
+--R                  +-------+ |   2
+--R        (e x + d)\|e x + d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 947
+
+--S 948 of 1457
+--r0:=2*(B*d-A*e)*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(x)*sqrt((d+e*x)/d)/((c*d-b*e)*sqrt(-d)*sqrt(e)*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2*A*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(-b)*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d*sqrt(c)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2*(B*d-A*e)*sqrt(b*x+c*x^2)/(d*(c*d-b*e)*sqrt(d+e*x))
+--E 948
+
+--S 949 of 1457
+--a0:=integrate(t0,x)
+--E 949
+
+--S 950 of 1457
+--m0:=a0-r0
+--E 950
+
+--S 951 of 1457
+--d0:=D(m0,x)
+--E 951
+
+)clear all
+
+--S 952 of 1457
+t0:=(A+B*x)/((d+e*x)^(5/2)*sqrt(b*x+c*x^2))
+--R 
+--R
+--R                          B x + A
+--R   (1)  -------------------------------------------
+--R                                       +----------+
+--R          2 2             2  +-------+ |   2
+--R        (e x  + 2d e x + d )\|e x + d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 952
+
+--S 953 of 1457
+--r0:=2/3*(2*A*e*(2*c*d-b*e)-B*d*(c*d+b*e))*(b+c*x)*elliptic_e(asin(_
+--     sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(x)*sqrt((d+e*x)/d)/_
+--     ((-d)^(3/2)*(c*d-b*e)^2*sqrt(e)*sqrt((b+c*x)/b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2/3*(b*B*d-3*A*c*d+2*A*b*e)*elliptic_f(asin(_
+--     sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(-b)*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d^2*(c*d-b*e)*sqrt(c)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/3*(B*d-A*e)*sqrt(b*x+c*x^2)/(d*(c*d-b*e)*_
+--     (d+e*x)^(3/2))-2/3*(2*A*e*(2*c*d-b*e)-B*d*(c*d+b*e))*sqrt(b*x+_
+--     c*x^2)/(d^2*(c*d-b*e)^2*sqrt(d+e*x))
+--E 953
+
+--S 954 of 1457
+--a0:=integrate(t0,x)
+--E 954
+
+--S 955 of 1457
+--m0:=a0-r0
+--E 955
+
+--S 956 of 1457
+--d0:=D(m0,x)
+--E 956
+
+)clear all
+
+--S 957 of 1457
+t0:=(A+B*x)/((d+e*x)^(7/2)*sqrt(b*x+c*x^2))
+--R 
+--R
+--R                               B x + A
+--R   (1)  -----------------------------------------------------
+--R                                                 +----------+
+--R          3 3       2 2     2       3  +-------+ |   2
+--R        (e x  + 3d e x  + 3d e x + d )\|e x + d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 957
+
+--S 958 of 1457
+--r0:=2/15*(B*d*(3*c^2*d^2+7*b*c*d*e-2*b^2*e^2)-A*e*(23*c^2*d^2-_
+--     23*b*c*d*e+8*b^2*e^2))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/_
+--     sqrt(-d)),c*d/(b*e))*sqrt(x)*sqrt((d+e*x)/d)/((-d)^(5/2)*_
+--     (c*d-b*e)^3*sqrt(e)*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+_
+--     2/15*(15*A*c^2*d^2+2*b^2*e*(B*d+4*A*e)-b*c*d*(6*B*d+19*A*e))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(-b)*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d^3*(c*d-b*e)^2*sqrt(c)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/5*(B*d-A*e)*sqrt(b*x+c*x^2)/_
+--     (d*(c*d-b*e)*(d+e*x)^(5/2))-2/15*(4*A*e*(2*c*d-b*e)-B*d*(3*c*d+_
+--     b*e))*sqrt(b*x+c*x^2)/(d^2*(c*d-b*e)^2*(d+e*x)^(3/2))+2/15*(B*d*_
+--     (3*c^2*d^2+7*b*c*d*e-2*b^2*e^2)-A*e*(23*c^2*d^2-23*b*c*d*e+_
+--     8*b^2*e^2))*sqrt(b*x+c*x^2)/(d^3*(c*d-b*e)^3*sqrt(d+e*x))
+--E 958
+
+--S 959 of 1457
+--a0:=integrate(t0,x)
+--E 959
+
+--S 960 of 1457
+--m0:=a0-r0
+--E 960
+
+--S 961 of 1457
+--d0:=D(m0,x)
+--E 961
+
+)clear all
+
+--S 962 of 1457
+t0:=(A+B*x)*(d+e*x)^(7/2)/(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R   (1)
+--R            3 4       3         2  3          2       2   2        2       3
+--R         B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x
+--R       + 
+--R            3
+--R         A d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R                  +----------+
+--R         2        |   2
+--R     (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 1457
+--r0:=-2*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(7/2)/(b^2*sqrt(b*x+c*x^2))+_
+--     2/15*(30*A*c^4*d^3+48*b^4*B*e^3-15*b*c^3*d^2*(B*d+3*A*e)-_
+--     8*b^3*c*e^2*(16*B*d+5*A*e)+b^2*c^2*d*e*(103*B*d+95*A*e))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*_
+--     sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^2*c^4*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/15*e*(c*d-b*e)*(15*A*c^3*d^2-_
+--     48*b^3*B*e^2-15*b*c^2*d*(4*B*d+5*A*e)+8*b^2*c*e*(13*B*d+5*A*e))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(9/2)*sqrt(-b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/5*e*(10*A*c^2*d+6*b^2*B*e-5*b*c*(B*d+A*e))*_
+--     (d+e*x)^(3/2)*sqrt(b*x+c*x^2)/(b^2*c^2)-2*(b*B-2*A*c)*e*_
+--     (d+e*x)^(5/2)*sqrt(b*x+c*x^2)/(b^2*c)+2/15*e*(30*A*c^3*d^2-_
+--     24*b^3*B*e^2-15*b*c^2*d*(B*d+2*A*e)+b^2*c*e*(43*B*d+20*A*e))*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2)/(b^2*c^3)
+--E 963
+
+--S 964 of 1457
+--a0:=integrate(t0,x)
+--E 964
+
+--S 965 of 1457
+--m0:=a0-r0
+--E 965
+
+--S 966 of 1457
+--d0:=D(m0,x)
+--E 966
+
+)clear all
+
+--S 967 of 1457
+t0:=(A+B*x)*(d+e*x)^(5/2)/(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R            2 3       2           2                2        2  +-------+
+--R        (B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d )\|e x + d
+--R   (1)  ----------------------------------------------------------------
+--R                                         +----------+
+--R                                2        |   2
+--R                            (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 967
+
+--S 968 of 1457
+--r0:=-2*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(5/2)/(b^2*sqrt(b*x+c*x^2))+_
+--     2/3*(6*A*c^3*d^2-8*b^3*B*e^2-3*b*c^2*d*(B*d+2*A*e)+b^2*c*e*_
+--     (13*B*d+6*A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(-d)*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^2*c^3*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*e*(c*d-b*e)*_
+--     (9*b*B*c*d-3*A*c^2*d-8*b^2*B*e+6*A*b*c*e)*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/(c^(7/2)*sqrt(-b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2*(b*B-2*A*c)*e*(d+e*x)^(3/2)*sqrt(b*x+c*x^2)/(b^2*c)+2/3*e*_
+--     (6*A*c^2*d+4*b^2*B*e-3*b*c*(B*d+A*e))*sqrt(d+e*x)*sqrt(b*x+c*x^2)/_
+--     (b^2*c^2)
+--E 968
+
+--S 969 of 1457
+--a0:=integrate(t0,x)
+--E 969
+
+--S 970 of 1457
+--m0:=a0-r0
+--E 970
+
+--S 971 of 1457
+--d0:=D(m0,x)
+--E 971
+
+)clear all
+
+--S 972 of 1457
+t0:=(A+B*x)*(d+e*x)^(3/2)/(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R              2                       +-------+
+--R        (B e x  + (A e + B d)x + A d)\|e x + d
+--R   (1)  ---------------------------------------
+--R                            +----------+
+--R                   2        |   2
+--R               (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 972
+
+--S 973 of 1457
+--r0:=-2*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(3/2)/(b^2*sqrt(b*x+c*x^2))+_
+--     2*(2*A*c^2*d+2*b^2*B*e-b*c*(B*d+A*e))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*_
+--     sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^2*c^2*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2*(2*b*B-A*c)*e*(c*d-b*e)*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(5/2)*sqrt(-b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2*(b*B-2*A*c)*e*sqrt(d+e*x)*sqrt(b*x+c*x^2)/(b^2*c)
+--E 973
+
+--S 974 of 1457
+--a0:=integrate(t0,x)
+--E 974
+
+--S 975 of 1457
+--m0:=a0-r0
+--E 975
+
+--S 976 of 1457
+--d0:=D(m0,x)
+--E 976
+
+)clear all
+
+--S 977 of 1457
+t0:=(A+B*x)*sqrt(d+e*x)/(b*x+c*x^2)^(3/2)
+--R 
+--R
+--R                     +-------+
+--R           (B x + A)\|e x + d
+--R   (1)  -------------------------
+--R                     +----------+
+--R            2        |   2
+--R        (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 1457
+--r0:=-2*(A*b-(b*B-2*A*c)*x)*sqrt(d+e*x)/(b^2*sqrt(b*x+c*x^2))-_
+--     2*(b*B-2*A*c)*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(-d)*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^2*c*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2*(b*B-A*c)*e*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(3/2)*sqrt(-b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))
+--E 978
+
+--S 979 of 1457
+--a0:=integrate(t0,x)
+--E 979
+
+--S 980 of 1457
+--m0:=a0-r0
+--E 980
+
+--S 981 of 1457
+--d0:=D(m0,x)
+--E 981
+
+)clear all
+
+--S 982 of 1457
+t0:=(A+B*x)/((b*x+c*x^2)^(3/2)*sqrt(d+e*x))
+--R 
+--R
+--R                      B x + A
+--R   (1)  -----------------------------------
+--R                               +----------+
+--R            2        +-------+ |   2
+--R        (c x  + b x)\|e x + d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 982
+
+--S 983 of 1457
+--r0:=-2*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)*sqrt(d+e*x)/(b^2*d*_
+--     (c*d-b*e)*sqrt(b*x+c*x^2))+2*(b*B*d-2*A*c*d+A*b*e)*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(e)*_
+--     sqrt(x)*sqrt((d+e*x)/d)/(b^2*(c*d-b*e)*sqrt(-d)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2*A*e*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/(d*sqrt(-b)*sqrt(c)*sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 983
+
+--S 984 of 1457
+--a0:=integrate(t0,x)
+--E 984
+
+--S 985 of 1457
+--m0:=a0-r0
+--E 985
+
+--S 986 of 1457
+--d0:=D(m0,x)
+--E 986
+
+)clear all
+
+--S 987 of 1457
+t0:=(A+B*x)/((d+e*x)^(3/2)*(b*x+c*x^2)^(3/2))
+--R 
+--R
+--R                                B x + A
+--R   (1)  -------------------------------------------------------
+--R                                                   +----------+
+--R              3               2          +-------+ |   2
+--R        (c e x  + (b e + c d)x  + b d x)\|e x + d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 987
+
+--S 988 of 1457
+--r0:=-2*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2*(2*A*c^2*d^2-b^2*e*(B*d-2*A*e)-_
+--     b*c*d*(B*d+2*A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/_
+--     sqrt(-d)),c*d/(b*e))*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/_
+--     (b^2*(-d)^(3/2)*(c*d-b*e)^2*sqrt((b+c*x)/b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2*e*(b*B*d+A*c*d-2*A*b*e)*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/(d^2*(c*d-b*e)*sqrt(-b)*sqrt(c)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2*e*(2*A*c^2*d^2-b^2*e*(B*d-2*A*e)-b*c*d*(B*d+_
+--     2*A*e))*sqrt(b*x+c*x^2)/(b^2*d^2*(c*d-b*e)^2*sqrt(d+e*x))
+--E 988
+
+--S 989 of 1457
+--a0:=integrate(t0,x)
+--E 989
+
+--S 990 of 1457
+--m0:=a0-r0
+--E 990
+
+--S 991 of 1457
+--d0:=D(m0,x)
+--E 991
+
+)clear all
+
+--S 992 of 1457
+t0:=(A+B*x)/((d+e*x)^(5/2)*(b*x+c*x^2)^(3/2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R           2 4       2           3                2  2      2   +-------+
+--R       (c e x  + (b e  + 2c d e)x  + (2b d e + c d )x  + b d x)\|e x + d
+--R    *
+--R        +----------+
+--R        |   2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 1457
+--r0:=-2*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*_
+--     (d+e*x)^(3/2)*sqrt(b*x+c*x^2))-2/3*(6*A*c^3*d^3-b^2*c*d*e*(7*B*d-_
+--     19*A*e)+2*b^3*e^2*(B*d-4*A*e)-3*b*c^2*d^2*(B*d+3*A*e))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(e)*_
+--     sqrt(x)*sqrt((d+e*x)/d)/(b^2*(-d)^(5/2)*(c*d-b*e)^3*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*e*(3*A*c^2*d^2+3*b*c*d*(2*B*d-_
+--     5*A*e)-2*b^2*e*(B*d-4*A*e))*elliptic_f(asin(sqrt(c)*sqrt(x)/_
+--     sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/_
+--     (d^3*(c*d-b*e)^2*sqrt(-b)*sqrt(c)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2/3*e*(6*A*c^2*d^2-b^2*e*(B*d-4*A*e)-3*b*c*d*(B*d+2*A*e))*_
+--     sqrt(b*x+c*x^2)/(b^2*d^2*(c*d-b*e)^2*(d+e*x)^(3/2))-_
+--     2/3*e*(6*A*c^3*d^3-b^2*c*d*e*(7*B*d-19*A*e)+2*b^3*e^2*(B*d-4*A*e)-_
+--     3*b*c^2*d^2*(B*d+3*A*e))*sqrt(b*x+c*x^2)/(b^2*d^3*(c*d-b*e)^3*_
+--     sqrt(d+e*x))
+--E 993
+
+--S 994 of 1457
+--a0:=integrate(t0,x)
+--E 994
+
+--S 995 of 1457
+--m0:=a0-r0
+--E 995
+
+--S 996 of 1457
+--d0:=D(m0,x)
+--E 996
+
+)clear all
+
+--S 997 of 1457
+t0:=(A+B*x)*(d+e*x)^(7/2)/(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R   (1)
+--R            3 4       3         2  3          2       2   2        2       3
+--R         B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x
+--R       + 
+--R            3
+--R         A d
+--R    *
+--R        +-------+
+--R       \|e x + d
+--R  /
+--R                             +----------+
+--R       2 4         3    2 2  |   2
+--R     (c x  + 2b c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 1457
+--r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(7/2)/(b^2*(b*x+c*x^2)^(3/2))-_
+--     2/3*(d+e*x)^(5/2)*(b*(4*b*B*d-8*A*c*d+7*A*b*e)-(16*A*c^2*d-_
+--     3*b^2*B*e-8*b*c*(B*d+A*e))*x)/(b^4*sqrt(b*x+c*x^2))-2/3*_
+--     (16*A*c^4*d^3-8*b^4*B*e^3+b^3*c*e^2*(5*B*d+2*A*e)-8*b*c^3*d^2*_
+--     (B*d+3*A*e)+b^2*c^2*d*e*(5*B*d+4*A*e))*(b+c*x)*elliptic_e(asin(_
+--     sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*sqrt(e)*sqrt(x)*_
+--     sqrt((d+e*x)/d)/(b^4*c^3*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+_
+--     c*x^2))-2/3*e*(c*d-b*e)*(8*A*c^3*d^2+8*b^3*B*e^2-b^2*c*e*(B*d+_
+--     2*A*e)-b*c^2*d*(4*B*d+5*A*e))*elliptic_f(asin(sqrt(c)*sqrt(x)/_
+--     sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/_
+--     ((-b)^(5/2)*c^(7/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*e*_
+--     (16*A*c^2*d-3*b^2*B*e-8*b*c*(B*d+A*e))*(d+e*x)^(3/2)*_
+--     sqrt(b*x+c*x^2)/(b^4*c)-2/3*e*(16*A*c^3*d^2+4*b^3*B*e^2+b^2*c*e*_
+--     (B*d-A*e)-8*b*c^2*d*(B*d+2*A*e))*sqrt(d+e*x)*sqrt(b*x+c*x^2)/(b^4*c^2)
+--E 998
+
+--S 999 of 1457
+--a0:=integrate(t0,x)
+--E 999
+
+--S 1000 of 1457
+--m0:=a0-r0
+--E 1000
+
+--S 1001 of 1457
+--d0:=D(m0,x)
+--E 1001
+
+)clear all
+
+--S 1002 of 1457
+t0:=(A+B*x)*(d+e*x)^(5/2)/(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R            2 3       2           2                2        2  +-------+
+--R        (B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d )\|e x + d
+--R   (1)  ----------------------------------------------------------------
+--R                                              +----------+
+--R                        2 4         3    2 2  |   2
+--R                      (c x  + 2b c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+--S 1003 of 1457
+--r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(5/2)/(b^2*(b*x+c*x^2)^(3/2))-_
+--     2/3*(d+e*x)^(3/2)*(b*(4*b*B*d-8*A*c*d+5*A*b*e)-(16*A*c^2*d-_
+--     b^2*B*e-8*b*c*(B*d+A*e))*x)/(b^4*sqrt(b*x+c*x^2))-2/3*_
+--     (16*A*c^3*d^2+2*b^3*B*e^2+b^2*c*e*(3*B*d+A*e)-8*b*c^2*d*(B*d+_
+--     2*A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/_
+--     (b*e))*sqrt(-d)*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^4*c^2*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*e*(c*d-b*e)*_
+--     (8*A*c^2*d-2*b^2*B*e-b*c*(4*B*d+A*e))*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/((-b)^(5/2)*c^(5/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2/3*e*(16*A*c^2*d-b^2*B*e-8*b*c*(B*d+A*e))*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2)/(b^4*c)
+--E 1003
+
+--S 1004 of 1457
+--a0:=integrate(t0,x)
+--E 1004
+
+--S 1005 of 1457
+--m0:=a0-r0
+--E 1005
+
+--S 1006 of 1457
+--d0:=D(m0,x)
+--E 1006
+
+)clear all
+
+--S 1007 of 1457
+t0:=(A+B*x)*(d+e*x)^(3/2)/(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R              2                       +-------+
+--R        (B e x  + (A e + B d)x + A d)\|e x + d
+--R   (1)  ---------------------------------------
+--R                                  +----------+
+--R            2 4         3    2 2  |   2
+--R          (c x  + 2b c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1007
+
+--S 1008 of 1457
+--r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(3/2)/(b^2*(b*x+c*x^2)^(3/2))-_
+--     2/3*(b*(4*b*B*d-8*A*c*d+3*A*b*e)-(16*A*c^2*d+b^2*B*e-8*b*c*_
+--     (B*d+A*e))*x)*sqrt(d+e*x)/(b^4*sqrt(b*x+c*x^2))-2/3*(16*A*c^2*d+_
+--     b^2*B*e-8*b*c*(B*d+A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/_
+--     sqrt(-d)),c*d/(b*e))*sqrt(-d)*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/_
+--     (b^4*c*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*e*_
+--     (4*b*B*c*d-8*A*c^2*d-b^2*B*e+5*A*b*c*e)*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/((-b)^(5/2)*c^(3/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 1008
+
+--S 1009 of 1457
+--a0:=integrate(t0,x)
+--E 1009
+
+--S 1010 of 1457
+--m0:=a0-r0
+--E 1010
+
+--S 1011 of 1457
+--d0:=D(m0,x)
+--E 1011
+
+)clear all
+
+--S 1012 of 1457
+t0:=(A+B*x)*sqrt(d+e*x)/(b*x+c*x^2)^(5/2)
+--R 
+--R
+--R                           +-------+
+--R                 (B x + A)\|e x + d
+--R   (1)  ------------------------------------
+--R                                +----------+
+--R          2 4         3    2 2  |   2
+--R        (c x  + 2b c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1012
+
+--S 1013 of 1457
+--r0:=-2/3*(A*b-(b*B-2*A*c)*x)*sqrt(d+e*x)/(b^2*(b*x+c*x^2)^(3/2))-_
+--     2/3*(b*(c*d-b*e)*(4*b*B*d-8*A*c*d+A*b*e)-c*(16*A*c^2*d^2+b^2*e*_
+--     (7*B*d+A*e)-8*b*c*d*(B*d+2*A*e))*x)*sqrt(d+e*x)/(b^4*d*(c*d-b*e)*_
+--     sqrt(b*x+c*x^2))+2/3*(16*A*c^2*d^2+b^2*e*(7*B*d+A*e)-8*b*c*d*_
+--     (B*d+2*A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^4*(c*d-b*e)*sqrt(-d)*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*e*(4*b*B*d-_
+--     8*A*c*d+A*b*e)*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/((-b)^(5/2)*d*sqrt(c)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 1013
+
+--S 1014 of 1457
+--a0:=integrate(t0,x)
+--E 1014
+
+--S 1015 of 1457
+--m0:=a0-r0
+--E 1015
+
+--S 1016 of 1457
+--d0:=D(m0,x)
+--E 1016
+
+)clear all
+
+--S 1017 of 1457
+t0:=(A+B*x)/((b*x+c*x^2)^(5/2)*sqrt(d+e*x))
+--R 
+--R
+--R                            B x + A
+--R   (1)  ----------------------------------------------
+--R                                          +----------+
+--R          2 4         3    2 2  +-------+ |   2
+--R        (c x  + 2b c x  + b x )\|e x + d \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1017
+
+--S 1018 of 1457
+--r0:=-2/3*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)*sqrt(d+e*x)/_
+--     (b^2*d*(c*d-b*e)*(b*x+c*x^2)^(3/2))+2/3*(b*(c*d-b*e)*(8*A*c^2*d^2+_
+--     b^2*e*(3*B*d-2*A*e)-b*c*d*(4*B*d+5*A*e))+c*(16*A*c^3*d^3-b^3*e^2*_
+--     (3*B*d-2*A*e)-8*b*c^2*d^2*(B*d+3*A*e)+b^2*c*d*e*(13*B*d+4*A*e))*x)*_
+--     sqrt(d+e*x)/(b^4*d^2*(c*d-b*e)^2*sqrt(b*x+c*x^2))-2/3*_
+--     (16*A*c^3*d^3-b^3*e^2*(3*B*d-2*A*e)-8*b*c^2*d^2*(B*d+3*A*e)+_
+--     b^2*c*d*e*(13*B*d+4*A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/_
+--     sqrt(-d)),c*d/(b*e))*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^4*(-d)^(3/2)*_
+--     (c*d-b*e)^2*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*e*_
+--     (8*A*c^2*d^2+b^2*e*(3*B*d-2*A*e)-b*c*d*(4*B*d+5*A*e))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/((-b)^(5/2)*d^2*(c*d-b*e)*sqrt(c)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 1018
+
+--S 1019 of 1457
+--a0:=integrate(t0,x)
+--E 1019
+
+--S 1020 of 1457
+--m0:=a0-r0
+--E 1020
+
+--S 1021 of 1457
+--d0:=D(m0,x)
+--E 1021
+
+)clear all
+
+--S 1022 of 1457
+t0:=(A+B*x)/((d+e*x)^(3/2)*(b*x+c*x^2)^(5/2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R         2   5              2   4     2            3    2   2  +-------+
+--R       (c e x  + (2b c e + c d)x  + (b e + 2b c d)x  + b d x )\|e x + d
+--R    *
+--R        +----------+
+--R        |   2
+--R       \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 1022
+
+--S 1023 of 1457
+--r0:=-2/3*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*_
+--     (b*x+c*x^2)^(3/2)*sqrt(d+e*x))+2/3*(b*(c*d-b*e)*(8*A*c^2*d^2+b^2*_
+--     e*(3*B*d-4*A*e)-b*c*d*(4*B*d+3*A*e))+c*(16*A*c^3*d^3+15*b^2*B*_
+--     c*d^2*e-b^3*e^2*(3*B*d-4*A*e)-8*b*c^2*d^2*(B*d+3*A*e))*x)/_
+--     (b^4*d^2*(c*d-b*e)^2*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*_
+--     (16*A*c^4*d^4-b^3*c*d*e^2*(9*B*d-7*A*e)-8*b*c^3*d^3*(B*d+4*A*e)+_
+--     b^2*c^2*d^2*e*(19*B*d+9*A*e)+b^4*(6*B*d*e^3-8*A*e^4))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(e)*_
+--     sqrt(x)*sqrt((d+e*x)/d)/(b^4*(-d)^(5/2)*(c*d-b*e)^3*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*e*(8*A*c^3*d^3+3*b^2*c*d*e*_
+--     (2*B*d-A*e)-b*c^2*d^2*(4*B*d+9*A*e)-b^3*(6*B*d*e^2-8*A*e^3))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/((-b)^(5/2)*d^3*(c*d-b*e)^2*_
+--     sqrt(c)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*e*(16*A*c^4*d^4-_
+--     b^3*c*d*e^2*(9*B*d-7*A*e)-8*b*c^3*d^3*(B*d+4*A*e)+b^2*c^2*d^2*_
+--     e*(19*B*d+9*A*e)+b^4*(6*B*d*e^3-8*A*e^4))*sqrt(b*x+c*x^2)/_
+--     (b^4*d^3*(c*d-b*e)^3*sqrt(d+e*x))
+--E 1023
+
+--S 1024 of 1457
+--a0:=integrate(t0,x)
+--E 1024
+
+--S 1025 of 1457
+--m0:=a0-r0
+--E 1025
+
+--S 1026 of 1457
+--d0:=D(m0,x)
+--E 1026
+
+)clear all
+
+--S 1027 of 1457
+t0:=(A+B*x)*(d+e*x)^m*(a+c*x^2)
+--R 
+--R
+--R              3        2                        m
+--R   (1)  (B c x  + A c x  + B a x + A a)(e x + d)
+--R                                                    Type: Expression(Integer)
+--E 1027
+
+--S 1028 of 1457
+r0:=-(B*d-A*e)*(c*d^2+a*e^2)*(d+e*x)^(1+m)/(e^4*(1+m))+(3*B*c*d^2-2*A*_
+     c*d*e+a*B*e^2)*(d+e*x)^(2+m)/(e^4*(2+m))-c*(3*B*d-A*e)*_
+     (d+e*x)^(3+m)/(e^4*(3+m))+B*c*(d+e*x)^(4+m)/(e^4*(4+m))
+--R 
+--R
+--R   (2)
+--R             3         2                           m + 4
+--R       (B c m  + 6B c m  + 11B c m + 6B c)(e x + d)
+--R     + 
+--R                            3                      2
+--R           (A c e - 3B c d)m  + (7A c e - 21B c d)m  + (14A c e - 42B c d)m
+--R         + 
+--R           8A c e - 24B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                 2                    2  3          2                      2  2
+--R           (B a e  - 2A c d e + 3B c d )m  + (8B a e  - 16A c d e + 24B c d )m
+--R         + 
+--R                   2                      2            2                      2
+--R           (19B a e  - 38A c d e + 57B c d )m + 12B a e  - 24A c d e + 36B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R                 3          2        2         3  3
+--R           (A a e  - B a d e  + A c d e - B c d )m
+--R         + 
+--R                  3           2         2          3  2
+--R           (9A a e  - 9B a d e  + 9A c d e - 9B c d )m
+--R         + 
+--R                   3            2          2           3            3
+--R           (26A a e  - 26B a d e  + 26A c d e - 26B c d )m + 24A a e
+--R         + 
+--R                      2          2           3
+--R           - 24B a d e  + 24A c d e - 24B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     e m  + 10e m  + 35e m  + 50e m + 24e
+--R                                                    Type: Expression(Integer)
+--E 1028
+
+--S 1029 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 3         4 2          4          4  4
+--R         (B c e m  + 6B c e m  + 11B c e m + 6B c e )x
+--R       + 
+--R                   4          3  3          4           3  2
+--R             (A c e  + B c d e )m  + (7A c e  + 3B c d e )m
+--R           + 
+--R                     4           3           4
+--R             (14A c e  + 2B c d e )m + 8A c e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                   4          3  3          4           3         2 2  2
+--R             (B a e  + A c d e )m  + (8B a e  + 5A c d e  - 3B c d e )m
+--R           + 
+--R                     4           3         2 2            4
+--R             (19B a e  + 4A c d e  - 3B c d e )m + 12B a e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                   4          3  3          4           3         2 2  2
+--R             (A a e  + B a d e )m  + (9A a e  + 7B a d e  - 2A c d e )m
+--R           + 
+--R                     4            3         2 2         3             4
+--R             (26A a e  + 12B a d e  - 8A c d e  + 6B c d e)m + 24A a e
+--R        *
+--R           x
+--R       + 
+--R                3 3            3        2 2  2
+--R         A a d e m  + (9A a d e  - B a d e )m
+--R       + 
+--R                   3         2 2         3               3          2 2
+--R         (26A a d e  - 7B a d e  + 2A c d e)m + 24A a d e  - 12B a d e
+--R       + 
+--R               3          4
+--R         8A c d e - 6B c d
+--R    *
+--R         m log(e x + d)
+--R       %e
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     e m  + 10e m  + 35e m  + 50e m + 24e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1029
+
+--S 1030 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 4 3         4 2          4          4  4
+--R           (B c e m  + 6B c e m  + 11B c e m + 6B c e )x
+--R         + 
+--R                     4          3  3          4           3  2
+--R               (A c e  + B c d e )m  + (7A c e  + 3B c d e )m
+--R             + 
+--R                       4           3           4
+--R               (14A c e  + 2B c d e )m + 8A c e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     4          3  3          4           3         2 2  2
+--R               (B a e  + A c d e )m  + (8B a e  + 5A c d e  - 3B c d e )m
+--R             + 
+--R                       4           3         2 2            4
+--R               (19B a e  + 4A c d e  - 3B c d e )m + 12B a e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     4          3  3          4           3         2 2  2
+--R               (A a e  + B a d e )m  + (9A a e  + 7B a d e  - 2A c d e )m
+--R             + 
+--R                       4            3         2 2         3             4
+--R               (26A a e  + 12B a d e  - 8A c d e  + 6B c d e)m + 24A a e
+--R          *
+--R             x
+--R         + 
+--R                  3 3            3        2 2  2
+--R           A a d e m  + (9A a d e  - B a d e )m
+--R         + 
+--R                     3         2 2         3               3          2 2
+--R           (26A a d e  - 7B a d e  + 2A c d e)m + 24A a d e  - 12B a d e
+--R         + 
+--R                 3          4
+--R           8A c d e - 6B c d
+--R      *
+--R           m log(e x + d)
+--R         %e
+--R     + 
+--R               3         2                           m + 4
+--R       (- B c m  - 6B c m  - 11B c m - 6B c)(e x + d)
+--R     + 
+--R                              3                        2
+--R           (- A c e + 3B c d)m  + (- 7A c e + 21B c d)m
+--R         + 
+--R           (- 14A c e + 42B c d)m - 8A c e + 24B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                   2                    2  3
+--R           (- B a e  + 2A c d e - 3B c d )m
+--R         + 
+--R                    2                      2  2
+--R           (- 8B a e  + 16A c d e - 24B c d )m
+--R         + 
+--R                   2                      2            2                      2
+--R         (- 19B a e  + 38A c d e - 57B c d )m - 12B a e  + 24A c d e - 36B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R                   3          2        2         3  3
+--R           (- A a e  + B a d e  - A c d e + B c d )m
+--R         + 
+--R                    3           2         2          3  2
+--R           (- 9A a e  + 9B a d e  - 9A c d e + 9B c d )m
+--R         + 
+--R                     3            2          2           3            3
+--R           (- 26A a e  + 26B a d e  - 26A c d e + 26B c d )m - 24A a e
+--R         + 
+--R                    2          2           3
+--R           24B a d e  - 24A c d e + 24B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     e m  + 10e m  + 35e m  + 50e m + 24e
+--R                                                    Type: Expression(Integer)
+--E 1030
+
+--S 1031 of 1457
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1031
+
+)clear all
+
+--S 1032 of 1457
+t0:=(A+B*x)*(d+e*x)^5*(a+c*x^2)
+--R 
+--R
+--R   (1)
+--R          5 8         5           4  7         5           4          2 3  6
+--R     B c e x  + (A c e  + 5B c d e )x  + (B a e  + 5A c d e  + 10B c d e )x
+--R   + 
+--R           5           4          2 3          3 2  5
+--R     (A a e  + 5B a d e  + 10A c d e  + 10B c d e )x
+--R   + 
+--R              4          2 3          3 2         4   4
+--R     (5A a d e  + 10B a d e  + 10A c d e  + 5B c d e)x
+--R   + 
+--R             2 3          3 2         4         5  3
+--R     (10A a d e  + 10B a d e  + 5A c d e + B c d )x
+--R   + 
+--R             3 2         4         5  2          4         5          5
+--R     (10A a d e  + 5B a d e + A c d )x  + (5A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1032
+
+--S 1033 of 1457
+r0:=-1/6*(B*d-A*e)*(c*d^2+a*e^2)*(d+e*x)^6/e^4+1/7*(3*B*c*d^2-2*A*c*d*e+_
+     a*B*e^2)*(d+e*x)^7/e^4-1/8*c*(3*B*d-A*e)*(d+e*x)^8/e^4+1/9*B*_
+     c*(d+e*x)^9/e^4
+--R 
+--R
+--R   (2)
+--R       1      9 9    1      9   5        8  8
+--R       - B c e x  + (- A c e  + - B c d e )x
+--R       9             8          8
+--R     + 
+--R        1      9   5        8   10      2 7  7
+--R       (- B a e  + - A c d e  + -- B c d e )x
+--R        7          7             7
+--R     + 
+--R        1      9   5        8   5      2 7   5      3 6  6
+--R       (- A a e  + - B a d e  + - A c d e  + - B c d e )x
+--R        6          6            3            3
+--R     + 
+--R               8         2 7         3 6        4 5  5
+--R       (A a d e  + 2B a d e  + 2A c d e  + B c d e )x
+--R     + 
+--R        5      2 7   5      3 6   5      4 5   1      5 4  4
+--R       (- A a d e  + - B a d e  + - A c d e  + - B c d e )x
+--R        2            2            4            4
+--R     + 
+--R        10      3 6   5      4 5   1      5 4  3    5      4 5   1      5 4  2
+--R       (-- A a d e  + - B a d e  + - A c d e )x  + (- A a d e  + - B a d e )x
+--R         3            3            3                2            2
+--R     + 
+--R            5 4    1      6 3    1      7 2    1       8     1       9
+--R       A a d e x + - A a d e  - -- B a d e  + --- A c d e - --- B c d
+--R                   6            42            168           504
+--R  /
+--R      4
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1033
+
+--S 1034 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1      5 9    1      5   5        4  8
+--R     - B c e x  + (- A c e  + - B c d e )x
+--R     9             8          8
+--R   + 
+--R      1      5   5        4   10      2 3  7
+--R     (- B a e  + - A c d e  + -- B c d e )x
+--R      7          7             7
+--R   + 
+--R      1      5   5        4   5      2 3   5      3 2  6
+--R     (- A a e  + - B a d e  + - A c d e  + - B c d e )x
+--R      6          6            3            3
+--R   + 
+--R             4         2 3         3 2        4   5
+--R     (A a d e  + 2B a d e  + 2A c d e  + B c d e)x
+--R   + 
+--R      5      2 3   5      3 2   5      4    1      5  4
+--R     (- A a d e  + - B a d e  + - A c d e + - B c d )x
+--R      2            2            4           4
+--R   + 
+--R    10      3 2   5      4    1      5  3    5      4    1      5  2        5
+--R   (-- A a d e  + - B a d e + - A c d )x  + (- A a d e + - B a d )x  + A a d x
+--R     3            3           3              2           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1034
+
+--S 1035 of 1457
+m0:=a0-r0
+--R 
+--R
+--R          1      6 3    1      7 2    1       8     1       9
+--R        - - A a d e  + -- B a d e  - --- A c d e + --- B c d
+--R          6            42            168           504
+--R   (4)  -----------------------------------------------------
+--R                                   4
+--R                                  e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1035
+
+--S 1036 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1036
+
+)clear all
+
+--S 1037 of 1457
+t0:=(A+B*x)*(d+e*x)^4*(a+c*x^2)
+--R 
+--R
+--R   (1)
+--R          4 7         4           3  6         4           3         2 2  5
+--R     B c e x  + (A c e  + 4B c d e )x  + (B a e  + 4A c d e  + 6B c d e )x
+--R   + 
+--R           4           3         2 2         3   4
+--R     (A a e  + 4B a d e  + 6A c d e  + 4B c d e)x
+--R   + 
+--R              3         2 2         3         4  3
+--R     (4A a d e  + 6B a d e  + 4A c d e + B c d )x
+--R   + 
+--R            2 2         3         4  2          3         4          4
+--R     (6A a d e  + 4B a d e + A c d )x  + (4A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1037
+
+--S 1038 of 1457
+r0:=-1/5*(B*d-A*e)*(c*d^2+a*e^2)*(d+e*x)^5/e^4+1/6*(3*B*c*d^2-2*A*c*d*e+_
+     a*B*e^2)*(d+e*x)^6/e^4-1/7*c*(3*B*d-A*e)*(d+e*x)^7/e^4+1/8*B*c*_
+     (d+e*x)^8/e^4
+--R 
+--R
+--R   (2)
+--R       1      8 8    1      8   4        7  7
+--R       - B c e x  + (- A c e  + - B c d e )x
+--R       8             7          7
+--R     + 
+--R        1      8   2        7        2 6  6
+--R       (- B a e  + - A c d e  + B c d e )x
+--R        6          3
+--R     + 
+--R        1      8   4        7   6      2 6   4      3 5  5
+--R       (- A a e  + - B a d e  + - A c d e  + - B c d e )x
+--R        5          5            5            5
+--R     + 
+--R               7   3      2 6        3 5   1      4 4  4
+--R       (A a d e  + - B a d e  + A c d e  + - B c d e )x
+--R                   2                       4
+--R     + 
+--R              2 6   4      3 5   1      4 4  3          3 5   1      4 4  2
+--R       (2A a d e  + - B a d e  + - A c d e )x  + (2A a d e  + - B a d e )x
+--R                    3            3                            2
+--R     + 
+--R            4 4    1      5 3    1      6 2    1       7     1       8
+--R       A a d e x + - A a d e  - -- B a d e  + --- A c d e - --- B c d
+--R                   5            30            105           280
+--R  /
+--R      4
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1038
+
+--S 1039 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1      4 8    1      4   4        3  7
+--R     - B c e x  + (- A c e  + - B c d e )x
+--R     8             7          7
+--R   + 
+--R      1      4   2        3        2 2  6
+--R     (- B a e  + - A c d e  + B c d e )x
+--R      6          3
+--R   + 
+--R      1      4   4        3   6      2 2   4      3   5
+--R     (- A a e  + - B a d e  + - A c d e  + - B c d e)x
+--R      5          5            5            5
+--R   + 
+--R             3   3      2 2        3    1      4  4
+--R     (A a d e  + - B a d e  + A c d e + - B c d )x
+--R                 2                      4
+--R   + 
+--R            2 2   4      3    1      4  3          3    1      4  2        4
+--R     (2A a d e  + - B a d e + - A c d )x  + (2A a d e + - B a d )x  + A a d x
+--R                  3           3                         2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1039
+
+--S 1040 of 1457
+m0:=a0-r0
+--R 
+--R
+--R          1      5 3    1      6 2    1       7     1       8
+--R        - - A a d e  + -- B a d e  - --- A c d e + --- B c d
+--R          5            30            105           280
+--R   (4)  -----------------------------------------------------
+--R                                   4
+--R                                  e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1040
+
+--S 1041 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1041
+
+)clear all
+
+--S 1042 of 1457
+t0:=(A+B*x)*(d+e*x)^3*(a+c*x^2)
+--R 
+--R
+--R   (1)
+--R          3 6         3           2  5         3           2         2   4
+--R     B c e x  + (A c e  + 3B c d e )x  + (B a e  + 3A c d e  + 3B c d e)x
+--R   + 
+--R           3           2         2         3  3
+--R     (A a e  + 3B a d e  + 3A c d e + B c d )x
+--R   + 
+--R              2         2         3  2          2         3          3
+--R     (3A a d e  + 3B a d e + A c d )x  + (3A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1042
+
+--S 1043 of 1457
+r0:=-1/4*(B*d-A*e)*(c*d^2+a*e^2)*(d+e*x)^4/e^4+1/5*(3*B*c*d^2-2*A*c*d*e+_
+     a*B*e^2)*(d+e*x)^5/e^4-1/6*c*(3*B*d-A*e)*(d+e*x)^6/e^4+_
+     1/7*B*c*(d+e*x)^7/e^4
+--R 
+--R
+--R   (2)
+--R       1      7 7    1      7   1        6  6
+--R       - B c e x  + (- A c e  + - B c d e )x
+--R       7             6          2
+--R     + 
+--R        1      7   3        6   3      2 5  5
+--R       (- B a e  + - A c d e  + - B c d e )x
+--R        5          5            5
+--R     + 
+--R        1      7   3        6   3      2 5   1      3 4  4
+--R       (- A a e  + - B a d e  + - A c d e  + - B c d e )x
+--R        4          4            4            4
+--R     + 
+--R               6        2 5   1      3 4  3    3      2 5   1      3 4  2
+--R       (A a d e  + B a d e  + - A c d e )x  + (- A a d e  + - B a d e )x
+--R                              3                2            2
+--R     + 
+--R            3 4    1      4 3    1      5 2    1      6     1       7
+--R       A a d e x + - A a d e  - -- B a d e  + -- A c d e - --- B c d
+--R                   4            20            60           140
+--R  /
+--R      4
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1043
+
+--S 1044 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1      3 7    1      3   1        2  6
+--R     - B c e x  + (- A c e  + - B c d e )x
+--R     7             6          2
+--R   + 
+--R      1      3   3        2   3      2   5
+--R     (- B a e  + - A c d e  + - B c d e)x
+--R      5          5            5
+--R   + 
+--R      1      3   3        2   3      2    1      3  4
+--R     (- A a e  + - B a d e  + - A c d e + - B c d )x
+--R      4          4            4           4
+--R   + 
+--R             2        2    1      3  3    3      2    1      3  2        3
+--R     (A a d e  + B a d e + - A c d )x  + (- A a d e + - B a d )x  + A a d x
+--R                           3              2           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1044
+
+--S 1045 of 1457
+m0:=a0-r0
+--R 
+--R
+--R          1      4 3    1      5 2    1      6     1       7
+--R        - - A a d e  + -- B a d e  - -- A c d e + --- B c d
+--R          4            20            60           140
+--R   (4)  ----------------------------------------------------
+--R                                  4
+--R                                 e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1045
+
+--S 1046 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1046
+
+)clear all
+
+--S 1047 of 1457
+t0:=(A+B*x)*(d+e*x)^2*(a+c*x^2)
+--R 
+--R
+--R   (1)
+--R          2 5         2             4         2                   2  3
+--R     B c e x  + (A c e  + 2B c d e)x  + (B a e  + 2A c d e + B c d )x
+--R   + 
+--R           2                   2  2                    2          2
+--R     (A a e  + 2B a d e + A c d )x  + (2A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1047
+
+--S 1048 of 1457
+r0:=a*A*d^2*x+1/2*a*d*(B*d+2*A*e)*x^2+1/3*(A*c*d^2+2*a*B*d*e+a*A*e^2)*x^3+_
+     1/4*(B*c*d^2+2*A*c*d*e+a*B*e^2)*x^4+1/5*c*e*(2*B*d+A*e)*x^5+_
+     1/6*B*c*e^2*x^6
+--R 
+--R
+--R   (2)
+--R     1      2 6    1      2   2          5    1      2   1           1      2  4
+--R     - B c e x  + (- A c e  + - B c d e)x  + (- B a e  + - A c d e + - B c d )x
+--R     6             5          5               4          2           4
+--R   + 
+--R      1      2   2           1      2  3              1      2  2        2
+--R     (- A a e  + - B a d e + - A c d )x  + (A a d e + - B a d )x  + A a d x
+--R      3          3           3                        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1048
+
+--S 1049 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1      2 6    1      2   2          5    1      2   1           1      2  4
+--R     - B c e x  + (- A c e  + - B c d e)x  + (- B a e  + - A c d e + - B c d )x
+--R     6             5          5               4          2           4
+--R   + 
+--R      1      2   2           1      2  3              1      2  2        2
+--R     (- A a e  + - B a d e + - A c d )x  + (A a d e + - B a d )x  + A a d x
+--R      3          3           3                        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1049
+
+--S 1050 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1050
+
+--S 1051 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1051
+
+)clear all
+
+--S 1052 of 1457
+t0:=(A+B*x)*(d+e*x)*(a+c*x^2)
+--R 
+--R
+--R   (1)
+--R          4                   3                   2
+--R   B c e x  + (A c e + B c d)x  + (B a e + A c d)x  + (A a e + B a d)x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1052
+
+--S 1053 of 1457
+r0:=a*A*d*x+1/2*a*(B*d+A*e)*x^2+1/3*(A*c*d+a*B*e)*x^3+1/4*c*(B*d+A*e)*x^4+_
+     1/5*B*c*e*x^5
+--R 
+--R
+--R   (2)
+--R     1        5    1         1        4    1         1        3
+--R     - B c e x  + (- A c e + - B c d)x  + (- B a e + - A c d)x
+--R     5             4         4             3         3
+--R   + 
+--R      1         1        2
+--R     (- A a e + - B a d)x  + A a d x
+--R      2         2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1053
+
+--S 1054 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1        5    1         1        4    1         1        3
+--R     - B c e x  + (- A c e + - B c d)x  + (- B a e + - A c d)x
+--R     5             4         4             3         3
+--R   + 
+--R      1         1        2
+--R     (- A a e + - B a d)x  + A a d x
+--R      2         2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1054
+
+--S 1055 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1055
+
+--S 1056 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1056
+
+)clear all
+
+--S 1057 of 1457
+t0:=(A+B*x)*(a+c*x^2)
+--R 
+--R
+--R             3        2
+--R   (1)  B c x  + A c x  + B a x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 1057
+
+--S 1058 of 1457
+r0:=a*A*x+1/2*a*B*x^2+1/3*A*c*x^3+1/4*B*c*x^4
+--R 
+--R
+--R        1      4   1      3   1      2
+--R   (2)  - B c x  + - A c x  + - B a x  + A a x
+--R        4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1058
+
+--S 1059 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1      4   1      3   1      2
+--R   (3)  - B c x  + - A c x  + - B a x  + A a x
+--R        4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1059
+
+--S 1060 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1060
+
+--S 1061 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1061
+
+)clear all
+
+--S 1062 of 1457
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)
+--R 
+--R
+--R             3        2
+--R        B c x  + A c x  + B a x + A a
+--R   (1)  -----------------------------
+--R                   e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1062
+
+--S 1063 of 1457
+r0:=(B*c*d^2-A*c*d*e+a*B*e^2)*x/e^3-1/2*c*(B*d-A*e)*x^2/e^2+1/3*B*c*x^3/e-_
+     (B*d-A*e)*(c*d^2+a*e^2)*log(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R              3           2         2          3                      3 3
+--R       (6A a e  - 6B a d e  + 6A c d e - 6B c d )log(e x + d) + 2B c e x
+--R     + 
+--R              3           2  2          3           2         2
+--R       (3A c e  - 3B c d e )x  + (6B a e  - 6A c d e  + 6B c d e)x
+--R  /
+--R       4
+--R     6e
+--R                                                    Type: Expression(Integer)
+--E 1063
+
+--S 1064 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3           2         2          3                      3 3
+--R       (6A a e  - 6B a d e  + 6A c d e - 6B c d )log(e x + d) + 2B c e x
+--R     + 
+--R              3           2  2          3           2         2
+--R       (3A c e  - 3B c d e )x  + (6B a e  - 6A c d e  + 6B c d e)x
+--R  /
+--R       4
+--R     6e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1064
+
+--S 1065 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1065
+
+--S 1066 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1066
+
+)clear all
+
+--S 1067 of 1457
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^2
+--R 
+--R
+--R             3        2
+--R        B c x  + A c x  + B a x + A a
+--R   (1)  -----------------------------
+--R               2 2             2
+--R              e x  + 2d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1067
+
+--S 1068 of 1457
+r0:=-c*(2*B*d-A*e)*x/e^3+1/2*B*c*x^2/e^2+(B*d-A*e)*(c*d^2+a*e^2)/_
+     (e^4*(d+e*x))+(3*B*c*d^2-2*A*c*d*e+a*B*e^2)*log(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R                 3           2         2              2         2          3
+--R         ((2B a e  - 4A c d e  + 6B c d e)x + 2B a d e  - 4A c d e + 6B c d )
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 3          3           2  2            2         2            3
+--R       B c e x  + (2A c e  - 3B c d e )x  + (2A c d e  - 4B c d e)x - 2A a e
+--R     + 
+--R               2         2          3
+--R       2B a d e  - 2A c d e + 2B c d
+--R  /
+--R       5        4
+--R     2e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 1068
+
+--S 1069 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3           2         2              2         2          3
+--R         ((2B a e  - 4A c d e  + 6B c d e)x + 2B a d e  - 4A c d e + 6B c d )
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 3          3           2  2            2         2            3
+--R       B c e x  + (2A c e  - 3B c d e )x  + (2A c d e  - 4B c d e)x - 2A a e
+--R     + 
+--R               2         2          3
+--R       2B a d e  - 2A c d e + 2B c d
+--R  /
+--R       5        4
+--R     2e x + 2d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1069
+
+--S 1070 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1070
+
+--S 1071 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1071
+
+)clear all
+
+--S 1072 of 1457
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^3
+--R 
+--R
+--R             3        2
+--R        B c x  + A c x  + B a x + A a
+--R   (1)  -----------------------------
+--R          3 3       2 2     2       3
+--R         e x  + 3d e x  + 3d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1072
+
+--S 1073 of 1457
+r0:=B*c*x/e^3+1/2*(B*d-A*e)*(c*d^2+a*e^2)/(e^4*(d+e*x)^2)+(-3*B*c*d^2+_
+     2*A*c*d*e-a*B*e^2)/(e^4*(d+e*x))-c*(3*B*d-A*e)*log(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R                    3           2  2            2          2            2
+--R             (2A c e  - 6B c d e )x  + (4A c d e  - 12B c d e)x + 2A c d e
+--R           + 
+--R                     3
+--R             - 6B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R             3 3           2 2            3           2         2           3
+--R       2B c e x  + 4B c d e x  + (- 2B a e  + 4A c d e  - 4B c d e)x - A a e
+--R     + 
+--R                2         2          3
+--R       - B a d e  + 3A c d e - 5B c d
+--R  /
+--R       6 2       5      2 4
+--R     2e x  + 4d e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 1073
+
+--S 1074 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    3           2  2            2          2            2
+--R             (2A c e  - 6B c d e )x  + (4A c d e  - 12B c d e)x + 2A c d e
+--R           + 
+--R                     3
+--R             - 6B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R             3 3           2 2            3           2         2           3
+--R       2B c e x  + 4B c d e x  + (- 2B a e  + 4A c d e  - 4B c d e)x - A a e
+--R     + 
+--R                2         2          3
+--R       - B a d e  + 3A c d e - 5B c d
+--R  /
+--R       6 2       5      2 4
+--R     2e x  + 4d e x + 2d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1074
+
+--S 1075 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1075
+
+--S 1076 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1076
+
+)clear all
+
+--S 1077 of 1457
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^4
+--R 
+--R
+--R                  3        2
+--R             B c x  + A c x  + B a x + A a
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1077
+
+--S 1078 of 1457
+r0:=1/3*(B*d-A*e)*(c*d^2+a*e^2)/(e^4*(d+e*x)^3)+1/2*(-3*B*c*d^2+2*A*c*d*e-_
+     a*B*e^2)/(e^4*(d+e*x)^2)+c*(3*B*d-A*e)/(e^4*(d+e*x))+B*c*log(d+e*x)/e^4
+--R 
+--R
+--R   (2)
+--R              3 3            2 2          2            3
+--R       (6B c e x  + 18B c d e x  + 18B c d e x + 6B c d )log(e x + d)
+--R     + 
+--R                3            2  2            3           2          2
+--R       (- 6A c e  + 18B c d e )x  + (- 3B a e  - 6A c d e  + 27B c d e)x
+--R     + 
+--R               3          2         2           3
+--R       - 2A a e  - B a d e  - 2A c d e + 11B c d
+--R  /
+--R       7 3        6 2      2 5      3 4
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 1078
+
+--S 1079 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 3            2 2          2            3
+--R       (6B c e x  + 18B c d e x  + 18B c d e x + 6B c d )log(e x + d)
+--R     + 
+--R                3            2  2            3           2          2
+--R       (- 6A c e  + 18B c d e )x  + (- 3B a e  - 6A c d e  + 27B c d e)x
+--R     + 
+--R               3          2         2           3
+--R       - 2A a e  - B a d e  - 2A c d e + 11B c d
+--R  /
+--R       7 3        6 2      2 5      3 4
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1079
+
+--S 1080 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1080
+
+--S 1081 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1081
+
+)clear all
+
+--S 1082 of 1457
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^5
+--R 
+--R
+--R                        3        2
+--R                   B c x  + A c x  + B a x + A a
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1082
+
+--S 1083 of 1457
+r0:=1/4*(B*d-A*e)*(c*d^2+a*e^2)/(e^4*(d+e*x)^4)+1/3*(-3*B*c*d^2+2*A*c*d*e-_
+     a*B*e^2)/(e^4*(d+e*x)^3)+1/2*c*(3*B*d-A*e)/(e^4*(d+e*x)^2)-_
+     B*c/(e^4*(d+e*x))
+--R 
+--R
+--R   (2)
+--R              3 3      1      3   3        2  2
+--R       - B c e x  + (- - A c e  - - B c d e )x
+--R                       2          2
+--R     + 
+--R          1      3   1        2        2      1      3    1        2
+--R       (- - B a e  - - A c d e  - B c d e)x - - A a e  - -- B a d e
+--R          3          3                        4          12
+--R     + 
+--R          1      2    1      3
+--R       - -- A c d e - - B c d
+--R         12           4
+--R  /
+--R      8 4       7 3     2 6 2     3 5     4 4
+--R     e x  + 4d e x  + 6d e x  + 4d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1083
+
+--S 1084 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 3            3            2  2
+--R       - 12B c e x  + (- 6A c e  - 18B c d e )x
+--R     + 
+--R                3           2          2            3          2        2
+--R       (- 4B a e  - 4A c d e  - 12B c d e)x - 3A a e  - B a d e  - A c d e
+--R     + 
+--R               3
+--R       - 3B c d
+--R  /
+--R        8 4        7 3      2 6 2      3 5       4 4
+--R     12e x  + 48d e x  + 72d e x  + 48d e x + 12d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1084
+
+--S 1085 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1085
+
+--S 1086 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1086
+
+)clear all
+
+--S 1087 of 1457
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^6
+--R 
+--R
+--R                             3        2
+--R                        B c x  + A c x  + B a x + A a
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1087
+
+--S 1088 of 1457
+r0:=1/5*(B*d-A*e)*(c*d^2+a*e^2)/(e^4*(d+e*x)^5)+1/4*(-3*B*c*d^2+2*A*c*d*e-_
+     a*B*e^2)/(e^4*(d+e*x)^4)+1/3*c*(3*B*d-A*e)/(e^4*(d+e*x)^3)-_
+     1/2*B*c/(e^4*(d+e*x)^2)
+--R 
+--R
+--R   (2)
+--R         1      3 3      1      3   1        2  2
+--R       - - B c e x  + (- - A c e  - - B c d e )x
+--R         2               3          2
+--R     + 
+--R          1      3   1        2   1      2      1      3    1        2
+--R       (- - B a e  - - A c d e  - - B c d e)x - - A a e  - -- B a d e
+--R          4          6            4             5          20
+--R     + 
+--R          1      2     1      3
+--R       - -- A c d e - -- B c d
+--R         30           20
+--R  /
+--R      9 5       8 4      2 7 3      3 6 2     4 5     5 4
+--R     e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1088
+
+--S 1089 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 3             3            2  2
+--R       - 30B c e x  + (- 20A c e  - 30B c d e )x
+--R     + 
+--R                 3            2          2             3           2         2
+--R       (- 15B a e  - 10A c d e  - 15B c d e)x - 12A a e  - 3B a d e  - 2A c d e
+--R     + 
+--R               3
+--R       - 3B c d
+--R  /
+--R        9 5         8 4       2 7 3       3 6 2       4 5       5 4
+--R     60e x  + 300d e x  + 600d e x  + 600d e x  + 300d e x + 60d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1089
+
+--S 1090 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1090
+
+--S 1091 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1091
+
+)clear all
+
+--S 1092 of 1457
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^7
+--R 
+--R
+--R   (1)
+--R                              3        2
+--R                         B c x  + A c x  + B a x + A a
+--R   ------------------------------------------------------------------------
+--R    7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R   e x  + 7d e x  + 21d e x  + 35d e x  + 35d e x  + 21d e x  + 7d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1092
+
+--S 1093 of 1457
+r0:=1/6*(B*d-A*e)*(c*d^2+a*e^2)/(e^4*(d+e*x)^6)+1/5*(-3*B*c*d^2+2*A*c*d*e-_
+     a*B*e^2)/(e^4*(d+e*x)^5)+1/4*c*(3*B*d-A*e)/(e^4*(d+e*x)^4)-_
+     1/3*B*c/(e^4*(d+e*x)^3)
+--R 
+--R
+--R   (2)
+--R         1      3 3      1      3   1        2  2
+--R       - - B c e x  + (- - A c e  - - B c d e )x
+--R         3               4          4
+--R     + 
+--R          1      3    1        2    1      2      1      3    1        2
+--R       (- - B a e  - -- A c d e  - -- B c d e)x - - A a e  - -- B a d e
+--R          5          10            10             6          30
+--R     + 
+--R          1      2     1      3
+--R       - -- A c d e - -- B c d
+--R         60           60
+--R  /
+--R      10 6       9 5      2 8 4      3 7 3      4 6 2     5 5     6 4
+--R     e  x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1093
+
+--S 1094 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 3             3            2  2
+--R       - 20B c e x  + (- 15A c e  - 15B c d e )x
+--R     + 
+--R                 3           2         2             3           2        2
+--R       (- 12B a e  - 6A c d e  - 6B c d e)x - 10A a e  - 2B a d e  - A c d e
+--R     + 
+--R              3
+--R       - B c d
+--R  /
+--R          10 6         9 5       2 8 4        3 7 3       4 6 2       5 5
+--R       60e  x  + 360d e x  + 900d e x  + 1200d e x  + 900d e x  + 360d e x
+--R     + 
+--R          6 4
+--R       60d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1094
+
+--S 1095 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1095
+
+--S 1096 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1096
+
+)clear all
+
+--S 1097 of 1457
+t0:=(A+B*x)*(d+e*x)^m*(a+c*x^2)^2
+--R 
+--R
+--R            2 5      2 4           3           2      2       2          m
+--R   (1)  (B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a )(e x + d)
+--R                                                    Type: Expression(Integer)
+--E 1097
+
+--S 1098 of 1457
+r0:=-(B*d-A*e)*(c*d^2+a*e^2)^2*(d+e*x)^(1+m)/(e^6*(1+m))+(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)*(d+e*x)^(2+m)/(e^6*(2+m))-2*c*_
+     (5*B*c*d^3-3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^(3+m)/(e^6*_
+     (3+m))+2*c*(5*B*c*d^2-2*A*c*d*e+a*B*e^2)*(d+e*x)^(4+m)/(e^6*(4+m))-_
+     c^2*(5*B*d-A*e)*(d+e*x)^(5+m)/(e^6*(5+m))+B*c^2*(d+e*x)^(6+m)/(e^6*(6+m))
+--R 
+--R
+--R   (2)
+--R             2 5        2 4        2 3         2 2         2          2
+--R         (B c m  + 15B c m  + 85B c m  + 225B c m  + 274B c m + 120B c )
+--R      *
+--R                  m + 6
+--R         (e x + d)
+--R     + 
+--R               2        2   5         2         2   4         2          2   3
+--R           (A c e - 5B c d)m  + (16A c e - 80B c d)m  + (95A c e - 475B c d)m
+--R         + 
+--R                  2           2   2          2           2            2
+--R           (260A c e - 1300B c d)m  + (324A c e - 1620B c d)m + 144A c e
+--R         + 
+--R                   2
+--R           - 720B c d
+--R      *
+--R                  m + 5
+--R         (e x + d)
+--R     + 
+--R                    2       2           2 2  5
+--R           (2B a c e  - 4A c d e + 10B c d )m
+--R         + 
+--R                     2        2            2 2  4
+--R           (34B a c e  - 68A c d e + 170B c d )m
+--R         + 
+--R                      2         2             2 2  3
+--R           (214B a c e  - 428A c d e + 1070B c d )m
+--R         + 
+--R                      2          2             2 2  2
+--R           (614B a c e  - 1228A c d e + 3070B c d )m
+--R         + 
+--R                      2          2             2 2               2         2
+--R           (792B a c e  - 1584A c d e + 3960B c d )m + 360B a c e  - 720A c d e
+--R         + 
+--R                  2 2
+--R           1800B c d
+--R      *
+--R                  m + 4
+--R         (e x + d)
+--R     + 
+--R                    3             2       2 2         2 3  5
+--R           (2A a c e  - 6B a c d e  + 6A c d e - 10B c d )m
+--R         + 
+--R                     3               2         2 2          2 3  4
+--R           (36A a c e  - 108B a c d e  + 108A c d e - 180B c d )m
+--R         + 
+--R                      3               2         2 2           2 3  3
+--R           (242A a c e  - 726B a c d e  + 726A c d e - 1210B c d )m
+--R         + 
+--R                      3                2          2 2           2 3  2
+--R           (744A a c e  - 2232B a c d e  + 2232A c d e - 3720B c d )m
+--R         + 
+--R                       3                2          2 2           2 3
+--R           (1016A a c e  - 3048B a c d e  + 3048A c d e - 5080B c d )m
+--R         + 
+--R                     3                2          2 2           2 3
+--R           480A a c e  - 1440B a c d e  + 1440A c d e - 2400B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R               2 4             3           2 2       2 3        2 4  5
+--R           (B a e  - 4A a c d e  + 6B a c d e  - 4A c d e + 5B c d )m
+--R         + 
+--R                 2 4              3             2 2        2 3         2 4  4
+--R           (19B a e  - 76A a c d e  + 114B a c d e  - 76A c d e + 95B c d )m
+--R         + 
+--R                       2 4               3             2 2         2 3
+--R                 137B a e  - 548A a c d e  + 822B a c d e  - 548A c d e
+--R               + 
+--R                       2 4
+--R                 685B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                     2 4                3              2 2          2 3
+--R               461B a e  - 1844A a c d e  + 2766B a c d e  - 1844A c d e
+--R             + 
+--R                      2 4
+--R               2305B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                     2 4                3              2 2          2 3
+--R               702B a e  - 2808A a c d e  + 4212B a c d e  - 2808A c d e
+--R             + 
+--R                      2 4
+--R               3510B c d
+--R          *
+--R             m
+--R         + 
+--R               2 4                3              2 2          2 3           2 4
+--R         360B a e  - 1440A a c d e  + 2160B a c d e  - 1440A c d e + 1800B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R               2 5      2   4           2 3           3 2      2 4       2 5  5
+--R           (A a e  - B a d e  + 2A a c d e  - 2B a c d e  + A c d e - B c d )m
+--R         + 
+--R                    2 5        2   4            2 3            3 2        2 4
+--R               20A a e  - 20B a d e  + 40A a c d e  - 40B a c d e  + 20A c d e
+--R             + 
+--R                      2 5
+--R               - 20B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                     2 5         2   4             2 3             3 2
+--R               155A a e  - 155B a d e  + 310A a c d e  - 310B a c d e
+--R             + 
+--R                     2 4          2 5
+--R               155A c d e - 155B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                     2 5         2   4              2 3              3 2
+--R               580A a e  - 580B a d e  + 1160A a c d e  - 1160B a c d e
+--R             + 
+--R                     2 4          2 5
+--R               580A c d e - 580B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                      2 5          2   4              2 3              3 2
+--R               1044A a e  - 1044B a d e  + 2088A a c d e  - 2088B a c d e
+--R             + 
+--R                      2 4           2 5
+--R               1044A c d e - 1044B c d
+--R          *
+--R             m
+--R         + 
+--R                 2 5         2   4              2 3              3 2
+--R           720A a e  - 720B a d e  + 1440A a c d e  - 1440B a c d e
+--R         + 
+--R                 2 4          2 5
+--R           720A c d e - 720B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     e m  + 21e m  + 175e m  + 735e m  + 1624e m  + 1764e m + 720e
+--R                                                    Type: Expression(Integer)
+--E 1098
+
+--S 1099 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 6 5        2 6 4        2 6 3         2 6 2         2 6
+--R             B c e m  + 15B c e m  + 85B c e m  + 225B c e m  + 274B c e m
+--R           + 
+--R                   2 6
+--R             120B c e
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                 2 6      2   5  5         2 6        2   5  4
+--R             (A c e  + B c d e )m  + (16A c e  + 10B c d e )m
+--R           + 
+--R                   2 6        2   5  3          2 6        2   5  2
+--R             (95A c e  + 35B c d e )m  + (260A c e  + 50B c d e )m
+--R           + 
+--R                    2 6        2   5           2 6
+--R             (324A c e  + 24B c d e )m + 144A c e
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                      6      2   5  5             6        2   5       2 2 4  4
+--R             (2B a c e  + A c d e )m  + (34B a c e  + 12A c d e  - 5B c d e )m
+--R           + 
+--R                        6        2   5        2 2 4  3
+--R             (214B a c e  + 47A c d e  - 30B c d e )m
+--R           + 
+--R                        6        2   5        2 2 4  2
+--R             (614B a c e  + 72A c d e  - 55B c d e )m
+--R           + 
+--R                        6        2   5        2 2 4               6
+--R             (792B a c e  + 36A c d e  - 30B c d e )m + 360B a c e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                      6             5  5
+--R             (2A a c e  + 2B a c d e )m
+--R           + 
+--R                       6              5       2 2 4  4
+--R             (36A a c e  + 28B a c d e  - 4A c d e )m
+--R           + 
+--R                        6               5        2 2 4        2 3 3  3
+--R             (242A a c e  + 130B a c d e  - 36A c d e  + 20B c d e )m
+--R           + 
+--R                        6               5        2 2 4        2 3 3  2
+--R             (744A a c e  + 224B a c d e  - 80A c d e  + 60B c d e )m
+--R           + 
+--R                         6               5        2 2 4        2 3 3
+--R             (1016A a c e  + 120B a c d e  - 48A c d e  + 40B c d e )m
+--R           + 
+--R                       6
+--R             480A a c e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                 2 6             5  5
+--R             (B a e  + 2A a c d e )m
+--R           + 
+--R                   2 6              5           2 4  4
+--R             (19B a e  + 32A a c d e  - 6B a c d e )m
+--R           + 
+--R                    2 6               5            2 4        2 3 3  3
+--R             (137B a e  + 178A a c d e  - 72B a c d e  + 12A c d e )m
+--R           + 
+--R                       2 6               5             2 4        2 3 3
+--R                 461B a e  + 388A a c d e  - 246B a c d e  + 84A c d e
+--R               + 
+--R                        2 4 2
+--R                 - 60B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                       2 6               5             2 4        2 3 3
+--R                 702B a e  + 240A a c d e  - 180B a c d e  + 72A c d e
+--R               + 
+--R                        2 4 2
+--R                 - 60B c d e
+--R            *
+--R               m
+--R           + 
+--R                   2 6
+--R             360B a e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                 2 6      2   5  5         2 6        2   5           2 4  4
+--R             (A a e  + B a d e )m  + (20A a e  + 18B a d e  - 4A a c d e )m
+--R           + 
+--R                    2 6         2   5            2 4            3 3  3
+--R             (155A a e  + 119B a d e  - 60A a c d e  + 12B a c d e )m
+--R           + 
+--R                       2 6         2   5             2 4             3 3
+--R                 580A a e  + 342B a d e  - 296A a c d e  + 132B a c d e
+--R               + 
+--R                        2 4 2
+--R                 - 24A c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                        2 6         2   5             2 4             3 3
+--R                 1044A a e  + 360B a d e  - 480A a c d e  + 360B a c d e
+--R               + 
+--R                         2 4 2         2 5
+--R                 - 144A c d e  + 120B c d e
+--R            *
+--R               m
+--R           + 
+--R                   2 6
+--R             720A a e
+--R        *
+--R           x
+--R       + 
+--R            2   5 5         2   5      2 2 4  4
+--R         A a d e m  + (20A a d e  - B a d e )m
+--R       + 
+--R                2   5        2 2 4           3 3  3
+--R         (155A a d e  - 18B a d e  + 4A a c d e )m
+--R       + 
+--R                2   5         2 2 4            3 3            4 2  2
+--R         (580A a d e  - 119B a d e  + 60A a c d e  - 12B a c d e )m
+--R       + 
+--R                    2   5         2 2 4             3 3             4 2
+--R             1044A a d e  - 342B a d e  + 296A a c d e  - 132B a c d e
+--R           + 
+--R                  2 5
+--R             24A c d e
+--R        *
+--R           m
+--R       + 
+--R               2   5         2 2 4             3 3             4 2         2 5
+--R         720A a d e  - 360B a d e  + 480A a c d e  - 360B a c d e  + 144A c d e
+--R       + 
+--R                 2 6
+--R         - 120B c d
+--R    *
+--R         m log(e x + d)
+--R       %e
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     e m  + 21e m  + 175e m  + 735e m  + 1624e m  + 1764e m + 720e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1099
+
+--S 1100 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  2 6 5        2 6 4        2 6 3         2 6 2         2 6
+--R               B c e m  + 15B c e m  + 85B c e m  + 225B c e m  + 274B c e m
+--R             + 
+--R                     2 6
+--R               120B c e
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                   2 6      2   5  5         2 6        2   5  4
+--R               (A c e  + B c d e )m  + (16A c e  + 10B c d e )m
+--R             + 
+--R                     2 6        2   5  3          2 6        2   5  2
+--R               (95A c e  + 35B c d e )m  + (260A c e  + 50B c d e )m
+--R             + 
+--R                      2 6        2   5           2 6
+--R               (324A c e  + 24B c d e )m + 144A c e
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                        6      2   5  5
+--R               (2B a c e  + A c d e )m
+--R             + 
+--R                         6        2   5       2 2 4  4
+--R               (34B a c e  + 12A c d e  - 5B c d e )m
+--R             + 
+--R                          6        2   5        2 2 4  3
+--R               (214B a c e  + 47A c d e  - 30B c d e )m
+--R             + 
+--R                          6        2   5        2 2 4  2
+--R               (614B a c e  + 72A c d e  - 55B c d e )m
+--R             + 
+--R                          6        2   5        2 2 4               6
+--R               (792B a c e  + 36A c d e  - 30B c d e )m + 360B a c e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        6             5  5
+--R               (2A a c e  + 2B a c d e )m
+--R             + 
+--R                         6              5       2 2 4  4
+--R               (36A a c e  + 28B a c d e  - 4A c d e )m
+--R             + 
+--R                          6               5        2 2 4        2 3 3  3
+--R               (242A a c e  + 130B a c d e  - 36A c d e  + 20B c d e )m
+--R             + 
+--R                          6               5        2 2 4        2 3 3  2
+--R               (744A a c e  + 224B a c d e  - 80A c d e  + 60B c d e )m
+--R             + 
+--R                           6               5        2 2 4        2 3 3
+--R               (1016A a c e  + 120B a c d e  - 48A c d e  + 40B c d e )m
+--R             + 
+--R                         6
+--R               480A a c e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   2 6             5  5
+--R               (B a e  + 2A a c d e )m
+--R             + 
+--R                     2 6              5           2 4  4
+--R               (19B a e  + 32A a c d e  - 6B a c d e )m
+--R             + 
+--R                      2 6               5            2 4        2 3 3  3
+--R               (137B a e  + 178A a c d e  - 72B a c d e  + 12A c d e )m
+--R             + 
+--R                         2 6               5             2 4        2 3 3
+--R                   461B a e  + 388A a c d e  - 246B a c d e  + 84A c d e
+--R                 + 
+--R                          2 4 2
+--R                   - 60B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                         2 6               5             2 4        2 3 3
+--R                   702B a e  + 240A a c d e  - 180B a c d e  + 72A c d e
+--R                 + 
+--R                          2 4 2
+--R                   - 60B c d e
+--R              *
+--R                 m
+--R             + 
+--R                     2 6
+--R               360B a e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   2 6      2   5  5         2 6        2   5           2 4  4
+--R               (A a e  + B a d e )m  + (20A a e  + 18B a d e  - 4A a c d e )m
+--R             + 
+--R                      2 6         2   5            2 4            3 3  3
+--R               (155A a e  + 119B a d e  - 60A a c d e  + 12B a c d e )m
+--R             + 
+--R                         2 6         2   5             2 4             3 3
+--R                   580A a e  + 342B a d e  - 296A a c d e  + 132B a c d e
+--R                 + 
+--R                          2 4 2
+--R                   - 24A c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                          2 6         2   5             2 4             3 3
+--R                   1044A a e  + 360B a d e  - 480A a c d e  + 360B a c d e
+--R                 + 
+--R                           2 4 2         2 5
+--R                   - 144A c d e  + 120B c d e
+--R              *
+--R                 m
+--R             + 
+--R                     2 6
+--R               720A a e
+--R          *
+--R             x
+--R         + 
+--R              2   5 5         2   5      2 2 4  4
+--R           A a d e m  + (20A a d e  - B a d e )m
+--R         + 
+--R                  2   5        2 2 4           3 3  3
+--R           (155A a d e  - 18B a d e  + 4A a c d e )m
+--R         + 
+--R                  2   5         2 2 4            3 3            4 2  2
+--R           (580A a d e  - 119B a d e  + 60A a c d e  - 12B a c d e )m
+--R         + 
+--R                      2   5         2 2 4             3 3             4 2
+--R               1044A a d e  - 342B a d e  + 296A a c d e  - 132B a c d e
+--R             + 
+--R                    2 5
+--R               24A c d e
+--R          *
+--R             m
+--R         + 
+--R                 2   5         2 2 4             3 3             4 2
+--R           720A a d e  - 360B a d e  + 480A a c d e  - 360B a c d e
+--R         + 
+--R                 2 5          2 6
+--R           144A c d e - 120B c d
+--R      *
+--R           m log(e x + d)
+--R         %e
+--R     + 
+--R               2 5        2 4        2 3         2 2         2          2
+--R         (- B c m  - 15B c m  - 85B c m  - 225B c m  - 274B c m - 120B c )
+--R      *
+--R                  m + 6
+--R         (e x + d)
+--R     + 
+--R                 2        2   5           2         2   4
+--R           (- A c e + 5B c d)m  + (- 16A c e + 80B c d)m
+--R         + 
+--R                   2          2   3            2           2   2
+--R           (- 95A c e + 475B c d)m  + (- 260A c e + 1300B c d)m
+--R         + 
+--R                    2           2            2          2
+--R           (- 324A c e + 1620B c d)m - 144A c e + 720B c d
+--R      *
+--R                  m + 5
+--R         (e x + d)
+--R     + 
+--R                      2       2           2 2  5
+--R           (- 2B a c e  + 4A c d e - 10B c d )m
+--R         + 
+--R                       2        2            2 2  4
+--R           (- 34B a c e  + 68A c d e - 170B c d )m
+--R         + 
+--R                        2         2             2 2  3
+--R           (- 214B a c e  + 428A c d e - 1070B c d )m
+--R         + 
+--R                        2          2             2 2  2
+--R           (- 614B a c e  + 1228A c d e - 3070B c d )m
+--R         + 
+--R                        2          2             2 2               2
+--R           (- 792B a c e  + 1584A c d e - 3960B c d )m - 360B a c e
+--R         + 
+--R                 2             2 2
+--R           720A c d e - 1800B c d
+--R      *
+--R                  m + 4
+--R         (e x + d)
+--R     + 
+--R                      3             2       2 2         2 3  5
+--R           (- 2A a c e  + 6B a c d e  - 6A c d e + 10B c d )m
+--R         + 
+--R                       3               2         2 2          2 3  4
+--R           (- 36A a c e  + 108B a c d e  - 108A c d e + 180B c d )m
+--R         + 
+--R                        3               2         2 2           2 3  3
+--R           (- 242A a c e  + 726B a c d e  - 726A c d e + 1210B c d )m
+--R         + 
+--R                        3                2          2 2           2 3  2
+--R           (- 744A a c e  + 2232B a c d e  - 2232A c d e + 3720B c d )m
+--R         + 
+--R                         3                2          2 2           2 3
+--R           (- 1016A a c e  + 3048B a c d e  - 3048A c d e + 5080B c d )m
+--R         + 
+--R                       3                2          2 2           2 3
+--R           - 480A a c e  + 1440B a c d e  - 1440A c d e + 2400B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                 2 4             3           2 2       2 3        2 4  5
+--R           (- B a e  + 4A a c d e  - 6B a c d e  + 4A c d e - 5B c d )m
+--R         + 
+--R                   2 4              3             2 2        2 3         2 4  4
+--R           (- 19B a e  + 76A a c d e  - 114B a c d e  + 76A c d e - 95B c d )m
+--R         + 
+--R                       2 4               3             2 2         2 3
+--R               - 137B a e  + 548A a c d e  - 822B a c d e  + 548A c d e
+--R             + 
+--R                       2 4
+--R               - 685B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       2 4                3              2 2          2 3
+--R               - 461B a e  + 1844A a c d e  - 2766B a c d e  + 1844A c d e
+--R             + 
+--R                        2 4
+--R               - 2305B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                       2 4                3              2 2          2 3
+--R               - 702B a e  + 2808A a c d e  - 4212B a c d e  + 2808A c d e
+--R             + 
+--R                        2 4
+--R               - 3510B c d
+--R          *
+--R             m
+--R         + 
+--R                   2 4                3              2 2          2 3
+--R           - 360B a e  + 1440A a c d e  - 2160B a c d e  + 1440A c d e
+--R         + 
+--R                    2 4
+--R           - 1800B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R                      2 5      2   4           2 3           3 2      2 4
+--R                 - A a e  + B a d e  - 2A a c d e  + 2B a c d e  - A c d e
+--R               + 
+--R                    2 5
+--R                 B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                      2 5        2   4            2 3            3 2        2 4
+--R               - 20A a e  + 20B a d e  - 40A a c d e  + 40B a c d e  - 20A c d e
+--R             + 
+--R                    2 5
+--R               20B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       2 5         2   4             2 3             3 2
+--R               - 155A a e  + 155B a d e  - 310A a c d e  + 310B a c d e
+--R             + 
+--R                       2 4          2 5
+--R               - 155A c d e + 155B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       2 5         2   4              2 3              3 2
+--R               - 580A a e  + 580B a d e  - 1160A a c d e  + 1160B a c d e
+--R             + 
+--R                       2 4          2 5
+--R               - 580A c d e + 580B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                        2 5          2   4              2 3              3 2
+--R               - 1044A a e  + 1044B a d e  - 2088A a c d e  + 2088B a c d e
+--R             + 
+--R                        2 4           2 5
+--R               - 1044A c d e + 1044B c d
+--R          *
+--R             m
+--R         + 
+--R                   2 5         2   4              2 3              3 2
+--R           - 720A a e  + 720B a d e  - 1440A a c d e  + 1440B a c d e
+--R         + 
+--R                   2 4          2 5
+--R           - 720A c d e + 720B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     e m  + 21e m  + 175e m  + 735e m  + 1624e m  + 1764e m + 720e
+--R                                                    Type: Expression(Integer)
+--E 1100
+
+--S 1101 of 1457
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1101
+
+)clear all
+
+--S 1102 of 1457
+t0:=(A+B*x)*(d+e*x)^5*(a+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R        2 5 10       2 5       2   4  9            5       2   4        2 2 3  8
+--R     B c e x   + (A c e  + 5B c d e )x  + (2B a c e  + 5A c d e  + 10B c d e )x
+--R   + 
+--R              5              4        2 2 3        2 3 2  7
+--R     (2A a c e  + 10B a c d e  + 10A c d e  + 10B c d e )x
+--R   + 
+--R         2 5              4            2 3        2 3 2       2 4   6
+--R     (B a e  + 10A a c d e  + 20B a c d e  + 10A c d e  + 5B c d e)x
+--R   + 
+--R         2 5       2   4            2 3            3 2       2 4       2 5  5
+--R     (A a e  + 5B a d e  + 20A a c d e  + 20B a c d e  + 5A c d e + B c d )x
+--R   + 
+--R          2   4        2 2 3            3 2            4       2 5  4
+--R     (5A a d e  + 10B a d e  + 20A a c d e  + 10B a c d e + A c d )x
+--R   + 
+--R           2 2 3        2 3 2            4            5  3
+--R     (10A a d e  + 10B a d e  + 10A a c d e + 2B a c d )x
+--R   + 
+--R           2 3 2       2 4            5  2        2 4       2 5        2 5
+--R     (10A a d e  + 5B a d e + 2A a c d )x  + (5A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1102
+
+--S 1103 of 1457
+r0:=-1/6*(B*d-A*e)*(c*d^2+a*e^2)^2*(d+e*x)^6/e^6+1/7*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)*(d+e*x)^7/e^6-1/4*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^8/e^6+2/9*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)*(d+e*x)^9/e^6-1/10*c^2*(5*B*d-A*e)*(d+e*x)^10/e^6+_
+     1/11*B*c^2*(d+e*x)^11/e^6
+--R 
+--R
+--R   (2)
+--R        1    2 11 11     1    2 11   1    2   10  10
+--R       -- B c e  x   + (-- A c e   + - B c d e  )x
+--R       11               10           2
+--R     + 
+--R        2        11   5    2   10   10    2 2 9  9
+--R       (- B a c e   + - A c d e   + -- B c d e )x
+--R        9             9              9
+--R     + 
+--R        1        11   5          10   5    2 2 9   5    2 3 8  8
+--R       (- A a c e   + - B a c d e   + - A c d e  + - B c d e )x
+--R        4             4               4            4
+--R     + 
+--R        1    2 11   10          10   20        2 9   10    2 3 8   5    2 4 7  7
+--R       (- B a e   + -- A a c d e   + -- B a c d e  + -- A c d e  + - B c d e )x
+--R        7            7                7               7            7
+--R     + 
+--R           1    2 11   5    2   10   10        2 9   10        3 8   5    2 4 7
+--R           - A a e   + - B a d e   + -- A a c d e  + -- B a c d e  + - A c d e
+--R           6           6              3               3              6
+--R         + 
+--R           1    2 5 6
+--R           - B c d e
+--R           6
+--R      *
+--R          6
+--R         x
+--R     + 
+--R           2   10       2 2 9           3 8           4 7   1    2 5 6  5
+--R       (A a d e   + 2B a d e  + 4A a c d e  + 2B a c d e  + - A c d e )x
+--R                                                            5
+--R     + 
+--R        5    2 2 9   5    2 3 8   5        4 7   1        5 6  4
+--R       (- A a d e  + - B a d e  + - A a c d e  + - B a c d e )x
+--R        2            2            2              2
+--R     + 
+--R        10    2 3 8   5    2 4 7   2        5 6  3    5    2 4 7   1    2 5 6  2
+--R       (-- A a d e  + - B a d e  + - A a c d e )x  + (- A a d e  + - B a d e )x
+--R         3            3            3                  2            2
+--R     + 
+--R          2 5 6    1    2 6 5    1    2 7 4    1        8 3    1         9 2
+--R       A a d e x + - A a d e  - -- B a d e  + -- A a c d e  - --- B a c d e
+--R                   6            42            84              252
+--R     + 
+--R         1     2 10      1     2 11
+--R       ---- A c d  e - ---- B c d
+--R       1260            2772
+--R  /
+--R      6
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1103
+
+--S 1104 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    2 5 11     1    2 5   1    2   4  10
+--R     -- B c e x   + (-- A c e  + - B c d e )x
+--R     11              10          2
+--R   + 
+--R      2        5   5    2   4   10    2 2 3  9
+--R     (- B a c e  + - A c d e  + -- B c d e )x
+--R      9            9             9
+--R   + 
+--R      1        5   5          4   5    2 2 3   5    2 3 2  8
+--R     (- A a c e  + - B a c d e  + - A c d e  + - B c d e )x
+--R      4            4              4            4
+--R   + 
+--R      1    2 5   10          4   20        2 3   10    2 3 2   5    2 4   7
+--R     (- B a e  + -- A a c d e  + -- B a c d e  + -- A c d e  + - B c d e)x
+--R      7           7               7               7            7
+--R   + 
+--R         1    2 5   5    2   4   10        2 3   10        3 2   5    2 4
+--R         - A a e  + - B a d e  + -- A a c d e  + -- B a c d e  + - A c d e
+--R         6          6             3               3              6
+--R       + 
+--R         1    2 5
+--R         - B c d
+--R         6
+--R    *
+--R        6
+--R       x
+--R   + 
+--R         2   4       2 2 3           3 2           4    1    2 5  5
+--R     (A a d e  + 2B a d e  + 4A a c d e  + 2B a c d e + - A c d )x
+--R                                                        5
+--R   + 
+--R      5    2 2 3   5    2 3 2   5        4    1        5  4
+--R     (- A a d e  + - B a d e  + - A a c d e + - B a c d )x
+--R      2            2            2             2
+--R   + 
+--R    10    2 3 2   5    2 4    2        5  3    5    2 4    1    2 5  2      2 5
+--R   (-- A a d e  + - B a d e + - A a c d )x  + (- A a d e + - B a d )x  + A a d x
+--R     3            3           3                2           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1104
+
+--S 1105 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         1    2 6 5    1    2 7 4    1        8 3    1         9 2
+--R       - - A a d e  + -- B a d e  - -- A a c d e  + --- B a c d e
+--R         6            42            84              252
+--R     + 
+--R           1     2 10      1     2 11
+--R       - ---- A c d  e + ---- B c d
+--R         1260            2772
+--R  /
+--R      6
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1105
+
+--S 1106 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1106
+
+)clear all
+
+--S 1107 of 1457
+t0:=(A+B*x)*(d+e*x)^4*(a+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R        2 4 9       2 4       2   3  8            4       2   3       2 2 2  7
+--R     B c e x  + (A c e  + 4B c d e )x  + (2B a c e  + 4A c d e  + 6B c d e )x
+--R   + 
+--R              4             3       2 2 2       2 3   6
+--R     (2A a c e  + 8B a c d e  + 6A c d e  + 4B c d e)x
+--R   + 
+--R         2 4             3            2 2       2 3       2 4  5
+--R     (B a e  + 8A a c d e  + 12B a c d e  + 4A c d e + B c d )x
+--R   + 
+--R         2 4       2   3            2 2           3       2 4  4
+--R     (A a e  + 4B a d e  + 12A a c d e  + 8B a c d e + A c d )x
+--R   + 
+--R          2   3       2 2 2           3            4  3
+--R     (4A a d e  + 6B a d e  + 8A a c d e + 2B a c d )x
+--R   + 
+--R          2 2 2       2 3            4  2        2 3       2 4        2 4
+--R     (6A a d e  + 4B a d e + 2A a c d )x  + (4A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1107
+
+--S 1108 of 1457
+r0:=-1/5*(B*d-A*e)*(c*d^2+a*e^2)^2*(d+e*x)^5/e^6+1/6*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)*(d+e*x)^6/e^6-2/7*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^7/e^6+1/4*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)*(d+e*x)^8/e^6-1/9*c^2*(5*B*d-A*e)*(d+e*x)^9/e^6+_
+     1/10*B*c^2*(d+e*x)^10/e^6
+--R 
+--R
+--R   (2)
+--R        1    2 10 10    1    2 10   4    2   9  9
+--R       -- B c e  x   + (- A c e   + - B c d e )x
+--R       10               9           9
+--R     + 
+--R        1        10   1    2   9   3    2 2 8  8
+--R       (- B a c e   + - A c d e  + - B c d e )x
+--R        4             2            4
+--R     + 
+--R        2        10   8          9   6    2 2 8   4    2 3 7  7
+--R       (- A a c e   + - B a c d e  + - A c d e  + - B c d e )x
+--R        7             7              7            7
+--R     + 
+--R        1    2 10   4          9           2 8   2    2 3 7   1    2 4 6  6
+--R       (- B a e   + - A a c d e  + 2B a c d e  + - A c d e  + - B c d e )x
+--R        6           3                            3            6
+--R     + 
+--R        1    2 10   4    2   9   12        2 8   8        3 7   1    2 4 6  5
+--R       (- A a e   + - B a d e  + -- A a c d e  + - B a c d e  + - A c d e )x
+--R        5           5             5              5              5
+--R     + 
+--R           2   9   3    2 2 8           3 7   1        4 6  4
+--R       (A a d e  + - B a d e  + 2A a c d e  + - B a c d e )x
+--R                   2                          2
+--R     + 
+--R            2 2 8   4    2 3 7   2        4 6  3        2 3 7   1    2 4 6  2
+--R       (2A a d e  + - B a d e  + - A a c d e )x  + (2A a d e  + - B a d e )x
+--R                    3            3                              2
+--R     + 
+--R          2 4 6    1    2 5 5    1    2 6 4    2         7 3    1         8 2
+--R       A a d e x + - A a d e  - -- B a d e  + --- A a c d e  - --- B a c d e
+--R                   5            30            105              140
+--R     + 
+--R        1     2 9      1     2 10
+--R       --- A c d e - ---- B c d
+--R       630           1260
+--R  /
+--R      6
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1108
+
+--S 1109 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    2 4 10    1    2 4   4    2   3  9
+--R     -- B c e x   + (- A c e  + - B c d e )x
+--R     10              9          9
+--R   + 
+--R      1        4   1    2   3   3    2 2 2  8
+--R     (- B a c e  + - A c d e  + - B c d e )x
+--R      4            2            4
+--R   + 
+--R      2        4   8          3   6    2 2 2   4    2 3   7
+--R     (- A a c e  + - B a c d e  + - A c d e  + - B c d e)x
+--R      7            7              7            7
+--R   + 
+--R      1    2 4   4          3           2 2   2    2 3    1    2 4  6
+--R     (- B a e  + - A a c d e  + 2B a c d e  + - A c d e + - B c d )x
+--R      6          3                            3           6
+--R   + 
+--R      1    2 4   4    2   3   12        2 2   8        3    1    2 4  5
+--R     (- A a e  + - B a d e  + -- A a c d e  + - B a c d e + - A c d )x
+--R      5          5             5              5             5
+--R   + 
+--R         2   3   3    2 2 2           3    1        4  4
+--R     (A a d e  + - B a d e  + 2A a c d e + - B a c d )x
+--R                 2                         2
+--R   + 
+--R          2 2 2   4    2 3    2        4  3        2 3    1    2 4  2      2 4
+--R     (2A a d e  + - B a d e + - A a c d )x  + (2A a d e + - B a d )x  + A a d x
+--R                  3           3                           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1109
+
+--S 1110 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         1    2 5 5    1    2 6 4    2         7 3    1         8 2
+--R       - - A a d e  + -- B a d e  - --- A a c d e  + --- B a c d e
+--R         5            30            105              140
+--R     + 
+--R          1     2 9      1     2 10
+--R       - --- A c d e + ---- B c d
+--R         630           1260
+--R  /
+--R      6
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1110
+
+--S 1111 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1111
+
+)clear all
+
+--S 1112 of 1457
+t0:=(A+B*x)*(d+e*x)^3*(a+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R        2 3 8       2 3       2   2  7            3       2   2       2 2   6
+--R     B c e x  + (A c e  + 3B c d e )x  + (2B a c e  + 3A c d e  + 3B c d e)x
+--R   + 
+--R              3             2       2 2       2 3  5
+--R     (2A a c e  + 6B a c d e  + 3A c d e + B c d )x
+--R   + 
+--R         2 3             2           2       2 3  4
+--R     (B a e  + 6A a c d e  + 6B a c d e + A c d )x
+--R   + 
+--R         2 3       2   2           2            3  3
+--R     (A a e  + 3B a d e  + 6A a c d e + 2B a c d )x
+--R   + 
+--R          2   2       2 2            3  2        2 2       2 3        2 3
+--R     (3A a d e  + 3B a d e + 2A a c d )x  + (3A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1112
+
+--S 1113 of 1457
+r0:=-1/4*(B*d-A*e)*(c*d^2+a*e^2)^2*(d+e*x)^4/e^6+1/5*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)*(d+e*x)^5/e^6-1/3*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^6/e^6+2/7*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)*(d+e*x)^7/e^6-1/8*c^2*(5*B*d-A*e)*(d+e*x)^8/e^6+_
+     1/9*B*c^2*(d+e*x)^9/e^6
+--R 
+--R
+--R   (2)
+--R       1    2 9 9    1    2 9   3    2   8  8
+--R       - B c e x  + (- A c e  + - B c d e )x
+--R       9             8          8
+--R     + 
+--R        2        9   3    2   8   3    2 2 7  7
+--R       (- B a c e  + - A c d e  + - B c d e )x
+--R        7            7            7
+--R     + 
+--R        1        9            8   1    2 2 7   1    2 3 6  6
+--R       (- A a c e  + B a c d e  + - A c d e  + - B c d e )x
+--R        3                         2            6
+--R     + 
+--R        1    2 9   6          8   6        2 7   1    2 3 6  5
+--R       (- B a e  + - A a c d e  + - B a c d e  + - A c d e )x
+--R        5          5              5              5
+--R     + 
+--R        1    2 9   3    2   8   3        2 7   1        3 6  4
+--R       (- A a e  + - B a d e  + - A a c d e  + - B a c d e )x
+--R        4          4            2              2
+--R     + 
+--R           2   8      2 2 7   2        3 6  3    3    2 2 7   1    2 3 6  2
+--R       (A a d e  + B a d e  + - A a c d e )x  + (- A a d e  + - B a d e )x
+--R                              3                  2            2
+--R     + 
+--R          2 3 6    1    2 4 5    1    2 5 4    1        6 3    1        7 2
+--R       A a d e x + - A a d e  - -- B a d e  + -- A a c d e  - -- B a c d e
+--R                   4            20            30              70
+--R     + 
+--R        1     2 8     1     2 9
+--R       --- A c d e - --- B c d
+--R       280           504
+--R  /
+--R      6
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1113
+
+--S 1114 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    2 3 9    1    2 3   3    2   2  8
+--R     - B c e x  + (- A c e  + - B c d e )x
+--R     9             8          8
+--R   + 
+--R      2        3   3    2   2   3    2 2   7
+--R     (- B a c e  + - A c d e  + - B c d e)x
+--R      7            7            7
+--R   + 
+--R      1        3            2   1    2 2    1    2 3  6
+--R     (- A a c e  + B a c d e  + - A c d e + - B c d )x
+--R      3                         2           6
+--R   + 
+--R      1    2 3   6          2   6        2    1    2 3  5
+--R     (- B a e  + - A a c d e  + - B a c d e + - A c d )x
+--R      5          5              5             5
+--R   + 
+--R      1    2 3   3    2   2   3        2    1        3  4
+--R     (- A a e  + - B a d e  + - A a c d e + - B a c d )x
+--R      4          4            2             2
+--R   + 
+--R         2   2      2 2    2        3  3    3    2 2    1    2 3  2      2 3
+--R     (A a d e  + B a d e + - A a c d )x  + (- A a d e + - B a d )x  + A a d x
+--R                           3                2           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1114
+
+--S 1115 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         1    2 4 5    1    2 5 4    1        6 3    1        7 2    1     2 8
+--R       - - A a d e  + -- B a d e  - -- A a c d e  + -- B a c d e  - --- A c d e
+--R         4            20            30              70              280
+--R     + 
+--R        1     2 9
+--R       --- B c d
+--R       504
+--R  /
+--R      6
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1115
+
+--S 1116 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1116
+
+)clear all
+
+--S 1117 of 1457
+t0:=(A+B*x)*(d+e*x)^2*(a+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R        2 2 7       2 2       2     6            2       2         2 2  5
+--R     B c e x  + (A c e  + 2B c d e)x  + (2B a c e  + 2A c d e + B c d )x
+--R   + 
+--R              2                   2 2  4       2 2                        2  3
+--R     (2A a c e  + 4B a c d e + A c d )x  + (B a e  + 4A a c d e + 2B a c d )x
+--R   + 
+--R         2 2       2              2  2        2         2 2        2 2
+--R     (A a e  + 2B a d e + 2A a c d )x  + (2A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1117
+
+--S 1118 of 1457
+r0:=a^2*A*d^2*x+1/2*a^2*d*(B*d+2*A*e)*x^2+1/3*a*(2*A*c*d^2+2*a*B*d*e+_
+     a*A*e^2)*x^3+1/4*a*(2*B*c*d^2+4*A*c*d*e+a*B*e^2)*x^4+1/5*c*(A*c*d^2+_
+     4*a*B*d*e+2*a*A*e^2)*x^5+1/6*c*(B*c*d^2+2*A*c*d*e+2*a*B*e^2)*x^6+_
+     1/7*c^2*e*(2*B*d+A*e)*x^7+1/8*B*c^2*e^2*x^8
+--R 
+--R
+--R   (2)
+--R     1    2 2 8    1    2 2   2    2     7
+--R     - B c e x  + (- A c e  + - B c d e)x
+--R     8             7          7
+--R   + 
+--R      1        2   1    2      1    2 2  6
+--R     (- B a c e  + - A c d e + - B c d )x
+--R      3            3           6
+--R   + 
+--R      2        2   4             1    2 2  5
+--R     (- A a c e  + - B a c d e + - A c d )x
+--R      5            5             5
+--R   + 
+--R      1    2 2               1        2  4
+--R     (- B a e  + A a c d e + - B a c d )x
+--R      4                      2
+--R   + 
+--R      1    2 2   2    2      2        2  3       2      1    2 2  2      2 2
+--R     (- A a e  + - B a d e + - A a c d )x  + (A a d e + - B a d )x  + A a d x
+--R      3          3           3                          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1118
+
+--S 1119 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    2 2 8    1    2 2   2    2     7
+--R     - B c e x  + (- A c e  + - B c d e)x
+--R     8             7          7
+--R   + 
+--R      1        2   1    2      1    2 2  6
+--R     (- B a c e  + - A c d e + - B c d )x
+--R      3            3           6
+--R   + 
+--R      2        2   4             1    2 2  5
+--R     (- A a c e  + - B a c d e + - A c d )x
+--R      5            5             5
+--R   + 
+--R      1    2 2               1        2  4
+--R     (- B a e  + A a c d e + - B a c d )x
+--R      4                      2
+--R   + 
+--R      1    2 2   2    2      2        2  3       2      1    2 2  2      2 2
+--R     (- A a e  + - B a d e + - A a c d )x  + (A a d e + - B a d )x  + A a d x
+--R      3          3           3                          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1119
+
+--S 1120 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1120
+
+--S 1121 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1121
+
+)clear all
+
+--S 1122 of 1457
+t0:=(A+B*x)*(d+e*x)*(a+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R        2   6       2       2   5                  2   4
+--R     B c e x  + (A c e + B c d)x  + (2B a c e + A c d)x
+--R   + 
+--R                           3       2              2       2       2         2
+--R     (2A a c e + 2B a c d)x  + (B a e + 2A a c d)x  + (A a e + B a d)x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1122
+
+--S 1123 of 1457
+r0:=a^2*A*d*x+1/2*a^2*(B*d+A*e)*x^2+1/3*a*(2*A*c*d+a*B*e)*x^3+1/2*a*c*_
+     (B*d+A*e)*x^4+1/5*c*(A*c*d+2*a*B*e)*x^5+1/6*c^2*(B*d+A*e)*x^6+_
+     1/7*B*c^2*e*x^7
+--R 
+--R
+--R   (2)
+--R     1    2   7    1    2    1    2   6    2           1    2   5
+--R     - B c e x  + (- A c e + - B c d)x  + (- B a c e + - A c d)x
+--R     7             6         6             5           5
+--R   + 
+--R      1           1          4    1    2    2          3    1    2    1    2   2
+--R     (- A a c e + - B a c d)x  + (- B a e + - A a c d)x  + (- A a e + - B a d)x
+--R      2           2               3         3               2         2
+--R   + 
+--R        2
+--R     A a d x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1123
+
+--S 1124 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    2   7    1    2    1    2   6    2           1    2   5
+--R     - B c e x  + (- A c e + - B c d)x  + (- B a c e + - A c d)x
+--R     7             6         6             5           5
+--R   + 
+--R      1           1          4    1    2    2          3    1    2    1    2   2
+--R     (- A a c e + - B a c d)x  + (- B a e + - A a c d)x  + (- A a e + - B a d)x
+--R      2           2               3         3               2         2
+--R   + 
+--R        2
+--R     A a d x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1124
+
+--S 1125 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1125
+
+--S 1126 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1126
+
+)clear all
+
+--S 1127 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2
+--R 
+--R
+--R           2 5      2 4           3           2      2       2
+--R   (1)  B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 1127
+
+--S 1128 of 1457
+r0:=a^2*A*x+2/3*a*A*c*x^3+1/5*A*c^2*x^5+1/6*B*(a+c*x^2)^3/c
+--R 
+--R
+--R   (2)
+--R   1    3 6   1    3 5   1      2 4   2      2 3   1    2   2      2      1    3
+--R   - B c x  + - A c x  + - B a c x  + - A a c x  + - B a c x  + A a c x + - B a
+--R   6          5          2            3            2                      6
+--R   -----------------------------------------------------------------------------
+--R                                         c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1128
+
+--S 1129 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    2 6   1    2 5   1        4   2        3   1    2 2      2
+--R   (3)  - B c x  + - A c x  + - B a c x  + - A a c x  + - B a x  + A a x
+--R        6          5          2            3            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1129
+
+--S 1130 of 1457
+m0:=a0-r0
+--R 
+--R
+--R          1    3
+--R          - B a
+--R          6
+--R   (4)  - ------
+--R             c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1130
+
+--S 1131 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1131
+
+)clear all
+
+--S 1132 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)
+--R 
+--R
+--R           2 5      2 4           3           2      2       2
+--R        B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R   (1)  ------------------------------------------------------
+--R                                e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1132
+
+--S 1133 of 1457
+r0:=(B*(c*d^2+a*e^2)^2-A*c*d*e*(c*d^2+2*a*e^2))*x/e^5-1/2*c*(B*d-A*e)*_
+     (c*d^2+2*a*e^2)*x^2/e^4+1/3*c*(B*c*d^2-A*c*d*e+2*a*B*e^2)*x^3/e^3-_
+     1/4*c^2*(B*d-A*e)*x^4/e^2+1/5*B*c^2*x^5/e-(B*d-A*e)*(c*d^2+a*e^2)^2*_
+     log(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R                2 5        2   4             2 3             3 2        2 4
+--R           60A a e  - 60B a d e  + 120A a c d e  - 120B a c d e  + 60A c d e
+--R         + 
+--R                  2 5
+--R           - 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            2 5 5         2 5        2   4  4
+--R       12B c e x  + (15A c e  - 15B c d e )x
+--R     + 
+--R                 5        2   4        2 2 3  3
+--R       (40B a c e  - 20A c d e  + 20B c d e )x
+--R     + 
+--R                 5              4        2 2 3        2 3 2  2
+--R       (60A a c e  - 60B a c d e  + 30A c d e  - 30B c d e )x
+--R     + 
+--R             2 5               4             2 3        2 3 2        2 4
+--R       (60B a e  - 120A a c d e  + 120B a c d e  - 60A c d e  + 60B c d e)x
+--R  /
+--R        6
+--R     60e
+--R                                                    Type: Expression(Integer)
+--E 1133
+
+--S 1134 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 5        2   4             2 3             3 2        2 4
+--R           60A a e  - 60B a d e  + 120A a c d e  - 120B a c d e  + 60A c d e
+--R         + 
+--R                  2 5
+--R           - 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            2 5 5         2 5        2   4  4
+--R       12B c e x  + (15A c e  - 15B c d e )x
+--R     + 
+--R                 5        2   4        2 2 3  3
+--R       (40B a c e  - 20A c d e  + 20B c d e )x
+--R     + 
+--R                 5              4        2 2 3        2 3 2  2
+--R       (60A a c e  - 60B a c d e  + 30A c d e  - 30B c d e )x
+--R     + 
+--R             2 5               4             2 3        2 3 2        2 4
+--R       (60B a e  - 120A a c d e  + 120B a c d e  - 60A c d e  + 60B c d e)x
+--R  /
+--R        6
+--R     60e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1134
+
+--S 1135 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1135
+
+--S 1136 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1136
+
+)clear all
+
+--S 1137 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^2
+--R 
+--R
+--R           2 5      2 4           3           2      2       2
+--R        B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R   (1)  ------------------------------------------------------
+--R                           2 2             2
+--R                          e x  + 2d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1137
+
+--S 1138 of 1457
+r0:=-c*(4*B*c*d^3-3*A*c*d^2*e+4*a*B*d*e^2-2*a*A*e^3)*x/e^5+1/2*c*_
+     (3*B*c*d^2-2*A*c*d*e+2*a*B*e^2)*x^2/e^4-1/3*c^2*(2*B*d-A*e)*x^3/e^3+_
+     1/4*B*c^2*x^4/e^2+(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x))+_
+     (c*d^2+a*e^2)*(5*B*c*d^2-4*A*c*d*e+a*B*e^2)*log(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R                 2 5              4            2 3        2 3 2        2 4
+--R           (12B a e  - 48A a c d e  + 72B a c d e  - 48A c d e  + 60B c d e)x
+--R         + 
+--R                2   4            2 3            3 2        2 4         2 5
+--R           12B a d e  - 48A a c d e  + 72B a c d e  - 48A c d e + 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5        2 5       2   4  4
+--R       3B c e x  + (4A c e  - 5B c d e )x
+--R     + 
+--R                 5       2   4        2 2 3  3
+--R       (12B a c e  - 8A c d e  + 10B c d e )x
+--R     + 
+--R                 5              4        2 2 3        2 3 2  2
+--R       (24A a c e  - 36B a c d e  + 24A c d e  - 30B c d e )x
+--R     + 
+--R                   4            2 3        2 3 2        2 4           2 5
+--R       (24A a c d e  - 48B a c d e  + 36A c d e  - 48B c d e)x - 12A a e
+--R     + 
+--R            2   4            2 3            3 2        2 4         2 5
+--R       12B a d e  - 24A a c d e  + 24B a c d e  - 12A c d e + 12B c d
+--R  /
+--R        7         6
+--R     12e x + 12d e
+--R                                                    Type: Expression(Integer)
+--E 1138
+
+--S 1139 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2 5              4            2 3        2 3 2        2 4
+--R           (12B a e  - 48A a c d e  + 72B a c d e  - 48A c d e  + 60B c d e)x
+--R         + 
+--R                2   4            2 3            3 2        2 4         2 5
+--R           12B a d e  - 48A a c d e  + 72B a c d e  - 48A c d e + 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5        2 5       2   4  4
+--R       3B c e x  + (4A c e  - 5B c d e )x
+--R     + 
+--R                 5       2   4        2 2 3  3
+--R       (12B a c e  - 8A c d e  + 10B c d e )x
+--R     + 
+--R                 5              4        2 2 3        2 3 2  2
+--R       (24A a c e  - 36B a c d e  + 24A c d e  - 30B c d e )x
+--R     + 
+--R                   4            2 3        2 3 2        2 4           2 5
+--R       (24A a c d e  - 48B a c d e  + 36A c d e  - 48B c d e)x - 12A a e
+--R     + 
+--R            2   4            2 3            3 2        2 4         2 5
+--R       12B a d e  - 24A a c d e  + 24B a c d e  - 12A c d e + 12B c d
+--R  /
+--R        7         6
+--R     12e x + 12d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1139
+
+--S 1140 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1140
+
+--S 1141 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1141
+
+)clear all
+
+--S 1142 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^3
+--R 
+--R
+--R           2 5      2 4           3           2      2       2
+--R        B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R   (1)  ------------------------------------------------------
+--R                      3 3       2 2     2       3
+--R                     e x  + 3d e x  + 3d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1142
+
+--S 1143 of 1457
+r0:=c*(6*B*c*d^2-3*A*c*d*e+2*a*B*e^2)*x/e^5-1/2*c^2*(3*B*d-A*e)*x^2/e^4+_
+     1/3*B*c^2*x^3/e^3+1/2*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^2)-_
+     (c*d^2+a*e^2)*(5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x))-_
+     2*c*(5*B*c*d^3-3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*log(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R                     5              4        2 2 3        2 3 2  2
+--R           (12A a c e  - 36B a c d e  + 36A c d e  - 60B c d e )x
+--R         + 
+--R                       4            2 3        2 3 2         2 4
+--R           (24A a c d e  - 72B a c d e  + 72A c d e  - 120B c d e)x
+--R         + 
+--R                    2 3            3 2        2 4         2 5
+--R           12A a c d e  - 36B a c d e  + 36A c d e - 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5        2 5       2   4  4
+--R       2B c e x  + (3A c e  - 5B c d e )x
+--R     + 
+--R                 5        2   4        2 2 3  3
+--R       (12B a c e  - 12A c d e  + 20B c d e )x
+--R     + 
+--R                   4        2 2 3        2 3 2  2
+--R       (24B a c d e  - 33A c d e  + 63B c d e )x
+--R     + 
+--R              2 5              4            2 3       2 3 2       2 4
+--R       (- 6B a e  + 24A a c d e  - 24B a c d e  + 6A c d e  + 6B c d e)x
+--R     + 
+--R           2 5       2   4            2 3            3 2        2 4         2 5
+--R     - 3A a e  - 3B a d e  + 18A a c d e  - 30B a c d e  + 21A c d e - 27B c d
+--R  /
+--R       8 2        7      2 6
+--R     6e x  + 12d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 1143
+
+--S 1144 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     5              4        2 2 3        2 3 2  2
+--R           (12A a c e  - 36B a c d e  + 36A c d e  - 60B c d e )x
+--R         + 
+--R                       4            2 3        2 3 2         2 4
+--R           (24A a c d e  - 72B a c d e  + 72A c d e  - 120B c d e)x
+--R         + 
+--R                    2 3            3 2        2 4         2 5
+--R           12A a c d e  - 36B a c d e  + 36A c d e - 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5        2 5       2   4  4
+--R       2B c e x  + (3A c e  - 5B c d e )x
+--R     + 
+--R                 5        2   4        2 2 3  3
+--R       (12B a c e  - 12A c d e  + 20B c d e )x
+--R     + 
+--R                   4        2 2 3        2 3 2  2
+--R       (24B a c d e  - 33A c d e  + 63B c d e )x
+--R     + 
+--R              2 5              4            2 3       2 3 2       2 4
+--R       (- 6B a e  + 24A a c d e  - 24B a c d e  + 6A c d e  + 6B c d e)x
+--R     + 
+--R           2 5       2   4            2 3            3 2        2 4         2 5
+--R     - 3A a e  - 3B a d e  + 18A a c d e  - 30B a c d e  + 21A c d e - 27B c d
+--R  /
+--R       8 2        7      2 6
+--R     6e x  + 12d e x + 6d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1144
+
+--S 1145 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1145
+
+--S 1146 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1146
+
+)clear all
+
+--S 1147 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^4
+--R 
+--R
+--R           2 5      2 4           3           2      2       2
+--R        B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R   (1)  ------------------------------------------------------
+--R                 4 4       3 3     2 2 2     3       4
+--R                e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1147
+
+--S 1148 of 1457
+r0:=-c^2*(4*B*d-A*e)*x/e^5+1/2*B*c^2*x^2/e^4+1/3*(B*d-A*e)*(c*d^2+_
+     a*e^2)^2/(e^6*(d+e*x)^3)-1/2*(c*d^2+a*e^2)*(5*B*c*d^2-4*A*c*d*e+_
+     a*B*e^2)/(e^6*(d+e*x)^2)+2*c*(5*B*c*d^3-3*A*c*d^2*e+3*a*B*d*e^2-_
+     a*A*e^3)/(e^6*(d+e*x))+2*c*(5*B*c*d^2-2*A*c*d*e+a*B*e^2)*log(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R                     5        2   4        2 2 3  3
+--R           (12B a c e  - 24A c d e  + 60B c d e )x
+--R         + 
+--R                       4        2 2 3         2 3 2  2
+--R           (36B a c d e  - 72A c d e  + 180B c d e )x
+--R         + 
+--R                     2 3        2 3 2         2 4               3 2        2 4
+--R           (36B a c d e  - 72A c d e  + 180B c d e)x + 12B a c d e  - 24A c d e
+--R         + 
+--R                2 5
+--R           60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5        2 5        2   4  4         2   4        2 2 3  3
+--R       3B c e x  + (6A c e  - 15B c d e )x  + (18A c d e  - 63B c d e )x
+--R     + 
+--R                   5              4        2 2 3       2 3 2  2
+--R       (- 12A a c e  + 36B a c d e  - 18A c d e  - 9B c d e )x
+--R     + 
+--R              2 5              4            2 3        2 3 2        2 4
+--R       (- 3B a e  - 12A a c d e  + 54B a c d e  - 54A c d e  + 81B c d e)x
+--R     + 
+--R             2 5      2   4           2 3            3 2        2 4         2 5
+--R       - 2A a e  - B a d e  - 4A a c d e  + 22B a c d e  - 26A c d e + 47B c d
+--R  /
+--R       9 3        8 2      2 7      3 6
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 1148
+
+--S 1149 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     5        2   4        2 2 3  3
+--R           (12B a c e  - 24A c d e  + 60B c d e )x
+--R         + 
+--R                       4        2 2 3         2 3 2  2
+--R           (36B a c d e  - 72A c d e  + 180B c d e )x
+--R         + 
+--R                     2 3        2 3 2         2 4               3 2        2 4
+--R           (36B a c d e  - 72A c d e  + 180B c d e)x + 12B a c d e  - 24A c d e
+--R         + 
+--R                2 5
+--R           60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 5 5        2 5        2   4  4         2   4        2 2 3  3
+--R       3B c e x  + (6A c e  - 15B c d e )x  + (18A c d e  - 63B c d e )x
+--R     + 
+--R                   5              4        2 2 3       2 3 2  2
+--R       (- 12A a c e  + 36B a c d e  - 18A c d e  - 9B c d e )x
+--R     + 
+--R              2 5              4            2 3        2 3 2        2 4
+--R       (- 3B a e  - 12A a c d e  + 54B a c d e  - 54A c d e  + 81B c d e)x
+--R     + 
+--R             2 5      2   4           2 3            3 2        2 4         2 5
+--R       - 2A a e  - B a d e  - 4A a c d e  + 22B a c d e  - 26A c d e + 47B c d
+--R  /
+--R       9 3        8 2      2 7      3 6
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1149
+
+--S 1150 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1150
+
+--S 1151 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1151
+
+)clear all
+
+--S 1152 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^5
+--R 
+--R
+--R           2 5      2 4           3           2      2       2
+--R        B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R   (1)  ------------------------------------------------------
+--R           5 5       4 4      2 3 3      3 2 2     4       5
+--R          e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1152
+
+--S 1153 of 1457
+r0:=B*c^2*x/e^5+1/4*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^4)-1/3*(c*d^2+_
+     a*e^2)*(5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^3)+c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^2)-2*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x))-c^2*(5*B*d-A*e)*log(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R                 2 5        2   4  4         2   4         2 2 3  3
+--R           (12A c e  - 60B c d e )x  + (48A c d e  - 240B c d e )x
+--R         + 
+--R                 2 2 3         2 3 2  2         2 3 2         2 4           2 4
+--R           (72A c d e  - 360B c d e )x  + (48A c d e  - 240B c d e)x + 12A c d e
+--R         + 
+--R                  2 5
+--R           - 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            2 5 5        2   4 4               5        2   4        2 2 3  3
+--R       12B c e x  + 48B c d e x  + (- 24B a c e  + 48A c d e  - 48B c d e )x
+--R     + 
+--R                   5              4         2 2 3         2 3 2  2
+--R       (- 12A a c e  - 36B a c d e  + 108A c d e  - 252B c d e )x
+--R     + 
+--R              2 5             4            2 3        2 3 2         2 4
+--R       (- 4B a e  - 8A a c d e  - 24B a c d e  + 88A c d e  - 248B c d e)x
+--R     + 
+--R             2 5      2   4           2 3           3 2        2 4         2 5
+--R       - 3A a e  - B a d e  - 2A a c d e  - 6B a c d e  + 25A c d e - 77B c d
+--R  /
+--R        10 4        9 3      2 8 2      3 7       4 6
+--R     12e  x  + 48d e x  + 72d e x  + 48d e x + 12d e
+--R                                                    Type: Expression(Integer)
+--E 1153
+
+--S 1154 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2 5        2   4  4         2   4         2 2 3  3
+--R           (12A c e  - 60B c d e )x  + (48A c d e  - 240B c d e )x
+--R         + 
+--R                 2 2 3         2 3 2  2         2 3 2         2 4           2 4
+--R           (72A c d e  - 360B c d e )x  + (48A c d e  - 240B c d e)x + 12A c d e
+--R         + 
+--R                  2 5
+--R           - 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            2 5 5        2   4 4               5        2   4        2 2 3  3
+--R       12B c e x  + 48B c d e x  + (- 24B a c e  + 48A c d e  - 48B c d e )x
+--R     + 
+--R                   5              4         2 2 3         2 3 2  2
+--R       (- 12A a c e  - 36B a c d e  + 108A c d e  - 252B c d e )x
+--R     + 
+--R              2 5             4            2 3        2 3 2         2 4
+--R       (- 4B a e  - 8A a c d e  - 24B a c d e  + 88A c d e  - 248B c d e)x
+--R     + 
+--R             2 5      2   4           2 3           3 2        2 4         2 5
+--R       - 3A a e  - B a d e  - 2A a c d e  - 6B a c d e  + 25A c d e - 77B c d
+--R  /
+--R        10 4        9 3      2 8 2      3 7       4 6
+--R     12e  x  + 48d e x  + 72d e x  + 48d e x + 12d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1154
+
+--S 1155 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1155
+
+--S 1156 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1156
+
+)clear all
+
+--S 1157 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^6
+--R 
+--R
+--R               2 5      2 4           3           2      2       2
+--R            B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1157
+
+--S 1158 of 1457
+r0:=1/5*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^5)-1/4*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^4)+2/3*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^3)-c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^2)+c^2*(5*B*d-A*e)/(e^6*(d+e*x))+_
+     B*c^2*log(d+e*x)/e^6
+--R 
+--R
+--R   (2)
+--R                2 5 5         2   4 4         2 2 3 3         2 3 2 2
+--R           60B c e x  + 300B c d e x  + 600B c d e x  + 600B c d e x
+--R         + 
+--R                 2 4           2 5
+--R           300B c d e x + 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R               2 5         2   4  4
+--R       (- 60A c e  + 300B c d e )x
+--R     + 
+--R                   5         2   4         2 2 3  3
+--R       (- 60B a c e  - 120A c d e  + 900B c d e )x
+--R     + 
+--R                   5              4         2 2 3          2 3 2  2
+--R       (- 40A a c e  - 60B a c d e  - 120A c d e  + 1100B c d e )x
+--R     + 
+--R               2 5              4            2 3        2 3 2         2 4
+--R       (- 15B a e  - 20A a c d e  - 30B a c d e  - 60A c d e  + 625B c d e)x
+--R     + 
+--R            2 5       2   4           2 3           3 2        2 4          2 5
+--R     - 12A a e  - 3B a d e  - 4A a c d e  - 6B a c d e  - 12A c d e + 137B c d
+--R  /
+--R        11 5         10 4       2 9 3       3 8 2       4 7       5 6
+--R     60e  x  + 300d e  x  + 600d e x  + 600d e x  + 300d e x + 60d e
+--R                                                    Type: Expression(Integer)
+--E 1158
+
+--S 1159 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 5 5         2   4 4         2 2 3 3         2 3 2 2
+--R           60B c e x  + 300B c d e x  + 600B c d e x  + 600B c d e x
+--R         + 
+--R                 2 4           2 5
+--R           300B c d e x + 60B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R               2 5         2   4  4
+--R       (- 60A c e  + 300B c d e )x
+--R     + 
+--R                   5         2   4         2 2 3  3
+--R       (- 60B a c e  - 120A c d e  + 900B c d e )x
+--R     + 
+--R                   5              4         2 2 3          2 3 2  2
+--R       (- 40A a c e  - 60B a c d e  - 120A c d e  + 1100B c d e )x
+--R     + 
+--R               2 5              4            2 3        2 3 2         2 4
+--R       (- 15B a e  - 20A a c d e  - 30B a c d e  - 60A c d e  + 625B c d e)x
+--R     + 
+--R            2 5       2   4           2 3           3 2        2 4          2 5
+--R     - 12A a e  - 3B a d e  - 4A a c d e  - 6B a c d e  - 12A c d e + 137B c d
+--R  /
+--R        11 5         10 4       2 9 3       3 8 2       4 7       5 6
+--R     60e  x  + 300d e  x  + 600d e x  + 600d e x  + 300d e x + 60d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1159
+
+--S 1160 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1160
+
+--S 1161 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1161
+
+)clear all
+
+--S 1162 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^7
+--R 
+--R
+--R   (1)
+--R               2 5      2 4           3           2      2       2
+--R            B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R   ------------------------------------------------------------------------
+--R    7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R   e x  + 7d e x  + 21d e x  + 35d e x  + 35d e x  + 21d e x  + 7d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1162
+
+--S 1163 of 1457
+r0:=1/6*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^6)-1/5*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^5)+1/2*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^4)-2/3*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^3)+1/2*c^2*(5*B*d-A*e)/_
+     (e^6*(d+e*x)^2)-B*c^2/(e^6*(d+e*x))
+--R 
+--R
+--R   (2)
+--R            2 5 5      1    2 5   5    2   4  4
+--R       - B c e x  + (- - A c e  - - B c d e )x
+--R                       2          2
+--R     + 
+--R          2        5   2    2   4   10    2 2 3  3
+--R       (- - B a c e  - - A c d e  - -- B c d e )x
+--R          3            3             3
+--R     + 
+--R          1        5   1          4   1    2 2 3   5    2 3 2  2
+--R       (- - A a c e  - - B a c d e  - - A c d e  - - B c d e )x
+--R          2            2              2            2
+--R     + 
+--R          1    2 5   1          4   1        2 3   1    2 3 2      2 4
+--R       (- - B a e  - - A a c d e  - - B a c d e  - - A c d e  - B c d e)x
+--R          5          5              5              5
+--R     + 
+--R         1    2 5    1    2   4    1        2 3    1        3 2    1    2 4
+--R       - - A a e  - -- B a d e  - -- A a c d e  - -- B a c d e  - -- A c d e
+--R         6          30            30              30              30
+--R     + 
+--R         1    2 5
+--R       - - B c d
+--R         6
+--R  /
+--R      12 6       11 5      2 10 4      3 9 3      4 8 2     5 7     6 6
+--R     e  x  + 6d e  x  + 15d e  x  + 20d e x  + 15d e x  + 6d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1163
+
+--S 1164 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 5 5           2 5        2   4  4
+--R       - 30B c e x  + (- 15A c e  - 75B c d e )x
+--R     + 
+--R                   5        2   4         2 2 3  3
+--R       (- 20B a c e  - 20A c d e  - 100B c d e )x
+--R     + 
+--R                   5              4        2 2 3        2 3 2  2
+--R       (- 15A a c e  - 15B a c d e  - 15A c d e  - 75B c d e )x
+--R     + 
+--R              2 5             4           2 3       2 3 2        2 4
+--R       (- 6B a e  - 6A a c d e  - 6B a c d e  - 6A c d e  - 30B c d e)x
+--R     + 
+--R             2 5      2   4          2 3          3 2      2 4        2 5
+--R       - 5A a e  - B a d e  - A a c d e  - B a c d e  - A c d e - 5B c d
+--R  /
+--R          12 6         11 5       2 10 4       3 9 3       4 8 2       5 7
+--R       30e  x  + 180d e  x  + 450d e  x  + 600d e x  + 450d e x  + 180d e x
+--R     + 
+--R          6 6
+--R       30d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1164
+
+--S 1165 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1165
+
+--S 1166 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1166
+
+)clear all
+
+--S 1167 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^8
+--R 
+--R
+--R   (1)
+--R        2 5      2 4           3           2      2       2
+--R     B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R  /
+--R        8 8       7 7      2 6 6      3 5 5      4 4 4      5 3 3      6 2 2
+--R       e x  + 8d e x  + 28d e x  + 56d e x  + 70d e x  + 56d e x  + 28d e x
+--R     + 
+--R         7       8
+--R       8d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1167
+
+--S 1168 of 1457
+r0:=1/7*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^7)-1/6*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^6)+2/5*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^5)-1/2*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^4)+1/3*c^2*(5*B*d-A*e)/(e^6*_
+     (d+e*x)^3)-1/2*B*c^2/(e^6*(d+e*x)^2)
+--R 
+--R
+--R   (2)
+--R         1    2 5 5      1    2 5   5    2   4  4
+--R       - - B c e x  + (- - A c e  - - B c d e )x
+--R         2               3          6
+--R     + 
+--R          1        5   1    2   4   5    2 2 3  3
+--R       (- - B a c e  - - A c d e  - - B c d e )x
+--R          2            3            6
+--R     + 
+--R          2        5    3          4   1    2 2 3   1    2 3 2  2
+--R       (- - A a c e  - -- B a c d e  - - A c d e  - - B c d e )x
+--R          5            10              5            2
+--R     + 
+--R          1    2 5    2          4    1        2 3    1    2 3 2   1    2 4
+--R       (- - B a e  - -- A a c d e  - -- B a c d e  - -- A c d e  - - B c d e)x
+--R          6          15              10              15            6
+--R     + 
+--R         1    2 5    1    2   4    2         2 3    1        3 2    1     2 4
+--R       - - A a e  - -- B a d e  - --- A a c d e  - -- B a c d e  - --- A c d e
+--R         7          42            105              70              105
+--R     + 
+--R          1    2 5
+--R       - -- B c d
+--R         42
+--R  /
+--R        13 7       12 6      2 11 5      3 10 4      4 9 3      5 8 2     6 7
+--R       e  x  + 7d e  x  + 21d e  x  + 35d e  x  + 35d e x  + 21d e x  + 7d e x
+--R     + 
+--R        7 6
+--R       d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1168
+
+--S 1169 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 5 5           2 5         2   4  4
+--R       - 105B c e x  + (- 70A c e  - 175B c d e )x
+--R     + 
+--R                    5        2   4         2 2 3  3
+--R       (- 105B a c e  - 70A c d e  - 175B c d e )x
+--R     + 
+--R                   5              4        2 2 3         2 3 2  2
+--R       (- 84A a c e  - 63B a c d e  - 42A c d e  - 105B c d e )x
+--R     + 
+--R               2 5              4            2 3        2 3 2        2 4
+--R       (- 35B a e  - 28A a c d e  - 21B a c d e  - 14A c d e  - 35B c d e)x
+--R     + 
+--R              2 5       2   4           2 3           3 2       2 4        2 5
+--R       - 30A a e  - 5B a d e  - 4A a c d e  - 3B a c d e  - 2A c d e - 5B c d
+--R  /
+--R           13 7          12 6        2 11 5        3 10 4        4 9 3
+--R       210e  x  + 1470d e  x  + 4410d e  x  + 7350d e  x  + 7350d e x
+--R     + 
+--R            5 8 2        6 7        7 6
+--R       4410d e x  + 1470d e x + 210d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1169
+
+--S 1170 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1170
+
+--S 1171 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1171
+
+)clear all
+
+--S 1172 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^9
+--R 
+--R
+--R   (1)
+--R        2 5      2 4           3           2      2       2
+--R     B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R  /
+--R        9 9       8 8      2 7 7      3 6 6       4 5 5       5 4 4      6 3 3
+--R       e x  + 9d e x  + 36d e x  + 84d e x  + 126d e x  + 126d e x  + 84d e x
+--R     + 
+--R          7 2 2     8       9
+--R       36d e x  + 9d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1172
+
+--S 1173 of 1457
+r0:=1/8*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^8)-1/7*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^7)+1/3*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^6)-2/5*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^5)+1/4*c^2*(5*B*d-A*e)/(e^6*_
+     (d+e*x)^4)-1/3*B*c^2/(e^6*(d+e*x)^3)
+--R 
+--R
+--R   (2)
+--R         1    2 5 5      1    2 5    5    2   4  4
+--R       - - B c e x  + (- - A c e  - -- B c d e )x
+--R         3               4          12
+--R     + 
+--R          2        5   1    2   4   1    2 2 3  3
+--R       (- - B a c e  - - A c d e  - - B c d e )x
+--R          5            5            3
+--R     + 
+--R          1        5   1          4    1    2 2 3   1    2 3 2  2
+--R       (- - A a c e  - - B a c d e  - -- A c d e  - - B c d e )x
+--R          3            5              10            6
+--R     + 
+--R          1    2 5    2          4    2        2 3    1    2 3 2    1    2 4
+--R       (- - B a e  - -- A a c d e  - -- B a c d e  - -- A c d e  - -- B c d e)x
+--R          7          21              35              35            21
+--R     + 
+--R         1    2 5    1    2   4    1        2 3    1         3 2    1     2 4
+--R       - - A a e  - -- B a d e  - -- A a c d e  - --- B a c d e  - --- A c d e
+--R         8          56            84              140              280
+--R     + 
+--R          1     2 5
+--R       - --- B c d
+--R         168
+--R  /
+--R        14 8       13 7      2 12 6      3 11 5      4 10 4      5 9 3
+--R       e  x  + 8d e  x  + 28d e  x  + 56d e  x  + 70d e  x  + 56d e x
+--R     + 
+--R          6 8 2     7 7     8 6
+--R       28d e x  + 8d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1173
+
+--S 1174 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 5 5            2 5         2   4  4
+--R       - 280B c e x  + (- 210A c e  - 350B c d e )x
+--R     + 
+--R                    5         2   4         2 2 3  3
+--R       (- 336B a c e  - 168A c d e  - 280B c d e )x
+--R     + 
+--R                    5               4        2 2 3         2 3 2  2
+--R       (- 280A a c e  - 168B a c d e  - 84A c d e  - 140B c d e )x
+--R     + 
+--R                2 5              4            2 3        2 3 2        2 4
+--R       (- 120B a e  - 80A a c d e  - 48B a c d e  - 24A c d e  - 40B c d e)x
+--R     + 
+--R             2 5        2   4            2 3           3 2       2 4        2 5
+--R     - 105A a e  - 15B a d e  - 10A a c d e  - 6B a c d e  - 3A c d e - 5B c d
+--R  /
+--R           14 8          13 7         2 12 6         3 11 5         4 10 4
+--R       840e  x  + 6720d e  x  + 23520d e  x  + 47040d e  x  + 58800d e  x
+--R     + 
+--R             5 9 3         6 8 2        7 7        8 6
+--R       47040d e x  + 23520d e x  + 6720d e x + 840d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1174
+
+--S 1175 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1175
+
+--S 1176 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1176
+
+)clear all
+
+--S 1177 of 1457
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^10
+--R 
+--R
+--R   (1)
+--R        2 5      2 4           3           2      2       2
+--R     B c x  + A c x  + 2B a c x  + 2A a c x  + B a x + A a
+--R  /
+--R        10 10        9 9      2 8 8       3 7 7       4 6 6       5 5 5
+--R       e  x   + 10d e x  + 45d e x  + 120d e x  + 210d e x  + 252d e x
+--R     + 
+--R           6 4 4       7 3 3      8 2 2      9       10
+--R       210d e x  + 120d e x  + 45d e x  + 10d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1177
+
+--S 1178 of 1457
+r0:=1/9*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^9)-1/8*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^8)+2/7*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^7)-1/3*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^6)+1/5*c^2*(5*B*d-A*e)/(e^6*_
+     (d+e*x)^5)-1/4*B*c^2/(e^6*(d+e*x)^4)
+--R 
+--R
+--R   (2)
+--R         1    2 5 5      1    2 5   1    2   4  4
+--R       - - B c e x  + (- - A c e  - - B c d e )x
+--R         4               5          4
+--R     + 
+--R          1        5    2    2   4   1    2 2 3  3
+--R       (- - B a c e  - -- A c d e  - - B c d e )x
+--R          3            15            6
+--R     + 
+--R          2        5   1          4    2    2 2 3    1    2 3 2  2
+--R       (- - A a c e  - - B a c d e  - -- A c d e  - -- B c d e )x
+--R          7            7              35            14
+--R     + 
+--R          1    2 5    1          4    1        2 3    1    2 3 2    1    2 4
+--R       (- - B a e  - -- A a c d e  - -- B a c d e  - -- A c d e  - -- B c d e)x
+--R          8          14              28              70            56
+--R     + 
+--R         1    2 5    1    2   4    1         2 3    1         3 2    1     2 4
+--R       - - A a e  - -- B a d e  - --- A a c d e  - --- B a c d e  - --- A c d e
+--R         9          72            126              252              630
+--R     + 
+--R          1     2 5
+--R       - --- B c d
+--R         504
+--R  /
+--R        15 9       14 8      2 13 7      3 12 6       4 11 5       5 10 4
+--R       e  x  + 9d e  x  + 36d e  x  + 84d e  x  + 126d e  x  + 126d e  x
+--R     + 
+--R          6 9 3      7 8 2     8 7     9 6
+--R       84d e x  + 36d e x  + 9d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1178
+
+--S 1179 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 5 5            2 5         2   4  4
+--R       - 630B c e x  + (- 504A c e  - 630B c d e )x
+--R     + 
+--R                    5         2   4         2 2 3  3
+--R       (- 840B a c e  - 336A c d e  - 420B c d e )x
+--R     + 
+--R                    5               4         2 2 3         2 3 2  2
+--R       (- 720A a c e  - 360B a c d e  - 144A c d e  - 180B c d e )x
+--R     + 
+--R                2 5               4            2 3        2 3 2        2 4
+--R       (- 315B a e  - 180A a c d e  - 90B a c d e  - 36A c d e  - 45B c d e)x
+--R     + 
+--R             2 5        2   4            2 3            3 2       2 4        2 5
+--R     - 280A a e  - 35B a d e  - 20A a c d e  - 10B a c d e  - 4A c d e - 5B c d
+--R  /
+--R            15 9           14 8         2 13 7          3 12 6          4 11 5
+--R       2520e  x  + 22680d e  x  + 90720d e  x  + 211680d e  x  + 317520d e  x
+--R     + 
+--R              5 10 4          6 9 3         7 8 2         8 7         9 6
+--R       317520d e  x  + 211680d e x  + 90720d e x  + 22680d e x + 2520d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1179
+
+--S 1180 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1180
+
+--S 1181 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1181
+
+)clear all
+
+--S 1182 of 1457
+t0:=(A+B*x)*(d+e*x)^m*(a+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  *
+--R              m
+--R     (e x + d)
+--R                                                    Type: Expression(Integer)
+--E 1182
+
+--S 1183 of 1457
+r0:=-(B*d-A*e)*(c*d^2+a*e^2)^3*(d+e*x)^(1+m)/(e^8*(1+m))+(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)*(d+e*x)^(2+m)/(e^8*(2+m))-3*c*(c*d^2+_
+     a*e^2)*(7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^(3+m)/_
+     (e^8*(3+m))-c*(4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*_
+     c*d^2*e^2+3*a^2*e^4))*(d+e*x)^(4+m)/(e^8*(4+m))-c^2*(35*B*c*d^3-_
+     15*A*c*d^2*e+15*a*B*d*e^2-3*a*A*e^3)*(d+e*x)^(5+m)/(e^8*(5+m))+_
+     3*c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)*(d+e*x)^(6+m)/(e^8*(6+m))-_
+     c^3*(7*B*d-A*e)*(d+e*x)^(7+m)/(e^8*(7+m))+B*c^3*(d+e*x)^(8+m)/(e^8*(8+m))
+--R 
+--R
+--R   (2)
+--R              3 7        3 6         3 5          3 4          3 3           3 2
+--R           B c m  + 28B c m  + 322B c m  + 1960B c m  + 6769B c m  + 13132B c m
+--R         + 
+--R                   3           3
+--R           13068B c m + 5040B c
+--R      *
+--R                  m + 8
+--R         (e x + d)
+--R     + 
+--R               3        3   7         3          3   6
+--R           (A c e - 7B c d)m  + (29A c e - 203B c d)m
+--R         + 
+--R                  3           3   5           3            3   4
+--R           (343A c e - 2401B c d)m  + (2135A c e - 14945B c d)m
+--R         + 
+--R                   3            3   3            3             3   2
+--R           (7504A c e - 52528B c d)m  + (14756A c e - 103292B c d)m
+--R         + 
+--R                    3             3             3            3
+--R           (14832A c e - 103824B c d)m + 5760A c e - 40320B c d
+--R      *
+--R                  m + 7
+--R         (e x + d)
+--R     + 
+--R                  2 2       3           3 2  7
+--R           (3B a c e  - 6A c d e + 21B c d )m
+--R         + 
+--R                   2 2         3            3 2  6
+--R           (90B a c e  - 180A c d e + 630B c d )m
+--R         + 
+--R                     2 2          3             3 2  5
+--R           (1098B a c e  - 2196A c d e + 7686B c d )m
+--R         + 
+--R                     2 2           3              3 2  4
+--R           (7020B a c e  - 14040A c d e + 49140B c d )m
+--R         + 
+--R                      2 2           3               3 2  3
+--R           (25227B a c e  - 50454A c d e + 176589B c d )m
+--R         + 
+--R                      2 2            3               3 2  2
+--R           (50490B a c e  - 100980A c d e + 353430B c d )m
+--R         + 
+--R                      2 2            3               3 2               2 2
+--R           (51432B a c e  - 102864A c d e + 360024B c d )m + 20160B a c e
+--R         + 
+--R                     3               3 2
+--R           - 40320A c d e + 141120B c d
+--R      *
+--R                  m + 6
+--R         (e x + d)
+--R     + 
+--R                  2 3          2   2        3 2         3 3  7
+--R           (3A a c e  - 15B a c d e  + 15A c d e - 35B c d )m
+--R         + 
+--R                   2 3           2   2         3 2           3 3  6
+--R           (93A a c e  - 465B a c d e  + 465A c d e - 1085B c d )m
+--R         + 
+--R                     2 3            2   2          3 2            3 3  5
+--R           (1173A a c e  - 5865B a c d e  + 5865A c d e - 13685B c d )m
+--R         + 
+--R                     2 3             2   2           3 2            3 3  4
+--R           (7743A a c e  - 38715B a c d e  + 38715A c d e - 90335B c d )m
+--R         + 
+--R                      2 3              2   2            3 2             3 3  3
+--R           (28632A a c e  - 143160B a c d e  + 143160A c d e - 334040B c d )m
+--R         + 
+--R                      2 3              2   2            3 2             3 3  2
+--R           (58692A a c e  - 293460B a c d e  + 293460A c d e - 684740B c d )m
+--R         + 
+--R                      2 3              2   2            3 2             3 3
+--R           (60912A a c e  - 304560B a c d e  + 304560A c d e - 710640B c d )m
+--R         + 
+--R                     2 3              2   2            3 2             3 3
+--R           24192A a c e  - 120960B a c d e  + 120960A c d e - 282240B c d
+--R      *
+--R                  m + 5
+--R         (e x + d)
+--R     + 
+--R                2   4          2   3          2 2 2        3 3         3 4  7
+--R           (3B a c e  - 12A a c d e  + 30B a c d e  - 20A c d e + 35B c d )m
+--R         + 
+--R                    2   4           2   3           2 2 2         3 3
+--R               96B a c e  - 384A a c d e  + 960B a c d e  - 640A c d e
+--R             + 
+--R                      3 4
+--R               1120B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                      2   4            2   3             2 2 2          3 3
+--R               1254B a c e  - 5016A a c d e  + 12540B a c d e  - 8360A c d e
+--R             + 
+--R                       3 4
+--R               14630B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                      2   4             2   3             2 2 2           3 3
+--R               8592B a c e  - 34368A a c d e  + 85920B a c d e  - 57280A c d e
+--R             + 
+--R                        3 4
+--R               100240B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       2   4              2   3              2 2 2
+--R               32979B a c e  - 131916A a c d e  + 329790B a c d e
+--R             + 
+--R                          3 3             3 4
+--R               - 219860A c d e + 384755B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       2   4              2   3              2 2 2
+--R               69936B a c e  - 279744A a c d e  + 699360B a c d e
+--R             + 
+--R                          3 3             3 4
+--R               - 466240A c d e + 815920B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                       2   4              2   3              2 2 2
+--R               74628B a c e  - 298512A a c d e  + 746280B a c d e
+--R             + 
+--R                          3 3             3 4
+--R               - 497520A c d e + 870660B c d
+--R          *
+--R             m
+--R         + 
+--R                   2   4              2   3              2 2 2            3 3
+--R           30240B a c e  - 120960A a c d e  + 302400B a c d e  - 201600A c d e
+--R         + 
+--R                    3 4
+--R           352800B c d
+--R      *
+--R                  m + 4
+--R         (e x + d)
+--R     + 
+--R                   2   5       2     4          2 2 3          2 3 2        3 4
+--R               3A a c e  - 9B a c d e  + 18A a c d e  - 30B a c d e  + 15A c d e
+--R             + 
+--R                      3 5
+--R               - 21B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                    2   5         2     4           2 2 3           2 3 2
+--R               99A a c e  - 297B a c d e  + 594A a c d e  - 990B a c d e
+--R             + 
+--R                     3 4          3 5
+--R               495A c d e - 693B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                      2   5          2     4            2 2 3             2 3 2
+--R               1341A a c e  - 4023B a c d e  + 8046A a c d e  - 13410B a c d e
+--R             + 
+--R                      3 4           3 5
+--R               6705A c d e - 9387B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                      2   5           2     4             2 2 3
+--R               9585A a c e  - 28755B a c d e  + 57510A a c d e
+--R             + 
+--R                           2 3 2           3 4            3 5
+--R               - 95850B a c d e  + 47925A c d e - 67095B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       2   5            2     4              2 2 3
+--R               38592A a c e  - 115776B a c d e  + 231552A a c d e
+--R             + 
+--R                            2 3 2            3 4             3 5
+--R               - 385920B a c d e  + 192960A c d e - 270144B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       2   5            2     4              2 2 3
+--R               86076A a c e  - 258228B a c d e  + 516456A a c d e
+--R             + 
+--R                            2 3 2            3 4             3 5
+--R               - 860760B a c d e  + 430380A c d e - 602532B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                       2   5            2     4              2 2 3
+--R               96144A a c e  - 288432B a c d e  + 576864A a c d e
+--R             + 
+--R                            2 3 2            3 4             3 5
+--R               - 961440B a c d e  + 480720A c d e - 673008B c d
+--R          *
+--R             m
+--R         + 
+--R                   2   5            2     4              2 2 3
+--R           40320A a c e  - 120960B a c d e  + 241920A a c d e
+--R         + 
+--R                        2 3 2            3 4             3 5
+--R           - 403200B a c d e  + 201600A c d e - 282240B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                  3 6       2     5       2   2 4          2 3 3          2 4 2
+--R               B a e  - 6A a c d e  + 9B a c d e  - 12A a c d e  + 15B a c d e
+--R             + 
+--R                     3 5        3 6
+--R               - 6A c d e + 7B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                    3 6         2     5         2   2 4           2 3 3
+--R               34B a e  - 204A a c d e  + 306B a c d e  - 408A a c d e
+--R             + 
+--R                       2 4 2         3 5          3 6
+--R               510B a c d e  - 204A c d e + 238B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                     3 6          2     5          2   2 4            2 3 3
+--R               478B a e  - 2868A a c d e  + 4302B a c d e  - 5736A a c d e
+--R             + 
+--R                        2 4 2          3 5           3 6
+--R               7170B a c d e  - 2868A c d e + 3346B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                      3 6           2     5           2   2 4             2 3 3
+--R               3580B a e  - 21480A a c d e  + 32220B a c d e  - 42960A a c d e
+--R             + 
+--R                         2 4 2           3 5            3 6
+--R               53700B a c d e  - 21480A c d e + 25060B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       3 6           2     5            2   2 4
+--R               15289B a e  - 91734A a c d e  + 137601B a c d e
+--R             + 
+--R                          2 3 3              2 4 2           3 5             3 6
+--R             - 183468A a c d e  + 229335B a c d e  - 91734A c d e + 107023B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       3 6            2     5            2   2 4
+--R               36706B a e  - 220236A a c d e  + 330354B a c d e
+--R             + 
+--R                            2 3 3              2 4 2            3 5
+--R               - 440472A a c d e  + 550590B a c d e  - 220236A c d e
+--R             + 
+--R                        3 6
+--R               256942B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                       3 6            2     5            2   2 4
+--R               44712B a e  - 268272A a c d e  + 402408B a c d e
+--R             + 
+--R                            2 3 3              2 4 2            3 5
+--R               - 536544A a c d e  + 670680B a c d e  - 268272A c d e
+--R             + 
+--R                        3 6
+--R               312984B c d
+--R          *
+--R             m
+--R         + 
+--R                   3 6            2     5            2   2 4              2 3 3
+--R           20160B a e  - 120960A a c d e  + 181440B a c d e  - 241920A a c d e
+--R         + 
+--R                      2 4 2            3 5             3 6
+--R           302400B a c d e  - 120960A c d e + 141120B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R                  3 7      3   6       2   2 5       2   3 4         2 4 3
+--R               A a e  - B a d e  + 3A a c d e  - 3B a c d e  + 3A a c d e
+--R             + 
+--R                       2 5 2      3 6       3 7
+--R               - 3B a c d e  + A c d e - B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                    3 7        3   6         2   2 5         2   3 4
+--R               35A a e  - 35B a d e  + 105A a c d e  - 105B a c d e
+--R             + 
+--R                       2 4 3           2 5 2        3 6         3 7
+--R               105A a c d e  - 105B a c d e  + 35A c d e - 35B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                     3 7         3   6          2   2 5          2   3 4
+--R               511A a e  - 511B a d e  + 1533A a c d e  - 1533B a c d e
+--R             + 
+--R                        2 4 3            2 5 2         3 6          3 7
+--R               1533A a c d e  - 1533B a c d e  + 511A c d e - 511B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                      3 7          3   6           2   2 5           2   3 4
+--R               4025A a e  - 4025B a d e  + 12075A a c d e  - 12075B a c d e
+--R             + 
+--R                         2 4 3             2 5 2          3 6           3 7
+--R               12075A a c d e  - 12075B a c d e  + 4025A c d e - 4025B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                       3 7           3   6           2   2 5           2   3 4
+--R               18424A a e  - 18424B a d e  + 55272A a c d e  - 55272B a c d e
+--R             + 
+--R                         2 4 3             2 5 2           3 6            3 7
+--R               55272A a c d e  - 55272B a c d e  + 18424A c d e - 18424B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       3 7           3   6            2   2 5            2   3 4
+--R               48860A a e  - 48860B a d e  + 146580A a c d e  - 146580B a c d e
+--R             + 
+--R                          2 4 3              2 5 2           3 6            3 7
+--R               146580A a c d e  - 146580B a c d e  + 48860A c d e - 48860B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                       3 7           3   6            2   2 5            2   3 4
+--R               69264A a e  - 69264B a d e  + 207792A a c d e  - 207792B a c d e
+--R             + 
+--R                          2 4 3              2 5 2           3 6            3 7
+--R               207792A a c d e  - 207792B a c d e  + 69264A c d e - 69264B c d
+--R          *
+--R             m
+--R         + 
+--R                   3 7           3   6            2   2 5            2   3 4
+--R           40320A a e  - 40320B a d e  + 120960A a c d e  - 120960B a c d e
+--R         + 
+--R                      2 4 3              2 5 2           3 6            3 7
+--R           120960A a c d e  - 120960B a c d e  + 40320A c d e - 40320B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R        8 8      8 7       8 6        8 5         8 4         8 3          8 2
+--R       e m  + 36e m  + 546e m  + 4536e m  + 22449e m  + 67284e m  + 118124e m
+--R     + 
+--R              8          8
+--R       109584e m + 40320e
+--R                                                    Type: Expression(Integer)
+--E 1183
+
+--S 1184 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 8 7        3 8 6         3 8 5          3 8 4          3 8 3
+--R             B c e m  + 28B c e m  + 322B c e m  + 1960B c e m  + 6769B c e m
+--R           + 
+--R                     3 8 2           3 8           3 8
+--R             13132B c e m  + 13068B c e m + 5040B c e
+--R        *
+--R            8
+--R           x
+--R       + 
+--R                 3 8      3   7  7         3 8        3   7  6
+--R             (A c e  + B c d e )m  + (29A c e  + 21B c d e )m
+--R           + 
+--R                    3 8         3   7  5           3 8         3   7  4
+--R             (343A c e  + 175B c d e )m  + (2135A c e  + 735B c d e )m
+--R           + 
+--R                     3 8          3   7  3            3 8          3   7  2
+--R             (7504A c e  + 1624B c d e )m  + (14756A c e  + 1764B c d e )m
+--R           + 
+--R                      3 8         3   7            3 8
+--R             (14832A c e  + 720B c d e )m + 5760A c e
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                    2 8      3   7  7           2 8        3   7       3 2 6  6
+--R             (3B a c e  + A c d e )m  + (90B a c e  + 23A c d e  - 7B c d e )m
+--R           + 
+--R                       2 8         3   7         3 2 6  5
+--R             (1098B a c e  + 205A c d e  - 105B c d e )m
+--R           + 
+--R                       2 8         3   7         3 2 6  4
+--R             (7020B a c e  + 905A c d e  - 595B c d e )m
+--R           + 
+--R                        2 8          3   7          3 2 6  3
+--R             (25227B a c e  + 2074A c d e  - 1575B c d e )m
+--R           + 
+--R                        2 8          3   7          3 2 6  2
+--R             (50490B a c e  + 2312A c d e  - 1918B c d e )m
+--R           + 
+--R                        2 8         3   7         3 2 6               2 8
+--R             (51432B a c e  + 960A c d e  - 840B c d e )m + 20160B a c e
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                    2 8         2   7  7
+--R             (3A a c e  + 3B a c d e )m
+--R           + 
+--R                     2 8          2   7       3 2 6  6
+--R             (93A a c e  + 75B a c d e  - 6A c d e )m
+--R           + 
+--R                       2 8           2   7         3 2 6        3 3 5  5
+--R             (1173A a c e  + 723B a c d e  - 108A c d e  + 42B c d e )m
+--R           + 
+--R                       2 8            2   7         3 2 6         3 3 5  4
+--R             (7743A a c e  + 3405B a c d e  - 690A c d e  + 420B c d e )m
+--R           + 
+--R                        2 8            2   7          3 2 6          3 3 5  3
+--R             (28632A a c e  + 8202B a c d e  - 1980A c d e  + 1470B c d e )m
+--R           + 
+--R                        2 8            2   7          3 2 6          3 3 5  2
+--R             (58692A a c e  + 9480B a c d e  - 2544A c d e  + 2100B c d e )m
+--R           + 
+--R                        2 8            2   7          3 2 6          3 3 5
+--R             (60912A a c e  + 4032B a c d e  - 1152A c d e  + 1008B c d e )m
+--R           + 
+--R                       2 8
+--R             24192A a c e
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                  2   8         2   7  7
+--R             (3B a c e  + 3A a c d e )m
+--R           + 
+--R                   2   8          2   7          2 2 6  6
+--R             (96B a c e  + 81A a c d e  - 15B a c d e )m
+--R           + 
+--R                     2   8           2   7           2 2 6        3 3 5  5
+--R             (1254B a c e  + 849A a c d e  - 315B a c d e  + 30A c d e )m
+--R           + 
+--R                        2   8            2   7            2 2 6         3 3 5
+--R                 8592B a c e  + 4347A a c d e  - 2355B a c d e  + 420A c d e
+--R               + 
+--R                         3 4 4
+--R                 - 210B c d e
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                         2   8             2   7            2 2 6          3 3 5
+--R                 32979B a c e  + 11244A a c d e  - 7605B a c d e  + 1770A c d e
+--R               + 
+--R                          3 4 4
+--R                 - 1260B c d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                         2   8             2   7             2 2 6
+--R                 69936B a c e  + 13716A a c d e  - 10590B a c d e
+--R               + 
+--R                        3 3 5          3 4 4
+--R                 2820A c d e  - 2310B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                         2   8            2   7            2 2 6          3 3 5
+--R                 74628B a c e  + 6048A a c d e  - 5040B a c d e  + 1440A c d e
+--R               + 
+--R                          3 4 4
+--R                 - 1260B c d e
+--R            *
+--R               m
+--R           + 
+--R                     2   8
+--R             30240B a c e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                  2   8       2     7  7
+--R             (3A a c e  + 3B a c d e )m
+--R           + 
+--R                   2   8        2     7          2 2 6  6
+--R             (99A a c e  + 87B a c d e  - 12A a c d e )m
+--R           + 
+--R                     2   8         2     7           2 2 6          2 3 5  5
+--R             (1341A a c e  + 993B a c d e  - 288A a c d e  + 60B a c d e )m
+--R           + 
+--R                        2   8          2     7            2 2 6            2 3 5
+--R                 9585A a c e  + 5613B a c d e  - 2532A a c d e  + 1080B a c d e
+--R               + 
+--R                         3 4 4
+--R                 - 120A c d e
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                         2   8           2     7            2 2 6
+--R                 38592A a c e  + 16140B a c d e  - 9792A a c d e
+--R               + 
+--R                          2 3 5          3 4 4         3 5 3
+--R                 6180B a c d e  - 1320A c d e  + 840B c d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                         2   8           2     7             2 2 6
+--R                 86076A a c e  + 21516B a c d e  - 15600A a c d e
+--R               + 
+--R                           2 3 5          3 4 4          3 5 3
+--R                 11880B a c d e  - 3120A c d e  + 2520B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                         2   8           2     7            2 2 6
+--R                 96144A a c e  + 10080B a c d e  - 8064A a c d e
+--R               + 
+--R                          2 3 5          3 4 4          3 5 3
+--R                 6720B a c d e  - 1920A c d e  + 1680B c d e
+--R            *
+--R               m
+--R           + 
+--R                     2   8
+--R             40320A a c e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                 3 8       2     7  7
+--R             (B a e  + 3A a c d e )m
+--R           + 
+--R                   3 8        2     7       2   2 6  6
+--R             (34B a e  + 93A a c d e  - 9B a c d e )m
+--R           + 
+--R                    3 8          2     7         2   2 6          2 3 5  5
+--R             (478B a e  + 1155A a c d e  - 243B a c d e  + 36A a c d e )m
+--R           + 
+--R                        3 8          2     7          2   2 6           2 3 5
+--R                 3580B a e  + 7275A a c d e  - 2493B a c d e  + 792A a c d e
+--R               + 
+--R                           2 4 4
+--R                 - 180B a c d e
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                         3 8           2     7           2   2 6
+--R                 15289B a e  + 24042A a c d e  - 11853B a c d e
+--R               + 
+--R                          2 3 5            2 4 4         3 5 3
+--R                 6012A a c d e  - 2880B a c d e  + 360A c d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                         3 8           2     7           2   2 6
+--R                 36706B a e  + 37992A a c d e  - 24714B a c d e
+--R               + 
+--R                         2 3 5             2 4 4          3 5 3          3 6 2
+--R               17352A a c d e  - 12780B a c d e  + 3240A c d e  - 2520B c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                         3 8           2     7           2   2 6
+--R                 44712B a e  + 20160A a c d e  - 15120B a c d e
+--R               + 
+--R                         2 3 5             2 4 4          3 5 3          3 6 2
+--R               12096A a c d e  - 10080B a c d e  + 2880A c d e  - 2520B c d e
+--R            *
+--R               m
+--R           + 
+--R                     3 8
+--R             20160B a e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                 3 8      3   7  7         3 8        3   7       2   2 6  6
+--R             (A a e  + B a d e )m  + (35A a e  + 33B a d e  - 6A a c d e )m
+--R           + 
+--R                    3 8         3   7         2   2 6        2   3 5  5
+--R             (511A a e  + 445B a d e  - 180A a c d e  + 18B a c d e )m
+--R           + 
+--R                        3 8          3   7          2   2 6         2   3 5
+--R                 4025A a e  + 3135B a d e  - 2130A a c d e  + 468B a c d e
+--R               + 
+--R                          2 4 4
+--R                 - 72A a c d e
+--R            *
+--R                4
+--R               m
+--R           + 
+--R                         3 8           3   7           2   2 6          2   3 5
+--R                 18424A a e  + 12154B a d e  - 12420A a c d e  + 4518B a c d e
+--R               + 
+--R                            2 4 4           2 5 3
+--R                 - 1512A a c d e  + 360B a c d e
+--R            *
+--R                3
+--R               m
+--R           + 
+--R                         3 8           3   7           2   2 6           2   3 5
+--R                 48860A a e  + 24552B a d e  - 35664A a c d e  + 19188B a c d e
+--R               + 
+--R                             2 4 4            2 5 3         3 6 2
+--R                 - 10512A a c d e  + 5400B a c d e  - 720A c d e
+--R            *
+--R                2
+--R               m
+--R           + 
+--R                         3 8           3   7           2   2 6           2   3 5
+--R                 69264A a e  + 20160B a d e  - 40320A a c d e  + 30240B a c d e
+--R               + 
+--R                           2 4 4             2 5 3          3 6 2          3 7
+--R               - 24192A a c d e  + 20160B a c d e  - 5760A c d e  + 5040B c d e
+--R            *
+--R               m
+--R           + 
+--R                     3 8
+--R             40320A a e
+--R        *
+--R           x
+--R       + 
+--R            3   7 7         3   7      3 2 6  6
+--R         A a d e m  + (35A a d e  - B a d e )m
+--R       + 
+--R                3   7        3 2 6       2   3 5  5
+--R         (511A a d e  - 33B a d e  + 6A a c d e )m
+--R       + 
+--R                 3   7         3 2 6         2   3 5        2   4 4  4
+--R         (4025A a d e  - 445B a d e  + 180A a c d e  - 18B a c d e )m
+--R       + 
+--R                     3   7          3 2 6          2   3 5         2   4 4
+--R             18424A a d e  - 3135B a d e  + 2130A a c d e  - 468B a c d e
+--R           + 
+--R                    2 5 3
+--R             72A a c d e
+--R        *
+--R            3
+--R           m
+--R       + 
+--R                     3   7           3 2 6           2   3 5          2   4 4
+--R             48860A a d e  - 12154B a d e  + 12420A a c d e  - 4518B a c d e
+--R           + 
+--R                      2 5 3           2 6 2
+--R             1512A a c d e  - 360B a c d e
+--R        *
+--R            2
+--R           m
+--R       + 
+--R                     3   7           3 2 6           2   3 5           2   4 4
+--R             69264A a d e  - 24552B a d e  + 35664A a c d e  - 19188B a c d e
+--R           + 
+--R                       2 5 3            2 6 2         3 7
+--R             10512A a c d e  - 5400B a c d e  + 720A c d e
+--R        *
+--R           m
+--R       + 
+--R                 3   7           3 2 6           2   3 5           2   4 4
+--R         40320A a d e  - 20160B a d e  + 40320A a c d e  - 30240B a c d e
+--R       + 
+--R                   2 5 3             2 6 2          3 7           3 8
+--R         24192A a c d e  - 20160B a c d e  + 5760A c d e - 5040B c d
+--R    *
+--R         m log(e x + d)
+--R       %e
+--R  /
+--R        8 8      8 7       8 6        8 5         8 4         8 3          8 2
+--R       e m  + 36e m  + 546e m  + 4536e m  + 22449e m  + 67284e m  + 118124e m
+--R     + 
+--R              8          8
+--R       109584e m + 40320e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1184
+
+--S 1185 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  3 8 7        3 8 6         3 8 5          3 8 4          3 8 3
+--R               B c e m  + 28B c e m  + 322B c e m  + 1960B c e m  + 6769B c e m
+--R             + 
+--R                       3 8 2           3 8           3 8
+--R               13132B c e m  + 13068B c e m + 5040B c e
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                   3 8      3   7  7         3 8        3   7  6
+--R               (A c e  + B c d e )m  + (29A c e  + 21B c d e )m
+--R             + 
+--R                      3 8         3   7  5           3 8         3   7  4
+--R               (343A c e  + 175B c d e )m  + (2135A c e  + 735B c d e )m
+--R             + 
+--R                       3 8          3   7  3            3 8          3   7  2
+--R               (7504A c e  + 1624B c d e )m  + (14756A c e  + 1764B c d e )m
+--R             + 
+--R                        3 8         3   7            3 8
+--R               (14832A c e  + 720B c d e )m + 5760A c e
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                      2 8      3   7  7
+--R               (3B a c e  + A c d e )m
+--R             + 
+--R                       2 8        3   7       3 2 6  6
+--R               (90B a c e  + 23A c d e  - 7B c d e )m
+--R             + 
+--R                         2 8         3   7         3 2 6  5
+--R               (1098B a c e  + 205A c d e  - 105B c d e )m
+--R             + 
+--R                         2 8         3   7         3 2 6  4
+--R               (7020B a c e  + 905A c d e  - 595B c d e )m
+--R             + 
+--R                          2 8          3   7          3 2 6  3
+--R               (25227B a c e  + 2074A c d e  - 1575B c d e )m
+--R             + 
+--R                          2 8          3   7          3 2 6  2
+--R               (50490B a c e  + 2312A c d e  - 1918B c d e )m
+--R             + 
+--R                          2 8         3   7         3 2 6               2 8
+--R               (51432B a c e  + 960A c d e  - 840B c d e )m + 20160B a c e
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      2 8         2   7  7
+--R               (3A a c e  + 3B a c d e )m
+--R             + 
+--R                       2 8          2   7       3 2 6  6
+--R               (93A a c e  + 75B a c d e  - 6A c d e )m
+--R             + 
+--R                         2 8           2   7         3 2 6        3 3 5  5
+--R               (1173A a c e  + 723B a c d e  - 108A c d e  + 42B c d e )m
+--R             + 
+--R                         2 8            2   7         3 2 6         3 3 5  4
+--R               (7743A a c e  + 3405B a c d e  - 690A c d e  + 420B c d e )m
+--R             + 
+--R                          2 8            2   7          3 2 6          3 3 5  3
+--R               (28632A a c e  + 8202B a c d e  - 1980A c d e  + 1470B c d e )m
+--R             + 
+--R                          2 8            2   7          3 2 6          3 3 5  2
+--R               (58692A a c e  + 9480B a c d e  - 2544A c d e  + 2100B c d e )m
+--R             + 
+--R                          2 8            2   7          3 2 6          3 3 5
+--R               (60912A a c e  + 4032B a c d e  - 1152A c d e  + 1008B c d e )m
+--R             + 
+--R                         2 8
+--R               24192A a c e
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    2   8         2   7  7
+--R               (3B a c e  + 3A a c d e )m
+--R             + 
+--R                     2   8          2   7          2 2 6  6
+--R               (96B a c e  + 81A a c d e  - 15B a c d e )m
+--R             + 
+--R                       2   8           2   7           2 2 6        3 3 5  5
+--R               (1254B a c e  + 849A a c d e  - 315B a c d e  + 30A c d e )m
+--R             + 
+--R                          2   8            2   7            2 2 6         3 3 5
+--R                   8592B a c e  + 4347A a c d e  - 2355B a c d e  + 420A c d e
+--R                 + 
+--R                           3 4 4
+--R                   - 210B c d e
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                           2   8             2   7            2 2 6
+--R                   32979B a c e  + 11244A a c d e  - 7605B a c d e
+--R                 + 
+--R                          3 3 5          3 4 4
+--R                   1770A c d e  - 1260B c d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                           2   8             2   7             2 2 6
+--R                   69936B a c e  + 13716A a c d e  - 10590B a c d e
+--R                 + 
+--R                          3 3 5          3 4 4
+--R                   2820A c d e  - 2310B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                           2   8            2   7            2 2 6
+--R                   74628B a c e  + 6048A a c d e  - 5040B a c d e
+--R                 + 
+--R                          3 3 5          3 4 4
+--R                   1440A c d e  - 1260B c d e
+--R              *
+--R                 m
+--R             + 
+--R                       2   8
+--R               30240B a c e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    2   8       2     7  7
+--R               (3A a c e  + 3B a c d e )m
+--R             + 
+--R                     2   8        2     7          2 2 6  6
+--R               (99A a c e  + 87B a c d e  - 12A a c d e )m
+--R             + 
+--R                       2   8         2     7           2 2 6          2 3 5  5
+--R               (1341A a c e  + 993B a c d e  - 288A a c d e  + 60B a c d e )m
+--R             + 
+--R                          2   8          2     7            2 2 6
+--R                   9585A a c e  + 5613B a c d e  - 2532A a c d e
+--R                 + 
+--R                            2 3 5         3 4 4
+--R                   1080B a c d e  - 120A c d e
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                           2   8           2     7            2 2 6
+--R                   38592A a c e  + 16140B a c d e  - 9792A a c d e
+--R                 + 
+--R                            2 3 5          3 4 4         3 5 3
+--R                   6180B a c d e  - 1320A c d e  + 840B c d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                           2   8           2     7             2 2 6
+--R                   86076A a c e  + 21516B a c d e  - 15600A a c d e
+--R                 + 
+--R                             2 3 5          3 4 4          3 5 3
+--R                   11880B a c d e  - 3120A c d e  + 2520B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                           2   8           2     7            2 2 6
+--R                   96144A a c e  + 10080B a c d e  - 8064A a c d e
+--R                 + 
+--R                            2 3 5          3 4 4          3 5 3
+--R                   6720B a c d e  - 1920A c d e  + 1680B c d e
+--R              *
+--R                 m
+--R             + 
+--R                       2   8
+--R               40320A a c e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   3 8       2     7  7
+--R               (B a e  + 3A a c d e )m
+--R             + 
+--R                     3 8        2     7       2   2 6  6
+--R               (34B a e  + 93A a c d e  - 9B a c d e )m
+--R             + 
+--R                      3 8          2     7         2   2 6          2 3 5  5
+--R               (478B a e  + 1155A a c d e  - 243B a c d e  + 36A a c d e )m
+--R             + 
+--R                          3 8          2     7          2   2 6           2 3 5
+--R                   3580B a e  + 7275A a c d e  - 2493B a c d e  + 792A a c d e
+--R                 + 
+--R                             2 4 4
+--R                   - 180B a c d e
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                           3 8           2     7           2   2 6
+--R                   15289B a e  + 24042A a c d e  - 11853B a c d e
+--R                 + 
+--R                            2 3 5            2 4 4         3 5 3
+--R                   6012A a c d e  - 2880B a c d e  + 360A c d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                           3 8           2     7           2   2 6
+--R                   36706B a e  + 37992A a c d e  - 24714B a c d e
+--R                 + 
+--R                           2 3 5             2 4 4          3 5 3          3 6 2
+--R                 17352A a c d e  - 12780B a c d e  + 3240A c d e  - 2520B c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                           3 8           2     7           2   2 6
+--R                   44712B a e  + 20160A a c d e  - 15120B a c d e
+--R                 + 
+--R                           2 3 5             2 4 4          3 5 3          3 6 2
+--R                 12096A a c d e  - 10080B a c d e  + 2880A c d e  - 2520B c d e
+--R              *
+--R                 m
+--R             + 
+--R                       3 8
+--R               20160B a e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   3 8      3   7  7         3 8        3   7       2   2 6  6
+--R               (A a e  + B a d e )m  + (35A a e  + 33B a d e  - 6A a c d e )m
+--R             + 
+--R                      3 8         3   7         2   2 6        2   3 5  5
+--R               (511A a e  + 445B a d e  - 180A a c d e  + 18B a c d e )m
+--R             + 
+--R                          3 8          3   7          2   2 6         2   3 5
+--R                   4025A a e  + 3135B a d e  - 2130A a c d e  + 468B a c d e
+--R                 + 
+--R                            2 4 4
+--R                   - 72A a c d e
+--R              *
+--R                  4
+--R                 m
+--R             + 
+--R                           3 8           3   7           2   2 6
+--R                   18424A a e  + 12154B a d e  - 12420A a c d e
+--R                 + 
+--R                          2   3 5            2 4 4           2 5 3
+--R                   4518B a c d e  - 1512A a c d e  + 360B a c d e
+--R              *
+--R                  3
+--R                 m
+--R             + 
+--R                           3 8           3   7           2   2 6
+--R                   48860A a e  + 24552B a d e  - 35664A a c d e
+--R                 + 
+--R                           2   3 5             2 4 4            2 5 3
+--R                   19188B a c d e  - 10512A a c d e  + 5400B a c d e
+--R                 + 
+--R                           3 6 2
+--R                   - 720A c d e
+--R              *
+--R                  2
+--R                 m
+--R             + 
+--R                           3 8           3   7           2   2 6
+--R                   69264A a e  + 20160B a d e  - 40320A a c d e
+--R                 + 
+--R                           2   3 5             2 4 4             2 5 3
+--R                   30240B a c d e  - 24192A a c d e  + 20160B a c d e
+--R                 + 
+--R                            3 6 2          3 7
+--R                   - 5760A c d e  + 5040B c d e
+--R              *
+--R                 m
+--R             + 
+--R                       3 8
+--R               40320A a e
+--R          *
+--R             x
+--R         + 
+--R              3   7 7         3   7      3 2 6  6
+--R           A a d e m  + (35A a d e  - B a d e )m
+--R         + 
+--R                  3   7        3 2 6       2   3 5  5
+--R           (511A a d e  - 33B a d e  + 6A a c d e )m
+--R         + 
+--R                   3   7         3 2 6         2   3 5        2   4 4  4
+--R           (4025A a d e  - 445B a d e  + 180A a c d e  - 18B a c d e )m
+--R         + 
+--R                       3   7          3 2 6          2   3 5         2   4 4
+--R               18424A a d e  - 3135B a d e  + 2130A a c d e  - 468B a c d e
+--R             + 
+--R                      2 5 3
+--R               72A a c d e
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                       3   7           3 2 6           2   3 5          2   4 4
+--R               48860A a d e  - 12154B a d e  + 12420A a c d e  - 4518B a c d e
+--R             + 
+--R                        2 5 3           2 6 2
+--R               1512A a c d e  - 360B a c d e
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                       3   7           3 2 6           2   3 5           2   4 4
+--R               69264A a d e  - 24552B a d e  + 35664A a c d e  - 19188B a c d e
+--R             + 
+--R                         2 5 3            2 6 2         3 7
+--R               10512A a c d e  - 5400B a c d e  + 720A c d e
+--R          *
+--R             m
+--R         + 
+--R                   3   7           3 2 6           2   3 5           2   4 4
+--R           40320A a d e  - 20160B a d e  + 40320A a c d e  - 30240B a c d e
+--R         + 
+--R                     2 5 3             2 6 2          3 7           3 8
+--R           24192A a c d e  - 20160B a c d e  + 5760A c d e - 5040B c d
+--R      *
+--R           m log(e x + d)
+--R         %e
+--R     + 
+--R                3 7        3 6         3 5          3 4          3 3
+--R           - B c m  - 28B c m  - 322B c m  - 1960B c m  - 6769B c m
+--R         + 
+--R                     3 2           3           3
+--R           - 13132B c m  - 13068B c m - 5040B c
+--R      *
+--R                  m + 8
+--R         (e x + d)
+--R     + 
+--R                 3        3   7           3          3   6
+--R           (- A c e + 7B c d)m  + (- 29A c e + 203B c d)m
+--R         + 
+--R                    3           3   5             3            3   4
+--R           (- 343A c e + 2401B c d)m  + (- 2135A c e + 14945B c d)m
+--R         + 
+--R                     3            3   3              3             3   2
+--R           (- 7504A c e + 52528B c d)m  + (- 14756A c e + 103292B c d)m
+--R         + 
+--R                      3             3             3            3
+--R           (- 14832A c e + 103824B c d)m - 5760A c e + 40320B c d
+--R      *
+--R                  m + 7
+--R         (e x + d)
+--R     + 
+--R                    2 2       3           3 2  7
+--R           (- 3B a c e  + 6A c d e - 21B c d )m
+--R         + 
+--R                     2 2         3            3 2  6
+--R           (- 90B a c e  + 180A c d e - 630B c d )m
+--R         + 
+--R                       2 2          3             3 2  5
+--R           (- 1098B a c e  + 2196A c d e - 7686B c d )m
+--R         + 
+--R                       2 2           3              3 2  4
+--R           (- 7020B a c e  + 14040A c d e - 49140B c d )m
+--R         + 
+--R                        2 2           3               3 2  3
+--R           (- 25227B a c e  + 50454A c d e - 176589B c d )m
+--R         + 
+--R                        2 2            3               3 2  2
+--R           (- 50490B a c e  + 100980A c d e - 353430B c d )m
+--R         + 
+--R                        2 2            3               3 2               2 2
+--R           (- 51432B a c e  + 102864A c d e - 360024B c d )m - 20160B a c e
+--R         + 
+--R                   3               3 2
+--R           40320A c d e - 141120B c d
+--R      *
+--R                  m + 6
+--R         (e x + d)
+--R     + 
+--R                    2 3          2   2        3 2         3 3  7
+--R           (- 3A a c e  + 15B a c d e  - 15A c d e + 35B c d )m
+--R         + 
+--R                     2 3           2   2         3 2           3 3  6
+--R           (- 93A a c e  + 465B a c d e  - 465A c d e + 1085B c d )m
+--R         + 
+--R                       2 3            2   2          3 2            3 3  5
+--R           (- 1173A a c e  + 5865B a c d e  - 5865A c d e + 13685B c d )m
+--R         + 
+--R                       2 3             2   2           3 2            3 3  4
+--R           (- 7743A a c e  + 38715B a c d e  - 38715A c d e + 90335B c d )m
+--R         + 
+--R                        2 3              2   2            3 2             3 3  3
+--R           (- 28632A a c e  + 143160B a c d e  - 143160A c d e + 334040B c d )m
+--R         + 
+--R                        2 3              2   2            3 2             3 3  2
+--R           (- 58692A a c e  + 293460B a c d e  - 293460A c d e + 684740B c d )m
+--R         + 
+--R                        2 3              2   2            3 2             3 3
+--R           (- 60912A a c e  + 304560B a c d e  - 304560A c d e + 710640B c d )m
+--R         + 
+--R                       2 3              2   2            3 2             3 3
+--R           - 24192A a c e  + 120960B a c d e  - 120960A c d e + 282240B c d
+--R      *
+--R                  m + 5
+--R         (e x + d)
+--R     + 
+--R                  2   4          2   3          2 2 2        3 3         3 4  7
+--R           (- 3B a c e  + 12A a c d e  - 30B a c d e  + 20A c d e - 35B c d )m
+--R         + 
+--R                      2   4           2   3           2 2 2         3 3
+--R               - 96B a c e  + 384A a c d e  - 960B a c d e  + 640A c d e
+--R             + 
+--R                        3 4
+--R               - 1120B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                        2   4            2   3             2 2 2          3 3
+--R               - 1254B a c e  + 5016A a c d e  - 12540B a c d e  + 8360A c d e
+--R             + 
+--R                         3 4
+--R               - 14630B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                        2   4             2   3             2 2 2           3 3
+--R               - 8592B a c e  + 34368A a c d e  - 85920B a c d e  + 57280A c d e
+--R             + 
+--R                          3 4
+--R               - 100240B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                         2   4              2   3              2 2 2
+--R               - 32979B a c e  + 131916A a c d e  - 329790B a c d e
+--R             + 
+--R                        3 3             3 4
+--R               219860A c d e - 384755B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                         2   4              2   3              2 2 2
+--R               - 69936B a c e  + 279744A a c d e  - 699360B a c d e
+--R             + 
+--R                        3 3             3 4
+--R               466240A c d e - 815920B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                         2   4              2   3              2 2 2
+--R               - 74628B a c e  + 298512A a c d e  - 746280B a c d e
+--R             + 
+--R                        3 3             3 4
+--R               497520A c d e - 870660B c d
+--R          *
+--R             m
+--R         + 
+--R                     2   4              2   3              2 2 2            3 3
+--R           - 30240B a c e  + 120960A a c d e  - 302400B a c d e  + 201600A c d e
+--R         + 
+--R                      3 4
+--R           - 352800B c d
+--R      *
+--R                  m + 4
+--R         (e x + d)
+--R     + 
+--R                     2   5       2     4          2 2 3          2 3 2
+--R               - 3A a c e  + 9B a c d e  - 18A a c d e  + 30B a c d e
+--R             + 
+--R                      3 4         3 5
+--R               - 15A c d e + 21B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                      2   5         2     4           2 2 3           2 3 2
+--R               - 99A a c e  + 297B a c d e  - 594A a c d e  + 990B a c d e
+--R             + 
+--R                       3 4          3 5
+--R               - 495A c d e + 693B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                        2   5          2     4            2 2 3
+--R               - 1341A a c e  + 4023B a c d e  - 8046A a c d e
+--R             + 
+--R                         2 3 2          3 4           3 5
+--R               13410B a c d e  - 6705A c d e + 9387B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                        2   5           2     4             2 2 3
+--R               - 9585A a c e  + 28755B a c d e  - 57510A a c d e
+--R             + 
+--R                         2 3 2           3 4            3 5
+--R               95850B a c d e  - 47925A c d e + 67095B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                         2   5            2     4              2 2 3
+--R               - 38592A a c e  + 115776B a c d e  - 231552A a c d e
+--R             + 
+--R                          2 3 2            3 4             3 5
+--R               385920B a c d e  - 192960A c d e + 270144B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                         2   5            2     4              2 2 3
+--R               - 86076A a c e  + 258228B a c d e  - 516456A a c d e
+--R             + 
+--R                          2 3 2            3 4             3 5
+--R               860760B a c d e  - 430380A c d e + 602532B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                         2   5            2     4              2 2 3
+--R               - 96144A a c e  + 288432B a c d e  - 576864A a c d e
+--R             + 
+--R                          2 3 2            3 4             3 5
+--R               961440B a c d e  - 480720A c d e + 673008B c d
+--R          *
+--R             m
+--R         + 
+--R                     2   5            2     4              2 2 3
+--R           - 40320A a c e  + 120960B a c d e  - 241920A a c d e
+--R         + 
+--R                      2 3 2            3 4             3 5
+--R           403200B a c d e  - 201600A c d e + 282240B c d
+--R      *
+--R                  m + 3
+--R         (e x + d)
+--R     + 
+--R                    3 6       2     5       2   2 4          2 3 3
+--R               - B a e  + 6A a c d e  - 9B a c d e  + 12A a c d e
+--R             + 
+--R                        2 4 2       3 5        3 6
+--R               - 15B a c d e  + 6A c d e - 7B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                      3 6         2     5         2   2 4           2 3 3
+--R               - 34B a e  + 204A a c d e  - 306B a c d e  + 408A a c d e
+--R             + 
+--R                         2 4 2         3 5          3 6
+--R               - 510B a c d e  + 204A c d e - 238B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                       3 6          2     5          2   2 4            2 3 3
+--R               - 478B a e  + 2868A a c d e  - 4302B a c d e  + 5736A a c d e
+--R             + 
+--R                          2 4 2          3 5           3 6
+--R               - 7170B a c d e  + 2868A c d e - 3346B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                        3 6           2     5           2   2 4
+--R               - 3580B a e  + 21480A a c d e  - 32220B a c d e
+--R             + 
+--R                         2 3 3             2 4 2           3 5            3 6
+--R               42960A a c d e  - 53700B a c d e  + 21480A c d e - 25060B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                         3 6           2     5            2   2 4
+--R               - 15289B a e  + 91734A a c d e  - 137601B a c d e
+--R             + 
+--R                        2 3 3              2 4 2           3 5             3 6
+--R             183468A a c d e  - 229335B a c d e  + 91734A c d e - 107023B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                         3 6            2     5            2   2 4
+--R               - 36706B a e  + 220236A a c d e  - 330354B a c d e
+--R             + 
+--R                        2 3 3              2 4 2            3 5             3 6
+--R             440472A a c d e  - 550590B a c d e  + 220236A c d e - 256942B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                         3 6            2     5            2   2 4
+--R               - 44712B a e  + 268272A a c d e  - 402408B a c d e
+--R             + 
+--R                        2 3 3              2 4 2            3 5             3 6
+--R             536544A a c d e  - 670680B a c d e  + 268272A c d e - 312984B c d
+--R          *
+--R             m
+--R         + 
+--R                     3 6            2     5            2   2 4
+--R           - 20160B a e  + 120960A a c d e  - 181440B a c d e
+--R         + 
+--R                      2 3 3              2 4 2            3 5             3 6
+--R           241920A a c d e  - 302400B a c d e  + 120960A c d e - 141120B c d
+--R      *
+--R                  m + 2
+--R         (e x + d)
+--R     + 
+--R                    3 7      3   6       2   2 5       2   3 4         2 4 3
+--R               - A a e  + B a d e  - 3A a c d e  + 3B a c d e  - 3A a c d e
+--R             + 
+--R                     2 5 2      3 6       3 7
+--R               3B a c d e  - A c d e + B c d
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                      3 7        3   6         2   2 5         2   3 4
+--R               - 35A a e  + 35B a d e  - 105A a c d e  + 105B a c d e
+--R             + 
+--R                         2 4 3           2 5 2        3 6         3 7
+--R               - 105A a c d e  + 105B a c d e  - 35A c d e + 35B c d
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                       3 7         3   6          2   2 5          2   3 4
+--R               - 511A a e  + 511B a d e  - 1533A a c d e  + 1533B a c d e
+--R             + 
+--R                          2 4 3            2 5 2         3 6          3 7
+--R               - 1533A a c d e  + 1533B a c d e  - 511A c d e + 511B c d
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                        3 7          3   6           2   2 5           2   3 4
+--R               - 4025A a e  + 4025B a d e  - 12075A a c d e  + 12075B a c d e
+--R             + 
+--R                           2 4 3             2 5 2          3 6           3 7
+--R               - 12075A a c d e  + 12075B a c d e  - 4025A c d e + 4025B c d
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                         3 7           3   6           2   2 5           2   3 4
+--R               - 18424A a e  + 18424B a d e  - 55272A a c d e  + 55272B a c d e
+--R             + 
+--R                           2 4 3             2 5 2           3 6            3 7
+--R               - 55272A a c d e  + 55272B a c d e  - 18424A c d e + 18424B c d
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                         3 7           3   6            2   2 5
+--R               - 48860A a e  + 48860B a d e  - 146580A a c d e
+--R             + 
+--R                        2   3 4              2 4 3              2 5 2
+--R               146580B a c d e  - 146580A a c d e  + 146580B a c d e
+--R             + 
+--R                         3 6            3 7
+--R               - 48860A c d e + 48860B c d
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                         3 7           3   6            2   2 5
+--R               - 69264A a e  + 69264B a d e  - 207792A a c d e
+--R             + 
+--R                        2   3 4              2 4 3              2 5 2
+--R               207792B a c d e  - 207792A a c d e  + 207792B a c d e
+--R             + 
+--R                         3 6            3 7
+--R               - 69264A c d e + 69264B c d
+--R          *
+--R             m
+--R         + 
+--R                     3 7           3   6            2   2 5            2   3 4
+--R           - 40320A a e  + 40320B a d e  - 120960A a c d e  + 120960B a c d e
+--R         + 
+--R                        2 4 3              2 5 2           3 6            3 7
+--R           - 120960A a c d e  + 120960B a c d e  - 40320A c d e + 40320B c d
+--R      *
+--R                  m + 1
+--R         (e x + d)
+--R  /
+--R        8 8      8 7       8 6        8 5         8 4         8 3          8 2
+--R       e m  + 36e m  + 546e m  + 4536e m  + 22449e m  + 67284e m  + 118124e m
+--R     + 
+--R              8          8
+--R       109584e m + 40320e
+--R                                                    Type: Expression(Integer)
+--E 1185
+
+--S 1186 of 1457
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1186
+
+)clear all
+
+--S 1187 of 1457
+t0:=(A+B*x)*(d+e*x)^5*(a+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3 5 12       3 5       3   4  11
+--R     B c e x   + (A c e  + 5B c d e )x
+--R   + 
+--R            2 5       3   4        3 2 3  10
+--R     (3B a c e  + 5A c d e  + 10B c d e )x
+--R   + 
+--R            2 5          2   4        3 2 3        3 3 2  9
+--R     (3A a c e  + 15B a c d e  + 10A c d e  + 10B c d e )x
+--R   + 
+--R          2   5          2   4          2 2 3        3 3 2       3 4   8
+--R     (3B a c e  + 15A a c d e  + 30B a c d e  + 10A c d e  + 5B c d e)x
+--R   + 
+--R             2   5        2     4          2 2 3          2 3 2       3 4
+--R         3A a c e  + 15B a c d e  + 30A a c d e  + 30B a c d e  + 5A c d e
+--R       + 
+--R            3 5
+--R         B c d
+--R    *
+--R        7
+--R       x
+--R   + 
+--R            3 5        2     4        2   2 3          2 3 2          2 4
+--R         B a e  + 15A a c d e  + 30B a c d e  + 30A a c d e  + 15B a c d e
+--R       + 
+--R            3 5
+--R         A c d
+--R    *
+--R        6
+--R       x
+--R   + 
+--R            3 5       3   4        2   2 3        2   3 2          2 4
+--R         A a e  + 5B a d e  + 30A a c d e  + 30B a c d e  + 15A a c d e
+--R       + 
+--R               2 5
+--R         3B a c d
+--R    *
+--R        5
+--R       x
+--R   + 
+--R          3   4        3 2 3        2   3 2        2   4          2 5  4
+--R     (5A a d e  + 10B a d e  + 30A a c d e  + 15B a c d e + 3A a c d )x
+--R   + 
+--R           3 2 3        3 3 2        2   4        2   5  3
+--R     (10A a d e  + 10B a d e  + 15A a c d e + 3B a c d )x
+--R   + 
+--R           3 3 2       3 4        2   5  2        3 4       3 5        3 5
+--R     (10A a d e  + 5B a d e + 3A a c d )x  + (5A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1187
+
+--S 1188 of 1457
+r0:=-1/6*(B*d-A*e)*(c*d^2+a*e^2)^3*(d+e*x)^6/e^8+1/7*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)*(d+e*x)^7/e^8-3/8*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^8/e^8-1/9*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*_
+     a^2*e^4))*(d+e*x)^9/e^8-1/10*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*_
+     B*d*e^2-3*a*A*e^3)*(d+e*x)^10/e^8+3/11*c^2*(7*B*c*d^2-2*A*c*d*e+_
+     a*B*e^2)*(d+e*x)^11/e^8-1/12*c^3*(7*B*d-A*e)*(d+e*x)^12/e^8+1/13*_
+     B*c^3*(d+e*x)^13/e^8
+--R 
+--R
+--R   (2)
+--R        1    3 13 13     1    3 13    5    3   12  12
+--R       -- B c e  x   + (-- A c e   + -- B c d e  )x
+--R       13               12           12
+--R     + 
+--R         3      2 13    5    3   12   10    3 2 11  11
+--R       (-- B a c e   + -- A c d e   + -- B c d e  )x
+--R        11             11             11
+--R     + 
+--R         3      2 13   3      2   12      3 2 11      3 3 10  10
+--R       (-- A a c e   + - B a c d e   + A c d e   + B c d e  )x
+--R        10             2
+--R     + 
+--R           1    2   13   5      2   12   10      2 2 11   10    3 3 10
+--R           - B a c e   + - A a c d e   + -- B a c d e   + -- A c d e
+--R           3             3                3                9
+--R         + 
+--R           5    3 4 9
+--R           - B c d e
+--R           9
+--R      *
+--R          9
+--R         x
+--R     + 
+--R           3    2   13   15    2     12   15      2 2 11   15      2 3 10
+--R           - A a c e   + -- B a c d e   + -- A a c d e   + -- B a c d e
+--R           8              8                4                4
+--R         + 
+--R           5    3 4 9   1    3 5 8
+--R           - A c d e  + - B c d e
+--R           8            8
+--R      *
+--R          8
+--R         x
+--R     + 
+--R           1    3 13   15    2     12   30    2   2 11   30      2 3 10
+--R           - B a e   + -- A a c d e   + -- B a c d e   + -- A a c d e
+--R           7            7                7                7
+--R         + 
+--R           15      2 4 9   1    3 5 8
+--R           -- B a c d e  + - A c d e
+--R            7              7
+--R      *
+--R          7
+--R         x
+--R     + 
+--R           1    3 13   5    3   12       2   2 11       2   3 10   5      2 4 9
+--R           - A a e   + - B a d e   + 5A a c d e   + 5B a c d e   + - A a c d e
+--R           6           6                                           2
+--R         + 
+--R           1      2 5 8
+--R           - B a c d e
+--R           2
+--R      *
+--R          6
+--R         x
+--R     + 
+--R           3   12       3 2 11       2   3 10       2   4 9   3      2 5 8  5
+--R       (A a d e   + 2B a d e   + 6A a c d e   + 3B a c d e  + - A a c d e )x
+--R                                                              5
+--R     + 
+--R        5    3 2 11   5    3 3 10   15    2   4 9   3    2   5 8  4
+--R       (- A a d e   + - B a d e   + -- A a c d e  + - B a c d e )x
+--R        2             2              4              4
+--R     + 
+--R        10    3 3 10   5    3 4 9      2   5 8  3    5    3 4 9   1    3 5 8  2
+--R       (-- A a d e   + - B a d e  + A a c d e )x  + (- A a d e  + - B a d e )x
+--R         3             3                             2            2
+--R     + 
+--R          3 5 8    1    3 6 7    1    3 7 6    1    2   8 5    1     2   9 4
+--R       A a d e x + - A a d e  - -- B a d e  + -- A a c d e  - --- B a c d e
+--R                   6            42            56              168
+--R     + 
+--R        1       2 10 3    1       2 11 2     1     3 12      1      3 13
+--R       --- A a c d  e  - --- B a c d  e  + ---- A c d  e - ----- B c d
+--R       420               924               5544            10296
+--R  /
+--R      8
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1188
+
+--S 1189 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    3 5 13     1    3 5    5    3   4  12
+--R     -- B c e x   + (-- A c e  + -- B c d e )x
+--R     13              12          12
+--R   + 
+--R       3      2 5    5    3   4   10    3 2 3  11
+--R     (-- B a c e  + -- A c d e  + -- B c d e )x
+--R      11            11            11
+--R   + 
+--R       3      2 5   3      2   4      3 2 3      3 3 2  10
+--R     (-- A a c e  + - B a c d e  + A c d e  + B c d e )x
+--R      10            2
+--R   + 
+--R      1    2   5   5      2   4   10      2 2 3   10    3 3 2   5    3 4   9
+--R     (- B a c e  + - A a c d e  + -- B a c d e  + -- A c d e  + - B c d e)x
+--R      3            3               3               9            9
+--R   + 
+--R         3    2   5   15    2     4   15      2 2 3   15      2 3 2   5    3 4
+--R         - A a c e  + -- B a c d e  + -- A a c d e  + -- B a c d e  + - A c d e
+--R         8             8               4               4              8
+--R       + 
+--R         1    3 5
+--R         - B c d
+--R         8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R         1    3 5   15    2     4   30    2   2 3   30      2 3 2   15      2 4
+--R         - B a e  + -- A a c d e  + -- B a c d e  + -- A a c d e  + -- B a c d e
+--R         7           7               7               7               7
+--R       + 
+--R         1    3 5
+--R         - A c d
+--R         7
+--R    *
+--R        7
+--R       x
+--R   + 
+--R         1    3 5   5    3   4       2   2 3       2   3 2   5      2 4
+--R         - A a e  + - B a d e  + 5A a c d e  + 5B a c d e  + - A a c d e
+--R         6          6                                        2
+--R       + 
+--R         1      2 5
+--R         - B a c d
+--R         2
+--R    *
+--R        6
+--R       x
+--R   + 
+--R         3   4       3 2 3       2   3 2       2   4    3      2 5  5
+--R     (A a d e  + 2B a d e  + 6A a c d e  + 3B a c d e + - A a c d )x
+--R                                                        5
+--R   + 
+--R      5    3 2 3   5    3 3 2   15    2   4    3    2   5  4
+--R     (- A a d e  + - B a d e  + -- A a c d e + - B a c d )x
+--R      2            2             4             4
+--R   + 
+--R    10    3 3 2   5    3 4       2   5  3    5    3 4    1    3 5  2      3 5
+--R   (-- A a d e  + - B a d e + A a c d )x  + (- A a d e + - B a d )x  + A a d x
+--R     3            3                          2           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1189
+
+--S 1190 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         1    3 6 7    1    3 7 6    1    2   8 5    1     2   9 4
+--R       - - A a d e  + -- B a d e  - -- A a c d e  + --- B a c d e
+--R         6            42            56              168
+--R     + 
+--R          1       2 10 3    1       2 11 2     1     3 12      1      3 13
+--R       - --- A a c d  e  + --- B a c d  e  - ---- A c d  e + ----- B c d
+--R         420               924               5544            10296
+--R  /
+--R      8
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1190
+
+--S 1191 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1191
+
+)clear all
+
+--S 1192 of 1457
+t0:=(A+B*x)*(d+e*x)^4*(a+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3 4 11       3 4       3   3  10          2 4       3   3       3 2 2  9
+--R     B c e x   + (A c e  + 4B c d e )x   + (3B a c e  + 4A c d e  + 6B c d e )x
+--R   + 
+--R            2 4          2   3       3 2 2       3 3   8
+--R     (3A a c e  + 12B a c d e  + 6A c d e  + 4B c d e)x
+--R   + 
+--R          2   4          2   3          2 2 2       3 3       3 4  7
+--R     (3B a c e  + 12A a c d e  + 18B a c d e  + 4A c d e + B c d )x
+--R   + 
+--R          2   4        2     3          2 2 2          2 3       3 4  6
+--R     (3A a c e  + 12B a c d e  + 18A a c d e  + 12B a c d e + A c d )x
+--R   + 
+--R         3 4        2     3        2   2 2          2 3          2 4  5
+--R     (B a e  + 12A a c d e  + 18B a c d e  + 12A a c d e + 3B a c d )x
+--R   + 
+--R         3 4       3   3        2   2 2        2   3          2 4  4
+--R     (A a e  + 4B a d e  + 18A a c d e  + 12B a c d e + 3A a c d )x
+--R   + 
+--R          3   3       3 2 2        2   3        2   4  3
+--R     (4A a d e  + 6B a d e  + 12A a c d e + 3B a c d )x
+--R   + 
+--R          3 2 2       3 3        2   4  2        3 3       3 4        3 4
+--R     (6A a d e  + 4B a d e + 3A a c d )x  + (4A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1192
+
+--S 1193 of 1457
+r0:=-1/5*(B*d-A*e)*(c*d^2+a*e^2)^3*(d+e*x)^5/e^8+1/6*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)*(d+e*x)^6/e^8-3/7*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^7/e^8-1/8*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*_
+     e^4))*(d+e*x)^8/e^8-1/9*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*d*e^2-_
+     3*a*A*e^3)*(d+e*x)^9/e^8+3/10*c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)*_
+     (d+e*x)^10/e^8-1/11*c^3*(7*B*d-A*e)*(d+e*x)^11/e^8+1/12*B*c^3*_
+     (d+e*x)^12/e^8
+--R 
+--R
+--R   (2)
+--R        1    3 12 12     1    3 12    4    3   11  11
+--R       -- B c e  x   + (-- A c e   + -- B c d e  )x
+--R       12               11           11
+--R     + 
+--R         3      2 12   2    3   11   3    3 2 10  10
+--R       (-- B a c e   + - A c d e   + - B c d e  )x
+--R        10             5             5
+--R     + 
+--R        1      2 12   4      2   11   2    3 2 10   4    3 3 9  9
+--R       (- A a c e   + - B a c d e   + - A c d e   + - B c d e )x
+--R        3             3               3             9
+--R     + 
+--R        3    2   12   3      2   11   9      2 2 10   1    3 3 9   1    3 4 8  8
+--R       (- B a c e   + - A a c d e   + - B a c d e   + - A c d e  + - B c d e )x
+--R        8             2               4               2            8
+--R     + 
+--R           3    2   12   12    2     11   18      2 2 10   12      2 3 9
+--R           - A a c e   + -- B a c d e   + -- A a c d e   + -- B a c d e
+--R           7              7                7                7
+--R         + 
+--R           1    3 4 8
+--R           - A c d e
+--R           7
+--R      *
+--R          7
+--R         x
+--R     + 
+--R        1    3 12       2     11       2   2 10         2 3 9   1      2 4 8  6
+--R       (- B a e   + 2A a c d e   + 3B a c d e   + 2A a c d e  + - B a c d e )x
+--R        6                                                       2
+--R     + 
+--R             1    3 12   4    3   11   18    2   2 10   12    2   3 9
+--R             - A a e   + - B a d e   + -- A a c d e   + -- B a c d e
+--R             5           5              5                5
+--R           + 
+--R             3      2 4 8
+--R             - A a c d e
+--R             5
+--R      *
+--R          5
+--R         x
+--R     + 
+--R           3   11   3    3 2 10       2   3 9   3    2   4 8  4
+--R       (A a d e   + - B a d e   + 3A a c d e  + - B a c d e )x
+--R                    2                           4
+--R     + 
+--R            3 2 10   4    3 3 9      2   4 8  3        3 3 9   1    3 4 8  2
+--R       (2A a d e   + - B a d e  + A a c d e )x  + (2A a d e  + - B a d e )x
+--R                     3                                         2
+--R     + 
+--R          3 4 8    1    3 5 7    1    3 6 6    1    2   7 5    3     2   8 4
+--R       A a d e x + - A a d e  - -- B a d e  + -- A a c d e  - --- B a c d e
+--R                   5            30            35              280
+--R     + 
+--R        1       2 9 3    1       2 10 2     1     3 11      1     3 12
+--R       --- A a c d e  - --- B a c d  e  + ---- A c d  e - ---- B c d
+--R       210              420               2310            3960
+--R  /
+--R      8
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1193
+
+--S 1194 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    3 4 12     1    3 4    4    3   3  11
+--R     -- B c e x   + (-- A c e  + -- B c d e )x
+--R     12              11          11
+--R   + 
+--R       3      2 4   2    3   3   3    3 2 2  10
+--R     (-- B a c e  + - A c d e  + - B c d e )x
+--R      10            5            5
+--R   + 
+--R      1      2 4   4      2   3   2    3 2 2   4    3 3   9
+--R     (- A a c e  + - B a c d e  + - A c d e  + - B c d e)x
+--R      3            3              3            9
+--R   + 
+--R      3    2   4   3      2   3   9      2 2 2   1    3 3    1    3 4  8
+--R     (- B a c e  + - A a c d e  + - B a c d e  + - A c d e + - B c d )x
+--R      8            2              4              2           8
+--R   + 
+--R      3    2   4   12    2     3   18      2 2 2   12      2 3    1    3 4  7
+--R     (- A a c e  + -- B a c d e  + -- A a c d e  + -- B a c d e + - A c d )x
+--R      7             7               7               7             7
+--R   + 
+--R      1    3 4       2     3       2   2 2         2 3    1      2 4  6
+--R     (- B a e  + 2A a c d e  + 3B a c d e  + 2A a c d e + - B a c d )x
+--R      6                                                   2
+--R   + 
+--R      1    3 4   4    3   3   18    2   2 2   12    2   3    3      2 4  5
+--R     (- A a e  + - B a d e  + -- A a c d e  + -- B a c d e + - A a c d )x
+--R      5          5             5               5             5
+--R   + 
+--R         3   3   3    3 2 2       2   3    3    2   4  4
+--R     (A a d e  + - B a d e  + 3A a c d e + - B a c d )x
+--R                 2                         4
+--R   + 
+--R          3 2 2   4    3 3       2   4  3        3 3    1    3 4  2      3 4
+--R     (2A a d e  + - B a d e + A a c d )x  + (2A a d e + - B a d )x  + A a d x
+--R                  3                                     2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1194
+
+--S 1195 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         1    3 5 7    1    3 6 6    1    2   7 5    3     2   8 4
+--R       - - A a d e  + -- B a d e  - -- A a c d e  + --- B a c d e
+--R         5            30            35              280
+--R     + 
+--R          1       2 9 3    1       2 10 2     1     3 11      1     3 12
+--R       - --- A a c d e  + --- B a c d  e  - ---- A c d  e + ---- B c d
+--R         210              420               2310            3960
+--R  /
+--R      8
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1195
+
+--S 1196 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1196
+
+)clear all
+
+--S 1197 of 1457
+t0:=(A+B*x)*(d+e*x)^3*(a+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3 3 10       3 3       3   2  9          2 3       3   2       3 2   8
+--R     B c e x   + (A c e  + 3B c d e )x  + (3B a c e  + 3A c d e  + 3B c d e)x
+--R   + 
+--R            2 3         2   2       3 2       3 3  7
+--R     (3A a c e  + 9B a c d e  + 3A c d e + B c d )x
+--R   + 
+--R          2   3         2   2         2 2       3 3  6
+--R     (3B a c e  + 9A a c d e  + 9B a c d e + A c d )x
+--R   + 
+--R          2   3       2     2         2 2          2 3  5
+--R     (3A a c e  + 9B a c d e  + 9A a c d e + 3B a c d )x
+--R   + 
+--R         3 3       2     2       2   2          2 3  4
+--R     (B a e  + 9A a c d e  + 9B a c d e + 3A a c d )x
+--R   + 
+--R         3 3       3   2       2   2        2   3  3
+--R     (A a e  + 3B a d e  + 9A a c d e + 3B a c d )x
+--R   + 
+--R          3   2       3 2        2   3  2        3 2       3 3        3 3
+--R     (3A a d e  + 3B a d e + 3A a c d )x  + (3A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1197
+
+--S 1198 of 1457
+r0:=a^3*A*d^3*x+1/2*a^3*d^2*(B*d+3*A*e)*x^2+a^2*d*(A*c*d^2+a*B*d*e+_
+     a*A*e^2)*x^3+1/4*a^2*(3*B*c*d^3+9*A*c*d^2*e+3*a*B*d*e^2+a*A*e^3)*_
+     x^4+1/5*a*(a*B*e*(9*c*d^2+a*e^2)+3*A*c*d*(c*d^2+3*a*e^2))*x^5+_
+     1/2*a*c*(B*c*d^3+3*A*c*d^2*e+3*a*B*d*e^2+a*A*e^3)*x^6+1/7*c*(3*a*_
+     B*e*(3*c*d^2+a*e^2)+A*c*d*(c*d^2+9*a*e^2))*x^7+1/8*c^2*(B*c*d^3+3*_
+     A*c*d^2*e+9*a*B*d*e^2+3*a*A*e^3)*x^8+1/3*c^2*e*(B*c*d^2+A*c*d*e+_
+     a*B*e^2)*x^9+1/10*c^3*e^2*(3*B*d+A*e)*x^10+1/11*B*c^3*e^3*x^11
+--R 
+--R
+--R   (2)
+--R      1    3 3 11     1    3 3    3    3   2  10
+--R     -- B c e x   + (-- A c e  + -- B c d e )x
+--R     11              10          10
+--R   + 
+--R      1      2 3   1    3   2   1    3 2   9
+--R     (- B a c e  + - A c d e  + - B c d e)x
+--R      3            3            3
+--R   + 
+--R      3      2 3   9      2   2   3    3 2    1    3 3  8
+--R     (- A a c e  + - B a c d e  + - A c d e + - B c d )x
+--R      8            8              8           8
+--R   + 
+--R      3    2   3   9      2   2   9      2 2    1    3 3  7
+--R     (- B a c e  + - A a c d e  + - B a c d e + - A c d )x
+--R      7            7              7             7
+--R   + 
+--R      1    2   3   3    2     2   3      2 2    1      2 3  6
+--R     (- A a c e  + - B a c d e  + - A a c d e + - B a c d )x
+--R      2            2              2             2
+--R   + 
+--R      1    3 3   9    2     2   9    2   2    3      2 3  5
+--R     (- B a e  + - A a c d e  + - B a c d e + - A a c d )x
+--R      5          5              5             5
+--R   + 
+--R      1    3 3   3    3   2   9    2   2    3    2   3  4
+--R     (- A a e  + - B a d e  + - A a c d e + - B a c d )x
+--R      4          4            4             4
+--R   + 
+--R         3   2      3 2       2   3  3    3    3 2    1    3 3  2      3 3
+--R     (A a d e  + B a d e + A a c d )x  + (- A a d e + - B a d )x  + A a d x
+--R                                          2           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1198
+
+--S 1199 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    3 3 11     1    3 3    3    3   2  10
+--R     -- B c e x   + (-- A c e  + -- B c d e )x
+--R     11              10          10
+--R   + 
+--R      1      2 3   1    3   2   1    3 2   9
+--R     (- B a c e  + - A c d e  + - B c d e)x
+--R      3            3            3
+--R   + 
+--R      3      2 3   9      2   2   3    3 2    1    3 3  8
+--R     (- A a c e  + - B a c d e  + - A c d e + - B c d )x
+--R      8            8              8           8
+--R   + 
+--R      3    2   3   9      2   2   9      2 2    1    3 3  7
+--R     (- B a c e  + - A a c d e  + - B a c d e + - A c d )x
+--R      7            7              7             7
+--R   + 
+--R      1    2   3   3    2     2   3      2 2    1      2 3  6
+--R     (- A a c e  + - B a c d e  + - A a c d e + - B a c d )x
+--R      2            2              2             2
+--R   + 
+--R      1    3 3   9    2     2   9    2   2    3      2 3  5
+--R     (- B a e  + - A a c d e  + - B a c d e + - A a c d )x
+--R      5          5              5             5
+--R   + 
+--R      1    3 3   3    3   2   9    2   2    3    2   3  4
+--R     (- A a e  + - B a d e  + - A a c d e + - B a c d )x
+--R      4          4            4             4
+--R   + 
+--R         3   2      3 2       2   3  3    3    3 2    1    3 3  2      3 3
+--R     (A a d e  + B a d e + A a c d )x  + (- A a d e + - B a d )x  + A a d x
+--R                                          2           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1199
+
+--S 1200 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1200
+
+--S 1201 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1201
+
+)clear all
+
+--S 1202 of 1457
+t0:=(A+B*x)*(d+e*x)^2*(a+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3 2 9       3 2       3     8          2 2       3         3 2  7
+--R     B c e x  + (A c e  + 2B c d e)x  + (3B a c e  + 2A c d e + B c d )x
+--R   + 
+--R            2 2         2         3 2  6
+--R     (3A a c e  + 6B a c d e + A c d )x
+--R   + 
+--R          2   2         2            2 2  5
+--R     (3B a c e  + 6A a c d e + 3B a c d )x
+--R   + 
+--R          2   2       2              2 2  4
+--R     (3A a c e  + 6B a c d e + 3A a c d )x
+--R   + 
+--R         3 2       2            2   2  3       3 2       3          2   2  2
+--R     (B a e  + 6A a c d e + 3B a c d )x  + (A a e  + 2B a d e + 3A a c d )x
+--R   + 
+--R          3         3 2        3 2
+--R     (2A a d e + B a d )x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1202
+
+--S 1203 of 1457
+r0:=a^3*A*d^2*x+1/2*a^3*d*(B*d+2*A*e)*x^2+1/3*a^2*(3*A*c*d^2+2*a*B*d*e+_
+     a*A*e^2)*x^3+1/4*a^2*(3*B*c*d^2+6*A*c*d*e+a*B*e^2)*x^4+3/5*a*c*_
+     (A*c*d^2+2*a*B*d*e+a*A*e^2)*x^5+1/2*a*c*(B*c*d^2+2*A*c*d*e+a*B*_
+     e^2)*x^6+1/7*c^2*(A*c*d^2+6*a*B*d*e+3*a*A*e^2)*x^7+1/8*c^2*(B*c*d^2+_
+     2*A*c*d*e+3*a*B*e^2)*x^8+1/9*c^3*e*(2*B*d+A*e)*x^9+1/10*B*c^3*e^2*x^10
+--R 
+--R
+--R   (2)
+--R      1    3 2 10    1    3 2   2    3     9
+--R     -- B c e x   + (- A c e  + - B c d e)x
+--R     10              9          9
+--R   + 
+--R      3      2 2   1    3      1    3 2  8
+--R     (- B a c e  + - A c d e + - B c d )x
+--R      8            4           8
+--R   + 
+--R      3      2 2   6      2      1    3 2  7
+--R     (- A a c e  + - B a c d e + - A c d )x
+--R      7            7             7
+--R   + 
+--R      1    2   2        2      1      2 2  6
+--R     (- B a c e  + A a c d e + - B a c d )x
+--R      2                        2
+--R   + 
+--R      3    2   2   6    2        3      2 2  5
+--R     (- A a c e  + - B a c d e + - A a c d )x
+--R      5            5             5
+--R   + 
+--R      1    3 2   3    2        3    2   2  4
+--R     (- B a e  + - A a c d e + - B a c d )x
+--R      4          2             4
+--R   + 
+--R      1    3 2   2    3         2   2  3       3      1    3 2  2      3 2
+--R     (- A a e  + - B a d e + A a c d )x  + (A a d e + - B a d )x  + A a d x
+--R      3          3                                    2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1203
+
+--S 1204 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    3 2 10    1    3 2   2    3     9
+--R     -- B c e x   + (- A c e  + - B c d e)x
+--R     10              9          9
+--R   + 
+--R      3      2 2   1    3      1    3 2  8
+--R     (- B a c e  + - A c d e + - B c d )x
+--R      8            4           8
+--R   + 
+--R      3      2 2   6      2      1    3 2  7
+--R     (- A a c e  + - B a c d e + - A c d )x
+--R      7            7             7
+--R   + 
+--R      1    2   2        2      1      2 2  6
+--R     (- B a c e  + A a c d e + - B a c d )x
+--R      2                        2
+--R   + 
+--R      3    2   2   6    2        3      2 2  5
+--R     (- A a c e  + - B a c d e + - A a c d )x
+--R      5            5             5
+--R   + 
+--R      1    3 2   3    2        3    2   2  4
+--R     (- B a e  + - A a c d e + - B a c d )x
+--R      4          2             4
+--R   + 
+--R      1    3 2   2    3         2   2  3       3      1    3 2  2      3 2
+--R     (- A a e  + - B a d e + A a c d )x  + (A a d e + - B a d )x  + A a d x
+--R      3          3                                    2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1204
+
+--S 1205 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1205
+
+--S 1206 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1206
+
+)clear all
+
+--S 1207 of 1457
+t0:=(A+B*x)*(d+e*x)*(a+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3   8       3       3   7          2       3   6
+--R     B c e x  + (A c e + B c d)x  + (3B a c e + A c d)x
+--R   + 
+--R            2          2   5        2            2   4        2          2     3
+--R     (3A a c e + 3B a c d)x  + (3B a c e + 3A a c d)x  + (3A a c e + 3B a c d)x
+--R   + 
+--R         3        2     2       3       3         3
+--R     (B a e + 3A a c d)x  + (A a e + B a d)x + A a d
+--R                                                    Type: Polynomial(Integer)
+--E 1207
+
+--S 1208 of 1457
+r0:=a^3*A*d*x+1/2*a^3*(B*d+A*e)*x^2+1/3*a^2*(3*A*c*d+a*B*e)*x^3+3/4*_
+     a^2*c*(B*d+A*e)*x^4+3/5*a*c*(A*c*d+a*B*e)*x^5+1/2*a*c^2*(B*d+A*e)*_
+     x^6+1/7*c^2*(A*c*d+3*a*B*e)*x^7+1/8*c^3*(B*d+A*e)*x^8+1/9*B*c^3*e*x^9
+--R 
+--R
+--R   (2)
+--R     1    3   9    1    3    1    3   8    3      2    1    3   7
+--R     - B c e x  + (- A c e + - B c d)x  + (- B a c e + - A c d)x
+--R     9             8         8             7           7
+--R   + 
+--R      1      2    1      2   6    3    2      3      2   5
+--R     (- A a c e + - B a c d)x  + (- B a c e + - A a c d)x
+--R      2           2               5           5
+--R   + 
+--R      3    2      3    2     4    1    3       2     3    1    3    1    3   2
+--R     (- A a c e + - B a c d)x  + (- B a e + A a c d)x  + (- A a e + - B a d)x
+--R      4           4               3                       2         2
+--R   + 
+--R        3
+--R     A a d x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1208
+
+--S 1209 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    3   9    1    3    1    3   8    3      2    1    3   7
+--R     - B c e x  + (- A c e + - B c d)x  + (- B a c e + - A c d)x
+--R     9             8         8             7           7
+--R   + 
+--R      1      2    1      2   6    3    2      3      2   5
+--R     (- A a c e + - B a c d)x  + (- B a c e + - A a c d)x
+--R      2           2               5           5
+--R   + 
+--R      3    2      3    2     4    1    3       2     3    1    3    1    3   2
+--R     (- A a c e + - B a c d)x  + (- B a e + A a c d)x  + (- A a e + - B a d)x
+--R      4           4               3                       2         2
+--R   + 
+--R        3
+--R     A a d x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1209
+
+--S 1210 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1210
+
+--S 1211 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1211
+
+)clear all
+
+--S 1212 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        3 7      3 6         2 5         2 4       2   3       2   2      3
+--R     B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R   + 
+--R        3
+--R     A a
+--R                                                    Type: Polynomial(Integer)
+--E 1212
+
+--S 1213 of 1457
+r0:=a^3*A*x+a^2*A*c*x^3+3/5*a*A*c^2*x^5+1/7*A*c^3*x^7+1/8*B*(a+c*x^2)^4/c
+--R 
+--R
+--R   (2)
+--R       1    4 8   1    4 7   1      3 6   3      3 5   3    2 2 4      2 2 3
+--R       - B c x  + - A c x  + - B a c x  + - A a c x  + - B a c x  + A a c x
+--R       8          7          2            5            4
+--R     + 
+--R       1    3   2      3      1    4
+--R       - B a c x  + A a c x + - B a
+--R       2                      8
+--R  /
+--R     c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1213
+
+--S 1214 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1    3 8   1    3 7   1      2 6   3      2 5   3    2   4      2   3
+--R     - B c x  + - A c x  + - B a c x  + - A a c x  + - B a c x  + A a c x
+--R     8          7          2            5            4
+--R   + 
+--R     1    3 2      3
+--R     - B a x  + A a x
+--R     2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1214
+
+--S 1215 of 1457
+m0:=a0-r0
+--R 
+--R
+--R          1    4
+--R          - B a
+--R          8
+--R   (4)  - ------
+--R             c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1215
+
+--S 1216 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1216
+
+)clear all
+
+--S 1217 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R     e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1217
+
+--S 1218 of 1457
+r0:=(B*(c*d^2+a*e^2)^3-A*c*d*e*(c^2*d^4+3*a*c*d^2*e^2+3*a^2*e^4))*x/e^7-_
+     1/2*c*(B*d-A*e)*(c^2*d^4+3*a*c*d^2*e^2+3*a^2*e^4)*x^2/e^6-1/3*c*_
+     (A*c*d*e*(c*d^2+3*a*e^2)-B*(c^2*d^4+3*a*c*d^2*e^2+3*a^2*e^4))*_
+     x^3/e^5-1/4*c^2*(B*d-A*e)*(c*d^2+3*a*e^2)*x^4/e^4+1/5*c^2*(B*c*_
+     d^2-A*c*d*e+3*a*B*e^2)*x^5/e^3-1/6*c^3*(B*d-A*e)*x^6/e^2+1/7*B*_
+     c^3*x^7/e-(B*d-A*e)*(c*d^2+a*e^2)^3*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                 3 7         3   6          2   2 5          2   3 4
+--R           420A a e  - 420B a d e  + 1260A a c d e  - 1260B a c d e
+--R         + 
+--R                    2 4 3            2 5 2         3 6          3 7
+--R           1260A a c d e  - 1260B a c d e  + 420A c d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7         3 7        3   6  6
+--R       60B c e x  + (70A c e  - 70B c d e )x
+--R     + 
+--R                2 7        3   6        3 2 5  5
+--R       (252B a c e  - 84A c d e  + 84B c d e )x
+--R     + 
+--R                2 7           2   6         3 2 5         3 3 4  4
+--R       (315A a c e  - 315B a c d e  + 105A c d e  - 105B c d e )x
+--R     + 
+--R                   2   7           2   6           2 2 5         3 3 4
+--R             420B a c e  - 420A a c d e  + 420B a c d e  - 140A c d e
+--R           + 
+--R                   3 4 3
+--R             140B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                 2   7         2     6           2 2 5           2 3 4
+--R           630A a c e  - 630B a c d e  + 630A a c d e  - 630B a c d e
+--R         + 
+--R                 3 4 3         3 5 2
+--R           210A c d e  - 210B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 7          2     6          2   2 5            2 3 4
+--R           420B a e  - 1260A a c d e  + 1260B a c d e  - 1260A a c d e
+--R         + 
+--R                    2 4 3         3 5 2         3 6
+--R           1260B a c d e  - 420A c d e  + 420B c d e
+--R      *
+--R         x
+--R  /
+--R         8
+--R     420e
+--R                                                    Type: Expression(Integer)
+--E 1218
+
+--S 1219 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3 7         3   6          2   2 5          2   3 4
+--R           420A a e  - 420B a d e  + 1260A a c d e  - 1260B a c d e
+--R         + 
+--R                    2 4 3            2 5 2         3 6          3 7
+--R           1260A a c d e  - 1260B a c d e  + 420A c d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7         3 7        3   6  6
+--R       60B c e x  + (70A c e  - 70B c d e )x
+--R     + 
+--R                2 7        3   6        3 2 5  5
+--R       (252B a c e  - 84A c d e  + 84B c d e )x
+--R     + 
+--R                2 7           2   6         3 2 5         3 3 4  4
+--R       (315A a c e  - 315B a c d e  + 105A c d e  - 105B c d e )x
+--R     + 
+--R                   2   7           2   6           2 2 5         3 3 4
+--R             420B a c e  - 420A a c d e  + 420B a c d e  - 140A c d e
+--R           + 
+--R                   3 4 3
+--R             140B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                 2   7         2     6           2 2 5           2 3 4
+--R           630A a c e  - 630B a c d e  + 630A a c d e  - 630B a c d e
+--R         + 
+--R                 3 4 3         3 5 2
+--R           210A c d e  - 210B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 7          2     6          2   2 5            2 3 4
+--R           420B a e  - 1260A a c d e  + 1260B a c d e  - 1260A a c d e
+--R         + 
+--R                    2 4 3         3 5 2         3 6
+--R           1260B a c d e  - 420A c d e  + 420B c d e
+--R      *
+--R         x
+--R  /
+--R         8
+--R     420e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1219
+
+--S 1220 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1220
+
+--S 1221 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1221
+
+)clear all
+
+--S 1222 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^2
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R      2 2             2
+--R     e x  + 2d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1222
+
+--S 1223 of 1457
+r0:=-c*(6*B*d*(c*d^2+a*e^2)^2-A*e*(5*c^2*d^4+9*a*c*d^2*e^2+3*a^2*e^4))*_
+     x/e^7-1/2*c*(2*A*c*d*e*(2*c*d^2+3*a*e^2)-B*(5*c^2*d^4+9*a*c*d^2*e^2+_
+     3*a^2*e^4))*x^2/e^6+1/3*c^2*(3*A*e*(c*d^2+a*e^2)-B*(4*c*d^3+_
+     6*a*d*e^2))*x^3/e^5-1/4*c^2*(2*A*c*d*e-3*B*(c*d^2+a*e^2))*x^4/e^4-_
+     1/5*c^3*(2*B*d-A*e)*x^5/e^3+1/6*B*c^3*x^6/e^2+(B*d-A*e)*(c*d^2+_
+     a*e^2)^3/(e^8*(d+e*x))+(c*d^2+a*e^2)^2*(7*B*c*d^2-6*A*c*d*e+_
+     a*B*e^2)*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                    3 7         2     6         2   2 5           2 3 4
+--R               60B a e  - 360A a c d e  + 540B a c d e  - 720A a c d e
+--R             + 
+--R                       2 4 3         3 5 2         3 6
+--R               900B a c d e  - 360A c d e  + 420B c d e
+--R          *
+--R             x
+--R         + 
+--R                3   6         2   2 5         2   3 4           2 4 3
+--R           60B a d e  - 360A a c d e  + 540B a c d e  - 720A a c d e
+--R         + 
+--R                   2 5 2         3 6          3 7
+--R           900B a c d e  - 360A c d e + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7         3 7        3   6  6
+--R       10B c e x  + (12A c e  - 14B c d e )x
+--R     + 
+--R               2 7        3   6        3 2 5  5
+--R       (45B a c e  - 18A c d e  + 21B c d e )x
+--R     + 
+--R               2 7          2   6        3 2 5        3 3 4  4
+--R       (60A a c e  - 75B a c d e  + 30A c d e  - 35B c d e )x
+--R     + 
+--R             2   7           2   6           2 2 5        3 3 4        3 4 3  3
+--R       (90B a c e  - 120A a c d e  + 150B a c d e  - 60A c d e  + 70B c d e )x
+--R     + 
+--R                 2   7         2     6           2 2 5           2 3 4
+--R           180A a c e  - 270B a c d e  + 360A a c d e  - 450B a c d e
+--R         + 
+--R                 3 4 3         3 5 2
+--R           180A c d e  - 210B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 2     6         2   2 5           2 3 4           2 4 3
+--R           180A a c d e  - 360B a c d e  + 540A a c d e  - 720B a c d e
+--R         + 
+--R                 3 5 2         3 6
+--R           300A c d e  - 360B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 7        3   6         2   2 5         2   3 4           2 4 3
+--R       - 60A a e  + 60B a d e  - 180A a c d e  + 180B a c d e  - 180A a c d e
+--R     + 
+--R               2 5 2        3 6         3 7
+--R       180B a c d e  - 60A c d e + 60B c d
+--R  /
+--R        9         8
+--R     60e x + 60d e
+--R                                                    Type: Expression(Integer)
+--E 1223
+
+--S 1224 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    3 7         2     6         2   2 5           2 3 4
+--R               60B a e  - 360A a c d e  + 540B a c d e  - 720A a c d e
+--R             + 
+--R                       2 4 3         3 5 2         3 6
+--R               900B a c d e  - 360A c d e  + 420B c d e
+--R          *
+--R             x
+--R         + 
+--R                3   6         2   2 5         2   3 4           2 4 3
+--R           60B a d e  - 360A a c d e  + 540B a c d e  - 720A a c d e
+--R         + 
+--R                   2 5 2         3 6          3 7
+--R           900B a c d e  - 360A c d e + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7         3 7        3   6  6
+--R       10B c e x  + (12A c e  - 14B c d e )x
+--R     + 
+--R               2 7        3   6        3 2 5  5
+--R       (45B a c e  - 18A c d e  + 21B c d e )x
+--R     + 
+--R               2 7          2   6        3 2 5        3 3 4  4
+--R       (60A a c e  - 75B a c d e  + 30A c d e  - 35B c d e )x
+--R     + 
+--R             2   7           2   6           2 2 5        3 3 4        3 4 3  3
+--R       (90B a c e  - 120A a c d e  + 150B a c d e  - 60A c d e  + 70B c d e )x
+--R     + 
+--R                 2   7         2     6           2 2 5           2 3 4
+--R           180A a c e  - 270B a c d e  + 360A a c d e  - 450B a c d e
+--R         + 
+--R                 3 4 3         3 5 2
+--R           180A c d e  - 210B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 2     6         2   2 5           2 3 4           2 4 3
+--R           180A a c d e  - 360B a c d e  + 540A a c d e  - 720B a c d e
+--R         + 
+--R                 3 5 2         3 6
+--R           300A c d e  - 360B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 7        3   6         2   2 5         2   3 4           2 4 3
+--R       - 60A a e  + 60B a d e  - 180A a c d e  + 180B a c d e  - 180A a c d e
+--R     + 
+--R               2 5 2        3 6         3 7
+--R       180B a c d e  - 60A c d e + 60B c d
+--R  /
+--R        9         8
+--R     60e x + 60d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1224
+
+--S 1225 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1225
+
+--S 1226 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1226
+
+)clear all
+
+--S 1227 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^3
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R      3 3       2 2     2       3
+--R     e x  + 3d e x  + 3d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1227
+
+--S 1228 of 1457
+r0:=-c*(A*c*d*e*(10*c*d^2+9*a*e^2)-3*B*(5*c^2*d^4+6*a*c*d^2*e^2+_
+     a^2*e^4))*x/e^7-1/2*c^2*(10*B*c*d^3-6*A*c*d^2*e+9*a*B*d*e^2-_
+     3*a*A*e^3)*x^2/e^6+c^2*(2*B*c*d^2-A*c*d*e+a*B*e^2)*x^3/e^5-_
+     1/4*c^3*(3*B*d-A*e)*x^4/e^4+1/5*B*c^3*x^5/e^3+1/2*(B*d-A*e)*_
+     (c*d^2+a*e^2)^3/(e^8*(d+e*x)^2)-(c*d^2+a*e^2)^2*(7*B*c*d^2-_
+     6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x))-3*c*(c*d^2+a*e^2)*(7*B*c*d^3-_
+     5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                    2   7         2     6           2 2 5           2 3 4
+--R               60A a c e  - 180B a c d e  + 360A a c d e  - 600B a c d e
+--R             + 
+--R                     3 4 3         3 5 2
+--R               300A c d e  - 420B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     2     6         2   2 5           2 3 4            2 4 3
+--R               120A a c d e  - 360B a c d e  + 720A a c d e  - 1200B a c d e
+--R             + 
+--R                     3 5 2         3 6
+--R               600A c d e  - 840B c d e
+--R          *
+--R             x
+--R         + 
+--R                2   2 5         2   3 4           2 4 3           2 5 2
+--R           60A a c d e  - 180B a c d e  + 360A a c d e  - 600B a c d e
+--R         + 
+--R                 3 6          3 7
+--R           300A c d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 7 7        3 7       3   6  6
+--R       4B c e x  + (5A c e  - 7B c d e )x
+--R     + 
+--R               2 7        3   6        3 2 5  5
+--R       (20B a c e  - 10A c d e  + 14B c d e )x
+--R     + 
+--R               2 7          2   6        3 2 5        3 3 4  4
+--R       (30A a c e  - 50B a c d e  + 25A c d e  - 35B c d e )x
+--R     + 
+--R                  2   7           2   6           2 2 5         3 3 4
+--R             60B a c e  - 120A a c d e  + 200B a c d e  - 100A c d e
+--R           + 
+--R                   3 4 3
+--R             140B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                 2     6           2 2 5           2 3 4         3 4 3
+--R           120B a c d e  - 330A a c d e  + 630B a c d e  - 340A c d e
+--R         + 
+--R                 3 5 2
+--R           500B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 7         2     6         2   2 5          2 3 4
+--R           - 20B a e  + 120A a c d e  - 120B a c d e  + 60A a c d e
+--R         + 
+--R                  2 4 3        3 5 2         3 6
+--R           60B a c d e  - 80A c d e  + 160B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 7        3   6        2   2 5         2   3 4           2 4 3
+--R       - 10A a e  - 10B a d e  + 90A a c d e  - 150B a c d e  + 210A a c d e
+--R     + 
+--R                 2 5 2         3 6          3 7
+--R       - 270B a c d e  + 110A c d e - 130B c d
+--R  /
+--R        10 2        9       2 8
+--R     20e  x  + 40d e x + 20d e
+--R                                                    Type: Expression(Integer)
+--E 1228
+
+--S 1229 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    2   7         2     6           2 2 5           2 3 4
+--R               60A a c e  - 180B a c d e  + 360A a c d e  - 600B a c d e
+--R             + 
+--R                     3 4 3         3 5 2
+--R               300A c d e  - 420B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     2     6         2   2 5           2 3 4            2 4 3
+--R               120A a c d e  - 360B a c d e  + 720A a c d e  - 1200B a c d e
+--R             + 
+--R                     3 5 2         3 6
+--R               600A c d e  - 840B c d e
+--R          *
+--R             x
+--R         + 
+--R                2   2 5         2   3 4           2 4 3           2 5 2
+--R           60A a c d e  - 180B a c d e  + 360A a c d e  - 600B a c d e
+--R         + 
+--R                 3 6          3 7
+--R           300A c d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 7 7        3 7       3   6  6
+--R       4B c e x  + (5A c e  - 7B c d e )x
+--R     + 
+--R               2 7        3   6        3 2 5  5
+--R       (20B a c e  - 10A c d e  + 14B c d e )x
+--R     + 
+--R               2 7          2   6        3 2 5        3 3 4  4
+--R       (30A a c e  - 50B a c d e  + 25A c d e  - 35B c d e )x
+--R     + 
+--R                  2   7           2   6           2 2 5         3 3 4
+--R             60B a c e  - 120A a c d e  + 200B a c d e  - 100A c d e
+--R           + 
+--R                   3 4 3
+--R             140B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                 2     6           2 2 5           2 3 4         3 4 3
+--R           120B a c d e  - 330A a c d e  + 630B a c d e  - 340A c d e
+--R         + 
+--R                 3 5 2
+--R           500B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 7         2     6         2   2 5          2 3 4
+--R           - 20B a e  + 120A a c d e  - 120B a c d e  + 60A a c d e
+--R         + 
+--R                  2 4 3        3 5 2         3 6
+--R           60B a c d e  - 80A c d e  + 160B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 7        3   6        2   2 5         2   3 4           2 4 3
+--R       - 10A a e  - 10B a d e  + 90A a c d e  - 150B a c d e  + 210A a c d e
+--R     + 
+--R                 2 5 2         3 6          3 7
+--R       - 270B a c d e  + 110A c d e - 130B c d
+--R  /
+--R        10 2        9       2 8
+--R     20e  x  + 40d e x + 20d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1229
+
+--S 1230 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1230
+
+--S 1231 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1231
+
+)clear all
+
+--S 1232 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^4
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R      4 4       3 3     2 2 2     3       4
+--R     e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1232
+
+--S 1233 of 1457
+r0:=-c^2*(20*B*c*d^3-10*A*c*d^2*e+12*a*B*d*e^2-3*a*A*e^3)*x/e^7+1/2*_
+     c^2*(10*B*c*d^2-4*A*c*d*e+3*a*B*e^2)*x^2/e^6-1/3*c^3*(4*B*d-A*e)*_
+     x^3/e^5+1/4*B*c^3*x^4/e^4+1/3*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+_
+     e*x)^3)-1/2*(c*d^2+a*e^2)^2*(7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*_
+     (d+e*x)^2)+3*c*(c*d^2+a*e^2)*(7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-_
+     a*A*e^3)/(e^8*(d+e*x))-c*(4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*_
+     d^4+30*a*c*d^2*e^2+3*a^2*e^4))*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                    2   7           2   6           2 2 5         3 3 4
+--R               36B a c e  - 144A a c d e  + 360B a c d e  - 240A c d e
+--R             + 
+--R                     3 4 3
+--R               420B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     2     6           2 2 5            2 3 4         3 4 3
+--R               108B a c d e  - 432A a c d e  + 1080B a c d e  - 720A c d e
+--R             + 
+--R                      3 5 2
+--R               1260B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     2   2 5           2 3 4            2 4 3         3 5 2
+--R               108B a c d e  - 432A a c d e  + 1080B a c d e  - 720A c d e
+--R             + 
+--R                      3 6
+--R               1260B c d e
+--R          *
+--R             x
+--R         + 
+--R              2   3 4           2 4 3           2 5 2         3 6          3 7
+--R         36B a c d e  - 144A a c d e  + 360B a c d e  - 240A c d e + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 7 7        3 7       3   6  6
+--R       3B c e x  + (4A c e  - 7B c d e )x
+--R     + 
+--R               2 7        3   6        3 2 5  5
+--R       (18B a c e  - 12A c d e  + 21B c d e )x
+--R     + 
+--R               2 7          2   6        3 2 5         3 3 4  4
+--R       (36A a c e  - 90B a c d e  + 60A c d e  - 105B c d e )x
+--R     + 
+--R                2   6           2 2 5         3 3 4         3 4 3  3
+--R       (108A a c d e  - 378B a c d e  + 292A c d e  - 556B c d e )x
+--R     + 
+--R                  2   7         2     6           2 2 5          2 3 4
+--R           - 36A a c e  + 108B a c d e  - 108A a c d e  - 54B a c d e
+--R         + 
+--R                 3 4 3         3 5 2
+--R           156A c d e  - 408B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 7        2     6         2   2 5           2 3 4
+--R           - 6B a e  - 36A a c d e  + 162B a c d e  - 324A a c d e
+--R         + 
+--R                   2 4 3         3 5 2         3 6
+--R           486B a c d e  - 204A c d e  + 222B c d e
+--R      *
+--R         x
+--R     + 
+--R             3 7       3   6        2   2 5        2   3 4           2 4 3
+--R       - 4A a e  - 2B a d e  - 12A a c d e  + 66B a c d e  - 156A a c d e
+--R     + 
+--R               2 5 2         3 6          3 7
+--R       282B a c d e  - 148A c d e + 214B c d
+--R  /
+--R        11 3        10 2      2 9       3 8
+--R     12e  x  + 36d e  x  + 36d e x + 12d e
+--R                                                    Type: Expression(Integer)
+--E 1233
+
+--S 1234 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    2   7           2   6           2 2 5         3 3 4
+--R               36B a c e  - 144A a c d e  + 360B a c d e  - 240A c d e
+--R             + 
+--R                     3 4 3
+--R               420B c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     2     6           2 2 5            2 3 4         3 4 3
+--R               108B a c d e  - 432A a c d e  + 1080B a c d e  - 720A c d e
+--R             + 
+--R                      3 5 2
+--R               1260B c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     2   2 5           2 3 4            2 4 3         3 5 2
+--R               108B a c d e  - 432A a c d e  + 1080B a c d e  - 720A c d e
+--R             + 
+--R                      3 6
+--R               1260B c d e
+--R          *
+--R             x
+--R         + 
+--R              2   3 4           2 4 3           2 5 2         3 6          3 7
+--R         36B a c d e  - 144A a c d e  + 360B a c d e  - 240A c d e + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 7 7        3 7       3   6  6
+--R       3B c e x  + (4A c e  - 7B c d e )x
+--R     + 
+--R               2 7        3   6        3 2 5  5
+--R       (18B a c e  - 12A c d e  + 21B c d e )x
+--R     + 
+--R               2 7          2   6        3 2 5         3 3 4  4
+--R       (36A a c e  - 90B a c d e  + 60A c d e  - 105B c d e )x
+--R     + 
+--R                2   6           2 2 5         3 3 4         3 4 3  3
+--R       (108A a c d e  - 378B a c d e  + 292A c d e  - 556B c d e )x
+--R     + 
+--R                  2   7         2     6           2 2 5          2 3 4
+--R           - 36A a c e  + 108B a c d e  - 108A a c d e  - 54B a c d e
+--R         + 
+--R                 3 4 3         3 5 2
+--R           156A c d e  - 408B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 7        2     6         2   2 5           2 3 4
+--R           - 6B a e  - 36A a c d e  + 162B a c d e  - 324A a c d e
+--R         + 
+--R                   2 4 3         3 5 2         3 6
+--R           486B a c d e  - 204A c d e  + 222B c d e
+--R      *
+--R         x
+--R     + 
+--R             3 7       3   6        2   2 5        2   3 4           2 4 3
+--R       - 4A a e  - 2B a d e  - 12A a c d e  + 66B a c d e  - 156A a c d e
+--R     + 
+--R               2 5 2         3 6          3 7
+--R       282B a c d e  - 148A c d e + 214B c d
+--R  /
+--R        11 3        10 2      2 9       3 8
+--R     12e  x  + 36d e  x  + 36d e x + 12d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1234
+
+--S 1235 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1235
+
+--S 1236 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1236
+
+)clear all
+
+--S 1237 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^5
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R      5 5       4 4      2 3 3      3 2 2     4       5
+--R     e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1237
+
+--S 1238 of 1457
+r0:=-c^2*(5*A*c*d*e-3*B*(5*c*d^2+a*e^2))*x/e^7-1/2*c^3*(5*B*d-A*e)*_
+     x^2/e^6+1/3*B*c^3*x^3/e^5+1/4*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*_
+     (d+e*x)^4)-1/3*(c*d^2+a*e^2)^2*(7*B*c*d^2-6*A*c*d*e+a*B*e^2)/_
+     (e^8*(d+e*x)^3)+3/2*c*(c*d^2+a*e^2)*(7*B*c*d^3-5*A*c*d^2*e+3*a*B*_
+     d*e^2-a*A*e^3)/(e^8*(d+e*x)^2)+c*(4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*_
+     (35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*e^4))/(e^8*(d+e*x))-c^2*(35*B*c*_
+     d^3-15*A*c*d^2*e+15*a*B*d*e^2-3*a*A*e^3)*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                   2 7           2   6         3 2 5         3 3 4  4
+--R           (36A a c e  - 180B a c d e  + 180A c d e  - 420B c d e )x
+--R         + 
+--R                    2   6           2 2 5         3 3 4          3 4 3  3
+--R           (144A a c d e  - 720B a c d e  + 720A c d e  - 1680B c d e )x
+--R         + 
+--R                    2 2 5            2 3 4          3 4 3          3 5 2  2
+--R           (216A a c d e  - 1080B a c d e  + 1080A c d e  - 2520B c d e )x
+--R         + 
+--R                    2 3 4           2 4 3         3 5 2          3 6
+--R           (144A a c d e  - 720B a c d e  + 720A c d e  - 1680B c d e)x
+--R         + 
+--R                  2 4 3           2 5 2         3 6          3 7
+--R           36A a c d e  - 180B a c d e  + 180A c d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 7 7        3 7        3   6  6
+--R       4B c e x  + (6A c e  - 14B c d e )x
+--R     + 
+--R               2 7        3   6        3 2 5  5
+--R       (36B a c e  - 36A c d e  + 84B c d e )x
+--R     + 
+--R                2   6         3 2 5         3 3 4  4
+--R       (144B a c d e  - 204A c d e  + 556B c d e )x
+--R     + 
+--R                    2   7           2   6           2 2 5        3 3 4
+--R             - 36B a c e  + 144A a c d e  - 144B a c d e  - 96A c d e
+--R           + 
+--R                   3 4 3
+--R             544B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                  2   7        2     6           2 2 5           2 3 4
+--R           - 18A a c e  - 54B a c d e  + 324A a c d e  - 756B a c d e
+--R         + 
+--R                 3 4 3         3 5 2
+--R           396A c d e  - 444B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 7        2     6        2   2 5           2 3 4
+--R           - 4B a e  - 12A a c d e  - 36B a c d e  + 264A a c d e
+--R         + 
+--R                     2 4 3         3 5 2         3 6
+--R           - 744B a c d e  + 504A c d e  - 856B c d e
+--R      *
+--R         x
+--R     + 
+--R             3 7      3   6       2   2 5       2   3 4          2 4 3
+--R       - 3A a e  - B a d e  - 3A a c d e  - 9B a c d e  + 75A a c d e
+--R     + 
+--R                 2 5 2         3 6          3 7
+--R       - 231B a c d e  + 171A c d e - 319B c d
+--R  /
+--R        12 4        11 3      2 10 2      3 9       4 8
+--R     12e  x  + 48d e  x  + 72d e  x  + 48d e x + 12d e
+--R                                                    Type: Expression(Integer)
+--E 1238
+
+--S 1239 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   2 7           2   6         3 2 5         3 3 4  4
+--R           (36A a c e  - 180B a c d e  + 180A c d e  - 420B c d e )x
+--R         + 
+--R                    2   6           2 2 5         3 3 4          3 4 3  3
+--R           (144A a c d e  - 720B a c d e  + 720A c d e  - 1680B c d e )x
+--R         + 
+--R                    2 2 5            2 3 4          3 4 3          3 5 2  2
+--R           (216A a c d e  - 1080B a c d e  + 1080A c d e  - 2520B c d e )x
+--R         + 
+--R                    2 3 4           2 4 3         3 5 2          3 6
+--R           (144A a c d e  - 720B a c d e  + 720A c d e  - 1680B c d e)x
+--R         + 
+--R                  2 4 3           2 5 2         3 6          3 7
+--R           36A a c d e  - 180B a c d e  + 180A c d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 7 7        3 7        3   6  6
+--R       4B c e x  + (6A c e  - 14B c d e )x
+--R     + 
+--R               2 7        3   6        3 2 5  5
+--R       (36B a c e  - 36A c d e  + 84B c d e )x
+--R     + 
+--R                2   6         3 2 5         3 3 4  4
+--R       (144B a c d e  - 204A c d e  + 556B c d e )x
+--R     + 
+--R                    2   7           2   6           2 2 5        3 3 4
+--R             - 36B a c e  + 144A a c d e  - 144B a c d e  - 96A c d e
+--R           + 
+--R                   3 4 3
+--R             544B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                  2   7        2     6           2 2 5           2 3 4
+--R           - 18A a c e  - 54B a c d e  + 324A a c d e  - 756B a c d e
+--R         + 
+--R                 3 4 3         3 5 2
+--R           396A c d e  - 444B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 7        2     6        2   2 5           2 3 4
+--R           - 4B a e  - 12A a c d e  - 36B a c d e  + 264A a c d e
+--R         + 
+--R                     2 4 3         3 5 2         3 6
+--R           - 744B a c d e  + 504A c d e  - 856B c d e
+--R      *
+--R         x
+--R     + 
+--R             3 7      3   6       2   2 5       2   3 4          2 4 3
+--R       - 3A a e  - B a d e  - 3A a c d e  - 9B a c d e  + 75A a c d e
+--R     + 
+--R                 2 5 2         3 6          3 7
+--R       - 231B a c d e  + 171A c d e - 319B c d
+--R  /
+--R        12 4        11 3      2 10 2      3 9       4 8
+--R     12e  x  + 48d e  x  + 72d e  x  + 48d e x + 12d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1239
+
+--S 1240 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1240
+
+--S 1241 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1241
+
+)clear all
+
+--S 1242 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^6
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R      6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R     e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1242
+
+--S 1243 of 1457
+r0:=-c^3*(6*B*d-A*e)*x/e^7+1/2*B*c^3*x^2/e^6+1/5*(B*d-A*e)*(c*d^2+_
+     a*e^2)^3/(e^8*(d+e*x)^5)-1/4*(c*d^2+a*e^2)^2*(7*B*c*d^2-6*A*c*d*e+_
+     a*B*e^2)/(e^8*(d+e*x)^4)+c*(c*d^2+a*e^2)*(7*B*c*d^3-5*A*c*d^2*e+_
+     3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^3)+1/2*c*(4*A*c*d*e*(5*c*d^2+_
+     3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*e^4))/(e^8*(d+e*x)^2)+_
+     c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*d*e^2-3*a*A*e^3)/(e^8*(d+e*x))+_
+     3*c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                   2 7         3   6         3 2 5  5
+--R           (60B a c e  - 120A c d e  + 420B c d e )x
+--R         + 
+--R                    2   6         3 2 5          3 3 4  4
+--R           (300B a c d e  - 600A c d e  + 2100B c d e )x
+--R         + 
+--R                    2 2 5          3 3 4          3 4 3  3
+--R           (600B a c d e  - 1200A c d e  + 4200B c d e )x
+--R         + 
+--R                    2 3 4          3 4 3          3 5 2  2
+--R           (600B a c d e  - 1200A c d e  + 4200B c d e )x
+--R         + 
+--R                    2 4 3         3 5 2          3 6             2 5 2
+--R           (300B a c d e  - 600A c d e  + 2100B c d e)x + 60B a c d e
+--R         + 
+--R                   3 6          3 7
+--R           - 120A c d e + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7         3 7        3   6  6          3   6         3 2 5  5
+--R       10B c e x  + (20A c e  - 70B c d e )x  + (100A c d e  - 500B c d e )x
+--R     + 
+--R                 2 7           2   6         3 2 5         3 3 4  4
+--R       (- 60A a c e  + 300B a c d e  - 100A c d e  - 400B c d e )x
+--R     + 
+--R                  2   7           2   6           2 2 5         3 3 4
+--R           - 30B a c e  - 120A a c d e  + 900B a c d e  - 800A c d e
+--R         + 
+--R                  3 4 3
+--R           1300B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                  2   7        2     6           2 2 5            2 3 4
+--R           - 20A a c e  - 30B a c d e  - 120A a c d e  + 1100B a c d e
+--R         + 
+--R                    3 4 3          3 5 2
+--R           - 1200A c d e  + 2700B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 7        2     6        2   2 5          2 3 4
+--R           - 5B a e  - 10A a c d e  - 15B a c d e  - 60A a c d e
+--R         + 
+--R                   2 4 3         3 5 2          3 6
+--R           625B a c d e  - 750A c d e  + 1875B c d e
+--R      *
+--R         x
+--R     + 
+--R             3 7      3   6       2   2 5       2   3 4          2 4 3
+--R       - 4A a e  - B a d e  - 2A a c d e  - 3B a c d e  - 12A a c d e
+--R     + 
+--R               2 5 2         3 6          3 7
+--R       137B a c d e  - 174A c d e + 459B c d
+--R  /
+--R        13 5         12 4       2 11 3       3 10 2       4 9       5 8
+--R     20e  x  + 100d e  x  + 200d e  x  + 200d e  x  + 100d e x + 20d e
+--R                                                    Type: Expression(Integer)
+--E 1243
+
+--S 1244 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   2 7         3   6         3 2 5  5
+--R           (60B a c e  - 120A c d e  + 420B c d e )x
+--R         + 
+--R                    2   6         3 2 5          3 3 4  4
+--R           (300B a c d e  - 600A c d e  + 2100B c d e )x
+--R         + 
+--R                    2 2 5          3 3 4          3 4 3  3
+--R           (600B a c d e  - 1200A c d e  + 4200B c d e )x
+--R         + 
+--R                    2 3 4          3 4 3          3 5 2  2
+--R           (600B a c d e  - 1200A c d e  + 4200B c d e )x
+--R         + 
+--R                    2 4 3         3 5 2          3 6             2 5 2
+--R           (300B a c d e  - 600A c d e  + 2100B c d e)x + 60B a c d e
+--R         + 
+--R                   3 6          3 7
+--R           - 120A c d e + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7         3 7        3   6  6          3   6         3 2 5  5
+--R       10B c e x  + (20A c e  - 70B c d e )x  + (100A c d e  - 500B c d e )x
+--R     + 
+--R                 2 7           2   6         3 2 5         3 3 4  4
+--R       (- 60A a c e  + 300B a c d e  - 100A c d e  - 400B c d e )x
+--R     + 
+--R                  2   7           2   6           2 2 5         3 3 4
+--R           - 30B a c e  - 120A a c d e  + 900B a c d e  - 800A c d e
+--R         + 
+--R                  3 4 3
+--R           1300B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                  2   7        2     6           2 2 5            2 3 4
+--R           - 20A a c e  - 30B a c d e  - 120A a c d e  + 1100B a c d e
+--R         + 
+--R                    3 4 3          3 5 2
+--R           - 1200A c d e  + 2700B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 7        2     6        2   2 5          2 3 4
+--R           - 5B a e  - 10A a c d e  - 15B a c d e  - 60A a c d e
+--R         + 
+--R                   2 4 3         3 5 2          3 6
+--R           625B a c d e  - 750A c d e  + 1875B c d e
+--R      *
+--R         x
+--R     + 
+--R             3 7      3   6       2   2 5       2   3 4          2 4 3
+--R       - 4A a e  - B a d e  - 2A a c d e  - 3B a c d e  - 12A a c d e
+--R     + 
+--R               2 5 2         3 6          3 7
+--R       137B a c d e  - 174A c d e + 459B c d
+--R  /
+--R        13 5         12 4       2 11 3       3 10 2       4 9       5 8
+--R     20e  x  + 100d e  x  + 200d e  x  + 200d e  x  + 100d e x + 20d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1244
+
+--S 1245 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1245
+
+--S 1246 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1246
+
+)clear all
+
+--S 1247 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^7
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R      7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R     e x  + 7d e x  + 21d e x  + 35d e x  + 35d e x  + 21d e x  + 7d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1247
+
+--S 1248 of 1457
+r0:=B*c^3*x/e^7+1/6*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+e*x)^6)-1/5*(c*d^2+_
+     a*e^2)^2*(7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x)^5)+3/4*c*(c*d^2+_
+     a*e^2)*(7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^4)+_
+     1/3*c*(4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*_
+     a^2*e^4))/(e^8*(d+e*x)^3)+1/2*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*_
+     d*e^2-3*a*A*e^3)/(e^8*(d+e*x)^2)-3*c^2*(7*B*c*d^2-2*A*c*d*e+a*_
+     B*e^2)/(e^8*(d+e*x))-c^3*(7*B*d-A*e)*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                 3 7         3   6  6          3   6          3 2 5  5
+--R           (60A c e  - 420B c d e )x  + (360A c d e  - 2520B c d e )x
+--R         + 
+--R                  3 2 5          3 3 4  4           3 3 4          3 4 3  3
+--R           (900A c d e  - 6300B c d e )x  + (1200A c d e  - 8400B c d e )x
+--R         + 
+--R                  3 4 3          3 5 2  2          3 5 2          3 6
+--R           (900A c d e  - 6300B c d e )x  + (360A c d e  - 2520B c d e)x
+--R         + 
+--R                3 6          3 7
+--R           60A c d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7         3   6 6
+--R       60B c e x  + 360B c d e x
+--R     + 
+--R                  2 7         3   6         3 2 5  5
+--R       (- 180B a c e  + 360A c d e  - 360B c d e )x
+--R     + 
+--R                 2 7           2   6          3 2 5          3 3 4  4
+--R       (- 90A a c e  - 450B a c d e  + 1350A c d e  - 4050B c d e )x
+--R     + 
+--R                  2   7           2   6           2 2 5          3 3 4
+--R           - 60B a c e  - 120A a c d e  - 600B a c d e  + 2200A c d e
+--R         + 
+--R                    3 4 3
+--R           - 8200B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                  2   7        2     6          2 2 5           2 3 4
+--R           - 45A a c e  - 45B a c d e  - 90A a c d e  - 450B a c d e
+--R         + 
+--R                  3 4 3          3 5 2
+--R           1875A c d e  - 7725B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 7        2     6        2   2 5          2 3 4
+--R           - 12B a e  - 18A a c d e  - 18B a c d e  - 36A a c d e
+--R         + 
+--R                     2 4 3         3 5 2          3 6
+--R           - 180B a c d e  + 822A c d e  - 3594B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 7       3   6       2   2 5       2   3 4         2 4 3
+--R       - 10A a e  - 2B a d e  - 3A a c d e  - 3B a c d e  - 6A a c d e
+--R     + 
+--R                2 5 2         3 6          3 7
+--R       - 30B a c d e  + 147A c d e - 669B c d
+--R  /
+--R          14 6         13 5       2 12 4        3 11 3       4 10 2       5 9
+--R       60e  x  + 360d e  x  + 900d e  x  + 1200d e  x  + 900d e  x  + 360d e x
+--R     + 
+--R          6 8
+--R       60d e
+--R                                                    Type: Expression(Integer)
+--E 1248
+
+--S 1249 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3 7         3   6  6          3   6          3 2 5  5
+--R           (60A c e  - 420B c d e )x  + (360A c d e  - 2520B c d e )x
+--R         + 
+--R                  3 2 5          3 3 4  4           3 3 4          3 4 3  3
+--R           (900A c d e  - 6300B c d e )x  + (1200A c d e  - 8400B c d e )x
+--R         + 
+--R                  3 4 3          3 5 2  2          3 5 2          3 6
+--R           (900A c d e  - 6300B c d e )x  + (360A c d e  - 2520B c d e)x
+--R         + 
+--R                3 6          3 7
+--R           60A c d e - 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 7 7         3   6 6
+--R       60B c e x  + 360B c d e x
+--R     + 
+--R                  2 7         3   6         3 2 5  5
+--R       (- 180B a c e  + 360A c d e  - 360B c d e )x
+--R     + 
+--R                 2 7           2   6          3 2 5          3 3 4  4
+--R       (- 90A a c e  - 450B a c d e  + 1350A c d e  - 4050B c d e )x
+--R     + 
+--R                  2   7           2   6           2 2 5          3 3 4
+--R           - 60B a c e  - 120A a c d e  - 600B a c d e  + 2200A c d e
+--R         + 
+--R                    3 4 3
+--R           - 8200B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                  2   7        2     6          2 2 5           2 3 4
+--R           - 45A a c e  - 45B a c d e  - 90A a c d e  - 450B a c d e
+--R         + 
+--R                  3 4 3          3 5 2
+--R           1875A c d e  - 7725B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 7        2     6        2   2 5          2 3 4
+--R           - 12B a e  - 18A a c d e  - 18B a c d e  - 36A a c d e
+--R         + 
+--R                     2 4 3         3 5 2          3 6
+--R           - 180B a c d e  + 822A c d e  - 3594B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 7       3   6       2   2 5       2   3 4         2 4 3
+--R       - 10A a e  - 2B a d e  - 3A a c d e  - 3B a c d e  - 6A a c d e
+--R     + 
+--R                2 5 2         3 6          3 7
+--R       - 30B a c d e  + 147A c d e - 669B c d
+--R  /
+--R          14 6         13 5       2 12 4        3 11 3       4 10 2       5 9
+--R       60e  x  + 360d e  x  + 900d e  x  + 1200d e  x  + 900d e  x  + 360d e x
+--R     + 
+--R          6 8
+--R       60d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1249
+
+--S 1250 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1250
+
+--S 1251 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1251
+
+)clear all
+
+--S 1252 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^8
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R        8 8       7 7      2 6 6      3 5 5      4 4 4      5 3 3      6 2 2
+--R       e x  + 8d e x  + 28d e x  + 56d e x  + 70d e x  + 56d e x  + 28d e x
+--R     + 
+--R         7       8
+--R       8d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1252
+
+--S 1253 of 1457
+r0:=1/7*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+e*x)^7)-1/6*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x)^6)+3/5*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^5)+1/4*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*_
+     e^4))/(e^8*(d+e*x)^4)+1/3*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*d*e^2-_
+     3*a*A*e^3)/(e^8*(d+e*x)^3)-3/2*c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)/_
+     (e^8*(d+e*x)^2)+c^3*(7*B*d-A*e)/(e^8*(d+e*x))+B*c^3*log(d+e*x)/e^8
+--R 
+--R
+--R   (2)
+--R                 3 7 7          3   6 6          3 2 5 5           3 3 4 4
+--R           420B c e x  + 2940B c d e x  + 8820B c d e x  + 14700B c d e x
+--R         + 
+--R                   3 4 3 3          3 5 2 2          3 6            3 7
+--R           14700B c d e x  + 8820B c d e x  + 2940B c d e x + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                3 7          3   6  6
+--R       (- 420A c e  + 2940B c d e )x
+--R     + 
+--R                  2 7          3   6           3 2 5  5
+--R       (- 630B a c e  - 1260A c d e  + 13230B c d e )x
+--R     + 
+--R                  2 7            2   6          3 2 5           3 3 4  4
+--R       (- 420A a c e  - 1050B a c d e  - 2100A c d e  + 26950B c d e )x
+--R     + 
+--R                   2   7           2   6            2 2 5          3 3 4
+--R           - 315B a c e  - 420A a c d e  - 1050B a c d e  - 2100A c d e
+--R         + 
+--R                   3 4 3
+--R           30625B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                   2   7         2     6           2 2 5           2 3 4
+--R           - 252A a c e  - 189B a c d e  - 252A a c d e  - 630B a c d e
+--R         + 
+--R                    3 4 3           3 5 2
+--R           - 1260A c d e  + 20139B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 7        2     6        2   2 5          2 3 4
+--R           - 70B a e  - 84A a c d e  - 63B a c d e  - 84A a c d e
+--R         + 
+--R                     2 4 3         3 5 2          3 6
+--R           - 210B a c d e  - 420A c d e  + 7203B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 7        3   6        2   2 5       2   3 4          2 4 3
+--R       - 60A a e  - 10B a d e  - 12A a c d e  - 9B a c d e  - 12A a c d e
+--R     + 
+--R                2 5 2        3 6           3 7
+--R       - 30B a c d e  - 60A c d e + 1089B c d
+--R  /
+--R           15 7          14 6        2 13 5         3 12 4         4 11 3
+--R       420e  x  + 2940d e  x  + 8820d e  x  + 14700d e  x  + 14700d e  x
+--R     + 
+--R            5 10 2        6 9        7 8
+--R       8820d e  x  + 2940d e x + 420d e
+--R                                                    Type: Expression(Integer)
+--E 1253
+
+--S 1254 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3 7 7          3   6 6          3 2 5 5           3 3 4 4
+--R           420B c e x  + 2940B c d e x  + 8820B c d e x  + 14700B c d e x
+--R         + 
+--R                   3 4 3 3          3 5 2 2          3 6            3 7
+--R           14700B c d e x  + 8820B c d e x  + 2940B c d e x + 420B c d
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                3 7          3   6  6
+--R       (- 420A c e  + 2940B c d e )x
+--R     + 
+--R                  2 7          3   6           3 2 5  5
+--R       (- 630B a c e  - 1260A c d e  + 13230B c d e )x
+--R     + 
+--R                  2 7            2   6          3 2 5           3 3 4  4
+--R       (- 420A a c e  - 1050B a c d e  - 2100A c d e  + 26950B c d e )x
+--R     + 
+--R                   2   7           2   6            2 2 5          3 3 4
+--R           - 315B a c e  - 420A a c d e  - 1050B a c d e  - 2100A c d e
+--R         + 
+--R                   3 4 3
+--R           30625B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                   2   7         2     6           2 2 5           2 3 4
+--R           - 252A a c e  - 189B a c d e  - 252A a c d e  - 630B a c d e
+--R         + 
+--R                    3 4 3           3 5 2
+--R           - 1260A c d e  + 20139B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 7        2     6        2   2 5          2 3 4
+--R           - 70B a e  - 84A a c d e  - 63B a c d e  - 84A a c d e
+--R         + 
+--R                     2 4 3         3 5 2          3 6
+--R           - 210B a c d e  - 420A c d e  + 7203B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 7        3   6        2   2 5       2   3 4          2 4 3
+--R       - 60A a e  - 10B a d e  - 12A a c d e  - 9B a c d e  - 12A a c d e
+--R     + 
+--R                2 5 2        3 6           3 7
+--R       - 30B a c d e  - 60A c d e + 1089B c d
+--R  /
+--R           15 7          14 6        2 13 5         3 12 4         4 11 3
+--R       420e  x  + 2940d e  x  + 8820d e  x  + 14700d e  x  + 14700d e  x
+--R     + 
+--R            5 10 2        6 9        7 8
+--R       8820d e  x  + 2940d e x + 420d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1254
+
+--S 1255 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1255
+
+--S 1256 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1256
+
+)clear all
+
+--S 1257 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^9
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R        9 9       8 8      2 7 7      3 6 6       4 5 5       5 4 4      6 3 3
+--R       e x  + 9d e x  + 36d e x  + 84d e x  + 126d e x  + 126d e x  + 84d e x
+--R     + 
+--R          7 2 2     8       9
+--R       36d e x  + 9d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1257
+
+--S 1258 of 1457
+r0:=1/8*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+e*x)^8)-1/7*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x)^7)+1/2*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^6)+1/5*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*_
+     e^4))/(e^8*(d+e*x)^5)+1/4*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*d*e^2-_
+     3*a*A*e^3)/(e^8*(d+e*x)^4)-c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)/(e^8*_
+     (d+e*x)^3)+1/2*c^3*(7*B*d-A*e)/(e^8*(d+e*x)^2)-B*c^3/(e^8*(d+e*x))
+--R 
+--R
+--R   (2)
+--R            3 7 7      1    3 7   7    3   6  6
+--R       - B c e x  + (- - A c e  - - B c d e )x
+--R                       2          2
+--R     + 
+--R               2 7      3   6       3 2 5  5
+--R       (- B a c e  - A c d e  - 7B c d e )x
+--R     + 
+--R          3      2 7   5      2   6   5    3 2 5   35    3 3 4  4
+--R       (- - A a c e  - - B a c d e  - - A c d e  - -- B c d e )x
+--R          4            4              4             4
+--R     + 
+--R          3    2   7   3      2   6        2 2 5      3 3 4       3 4 3  3
+--R       (- - B a c e  - - A a c d e  - B a c d e  - A c d e  - 7B c d e )x
+--R          5            5
+--R     + 
+--R             1    2   7    3    2     6    3      2 2 5   1      2 3 4
+--R           - - A a c e  - -- B a c d e  - -- A a c d e  - - B a c d e
+--R             2            10              10              2
+--R         + 
+--R             1    3 4 3   7    3 5 2
+--R           - - A c d e  - - B c d e
+--R             2            2
+--R      *
+--R          2
+--R         x
+--R     + 
+--R             1    3 7   1    2     6    3    2   2 5    3      2 3 4
+--R           - - B a e  - - A a c d e  - -- B a c d e  - -- A a c d e
+--R             7          7              35              35
+--R         + 
+--R             1      2 4 3   1    3 5 2      3 6
+--R           - - B a c d e  - - A c d e  - B c d e
+--R             7              7
+--R      *
+--R         x
+--R     + 
+--R         1    3 7    1    3   6    1    2   2 5    3     2   3 4
+--R       - - A a e  - -- B a d e  - -- A a c d e  - --- B a c d e
+--R         8          56            56              280
+--R     + 
+--R          3       2 4 3    1      2 5 2    1    3 6    1    3 7
+--R       - --- A a c d e  - -- B a c d e  - -- A c d e - - B c d
+--R         280              56              56           8
+--R  /
+--R        16 8       15 7      2 14 6      3 13 5      4 12 4      5 11 3
+--R       e  x  + 8d e  x  + 28d e  x  + 56d e  x  + 70d e  x  + 56d e  x
+--R     + 
+--R          6 10 2     7 9     8 8
+--R       28d e  x  + 8d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1258
+
+--S 1259 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 7 7            3 7         3   6  6
+--R       - 280B c e x  + (- 140A c e  - 980B c d e )x
+--R     + 
+--R                  2 7         3   6          3 2 5  5
+--R       (- 280B a c e  - 280A c d e  - 1960B c d e )x
+--R     + 
+--R                  2 7           2   6         3 2 5          3 3 4  4
+--R       (- 210A a c e  - 350B a c d e  - 350A c d e  - 2450B c d e )x
+--R     + 
+--R                   2   7           2   6           2 2 5         3 3 4
+--R           - 168B a c e  - 168A a c d e  - 280B a c d e  - 280A c d e
+--R         + 
+--R                    3 4 3
+--R           - 1960B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                   2   7        2     6          2 2 5           2 3 4
+--R           - 140A a c e  - 84B a c d e  - 84A a c d e  - 140B a c d e
+--R         + 
+--R                   3 4 3         3 5 2
+--R           - 140A c d e  - 980B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 7        2     6        2   2 5          2 3 4
+--R           - 40B a e  - 40A a c d e  - 24B a c d e  - 24A a c d e
+--R         + 
+--R                    2 4 3        3 5 2         3 6
+--R           - 40B a c d e  - 40A c d e  - 280B c d e
+--R      *
+--R         x
+--R     + 
+--R              3 7       3   6       2   2 5       2   3 4         2 4 3
+--R       - 35A a e  - 5B a d e  - 5A a c d e  - 3B a c d e  - 3A a c d e
+--R     + 
+--R               2 5 2       3 6         3 7
+--R       - 5B a c d e  - 5A c d e - 35B c d
+--R  /
+--R           16 8          15 7        2 14 6         3 13 5         4 12 4
+--R       280e  x  + 2240d e  x  + 7840d e  x  + 15680d e  x  + 19600d e  x
+--R     + 
+--R             5 11 3        6 10 2        7 9        8 8
+--R       15680d e  x  + 7840d e  x  + 2240d e x + 280d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1259
+
+--S 1260 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1260
+
+--S 1261 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1261
+
+)clear all
+
+--S 1262 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^10
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R        10 10        9 9      2 8 8       3 7 7       4 6 6       5 5 5
+--R       e  x   + 10d e x  + 45d e x  + 120d e x  + 210d e x  + 252d e x
+--R     + 
+--R           6 4 4       7 3 3      8 2 2      9       10
+--R       210d e x  + 120d e x  + 45d e x  + 10d e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1262
+
+--S 1263 of 1457
+r0:=1/9*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+e*x)^9)-1/8*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x)^8)+3/7*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^7)+1/6*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*_
+     a^2*e^4))/(e^8*(d+e*x)^6)+1/5*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*_
+     d*e^2-3*a*A*e^3)/(e^8*(d+e*x)^5)-3/4*c^2*(7*B*c*d^2-2*A*c*d*e+_
+     a*B*e^2)/(e^8*(d+e*x)^4)+1/3*c^3*(7*B*d-A*e)/(e^8*(d+e*x)^3)-_
+     1/2*B*c^3/(e^8*(d+e*x)^2)
+--R 
+--R
+--R   (2)
+--R         1    3 7 7      1    3 7   7    3   6  6
+--R       - - B c e x  + (- - A c e  - - B c d e )x
+--R         2               3          6
+--R     + 
+--R          3      2 7   1    3   6   7    3 2 5  5
+--R       (- - B a c e  - - A c d e  - - B c d e )x
+--R          4            2            4
+--R     + 
+--R          3      2 7   3      2   6   1    3 2 5   7    3 3 4  4
+--R       (- - A a c e  - - B a c d e  - - A c d e  - - B c d e )x
+--R          5            4              2            4
+--R     + 
+--R          1    2   7   2      2   6   1      2 2 5   1    3 3 4   7    3 4 3  3
+--R       (- - B a c e  - - A a c d e  - - B a c d e  - - A c d e  - - B c d e )x
+--R          2            5              2              3            6
+--R     + 
+--R             3    2   7    3    2     6    6      2 2 5    3      2 3 4
+--R           - - A a c e  - -- B a c d e  - -- A a c d e  - -- B a c d e
+--R             7            14              35              14
+--R         + 
+--R             1    3 4 3   1    3 5 2
+--R           - - A c d e  - - B c d e
+--R             7            2
+--R      *
+--R          2
+--R         x
+--R     + 
+--R             1    3 7    3    2     6    3    2   2 5    3      2 3 4
+--R           - - B a e  - -- A a c d e  - -- B a c d e  - -- A a c d e
+--R             8          28              56              70
+--R         + 
+--R              3      2 4 3    1    3 5 2   1    3 6
+--R           - -- B a c d e  - -- A c d e  - - B c d e
+--R             56              28            8
+--R      *
+--R         x
+--R     + 
+--R         1    3 7    1    3   6    1    2   2 5    1     2   3 4
+--R       - - A a e  - -- B a d e  - -- A a c d e  - --- B a c d e
+--R         9          72            84              168
+--R     + 
+--R          1       2 4 3    1       2 5 2    1     3 6     1    3 7
+--R       - --- A a c d e  - --- B a c d e  - --- A c d e - -- B c d
+--R         210              168              252           72
+--R  /
+--R        17 9       16 8      2 15 7      3 14 6       4 13 5       5 12 4
+--R       e  x  + 9d e  x  + 36d e  x  + 84d e  x  + 126d e  x  + 126d e  x
+--R     + 
+--R          6 11 3      7 10 2     8 9     9 8
+--R       84d e  x  + 36d e  x  + 9d e x + d e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1263
+
+--S 1264 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 7 7            3 7          3   6  6
+--R       - 1260B c e x  + (- 840A c e  - 2940B c d e )x
+--R     + 
+--R                   2 7          3   6          3 2 5  5
+--R       (- 1890B a c e  - 1260A c d e  - 4410B c d e )x
+--R     + 
+--R                   2 7            2   6          3 2 5          3 3 4  4
+--R       (- 1512A a c e  - 1890B a c d e  - 1260A c d e  - 4410B c d e )x
+--R     + 
+--R                    2   7            2   6            2 2 5         3 3 4
+--R           - 1260B a c e  - 1008A a c d e  - 1260B a c d e  - 840A c d e
+--R         + 
+--R                    3 4 3
+--R           - 2940B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                    2   7         2     6           2 2 5           2 3 4
+--R           - 1080A a c e  - 540B a c d e  - 432A a c d e  - 540B a c d e
+--R         + 
+--R                   3 4 3          3 5 2
+--R           - 360A c d e  - 1260B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                   3 7         2     6         2   2 5           2 3 4
+--R           - 315B a e  - 270A a c d e  - 135B a c d e  - 108A a c d e
+--R         + 
+--R                     2 4 3        3 5 2         3 6
+--R           - 135B a c d e  - 90A c d e  - 315B c d e
+--R      *
+--R         x
+--R     + 
+--R               3 7        3   6        2   2 5        2   3 4          2 4 3
+--R       - 280A a e  - 35B a d e  - 30A a c d e  - 15B a c d e  - 12A a c d e
+--R     + 
+--R                2 5 2        3 6         3 7
+--R       - 15B a c d e  - 10A c d e - 35B c d
+--R  /
+--R            17 9           16 8         2 15 7          3 14 6          4 13 5
+--R       2520e  x  + 22680d e  x  + 90720d e  x  + 211680d e  x  + 317520d e  x
+--R     + 
+--R              5 12 4          6 11 3         7 10 2         8 9         9 8
+--R       317520d e  x  + 211680d e  x  + 90720d e  x  + 22680d e x + 2520d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1264
+
+--S 1265 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1265
+
+--S 1266 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1266
+
+)clear all
+
+--S 1267 of 1457
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^11
+--R 
+--R
+--R   (1)
+--R          3 7      3 6         2 5         2 4       2   3       2   2      3
+--R       B c x  + A c x  + 3B a c x  + 3A a c x  + 3B a c x  + 3A a c x  + B a x
+--R     + 
+--R          3
+--R       A a
+--R  /
+--R        11 11        10 10      2 9 9       3 8 8       4 7 7       5 6 6
+--R       e  x   + 11d e  x   + 55d e x  + 165d e x  + 330d e x  + 462d e x
+--R     + 
+--R           6 5 5       7 4 4       8 3 3      9 2 2      10       11
+--R       462d e x  + 330d e x  + 165d e x  + 55d e x  + 11d  e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1267
+
+--S 1268 of 1457
+r0:=1/10*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+e*x)^10)-1/9*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x)^9)+3/8*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^8)+1/7*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*_
+     e^4))/(e^8*(d+e*x)^7)+1/6*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*d*e^2-_
+     3*a*A*e^3)/(e^8*(d+e*x)^6)-3/5*c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)/_
+     (e^8*(d+e*x)^5)+1/4*c^3*(7*B*d-A*e)/(e^8*(d+e*x)^4)-1/3*B*c^3/_
+     (e^8*(d+e*x)^3)
+--R 
+--R
+--R   (2)
+--R         1    3 7 7      1    3 7    7    3   6  6
+--R       - - B c e x  + (- - A c e  - -- B c d e )x
+--R         3               4          12
+--R     + 
+--R          3      2 7    3    3   6    7    3 2 5  5
+--R       (- - B a c e  - -- A c d e  - -- B c d e )x
+--R          5            10            10
+--R     + 
+--R          1      2 7   1      2   6   1    3 2 5    7    3 3 4  4
+--R       (- - A a c e  - - B a c d e  - - A c d e  - -- B c d e )x
+--R          2            2              4            12
+--R     + 
+--R          3    2   7   2      2   6   2      2 2 5   1    3 3 4   1    3 4 3  3
+--R       (- - B a c e  - - A a c d e  - - B a c d e  - - A c d e  - - B c d e )x
+--R          7            7              7              7            3
+--R     + 
+--R             3    2   7    9    2     6    3      2 2 5    3      2 3 4
+--R           - - A a c e  - -- B a c d e  - -- A a c d e  - -- B a c d e
+--R             8            56              28              28
+--R         + 
+--R              3    3 4 3   1    3 5 2
+--R           - -- A c d e  - - B c d e
+--R             56            8
+--R      *
+--R          2
+--R         x
+--R     + 
+--R             1    3 7    1    2     6    1    2   2 5    1      2 3 4
+--R           - - B a e  - -- A a c d e  - -- B a c d e  - -- A a c d e
+--R             9          12              28              42
+--R         + 
+--R              1      2 4 3    1    3 5 2    1    3 6
+--R           - -- B a c d e  - -- A c d e  - -- B c d e
+--R             42              84            36
+--R      *
+--R         x
+--R     + 
+--R          1    3 7    1    3   6    1     2   2 5    1     2   3 4
+--R       - -- A a e  - -- B a d e  - --- A a c d e  - --- B a c d e
+--R         10          90            120              280
+--R     + 
+--R          1       2 4 3    1       2 5 2    1     3 6     1     3 7
+--R       - --- A a c d e  - --- B a c d e  - --- A c d e - --- B c d
+--R         420              420              840           360
+--R  /
+--R        18 10        17 9      2 16 8       3 15 7       4 14 6       5 13 5
+--R       e  x   + 10d e  x  + 45d e  x  + 120d e  x  + 210d e  x  + 252d e  x
+--R     + 
+--R           6 12 4       7 11 3      8 10 2      9 9     10 8
+--R       210d e  x  + 120d e  x  + 45d e  x  + 10d e x + d  e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1268
+
+--S 1269 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 7 7            3 7          3   6  6
+--R       - 840B c e x  + (- 630A c e  - 1470B c d e )x
+--R     + 
+--R                   2 7         3   6          3 2 5  5
+--R       (- 1512B a c e  - 756A c d e  - 1764B c d e )x
+--R     + 
+--R                   2 7            2   6         3 2 5          3 3 4  4
+--R       (- 1260A a c e  - 1260B a c d e  - 630A c d e  - 1470B c d e )x
+--R     + 
+--R                    2   7           2   6           2 2 5         3 3 4
+--R           - 1080B a c e  - 720A a c d e  - 720B a c d e  - 360A c d e
+--R         + 
+--R                   3 4 3
+--R           - 840B c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                   2   7         2     6           2 2 5           2 3 4
+--R           - 945A a c e  - 405B a c d e  - 270A a c d e  - 270B a c d e
+--R         + 
+--R                   3 4 3         3 5 2
+--R           - 135A c d e  - 315B c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                   3 7         2     6        2   2 5          2 3 4
+--R           - 280B a e  - 210A a c d e  - 90B a c d e  - 60A a c d e
+--R         + 
+--R                    2 4 3        3 5 2        3 6
+--R           - 60B a c d e  - 30A c d e  - 70B c d e
+--R      *
+--R         x
+--R     + 
+--R               3 7        3   6        2   2 5       2   3 4         2 4 3
+--R       - 252A a e  - 28B a d e  - 21A a c d e  - 9B a c d e  - 6A a c d e
+--R     + 
+--R               2 5 2       3 6        3 7
+--R       - 6B a c d e  - 3A c d e - 7B c d
+--R  /
+--R            18 10           17 9          2 16 8          3 15 7          4 14 6
+--R       2520e  x   + 25200d e  x  + 113400d e  x  + 302400d e  x  + 529200d e  x
+--R     + 
+--R              5 13 5          6 12 4          7 11 3          8 10 2
+--R       635040d e  x  + 529200d e  x  + 302400d e  x  + 113400d e  x
+--R     + 
+--R             9 9         10 8
+--R       25200d e x + 2520d  e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1269
+
+--S 1270 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1270
+
+--S 1271 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1271
+
+)clear all
+
+--S 1272 of 1457
+t0:=(A+B*x)*(d+e*x)^m/(a+c*x^2)
+--R 
+--R
+--R                          m
+--R        (B x + A)(e x + d)
+--R   (1)  -------------------
+--R                 2
+--R              c x  + a
+--R                                                    Type: Expression(Integer)
+--E 1272
+
+--S 1273 of 1457
+--r0:=-1/2*(d+e*x)^(1+m)*hypergeometric(1,1+m,2+m,(d+e*x)*sqrt(c)/_
+--     (e*sqrt(-a)+d*sqrt(c)))*(A+B*sqrt(-a)/sqrt(c))/((1+m)*sqrt(-a)*_
+--     (e*sqrt(-a)+d*sqrt(c)))-1/2*(d+e*x)^(1+m)*hypergeometric(1,1+m,2+_
+--     m,(d+e*x)*sqrt(c)/(-e*sqrt(-a)+d*sqrt(c)))*(a*B+A*sqrt(-a)*sqrt(c))/_
+--     (a*(1+m)*sqrt(c)*(-e*sqrt(-a)+d*sqrt(c)))
+--E 1273
+
+--S 1274 of 1457
+--a0:=integrate(t0,x)
+--E 1274
+
+--S 1275 of 1457
+--m0:=a0-r0
+--E 1275
+
+--S 1276 of 1457
+--d0:=D(m0,x)
+--E 1276
+
+)clear all
+
+--S 1277 of 1457
+t0:=(A+B*x)*(d+e*x)^(1+m)/(a+c*x^2)
+--R 
+--R
+--R                          m + 1
+--R        (B x + A)(e x + d)
+--R   (1)  -----------------------
+--R                   2
+--R                c x  + a
+--R                                                    Type: Expression(Integer)
+--E 1277
+
+--S 1278 of 1457
+--r0:=-1/2*(d+e*x)^(2+m)*hypergeometric(1,2+m,3+m,(d+e*x)*sqrt(c)/(e*_
+--     sqrt(-a)+d*sqrt(c)))*(A+B*sqrt(-a)/sqrt(c))/((2+m)*sqrt(-a)*(e*_
+--     sqrt(-a)+d*sqrt(c)))-1/2*(d+e*x)^(2+m)*hypergeometric(1,2+m,3+m,_
+--     (d+e*x)*sqrt(c)/(-e*sqrt(-a)+d*sqrt(c)))*(a*B+A*sqrt(-a)*sqrt(c))/_
+--     (a*(2+m)*sqrt(c)*(-e*sqrt(-a)+d*sqrt(c)))
+--E 1278
+
+--S 1279 of 1457
+--a0:=integrate(t0,x)
+--E 1279
+
+--S 1280 of 1457
+--m0:=a0-r0
+--E 1280
+
+--S 1281 of 1457
+--d0:=D(m0,x)
+--E 1281
+
+)clear all
+
+--S 1282 of 1457
+t0:=(A+B*x)*(d+e*x)^4/(a+c*x^2)
+--R 
+--R
+--R   (1)
+--R          4 5       4         3  4          3       2 2  3
+--R       B e x  + (A e  + 4B d e )x  + (4A d e  + 6B d e )x
+--R     + 
+--R            2 2       3   2        3       4        4
+--R       (6A d e  + 4B d e)x  + (4A d e + B d )x + A d
+--R  /
+--R        2
+--R     c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1282
+
+--S 1283 of 1457
+r0:=e*(4*B*c*d^3+6*A*c*d^2*e-4*a*B*d*e^2-a*A*e^3)*x/c^2+1/2*e^2*(6*B*c*d^2+_
+     4*A*c*d*e-a*B*e^2)*x^2/c^2+1/3*e^3*(4*B*d+A*e)*x^3/c+1/4*B*e^4*x^4/c+_
+     1/2*(4*A*c*d*e*(c*d^2-a*e^2)+B*(c^2*d^4-6*a*c*d^2*e^2+a^2*e^4))*_
+     log(a+c*x^2)/c^3-(4*a*B*d*e*(c*d^2-a*e^2)-A*(c^2*d^4-6*a*c*d^2*_
+     e^2+a^2*e^4))*atan(x*sqrt(c)/sqrt(a))/(c^(5/2)*sqrt(a))
+--R 
+--R
+--R   (2)
+--R               2   4        2     3          2 2 2          2 3         3 4
+--R         (12A a c e  + 48B a c d e  - 72A a c d e  - 48B a c d e + 12A c d )
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                  2 4              3            2 2        2 3        2 4
+--R             (6B a e  - 24A a c d e  - 36B a c d e  + 24A c d e + 6B c d )
+--R          *
+--R                    2
+--R             log(c x  + a)
+--R         + 
+--R               2 4 4        2 4        2   3  3
+--R           3B c e x  + (4A c e  + 16B c d e )x
+--R         + 
+--R                      4        2   3        2 2 2  2
+--R           (- 6B a c e  + 24A c d e  + 36B c d e )x
+--R         + 
+--R                       4              3        2 2 2        2 3
+--R           (- 12A a c e  - 48B a c d e  + 72A c d e  + 48B c d e)x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R        3 +-+ +-+
+--R     12c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1283
+
+--S 1284 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2   4        2     3          2 2 2          2 3        3 4
+--R           (6A a c e  + 24B a c d e  - 36A a c d e  - 24B a c d e + 6A c d )
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                    2 4              3            2 2        2 3        2 4
+--R               (6B a e  - 24A a c d e  - 36B a c d e  + 24A c d e + 6B c d )
+--R            *
+--R                      2
+--R               log(c x  + a)
+--R           + 
+--R                 2 4 4        2 4        2   3  3
+--R             3B c e x  + (4A c e  + 16B c d e )x
+--R           + 
+--R                        4        2   3        2 2 2  2
+--R             (- 6B a c e  + 24A c d e  + 36B c d e )x
+--R           + 
+--R                         4              3        2 2 2        2 3
+--R             (- 12A a c e  - 48B a c d e  + 72A c d e  + 48B c d e)x
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R          3 +-----+
+--R       12c \|- a c
+--R     ,
+--R
+--R                 2   4        2     3          2 2 2          2 3         3 4
+--R           (12A a c e  + 48B a c d e  - 72A a c d e  - 48B a c d e + 12A c d )
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                    2 4              3            2 2        2 3        2 4
+--R               (6B a e  - 24A a c d e  - 36B a c d e  + 24A c d e + 6B c d )
+--R            *
+--R                      2
+--R               log(c x  + a)
+--R           + 
+--R                 2 4 4        2 4        2   3  3
+--R             3B c e x  + (4A c e  + 16B c d e )x
+--R           + 
+--R                        4        2   3        2 2 2  2
+--R             (- 6B a c e  + 24A c d e  + 36B c d e )x
+--R           + 
+--R                         4              3        2 2 2        2 3
+--R             (- 12A a c e  - 48B a c d e  + 72A c d e  + 48B c d e)x
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R          3 +---+
+--R       12c \|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1284
+
+--S 1285 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2 4       2   3           2 2           3       2 4  +-+ +-+
+--R         (A a e  + 4B a d e  - 6A a c d e  - 4B a c d e + A c d )\|a \|c
+--R      *
+--R                 2      +-----+
+--R             (c x  - a)\|- a c  + 2a c x
+--R         log(---------------------------)
+--R                          2
+--R                       c x  + a
+--R     + 
+--R                2 4       2   3            2 2           3        2 4  +-----+
+--R         (- 2A a e  - 8B a d e  + 12A a c d e  + 8B a c d e - 2A c d )\|- a c
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R  /
+--R       2 +-----+ +-+ +-+
+--R     2c \|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1285
+
+--S 1286 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1286
+
+--S 1287 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             2 4       2   3           2 2           3       2 4  +-+ +-+
+--R         (A a e  + 4B a d e  - 6A a c d e  - 4B a c d e + A c d )\|a \|c
+--R      *
+--R                +---+
+--R              x\|a c
+--R         atan(-------)
+--R                 a
+--R     + 
+--R                                                                            +-+
+--R           2 4       2   3           2 2           3       2 4  +---+     x\|c
+--R     (- A a e  - 4B a d e  + 6A a c d e  + 4B a c d e - A c d )\|a c atan(-----)
+--R                                                                            +-+
+--R                                                                           \|a
+--R  /
+--R      2 +-+ +-+ +---+
+--R     c \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1287
+
+--S 1288 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1288
+
+)clear all
+
+--S 1289 of 1457
+t0:=(A+B*x)*(d+e*x)^3/(a+c*x^2)
+--R 
+--R
+--R   (1)
+--R      3 4       3         2  3          2       2   2        2       3        3
+--R   B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x + A d
+--R   ----------------------------------------------------------------------------
+--R                                        2
+--R                                     c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1289
+
+--S 1290 of 1457
+r0:=e*(3*B*c*d^2+3*A*c*d*e-a*B*e^2)*x/c^2+1/2*e^2*(3*B*d+A*e)*x^2/c+_
+     1/3*B*e^3*x^3/c+1/2*(B*c*d^3+3*A*c*d^2*e-3*a*B*d*e^2-a*A*e^3)*_
+     log(a+c*x^2)/c^2+(A*c*d*(c*d^2-3*a*e^2)-a*B*e*(3*c*d^2-a*e^2))*_
+     atan(x*sqrt(c)/sqrt(a))/(c^(5/2)*sqrt(a))
+--R 
+--R
+--R   (2)
+--R                                                              +-+
+--R            2 3              2            2        2 3      x\|c
+--R       (6B a e  - 18A a c d e  - 18B a c d e + 6A c d )atan(-----)
+--R                                                              +-+
+--R                                                             \|a
+--R     + 
+--R                    3           2         2          3        2              3 3
+--R           (- 3A a e  - 9B a d e  + 9A c d e + 3B c d )log(c x  + a) + 2B c e x
+--R         + 
+--R                  3           2  2            3            2          2
+--R           (3A c e  + 9B c d e )x  + (- 6B a e  + 18A c d e  + 18B c d e)x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R       2 +-+ +-+
+--R     6c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1290
+
+--S 1291 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3             2           2        2 3
+--R           (3B a e  - 9A a c d e  - 9B a c d e + 3A c d )
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                      3           2         2          3        2
+--R             (- 3A a e  - 9B a d e  + 9A c d e + 3B c d )log(c x  + a)
+--R           + 
+--R                   3 3          3           2  2
+--R             2B c e x  + (3A c e  + 9B c d e )x
+--R           + 
+--R                      3            2          2
+--R             (- 6B a e  + 18A c d e  + 18B c d e)x
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R         2 +-----+
+--R       6c \|- a c
+--R     ,
+--R
+--R                                                                +---+
+--R              2 3              2            2        2 3      x\|a c
+--R         (6B a e  - 18A a c d e  - 18B a c d e + 6A c d )atan(-------)
+--R                                                                 a
+--R       + 
+--R                      3           2         2          3        2
+--R             (- 3A a e  - 9B a d e  + 9A c d e + 3B c d )log(c x  + a)
+--R           + 
+--R                   3 3          3           2  2
+--R             2B c e x  + (3A c e  + 9B c d e )x
+--R           + 
+--R                      3            2          2
+--R             (- 6B a e  + 18A c d e  + 18B c d e)x
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R         2 +---+
+--R       6c \|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1291
+
+--S 1292 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2 3             2           2       2 3  +-+ +-+
+--R         (B a e  - 3A a c d e  - 3B a c d e + A c d )\|a \|c
+--R      *
+--R                 2      +-----+
+--R             (c x  - a)\|- a c  + 2a c x
+--R         log(---------------------------)
+--R                          2
+--R                       c x  + a
+--R     + 
+--R                                                                      +-+
+--R              2 3             2           2        2 3  +-----+     x\|c
+--R       (- 2B a e  + 6A a c d e  + 6B a c d e - 2A c d )\|- a c atan(-----)
+--R                                                                      +-+
+--R                                                                     \|a
+--R  /
+--R       2 +-----+ +-+ +-+
+--R     2c \|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1292
+
+--S 1293 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1293
+
+--S 1294 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                  +---+
+--R           2 3             2           2       2 3  +-+ +-+     x\|a c
+--R       (B a e  - 3A a c d e  - 3B a c d e + A c d )\|a \|c atan(-------)
+--R                                                                   a
+--R     + 
+--R                                                                  +-+
+--R             2 3             2           2       2 3  +---+     x\|c
+--R       (- B a e  + 3A a c d e  + 3B a c d e - A c d )\|a c atan(-----)
+--R                                                                  +-+
+--R                                                                 \|a
+--R  /
+--R      2 +-+ +-+ +---+
+--R     c \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1294
+
+--S 1295 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1295
+
+)clear all
+
+--S 1296 of 1457
+t0:=(A+B*x)*(d+e*x)^2/(a+c*x^2)
+--R 
+--R
+--R           2 3       2           2                2        2
+--R        B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d
+--R   (1)  ----------------------------------------------------
+--R                                 2
+--R                              c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1296
+
+--S 1297 of 1457
+r0:=e*(2*B*d+A*e)*x/c+1/2*B*e^2*x^2/c+1/2*(B*c*d^2+2*A*c*d*e-a*B*e^2)*_
+     log(a+c*x^2)/c^2+(A*c*d^2-2*a*B*d*e-a*A*e^2)*atan(x*sqrt(c)/_
+     sqrt(a))/(c^(3/2)*sqrt(a))
+--R 
+--R
+--R   (2)
+--R                                                  +-+
+--R                  2                    2 2      x\|c
+--R       (- 2A a c e  - 4B a c d e + 2A c d )atan(-----)
+--R                                                  +-+
+--R                                                 \|a
+--R     + 
+--R                   2                   2        2             2 2
+--R           (- B a e  + 2A c d e + B c d )log(c x  + a) + B c e x
+--R         + 
+--R                  2
+--R           (2A c e  + 4B c d e)x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R       2 +-+ +-+
+--R     2c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1297
+
+--S 1298 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                 2      +-----+
+--R                 2                   2 2     (c x  - a)\|- a c  - 2a c x
+--R         (A a c e  + 2B a c d e - A c d )log(---------------------------)
+--R                                                          2
+--R                                                       c x  + a
+--R       + 
+--R                     2                   2        2             2 2
+--R             (- B a e  + 2A c d e + B c d )log(c x  + a) + B c e x
+--R           + 
+--R                    2
+--R             (2A c e  + 4B c d e)x
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R         2 +-----+
+--R       2c \|- a c
+--R     ,
+--R
+--R                                                    +---+
+--R                    2                    2 2      x\|a c
+--R         (- 2A a c e  - 4B a c d e + 2A c d )atan(-------)
+--R                                                     a
+--R       + 
+--R                     2                   2        2             2 2
+--R             (- B a e  + 2A c d e + B c d )log(c x  + a) + B c e x
+--R           + 
+--R                    2
+--R             (2A c e  + 4B c d e)x
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R         2 +---+
+--R       2c \|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1298
+
+--S 1299 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                   2      +-----+
+--R             2                   2  +-+ +-+    (c x  - a)\|- a c  - 2a c x
+--R       (A a e  + 2B a d e - A c d )\|a \|c log(---------------------------)
+--R                                                            2
+--R                                                         c x  + a
+--R     + 
+--R                                                    +-+
+--R              2                    2  +-----+     x\|c
+--R       (2A a e  + 4B a d e - 2A c d )\|- a c atan(-----)
+--R                                                    +-+
+--R                                                   \|a
+--R  /
+--R        +-----+ +-+ +-+
+--R     2c\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1299
+
+--S 1300 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1300
+
+--S 1301 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                    +---+
+--R               2                   2  +-+ +-+     x\|a c
+--R       (- A a e  - 2B a d e + A c d )\|a \|c atan(-------)
+--R                                                     a
+--R     + 
+--R                                                +-+
+--R             2                   2  +---+     x\|c
+--R       (A a e  + 2B a d e - A c d )\|a c atan(-----)
+--R                                                +-+
+--R                                               \|a
+--R  /
+--R       +-+ +-+ +---+
+--R     c\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1301
+
+--S 1302 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1302
+
+)clear all
+
+--S 1303 of 1457
+t0:=(A+B*x)*(d+e*x)/(a+c*x^2)
+--R 
+--R
+--R             2
+--R        B e x  + (A e + B d)x + A d
+--R   (1)  ---------------------------
+--R                     2
+--R                  c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1303
+
+--S 1304 of 1457
+r0:=B*e*x/c+1/2*(B*d+A*e)*log(a+c*x^2)/c+(A*c*d-a*B*e)*atan(x*sqrt(c)/_
+     sqrt(a))/(c^(3/2)*sqrt(a))
+--R 
+--R
+--R   (2)
+--R                             +-+
+--R                           x\|c                        2                +-+ +-+
+--R   (- 2B a e + 2A c d)atan(-----) + ((A e + B d)log(c x  + a) + 2B e x)\|a \|c
+--R                             +-+
+--R                            \|a
+--R   ----------------------------------------------------------------------------
+--R                                       +-+ +-+
+--R                                    2c\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1304
+
+--S 1305 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                2      +-----+
+--R                            (c x  - a)\|- a c  - 2a c x
+--R         (B a e - A c d)log(---------------------------)
+--R                                         2
+--R                                      c x  + a
+--R       + 
+--R                            2                +-----+
+--R         ((A e + B d)log(c x  + a) + 2B e x)\|- a c
+--R    /
+--R          +-----+
+--R       2c\|- a c
+--R     ,
+--R                              +---+
+--R                            x\|a c                        2                +---+
+--R    (- 2B a e + 2A c d)atan(-------) + ((A e + B d)log(c x  + a) + 2B e x)\|a c
+--R                               a
+--R    ----------------------------------------------------------------------------
+--R                                         +---+
+--R                                      2c\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1305
+
+--S 1306 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                      2      +-----+
+--R                       +-+ +-+    (c x  - a)\|- a c  - 2a c x
+--R       (B a e - A c d)\|a \|c log(---------------------------)
+--R                                               2
+--R                                            c x  + a
+--R     + 
+--R                                       +-+
+--R                         +-----+     x\|c
+--R       (2B a e - 2A c d)\|- a c atan(-----)
+--R                                       +-+
+--R                                      \|a
+--R  /
+--R        +-----+ +-+ +-+
+--R     2c\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1306
+
+--S 1307 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1307
+
+--S 1308 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                   +---+                                +-+
+--R                     +-+ +-+     x\|a c                     +---+     x\|c
+--R   (- B a e + A c d)\|a \|c atan(-------) + (B a e - A c d)\|a c atan(-----)
+--R                                    a                                   +-+
+--R                                                                       \|a
+--R   -------------------------------------------------------------------------
+--R                                  +-+ +-+ +---+
+--R                                c\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1308
+
+--S 1309 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1309
+
+)clear all
+
+--S 1310 of 1457
+t0:=(A+B*x)/(a+c*x^2)
+--R 
+--R
+--R         B x + A
+--R   (1)  --------
+--R           2
+--R        c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1310
+
+--S 1311 of 1457
+r0:=1/2*B*log(a+c*x^2)/c+A*atan(x*sqrt(c)/sqrt(a))/(sqrt(a)*sqrt(c))
+--R 
+--R
+--R                    +-+
+--R                  x\|c              2      +-+ +-+
+--R        2A c atan(-----) + B log(c x  + a)\|a \|c
+--R                    +-+
+--R                   \|a
+--R   (2)  ------------------------------------------
+--R                           +-+ +-+
+--R                        2c\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1311
+
+--S 1312 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2      +-----+
+--R            (c x  - a)\|- a c  + 2a c x             2      +-----+
+--R    A c log(---------------------------) + B log(c x  + a)\|- a c
+--R                         2
+--R                      c x  + a
+--R   [--------------------------------------------------------------,
+--R                                 +-----+
+--R                              2c\|- a c
+--R                +---+
+--R              x\|a c              2      +---+
+--R    2A c atan(-------) + B log(c x  + a)\|a c
+--R                 a
+--R    ------------------------------------------]
+--R                        +---+
+--R                     2c\|a c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1312
+
+--S 1313 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R                         2      +-----+                              +-+
+--R          +-+ +-+    (c x  - a)\|- a c  + 2a c x       +-----+     x\|c
+--R        A\|a \|c log(---------------------------) - 2A\|- a c atan(-----)
+--R                                  2                                  +-+
+--R                               c x  + a                             \|a
+--R   (4)  -----------------------------------------------------------------
+--R                                  +-----+ +-+ +-+
+--R                                2\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1313
+
+--S 1314 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1314
+
+--S 1315 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+                  +-+
+--R          +-+ +-+     x\|a c       +---+     x\|c
+--R        A\|a \|c atan(-------) - A\|a c atan(-----)
+--R                         a                     +-+
+--R                                              \|a
+--R   (6)  -------------------------------------------
+--R                        +-+ +-+ +---+
+--R                       \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1315
+
+--S 1316 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1316
+
+)clear all
+
+--S 1317 of 1457
+t0:=(A+B*x)/((d+e*x)*(a+c*x^2))
+--R 
+--R
+--R                   B x + A
+--R   (1)  -----------------------------
+--R             3        2
+--R        c e x  + c d x  + a e x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1317
+
+--S 1318 of 1457
+r0:=-(B*d-A*e)*log(d+e*x)/(c*d^2+a*e^2)+1/2*(B*d-A*e)*log(a+c*x^2)/_
+     (c*d^2+a*e^2)+(A*c*d+a*B*e)*atan(x*sqrt(c)/sqrt(a))/((c*d^2+a*e^2)*_
+     sqrt(a)*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                               +-+
+--R                             x\|c
+--R       (2B a e + 2A c d)atan(-----)
+--R                               +-+
+--R                              \|a
+--R     + 
+--R                            2                                   +-+ +-+
+--R       ((- A e + B d)log(c x  + a) + (2A e - 2B d)log(e x + d))\|a \|c
+--R  /
+--R          2       2  +-+ +-+
+--R     (2a e  + 2c d )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1318
+
+--S 1319 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                2      +-----+
+--R                            (c x  - a)\|- a c  + 2a c x
+--R         (B a e + A c d)log(---------------------------)
+--R                                         2
+--R                                      c x  + a
+--R       + 
+--R                              2                                   +-----+
+--R         ((- A e + B d)log(c x  + a) + (2A e - 2B d)log(e x + d))\|- a c
+--R    /
+--R            2       2  +-----+
+--R       (2a e  + 2c d )\|- a c
+--R     ,
+--R
+--R                                 +---+
+--R                               x\|a c
+--R         (2B a e + 2A c d)atan(-------)
+--R                                  a
+--R       + 
+--R                              2                                   +---+
+--R         ((- A e + B d)log(c x  + a) + (2A e - 2B d)log(e x + d))\|a c
+--R    /
+--R            2       2  +---+
+--R       (2a e  + 2c d )\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1319
+
+--S 1320 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                      2      +-----+
+--R                       +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R       (B a e + A c d)\|a \|c log(---------------------------)
+--R                                               2
+--R                                            c x  + a
+--R     + 
+--R                                         +-+
+--R                           +-----+     x\|c
+--R       (- 2B a e - 2A c d)\|- a c atan(-----)
+--R                                         +-+
+--R                                        \|a
+--R  /
+--R          2       2  +-----+ +-+ +-+
+--R     (2a e  + 2c d )\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1320
+
+--S 1321 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1321
+
+--S 1322 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                 +---+                                  +-+
+--R                   +-+ +-+     x\|a c                       +---+     x\|c
+--R   (B a e + A c d)\|a \|c atan(-------) + (- B a e - A c d)\|a c atan(-----)
+--R                                  a                                     +-+
+--R                                                                       \|a
+--R   -------------------------------------------------------------------------
+--R                              2      2  +-+ +-+ +---+
+--R                          (a e  + c d )\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1322
+
+--S 1323 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1323
+
+)clear all
+
+--S 1324 of 1457
+t0:=(A+B*x)/((d+e*x)^2*(a+c*x^2))
+--R 
+--R
+--R                                B x + A
+--R   (1)  ------------------------------------------------------
+--R           2 4           3       2      2  2                 2
+--R        c e x  + 2c d e x  + (a e  + c d )x  + 2a d e x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1324
+
+--S 1325 of 1457
+r0:=(B*d-A*e)/((c*d^2+a*e^2)*(d+e*x))-(B*c*d^2-2*A*c*d*e-a*B*e^2)*_
+     log(d+e*x)/(c*d^2+a*e^2)^2+1/2*(B*c*d^2-2*A*c*d*e-a*B*e^2)*_
+     log(a+c*x^2)/(c*d^2+a*e^2)^2+(A*c*d^2+2*a*B*d*e-a*A*e^2)*_
+     atan(x*sqrt(c)/sqrt(a))*sqrt(c)/((c*d^2+a*e^2)^2*sqrt(a))
+--R 
+--R
+--R   (2)
+--R                   3           2         2              2         2          3
+--R         ((- 2A a e  + 4B a d e  + 2A c d e)x - 2A a d e  + 4B a d e + 2A c d )
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|c atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                      3           2        2             2         2         3
+--R             ((- B a e  - 2A c d e  + B c d e)x - B a d e  - 2A c d e + B c d )
+--R          *
+--R                    2
+--R             log(c x  + a)
+--R         + 
+--R                        3           2         2              2         2
+--R                 (2B a e  + 4A c d e  - 2B c d e)x + 2B a d e  + 4A c d e
+--R               + 
+--R                         3
+--R                 - 2B c d
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                   3           2         2          3
+--R           - 2A a e  + 2B a d e  - 2A c d e + 2B c d
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R         2 5         2 3     2 4        2   4         3 2     2 5  +-+
+--R     ((2a e  + 4a c d e  + 2c d e)x + 2a d e  + 4a c d e  + 2c d )\|a
+--R                                                    Type: Expression(Integer)
+--E 1325
+
+--S 1326 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3           2        2             2         2         3
+--R           ((A a e  - 2B a d e  - A c d e)x + A a d e  - 2B a d e - A c d )
+--R        *
+--R                            +---+
+--R                            |  c       2
+--R            +---+    - 2a x |- -  + c x  - a
+--R            |  c           \|  a
+--R            |- - log(-----------------------)
+--R           \|  a                2
+--R                             c x  + a
+--R       + 
+--R                    3           2        2             2         2         3
+--R           ((- B a e  - 2A c d e  + B c d e)x - B a d e  - 2A c d e + B c d )
+--R        *
+--R                  2
+--R           log(c x  + a)
+--R       + 
+--R                   3           2         2              2         2          3
+--R           ((2B a e  + 4A c d e  - 2B c d e)x + 2B a d e  + 4A c d e - 2B c d )
+--R        *
+--R           log(e x + d)
+--R       + 
+--R                 3           2         2          3
+--R         - 2A a e  + 2B a d e  - 2A c d e + 2B c d
+--R    /
+--R          2 5         2 3     2 4        2   4         3 2     2 5
+--R       (2a e  + 4a c d e  + 2c d e)x + 2a d e  + 4a c d e  + 2c d
+--R     ,
+--R
+--R                   3           2         2              2         2          3
+--R           ((2A a e  - 4B a d e  - 2A c d e)x + 2A a d e  - 4B a d e - 2A c d )
+--R        *
+--R                      +-+
+--R                      |c
+--R            +-+     a |-
+--R            |c       \|a
+--R            |- atan(-----)
+--R           \|a       c x
+--R       + 
+--R                    3           2        2             2         2         3
+--R           ((- B a e  - 2A c d e  + B c d e)x - B a d e  - 2A c d e + B c d )
+--R        *
+--R                  2
+--R           log(c x  + a)
+--R       + 
+--R                   3           2         2              2         2          3
+--R           ((2B a e  + 4A c d e  - 2B c d e)x + 2B a d e  + 4A c d e - 2B c d )
+--R        *
+--R           log(e x + d)
+--R       + 
+--R                 3           2         2          3
+--R         - 2A a e  + 2B a d e  - 2A c d e + 2B c d
+--R    /
+--R          2 5         2 3     2 4        2   4         3 2     2 5
+--R       (2a e  + 4a c d e  + 2c d e)x + 2a d e  + 4a c d e  + 2c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1326
+
+--S 1327 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                        +---+
+--R                                                        |  c       2
+--R                                    +---+        - 2a x |- -  + c x  - a
+--R             2                   2  |  c  +-+          \|  a
+--R       (A a e  - 2B a d e - A c d ) |- - \|a log(-----------------------)
+--R                                   \|  a                    2
+--R                                                         c x  + a
+--R     + 
+--R                                                +-+
+--R              2                    2  +-+     x\|c
+--R       (2A a e  - 4B a d e - 2A c d )\|c atan(-----)
+--R                                                +-+
+--R                                               \|a
+--R  /
+--R        2 4         2 2     2 4  +-+
+--R     (2a e  + 4a c d e  + 2c d )\|a
+--R                                                    Type: Expression(Integer)
+--E 1327
+
+--S 1328 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1328
+
+--S 1329 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                              +-+
+--R             2                   2  +-+     x\|c
+--R       (A a e  - 2B a d e - A c d )\|c atan(-----)
+--R                                              +-+
+--R                                             \|a
+--R     + 
+--R                                                  +-+
+--R                                                  |c
+--R                                        +-+     a |-
+--R             2                   2  +-+ |c       \|a
+--R       (A a e  - 2B a d e - A c d )\|a  |- atan(-----)
+--R                                       \|a       c x
+--R  /
+--R       2 4         2 2    2 4  +-+
+--R     (a e  + 2a c d e  + c d )\|a
+--R                                                    Type: Expression(Integer)
+--E 1329
+
+--S 1330 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1330
+
+)clear all
+
+--S 1331 of 1457
+t0:=(A+B*x)/((d+e*x)^3*(a+c*x^2))
+--R 
+--R
+--R   (1)
+--R                                      B x + A
+--R   -----------------------------------------------------------------------------
+--R      3 5         2 4       3       2   3          2      3  2       2         3
+--R   c e x  + 3c d e x  + (a e  + 3c d e)x  + (3a d e  + c d )x  + 3a d e x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1331
+
+--S 1332 of 1457
+r0:=1/2*(B*d-A*e)/((c*d^2+a*e^2)*(d+e*x)^2)+(B*c*d^2-2*A*c*d*e-a*B*e^2)/_
+     ((c*d^2+a*e^2)^2*(d+e*x))-c*(B*c*d^3-3*A*c*d^2*e-3*a*B*d*e^2+_
+     a*A*e^3)*log(d+e*x)/(c*d^2+a*e^2)^3+1/2*c*(B*c*d^3-3*A*c*d^2*e-_
+     3*a*B*d*e^2+a*A*e^3)*log(a+c*x^2)/(c*d^2+a*e^2)^3+(A*c*d*(c*d^2-_
+     3*a*e^2)+a*B*e*(3*c*d^2-a*e^2))*atan(x*sqrt(c)/sqrt(a))*sqrt(c)/_
+     ((c*d^2+a*e^2)^3*sqrt(a))
+--R 
+--R
+--R   (2)
+--R                  2 5             4           2 3       2 3 2  2
+--R           (- 2B a e  - 6A a c d e  + 6B a c d e  + 2A c d e )x
+--R         + 
+--R                  2   4            2 3            3 2       2 4          2 2 3
+--R           (- 4B a d e  - 12A a c d e  + 12B a c d e  + 4A c d e)x - 2B a d e
+--R         + 
+--R                     3 2           4        2 5
+--R           - 6A a c d e  + 6B a c d e + 2A c d
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|c atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                       5             4       2 2 3      2 3 2  2
+--R               (A a c e  - 3B a c d e  - 3A c d e  + B c d e )x
+--R             + 
+--R                          4           2 3       2 3 2       2 4             2 3
+--R               (2A a c d e  - 6B a c d e  - 6A c d e  + 2B c d e)x + A a c d e
+--R             + 
+--R                         3 2       2 4       2 5
+--R               - 3B a c d e  - 3A c d e + B c d
+--R          *
+--R                    2
+--R             log(c x  + a)
+--R         + 
+--R                          5             4       2 2 3       2 3 2  2
+--R               (- 2A a c e  + 6B a c d e  + 6A c d e  - 2B c d e )x
+--R             + 
+--R                            4            2 3        2 3 2       2 4
+--R               (- 4A a c d e  + 12B a c d e  + 12A c d e  - 4B c d e)x
+--R             + 
+--R                         2 3           3 2       2 4        2 5
+--R               - 2A a c d e  + 6B a c d e  + 6A c d e - 2B c d
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                  2 5             4       2 3 2       2 4         2 5      2   4
+--R           (- 2B a e  - 4A a c d e  - 4A c d e  + 2B c d e)x - A a e  - B a d e
+--R         + 
+--R                     2 3           3 2       2 4        2 5
+--R           - 6A a c d e  + 2B a c d e  - 5A c d e + 3B c d
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R            3 8     2   2 6       2 4 4     3 6 2  2
+--R         (2a e  + 6a c d e  + 6a c d e  + 2c d e )x
+--R       + 
+--R            3   7      2   3 5        2 5 3     3 7        3 2 6     2   4 4
+--R         (4a d e  + 12a c d e  + 12a c d e  + 4c d e)x + 2a d e  + 6a c d e
+--R       + 
+--R             2 6 2     3 8
+--R         6a c d e  + 2c d
+--R    *
+--R        +-+
+--R       \|a
+--R                                                    Type: Expression(Integer)
+--E 1332
+
+--S 1333 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2 5             4           2 3      2 3 2  2
+--R             (B a e  + 3A a c d e  - 3B a c d e  - A c d e )x
+--R           + 
+--R                  2   4           2 3           3 2       2 4         2 2 3
+--R             (2B a d e  + 6A a c d e  - 6B a c d e  - 2A c d e)x + B a d e
+--R           + 
+--R                     3 2           4       2 5
+--R             3A a c d e  - 3B a c d e - A c d
+--R        *
+--R                            +---+
+--R                            |  c       2
+--R            +---+    - 2a x |- -  + c x  - a
+--R            |  c           \|  a
+--R            |- - log(-----------------------)
+--R           \|  a                2
+--R                             c x  + a
+--R       + 
+--R                     5             4       2 2 3      2 3 2  2
+--R             (A a c e  - 3B a c d e  - 3A c d e  + B c d e )x
+--R           + 
+--R                        4           2 3       2 3 2       2 4             2 3
+--R             (2A a c d e  - 6B a c d e  - 6A c d e  + 2B c d e)x + A a c d e
+--R           + 
+--R                       3 2       2 4       2 5
+--R             - 3B a c d e  - 3A c d e + B c d
+--R        *
+--R                  2
+--R           log(c x  + a)
+--R       + 
+--R                        5             4       2 2 3       2 3 2  2
+--R             (- 2A a c e  + 6B a c d e  + 6A c d e  - 2B c d e )x
+--R           + 
+--R                          4            2 3        2 3 2       2 4
+--R             (- 4A a c d e  + 12B a c d e  + 12A c d e  - 4B c d e)x
+--R           + 
+--R                       2 3           3 2       2 4        2 5
+--R             - 2A a c d e  + 6B a c d e  + 6A c d e - 2B c d
+--R        *
+--R           log(e x + d)
+--R       + 
+--R                2 5             4       2 3 2       2 4         2 5      2   4
+--R         (- 2B a e  - 4A a c d e  - 4A c d e  + 2B c d e)x - A a e  - B a d e
+--R       + 
+--R                   2 3           3 2       2 4        2 5
+--R         - 6A a c d e  + 2B a c d e  - 5A c d e + 3B c d
+--R    /
+--R            3 8     2   2 6       2 4 4     3 6 2  2
+--R         (2a e  + 6a c d e  + 6a c d e  + 2c d e )x
+--R       + 
+--R            3   7      2   3 5        2 5 3     3 7        3 2 6     2   4 4
+--R         (4a d e  + 12a c d e  + 12a c d e  + 4c d e)x + 2a d e  + 6a c d e
+--R       + 
+--R             2 6 2     3 8
+--R         6a c d e  + 2c d
+--R     ,
+--R
+--R                  2 5             4           2 3       2 3 2  2
+--R             (2B a e  + 6A a c d e  - 6B a c d e  - 2A c d e )x
+--R           + 
+--R                  2   4            2 3            3 2       2 4          2 2 3
+--R             (4B a d e  + 12A a c d e  - 12B a c d e  - 4A c d e)x + 2B a d e
+--R           + 
+--R                     3 2           4        2 5
+--R             6A a c d e  - 6B a c d e - 2A c d
+--R        *
+--R                      +-+
+--R                      |c
+--R            +-+     a |-
+--R            |c       \|a
+--R            |- atan(-----)
+--R           \|a       c x
+--R       + 
+--R                     5             4       2 2 3      2 3 2  2
+--R             (A a c e  - 3B a c d e  - 3A c d e  + B c d e )x
+--R           + 
+--R                        4           2 3       2 3 2       2 4             2 3
+--R             (2A a c d e  - 6B a c d e  - 6A c d e  + 2B c d e)x + A a c d e
+--R           + 
+--R                       3 2       2 4       2 5
+--R             - 3B a c d e  - 3A c d e + B c d
+--R        *
+--R                  2
+--R           log(c x  + a)
+--R       + 
+--R                        5             4       2 2 3       2 3 2  2
+--R             (- 2A a c e  + 6B a c d e  + 6A c d e  - 2B c d e )x
+--R           + 
+--R                          4            2 3        2 3 2       2 4
+--R             (- 4A a c d e  + 12B a c d e  + 12A c d e  - 4B c d e)x
+--R           + 
+--R                       2 3           3 2       2 4        2 5
+--R             - 2A a c d e  + 6B a c d e  + 6A c d e - 2B c d
+--R        *
+--R           log(e x + d)
+--R       + 
+--R                2 5             4       2 3 2       2 4         2 5      2   4
+--R         (- 2B a e  - 4A a c d e  - 4A c d e  + 2B c d e)x - A a e  - B a d e
+--R       + 
+--R                   2 3           3 2       2 4        2 5
+--R         - 6A a c d e  + 2B a c d e  - 5A c d e + 3B c d
+--R    /
+--R            3 8     2   2 6       2 4 4     3 6 2  2
+--R         (2a e  + 6a c d e  + 6a c d e  + 2c d e )x
+--R       + 
+--R            3   7      2   3 5        2 5 3     3 7        3 2 6     2   4 4
+--R         (4a d e  + 12a c d e  + 12a c d e  + 4c d e)x + 2a d e  + 6a c d e
+--R       + 
+--R             2 6 2     3 8
+--R         6a c d e  + 2c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1333
+
+--S 1334 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                      +---+
+--R             2 3             2           2       2 3  |  c  +-+
+--R         (B a e  + 3A a c d e  - 3B a c d e - A c d ) |- - \|a
+--R                                                     \|  a
+--R      *
+--R                    +---+
+--R                    |  c       2
+--R             - 2a x |- -  + c x  - a
+--R                   \|  a
+--R         log(-----------------------)
+--R                        2
+--R                     c x  + a
+--R     + 
+--R                                                                +-+
+--R            2 3             2           2        2 3  +-+     x\|c
+--R       (2B a e  + 6A a c d e  - 6B a c d e - 2A c d )\|c atan(-----)
+--R                                                                +-+
+--R                                                               \|a
+--R  /
+--R        3 6     2   2 4       2 4 2     3 6  +-+
+--R     (2a e  + 6a c d e  + 6a c d e  + 2c d )\|a
+--R                                                    Type: Expression(Integer)
+--E 1334
+
+--S 1335 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1335
+
+--S 1336 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                              +-+
+--R           2 3             2           2       2 3  +-+     x\|c
+--R       (B a e  + 3A a c d e  - 3B a c d e - A c d )\|c atan(-----)
+--R                                                              +-+
+--R                                                             \|a
+--R     + 
+--R                                                                  +-+
+--R                                                                  |c
+--R                                                        +-+     a |-
+--R           2 3             2           2       2 3  +-+ |c       \|a
+--R       (B a e  + 3A a c d e  - 3B a c d e - A c d )\|a  |- atan(-----)
+--R                                                       \|a       c x
+--R  /
+--R       3 6     2   2 4       2 4 2    3 6  +-+
+--R     (a e  + 3a c d e  + 3a c d e  + c d )\|a
+--R                                                    Type: Expression(Integer)
+--E 1336
+
+--S 1337 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1337
+
+)clear all
+
+--S 1338 of 1457
+t0:=(A+B*x)*(d+e*x)^5/(a+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R          5 6       5         4  5          4        2 3  4
+--R       B e x  + (A e  + 5B d e )x  + (5A d e  + 10B d e )x
+--R     + 
+--R           2 3        3 2  3         3 2       4   2        4       5        5
+--R     (10A d e  + 10B d e )x  + (10A d e  + 5B d e)x  + (5A d e + B d )x + A d
+--R  /
+--R      2 4         2    2
+--R     c x  + 2a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1338
+
+--S 1339 of 1457
+r0:=-5/2*e^2*(A*c*d*(2*c*d^2-3*a*e^2)-a*B*e*(6*c*d^2-a*e^2))*x/(a*c^3)-_
+     e^3*(5*A*c*d^2-5*a*B*d*e-a*A*e^2)*x^2/(a*c^2)-5/6*e^4*(3*A*c*d-a*B*e)*_
+     x^3/(a*c^2)-1/2*A*e^5*x^4/(a*c)-1/2*(a*B-A*c*x)*(d+e*x)^5/(a*c*_
+     (a+c*x^2))+1/2*(A*c*d*(c^2*d^4+10*a*c*d^2*e^2-15*a^2*e^4)+5*a*B*_
+     e*(c^2*d^4-6*a*c*d^2*e^2+a^2*e^4))*atan(x*sqrt(c)/sqrt(a))/_
+     (a^(3/2)*c^(7/2))+e^2*(5*B*c*d^3+5*A*c*d^2*e-5*a*B*d*e^2-a*A*e^3)*_
+     log(a+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                    3   5        2 2   4        2 2 2 3          3 3 2
+--R               15B a c e  - 45A a c d e  - 90B a c d e  + 30A a c d e
+--R             + 
+--R                      3 4        4 5
+--R               15B a c d e + 3A c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                4 5        3     4        3   2 3        2 2 3 2        2 2 4
+--R           15B a e  - 45A a c d e  - 90B a c d e  + 30A a c d e  + 15B a c d e
+--R         + 
+--R                 3 5
+--R           3A a c d
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                      2   5        2     4          2 2 3          2 3 2  2
+--R               (- 6A a c e  - 30B a c d e  + 30A a c d e  + 30B a c d e )x
+--R             + 
+--R                     3 5        3   4        2   2 3        2   3 2
+--R               - 6A a e  - 30B a d e  + 30A a c d e  + 30B a c d e
+--R          *
+--R                    2
+--R             log(c x  + a)
+--R         + 
+--R                 2 5 5          2 5          2   4  4
+--R           2B a c e x  + (3A a c e  + 15B a c d e )x
+--R         + 
+--R                   2   5          2   4          2 2 3  3
+--R           (- 10B a c e  + 30A a c d e  + 60B a c d e )x
+--R         + 
+--R                     2   5        2     4          2 2 3          2 3 2
+--R                 6A a c e  + 30B a c d e  - 30A a c d e  - 30B a c d e
+--R               + 
+--R                      3 4
+--R                 15A c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3 5        2     4        2   2 3          2 3 2
+--R               - 15B a e  + 45A a c d e  + 90B a c d e  - 30A a c d e
+--R             + 
+--R                        2 4        3 5
+--R               - 15B a c d e + 3A c d
+--R          *
+--R             x
+--R         + 
+--R                   2 5
+--R           - 3B a c d
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R          4 2     2 3  +-+ +-+
+--R     (6a c x  + 6a c )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1339
+
+--S 1340 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3   5        2 2   4        2 2 2 3          3 3 2
+--R                 15B a c e  - 45A a c d e  - 90B a c d e  + 30A a c d e
+--R               + 
+--R                        3 4        4 5
+--R                 15B a c d e + 3A c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                  4 5        3     4        3   2 3        2 2 3 2        2 2 4
+--R             15B a e  - 45A a c d e  - 90B a c d e  + 30A a c d e  + 15B a c d e
+--R           + 
+--R                   3 5
+--R             3A a c d
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                         2   5        2     4          2 2 3          2 3 2  2
+--R                 (- 12A a c e  - 60B a c d e  + 60A a c d e  + 60B a c d e )x
+--R               + 
+--R                        3 5        3   4        2   2 3        2   3 2
+--R                 - 12A a e  - 60B a d e  + 60A a c d e  + 60B a c d e
+--R            *
+--R                      2
+--R               log(c x  + a)
+--R           + 
+--R                   2 5 5          2 5          2   4  4
+--R             4B a c e x  + (6A a c e  + 30B a c d e )x
+--R           + 
+--R                     2   5          2   4           2 2 3  3
+--R             (- 20B a c e  + 60A a c d e  + 120B a c d e )x
+--R           + 
+--R                  2   5        2     4  2
+--R             (6A a c e  + 30B a c d e )x
+--R           + 
+--R                        3 5        2     4         2   2 3          2 3 2
+--R                 - 30B a e  + 90A a c d e  + 180B a c d e  - 60A a c d e
+--R               + 
+--R                          2 4        3 5
+--R                 - 30B a c d e + 6A c d
+--R            *
+--R               x
+--R           + 
+--R                   3 5        3   4        2   2 3        2   3 2          2 4
+--R             - 6A a e  - 30B a d e  + 60A a c d e  + 60B a c d e  - 30A a c d e
+--R           + 
+--R                     2 5
+--R             - 6B a c d
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R             4 2      2 3  +-----+
+--R       (12a c x  + 12a c )\|- a c
+--R     ,
+--R
+--R                      3   5        2 2   4        2 2 2 3          3 3 2
+--R                 15B a c e  - 45A a c d e  - 90B a c d e  + 30A a c d e
+--R               + 
+--R                        3 4        4 5
+--R                 15B a c d e + 3A c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                  4 5        3     4        3   2 3        2 2 3 2        2 2 4
+--R             15B a e  - 45A a c d e  - 90B a c d e  + 30A a c d e  + 15B a c d e
+--R           + 
+--R                   3 5
+--R             3A a c d
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                        2   5        2     4          2 2 3          2 3 2  2
+--R                 (- 6A a c e  - 30B a c d e  + 30A a c d e  + 30B a c d e )x
+--R               + 
+--R                       3 5        3   4        2   2 3        2   3 2
+--R                 - 6A a e  - 30B a d e  + 30A a c d e  + 30B a c d e
+--R            *
+--R                      2
+--R               log(c x  + a)
+--R           + 
+--R                   2 5 5          2 5          2   4  4
+--R             2B a c e x  + (3A a c e  + 15B a c d e )x
+--R           + 
+--R                     2   5          2   4          2 2 3  3
+--R             (- 10B a c e  + 30A a c d e  + 60B a c d e )x
+--R           + 
+--R                  2   5        2     4  2
+--R             (3A a c e  + 15B a c d e )x
+--R           + 
+--R                        3 5        2     4        2   2 3          2 3 2
+--R                 - 15B a e  + 45A a c d e  + 90B a c d e  - 30A a c d e
+--R               + 
+--R                          2 4        3 5
+--R                 - 15B a c d e + 3A c d
+--R            *
+--R               x
+--R           + 
+--R                   3 5        3   4        2   2 3        2   3 2          2 4
+--R             - 3A a e  - 15B a d e  + 30A a c d e  + 30B a c d e  - 15A a c d e
+--R           + 
+--R                     2 5
+--R             - 3B a c d
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R            4 2     2 3  +---+
+--R       (6a c x  + 6a c )\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1340
+
+--S 1341 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               3 5        2     4        2   2 3          2 3 2         2 4
+--R           5B a e  - 15A a c d e  - 30B a c d e  + 10A a c d e  + 5B a c d e
+--R         + 
+--R              3 5
+--R           A c d
+--R      *
+--R                         2      +-----+
+--R          +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R         \|a \|c log(---------------------------)
+--R                                  2
+--R                               c x  + a
+--R     + 
+--R                  3 5        2     4        2   2 3          2 3 2          2 4
+--R           - 10B a e  + 30A a c d e  + 60B a c d e  - 20A a c d e  - 10B a c d e
+--R         + 
+--R                 3 5
+--R           - 2A c d
+--R      *
+--R                        +-+
+--R          +-----+     x\|c
+--R         \|- a c atan(-----)
+--R                        +-+
+--R                       \|a
+--R     + 
+--R                2 5        2   4            2 3            3 2        2 4
+--R         (- 2A a e  - 10B a d e  + 20A a c d e  + 20B a c d e  - 10A c d e)
+--R      *
+--R          +-----+ +-+ +-+
+--R         \|- a c \|a \|c
+--R  /
+--R         3 +-----+ +-+ +-+
+--R     4a c \|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1341
+
+--S 1342 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1342
+
+--S 1343 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               3 5        2     4        2   2 3          2 3 2         2 4
+--R           5B a e  - 15A a c d e  - 30B a c d e  + 10A a c d e  + 5B a c d e
+--R         + 
+--R              3 5
+--R           A c d
+--R      *
+--R                        +---+
+--R          +-+ +-+     x\|a c
+--R         \|a \|c atan(-------)
+--R                         a
+--R     + 
+--R                 3 5        2     4        2   2 3          2 3 2         2 4
+--R           - 5B a e  + 15A a c d e  + 30B a c d e  - 10A a c d e  - 5B a c d e
+--R         + 
+--R                3 5
+--R           - A c d
+--R      *
+--R                      +-+
+--R          +---+     x\|c
+--R         \|a c atan(-----)
+--R                      +-+
+--R                     \|a
+--R     + 
+--R               2 5       2   4            2 3            3 2       2 4   +-+ +-+
+--R         (- A a e  - 5B a d e  + 10A a c d e  + 10B a c d e  - 5A c d e)\|a \|c
+--R      *
+--R          +---+
+--R         \|a c
+--R  /
+--R         3 +-+ +-+ +---+
+--R     2a c \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1343
+
+--S 1344 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1344
+
+)clear all
+
+--S 1345 of 1457
+t0:=(A+B*x)*(d+e*x)^4/(a+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R          4 5       4         3  4          3       2 2  3
+--R       B e x  + (A e  + 4B d e )x  + (4A d e  + 6B d e )x
+--R     + 
+--R            2 2       3   2        3       4        4
+--R       (6A d e  + 4B d e)x  + (4A d e + B d )x + A d
+--R  /
+--R      2 4         2    2
+--R     c x  + 2a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1345
+
+--S 1346 of 1457
+r0:=-3/2*e^2*(2*A*c*d^2-4*a*B*d*e-a*A*e^2)*x/(a*c^2)-e^3*(2*A*c*d-a*B*e)*_
+     x^2/(a*c^2)-1/2*A*e^4*x^3/(a*c)-1/2*(a*B-A*c*x)*(d+e*x)^4/(a*c*_
+     (a+c*x^2))+1/2*(4*a*B*d*e*(c*d^2-3*a*e^2)+A*(c^2*d^4+6*a*c*d^2*_
+     e^2-3*a^2*e^4))*atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*c^(5/2))+e^2*_
+     (3*B*c*d^2+2*A*c*d*e-a*B*e^2)*log(a+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                  2 2 4        2 2   3         3 2 2         3 3       4 4  2
+--R           (- 3A a c e  - 12B a c d e  + 6A a c d e  + 4B a c d e + A c d )x
+--R         + 
+--R                 3   4        3     3       2 2 2 2       2 2 3         3 4
+--R           - 3A a c e  - 12B a c d e  + 6A a c d e  + 4B a c d e + A a c d
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                      2   4         2   3         2 2 2  2       3 4
+--R               (- 2B a c e  + 4A a c d e  + 6B a c d e )x  - 2B a e
+--R             + 
+--R                   2     3       2   2 2
+--R               4A a c d e  + 6B a c d e
+--R          *
+--R                    2
+--R             log(c x  + a)
+--R         + 
+--R                2 4 4          2 4         2   3  3
+--R           B a c e x  + (2A a c e  + 8B a c d e )x
+--R         + 
+--R                2   4         2   3         2 2 2       3 3   2
+--R           (2B a c e  - 4A a c d e  - 6B a c d e  + 4A c d e)x
+--R         + 
+--R                2   4        2     3         2 2 2         2 3       3 4
+--R           (3A a c e  + 12B a c d e  - 6A a c d e  - 4B a c d e + A c d )x
+--R         + 
+--R                  2 4
+--R           - B a c d
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R          4 2     2 3  +-+ +-+
+--R     (2a c x  + 2a c )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1346
+
+--S 1347 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2 2 4        2 2   3         3 2 2         3 3       4 4  2
+--R             (3A a c e  + 12B a c d e  - 6A a c d e  - 4B a c d e - A c d )x
+--R           + 
+--R                 3   4        3     3       2 2 2 2       2 2 3         3 4
+--R             3A a c e  + 12B a c d e  - 6A a c d e  - 4B a c d e - A a c d
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  - 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                        2   4         2   3          2 2 2  2       3 4
+--R                 (- 4B a c e  + 8A a c d e  + 12B a c d e )x  - 4B a e
+--R               + 
+--R                     2     3        2   2 2
+--R                 8A a c d e  + 12B a c d e
+--R            *
+--R                      2
+--R               log(c x  + a)
+--R           + 
+--R                   2 4 4          2 4          2   3  3       2   4 2
+--R             2B a c e x  + (4A a c e  + 16B a c d e )x  + 2B a c e x
+--R           + 
+--R                  2   4        2     3          2 2 2         2 3        3 4
+--R             (6A a c e  + 24B a c d e  - 12A a c d e  - 8B a c d e + 2A c d )x
+--R           + 
+--R                   3 4       2     3        2   2 2         2 3          2 4
+--R             - 2B a e  + 8A a c d e  + 12B a c d e  - 8A a c d e - 2B a c d
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R            4 2     2 3  +-----+
+--R       (4a c x  + 4a c )\|- a c
+--R     ,
+--R
+--R                    2 2 4        2 2   3         3 2 2         3 3       4 4  2
+--R             (- 3A a c e  - 12B a c d e  + 6A a c d e  + 4B a c d e + A c d )x
+--R           + 
+--R                   3   4        3     3       2 2 2 2       2 2 3         3 4
+--R             - 3A a c e  - 12B a c d e  + 6A a c d e  + 4B a c d e + A a c d
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                        2   4         2   3         2 2 2  2       3 4
+--R                 (- 2B a c e  + 4A a c d e  + 6B a c d e )x  - 2B a e
+--R               + 
+--R                     2     3       2   2 2
+--R                 4A a c d e  + 6B a c d e
+--R            *
+--R                      2
+--R               log(c x  + a)
+--R           + 
+--R                  2 4 4          2 4         2   3  3      2   4 2
+--R             B a c e x  + (2A a c e  + 8B a c d e )x  + B a c e x
+--R           + 
+--R                  2   4        2     3         2 2 2         2 3       3 4
+--R             (3A a c e  + 12B a c d e  - 6A a c d e  - 4B a c d e + A c d )x
+--R           + 
+--R                  3 4       2     3       2   2 2         2 3         2 4
+--R             - B a e  + 4A a c d e  + 6B a c d e  - 4A a c d e - B a c d
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R            4 2     2 3  +---+
+--R       (2a c x  + 2a c )\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1347
+
+--S 1348 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2   4        2     3         2 2 2         2 3       3 4  +-+ +-+
+--R         (3A a c e  + 12B a c d e  - 6A a c d e  - 4B a c d e - A c d )\|a \|c
+--R      *
+--R                 2      +-----+
+--R             (c x  - a)\|- a c  - 2a c x
+--R         log(---------------------------)
+--R                          2
+--R                       c x  + a
+--R     + 
+--R              2   4        2     3          2 2 2         2 3        3 4
+--R         (6A a c e  + 24B a c d e  - 12A a c d e  - 8B a c d e - 2A c d )
+--R      *
+--R                        +-+
+--R          +-----+     x\|c
+--R         \|- a c atan(-----)
+--R                        +-+
+--R                       \|a
+--R     + 
+--R              2 4             3            2 2       2 3   +-----+ +-+ +-+
+--R       (- 2B a e  + 8A a c d e  + 12B a c d e  - 8A c d e)\|- a c \|a \|c
+--R  /
+--R         3 +-----+ +-+ +-+
+--R     4a c \|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1348
+
+--S 1349 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1349
+
+--S 1350 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                2   4        2     3         2 2 2         2 3       3 4  +-+
+--R         (- 3A a c e  - 12B a c d e  + 6A a c d e  + 4B a c d e + A c d )\|a
+--R      *
+--R                    +---+
+--R          +-+     x\|a c
+--R         \|c atan(-------)
+--R                     a
+--R     + 
+--R              2   4        2     3         2 2 2         2 3       3 4  +---+
+--R         (3A a c e  + 12B a c d e  - 6A a c d e  - 4B a c d e - A c d )\|a c
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R             2 4             3           2 2       2 3   +-+ +-+ +---+
+--R       (- B a e  + 4A a c d e  + 6B a c d e  - 4A c d e)\|a \|c \|a c
+--R  /
+--R         3 +-+ +-+ +---+
+--R     2a c \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1350
+
+--S 1351 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1351
+
+)clear all
+
+--S 1352 of 1457
+t0:=(A+B*x)*(d+e*x)^3/(a+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R      3 4       3         2  3          2       2   2        2       3        3
+--R   B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x + A d
+--R   ----------------------------------------------------------------------------
+--R                                 2 4         2    2
+--R                                c x  + 2a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1352
+
+--S 1353 of 1457
+r0:=-3/2*e^2*(A*c*d-a*B*e)*x/(a*c^2)-1/2*A*e^3*x^2/(a*c)-1/2*(a*B-A*c*x)*_
+     (d+e*x)^3/(a*c*(a+c*x^2))+1/2*(3*a*B*e*(c*d^2-a*e^2)+A*c*d*_
+     (c*d^2+3*a*e^2))*atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*c^(5/2))+1/2*_
+     e^2*(3*B*d+A*e)*log(a+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R                  2   3         2   2         2 2       3 3  2       3 3
+--R           (- 3B a c e  + 3A a c d e  + 3B a c d e + A c d )x  - 3B a e
+--R         + 
+--R               2     2       2   2         2 3
+--R           3A a c d e  + 3B a c d e + A a c d
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                    3             2  2      2 3       2   2        2
+--R           ((A a c e  + 3B a c d e )x  + A a e  + 3B a d e )log(c x  + a)
+--R         + 
+--R                   3 3             3             2       2 2   2
+--R           2B a c e x  + (- A a c e  - 3B a c d e  + 3A c d e)x
+--R         + 
+--R                2 3             2           2       2 3            3
+--R           (3B a e  - 3A a c d e  - 3B a c d e + A c d )x - B a c d
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R          3 2     2 2  +-+ +-+
+--R     (2a c x  + 2a c )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1353
+
+--S 1354 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2   3         2   2         2 2       3 3  2       3 3
+--R             (3B a c e  - 3A a c d e  - 3B a c d e - A c d )x  + 3B a e
+--R           + 
+--R                   2     2       2   2         2 3
+--R             - 3A a c d e  - 3B a c d e - A a c d
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  - 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                       3             2  2       2 3       2   2        2
+--R             ((2A a c e  + 6B a c d e )x  + 2A a e  + 6B a d e )log(c x  + a)
+--R           + 
+--R                     3 3        2 3             2           2        2 3
+--R             4B a c e x  + (6B a e  - 6A a c d e  - 6B a c d e + 2A c d )x
+--R           + 
+--R                 2 3       2   2           2            3
+--R             2A a e  + 6B a d e  - 6A a c d e - 2B a c d
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R            3 2     2 2  +-----+
+--R       (4a c x  + 4a c )\|- a c
+--R     ,
+--R
+--R                    2   3         2   2         2 2       3 3  2       3 3
+--R             (- 3B a c e  + 3A a c d e  + 3B a c d e + A c d )x  - 3B a e
+--R           + 
+--R                 2     2       2   2         2 3
+--R             3A a c d e  + 3B a c d e + A a c d
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                      3             2  2      2 3       2   2        2
+--R             ((A a c e  + 3B a c d e )x  + A a e  + 3B a d e )log(c x  + a)
+--R           + 
+--R                     3 3        2 3             2           2       2 3
+--R             2B a c e x  + (3B a e  - 3A a c d e  - 3B a c d e + A c d )x
+--R           + 
+--R                2 3       2   2           2           3
+--R             A a e  + 3B a d e  - 3A a c d e - B a c d
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R            3 2     2 2  +---+
+--R       (2a c x  + 2a c )\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1354
+
+--S 1355 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2 3             2           2       2 3  +-+ +-+
+--R         (3B a e  - 3A a c d e  - 3B a c d e - A c d )\|a \|c
+--R      *
+--R                 2      +-----+
+--R             (c x  - a)\|- a c  - 2a c x
+--R         log(---------------------------)
+--R                          2
+--R                       c x  + a
+--R     + 
+--R                                                                    +-+
+--R            2 3             2           2        2 3  +-----+     x\|c
+--R       (6B a e  - 6A a c d e  - 6B a c d e - 2A c d )\|- a c atan(-----)
+--R                                                                    +-+
+--R                                                                   \|a
+--R     + 
+--R              3           2         2   +-----+ +-+ +-+
+--R       (2A a e  + 6B a d e  - 6A c d e)\|- a c \|a \|c
+--R  /
+--R         2 +-----+ +-+ +-+
+--R     4a c \|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1355
+
+--S 1356 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1356
+
+--S 1357 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                     +---+
+--R              2 3             2           2       2 3  +-+ +-+     x\|a c
+--R       (- 3B a e  + 3A a c d e  + 3B a c d e + A c d )\|a \|c atan(-------)
+--R                                                                      a
+--R     + 
+--R                                                                 +-+
+--R            2 3             2           2       2 3  +---+     x\|c
+--R       (3B a e  - 3A a c d e  - 3B a c d e - A c d )\|a c atan(-----)
+--R                                                                 +-+
+--R                                                                \|a
+--R     + 
+--R             3           2         2   +-+ +-+ +---+
+--R       (A a e  + 3B a d e  - 3A c d e)\|a \|c \|a c
+--R  /
+--R         2 +-+ +-+ +---+
+--R     2a c \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1357
+
+--S 1358 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1358
+
+)clear all
+
+--S 1359 of 1457
+t0:=(A+B*x)*(d+e*x)^2/(a+c*x^2)^2
+--R 
+--R
+--R           2 3       2           2                2        2
+--R        B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d
+--R   (1)  ----------------------------------------------------
+--R                          2 4         2    2
+--R                         c x  + 2a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1359
+
+--S 1360 of 1457
+r0:=-1/2*A*e^2*x/(a*c)-1/2*(a*B-A*c*x)*(d+e*x)^2/(a*c*(a+c*x^2))+_
+     1/2*(A*c*d^2+2*a*B*d*e+a*A*e^2)*atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*_
+     c^(3/2))+1/2*B*e^2*log(a+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R                2 2         2         3 2  2      2   2       2             2 2
+--R         ((A a c e  + 2B a c d e + A c d )x  + A a c e  + 2B a c d e + A a c d )
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                   2 2      2 2        2                  2       2     2
+--R           (B a c e x  + B a e )log(c x  + a) + (- B a c e  + 2A c d e)x
+--R         + 
+--R                     2                   2 2            2
+--R           (- A a c e  - 2B a c d e + A c d )x - B a c d
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R          3 2     2 2  +-+ +-+
+--R     (2a c x  + 2a c )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1360
+
+--S 1361 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     2 2         2         3 2  2      2   2       2
+--R               (A a c e  + 2B a c d e + A c d )x  + A a c e  + 2B a c d e
+--R             + 
+--R                    2 2
+--R               A a c d
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                      2 2       2 2        2
+--R             (2B a c e x  + 2B a e )log(c x  + a)
+--R           + 
+--R                        2                    2 2         2 2
+--R             (- 2A a c e  - 4B a c d e + 2A c d )x + 2B a e  - 4A a c d e
+--R           + 
+--R                       2
+--R             - 2B a c d
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R            3 2     2 2  +-----+
+--R       (4a c x  + 4a c )\|- a c
+--R     ,
+--R
+--R                     2 2         2         3 2  2      2   2       2
+--R               (A a c e  + 2B a c d e + A c d )x  + A a c e  + 2B a c d e
+--R             + 
+--R                    2 2
+--R               A a c d
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                     2 2      2 2        2
+--R             (B a c e x  + B a e )log(c x  + a)
+--R           + 
+--R                     2                   2 2        2 2                       2
+--R           (- A a c e  - 2B a c d e + A c d )x + B a e  - 2A a c d e - B a c d
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R            3 2     2 2  +---+
+--R       (2a c x  + 2a c )\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1361
+
+--S 1362 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                       2      +-----+
+--R               2                   2 2  +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R       (A a c e  + 2B a c d e + A c d )\|a \|c log(---------------------------)
+--R                                                                2
+--R                                                             c x  + a
+--R     + 
+--R                                                          +-+
+--R                  2                    2 2  +-----+     x\|c
+--R       (- 2A a c e  - 4B a c d e - 2A c d )\|- a c atan(-----)
+--R                                                          +-+
+--R                                                         \|a
+--R     + 
+--R              2             +-----+ +-+ +-+
+--R       (2B a e  - 4A c d e)\|- a c \|a \|c
+--R  /
+--R         2 +-----+ +-+ +-+
+--R     4a c \|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1362
+
+--S 1363 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1363
+
+--S 1364 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                      +---+
+--R               2                   2 2  +-+ +-+     x\|a c
+--R       (A a c e  + 2B a c d e + A c d )\|a \|c atan(-------)
+--R                                                       a
+--R     + 
+--R                                                      +-+
+--R                 2                   2 2  +---+     x\|c
+--R       (- A a c e  - 2B a c d e - A c d )\|a c atan(-----)
+--R                                                      +-+
+--R                                                     \|a
+--R     + 
+--R             2             +-+ +-+ +---+
+--R       (B a e  - 2A c d e)\|a \|c \|a c
+--R  /
+--R         2 +-+ +-+ +---+
+--R     2a c \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1364
+
+--S 1365 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1365
+
+)clear all
+
+--S 1366 of 1457
+t0:=(A+B*x)*(d+e*x)/(a+c*x^2)^2
+--R 
+--R
+--R             2
+--R        B e x  + (A e + B d)x + A d
+--R   (1)  ---------------------------
+--R             2 4         2    2
+--R            c x  + 2a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1366
+
+--S 1367 of 1457
+r0:=-1/2*(a*B-A*c*x)*(d+e*x)/(a*c*(a+c*x^2))+1/2*(A*c*d+a*B*e)*_
+     atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                                                     +-+
+--R                      2   2      2                 x\|c
+--R       ((B a c e + A c d)x  + B a e + A a c d)atan(-----)
+--R                                                     +-+
+--R                                                    \|a
+--R     + 
+--R               2                               +-+ +-+
+--R       (A c e x  + (- B a e + A c d)x - B a d)\|a \|c
+--R  /
+--R          2 2     2   +-+ +-+
+--R     (2a c x  + 2a c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1367
+
+--S 1368 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                        2      +-----+
+--R                        2   2      2                (c x  - a)\|- a c  + 2a c x
+--R         ((B a c e + A c d)x  + B a e + A a c d)log(---------------------------)
+--R                                                                 2
+--R                                                              c x  + a
+--R       + 
+--R                                                  +-----+
+--R         ((- 2B a e + 2A c d)x - 2A a e - 2B a d)\|- a c
+--R    /
+--R            2 2     2   +-----+
+--R       (4a c x  + 4a c)\|- a c
+--R     ,
+--R
+--R                                                       +---+
+--R                        2   2      2                 x\|a c
+--R         ((B a c e + A c d)x  + B a e + A a c d)atan(-------)
+--R                                                        a
+--R       + 
+--R                                              +---+
+--R         ((- B a e + A c d)x - A a e - B a d)\|a c
+--R    /
+--R            2 2     2   +---+
+--R       (2a c x  + 2a c)\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1368
+
+--S 1369 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                      2      +-----+
+--R                       +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R       (B a e + A c d)\|a \|c log(---------------------------)
+--R                                               2
+--R                                            c x  + a
+--R     + 
+--R                                         +-+
+--R                           +-----+     x\|c          +-----+ +-+ +-+
+--R       (- 2B a e - 2A c d)\|- a c atan(-----) - 2A e\|- a c \|a \|c
+--R                                         +-+
+--R                                        \|a
+--R  /
+--R          +-----+ +-+ +-+
+--R     4a c\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1369
+
+--S 1370 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1370
+
+--S 1371 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                     +---+                                  +-+
+--R                       +-+ +-+     x\|a c                       +---+     x\|c
+--R       (B a e + A c d)\|a \|c atan(-------) + (- B a e - A c d)\|a c atan(-----)
+--R                                      a                                     +-+
+--R                                                                           \|a
+--R     + 
+--R             +-+ +-+ +---+
+--R       - A e\|a \|c \|a c
+--R  /
+--R          +-+ +-+ +---+
+--R     2a c\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1371
+
+--S 1372 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1372
+
+)clear all
+
+--S 1373 of 1457
+t0:=(A+B*x)/(a+c*x^2)^2
+--R 
+--R
+--R              B x + A
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1373
+
+--S 1374 of 1457
+r0:=1/2*(-a*B+A*c*x)/(a*c*(a+c*x^2))+1/2*A*atan(x*sqrt(c)/sqrt(a))/_
+     (a^(3/2)*sqrt(c))
+--R 
+--R
+--R                               +-+
+--R            2 2              x\|c                   +-+ +-+
+--R        (A c x  + A a c)atan(-----) + (A c x - B a)\|a \|c
+--R                               +-+
+--R                              \|a
+--R   (2)  ---------------------------------------------------
+--R                           2 2     2   +-+ +-+
+--R                      (2a c x  + 2a c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1374
+
+--S 1375 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                            2      +-----+
+--R        2 2             (c x  - a)\|- a c  + 2a c x                    +-----+
+--R    (A c x  + A a c)log(---------------------------) + (2A c x - 2B a)\|- a c
+--R                                     2
+--R                                  c x  + a
+--R   [--------------------------------------------------------------------------,
+--R                                  2 2     2   +-----+
+--R                             (4a c x  + 4a c)\|- a c
+--R                           +---+
+--R        2 2              x\|a c                   +---+
+--R    (A c x  + A a c)atan(-------) + (A c x - B a)\|a c
+--R                            a
+--R    ---------------------------------------------------]
+--R                        2 2     2   +---+
+--R                   (2a c x  + 2a c)\|a c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1375
+
+--S 1376 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R                         2      +-----+                              +-+
+--R          +-+ +-+    (c x  - a)\|- a c  + 2a c x       +-----+     x\|c
+--R        A\|a \|c log(---------------------------) - 2A\|- a c atan(-----)
+--R                                  2                                  +-+
+--R                               c x  + a                             \|a
+--R   (4)  -----------------------------------------------------------------
+--R                                   +-----+ +-+ +-+
+--R                                4a\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1376
+
+--S 1377 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1377
+
+--S 1378 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+                  +-+
+--R          +-+ +-+     x\|a c       +---+     x\|c
+--R        A\|a \|c atan(-------) - A\|a c atan(-----)
+--R                         a                     +-+
+--R                                              \|a
+--R   (6)  -------------------------------------------
+--R                         +-+ +-+ +---+
+--R                      2a\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1378
+
+--S 1379 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1379
+
+)clear all
+
+--S 1380 of 1457
+t0:=(A+B*x)/((d+e*x)*(a+c*x^2)^2)
+--R 
+--R
+--R                               B x + A
+--R   (1)  -----------------------------------------------------
+--R         2   5    2   4           3           2    2       2
+--R        c e x  + c d x  + 2a c e x  + 2a c d x  + a e x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1380
+
+--S 1381 of 1457
+r0:=1/2*(-a*(B*d-A*e)+(A*c*d+a*B*e)*x)/(a*(c*d^2+a*e^2)*(a+c*x^2))-_
+     e^2*(B*d-A*e)*log(d+e*x)/(c*d^2+a*e^2)^2+1/2*e^2*(B*d-A*e)*log(a+_
+     c*x^2)/(c*d^2+a*e^2)^2-1/2*(a*B*e*(c*d^2-a*e^2)-A*c*d*(c*d^2+_
+     3*a*e^2))*atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*(c*d^2+a*e^2)^2*sqrt(c))
+--R 
+--R
+--R   (2)
+--R               2   3         2   2        2 2       3 3  2      3 3
+--R           (B a c e  + 3A a c d e  - B a c d e + A c d )x  + B a e
+--R         + 
+--R               2     2      2   2         2 3
+--R           3A a c d e  - B a c d e + A a c d
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                      3            2  2      2 3      2   2        2
+--R           ((- A a c e  + B a c d e )x  - A a e  + B a d e )log(c x  + a)
+--R         + 
+--R                     3             2  2       2 3       2   2
+--R           ((2A a c e  - 2B a c d e )x  + 2A a e  - 2B a d e )log(e x + d)
+--R         + 
+--R               2 3            2          2       2 3        2 3      2   2
+--R           (B a e  + A a c d e  + B a c d e + A c d )x + A a e  - B a d e
+--R         + 
+--R                  2           3
+--R           A a c d e - B a c d
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R         3   4     2 2 2 2       3 4  2     4 4     3   2 2     2 2 4  +-+ +-+
+--R     ((2a c e  + 4a c d e  + 2a c d )x  + 2a e  + 4a c d e  + 2a c d )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1381
+
+--S 1382 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   3         2   2        2 2       3 3  2      3 3
+--R             (B a c e  + 3A a c d e  - B a c d e + A c d )x  + B a e
+--R           + 
+--R                 2     2      2   2         2 3
+--R             3A a c d e  - B a c d e + A a c d
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                         3             2  2       2 3       2   2        2
+--R             ((- 2A a c e  + 2B a c d e )x  - 2A a e  + 2B a d e )log(c x  + a)
+--R           + 
+--R                       3             2  2       2 3       2   2
+--R             ((4A a c e  - 4B a c d e )x  + 4A a e  - 4B a d e )log(e x + d)
+--R           + 
+--R                  2 3             2           2        2 3         2 3
+--R             (2B a e  + 2A a c d e  + 2B a c d e + 2A c d )x + 2A a e
+--R           + 
+--R                   2   2           2            3
+--R             - 2B a d e  + 2A a c d e - 2B a c d
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R           3   4     2 2 2 2       3 4  2     4 4     3   2 2     2 2 4  +-----+
+--R       ((4a c e  + 8a c d e  + 4a c d )x  + 4a e  + 8a c d e  + 4a c d )\|- a c
+--R     ,
+--R
+--R                 2   3         2   2        2 2       3 3  2      3 3
+--R             (B a c e  + 3A a c d e  - B a c d e + A c d )x  + B a e
+--R           + 
+--R                 2     2      2   2         2 3
+--R             3A a c d e  - B a c d e + A a c d
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                        3            2  2      2 3      2   2        2
+--R             ((- A a c e  + B a c d e )x  - A a e  + B a d e )log(c x  + a)
+--R           + 
+--R                       3             2  2       2 3       2   2
+--R             ((2A a c e  - 2B a c d e )x  + 2A a e  - 2B a d e )log(e x + d)
+--R           + 
+--R                 2 3            2          2       2 3        2 3      2   2
+--R             (B a e  + A a c d e  + B a c d e + A c d )x + A a e  - B a d e
+--R           + 
+--R                    2           3
+--R             A a c d e - B a c d
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R           3   4     2 2 2 2       3 4  2     4 4     3   2 2     2 2 4  +---+
+--R       ((2a c e  + 4a c d e  + 2a c d )x  + 2a e  + 4a c d e  + 2a c d )\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1382
+
+--S 1383 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2 3             2          2       2 3  +-+ +-+
+--R         (B a e  + 3A a c d e  - B a c d e + A c d )\|a \|c
+--R      *
+--R                 2      +-----+
+--R             (c x  - a)\|- a c  + 2a c x
+--R         log(---------------------------)
+--R                          2
+--R                       c x  + a
+--R     + 
+--R                                                                      +-+
+--R              2 3             2           2        2 3  +-----+     x\|c
+--R       (- 2B a e  - 6A a c d e  + 2B a c d e - 2A c d )\|- a c atan(-----)
+--R                                                                      +-+
+--R                                                                     \|a
+--R  /
+--R        3 4     2   2 2       2 4  +-----+ +-+ +-+
+--R     (4a e  + 8a c d e  + 4a c d )\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1383
+
+--S 1384 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1384
+
+--S 1385 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                 +---+
+--R           2 3             2          2       2 3  +-+ +-+     x\|a c
+--R       (B a e  + 3A a c d e  - B a c d e + A c d )\|a \|c atan(-------)
+--R                                                                  a
+--R     + 
+--R                                                                 +-+
+--R             2 3             2          2       2 3  +---+     x\|c
+--R       (- B a e  - 3A a c d e  + B a c d e - A c d )\|a c atan(-----)
+--R                                                                 +-+
+--R                                                                \|a
+--R  /
+--R        3 4     2   2 2       2 4  +-+ +-+ +---+
+--R     (2a e  + 4a c d e  + 2a c d )\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1385
+
+--S 1386 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1386
+
+)clear all
+
+--S 1387 of 1457
+t0:=(A+B*x)/((d+e*x)^2*(a+c*x^2)^2)
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R        2 2 6     2     5          2    2 2  4             3
+--R       c e x  + 2c d e x  + (2a c e  + c d )x  + 4a c d e x
+--R     + 
+--R         2 2         2  2     2         2 2
+--R       (a e  + 2a c d )x  + 2a d e x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1387
+
+--S 1388 of 1457
+r0:=1/2*e*(A*c*d^2+4*a*B*d*e-3*a*A*e^2)/(a*(c*d^2+a*e^2)^2*(d+e*x))+_
+     1/2*(-a*(B*d-A*e)+(A*c*d+a*B*e)*x)/(a*(c*d^2+a*e^2)*(d+e*x)*_
+     (a+c*x^2))-e^2*(3*B*c*d^2-4*A*c*d*e-a*B*e^2)*log(d+e*x)/(c*d^2+_
+     a*e^2)^3+1/2*e^2*(3*B*c*d^2-4*A*c*d*e-a*B*e^2)*log(a+c*x^2)/_
+     (c*d^2+a*e^2)^3-1/2*(2*a*B*d*e*(c*d^2-3*a*e^2)-A*(c^2*d^4+6*a*_
+     c*d^2*e^2-3*a^2*e^4))*atan(x*sqrt(c)/sqrt(a))*sqrt(c)/(a^(3/2)*_
+     (c*d^2+a*e^2)^3)
+--R 
+--R
+--R   (2)
+--R                  2   5       2     4         2 2 3         2 3 2      3 4   3
+--R           (- 3A a c e  + 6B a c d e  + 6A a c d e  - 2B a c d e  + A c d e)x
+--R         + 
+--R                  2     4       2   2 3         2 3 2         2 4       3 5  2
+--R           (- 3A a c d e  + 6B a c d e  + 6A a c d e  - 2B a c d e + A c d )x
+--R         + 
+--R                  3 5       3   4       2   2 3       2   3 2        2 4
+--R           (- 3A a e  + 6B a d e  + 6A a c d e  - 2B a c d e  + A a c d e)x
+--R         + 
+--R                 3   4       3 2 3       2   3 2       2   4         2 5
+--R           - 3A a d e  + 6B a d e  + 6A a c d e  - 2B a c d e + A a c d
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|c atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                     2   5         2   4         2 2 3  3
+--R               (- B a c e  - 4A a c d e  + 3B a c d e )x
+--R             + 
+--R                     2     4         2 2 3         2 3 2  2
+--R               (- B a c d e  - 4A a c d e  + 3B a c d e )x
+--R             + 
+--R                     3 5       2     4       2   2 3        3   4       2   2 3
+--R               (- B a e  - 4A a c d e  + 3B a c d e )x - B a d e  - 4A a c d e
+--R             + 
+--R                   2   3 2
+--R               3B a c d e
+--R          *
+--R                    2
+--R             log(c x  + a)
+--R         + 
+--R                    2   5         2   4         2 2 3  3
+--R               (2B a c e  + 8A a c d e  - 6B a c d e )x
+--R             + 
+--R                    2     4         2 2 3         2 3 2  2
+--R               (2B a c d e  + 8A a c d e  - 6B a c d e )x
+--R             + 
+--R                    3 5       2     4       2   2 3         3   4       2   2 3
+--R               (2B a e  + 8A a c d e  - 6B a c d e )x + 2B a d e  + 8A a c d e
+--R             + 
+--R                     2   3 2
+--R               - 6B a c d e
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                  2   5       2     4         2 2 3         2 3 2      3 4   2
+--R           (- 3A a c e  + 4B a c d e  - 2A a c d e  + 4B a c d e  + A c d e)x
+--R         + 
+--R                  3 5      2     4       2   2 3         2 3 2        2 4
+--R               B a e  + A a c d e  + 2B a c d e  + 2A a c d e  + B a c d e
+--R             + 
+--R                  3 5
+--R               A c d
+--R          *
+--R             x
+--R         + 
+--R                 3 5       3   4       2   3 2         2 4         2 5
+--R           - 2A a e  + 3B a d e  + 2B a c d e  + 2A a c d e - B a c d
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R            4   7     3 2 2 5     2 3 4 3       4 6   3
+--R         (2a c e  + 6a c d e  + 6a c d e  + 2a c d e)x
+--R       + 
+--R            4     6     3 2 3 4     2 3 5 2       4 7  2
+--R         (2a c d e  + 6a c d e  + 6a c d e  + 2a c d )x
+--R       + 
+--R            5 7     4   2 5     3 2 4 3     2 3 6        5   6     4   3 4
+--R         (2a e  + 6a c d e  + 6a c d e  + 2a c d e)x + 2a d e  + 6a c d e
+--R       + 
+--R           3 2 5 2     2 3 7
+--R         6a c d e  + 2a c d
+--R    *
+--R        +-+
+--R       \|a
+--R                                                    Type: Expression(Integer)
+--E 1388
+
+--S 1389 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2   5       2     4         2 2 3         2 3 2      3 4   3
+--R             (3A a c e  - 6B a c d e  - 6A a c d e  + 2B a c d e  - A c d e)x
+--R           + 
+--R                  2     4       2   2 3         2 3 2         2 4       3 5  2
+--R             (3A a c d e  - 6B a c d e  - 6A a c d e  + 2B a c d e - A c d )x
+--R           + 
+--R                  3 5       3   4       2   2 3       2   3 2        2 4
+--R             (3A a e  - 6B a d e  - 6A a c d e  + 2B a c d e  - A a c d e)x
+--R           + 
+--R                 3   4       3 2 3       2   3 2       2   4         2 5
+--R             3A a d e  - 6B a d e  - 6A a c d e  + 2B a c d e - A a c d
+--R        *
+--R                            +---+
+--R                            |  c       2
+--R            +---+    - 2a x |- -  + c x  - a
+--R            |  c           \|  a
+--R            |- - log(-----------------------)
+--R           \|  a                2
+--R                             c x  + a
+--R       + 
+--R                    2   5         2   4         2 2 3  3
+--R             (- 2B a c e  - 8A a c d e  + 6B a c d e )x
+--R           + 
+--R                    2     4         2 2 3         2 3 2  2
+--R             (- 2B a c d e  - 8A a c d e  + 6B a c d e )x
+--R           + 
+--R                    3 5       2     4       2   2 3         3   4       2   2 3
+--R             (- 2B a e  - 8A a c d e  + 6B a c d e )x - 2B a d e  - 8A a c d e
+--R           + 
+--R                 2   3 2
+--R             6B a c d e
+--R        *
+--R                  2
+--R           log(c x  + a)
+--R       + 
+--R                  2   5          2   4          2 2 3  3
+--R             (4B a c e  + 16A a c d e  - 12B a c d e )x
+--R           + 
+--R                  2     4          2 2 3          2 3 2  2
+--R             (4B a c d e  + 16A a c d e  - 12B a c d e )x
+--R           + 
+--R                  3 5        2     4        2   2 3         3   4        2   2 3
+--R             (4B a e  + 16A a c d e  - 12B a c d e )x + 4B a d e  + 16A a c d e
+--R           + 
+--R                    2   3 2
+--R             - 12B a c d e
+--R        *
+--R           log(e x + d)
+--R       + 
+--R                2   5       2     4         2 2 3         2 3 2       3 4   2
+--R         (- 6A a c e  + 8B a c d e  - 4A a c d e  + 8B a c d e  + 2A c d e)x
+--R       + 
+--R                 3 5       2     4       2   2 3         2 3 2         2 4
+--R             2B a e  + 2A a c d e  + 4B a c d e  + 4A a c d e  + 2B a c d e
+--R           + 
+--R                 3 5
+--R             2A c d
+--R        *
+--R           x
+--R       + 
+--R               3 5       3   4       2   3 2         2 4          2 5
+--R         - 4A a e  + 6B a d e  + 4B a c d e  + 4A a c d e - 2B a c d
+--R    /
+--R            4   7      3 2 2 5      2 3 4 3       4 6   3
+--R         (4a c e  + 12a c d e  + 12a c d e  + 4a c d e)x
+--R       + 
+--R            4     6      3 2 3 4      2 3 5 2       4 7  2
+--R         (4a c d e  + 12a c d e  + 12a c d e  + 4a c d )x
+--R       + 
+--R            5 7      4   2 5      3 2 4 3     2 3 6        5   6      4   3 4
+--R         (4a e  + 12a c d e  + 12a c d e  + 4a c d e)x + 4a d e  + 12a c d e
+--R       + 
+--R            3 2 5 2     2 3 7
+--R         12a c d e  + 4a c d
+--R     ,
+--R
+--R                  2   5       2     4         2 2 3         2 3 2      3 4   3
+--R             (3A a c e  - 6B a c d e  - 6A a c d e  + 2B a c d e  - A c d e)x
+--R           + 
+--R                  2     4       2   2 3         2 3 2         2 4       3 5  2
+--R             (3A a c d e  - 6B a c d e  - 6A a c d e  + 2B a c d e - A c d )x
+--R           + 
+--R                  3 5       3   4       2   2 3       2   3 2        2 4
+--R             (3A a e  - 6B a d e  - 6A a c d e  + 2B a c d e  - A a c d e)x
+--R           + 
+--R                 3   4       3 2 3       2   3 2       2   4         2 5
+--R             3A a d e  - 6B a d e  - 6A a c d e  + 2B a c d e - A a c d
+--R        *
+--R                      +-+
+--R                      |c
+--R            +-+     a |-
+--R            |c       \|a
+--R            |- atan(-----)
+--R           \|a       c x
+--R       + 
+--R                   2   5         2   4         2 2 3  3
+--R             (- B a c e  - 4A a c d e  + 3B a c d e )x
+--R           + 
+--R                   2     4         2 2 3         2 3 2  2
+--R             (- B a c d e  - 4A a c d e  + 3B a c d e )x
+--R           + 
+--R                   3 5       2     4       2   2 3        3   4       2   2 3
+--R             (- B a e  - 4A a c d e  + 3B a c d e )x - B a d e  - 4A a c d e
+--R           + 
+--R                 2   3 2
+--R             3B a c d e
+--R        *
+--R                  2
+--R           log(c x  + a)
+--R       + 
+--R                  2   5         2   4         2 2 3  3
+--R             (2B a c e  + 8A a c d e  - 6B a c d e )x
+--R           + 
+--R                  2     4         2 2 3         2 3 2  2
+--R             (2B a c d e  + 8A a c d e  - 6B a c d e )x
+--R           + 
+--R                  3 5       2     4       2   2 3         3   4       2   2 3
+--R             (2B a e  + 8A a c d e  - 6B a c d e )x + 2B a d e  + 8A a c d e
+--R           + 
+--R                   2   3 2
+--R             - 6B a c d e
+--R        *
+--R           log(e x + d)
+--R       + 
+--R                2   5       2     4         2 2 3         2 3 2      3 4   2
+--R         (- 3A a c e  + 4B a c d e  - 2A a c d e  + 4B a c d e  + A c d e)x
+--R       + 
+--R             3 5      2     4       2   2 3         2 3 2        2 4       3 5
+--R         (B a e  + A a c d e  + 2B a c d e  + 2A a c d e  + B a c d e + A c d )x
+--R       + 
+--R               3 5       3   4       2   3 2         2 4         2 5
+--R         - 2A a e  + 3B a d e  + 2B a c d e  + 2A a c d e - B a c d
+--R    /
+--R            4   7     3 2 2 5     2 3 4 3       4 6   3
+--R         (2a c e  + 6a c d e  + 6a c d e  + 2a c d e)x
+--R       + 
+--R            4     6     3 2 3 4     2 3 5 2       4 7  2
+--R         (2a c d e  + 6a c d e  + 6a c d e  + 2a c d )x
+--R       + 
+--R            5 7     4   2 5     3 2 4 3     2 3 6        5   6     4   3 4
+--R         (2a e  + 6a c d e  + 6a c d e  + 2a c d e)x + 2a d e  + 6a c d e
+--R       + 
+--R           3 2 5 2     2 3 7
+--R         6a c d e  + 2a c d
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1389
+
+--S 1390 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                                   +---+
+--R              2 4       2   3           2 2           3       2 4  |  c  +-+
+--R         (3A a e  - 6B a d e  - 6A a c d e  + 2B a c d e - A c d ) |- - \|a
+--R                                                                  \|  a
+--R      *
+--R                    +---+
+--R                    |  c       2
+--R             - 2a x |- -  + c x  - a
+--R                   \|  a
+--R         log(-----------------------)
+--R                        2
+--R                     c x  + a
+--R     + 
+--R                                                                            +-+
+--R          2 4        2   3            2 2           3        2 4  +-+     x\|c
+--R     (6A a e  - 12B a d e  - 12A a c d e  + 4B a c d e - 2A c d )\|c atan(-----)
+--R                                                                            +-+
+--R                                                                           \|a
+--R  /
+--R        4 6      3   2 4      2 2 4 2       3 6  +-+
+--R     (4a e  + 12a c d e  + 12a c d e  + 4a c d )\|a
+--R                                                    Type: Expression(Integer)
+--E 1390
+
+--S 1391 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1391
+
+--S 1392 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                           +-+
+--R            2 4       2   3           2 2           3       2 4  +-+     x\|c
+--R       (3A a e  - 6B a d e  - 6A a c d e  + 2B a c d e - A c d )\|c atan(-----)
+--R                                                                           +-+
+--R                                                                          \|a
+--R     + 
+--R                                                                       +-+
+--R              2 4       2   3           2 2           3       2 4  +-+ |c
+--R         (3A a e  - 6B a d e  - 6A a c d e  + 2B a c d e - A c d )\|a  |-
+--R                                                                      \|a
+--R      *
+--R                +-+
+--R                |c
+--R              a |-
+--R               \|a
+--R         atan(-----)
+--R               c x
+--R  /
+--R        4 6     3   2 4     2 2 4 2       3 6  +-+
+--R     (2a e  + 6a c d e  + 6a c d e  + 2a c d )\|a
+--R                                                    Type: Expression(Integer)
+--E 1392
+
+--S 1393 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1393
+
+)clear all
+
+--S 1394 of 1457
+t0:=(A+B*x)*(d+e*x)^5/(a+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R          5 6       5         4  5          4        2 3  4
+--R       B e x  + (A e  + 5B d e )x  + (5A d e  + 10B d e )x
+--R     + 
+--R           2 3        3 2  3         3 2       4   2        4       5        5
+--R     (10A d e  + 10B d e )x  + (10A d e  + 5B d e)x  + (5A d e + B d )x + A d
+--R  /
+--R      3 6       2 4     2   2    3
+--R     c x  + 3a c x  + 3a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1394
+
+--S 1395 of 1457
+r0:=-3/8*e^2*(5*a*B*e*(2*c*d^2-a*e^2)+A*c*d*(6*c*d^2+5*a*e^2))*x/(a^2*c^3)-_
+     1/2*e^3*(3*A*c*d^2+5*a*B*d*e+a*A*e^2)*x^2/(a^2*c^2)-1/8*e^4*(3*A*_
+     c*d+5*a*B*e)*x^3/(a^2*c^2)-1/4*(a*B-A*c*x)*(d+e*x)^5/(a*c*(a+_
+     c*x^2)^2)+1/8*(d+e*x)^4*(2*a*A*e+(3*A*c*d+5*a*B*e)*x)/(a^2*c*(a+_
+     c*x^2))+1/8*(5*a*B*e*(c^2*d^4+6*a*c*d^2*e^2-3*a^2*e^4)+A*c*d*_
+     (3*c^2*d^4+10*a*c*d^2*e^2+15*a^2*e^4))*atan(x*sqrt(c)/sqrt(a))/_
+     (a^(5/2)*c^(7/2))+1/2*e^4*(5*B*d+A*e)*log(a+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                      3 2 5        2 3   4        2 3 2 3          4 3 2
+--R               - 15B a c e  + 15A a c d e  + 30B a c d e  + 10A a c d e
+--R             + 
+--R                     4 4        5 5
+--R               5B a c d e + 3A c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      4   5        3 2   4        3 2 2 3        2 3 3 2
+--R               - 30B a c e  + 30A a c d e  + 60B a c d e  + 20A a c d e
+--R             + 
+--R                    2 3 4          4 5
+--R               10B a c d e + 6A a c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                  5 5        4     4        4   2 3        3 2 3 2       3 2 4
+--R           - 15B a e  + 15A a c d e  + 30B a c d e  + 10A a c d e  + 5B a c d e
+--R         + 
+--R               2 3 5
+--R           3A a c d
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                    2 2 5        2 2   4  4        3   5        3     4  2
+--R               (4A a c e  + 20B a c d e )x  + (8A a c e  + 40B a c d e )x
+--R             + 
+--R                   4 5        4   4
+--R               4A a e  + 20B a d e
+--R          *
+--R                    2
+--R             log(c x  + a)
+--R         + 
+--R               2 2 5 5
+--R           8B a c e x
+--R         + 
+--R                     2 2 5        2 2   4          3 2 3          3 3 2
+--R               - 6A a c e  - 30B a c d e  + 20A a c d e  + 20B a c d e
+--R             + 
+--R                    4 4
+--R               12A c d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    3   5        2 2   4        2 2 2 3          3 3 2
+--R               25B a c e  - 25A a c d e  - 50B a c d e  + 10A a c d e
+--R             + 
+--R                     3 4        4 5
+--R               5B a c d e + 3A c d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  3   5        3     4          3 4   2
+--R           (- 4A a c e  - 20B a c d e  + 24A a c d e)x
+--R         + 
+--R                    4 5        3     4        3   2 3        2 2 3 2
+--R               15B a e  - 15A a c d e  - 30B a c d e  - 10A a c d e
+--R             + 
+--R                     2 2 4          3 5
+--R               - 5B a c d e + 5A a c d
+--R          *
+--R             x
+--R         + 
+--R               2 2 4        2 2 5
+--R           2A a c d e - 2B a c d
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R        2 5 4      3 4 2     4 3  +-+ +-+
+--R     (8a c x  + 16a c x  + 8a c )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1395
+
+--S 1396 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3 2 5        2 3   4        2 3 2 3          4 3 2
+--R                 15B a c e  - 15A a c d e  - 30B a c d e  - 10A a c d e
+--R               + 
+--R                         4 4        5 5
+--R                 - 5B a c d e - 3A c d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      4   5        3 2   4        3 2 2 3        2 3 3 2
+--R                 30B a c e  - 30A a c d e  - 60B a c d e  - 20A a c d e
+--R               + 
+--R                        2 3 4          4 5
+--R                 - 10B a c d e - 6A a c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                  5 5        4     4        4   2 3        3 2 3 2       3 2 4
+--R             15B a e  - 15A a c d e  - 30B a c d e  - 10A a c d e  - 5B a c d e
+--R           + 
+--R                   2 3 5
+--R             - 3A a c d
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  - 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                      2 2 5        2 2   4  4         3   5        3     4  2
+--R                 (8A a c e  + 40B a c d e )x  + (16A a c e  + 80B a c d e )x
+--R               + 
+--R                     4 5        4   4
+--R                 8A a e  + 40B a d e
+--R            *
+--R                      2
+--R               log(c x  + a)
+--R           + 
+--R                  2 2 5 5
+--R             16B a c e x
+--R           + 
+--R                      3   5        2 2   4         2 2 2 3          3 3 2
+--R                 50B a c e  - 50A a c d e  - 100B a c d e  + 20A a c d e
+--R               + 
+--R                        3 4        4 5
+--R                 10B a c d e + 6A c d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                   3   5        3     4        2 2 2 3        2 2 3 2  2
+--R             (16A a c e  + 80B a c d e  - 80A a c d e  - 80B a c d e )x
+--R           + 
+--R                      4 5        3     4        3   2 3        2 2 3 2
+--R                 30B a e  - 30A a c d e  - 60B a c d e  - 20A a c d e
+--R               + 
+--R                        2 2 4           3 5
+--R                 - 10B a c d e + 10A a c d
+--R            *
+--R               x
+--R           + 
+--R                  4 5        4   4        3   2 3        3   3 2        2 2 4
+--R             12A a e  + 60B a d e  - 40A a c d e  - 40B a c d e  - 20A a c d e
+--R           + 
+--R                   2 2 5
+--R             - 4B a c d
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R           2 5 4      3 4 2      4 3  +-----+
+--R       (16a c x  + 32a c x  + 16a c )\|- a c
+--R     ,
+--R
+--R                        3 2 5        2 3   4        2 3 2 3          4 3 2
+--R                 - 15B a c e  + 15A a c d e  + 30B a c d e  + 10A a c d e
+--R               + 
+--R                       4 4        5 5
+--R                 5B a c d e + 3A c d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        4   5        3 2   4        3 2 2 3        2 3 3 2
+--R                 - 30B a c e  + 30A a c d e  + 60B a c d e  + 20A a c d e
+--R               + 
+--R                      2 3 4          4 5
+--R                 10B a c d e + 6A a c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                    5 5        4     4        4   2 3        3 2 3 2
+--R             - 15B a e  + 15A a c d e  + 30B a c d e  + 10A a c d e
+--R           + 
+--R                 3 2 4        2 3 5
+--R             5B a c d e + 3A a c d
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                      2 2 5        2 2   4  4        3   5        3     4  2
+--R                 (4A a c e  + 20B a c d e )x  + (8A a c e  + 40B a c d e )x
+--R               + 
+--R                     4 5        4   4
+--R                 4A a e  + 20B a d e
+--R            *
+--R                      2
+--R               log(c x  + a)
+--R           + 
+--R                 2 2 5 5
+--R             8B a c e x
+--R           + 
+--R                      3   5        2 2   4        2 2 2 3          3 3 2
+--R                 25B a c e  - 25A a c d e  - 50B a c d e  + 10A a c d e
+--R               + 
+--R                       3 4        4 5
+--R                 5B a c d e + 3A c d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                  3   5        3     4        2 2 2 3        2 2 3 2  2
+--R             (8A a c e  + 40B a c d e  - 40A a c d e  - 40B a c d e )x
+--R           + 
+--R                      4 5        3     4        3   2 3        2 2 3 2
+--R                 15B a e  - 15A a c d e  - 30B a c d e  - 10A a c d e
+--R               + 
+--R                       2 2 4          3 5
+--R                 - 5B a c d e + 5A a c d
+--R            *
+--R               x
+--R           + 
+--R                 4 5        4   4        3   2 3        3   3 2        2 2 4
+--R             6A a e  + 30B a d e  - 20A a c d e  - 20B a c d e  - 10A a c d e
+--R           + 
+--R                   2 2 5
+--R             - 2B a c d
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R          2 5 4      3 4 2     4 3  +---+
+--R       (8a c x  + 16a c x  + 8a c )\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1396
+
+--S 1397 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                3 5        2     4        2   2 3          2 3 2         2 4
+--R           15B a e  - 15A a c d e  - 30B a c d e  - 10A a c d e  - 5B a c d e
+--R         + 
+--R                 3 5
+--R           - 3A c d
+--R      *
+--R                         2      +-----+
+--R          +-+ +-+    (c x  - a)\|- a c  - 2a c x
+--R         \|a \|c log(---------------------------)
+--R                                  2
+--R                               c x  + a
+--R     + 
+--R                3 5        2     4        2   2 3          2 3 2          2 4
+--R           30B a e  - 30A a c d e  - 60B a c d e  - 20A a c d e  - 10B a c d e
+--R         + 
+--R                 3 5
+--R           - 6A c d
+--R      *
+--R                        +-+
+--R          +-----+     x\|c
+--R         \|- a c atan(-----)
+--R                        +-+
+--R                       \|a
+--R     + 
+--R               2 5        2   4            2 3            3 2        2 4
+--R         (12A a e  + 60B a d e  - 40A a c d e  - 40B a c d e  - 24A c d e)
+--R      *
+--R          +-----+ +-+ +-+
+--R         \|- a c \|a \|c
+--R  /
+--R        2 3 +-----+ +-+ +-+
+--R     16a c \|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1397
+
+--S 1398 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1398
+
+--S 1399 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                  3 5        2     4        2   2 3          2 3 2         2 4
+--R           - 15B a e  + 15A a c d e  + 30B a c d e  + 10A a c d e  + 5B a c d e
+--R         + 
+--R               3 5
+--R           3A c d
+--R      *
+--R                        +---+
+--R          +-+ +-+     x\|a c
+--R         \|a \|c atan(-------)
+--R                         a
+--R     + 
+--R                3 5        2     4        2   2 3          2 3 2         2 4
+--R           15B a e  - 15A a c d e  - 30B a c d e  - 10A a c d e  - 5B a c d e
+--R         + 
+--R                 3 5
+--R           - 3A c d
+--R      *
+--R                      +-+
+--R          +---+     x\|c
+--R         \|a c atan(-----)
+--R                      +-+
+--R                     \|a
+--R     + 
+--R              2 5        2   4            2 3            3 2        2 4   +-+
+--R         (6A a e  + 30B a d e  - 20A a c d e  - 20B a c d e  - 12A c d e)\|a
+--R      *
+--R          +-+ +---+
+--R         \|c \|a c
+--R  /
+--R       2 3 +-+ +-+ +---+
+--R     8a c \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1399
+
+--S 1400 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1400
+
+)clear all
+
+--S 1401 of 1457
+t0:=(A+B*x)*(d+e*x)^4/(a+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R          4 5       4         3  4          3       2 2  3
+--R       B e x  + (A e  + 4B d e )x  + (4A d e  + 6B d e )x
+--R     + 
+--R            2 2       3   2        3       4        4
+--R       (6A d e  + 4B d e)x  + (4A d e + B d )x + A d
+--R  /
+--R      3 6       2 4     2   2    3
+--R     c x  + 3a c x  + 3a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1401
+
+--S 1402 of 1457
+r0:=-3/8*e^2*(3*A*c*d^2+4*a*B*d*e+a*A*e^2)*x/(a^2*c^2)-1/8*e^3*(3*A*c*d+_
+     4*a*B*e)*x^2/(a^2*c^2)-1/4*(a*B-A*c*x)*(d+e*x)^4/(a*c*(a+c*x^2)^2)+_
+     1/8*(d+e*x)^3*(a*A*e+(3*A*c*d+4*a*B*e)*x)/(a^2*c*(a+c*x^2))+_
+     1/8*(3*A*(c*d^2+a*e^2)^2+4*a*B*d*e*(c*d^2+3*a*e^2))*atan(x*_
+     sqrt(c)/sqrt(a))/(a^(5/2)*c^(5/2))+1/2*B*e^4*log(a+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                2 3 4        2 3   3         4 2 2         4 3        5 4  4
+--R           (3A a c e  + 12B a c d e  + 6A a c d e  + 4B a c d e + 3A c d )x
+--R         + 
+--R                3 2 4        3 2   3        2 3 2 2       2 3 3          4 4  2
+--R           (6A a c e  + 24B a c d e  + 12A a c d e  + 8B a c d e + 6A a c d )x
+--R         + 
+--R               4   4        4     3       3 2 2 2       3 2 3        2 3 4
+--R           3A a c e  + 12B a c d e  + 6A a c d e  + 4B a c d e + 3A a c d
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                2 2 4 4       3   4 2       4 4        2
+--R           (4B a c e x  + 8B a c e x  + 4B a e )log(c x  + a)
+--R         + 
+--R                  2 2 4         3   3          3 2 2       4 3   4
+--R           (- 6B a c e  + 8A a c d e  + 12B a c d e  + 9A c d e)x
+--R         + 
+--R                  2 2 4        2 2   3         3 2 2         3 3        4 4  3
+--R           (- 5A a c e  - 20B a c d e  + 6A a c d e  + 4B a c d e + 3A c d )x
+--R         + 
+--R                  3   4          3 3   2
+--R           (- 4B a c e  + 18A a c d e)x
+--R         + 
+--R                  3   4        3     3       2 2 2 2       2 2 3          3 4
+--R           (- 3A a c e  - 12B a c d e  - 6A a c d e  - 4B a c d e + 5A a c d )x
+--R         + 
+--R              2 2 3        2 2 4
+--R           A a c d e - 2B a c d
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R        2 5 4      3 4 2     4 3  +-+ +-+
+--R     (8a c x  + 16a c x  + 8a c )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1402
+
+--S 1403 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2 3 4        2 3   3         4 2 2         4 3        5 4  4
+--R             (3A a c e  + 12B a c d e  + 6A a c d e  + 4B a c d e + 3A c d )x
+--R           + 
+--R                       3 2 4        3 2   3        2 3 2 2       2 3 3
+--R                   6A a c e  + 24B a c d e  + 12A a c d e  + 8B a c d e
+--R                 + 
+--R                         4 4
+--R                   6A a c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                 4   4        4     3       3 2 2 2       3 2 3        2 3 4
+--R             3A a c e  + 12B a c d e  + 6A a c d e  + 4B a c d e + 3A a c d
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                  2 2 4 4        3   4 2       4 4        2
+--R             (8B a c e x  + 16B a c e x  + 8B a e )log(c x  + a)
+--R           + 
+--R                          2 2 4        2 2   3          3 2 2         3 3
+--R                   - 10A a c e  - 40B a c d e  + 12A a c d e  + 8B a c d e
+--R                 + 
+--R                       4 4
+--R                   6A c d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                   3   4        2 2   3        2 2 2 2  2
+--R             (16B a c e  - 32A a c d e  - 48B a c d e )x
+--R           + 
+--R                       3   4        3     3        2 2 2 2       2 2 3
+--R                 - 6A a c e  - 24B a c d e  - 12A a c d e  - 8B a c d e
+--R               + 
+--R                        3 4
+--R                 10A a c d
+--R            *
+--R               x
+--R           + 
+--R                  4 4        3     3        3   2 2        2 2 3        2 2 4
+--R             12B a e  - 16A a c d e  - 24B a c d e  - 16A a c d e - 4B a c d
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R           2 5 4      3 4 2      4 3  +-----+
+--R       (16a c x  + 32a c x  + 16a c )\|- a c
+--R     ,
+--R
+--R                  2 3 4        2 3   3         4 2 2         4 3        5 4  4
+--R             (3A a c e  + 12B a c d e  + 6A a c d e  + 4B a c d e + 3A c d )x
+--R           + 
+--R                       3 2 4        3 2   3        2 3 2 2       2 3 3
+--R                   6A a c e  + 24B a c d e  + 12A a c d e  + 8B a c d e
+--R                 + 
+--R                         4 4
+--R                   6A a c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                 4   4        4     3       3 2 2 2       3 2 3        2 3 4
+--R             3A a c e  + 12B a c d e  + 6A a c d e  + 4B a c d e + 3A a c d
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                  2 2 4 4       3   4 2       4 4        2
+--R             (4B a c e x  + 8B a c e x  + 4B a e )log(c x  + a)
+--R           + 
+--R                    2 2 4        2 2   3         3 2 2         3 3        4 4  3
+--R             (- 5A a c e  - 20B a c d e  + 6A a c d e  + 4B a c d e + 3A c d )x
+--R           + 
+--R                  3   4        2 2   3        2 2 2 2  2
+--R             (8B a c e  - 16A a c d e  - 24B a c d e )x
+--R           + 
+--R                         3   4        3     3       2 2 2 2       2 2 3
+--R                   - 3A a c e  - 12B a c d e  - 6A a c d e  - 4B a c d e
+--R                 + 
+--R                         3 4
+--R                   5A a c d
+--R            *
+--R               x
+--R           + 
+--R                 4 4       3     3        3   2 2       2 2 3        2 2 4
+--R             6B a e  - 8A a c d e  - 12B a c d e  - 8A a c d e - 2B a c d
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R          2 5 4      3 4 2     4 3  +---+
+--R       (8a c x  + 16a c x  + 8a c )\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1403
+
+--S 1404 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2   4        2     3         2 2 2         2 3        3 4  +-+ +-+
+--R         (3A a c e  + 12B a c d e  + 6A a c d e  + 4B a c d e + 3A c d )\|a \|c
+--R      *
+--R                 2      +-----+
+--R             (c x  - a)\|- a c  + 2a c x
+--R         log(---------------------------)
+--R                          2
+--R                       c x  + a
+--R     + 
+--R                2   4        2     3          2 2 2         2 3        3 4
+--R         (- 6A a c e  - 24B a c d e  - 12A a c d e  - 8B a c d e - 6A c d )
+--R      *
+--R                        +-+
+--R          +-----+     x\|c
+--R         \|- a c atan(-----)
+--R                        +-+
+--R                       \|a
+--R     + 
+--R             2 4              3            2 2        2 3   +-----+ +-+ +-+
+--R       (12B a e  - 16A a c d e  - 24B a c d e  - 18A c d e)\|- a c \|a \|c
+--R  /
+--R        2 3 +-----+ +-+ +-+
+--R     16a c \|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1404
+
+--S 1405 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1405
+
+--S 1406 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              2   4        2     3         2 2 2         2 3        3 4  +-+ +-+
+--R         (3A a c e  + 12B a c d e  + 6A a c d e  + 4B a c d e + 3A c d )\|a \|c
+--R      *
+--R                +---+
+--R              x\|a c
+--R         atan(-------)
+--R                 a
+--R     + 
+--R                2   4        2     3         2 2 2         2 3        3 4  +---+
+--R         (- 3A a c e  - 12B a c d e  - 6A a c d e  - 4B a c d e - 3A c d )\|a c
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R            2 4             3            2 2       2 3   +-+ +-+ +---+
+--R       (6B a e  - 8A a c d e  - 12B a c d e  - 9A c d e)\|a \|c \|a c
+--R  /
+--R       2 3 +-+ +-+ +---+
+--R     8a c \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1406
+
+--S 1407 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1407
+
+)clear all
+
+--S 1408 of 1457
+t0:=(A+B*x)*(d+e*x)^3/(a+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R      3 4       3         2  3          2       2   2        2       3        3
+--R   B e x  + (A e  + 3B d e )x  + (3A d e  + 3B d e)x  + (3A d e + B d )x + A d
+--R   ----------------------------------------------------------------------------
+--R                            3 6       2 4     2   2    3
+--R                           c x  + 3a c x  + 3a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1408
+
+--S 1409 of 1457
+r0:=-1/4*(a*B-A*c*x)*(d+e*x)^3/(a*c*(a+c*x^2)^2)-3/8*(A*c*d+a*B*e)*_
+     (a*e-c*d*x)*(d+e*x)/(a^2*c^2*(a+c*x^2))+3/8*(A*c*d+a*B*e)*(c*d^2+_
+     a*e^2)*atan(x*sqrt(c)/sqrt(a))/(a^(5/2)*c^(5/2))
+--R 
+--R
+--R   (2)
+--R                2 2 3         3   2         3 2        4 3  4
+--R           (3B a c e  + 3A a c d e  + 3B a c d e + 3A c d )x
+--R         + 
+--R                3   3       2 2   2       2 2 2          3 3  2       4 3
+--R           (6B a c e  + 6A a c d e  + 6B a c d e + 6A a c d )x  + 3B a e
+--R         + 
+--R               3     2       3   2        2 2 3
+--R           3A a c d e  + 3B a c d e + 3A a c d
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                  2 3         2   2       3 2   4
+--R           (2A a c e  + 3B a c d e  + 3A c d e)x
+--R         + 
+--R                  2   3         2   2         2 2        3 3  3
+--R           (- 5B a c e  + 3A a c d e  + 3B a c d e + 3A c d )x
+--R         + 
+--R                  2     2         2 2   2
+--R           (- 6B a c d e  + 6A a c d e)x
+--R         + 
+--R                  3 3       2     2       2   2          2 3         3   2
+--R           (- 3B a e  - 3A a c d e  - 3B a c d e + 5A a c d )x - 3B a d e
+--R         + 
+--R                 2   2        2   3
+--R           - 3A a c d e - 2B a c d
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R        2 4 4      3 3 2     4 2  +-+ +-+
+--R     (8a c x  + 16a c x  + 8a c )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1409
+
+--S 1410 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2 2 3         3   2         3 2        4 3  4
+--R             (3B a c e  + 3A a c d e  + 3B a c d e + 3A c d )x
+--R           + 
+--R                  3   3       2 2   2       2 2 2          3 3  2       4 3
+--R             (6B a c e  + 6A a c d e  + 6B a c d e + 6A a c d )x  + 3B a e
+--R           + 
+--R                 3     2       3   2        2 2 3
+--R             3A a c d e  + 3B a c d e + 3A a c d
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                     2   3         2   2         2 2        3 3  3
+--R             (- 10B a c e  + 6A a c d e  + 6B a c d e + 6A c d )x
+--R           + 
+--R                    2   3        2     2  2
+--R             (- 8A a c e  - 24B a c d e )x
+--R           + 
+--R                    3 3       2     2       2   2           2 3         3 3
+--R             (- 6B a e  - 6A a c d e  - 6B a c d e + 10A a c d )x - 4A a e
+--R           + 
+--R                    3   2        2   2        2   3
+--R             - 12B a d e  - 12A a c d e - 4B a c d
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R           2 4 4      3 3 2      4 2  +-----+
+--R       (16a c x  + 32a c x  + 16a c )\|- a c
+--R     ,
+--R
+--R                  2 2 3         3   2         3 2        4 3  4
+--R             (3B a c e  + 3A a c d e  + 3B a c d e + 3A c d )x
+--R           + 
+--R                  3   3       2 2   2       2 2 2          3 3  2       4 3
+--R             (6B a c e  + 6A a c d e  + 6B a c d e + 6A a c d )x  + 3B a e
+--R           + 
+--R                 3     2       3   2        2 2 3
+--R             3A a c d e  + 3B a c d e + 3A a c d
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                    2   3         2   2         2 2        3 3  3
+--R             (- 5B a c e  + 3A a c d e  + 3B a c d e + 3A c d )x
+--R           + 
+--R                    2   3        2     2  2
+--R             (- 4A a c e  - 12B a c d e )x
+--R           + 
+--R                    3 3       2     2       2   2          2 3         3 3
+--R             (- 3B a e  - 3A a c d e  - 3B a c d e + 5A a c d )x - 2A a e
+--R           + 
+--R                   3   2       2   2        2   3
+--R             - 6B a d e  - 6A a c d e - 2B a c d
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R          2 4 4      3 3 2     4 2  +---+
+--R       (8a c x  + 16a c x  + 8a c )\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1410
+
+--S 1411 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              2 3             2           2        2 3  +-+ +-+
+--R         (3B a e  + 3A a c d e  + 3B a c d e + 3A c d )\|a \|c
+--R      *
+--R                 2      +-----+
+--R             (c x  - a)\|- a c  + 2a c x
+--R         log(---------------------------)
+--R                          2
+--R                       c x  + a
+--R     + 
+--R                                                                      +-+
+--R              2 3             2           2        2 3  +-----+     x\|c
+--R       (- 6B a e  - 6A a c d e  - 6B a c d e - 6A c d )\|- a c atan(-----)
+--R                                                                      +-+
+--R                                                                     \|a
+--R     + 
+--R                3           2         2   +-----+ +-+ +-+
+--R       (- 4A a e  - 6B a d e  - 6A c d e)\|- a c \|a \|c
+--R  /
+--R        2 2 +-----+ +-+ +-+
+--R     16a c \|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1411
+
+--S 1412 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1412
+
+--S 1413 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                    +---+
+--R            2 3             2           2        2 3  +-+ +-+     x\|a c
+--R       (3B a e  + 3A a c d e  + 3B a c d e + 3A c d )\|a \|c atan(-------)
+--R                                                                     a
+--R     + 
+--R                                                                    +-+
+--R              2 3             2           2        2 3  +---+     x\|c
+--R       (- 3B a e  - 3A a c d e  - 3B a c d e - 3A c d )\|a c atan(-----)
+--R                                                                    +-+
+--R                                                                   \|a
+--R     + 
+--R                3           2         2   +-+ +-+ +---+
+--R       (- 2A a e  - 3B a d e  - 3A c d e)\|a \|c \|a c
+--R  /
+--R       2 2 +-+ +-+ +---+
+--R     8a c \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1413
+
+--S 1414 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1414
+
+)clear all
+
+--S 1415 of 1457
+t0:=(A+B*x)*(d+e*x)^2/(a+c*x^2)^3
+--R 
+--R
+--R           2 3       2           2                2        2
+--R        B e x  + (A e  + 2B d e)x  + (2A d e + B d )x + A d
+--R   (1)  ----------------------------------------------------
+--R                     3 6       2 4     2   2    3
+--R                    c x  + 3a c x  + 3a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1415
+
+--S 1416 of 1457
+r0:=-1/4*(a*B-A*c*x)*(d+e*x)^2/(a*c*(a+c*x^2)^2)-1/8*(a*e-c*d*x)*_
+     (3*A*c*d+2*a*B*e+A*c*e*x)/(a^2*c^2*(a+c*x^2))+1/8*(3*A*c*d^2+2*a*_
+     B*d*e+a*A*e^2)*atan(x*sqrt(c)/sqrt(a))/(a^(5/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                 3 2         3          4 2  4
+--R           (A a c e  + 2B a c d e + 3A c d )x
+--R         + 
+--R                2 2 2       2 2            3 2  2      3   2       3
+--R           (2A a c e  + 4B a c d e + 6A a c d )x  + A a c e  + 2B a c d e
+--R         + 
+--R               2 2 2
+--R           3A a c d
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R              3     4         2 2         2          3 2  3
+--R           A c d e x  + (A a c e  + 2B a c d e + 3A c d )x
+--R         + 
+--R                  2   2         2     2         2   2       2              2 2
+--R           (- 4B a c e  + 2A a c d e)x  + (- A a c e  - 2B a c d e + 5A a c d )x
+--R         + 
+--R                 3 2       2            2   2
+--R           - 2B a e  - 3A a c d e - 2B a c d
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R        2 4 4      3 3 2     4 2  +-+ +-+
+--R     (8a c x  + 16a c x  + 8a c )\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1416
+
+--S 1417 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   3 2         3          4 2  4
+--R             (A a c e  + 2B a c d e + 3A c d )x
+--R           + 
+--R                  2 2 2       2 2            3 2  2      3   2       3
+--R             (2A a c e  + 4B a c d e + 6A a c d )x  + A a c e  + 2B a c d e
+--R           + 
+--R                 2 2 2
+--R             3A a c d
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                    2 2         2          3 2  3       2   2 2
+--R             (2A a c e  + 4B a c d e + 6A c d )x  - 8B a c e x
+--R           + 
+--R                    2   2       2               2 2         3 2       2
+--R             (- 2A a c e  - 4B a c d e + 10A a c d )x - 4B a e  - 8A a c d e
+--R           + 
+--R                   2   2
+--R             - 4B a c d
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R           2 4 4      3 3 2      4 2  +-----+
+--R       (16a c x  + 32a c x  + 16a c )\|- a c
+--R     ,
+--R
+--R                   3 2         3          4 2  4
+--R             (A a c e  + 2B a c d e + 3A c d )x
+--R           + 
+--R                  2 2 2       2 2            3 2  2      3   2       3
+--R             (2A a c e  + 4B a c d e + 6A a c d )x  + A a c e  + 2B a c d e
+--R           + 
+--R                 2 2 2
+--R             3A a c d
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                   2 2         2          3 2  3       2   2 2
+--R             (A a c e  + 2B a c d e + 3A c d )x  - 4B a c e x
+--R           + 
+--R                   2   2       2              2 2         3 2       2
+--R             (- A a c e  - 2B a c d e + 5A a c d )x - 2B a e  - 4A a c d e
+--R           + 
+--R                   2   2
+--R             - 2B a c d
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R          2 4 4      3 3 2     4 2  +---+
+--R       (8a c x  + 16a c x  + 8a c )\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1417
+
+--S 1418 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                    2      +-----+
+--R             2                    2  +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R       (A a e  + 2B a d e + 3A c d )\|a \|c log(---------------------------)
+--R                                                             2
+--R                                                          c x  + a
+--R     + 
+--R                                                      +-+
+--R                2                    2  +-----+     x\|c
+--R       (- 2A a e  - 4B a d e - 6A c d )\|- a c atan(-----)
+--R                                                      +-+
+--R                                                     \|a
+--R     + 
+--R                +-----+ +-+ +-+
+--R       - 2A d e\|- a c \|a \|c
+--R  /
+--R        2  +-----+ +-+ +-+
+--R     16a c\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1418
+
+--S 1419 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1419
+
+--S 1420 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                   +---+
+--R             2                    2  +-+ +-+     x\|a c
+--R       (A a e  + 2B a d e + 3A c d )\|a \|c atan(-------)
+--R                                                    a
+--R     + 
+--R                                                   +-+
+--R               2                    2  +---+     x\|c           +-+ +-+ +---+
+--R       (- A a e  - 2B a d e - 3A c d )\|a c atan(-----) - A d e\|a \|c \|a c
+--R                                                   +-+
+--R                                                  \|a
+--R  /
+--R       2  +-+ +-+ +---+
+--R     8a c\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1420
+
+--S 1421 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1421
+
+)clear all
+
+--S 1422 of 1457
+t0:=(A+B*x)*(d+e*x)/(a+c*x^2)^3
+--R 
+--R
+--R              2
+--R         B e x  + (A e + B d)x + A d
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3a c x  + 3a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1422
+
+--S 1423 of 1457
+r0:=-1/4*(a*B-A*c*x)*(d+e*x)/(a*c*(a+c*x^2)^2)+1/8*(-2*a*A*e+(3*A*c*d+_
+     a*B*e)*x)/(a^2*c*(a+c*x^2))+1/8*(3*A*c*d+a*B*e)*atan(x*sqrt(c)/_
+     sqrt(a))/(a^(5/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                2        3   4        2            2   2      3        2
+--R         ((B a c e + 3A c d)x  + (2B a c e + 6A a c d)x  + B a e + 3A a c d)
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                       2   3         2                     2        2   +-+ +-+
+--R       ((B a c e + 3A c d)x  + (- B a e + 5A a c d)x - 2A a e - 2B a d)\|a \|c
+--R  /
+--R        2 3 4      3 2 2     4   +-+ +-+
+--R     (8a c x  + 16a c x  + 8a c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1423
+
+--S 1424 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2        3   4        2            2   2      3        2
+--R           ((B a c e + 3A c d)x  + (2B a c e + 6A a c d)x  + B a e + 3A a c d)
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                            2   3          2                      2        2
+--R           ((2B a c e + 6A c d)x  + (- 2B a e + 10A a c d)x - 4A a e - 4B a d)
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R           2 3 4      3 2 2      4   +-----+
+--R       (16a c x  + 32a c x  + 16a c)\|- a c
+--R     ,
+--R
+--R                  2        3   4        2            2   2      3        2
+--R           ((B a c e + 3A c d)x  + (2B a c e + 6A a c d)x  + B a e + 3A a c d)
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                         2   3         2                     2        2   +---+
+--R         ((B a c e + 3A c d)x  + (- B a e + 5A a c d)x - 2A a e - 2B a d)\|a c
+--R    /
+--R          2 3 4      3 2 2     4   +---+
+--R       (8a c x  + 16a c x  + 8a c)\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1424
+
+--S 1425 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                       2      +-----+
+--R                        +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R       (B a e + 3A c d)\|a \|c log(---------------------------)
+--R                                                2
+--R                                             c x  + a
+--R     + 
+--R                                         +-+
+--R                           +-----+     x\|c
+--R       (- 2B a e - 6A c d)\|- a c atan(-----)
+--R                                         +-+
+--R                                        \|a
+--R  /
+--R        2  +-----+ +-+ +-+
+--R     16a c\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1425
+
+--S 1426 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1426
+
+--S 1427 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---+                                   +-+
+--R                    +-+ +-+     x\|a c                        +---+     x\|c
+--R   (B a e + 3A c d)\|a \|c atan(-------) + (- B a e - 3A c d)\|a c atan(-----)
+--R                                   a                                      +-+
+--R                                                                         \|a
+--R   ---------------------------------------------------------------------------
+--R                                  2  +-+ +-+ +---+
+--R                                8a c\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1427
+
+--S 1428 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1428
+
+)clear all
+
+--S 1429 of 1457
+t0:=(A+B*x)/(a+c*x^2)^3
+--R 
+--R
+--R                   B x + A
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3a c x  + 3a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1429
+
+--S 1430 of 1457
+r0:=1/4*(-a*B+A*c*x)/(a*c*(a+c*x^2)^2)+3/8*A*x/(a^2*(a+c*x^2))+_
+     3/8*A*atan(x*sqrt(c)/sqrt(a))/(a^(5/2)*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                                            +-+
+--R            3 4         2 2       2       x\|c
+--R       (3A c x  + 6A a c x  + 3A a c)atan(-----)
+--R                                            +-+
+--R                                           \|a
+--R     + 
+--R            2 3                  2  +-+ +-+
+--R       (3A c x  + 5A a c x - 2B a )\|a \|c
+--R  /
+--R        2 3 4      3 2 2     4   +-+ +-+
+--R     (8a c x  + 16a c x  + 8a c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1430
+
+--S 1431 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                               2      +-----+
+--R              3 4         2 2       2      (c x  - a)\|- a c  + 2a c x
+--R         (3A c x  + 6A a c x  + 3A a c)log(---------------------------)
+--R                                                        2
+--R                                                     c x  + a
+--R       + 
+--R              2 3                   2  +-----+
+--R         (6A c x  + 10A a c x - 4B a )\|- a c
+--R    /
+--R           2 3 4      3 2 2      4   +-----+
+--R       (16a c x  + 32a c x  + 16a c)\|- a c
+--R     ,
+--R
+--R                                              +---+
+--R              3 4         2 2       2       x\|a c
+--R         (3A c x  + 6A a c x  + 3A a c)atan(-------)
+--R                                               a
+--R       + 
+--R              2 3                  2  +---+
+--R         (3A c x  + 5A a c x - 2B a )\|a c
+--R    /
+--R          2 3 4      3 2 2     4   +---+
+--R       (8a c x  + 16a c x  + 8a c)\|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1431
+
+--S 1432 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R                          2      +-----+                              +-+
+--R           +-+ +-+    (c x  - a)\|- a c  + 2a c x       +-----+     x\|c
+--R        3A\|a \|c log(---------------------------) - 6A\|- a c atan(-----)
+--R                                   2                                  +-+
+--R                                c x  + a                             \|a
+--R   (4)  ------------------------------------------------------------------
+--R                                  2 +-----+ +-+ +-+
+--R                               16a \|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1432
+
+--S 1433 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1433
+
+--S 1434 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R                         +---+                   +-+
+--R           +-+ +-+     x\|a c        +---+     x\|c
+--R        3A\|a \|c atan(-------) - 3A\|a c atan(-----)
+--R                          a                      +-+
+--R                                                \|a
+--R   (6)  ---------------------------------------------
+--R                        2 +-+ +-+ +---+
+--R                      8a \|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1434
+
+--S 1435 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1435
+
+)clear all
+
+--S 1436 of 1457
+t0:=(A+B*x)/((d+e*x)*(a+c*x^2)^3)
+--R 
+--R
+--R   (1)
+--R                                      B x + A
+--R   -----------------------------------------------------------------------------
+--R    3   7    3   6       2   5       2   4     2     3     2     2    3       3
+--R   c e x  + c d x  + 3a c e x  + 3a c d x  + 3a c e x  + 3a c d x  + a e x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1436
+
+--S 1437 of 1457
+r0:=1/4*(-a*(B*d-A*e)+(A*c*d+a*B*e)*x)/(a*(c*d^2+a*e^2)*(a+c*x^2)^2)+_
+     1/8*(-4*a^2*e^2*(B*d-A*e)-(a*B*e*(c*d^2-3*a*e^2)-A*c*d*(3*c*d^2+7*_
+     a*e^2))*x)/(a^2*(c*d^2+a*e^2)^2*(a+c*x^2))-e^4*(B*d-A*e)*log(d+_
+     e*x)/(c*d^2+a*e^2)^3+1/2*e^4*(B*d-A*e)*log(a+c*x^2)/(c*d^2+_
+     a*e^2)^3-1/8*(a*B*e*(c^2*d^4+6*a*c*d^2*e^2-3*a^2*e^4)-A*c*d*_
+     (3*c^2*d^4+10*a*c*d^2*e^2+15*a^2*e^4))*atan(x*sqrt(c)/sqrt(a))/_
+     (a^(5/2)*(c*d^2+a*e^2)^3*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                   3 2 5        2 3   4       2 3 2 3          4 3 2        4 4
+--R               3B a c e  + 15A a c d e  - 6B a c d e  + 10A a c d e  - B a c d e
+--R             + 
+--R                   5 5
+--R               3A c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   4   5        3 2   4        3 2 2 3        2 3 3 2
+--R               6B a c e  + 30A a c d e  - 12B a c d e  + 20A a c d e
+--R             + 
+--R                     2 3 4          4 5
+--R               - 2B a c d e + 6A a c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R               5 5        4     4       4   2 3        3 2 3 2      3 2 4
+--R           3B a e  + 15A a c d e  - 6B a c d e  + 10A a c d e  - B a c d e
+--R         + 
+--R               2 3 5
+--R           3A a c d
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                      2 2 5       2 2   4  4          3   5       3     4  2
+--R               (- 4A a c e  + 4B a c d e )x  + (- 8A a c e  + 8B a c d e )x
+--R             + 
+--R                     4 5       4   4
+--R               - 4A a e  + 4B a d e
+--R          *
+--R                    2
+--R             log(c x  + a)
+--R         + 
+--R                    2 2 5       2 2   4  4         3   5        3     4  2
+--R               (8A a c e  - 8B a c d e )x  + (16A a c e  - 16B a c d e )x
+--R             + 
+--R                   4 5       4   4
+--R               8A a e  - 8B a d e
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                   3   5       2 2   4       2 2 2 3          3 3 2        3 4
+--R               3B a c e  + 7A a c d e  + 2B a c d e  + 10A a c d e  - B a c d e
+--R             + 
+--R                   4 5
+--R               3A c d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                3   5       3     4       2 2 2 3       2 2 3 2  2
+--R           (4A a c e  - 4B a c d e  + 4A a c d e  - 4B a c d e )x
+--R         + 
+--R                   4 5       3     4       3   2 3        2 2 3 2      2 2 4
+--R               5B a e  + 9A a c d e  + 6B a c d e  + 14A a c d e  + B a c d e
+--R             + 
+--R                     3 5
+--R               5A a c d
+--R          *
+--R             x
+--R         + 
+--R               4 5       4   4       3   2 3       3   3 2       2 2 4
+--R           6A a e  - 6B a d e  + 8A a c d e  - 8B a c d e  + 2A a c d e
+--R         + 
+--R                 2 2 5
+--R           - 2B a c d
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R            5 2 6      4 3 2 4      3 4 4 2     2 5 6  4
+--R         (8a c e  + 24a c d e  + 24a c d e  + 8a c d )x
+--R       + 
+--R             6   6      5 2 2 4      4 3 4 2      3 4 6  2     7 6      6   2 4
+--R         (16a c e  + 48a c d e  + 48a c d e  + 16a c d )x  + 8a e  + 24a c d e
+--R       + 
+--R            5 2 4 2     4 3 6
+--R         24a c d e  + 8a c d
+--R    *
+--R        +-+ +-+
+--R       \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1437
+
+--S 1438 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     3 2 5        2 3   4       2 3 2 3          4 3 2
+--R                 3B a c e  + 15A a c d e  - 6B a c d e  + 10A a c d e
+--R               + 
+--R                        4 4        5 5
+--R                 - B a c d e + 3A c d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                     4   5        3 2   4        3 2 2 3        2 3 3 2
+--R                 6B a c e  + 30A a c d e  - 12B a c d e  + 20A a c d e
+--R               + 
+--R                       2 3 4          4 5
+--R                 - 2B a c d e + 6A a c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                 5 5        4     4       4   2 3        3 2 3 2      3 2 4
+--R             3B a e  + 15A a c d e  - 6B a c d e  + 10A a c d e  - B a c d e
+--R           + 
+--R                 2 3 5
+--R             3A a c d
+--R        *
+--R                   2      +-----+
+--R               (c x  - a)\|- a c  + 2a c x
+--R           log(---------------------------)
+--R                            2
+--R                         c x  + a
+--R       + 
+--R                        2 2 5       2 2   4  4           3   5        3     4  2
+--R                 (- 8A a c e  + 8B a c d e )x  + (- 16A a c e  + 16B a c d e )x
+--R               + 
+--R                       4 5       4   4
+--R                 - 8A a e  + 8B a d e
+--R            *
+--R                      2
+--R               log(c x  + a)
+--R           + 
+--R                       2 2 5        2 2   4  4         3   5        3     4  2
+--R                 (16A a c e  - 16B a c d e )x  + (32A a c e  - 32B a c d e )x
+--R               + 
+--R                      4 5        4   4
+--R                 16A a e  - 16B a d e
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                     3   5        2 2   4       2 2 2 3          3 3 2
+--R                 6B a c e  + 14A a c d e  + 4B a c d e  + 20A a c d e
+--R               + 
+--R                         3 4        4 5
+--R                 - 2B a c d e + 6A c d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                  3   5       3     4       2 2 2 3       2 2 3 2  2
+--R             (8A a c e  - 8B a c d e  + 8A a c d e  - 8B a c d e )x
+--R           + 
+--R                      4 5        3     4        3   2 3        2 2 3 2
+--R                 10B a e  + 18A a c d e  + 12B a c d e  + 28A a c d e
+--R               + 
+--R                     2 2 4           3 5
+--R                 2B a c d e + 10A a c d
+--R            *
+--R               x
+--R           + 
+--R                  4 5        4   4        3   2 3        3   3 2       2 2 4
+--R             12A a e  - 12B a d e  + 16A a c d e  - 16B a c d e  + 4A a c d e
+--R           + 
+--R                   2 2 5
+--R             - 4B a c d
+--R        *
+--R            +-----+
+--R           \|- a c
+--R    /
+--R               5 2 6      4 3 2 4      3 4 4 2      2 5 6  4
+--R           (16a c e  + 48a c d e  + 48a c d e  + 16a c d )x
+--R         + 
+--R               6   6      5 2 2 4      4 3 4 2      3 4 6  2      7 6
+--R           (32a c e  + 96a c d e  + 96a c d e  + 32a c d )x  + 16a e
+--R         + 
+--R              6   2 4      5 2 4 2      4 3 6
+--R           48a c d e  + 48a c d e  + 16a c d
+--R      *
+--R          +-----+
+--R         \|- a c
+--R     ,
+--R
+--R                     3 2 5        2 3   4       2 3 2 3          4 3 2
+--R                 3B a c e  + 15A a c d e  - 6B a c d e  + 10A a c d e
+--R               + 
+--R                        4 4        5 5
+--R                 - B a c d e + 3A c d
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                     4   5        3 2   4        3 2 2 3        2 3 3 2
+--R                 6B a c e  + 30A a c d e  - 12B a c d e  + 20A a c d e
+--R               + 
+--R                       2 3 4          4 5
+--R                 - 2B a c d e + 6A a c d
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                 5 5        4     4       4   2 3        3 2 3 2      3 2 4
+--R             3B a e  + 15A a c d e  - 6B a c d e  + 10A a c d e  - B a c d e
+--R           + 
+--R                 2 3 5
+--R             3A a c d
+--R        *
+--R                  +---+
+--R                x\|a c
+--R           atan(-------)
+--R                   a
+--R       + 
+--R                        2 2 5       2 2   4  4          3   5       3     4  2
+--R                 (- 4A a c e  + 4B a c d e )x  + (- 8A a c e  + 8B a c d e )x
+--R               + 
+--R                       4 5       4   4
+--R                 - 4A a e  + 4B a d e
+--R            *
+--R                      2
+--R               log(c x  + a)
+--R           + 
+--R                      2 2 5       2 2   4  4         3   5        3     4  2
+--R                 (8A a c e  - 8B a c d e )x  + (16A a c e  - 16B a c d e )x
+--R               + 
+--R                     4 5       4   4
+--R                 8A a e  - 8B a d e
+--R            *
+--R               log(e x + d)
+--R           + 
+--R                     3   5       2 2   4       2 2 2 3          3 3 2
+--R                 3B a c e  + 7A a c d e  + 2B a c d e  + 10A a c d e
+--R               + 
+--R                        3 4        4 5
+--R                 - B a c d e + 3A c d
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                  3   5       3     4       2 2 2 3       2 2 3 2  2
+--R             (4A a c e  - 4B a c d e  + 4A a c d e  - 4B a c d e )x
+--R           + 
+--R                     4 5       3     4       3   2 3        2 2 3 2      2 2 4
+--R                 5B a e  + 9A a c d e  + 6B a c d e  + 14A a c d e  + B a c d e
+--R               + 
+--R                       3 5
+--R                 5A a c d
+--R            *
+--R               x
+--R           + 
+--R                 4 5       4   4       3   2 3       3   3 2       2 2 4
+--R             6A a e  - 6B a d e  + 8A a c d e  - 8B a c d e  + 2A a c d e
+--R           + 
+--R                   2 2 5
+--R             - 2B a c d
+--R        *
+--R            +---+
+--R           \|a c
+--R    /
+--R              5 2 6      4 3 2 4      3 4 4 2     2 5 6  4
+--R           (8a c e  + 24a c d e  + 24a c d e  + 8a c d )x
+--R         + 
+--R               6   6      5 2 2 4      4 3 4 2      3 4 6  2     7 6
+--R           (16a c e  + 48a c d e  + 48a c d e  + 16a c d )x  + 8a e
+--R         + 
+--R              6   2 4      5 2 4 2     4 3 6
+--R           24a c d e  + 24a c d e  + 8a c d
+--R      *
+--R          +---+
+--R         \|a c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1438
+
+--S 1439 of 1457
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               3 5        2     4       2   2 3          2 3 2        2 4
+--R           3B a e  + 15A a c d e  - 6B a c d e  + 10A a c d e  - B a c d e
+--R         + 
+--R               3 5
+--R           3A c d
+--R      *
+--R                         2      +-----+
+--R          +-+ +-+    (c x  - a)\|- a c  + 2a c x
+--R         \|a \|c log(---------------------------)
+--R                                  2
+--R                               c x  + a
+--R     + 
+--R                 3 5        2     4        2   2 3          2 3 2         2 4
+--R           - 6B a e  - 30A a c d e  + 12B a c d e  - 20A a c d e  + 2B a c d e
+--R         + 
+--R                 3 5
+--R           - 6A c d
+--R      *
+--R                        +-+
+--R          +-----+     x\|c
+--R         \|- a c atan(-----)
+--R                        +-+
+--R                       \|a
+--R  /
+--R         5 6      4   2 4      3 2 4 2      2 3 6  +-----+ +-+ +-+
+--R     (16a e  + 48a c d e  + 48a c d e  + 16a c d )\|- a c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1439
+
+--S 1440 of 1457
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1440
+
+--S 1441 of 1457
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               3 5        2     4       2   2 3          2 3 2        2 4
+--R           3B a e  + 15A a c d e  - 6B a c d e  + 10A a c d e  - B a c d e
+--R         + 
+--R               3 5
+--R           3A c d
+--R      *
+--R                        +---+
+--R          +-+ +-+     x\|a c
+--R         \|a \|c atan(-------)
+--R                         a
+--R     + 
+--R                 3 5        2     4       2   2 3          2 3 2        2 4
+--R           - 3B a e  - 15A a c d e  + 6B a c d e  - 10A a c d e  + B a c d e
+--R         + 
+--R                 3 5
+--R           - 3A c d
+--R      *
+--R                      +-+
+--R          +---+     x\|c
+--R         \|a c atan(-----)
+--R                      +-+
+--R                     \|a
+--R  /
+--R        5 6      4   2 4      3 2 4 2     2 3 6  +-+ +-+ +---+
+--R     (8a e  + 24a c d e  + 24a c d e  + 8a c d )\|a \|c \|a c
+--R                                                    Type: Expression(Integer)
+--E 1441
+
+--S 1442 of 1457
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1442
+
+)clear all
+
+--S 1443 of 1457
+t0:=(A+B*x)/((d+e*x)^2*(a+c*x^2)^3)
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R        3 2 8     3     7        2 2    3 2  6       2     5
+--R       c e x  + 2c d e x  + (3a c e  + c d )x  + 6a c d e x
+--R     + 
+--R        2   2       2 2  4     2       3     3 2     2   2  2     3         3 2
+--R     (3a c e  + 3a c d )x  + 6a c d e x  + (a e  + 3a c d )x  + 2a d e x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1443
+
+--S 1444 of 1457
+r0:=-1/8*e*(2*a*B*d*e*(c*d^2-11*a*e^2)-3*A*(c^2*d^4+4*a*c*d^2*e^2-_
+     5*a^2*e^4))/(a^2*(c*d^2+a*e^2)^3*(d+e*x))+1/4*(-a*(B*d-A*e)+_
+     (A*c*d+a*B*e)*x)/(a*(c*d^2+a*e^2)*(d+e*x)*(a+c*x^2)^2)+1/8*(-a*_
+     e*(A*c*d^2+6*a*B*d*e-5*a*A*e^2)-(2*a*B*e*(c*d^2-2*a*e^2)-3*A*c*d*_
+     (c*d^2+3*a*e^2))*x)/(a^2*(c*d^2+a*e^2)^2*(d+e*x)*(a+c*x^2))-e^4*_
+     (5*B*c*d^2-6*A*c*d*e-a*B*e^2)*log(d+e*x)/(c*d^2+a*e^2)^4+1/2*e^4*_
+     (5*B*c*d^2-6*A*c*d*e-a*B*e^2)*log(a+c*x^2)/(c*d^2+a*e^2)^4-1/8*_
+     (2*a*B*d*e*(c^2*d^4+10*a*c*d^2*e^2-15*a^2*e^4)-3*A*(c^3*d^6+_
+     5*a*c^2*d^4*e^2+15*a^2*c*d^2*e^4-5*a^3*e^6))*atan(x*sqrt(c)/_
+     sqrt(a))*sqrt(c)/(a^(5/2)*(c*d^2+a*e^2)^4)
+--R 
+--R
+--R   (2)
+--R                      3 2 7        3 2   6        2 3 2 5        2 3 3 4
+--R               - 15A a c e  + 30B a c d e  + 45A a c d e  - 20B a c d e
+--R             + 
+--R                      4 4 3         4 5 2       5 6
+--R               15A a c d e  - 2B a c d e  + 3A c d e
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                      3 2   6        3 2 2 5        2 3 3 4        2 3 4 3
+--R               - 15A a c d e  + 30B a c d e  + 45A a c d e  - 20B a c d e
+--R             + 
+--R                      4 5 2         4 6        5 7
+--R               15A a c d e  - 2B a c d e + 3A c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      4   7        4     6        3 2 2 5        3 2 3 4
+--R               - 30A a c e  + 60B a c d e  + 90A a c d e  - 40B a c d e
+--R             + 
+--R                    2 3 4 3       2 3 5 2         4 6
+--R               30A a c d e  - 4B a c d e  + 6A a c d e
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      4     6        4   2 5        3 2 3 4        3 2 4 3
+--R               - 30A a c d e  + 60B a c d e  + 90A a c d e  - 40B a c d e
+--R             + 
+--R                    2 3 5 2       2 3 6          4 7
+--R               30A a c d e  - 4B a c d e + 6A a c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      5 7        5   6        4   2 5        4   3 4
+--R               - 15A a e  + 30B a d e  + 45A a c d e  - 20B a c d e
+--R             + 
+--R                    3 2 4 3       3 2 5 2       2 3 6
+--R               15A a c d e  - 2B a c d e  + 3A a c d e
+--R          *
+--R             x
+--R         + 
+--R                  5   6        5 2 5        4   3 4        4   4 3
+--R           - 15A a d e  + 30B a d e  + 45A a c d e  - 20B a c d e
+--R         + 
+--R                3 2 5 2       3 2 6        2 3 7
+--R           15A a c d e  - 2B a c d e + 3A a c d
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|c atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                      3 2 7        2 3   6        2 3 2 5  5
+--R               (- 4B a c e  - 24A a c d e  + 20B a c d e )x
+--R             + 
+--R                      3 2   6        2 3 2 5        2 3 3 4  4
+--R               (- 4B a c d e  - 24A a c d e  + 20B a c d e )x
+--R             + 
+--R                      4   7        3 2   6        3 2 2 5  3
+--R               (- 8B a c e  - 48A a c d e  + 40B a c d e )x
+--R             + 
+--R                      4     6        3 2 2 5        3 2 3 4  2
+--R               (- 8B a c d e  - 48A a c d e  + 40B a c d e )x
+--R             + 
+--R                      5 7        4     6        4   2 5         5   6
+--R               (- 4B a e  - 24A a c d e  + 20B a c d e )x - 4B a d e
+--R             + 
+--R                      4   2 5        4   3 4
+--R               - 24A a c d e  + 20B a c d e
+--R          *
+--R                    2
+--R             log(c x  + a)
+--R         + 
+--R                    3 2 7        2 3   6        2 3 2 5  5
+--R               (8B a c e  + 48A a c d e  - 40B a c d e )x
+--R             + 
+--R                    3 2   6        2 3 2 5        2 3 3 4  4
+--R               (8B a c d e  + 48A a c d e  - 40B a c d e )x
+--R             + 
+--R                     4   7        3 2   6        3 2 2 5  3
+--R               (16B a c e  + 96A a c d e  - 80B a c d e )x
+--R             + 
+--R                     4     6        3 2 2 5        3 2 3 4  2
+--R               (16B a c d e  + 96A a c d e  - 80B a c d e )x
+--R             + 
+--R                    5 7        4     6        4   2 5         5   6
+--R               (8B a e  + 48A a c d e  - 40B a c d e )x + 8B a d e
+--R             + 
+--R                    4   2 5        4   3 4
+--R               48A a c d e  - 40B a c d e
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                      3 2 7        3 2   6       2 3 2 5        2 3 3 4
+--R               - 15A a c e  + 22B a c d e  - 3A a c d e  + 20B a c d e
+--R             + 
+--R                      4 4 3         4 5 2       5 6
+--R               15A a c d e  - 2B a c d e  + 3A c d e
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   4   7       3 2   6       3 2 2 5        2 3 3 4
+--R               4B a c e  + 9A a c d e  + 6B a c d e  + 21A a c d e
+--R             + 
+--R                      4 5 2         4 6        5 7
+--R               15A a c d e  - 2B a c d e + 3A c d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      4   7        4     6       3 2 2 5        3 2 3 4
+--R               - 25A a c e  + 38B a c d e  + 3A a c d e  + 28B a c d e
+--R             + 
+--R                    2 3 4 3        2 3 5 2         4 6
+--R               33A a c d e  - 10B a c d e  + 5A a c d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   5 7        4     6        4   2 5        3 2 3 4
+--R               6B a e  + 11A a c d e  + 12B a c d e  + 27A a c d e
+--R             + 
+--R                   3 2 4 3        2 3 5 2         4 7
+--R               6B a c d e  + 21A a c d e  + 5A a c d
+--R          *
+--R             x
+--R         + 
+--R                 5 7        5   6        4   2 5       4   3 4        3 2 4 3
+--R           - 8A a e  + 14B a d e  + 12A a c d e  + 2B a c d e  + 24A a c d e
+--R         + 
+--R                  3 2 5 2       2 3 6        2 3 7
+--R           - 14B a c d e  + 4A a c d e - 2B a c d
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R            6 2 9      5 3 2 7      4 4 4 5      3 5 6 3     2 6 8   5
+--R         (8a c e  + 32a c d e  + 48a c d e  + 32a c d e  + 8a c d e)x
+--R       + 
+--R            6 2   8      5 3 3 6      4 4 5 4      3 5 7 2     2 6 9  4
+--R         (8a c d e  + 32a c d e  + 48a c d e  + 32a c d e  + 8a c d )x
+--R       + 
+--R             7   9      6 2 2 7      5 3 4 5      4 4 6 3      3 5 8   3
+--R         (16a c e  + 64a c d e  + 96a c d e  + 64a c d e  + 16a c d e)x
+--R       + 
+--R             7     8      6 2 3 6      5 3 5 4      4 4 7 2      3 5 9  2
+--R         (16a c d e  + 64a c d e  + 96a c d e  + 64a c d e  + 16a c d )x
+--R       + 
+--R            8 9      7   2 7      6 2 4 5      5 3 6 3     4 4 8        8   8
+--R         (8a e  + 32a c d e  + 48a c d e  + 32a c d e  + 8a c d e)x + 8a d e
+--R       + 
+--R            7   3 6      6 2 5 4      5 3 7 2     4 4 9
+--R         32a c d e  + 48a c d e  + 32a c d e  + 8a c d
+--R    *
+--R        +-+
+--R       \|a
+--R                                                    Type: Expression(Integer)
+--E 1444
+
+--S 1445 of 1457
+--a0:=integrate(t0,x)
+--E 1445
+
+--S 1446 of 1457
+--m0:=a0-r0
+--E 1446
+
+--S 1447 of 1457
+--d0:=D(m0,x)
+--E 1447
+
+)clear all
+
+--S 1448 of 1457
+t0:=(-11+6*x)/((-1+2*x)*(-1+x^2))
+--R 
+--R
+--R             6x - 11
+--R   (1)  -----------------
+--R          3    2
+--R        2x  - x  - 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1448
+
+--S 1449 of 1457
+r0:=16/3*log(1-2*x)-5/2*log(1-x)-17/6*log(1+x)
+--R 
+--R
+--R        - 17log(x + 1) - 15log(- x + 1) + 32log(- 2x + 1)
+--R   (2)  -------------------------------------------------
+--R                                6
+--R                                                    Type: Expression(Integer)
+--E 1449
+
+--S 1450 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R        32log(2x - 1) - 17log(x + 1) - 15log(x - 1)
+--R   (3)  -------------------------------------------
+--R                             6
+--R                                         Type: Union(Expression(Integer),...)
+--E 1450
+
+--S 1451 of 1457
+m0:=a0-r0
+--R 
+--R
+--R        32log(2x - 1) - 15log(x - 1) + 15log(- x + 1) - 32log(- 2x + 1)
+--R   (4)  ---------------------------------------------------------------
+--R                                       6
+--R                                                    Type: Expression(Integer)
+--E 1451
+
+--S 1452 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1452
+
+)clear all
+
+--S 1453 of 1457
+t0:=(5-x)*(3+2*x)^4*sqrt(2+3*x^2)
+--R 
+--R
+--R                                                     +-------+
+--R              5      4       3       2               |  2
+--R   (1)  (- 16x  - 16x  + 264x  + 864x  + 999x + 405)\|3x  + 2
+--R                                                    Type: Expression(Integer)
+--E 1453
+
+--S 1454 of 1457
+r0:=8275/162*(2+3*x^2)^(3/2)+923/315*(3+2*x)^2*(2+3*x^2)^(3/2)+29/63*_
+     (3+2*x)^3*(2+3*x^2)^(3/2)-1/21*(3+2*x)^4*(2+3*x^2)^(3/2)+1/270*_
+     (4583+6132*x)*(2+3*x^2)^(3/2)+2341/9*asinh(x*sqrt(3/2))/sqrt(3)+_
+     2341/18*x*sqrt(2+3*x^2)
+--R 
+--R
+--R   (2)
+--R                   6         5          4           3           2
+--R           - 12960x  - 15120x  + 297648x  + 1222200x  + 1956174x  + 1558935x
+--R         + 
+--R           1167988
+--R      *
+--R              +-------+
+--R          +-+ |  2
+--R         \|3 \|3x  + 2
+--R     + 
+--R                      +-+
+--R                    x\|3
+--R       1474830asinh(-----)
+--R                      +-+
+--R                     \|2
+--R  /
+--R          +-+
+--R     5670\|3
+--R                                                    Type: Expression(Integer)
+--E 1454
+
+--S 1455 of 1457
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                 +-------+
+--R                    6            4             2             +-+ |  2
+--R           (4424490x  + 70791840x  + 157315200x  + 83901440)\|2 \|3x  + 2
+--R         + 
+--R                      6             4             2
+--R           - 61942860x  - 330361920x  - 440482560x  - 167802880
+--R      *
+--R                             +-------+
+--R               +-+ +-+       |  2             2      +-+      +-+
+--R             (\|2 \|3  - 3x)\|3x  + 2  + (- 3x  - 2)\|3  + 3x\|2
+--R         log(----------------------------------------------------)
+--R                                   +-------+
+--R                               +-+ |  2
+--R                              \|2 \|3x  + 2  - 2
+--R     + 
+--R                  12          11           10            9             8
+--R           544320x   + 635040x   - 9598176x   - 47945520x  - 144961740x
+--R         + 
+--R                       7             6             5             4             3
+--R           - 334732230x  - 567653520x  - 712511520x  - 767612160x  - 604661120x
+--R         + 
+--R                       2
+--R           - 322237440x  - 177372160x
+--R      *
+--R              +-------+
+--R          +-+ |  2
+--R         \|3 \|3x  + 2
+--R     + 
+--R                    14          13          12           11            10
+--R           - 116640x   - 136080x   + 734832x   + 8731800x   + 56861406x
+--R         + 
+--R                     9             8             7              6              5
+--R           191070495x  + 422782920x  + 736469370x  + 1052733360x  + 1116121440x
+--R         + 
+--R                      4             3             2
+--R           1009290240x  + 737690240x  + 322237440x  + 177372160x
+--R      *
+--R          +-+ +-+
+--R         \|2 \|3
+--R  /
+--R                                                        +-------+
+--R              6          4          2           +-+ +-+ |  2
+--R       (17010x  + 272160x  + 604800x  + 322560)\|2 \|3 \|3x  + 2
+--R     + 
+--R                 6           4           2           +-+
+--R       (- 238140x  - 1270080x  - 1693440x  - 645120)\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1455
+
+--S 1456 of 1457
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                    +-------+
+--R                     6             4             2              +-+ |  2
+--R           (19910205x  + 318563280x  + 707918400x  + 377556480)\|2 \|3x  + 2
+--R         + 
+--R                       6              4              2
+--R           - 278742870x  - 1486628640x  - 1982171520x  - 755112960
+--R      *
+--R                             +-------+
+--R               +-+ +-+       |  2             2      +-+      +-+
+--R             (\|2 \|3  - 3x)\|3x  + 2  + (- 3x  - 2)\|3  + 3x\|2
+--R         log(----------------------------------------------------)
+--R                                   +-------+
+--R                               +-+ |  2
+--R                              \|2 \|3x  + 2  - 2
+--R     + 
+--R                         6             4             2              +-+
+--R             (- 19910205x  - 318563280x  - 707918400x  - 377556480)\|2
+--R          *
+--R                     +-+
+--R                   x\|3
+--R             asinh(-----)
+--R                     +-+
+--R                    \|2
+--R         + 
+--R                     6             4              2              +-+
+--R           (31535676x  + 504570816x  + 1121268480x  + 598009856)\|3
+--R      *
+--R          +-------+
+--R          |  2
+--R         \|3x  + 2
+--R     + 
+--R                                                                      +-+
+--R                  6              4              2                   x\|3
+--R       (278742870x  + 1486628640x  + 1982171520x  + 755112960)asinh(-----)
+--R                                                                      +-+
+--R                                                                     \|2
+--R     + 
+--R                    6              4              2              +-+ +-+
+--R       (- 220749732x  - 1177331904x  - 1569775872x  - 598009856)\|2 \|3
+--R  /
+--R                                                           +-------+
+--R              6           4           2            +-+ +-+ |  2
+--R       (76545x  + 1224720x  + 2721600x  + 1451520)\|2 \|3 \|3x  + 2
+--R     + 
+--R                  6           4           2            +-+
+--R       (- 1071630x  - 5715360x  - 7620480x  - 2903040)\|3
+--R                                                    Type: Expression(Integer)
+--E 1456
+
+--S 1457 of 1457
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1457
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
+ 
+--S 1 of 704
+t0:=x^2*(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R           6      5      4
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 1
+
+--S 2 of 704
+r0:=1/5*a*x^5+1/6*b*x^6+1/7*c*x^7
+--R 
+--R
+--R        1    7   1    6   1    5
+--R   (2)  - c x  + - b x  + - a x
+--R        7        6        5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 2
+
+--S 3 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    7   1    6   1    5
+--R   (3)  - c x  + - b x  + - a x
+--R        7        6        5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 3
+
+--S 4 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 4
+
+--S 5 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 5
+
+)clear all
+
+--S 6 of 704
+t0:=x*(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R           5      4      3
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 6
+
+--S 7 of 704
+r0:=1/4*a*x^4+1/5*b*x^5+1/6*c*x^6
+--R 
+--R
+--R        1    6   1    5   1    4
+--R   (2)  - c x  + - b x  + - a x
+--R        6        5        4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 7
+
+--S 8 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    6   1    5   1    4
+--R   (3)  - c x  + - b x  + - a x
+--R        6        5        4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 8
+
+--S 9 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 9
+
+--S 10 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 10
+
+)clear all
+
+--S 11 of 704
+t0:=a*x^2+b*x^3+c*x^4
+--R 
+--R
+--R           4      3      2
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 11
+
+--S 12 of 704
+r0:=1/3*a*x^3+1/4*b*x^4+1/5*c*x^5
+--R 
+--R
+--R        1    5   1    4   1    3
+--R   (2)  - c x  + - b x  + - a x
+--R        5        4        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 12
+
+--S 13 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    5   1    4   1    3
+--R   (3)  - c x  + - b x  + - a x
+--R        5        4        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 13
+
+--S 14 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 14
+
+--S 15 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 15
+
+)clear all
+
+--S 16 of 704
+t0:=(a*x^2+b*x^3+c*x^4)/x
+--R 
+--R
+--R           3      2
+--R   (1)  c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 16
+
+--S 17 of 704
+r0:=1/2*a*x^2+1/3*b*x^3+1/4*c*x^4
+--R 
+--R
+--R        1    4   1    3   1    2
+--R   (2)  - c x  + - b x  + - a x
+--R        4        3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 17
+
+--S 18 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4       3       2
+--R        3c x  + 4b x  + 6a x
+--R   (3)  ---------------------
+--R                  12
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 704
+t0:=(a*x^2+b*x^3+c*x^4)/x^2
+--R 
+--R
+--R           2
+--R   (1)  c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 21
+
+--S 22 of 704
+r0:=a*x+1/2*b*x^2+1/3*c*x^3
+--R 
+--R
+--R        1    3   1    2
+--R   (2)  - c x  + - b x  + a x
+--R        3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 22
+
+--S 23 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3       2
+--R        2c x  + 3b x  + 6a x
+--R   (3)  --------------------
+--R                  6
+--R                                         Type: Union(Expression(Integer),...)
+--E 23
+
+--S 24 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 25
+
+)clear all
+
+--S 26 of 704
+t0:=x^2*(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R         2 10         9            2  8         7    2 6
+--R   (1)  c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 26
+
+--S 27 of 704
+r0:=1/7*a^2*x^7+1/4*a*b*x^8+1/9*(b^2+2*a*c)*x^9+1/5*b*c*x^10+1/11*c^2*x^11
+--R 
+--R
+--R         1  2 11   1      10    2       1  2  9   1      8   1  2 7
+--R   (2)  -- c x   + - b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        11         5            9       9         4          7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 27
+
+--S 28 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  2 11   1      10    2       1  2  9   1      8   1  2 7
+--R   (3)  -- c x   + - b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        11         5            9       9         4          7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 28
+
+--S 29 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 29
+
+--S 30 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 30
+
+)clear all
+
+--S 31 of 704
+t0:=x*(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R         2 9         8            2  7         6    2 5
+--R   (1)  c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 31
+
+--S 32 of 704
+r0:=1/6*a^2*x^6+2/7*a*b*x^7+1/8*(b^2+2*a*c)*x^8+2/9*b*c*x^9+1/10*c^2*x^10
+--R 
+--R
+--R         1  2 10   2      9    1       1  2  8   2      7   1  2 6
+--R   (2)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        10         9           4       8         7          6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 32
+
+--S 33 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  2 10   2      9    1       1  2  8   2      7   1  2 6
+--R   (3)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        10         9           4       8         7          6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 33
+
+--S 34 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 34
+
+--S 35 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 35
+
+)clear all
+
+--S 36 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R         2 8         7            2  6         5    2 4
+--R   (1)  c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 36
+
+--S 37 of 704
+r0:=1/5*a^2*x^5+1/3*a*b*x^6+1/7*(b^2+2*a*c)*x^7+1/4*b*c*x^8+1/9*c^2*x^9
+--R 
+--R
+--R        1  2 9   1      8    2       1  2  7   1      6   1  2 5
+--R   (2)  - c x  + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        9        4           7       7         3          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 37
+
+--S 38 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  2 9   1      8    2       1  2  7   1      6   1  2 5
+--R   (3)  - c x  + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        9        4           7       7         3          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 38
+
+--S 39 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 39
+
+--S 40 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 40
+
+)clear all
+
+--S 41 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^2/x
+--R 
+--R
+--R         2 7         6            2  5         4    2 3
+--R   (1)  c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 41
+
+--S 42 of 704
+r0:=1/4*a^2*x^4+2/5*a*b*x^5+1/6*(b^2+2*a*c)*x^6+2/7*b*c*x^7+1/8*c^2*x^8
+--R 
+--R
+--R        1  2 8   2      7    1       1  2  6   2      5   1  2 4
+--R   (2)  - c x  + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        8        7           3       6         5          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 42
+
+--S 43 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 8           7                 2  6           5       2 4
+--R        105c x  + 240b c x  + (280a c + 140b )x  + 336a b x  + 210a x
+--R   (3)  --------------------------------------------------------------
+--R                                      840
+--R                                         Type: Union(Expression(Integer),...)
+--E 43
+
+--S 44 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^2/x^2
+--R 
+--R
+--R         2 6         5            2  4         3    2 2
+--R   (1)  c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 46
+
+--S 47 of 704
+r0:=1/3*a^2*x^3+1/2*a*b*x^4+1/5*(b^2+2*a*c)*x^5+1/3*b*c*x^6+1/7*c^2*x^7
+--R 
+--R
+--R        1  2 7   1      6    2       1  2  5   1      4   1  2 3
+--R   (2)  - c x  + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        7        3           5       5         2          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 47
+
+--S 48 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 7          6               2  5           4      2 3
+--R        30c x  + 70b c x  + (84a c + 42b )x  + 105a b x  + 70a x
+--R   (3)  ---------------------------------------------------------
+--R                                   210
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 704
+t0:=x^5/(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 51
+
+--S 52 of 704
+r0:=-b*x/c^2+1/2*x^2/c+1/2*(b^2-a*c)*log(a+b*x+c*x^2)/c^3+b*(b^2-3*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                     3          2c x + b
+--R       (- 6a b c + 2b )atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                                         +-----------+
+--R                  2        2               2 2           |          2
+--R       ((- a c + b )log(c x  + b x + a) + c x  - 2b c x)\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3
+--R           (3a b c - b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                                           +-----------+
+--R                    2        2               2 2           |          2
+--R         ((- a c + b )log(c x  + b x + a) + c x  - 2b c x)\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         3 |          2
+--R       2c \|- 4a c + b
+--R     ,
+--R
+--R                                       +---------+
+--R                                       |        2
+--R                     3      (2c x + b)\|4a c - b
+--R         (6a b c - 2b )atan(----------------------)
+--R                                           2
+--R                                   4a c - b
+--R       + 
+--R                                                           +---------+
+--R                    2        2               2 2           |        2
+--R         ((- a c + b )log(c x  + b x + a) + c x  - 2b c x)\|4a c - b
+--R    /
+--R           +---------+
+--R         3 |        2
+--R       2c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 53
+
+--S 54 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (3a b c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                   3          2c x + b
+--R       (6a b c - 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+
+--R                  3  |        2          2c x + b
+--R       (3a b c - b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                     +-----------+                |        2
+--R                  3  |          2      (2c x + b)\|4a c - b
+--R       (3a b c - b )\|- 4a c + b  atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      3 |          2  |        2
+--R     c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 704
+t0:=x^4/(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 58
+
+--S 59 of 704
+r0:=x/c-1/2*b*log(a+b*x+c*x^2)/c^2-(b^2-2*a*c)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                 2          2c x + b
+--R       (4a c - 2b )atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                        +-----------+
+--R                   2                    |          2
+--R       (- b log(c x  + b x + a) + 2c x)\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2
+--R           (2a c - b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                          +-----------+
+--R                     2                    |          2
+--R         (- b log(c x  + b x + a) + 2c x)\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         2 |          2
+--R       2c \|- 4a c + b
+--R     ,
+--R
+--R                                       +---------+
+--R                                       |        2
+--R                     2      (2c x + b)\|4a c - b
+--R         (- 4a c + 2b )atan(----------------------)
+--R                                           2
+--R                                   4a c - b
+--R       + 
+--R                                          +---------+
+--R                     2                    |        2
+--R         (- b log(c x  + b x + a) + 2c x)\|4a c - b
+--R    /
+--R           +---------+
+--R         2 |        2
+--R       2c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 60
+
+--S 61 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                   2          2c x + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+
+--R                  2  |        2          2c x + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                     +-----------+                |        2
+--R                  2  |          2      (2c x + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      2 |          2  |        2
+--R     c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 63
+
+--S 64 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 64
+
+)clear all
+
+--S 65 of 704
+t0:=x^3/(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 65
+
+--S 66 of 704
+r0:=1/2*log(a+b*x+c*x^2)/c+b*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                                                       +-----------+
+--R                    2c x + b              2            |          2
+--R        2b atanh(--------------) + log(c x  + b x + a)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  ------------------------------------------------------------
+--R                                 +-----------+
+--R                                 |          2
+--R                              2c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                             +-----------+
+--R                2            |          2
+--R         log(c x  + b x + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       2c\|- 4a c + b
+--R     ,
+--R                         +---------+
+--R                         |        2                         +---------+
+--R              (2c x + b)\|4a c - b             2            |        2
+--R    - 2b atan(----------------------) + log(c x  + b x + a)\|4a c - b
+--R                             2
+--R                     4a c - b
+--R    -------------------------------------------------------------------]
+--R                                  +---------+
+--R                                  |        2
+--R                               2c\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 67
+
+--S 68 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                     2c x + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     2c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+
+--R           |        2          2c x + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                        +---------+
+--R           +-----------+                |        2
+--R           |          2      (2c x + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R       +-----------+ +---------+
+--R       |          2  |        2
+--R     c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 71
+
+)clear all
+
+--S 72 of 704
+t0:=x^2/(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 72
+
+--S 73 of 704
+r0:=-2*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                    2c x + b
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  - ----------------------
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                           +-----------+
+--R                 2 2                    2  |          2         2     2
+--R              (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               2
+--R            c x  + b x + a
+--R    /
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R     ,
+--R                     +---------+
+--R                     |        2
+--R          (2c x + b)\|4a c - b
+--R    2atan(----------------------)
+--R                         2
+--R                 4a c - b
+--R    -----------------------------]
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 74
+
+--S 75 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                           +-----------+
+--R                 2 2                    2  |          2         2     2
+--R              (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               2
+--R            c x  + b x + a
+--R     + 
+--R                 2c x + b
+--R       2atanh(--------------)
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R  /
+--R      +-----------+
+--R      |          2
+--R     \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 75
+
+--S 76 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R         +---------+
+--R         |        2          2c x + b
+--R       2\|4a c - b  atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R     + 
+--R                                      +---------+
+--R         +-----------+                |        2
+--R         |          2      (2c x + b)\|4a c - b
+--R       2\|- 4a c + b  atan(----------------------)
+--R                                          2
+--R                                  4a c - b
+--R  /
+--R      +-----------+ +---------+
+--R      |          2  |        2
+--R     \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 704
+t0:=x/(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           3      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 79
+
+--S 80 of 704
+r0:=log(x)/a-1/2*log(a+b*x+c*x^2)/a+b*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                                                +-----------+
+--R               2c x + b                 2                       |          2
+--R   2b atanh(--------------) + (- log(c x  + b x + a) + 2log(x))\|- 4a c + b
+--R             +-----------+
+--R             |          2
+--R            \|- 4a c + b
+--R   --------------------------------------------------------------------------
+--R                                   +-----------+
+--R                                   |          2
+--R                                2a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                           +-----------+
+--R                   2                       |          2
+--R         (- log(c x  + b x + a) + 2log(x))\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       2a\|- 4a c + b
+--R     ,
+--R
+--R                              +---------+
+--R                              |        2
+--R                   (2c x + b)\|4a c - b
+--R         - 2b atan(----------------------)
+--R                                  2
+--R                          4a c - b
+--R       + 
+--R                                           +---------+
+--R                   2                       |        2
+--R         (- log(c x  + b x + a) + 2log(x))\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       2a\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 81
+
+--S 82 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                     2c x + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     2a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+
+--R           |        2          2c x + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                        +---------+
+--R           +-----------+                |        2
+--R           |          2      (2c x + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R       +-----------+ +---------+
+--R       |          2  |        2
+--R     a\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 704
+t0:=1/(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           4      3      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 86
+
+--S 87 of 704
+r0:=(-1)/(a*x)-b*log(x)/a^2+1/2*b*log(a+b*x+c*x^2)/a^2-(b^2-2*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                 2            2c x + b
+--R       (4a c - 2b )x atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                                    +-----------+
+--R                   2                                |          2
+--R       (b x log(c x  + b x + a) - 2b x log(x) - 2a)\|- 4a c + b
+--R  /
+--R          +-----------+
+--R       2  |          2
+--R     2a x\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2
+--R           (2a c - b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                                      +-----------+
+--R                     2                                |          2
+--R         (b x log(c x  + b x + a) - 2b x log(x) - 2a)\|- 4a c + b
+--R    /
+--R            +-----------+
+--R         2  |          2
+--R       2a x\|- 4a c + b
+--R     ,
+--R
+--R                                         +---------+
+--R                                         |        2
+--R                     2        (2c x + b)\|4a c - b
+--R         (- 4a c + 2b )x atan(----------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R                                                      +---------+
+--R                     2                                |        2
+--R         (b x log(c x  + b x + a) - 2b x log(x) - 2a)\|4a c - b
+--R    /
+--R            +---------+
+--R         2  |        2
+--R       2a x\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 88
+
+--S 89 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                   2          2c x + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+--S 91 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+
+--R                  2  |        2          2c x + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                     +-----------+                |        2
+--R                  2  |          2      (2c x + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      2 |          2  |        2
+--R     a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 92
+
+)clear all
+
+--S 93 of 704
+t0:=1/(x*(a*x^2+b*x^3+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           5      4      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 93
+
+--S 94 of 704
+r0:=(-1/2)/(a*x^2)+b/(a^2*x)+(b^2-a*c)*log(x)/a^3-1/2*(b^2-a*c)*_
+   log(a+b*x+c*x^2)/a^3+b*(b^2-3*a*c)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (a^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                     3  2         2c x + b
+--R       (- 6a b c + 2b )x atanh(--------------)
+--R                                +-----------+
+--R                                |          2
+--R                               \|- 4a c + b
+--R     + 
+--R                     2  2       2                          2  2
+--R             (a c - b )x log(c x  + b x + a) + (- 2a c + 2b )x log(x) + 2a b x
+--R           + 
+--R                2
+--R             - a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       3 2 |          2
+--R     2a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3  2
+--R           (3a b c - b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                     2  2       2                          2  2
+--R             (a c - b )x log(c x  + b x + a) + (- 2a c + 2b )x log(x) + 2a b x
+--R           + 
+--R                2
+--R             - a
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             +-----------+
+--R         3 2 |          2
+--R       2a x \|- 4a c + b
+--R     ,
+--R
+--R                                         +---------+
+--R                                         |        2
+--R                     3  2     (2c x + b)\|4a c - b
+--R         (6a b c - 2b )x atan(----------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R                     2  2       2                          2  2
+--R             (a c - b )x log(c x  + b x + a) + (- 2a c + 2b )x log(x) + 2a b x
+--R           + 
+--R                2
+--R             - a
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R             +---------+
+--R         3 2 |        2
+--R       2a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 95
+
+--S 96 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (3a b c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                   3          2c x + b
+--R       (6a b c - 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     2a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+
+--R                  3  |        2          2c x + b
+--R       (3a b c - b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                  +---------+
+--R                     +-----------+                |        2
+--R                  3  |          2      (2c x + b)\|4a c - b
+--R       (3a b c - b )\|- 4a c + b  atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      3 |          2  |        2
+--R     a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 704
+t0:=1/(x^2*(a*x^2+b*x^3+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           6      5      4
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 100
+
+--S 101 of 704
+r0:=(-1/3)/(a*x^3)+1/2*b/(a^2*x^2)+(-b^2+a*c)/(a^3*x)-b*(b^2-2*a*c)*_
+   log(x)/a^4+1/2*b*(b^2-2*a*c)*log(a+b*x+c*x^2)/a^4-(b^4-4*a*b^2*c+_
+   2*a^2*c^2)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^4*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R             2 2        2      4  3         2c x + b
+--R       (- 12a c  + 24a b c - 6b )x atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R     + 
+--R                         3  3       2                           3  3
+--R           (- 6a b c + 3b )x log(c x  + b x + a) + (12a b c - 6b )x log(x)
+--R         + 
+--R              2        2  2     2        3
+--R           (6a c - 6a b )x  + 3a b x - 2a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       4 3 |          2
+--R     6a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              2 2        2      4  3
+--R           (6a c  - 12a b c + 3b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                           3  3       2                           3  3
+--R             (- 6a b c + 3b )x log(c x  + b x + a) + (12a b c - 6b )x log(x)
+--R           + 
+--R                2        2  2     2        3
+--R             (6a c - 6a b )x  + 3a b x - 2a
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             +-----------+
+--R         4 3 |          2
+--R       6a x \|- 4a c + b
+--R     ,
+--R
+--R                                                   +---------+
+--R                                                   |        2
+--R             2 2        2      4  3     (2c x + b)\|4a c - b
+--R         (12a c  - 24a b c + 6b )x atan(----------------------)
+--R                                                       2
+--R                                               4a c - b
+--R       + 
+--R                           3  3       2                           3  3
+--R             (- 6a b c + 3b )x log(c x  + b x + a) + (12a b c - 6b )x log(x)
+--R           + 
+--R                2        2  2     2        3
+--R             (6a c - 6a b )x  + 3a b x - 2a
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R             +---------+
+--R         4 3 |        2
+--R       6a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 102
+
+--S 103 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (2a c  - 4a b c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R          2 2       2      4          2c x + b
+--R       (4a c  - 8a b c + 2b )atanh(--------------)
+--R                                    +-----------+
+--R                                    |          2
+--R                                   \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       4 |          2
+--R     2a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             +---------+
+--R          2 2       2     4  |        2          2c x + b
+--R       (2a c  - 4a b c + b )\|4a c - b  atanh(--------------)
+--R                                               +-----------+
+--R                                               |          2
+--R                                              \|- 4a c + b
+--R     + 
+--R                                                          +---------+
+--R                             +-----------+                |        2
+--R          2 2       2     4  |          2      (2c x + b)\|4a c - b
+--R       (2a c  - 4a b c + b )\|- 4a c + b  atan(----------------------)
+--R                                                              2
+--R                                                      4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R      4 |          2  |        2
+--R     a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 105
+
+--S 106 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 106
+
+)clear all
+
+--S 107 of 704
+t0:=x^8/(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R                              4
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 107
+
+--S 108 of 704
+r0:=2*(b^2-3*a*c)*x/(c^2*(b^2-4*a*c))-b*x^2/(c*(b^2-4*a*c))+_
+   x^3*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))-2*(b^4-6*a*b^2*c+6*a^2*c^2)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^3*(b^2-4*a*c)^(3/2))-_
+   b*log(a+b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   2       2   2        3      5        3 2
+--R           (12a c  - 12a b c  + 2b c)x  + (12a b c  - 12a b c + 2b )x + 12a c
+--R         + 
+--R                2 2        4
+--R           - 12a b c + 2a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                       2    3   2          2     4       2         3
+--R             ((- 4a b c  + b c)x  + (- 4a b c + b )x - 4a b c + a b )
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                3    2 2  3          2     3   2      2 2       2
+--R           (4a c  - b c )x  + (7a b c  - 2b c)x  + (6a c  - 2a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                             +-----------+
+--R           5    2 4  2          4    3 3       2 4      2 3  |          2
+--R     ((4a c  - b c )x  + (4a b c  - b c )x + 4a c  - a b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 108
+
+--S 109 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3       2 2    4   2      2   2       3     5       3 2
+--R             (6a c  - 6a b c  + b c)x  + (6a b c  - 6a b c + b )x + 6a c
+--R           + 
+--R                 2 2       4
+--R             - 6a b c + a b
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                         2    3   2          2     4       2         3
+--R               ((- 4a b c  + b c)x  + (- 4a b c + b )x - 4a b c + a b )
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                  3    2 2  3          2    3   2      2 2       2     4
+--R             (4a c  - b c )x  + (4a b c  - b c)x  + (6a c  - 5a b c + b )x
+--R           + 
+--R                 2         3
+--R             - 3a b c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                               +-----------+
+--R             5    2 4  2          4    3 3       2 4      2 3  |          2
+--R       ((4a c  - b c )x  + (4a b c  - b c )x + 4a c  - a b c )\|- 4a c + b
+--R     ,
+--R
+--R                   2 3        2 2     4   2         2   2        3      5
+--R             (- 12a c  + 12a b c  - 2b c)x  + (- 12a b c  + 12a b c - 2b )x
+--R           + 
+--R                  3 2      2 2        4
+--R             - 12a c  + 12a b c - 2a b
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                         2    3   2          2     4       2         3
+--R               ((- 4a b c  + b c)x  + (- 4a b c + b )x - 4a b c + a b )
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                  3    2 2  3          2    3   2      2 2       2     4
+--R             (4a c  - b c )x  + (4a b c  - b c)x  + (6a c  - 5a b c + b )x
+--R           + 
+--R                 2         3
+--R             - 3a b c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                               +---------+
+--R             5    2 4  2          4    3 3       2 4      2 3  |        2
+--R       ((4a c  - b c )x  + (4a b c  - b c )x + 4a c  - a b c )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 109
+
+--S 110 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (6a c  - 6a b c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R             2 2        2      4          2c x + b
+--R       (- 12a c  + 12a b c - 2b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                       +-----------+
+--R                    3  |          2
+--R       (- 3a b c + b )\|- 4a c + b
+--R  /
+--R                    +-----------+
+--R          4    2 3  |          2
+--R     (4a c  - b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------+
+--R             2 2        2      4  |        2          2c x + b
+--R       (- 12a c  + 12a b c - 2b )\|4a c - b  atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R                                  +-----------+                |        2
+--R             2 2        2      4  |          2      (2c x + b)\|4a c - b
+--R       (- 12a c  + 12a b c - 2b )\|- 4a c + b  atan(----------------------)
+--R                                                                   2
+--R                                                           4a c - b
+--R     + 
+--R                       +-----------+ +---------+
+--R                    3  |          2  |        2
+--R       (- 3a b c + b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R          4    2 3  |          2  |        2
+--R     (4a c  - b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 113
+
+)clear all
+
+--S 114 of 704
+t0:=x^7/(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R                              3
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 114
+
+--S 115 of 704
+r0:=-b*x/(c*(b^2-4*a*c))+x^2*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))+_
+   b*(b^2-6*a*c)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^2*(b^2-_
+   4*a*c)^(3/2))+1/2*log(a+b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R                  2     3   2         2      4        2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x + 12a b c - 2a b )
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 2    2   2              3       2       2        2
+--R           ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )log(c x  + b x + a)
+--R         + 
+--R                  2     2   2
+--R           (- 4a c  + 2b c)x  + 2a b c x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                +-----------+
+--R           4     2 3  2          3     3 2       2 3       2 2  |          2
+--R     ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2    3   2        2     4       2         3
+--R           ((6a b c  - b c)x  + (6a b c - b )x + 6a b c - a b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                   2    2   2              3       2       2        2
+--R             ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )log(c x  + b x + a)
+--R           + 
+--R                         3       2        2
+--R             (6a b c - 2b )x + 4a c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                                  +-----------+
+--R             4     2 3  2          3     3 2       2 3       2 2  |          2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|- 4a c + b
+--R     ,
+--R
+--R                      2     3   2           2      4        2          3
+--R           ((- 12a b c  + 2b c)x  + (- 12a b c + 2b )x - 12a b c + 2a b )
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                   2    2   2              3       2       2        2
+--R             ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )log(c x  + b x + a)
+--R           + 
+--R                         3       2        2
+--R             (6a b c - 2b )x + 4a c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                  +---------+
+--R             4     2 3  2          3     3 2       2 3       2 2  |        2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 116
+
+--S 117 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (6a b c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                                                             +-----------+
+--R                      3          2c x + b                 2  |          2
+--R       (- 12a b c + 2b )atanh(--------------) + (4a c - 2b )\|- 4a c + b
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                     +-----------+
+--R          3     2 2  |          2
+--R     (8a c  - 2b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+
+--R                    3  |        2          2c x + b
+--R       (- 6a b c + b )\|4a c - b  atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                                                    +---------+
+--R                       +-----------+                |        2
+--R                    3  |          2      (2c x + b)\|4a c - b
+--R       (- 6a b c + b )\|- 4a c + b  atan(----------------------)
+--R                                                        2
+--R                                                4a c - b
+--R     + 
+--R                   +-----------+ +---------+
+--R                2  |          2  |        2
+--R       (2a c - b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R          3    2 2  |          2  |        2
+--R     (4a c  - b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 704
+t0:=x^6/(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R                              2
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 121
+
+--S 122 of 704
+r0:=x*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))+4*a*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                2              2          2c x + b
+--R       (- 4a c x  - 4a b x - 4a )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                       +-----------+
+--R             2         |          2
+--R       (- b x  - 2a x)\|- 4a c + b
+--R  /
+--R                                                      +-----------+
+--R           2    2   2              3       2       2  |          2
+--R     ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 2                2
+--R           (2a c x  + 2a b c x + 2a c)
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                                +-----------+
+--R                     2          |          2
+--R         ((- 2a c + b )x + a b)\|- 4a c + b
+--R    /
+--R                                                             +-----------+
+--R             3    2 2  2          2    3        2 2      2   |          2
+--R       ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|- 4a c + b
+--R     ,
+--R
+--R                                                    +---------+
+--R                                                    |        2
+--R              2 2                2       (2c x + b)\|4a c - b
+--R         (4a c x  + 4a b c x + 4a c)atan(----------------------)
+--R                                                        2
+--R                                                4a c - b
+--R       + 
+--R                                +---------+
+--R                     2          |        2
+--R         ((- 2a c + b )x + a b)\|4a c - b
+--R    /
+--R                                                             +---------+
+--R             3    2 2  2          2    3        2 2      2   |        2
+--R       ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 123
+
+--S 124 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         2a c
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                                      +-----------+
+--R                     2c x + b         |          2
+--R       4a c atanh(--------------) + b\|- 4a c + b
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R                   +-----------+
+--R          2    2   |          2
+--R     (4a c  - b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            +---------+
+--R            |        2          2c x + b
+--R       4a c\|4a c - b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R            +-----------+                |        2
+--R            |          2      (2c x + b)\|4a c - b
+--R       4a c\|- 4a c + b  atan(----------------------)
+--R                                             2
+--R                                     4a c - b
+--R     + 
+--R         +-----------+ +---------+
+--R         |          2  |        2
+--R       b\|- 4a c + b  \|4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R          2    2   |          2  |        2
+--R     (4a c  - b c)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 127
+
+)clear all
+
+--S 128 of 704
+t0:=x^5/(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R                              x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 128
+
+--S 129 of 704
+r0:=(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))-2*b*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                                               +-----------+
+--R          2     2                  2c x + b                    |          2
+--R   (2b c x  + 2b x + 2a b)atanh(--------------) + (- b x - 2a)\|- 4a c + b
+--R                                 +-----------+
+--R                                 |          2
+--R                                \|- 4a c + b
+--R   -------------------------------------------------------------------------
+--R                                                          +-----------+
+--R               2    2   2              3       2       2  |          2
+--R         ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2    2
+--R           (b c x  + b x + a b)
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                      +-----------+
+--R                      |          2
+--R         (- b x - 2a)\|- 4a c + b
+--R    /
+--R                                                        +-----------+
+--R             2    2   2              3       2       2  |          2
+--R       ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R     ,
+--R
+--R                                                  +---------+
+--R                                                  |        2
+--R                  2     2              (2c x + b)\|4a c - b
+--R         (- 2b c x  - 2b x - 2a b)atan(----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R       + 
+--R                      +---------+
+--R                      |        2
+--R         (- b x - 2a)\|4a c - b
+--R    /
+--R                                                        +---------+
+--R             2    2   2              3       2       2  |        2
+--R       ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 130
+
+--S 131 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                     2c x + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R              2  |          2
+--R     (4a c - b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            +---------+
+--R            |        2          2c x + b
+--R       - 2b\|4a c - b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R            +-----------+                |        2
+--R            |          2      (2c x + b)\|4a c - b
+--R       - 2b\|- 4a c + b  atan(----------------------)
+--R                                             2
+--R                                     4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 134
+
+)clear all
+
+--S 135 of 704
+t0:=x^4/(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 135
+
+--S 136 of 704
+r0:=(-b-2*c*x)/((b^2-4*a*c)*(a+b*x+c*x^2))+4*c*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                                               +-----------+
+--R        2 2                          2c x + b                  |          2
+--R   (- 4c x  - 4b c x - 4a c)atanh(--------------) + (2c x + b)\|- 4a c + b
+--R                                   +-----------+
+--R                                   |          2
+--R                                  \|- 4a c + b
+--R   -------------------------------------------------------------------------
+--R                                                          +-----------+
+--R               2    2   2              3       2       2  |          2
+--R         ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              2 2
+--R           (2c x  + 2b c x + 2a c)
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                    +-----------+
+--R                    |          2
+--R         (2c x + b)\|- 4a c + b
+--R    /
+--R                                                        +-----------+
+--R             2    2   2              3       2       2  |          2
+--R       ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R     ,
+--R                                           +---------+
+--R                                           |        2                +---------+
+--R       2 2                      (2c x + b)\|4a c - b                 |        2
+--R    (4c x  + 4b c x + 4a c)atan(----------------------) + (2c x + b)\|4a c - b
+--R                                               2
+--R                                       4a c - b
+--R    ----------------------------------------------------------------------------
+--R                                                             +---------+
+--R                  2    2   2              3       2       2  |        2
+--R            ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 137
+
+--S 138 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         2c
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                   2c x + b
+--R       4c atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R              2  |          2
+--R     (4a c - b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 138
+
+--S 139 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +---------+
+--R          |        2          2c x + b
+--R       4c\|4a c - b  atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                       +---------+
+--R          +-----------+                |        2
+--R          |          2      (2c x + b)\|4a c - b
+--R       4c\|- 4a c + b  atan(----------------------)
+--R                                           2
+--R                                   4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 704
+t0:=x^3/(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R         2 5         4            2  3         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 142
+
+--S 143 of 704
+r0:=(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*(a+b*x+c*x^2))+b*(b^2-6*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^(3/2))+log(x)/a^2-_
+   1/2*log(a+b*x+c*x^2)/a^2
+--R 
+--R
+--R   (2)
+--R                  2     3   2         2      4        2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x + 12a b c - 2a b )
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    2   2                3       2       2
+--R             ((- 4a c  + b c)x  + (- 4a b c + b )x - 4a c + a b )
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                 2     2   2               3       2        2
+--R           ((8a c  - 2b c)x  + (8a b c - 2b )x + 8a c - 2a b )log(x) - 2a b c x
+--R         + 
+--R             2        2
+--R           4a c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                             +-----------+
+--R         3 2     2 2   2      3        2 3       4      3 2  |          2
+--R     ((8a c  - 2a b c)x  + (8a b c - 2a b )x + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2    3   2        2     4       2         3
+--R           ((6a b c  - b c)x  + (6a b c - b )x + 6a b c - a b )
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                       2    2   2                3       2       2
+--R               ((- 4a c  + b c)x  + (- 4a b c + b )x - 4a c + a b )
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                   2     2   2               3       2        2
+--R             ((8a c  - 2b c)x  + (8a b c - 2b )x + 8a c - 2a b )log(x)
+--R           + 
+--R                            2        2
+--R             - 2a b c x + 4a c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                               +-----------+
+--R           3 2     2 2   2      3        2 3       4      3 2  |          2
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x + 8a c - 2a b )\|- 4a c + b
+--R     ,
+--R
+--R                      2     3   2           2      4        2          3
+--R           ((- 12a b c  + 2b c)x  + (- 12a b c + 2b )x - 12a b c + 2a b )
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2    2   2                3       2       2
+--R               ((- 4a c  + b c)x  + (- 4a b c + b )x - 4a c + a b )
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                   2     2   2               3       2        2
+--R             ((8a c  - 2b c)x  + (8a b c - 2b )x + 8a c - 2a b )log(x)
+--R           + 
+--R                            2        2
+--R             - 2a b c x + 4a c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                               +---------+
+--R           3 2     2 2   2      3        2 3       4      3 2  |        2
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x + 8a c - 2a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 144
+
+--S 145 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (6a b c - b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R                      3          2c x + b
+--R       (- 12a b c + 2b )atanh(--------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R        3      2 2  |          2
+--R     (8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+
+--R                    3  |        2          2c x + b
+--R       (- 6a b c + b )\|4a c - b  atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                                                    +---------+
+--R                       +-----------+                |        2
+--R                    3  |          2      (2c x + b)\|4a c - b
+--R       (- 6a b c + b )\|- 4a c + b  atan(----------------------)
+--R                                                        2
+--R                                                4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R        3     2 2  |          2  |        2
+--R     (4a c - a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 148
+
+)clear all
+
+--S 149 of 704
+t0:=x^2/(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R         2 6         5            2  4         3    2 2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 149
+
+--S 150 of 704
+r0:=-2*(b^2-3*a*c)/(a^2*(b^2-4*a*c)*x)+(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*_
+   x*(a+b*x+c*x^2))-2*(b^4-6*a*b^2*c+6*a^2*c^2)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(3/2))-2*b*log(x)/a^3+_
+   b*log(a+b*x+c*x^2)/a^3
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   3       2   2        3      5  2
+--R           (12a c  - 12a b c  + 2b c)x  + (12a b c  - 12a b c + 2b )x
+--R         + 
+--R               3 2      2 2        4
+--R           (12a c  - 12a b c + 2a b )x
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    3   3        2     4  2      2         3
+--R             ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x)
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                       2     3   3          2      4  2        2          3
+--R             ((- 8a b c  + 2b c)x  + (- 8a b c + 2b )x  + (- 8a b c + 2a b )x)
+--R          *
+--R             log(x)
+--R         + 
+--R                2 2       2   2        2          3       3     2 2
+--R           (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                              +-----------+
+--R         4 2    3 2   3      4       3 3  2      5     4 2    |          2
+--R     ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 150
+
+--S 151 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3       2 2    4   3      2   2       3     5  2
+--R             (6a c  - 6a b c  + b c)x  + (6a b c  - 6a b c + b )x
+--R           + 
+--R                3 2     2 2       4
+--R             (6a c  - 6a b c + a b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                       2    3   3        2     4  2      2         3
+--R               ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x)
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                         2     3   3          2      4  2        2          3
+--R               ((- 8a b c  + 2b c)x  + (- 8a b c + 2b )x  + (- 8a b c + 2a b )x)
+--R            *
+--R               log(x)
+--R           + 
+--R                  2 2       2   2        2          3       3     2 2
+--R             (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x - 4a c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                                +-----------+
+--R           4 2    3 2   3      4       3 3  2      5     4 2    |          2
+--R       ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)\|- 4a c + b
+--R     ,
+--R
+--R                   2 3        2 2     4   3         2   2        3      5  2
+--R             (- 12a c  + 12a b c  - 2b c)x  + (- 12a b c  + 12a b c - 2b )x
+--R           + 
+--R                   3 2      2 2        4
+--R             (- 12a c  + 12a b c - 2a b )x
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2    3   3        2     4  2      2         3
+--R               ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x)
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                         2     3   3          2      4  2        2          3
+--R               ((- 8a b c  + 2b c)x  + (- 8a b c + 2b )x  + (- 8a b c + 2a b )x)
+--R            *
+--R               log(x)
+--R           + 
+--R                  2 2       2   2        2          3       3     2 2
+--R             (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x - 4a c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                +---------+
+--R           4 2    3 2   3      4       3 3  2      5     4 2    |        2
+--R       ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 151
+
+--S 152 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (6a c  - 6a b c + b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R             2 2        2      4          2c x + b
+--R       (- 12a c  + 12a b c - 2b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R                   +-----------+
+--R        4     3 2  |          2
+--R     (4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+--S 154 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------+
+--R             2 2        2      4  |        2          2c x + b
+--R       (- 12a c  + 12a b c - 2b )\|4a c - b  atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R                                  +-----------+                |        2
+--R             2 2        2      4  |          2      (2c x + b)\|4a c - b
+--R       (- 12a c  + 12a b c - 2b )\|- 4a c + b  atan(----------------------)
+--R                                                                   2
+--R                                                           4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R        4     3 2  |          2  |        2
+--R     (4a c - a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 155
+
+)clear all
+
+--S 156 of 704
+t0:=x/(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R         2 7         6            2  5         4    2 3
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 156
+
+--S 157 of 704
+r0:=1/2*(-3*b^2+8*a*c)/(a^2*(b^2-4*a*c)*x^2)+b*(3*b^2-11*a*c)/(a^3*_
+   (b^2-4*a*c)*x)+(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^2*(a+b*x+c*x^2))+_
+   b*(3*b^4-20*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (a^4*(b^2-4*a*c)^(3/2))+(3*b^2-2*a*c)*log(x)/a^4-1/2*(3*b^2-2*a*c)*_
+   log(a+b*x+c*x^2)/a^4
+--R 
+--R
+--R   (2)
+--R                 2   3        3 2     5   4         2 2 2        4      6  3
+--R           (- 60a b c  + 40a b c  - 6b c)x  + (- 60a b c  + 40a b c - 6b )x
+--R         + 
+--R                 3   2      2 3        5  2
+--R           (- 60a b c  + 40a b c - 6a b )x
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                  2 3        2 2     4   4      2   2        3      5  3
+--R               (8a c  - 14a b c  + 3b c)x  + (8a b c  - 14a b c + 3b )x
+--R             + 
+--R                  3 2      2 2        4  2
+--R               (8a c  - 14a b c + 3a b )x
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                     2 3        2 2     4   4         2   2        3      5  3
+--R               (- 16a c  + 28a b c  - 6b c)x  + (- 16a b c  + 28a b c - 6b )x
+--R             + 
+--R                     3 2      2 2        4  2
+--R               (- 16a c  + 28a b c - 6a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R               2   2       3   3        3 2      2 2        4  2
+--R           (22a b c  - 6a b c)x  + (- 8a c  + 25a b c - 6a b )x
+--R         + 
+--R               3        2 3       4     3 2
+--R           (12a b c - 3a b )x - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                  +-----------+
+--R         5 2     4 2   4      5        4 3  3      6      5 2  2  |          2
+--R     ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   3        3 2     5   4       2 2 2        4      6  3
+--R             (30a b c  - 20a b c  + 3b c)x  + (30a b c  - 20a b c + 3b )x
+--R           + 
+--R                 3   2      2 3        5  2
+--R             (30a b c  - 20a b c + 3a b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                    2 3        2 2     4   4      2   2        3      5  3
+--R                 (8a c  - 14a b c  + 3b c)x  + (8a b c  - 14a b c + 3b )x
+--R               + 
+--R                    3 2      2 2        4  2
+--R                 (8a c  - 14a b c + 3a b )x
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                       2 3        2 2     4   4         2   2        3      5  3
+--R                 (- 16a c  + 28a b c  - 6b c)x  + (- 16a b c  + 28a b c - 6b )x
+--R               + 
+--R                       3 2      2 2        4  2
+--R                 (- 16a c  + 28a b c - 6a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                 2   2       3   3        3 2      2 2        4  2
+--R             (22a b c  - 6a b c)x  + (- 8a c  + 25a b c - 6a b )x
+--R           + 
+--R                 3        2 3       4     3 2
+--R             (12a b c - 3a b )x - 4a c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             5 2     4 2   4      5        4 3  3      6      5 2  2
+--R         ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                 2   3        3 2     5   4       2 2 2        4      6  3
+--R             (60a b c  - 40a b c  + 6b c)x  + (60a b c  - 40a b c + 6b )x
+--R           + 
+--R                 3   2      2 3        5  2
+--R             (60a b c  - 40a b c + 6a b )x
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                    2 3        2 2     4   4      2   2        3      5  3
+--R                 (8a c  - 14a b c  + 3b c)x  + (8a b c  - 14a b c + 3b )x
+--R               + 
+--R                    3 2      2 2        4  2
+--R                 (8a c  - 14a b c + 3a b )x
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                       2 3        2 2     4   4         2   2        3      5  3
+--R                 (- 16a c  + 28a b c  - 6b c)x  + (- 16a b c  + 28a b c - 6b )x
+--R               + 
+--R                       3 2      2 2        4  2
+--R                 (- 16a c  + 28a b c - 6a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                 2   2       3   3        3 2      2 2        4  2
+--R             (22a b c  - 6a b c)x  + (- 8a c  + 25a b c - 6a b )x
+--R           + 
+--R                 3        2 3       4     3 2
+--R             (12a b c - 3a b )x - 4a c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                    +---------+
+--R           5 2     4 2   4      5        4 3  3      6      5 2  2  |        2
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 158
+
+--S 159 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2   2        3      5
+--R         (30a b c  - 20a b c + 3b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R           2   2        3      5          2c x + b
+--R       (60a b c  - 40a b c + 6b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R        5      4 2  |          2
+--R     (8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------+
+--R           2   2        3      5  |        2          2c x + b
+--R       (30a b c  - 20a b c + 3b )\|4a c - b  atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R     + 
+--R                                                               +---------+
+--R                                  +-----------+                |        2
+--R           2   2        3      5  |          2      (2c x + b)\|4a c - b
+--R       (30a b c  - 20a b c + 3b )\|- 4a c + b  atan(----------------------)
+--R                                                                   2
+--R                                                           4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R        5     4 2  |          2  |        2
+--R     (4a c - a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 704
+t0:=1/(a*x^2+b*x^3+c*x^4)^2
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R         2 8         7            2  6         5    2 4
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 163
+
+--S 164 of 704
+r0:=-2/3*(2*b^2-5*a*c)/(a^2*(b^2-4*a*c)*x^3)+b*(2*b^2-7*a*c)/(a^3*_
+   (b^2-4*a*c)*x^2)-2*(2*b^4-9*a*b^2*c+5*a^2*c^2)/(a^4*(b^2-4*a*c)*x)+_
+   (b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^3*(a+b*x+c*x^2))-2*(2*b^6-_
+   15*a*b^4*c+30*a^2*b^2*c^2-10*a^3*c^3)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (a^5*(b^2-4*a*c)^(3/2))-2*b*(2*b^2-3*a*c)*log(x)/a^5+b*(2*b^2-3*a*c)*_
+   log(a+b*x+c*x^2)/a^5
+--R 
+--R
+--R   (2)
+--R                 3 4       2 2 3        4 2      6   5
+--R           (- 60a c  + 180a b c  - 90a b c  + 12b c)x
+--R         + 
+--R                 3   3       2 3 2        5       7  4
+--R           (- 60a b c  + 180a b c  - 90a b c + 12b )x
+--R         + 
+--R                 4 3       3 2 2      2 4         6  3
+--R           (- 60a c  + 180a b c  - 90a b c + 12a b )x
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2   3        3 2     5   5         2 2 2        4      6  4
+--R               (- 36a b c  + 33a b c  - 6b c)x  + (- 36a b c  + 33a b c - 6b )x
+--R             + 
+--R                     3   2      2 3        5  3
+--R               (- 36a b c  + 33a b c - 6a b )x
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                   2   3        3 2      5   5       2 2 2        4       6  4
+--R               (72a b c  - 66a b c  + 12b c)x  + (72a b c  - 66a b c + 12b )x
+--R             + 
+--R                   3   2      2 3         5  3
+--R               (72a b c  - 66a b c + 12a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R               3 3      2 2 2        4   4       3   2      2 3         5  3
+--R           (30a c  - 54a b c  + 12a b c)x  + (51a b c  - 60a b c + 12a b )x
+--R         + 
+--R               4 2      3 2      2 4  2      4        3 3       5     4 2
+--R           (20a c  - 29a b c + 6a b )x  + (8a b c - 2a b )x - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            6 2     5 2   5       6        5 3  4       7      6 2  3
+--R       ((12a c  - 3a b c)x  + (12a b c - 3a b )x  + (12a c - 3a b )x )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3 4      2 2 3        4 2     6   5
+--R             (30a c  - 90a b c  + 45a b c  - 6b c)x
+--R           + 
+--R                 3   3      2 3 2        5      7  4
+--R             (30a b c  - 90a b c  + 45a b c - 6b )x
+--R           + 
+--R                 4 3      3 2 2      2 4        6  3
+--R             (30a c  - 90a b c  + 45a b c - 6a b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2         2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                       2   3        3 2     5   5
+--R                 (- 36a b c  + 33a b c  - 6b c)x
+--R               + 
+--R                     2 2 2        4      6  4         3   2      2 3        5  3
+--R               (- 36a b c  + 33a b c - 6b )x  + (- 36a b c  + 33a b c - 6a b )x
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                     2   3        3 2      5   5       2 2 2        4       6  4
+--R                 (72a b c  - 66a b c  + 12b c)x  + (72a b c  - 66a b c + 12b )x
+--R               + 
+--R                     3   2      2 3         5  3
+--R                 (72a b c  - 66a b c + 12a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                 3 3      2 2 2        4   4       3   2      2 3         5  3
+--R             (30a c  - 54a b c  + 12a b c)x  + (51a b c  - 60a b c + 12a b )x
+--R           + 
+--R                 4 2      3 2      2 4  2      4        3 3       5     4 2
+--R             (20a c  - 29a b c + 6a b )x  + (8a b c - 2a b )x - 4a c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R              6 2     5 2   5       6        5 3  4       7      6 2  3
+--R         ((12a c  - 3a b c)x  + (12a b c - 3a b )x  + (12a c - 3a b )x )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                 3 4       2 2 3        4 2      6   5
+--R             (60a c  - 180a b c  + 90a b c  - 12b c)x
+--R           + 
+--R                 3   3       2 3 2        5       7  4
+--R             (60a b c  - 180a b c  + 90a b c - 12b )x
+--R           + 
+--R                 4 3       3 2 2      2 4         6  3
+--R             (60a c  - 180a b c  + 90a b c - 12a b )x
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2   3        3 2     5   5
+--R                 (- 36a b c  + 33a b c  - 6b c)x
+--R               + 
+--R                     2 2 2        4      6  4         3   2      2 3        5  3
+--R               (- 36a b c  + 33a b c - 6b )x  + (- 36a b c  + 33a b c - 6a b )x
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                     2   3        3 2      5   5       2 2 2        4       6  4
+--R                 (72a b c  - 66a b c  + 12b c)x  + (72a b c  - 66a b c + 12b )x
+--R               + 
+--R                     3   2      2 3         5  3
+--R                 (72a b c  - 66a b c + 12a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                 3 3      2 2 2        4   4       3   2      2 3         5  3
+--R             (30a c  - 54a b c  + 12a b c)x  + (51a b c  - 60a b c + 12a b )x
+--R           + 
+--R                 4 2      3 2      2 4  2      4        3 3       5     4 2
+--R             (20a c  - 29a b c + 6a b )x  + (8a b c - 2a b )x - 4a c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R              6 2     5 2   5       6        5 3  4       7      6 2  3
+--R         ((12a c  - 3a b c)x  + (12a b c - 3a b )x  + (12a c - 3a b )x )
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 165
+
+--S 166 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             3 3      2 2 2        4      6
+--R         (10a c  - 30a b c  + 15a b c - 2b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2         2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R           3 3      2 2 2        4      6          2c x + b
+--R       (20a c  - 60a b c  + 30a b c - 4b )atanh(--------------)
+--R                                                 +-----------+
+--R                                                 |          2
+--R                                                \|- 4a c + b
+--R  /
+--R                   +-----------+
+--R        6     5 2  |          2
+--R     (4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                           +---------+
+--R           3 3      2 2 2        4      6  |        2          2c x + b
+--R       (20a c  - 60a b c  + 30a b c - 4b )\|4a c - b  atanh(--------------)
+--R                                                             +-----------+
+--R                                                             |          2
+--R                                                            \|- 4a c + b
+--R     + 
+--R                                             +-----------+
+--R             3 3      2 2 2        4      6  |          2
+--R         (20a c  - 60a b c  + 30a b c - 4b )\|- 4a c + b
+--R      *
+--R                         +---------+
+--R                         |        2
+--R              (2c x + b)\|4a c - b
+--R         atan(----------------------)
+--R                             2
+--R                     4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R        6     5 2  |          2  |        2
+--R     (4a c - a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 168
+
+--S 169 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 169
+
+)clear all
+
+--S 170 of 704
+t0:=1/(x*(a*x^2+b*x^3+c*x^4)^2)
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R         2 9         8            2  7         6    2 5
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 170
+
+--S 171 of 704
+r0:=1/4*(-5*b^2+12*a*c)/(a^2*(b^2-4*a*c)*x^4)+1/3*b*(5*b^2-17*a*c)/_
+   (a^3*(b^2-4*a*c)*x^3)+1/2*(-5*b^4+22*a*b^2*c-12*a^2*c^2)/(a^4*_
+   (b^2-4*a*c)*x^2)+b*(5*b^4-27*a*b^2*c+29*a^2*c^2)/(a^5*(b^2-4*a*c)*x)+_
+   (b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^4*(a+b*x+c*x^2))+b*(5*b^6-_
+   42*a*b^4*c+105*a^2*b^2*c^2-70*a^3*c^3)*atanh((b+2*c*x)/sqrt(b^2-_
+   4*a*c))/(a^6*(b^2-4*a*c)^(3/2))+(5*b^4-12*a*b^2*c+3*a^2*c^2)*log(x)/a^6-_
+   1/2*(5*b^4-12*a*b^2*c+3*a^2*c^2)*log(a+b*x+c*x^2)/a^6
+--R 
+--R
+--R   (2)
+--R                3   4        2 3 3         5 2      7   6
+--R           (840a b c  - 1260a b c  + 504a b c  - 60b c)x
+--R         + 
+--R                3 2 3        2 4 2         6       8  5
+--R           (840a b c  - 1260a b c  + 504a b c - 60b )x
+--R         + 
+--R                4   3        3 3 2       2 5         7  4
+--R           (840a b c  - 1260a b c  + 504a b c - 60a b )x
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     3 4       2 2 3         4 2      6   6
+--R               (- 72a c  + 306a b c  - 192a b c  + 30b c)x
+--R             + 
+--R                     3   3       2 3 2         5       7  5
+--R               (- 72a b c  + 306a b c  - 192a b c + 30b )x
+--R             + 
+--R                     4 3       3 2 2       2 4         6  4
+--R               (- 72a c  + 306a b c  - 192a b c + 30a b )x
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                    3 4       2 2 3         4 2      6   6
+--R               (144a c  - 612a b c  + 384a b c  - 60b c)x
+--R             + 
+--R                    3   3       2 3 2         5       7  5
+--R               (144a b c  - 612a b c  + 384a b c - 60b )x
+--R             + 
+--R                    4 3       3 2 2       2 4         6  4
+--R               (144a c  - 612a b c  + 384a b c - 60a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R                  3   3       2 3 2        5   5
+--R           (- 348a b c  + 324a b c  - 60a b c)x
+--R         + 
+--R               4 3       3 2 2       2 4         6  4
+--R           (72a c  - 480a b c  + 354a b c - 60a b )x
+--R         + 
+--R                  4   2       3 3       2 5  3       5 2      4 2       3 4  2
+--R           (- 208a b c  + 172a b c - 30a b )x  + (36a c  - 49a b c + 10a b )x
+--R         + 
+--R               5        4 3        6      5 2
+--R           (20a b c - 5a b )x - 12a c + 3a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            7 2      6 2   6       7         6 3  5       8       7 2  4
+--R       ((48a c  - 12a b c)x  + (48a b c - 12a b )x  + (48a c - 12a b )x )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  3   4       2 3 3         5 2      7   6
+--R             (420a b c  - 630a b c  + 252a b c  - 30b c)x
+--R           + 
+--R                  3 2 3       2 4 2         6       8  5
+--R             (420a b c  - 630a b c  + 252a b c - 30b )x
+--R           + 
+--R                  4   3       3 3 2       2 5         7  4
+--R             (420a b c  - 630a b c  + 252a b c - 30a b )x
+--R        *
+--R           log
+--R                                               +-----------+
+--R                     2 2                    2  |          2           2     2
+--R                  (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R                + 
+--R                              3
+--R                  - 4a b c + b
+--R             /
+--R                   2
+--R                c x  + b x + a
+--R       + 
+--R                       3 4       2 2 3         4 2      6   6
+--R                 (- 72a c  + 306a b c  - 192a b c  + 30b c)x
+--R               + 
+--R                       3   3       2 3 2         5       7  5
+--R                 (- 72a b c  + 306a b c  - 192a b c + 30b )x
+--R               + 
+--R                       4 3       3 2 2       2 4         6  4
+--R                 (- 72a c  + 306a b c  - 192a b c + 30a b )x
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                      3 4       2 2 3         4 2      6   6
+--R                 (144a c  - 612a b c  + 384a b c  - 60b c)x
+--R               + 
+--R                      3   3       2 3 2         5       7  5
+--R                 (144a b c  - 612a b c  + 384a b c - 60b )x
+--R               + 
+--R                      4 3       3 2 2       2 4         6  4
+--R                 (144a c  - 612a b c  + 384a b c - 60a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                    3   3       2 3 2        5   5
+--R             (- 348a b c  + 324a b c  - 60a b c)x
+--R           + 
+--R                 4 3       3 2 2       2 4         6  4
+--R             (72a c  - 480a b c  + 354a b c - 60a b )x
+--R           + 
+--R                    4   2       3 3       2 5  3       5 2      4 2       3 4  2
+--R             (- 208a b c  + 172a b c - 30a b )x  + (36a c  - 49a b c + 10a b )x
+--R           + 
+--R                 5        4 3        6      5 2
+--R             (20a b c - 5a b )x - 12a c + 3a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R              7 2      6 2   6       7         6 3  5       8       7 2  4
+--R         ((48a c  - 12a b c)x  + (48a b c - 12a b )x  + (48a c - 12a b )x )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                    3   4        2 3 3         5 2      7   6
+--R             (- 840a b c  + 1260a b c  - 504a b c  + 60b c)x
+--R           + 
+--R                    3 2 3        2 4 2         6       8  5
+--R             (- 840a b c  + 1260a b c  - 504a b c + 60b )x
+--R           + 
+--R                    4   3        3 3 2       2 5         7  4
+--R             (- 840a b c  + 1260a b c  - 504a b c + 60a b )x
+--R        *
+--R                           +---------+
+--R                           |        2
+--R                (2c x + b)\|4a c - b
+--R           atan(----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       3 4       2 2 3         4 2      6   6
+--R                 (- 72a c  + 306a b c  - 192a b c  + 30b c)x
+--R               + 
+--R                       3   3       2 3 2         5       7  5
+--R                 (- 72a b c  + 306a b c  - 192a b c + 30b )x
+--R               + 
+--R                       4 3       3 2 2       2 4         6  4
+--R                 (- 72a c  + 306a b c  - 192a b c + 30a b )x
+--R            *
+--R                      2
+--R               log(c x  + b x + a)
+--R           + 
+--R                      3 4       2 2 3         4 2      6   6
+--R                 (144a c  - 612a b c  + 384a b c  - 60b c)x
+--R               + 
+--R                      3   3       2 3 2         5       7  5
+--R                 (144a b c  - 612a b c  + 384a b c - 60b )x
+--R               + 
+--R                      4 3       3 2 2       2 4         6  4
+--R                 (144a c  - 612a b c  + 384a b c - 60a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                    3   3       2 3 2        5   5
+--R             (- 348a b c  + 324a b c  - 60a b c)x
+--R           + 
+--R                 4 3       3 2 2       2 4         6  4
+--R             (72a c  - 480a b c  + 354a b c - 60a b )x
+--R           + 
+--R                    4   2       3 3       2 5  3       5 2      4 2       3 4  2
+--R             (- 208a b c  + 172a b c - 30a b )x  + (36a c  - 49a b c + 10a b )x
+--R           + 
+--R                 5        4 3        6      5 2
+--R             (20a b c - 5a b )x - 12a c + 3a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R              7 2      6 2   6       7         6 3  5       8       7 2  4
+--R         ((48a c  - 12a b c)x  + (48a b c - 12a b )x  + (48a c - 12a b )x )
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 172
+
+--S 173 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             3   3       2 3 2        5      7
+--R         (70a b c  - 105a b c  + 42a b c - 5b )
+--R      *
+--R         log
+--R                                             +-----------+
+--R                   2 2                    2  |          2           2     2
+--R                (2c x  + 2b c x - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 2
+--R              c x  + b x + a
+--R     + 
+--R              3   3       2 3 2        5       7          2c x + b
+--R       (- 140a b c  + 210a b c  - 84a b c + 10b )atanh(--------------)
+--R                                                        +-----------+
+--R                                                        |          2
+--R                                                       \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R        7      6 2  |          2
+--R     (8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                +---------+
+--R             3   3       2 3 2        5      7  |        2          2c x + b
+--R       (- 70a b c  + 105a b c  - 42a b c + 5b )\|4a c - b  atanh(--------------)
+--R                                                                  +-----------+
+--R                                                                  |          2
+--R                                                                 \|- 4a c + b
+--R     + 
+--R                                                  +-----------+
+--R               3   3       2 3 2        5      7  |          2
+--R         (- 70a b c  + 105a b c  - 42a b c + 5b )\|- 4a c + b
+--R      *
+--R                         +---------+
+--R                         |        2
+--R              (2c x + b)\|4a c - b
+--R         atan(----------------------)
+--R                             2
+--R                     4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R        7     6 2  |          2  |        2
+--R     (4a c - a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 176
+
+)clear all
+
+--S 177 of 704
+t0:=x^2*sqrt(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R           +------------------+
+--R         2 |   4      3      2
+--R   (1)  x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 704
+r0:=1/256*b*(7*b^2-12*a*c)*(b^2-4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(c^(9/2)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   1/960*b*(35*b^2-116*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/c^3-1/1920*(105*b^4-_
+   460*a*b^2*c+256*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/(c^4*x)-1/240*(7*b^2-_
+   16*a*c)*x*sqrt(a*x^2+b*x^3+c*x^4)/c^2+1/40*x^2*(b+8*c*x)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                         +--------------+
+--R              2   2         3        5   |   2
+--R         (720a b c  - 600a b c + 105b )x\|c x  + b x + a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R               5 7         4 6           4      2 3  5
+--R           768c x  + 864b c x  + (1024a c  - 16b c )x
+--R         + 
+--R                      3      3 2  4          2 3         2 2      4   3
+--R           (- 112a b c  + 28b c )x  + (- 256a c  + 344a b c  - 70b c)x
+--R         + 
+--R                2   2          3        5  2          3 2       2 2          4
+--R         (- 976a b c  + 1060a b c - 210b )x  + (- 512a c  + 920a b c - 210a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                +------------------+
+--R          4 +-+ |   4      3      2
+--R     3840c \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             4   4         3 3 3         2 5 2          7
+--R                       23040a b c  + 38400a b c  - 37440a b c  + 2400a b c
+--R                     + 
+--R                            9
+--R                       1050b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                         4 2 3          3 4 2         2 6            8  3
+--R                 (276480a b c  - 115200a b c  - 55680a b c + 16800a b )x
+--R               + 
+--R                         5   3          4 3 2          3 5          2 7  2
+--R                 (276480a b c  + 253440a b c  - 362880a b c + 70560a b )x
+--R               + 
+--R                         5 2 2          4 4           3 6            6   2
+--R                 (737280a b c  - 614400a b c + 107520a b )x + 368640a b c
+--R               + 
+--R                          5 3          4 5
+--R                 - 307200a b c + 53760a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                      4 2 4         3 4 3         2 6 2          8        10  5
+--R             (- 57600a b c  + 19200a b c  + 14880a b c  - 3600a b c - 105b  )x
+--R           + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                 - 115200a b c  - 192000a b c  + 187200a b c  - 12000a b c
+--R               + 
+--R                          9
+--R                 - 5250a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       5 2 3          4 4 2          3 6          2 8  3
+--R             (- 691200a b c  + 288000a b c  + 139200a b c - 42000a b )x
+--R           + 
+--R                       6   3          5 3 2          4 5           3 7  2
+--R             (- 460800a b c  - 422400a b c  + 604800a b c - 117600a b )x
+--R           + 
+--R                       6 2 2          5 4           4 6            7   2
+--R             (- 921600a b c  + 768000a b c - 134400a b )x - 368640a b c
+--R           + 
+--R                    6 3          5 5
+--R             307200a b c - 53760a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                      2   6           3 5       5 4  9
+--R             (- 61440a b c  - 30720a b c  - 768b c )x
+--R           + 
+--R                       3 6          2 2 5           4 4      6 3  8
+--R             (- 122880a c  - 314880a b c  - 42240a b c  - 96b c )x
+--R           + 
+--R                       3   5          2 3 4         5 3       7 2  7
+--R             (- 773120a b c  - 346880a b c  - 576a b c  + 112b c )x
+--R           + 
+--R                       4 5          3 2 4       2 4 3         6 2       8   6
+--R             (- 532480a c  - 999680a b c  + 960a b c  + 464a b c  - 140b c)x
+--R           + 
+--R                        4   4        3 3 3        2 5 2         7        9  5
+--R             (- 1175040a b c  + 7680a b c  - 7488a b c  + 480a b c + 210b )x
+--R           + 
+--R                            5 4          4 2 3         3 4 2         2 6
+--R                   - 491520a c  + 153600a b c  - 70400a b c  - 25600a b c
+--R                 + 
+--R                          8
+--R                   8400a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                     5   3          4 3 2          3 5          2 7  3
+--R             (215040a b c  + 166400a b c  - 256640a b c + 50400a b )x
+--R           + 
+--R                     5 2 2          4 4          3 6  2
+--R             (645120a b c  - 537600a b c + 94080a b )x
+--R           + 
+--R                     6   2          5 3          4 5
+--R             (368640a b c  - 307200a b c + 53760a b )x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                    2 7           2 6        4 5  10
+--R             (24576a c  + 61440a b c  + 7680b c )x
+--R           + 
+--R                     2   6            3 5        5 4  9
+--R             (322560a b c  + 192000a b c  + 8640b c )x
+--R           + 
+--R                     3 6          2 2 5            4 4       6 3  8
+--R             (327680a c  + 929280a b c  + 147200a b c  - 160b c )x
+--R           + 
+--R                      3   5          2 3 4          5 3       7 2  7
+--R             (1507840a b c  + 730240a b c  - 1440a b c  + 280b c )x
+--R           + 
+--R                     4 5           3 2 4        2 4 3          6 2       8   6
+--R             (778240a c  + 1514240a b c  + 4800a b c  + 2320a b c  - 700b c)x
+--R           + 
+--R                      4   4         3 3 3         2 5 2          7         9  5
+--R             (1359360a b c  - 87040a b c  + 95808a b c  - 9920a b c - 1890b )x
+--R           + 
+--R                          5 4          4 2 3          3 4 2         2 6
+--R                   491520a c  - 491520a b c  + 236800a b c  + 72320a b c
+--R                 + 
+--R                             8
+--R                   - 25200a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       5   3          4 3 2          3 5          2 7  3
+--R             (- 399360a b c  - 289280a b c  + 460160a b c - 90720a b )x
+--R           + 
+--R                       5 2 2          4 4           3 6  2
+--R             (- 829440a b c  + 691200a b c - 120960a b )x
+--R           + 
+--R                       6   2          5 3          4 5
+--R             (- 368640a b c  + 307200a b c - 53760a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                     2 6            2 5         4 4  4
+--R             (122880a c  + 307200a b c  + 38400b c )x
+--R           + 
+--R                      2   5            3 4  3            3 5           2 2 4  2
+--R             (1474560a b c  + 614400a b c )x  + (1474560a c  + 2580480a b c )x
+--R           + 
+--R                     3   4            4 4
+--R             3932160a b c x + 1966080a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                       2   6            3 5        5 4  5
+--R             (- 307200a b c  - 153600a b c  - 3840b c )x
+--R           + 
+--R                       3 6           2 2 5            4 4  4
+--R             (- 614400a c  - 1536000a b c  - 192000a b c )x
+--R           + 
+--R                        3   5           2 3 4  3
+--R             (- 3686400a b c  - 1536000a b c )x
+--R           + 
+--R                        4 5           3 2 4  2           4   4            5 4
+--R             (- 2457600a c  - 4300800a b c )x  - 4915200a b c x - 1966080a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                             4   4         3 3 3         2 5 2          7
+--R                       23040a b c  + 38400a b c  - 37440a b c  + 2400a b c
+--R                     + 
+--R                            9
+--R                       1050b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                         4 2 3          3 4 2         2 6            8  3
+--R                 (276480a b c  - 115200a b c  - 55680a b c + 16800a b )x
+--R               + 
+--R                         5   3          4 3 2          3 5          2 7  2
+--R                 (276480a b c  + 253440a b c  - 362880a b c + 70560a b )x
+--R               + 
+--R                         5 2 2          4 4           3 6            6   2
+--R                 (737280a b c  - 614400a b c + 107520a b )x + 368640a b c
+--R               + 
+--R                          5 3          4 5
+--R                 - 307200a b c + 53760a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                      4 2 4         3 4 3         2 6 2          8        10  5
+--R             (- 57600a b c  + 19200a b c  + 14880a b c  - 3600a b c - 105b  )x
+--R           + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                 - 115200a b c  - 192000a b c  + 187200a b c  - 12000a b c
+--R               + 
+--R                          9
+--R                 - 5250a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       5 2 3          4 4 2          3 6          2 8  3
+--R             (- 691200a b c  + 288000a b c  + 139200a b c - 42000a b )x
+--R           + 
+--R                       6   3          5 3 2          4 5           3 7  2
+--R             (- 460800a b c  - 422400a b c  + 604800a b c - 117600a b )x
+--R           + 
+--R                       6 2 2          5 4           4 6            7   2
+--R             (- 921600a b c  + 768000a b c - 134400a b )x - 368640a b c
+--R           + 
+--R                    6 3          5 5
+--R             307200a b c - 53760a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                      2   6           3 5       5 4  9
+--R             (- 30720a b c  - 15360a b c  - 384b c )x
+--R           + 
+--R                      3 6          2 2 5           4 4      6 3  8
+--R             (- 61440a c  - 157440a b c  - 21120a b c  - 48b c )x
+--R           + 
+--R                       3   5          2 3 4         5 3      7 2  7
+--R             (- 386560a b c  - 173440a b c  - 288a b c  + 56b c )x
+--R           + 
+--R                       4 5          3 2 4       2 4 3         6 2      8   6
+--R             (- 266240a c  - 499840a b c  + 480a b c  + 232a b c  - 70b c)x
+--R           + 
+--R                       4   4        3 3 3        2 5 2         7        9  5
+--R             (- 587520a b c  + 3840a b c  - 3744a b c  + 240a b c + 105b )x
+--R           + 
+--R                            5 4         4 2 3         3 4 2         2 6
+--R                   - 245760a c  + 76800a b c  - 35200a b c  - 12800a b c
+--R                 + 
+--R                          8
+--R                   4200a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                     5   3         4 3 2          3 5          2 7  3
+--R             (107520a b c  + 83200a b c  - 128320a b c + 25200a b )x
+--R           + 
+--R                     5 2 2          4 4          3 6  2
+--R             (322560a b c  - 268800a b c + 47040a b )x
+--R           + 
+--R                     6   2          5 3          4 5
+--R             (184320a b c  - 153600a b c + 26880a b )x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                    2 7           2 6        4 5  10
+--R             (12288a c  + 30720a b c  + 3840b c )x
+--R           + 
+--R                     2   6           3 5        5 4  9
+--R             (161280a b c  + 96000a b c  + 4320b c )x
+--R           + 
+--R                     3 6          2 2 5           4 4      6 3  8
+--R             (163840a c  + 464640a b c  + 73600a b c  - 80b c )x
+--R           + 
+--R                     3   5          2 3 4         5 3       7 2  7
+--R             (753920a b c  + 365120a b c  - 720a b c  + 140b c )x
+--R           + 
+--R                     4 5          3 2 4        2 4 3          6 2       8   6
+--R             (389120a c  + 757120a b c  + 2400a b c  + 1160a b c  - 350b c)x
+--R           + 
+--R                     4   4         3 3 3         2 5 2          7        9  5
+--R             (679680a b c  - 43520a b c  + 47904a b c  - 4960a b c - 945b )x
+--R           + 
+--R                          5 4          4 2 3          3 4 2         2 6
+--R                   245760a c  - 245760a b c  + 118400a b c  + 36160a b c
+--R                 + 
+--R                             8
+--R                   - 12600a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                       5   3          4 3 2          3 5          2 7  3
+--R             (- 199680a b c  - 144640a b c  + 230080a b c - 45360a b )x
+--R           + 
+--R                       5 2 2          4 4          3 6  2
+--R             (- 414720a b c  + 345600a b c - 60480a b )x
+--R           + 
+--R                       6   2          5 3          4 5
+--R             (- 184320a b c  + 153600a b c - 26880a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                    2 6            2 5         4 4  4
+--R             (61440a c  + 153600a b c  + 19200b c )x
+--R           + 
+--R                     2   5            3 4  3           3 5           2 2 4  2
+--R             (737280a b c  + 307200a b c )x  + (737280a c  + 1290240a b c )x
+--R           + 
+--R                     3   4           4 4
+--R             1966080a b c x + 983040a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                       2   6           3 5        5 4  5
+--R             (- 153600a b c  - 76800a b c  - 1920b c )x
+--R           + 
+--R                       3 6          2 2 5           4 4  4
+--R             (- 307200a c  - 768000a b c  - 96000a b c )x
+--R           + 
+--R                        3   5          2 3 4  3
+--R             (- 1843200a b c  - 768000a b c )x
+--R           + 
+--R                        4 5           3 2 4  2           4   4           5 4
+--R             (- 1228800a c  - 2150400a b c )x  - 2457600a b c x - 983040a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 179
+
+--S 180 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      4   4         3 3 3         2 5 2          7         9  4
+--R               (23040a b c  + 38400a b c  - 37440a b c  + 2400a b c + 1050b )x
+--R             + 
+--R                       4 2 3          3 4 2         2 6            8  3
+--R               (276480a b c  - 115200a b c  - 55680a b c + 16800a b )x
+--R             + 
+--R                       5   3          4 3 2          3 5          2 7  2
+--R               (276480a b c  + 253440a b c  - 362880a b c + 70560a b )x
+--R             + 
+--R                       5 2 2          4 4           3 6            6   2
+--R               (737280a b c  - 614400a b c + 107520a b )x + 368640a b c
+--R             + 
+--R                        5 3          4 5
+--R               - 307200a b c + 53760a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                    4 2 4         3 4 3         2 6 2          8        10  5
+--R           (- 57600a b c  + 19200a b c  + 14880a b c  - 3600a b c - 105b  )x
+--R         + 
+--R                        5   4          4 3 3          3 5 2         2 7
+--R               - 115200a b c  - 192000a b c  + 187200a b c  - 12000a b c
+--R             + 
+--R                        9
+--R               - 5250a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     5 2 3          4 4 2          3 6          2 8  3
+--R           (- 691200a b c  + 288000a b c  + 139200a b c - 42000a b )x
+--R         + 
+--R                     6   3          5 3 2          4 5           3 7  2
+--R           (- 460800a b c  - 422400a b c  + 604800a b c - 117600a b )x
+--R         + 
+--R                     6 2 2          5 4           4 6            7   2
+--R           (- 921600a b c  + 768000a b c - 134400a b )x - 368640a b c
+--R         + 
+--R                  6 3          5 5
+--R           307200a b c - 53760a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                      4 2 4         3 4 3         2 6 2          8        10  6
+--R               (57600a b c  - 19200a b c  - 14880a b c  + 3600a b c + 105b  )x
+--R             + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                   115200a b c  + 192000a b c  - 187200a b c  + 12000a b c
+--R                 + 
+--R                          9
+--R                   5250a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                       5 2 3          4 4 2          3 6          2 8  4
+--R               (691200a b c  - 288000a b c  - 139200a b c + 42000a b )x
+--R             + 
+--R                       6   3          5 3 2          4 5           3 7  3
+--R               (460800a b c  + 422400a b c  - 604800a b c + 117600a b )x
+--R             + 
+--R                       6 2 2          5 4           4 6  2
+--R               (921600a b c  - 768000a b c + 134400a b )x
+--R             + 
+--R                       7   2          6 3          5 5
+--R               (368640a b c  - 307200a b c + 53760a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                           4   5         3 3 4         2 5 3          7 2
+--R                   - 23040a b c  - 38400a b c  + 37440a b c  - 2400a b c
+--R                 + 
+--R                          9
+--R                   - 1050b c
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            4 2 4         3 4 3         2 6 2           8
+--R                   - 299520a b c  + 76800a b c  + 93120a b c  - 19200a b c
+--R                 + 
+--R                          10
+--R                   - 1050b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            5   4          4 3 3          3 5 2         2 7
+--R                   - 299520a b c  - 568320a b c  + 515520a b c  - 17280a b c
+--R                 + 
+--R                             9
+--R                   - 17850a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                          5 2 3          4 4 2          3 6          2 8  4
+--R               (- 1290240a b c  + 476160a b c  + 311040a b c - 87360a b )x
+--R             + 
+--R                         6   3          5 3 2          4 5           3 7  3
+--R               (- 645120a b c  - 683520a b c  + 923520a b c - 178080a b )x
+--R             + 
+--R                          6 2 2          5 4           4 6  2
+--R               (- 1105920a b c  + 921600a b c - 161280a b )x
+--R             + 
+--R                         7   2          6 3          5 5
+--R               (- 368640a b c  + 307200a b c - 53760a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                        2   6           3 5       5 4  9
+--R               (- 61440a b c  - 30720a b c  - 768b c )x
+--R             + 
+--R                         3 6          2 2 5           4 4      6 3  8
+--R               (- 122880a c  - 314880a b c  - 42240a b c  - 96b c )x
+--R             + 
+--R                         3   5          2 3 4         5 3       7 2  7
+--R               (- 773120a b c  - 346880a b c  - 576a b c  + 112b c )x
+--R             + 
+--R                         4 5          3 2 4       2 4 3         6 2       8   6
+--R               (- 532480a c  - 999680a b c  + 960a b c  + 464a b c  - 140b c)x
+--R             + 
+--R                          4   4        3 3 3        2 5 2         7        9  5
+--R               (- 1175040a b c  + 7680a b c  - 7488a b c  + 480a b c + 210b )x
+--R             + 
+--R                            5 4          4 2 3         3 4 2         2 6
+--R                   - 491520a c  + 153600a b c  - 70400a b c  - 25600a b c
+--R                 + 
+--R                          8
+--R                   8400a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                       5   3          4 3 2          3 5          2 7  3
+--R               (215040a b c  + 166400a b c  - 256640a b c + 50400a b )x
+--R             + 
+--R                       5 2 2          4 4          3 6  2
+--R               (645120a b c  - 537600a b c + 94080a b )x
+--R             + 
+--R                       6   2          5 3          4 5
+--R               (368640a b c  - 307200a b c + 53760a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                      2 7           2 6        4 5  10
+--R               (24576a c  + 61440a b c  + 7680b c )x
+--R             + 
+--R                       2   6            3 5        5 4  9
+--R               (322560a b c  + 192000a b c  + 8640b c )x
+--R             + 
+--R                       3 6          2 2 5            4 4       6 3  8
+--R               (327680a c  + 929280a b c  + 147200a b c  - 160b c )x
+--R             + 
+--R                        3   5          2 3 4          5 3       7 2  7
+--R               (1507840a b c  + 730240a b c  - 1440a b c  + 280b c )x
+--R             + 
+--R                       4 5           3 2 4        2 4 3          6 2       8   6
+--R               (778240a c  + 1514240a b c  + 4800a b c  + 2320a b c  - 700b c)x
+--R             + 
+--R                             4   4         3 3 3         2 5 2          7
+--R                     1359360a b c  - 87040a b c  + 95808a b c  - 9920a b c
+--R                   + 
+--R                            9
+--R                     - 1890b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                          5 4          4 2 3          3 4 2         2 6
+--R                   491520a c  - 491520a b c  + 236800a b c  + 72320a b c
+--R                 + 
+--R                             8
+--R                   - 25200a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         5   3          4 3 2          3 5          2 7  3
+--R               (- 399360a b c  - 289280a b c  + 460160a b c - 90720a b )x
+--R             + 
+--R                         5 2 2          4 4           3 6  2
+--R               (- 829440a b c  + 691200a b c - 120960a b )x
+--R             + 
+--R                         6   2          5 3          4 5
+--R               (- 368640a b c  + 307200a b c - 53760a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                    2 7           2 6        4 5  11
+--R           (- 24576a c  - 61440a b c  - 7680b c )x
+--R         + 
+--R                     2   6            3 5        5 4  10
+--R           (- 322560a b c  - 192000a b c  - 8640b c )x
+--R         + 
+--R                     3 6          2 2 5            4 4       6 3  9
+--R           (- 327680a c  - 929280a b c  - 147200a b c  + 160b c )x
+--R         + 
+--R                      3   5          2 3 4          5 3       7 2  8
+--R           (- 1507840a b c  - 730240a b c  + 1440a b c  - 280b c )x
+--R         + 
+--R                     4 5           3 2 4        2 4 3          6 2       8   7
+--R           (- 778240a c  - 1514240a b c  - 4800a b c  - 2320a b c  + 700b c)x
+--R         + 
+--R                           4   4         3 3 3          2 5 2           7
+--R                 - 1318400a b c  + 33920a b c  - 115296a b c  + 17400a b c
+--R               + 
+--R                      9
+--R                 2100b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          5 4          4 2 3          3 4 2         2 6
+--R                 - 409600a c  + 549120a b c  - 545600a b c  - 34320a b c
+--R               + 
+--R                         8
+--R                 35700a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                   5   3          4 3 2          3 5           2 7  4
+--R           (890880a b c  - 389120a b c  - 626560a b c + 174720a b )x
+--R         + 
+--R                   6 3          5 2 2           4 4           3 6  3
+--R           (327680a c  + 814080a b c  - 1587200a b c + 356160a b )x
+--R         + 
+--R                    6   2           5 3           4 5  2
+--R           (1024000a b c  - 1484800a b c + 322560a b )x
+--R         + 
+--R                   7 2          6 2           5 4
+--R           (262144a c  - 471040a b c + 107520a b )x
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                  2   7           3 6       5 5  12
+--R           (61440a b c  + 30720a b c  + 768b c )x
+--R         + 
+--R                   3 7          2 2 6           4 5       6 4  11
+--R           (122880a c  + 376320a b c  + 72960a b c  + 864b c )x
+--R         + 
+--R                   3   6          2 3 5           5 4      7 3  10
+--R           (957440a b c  + 692480a b c  + 43584a b c  - 16b c )x
+--R         + 
+--R                   4 6           3 2 5          2 4 4         6 3      8 2  9
+--R           (655360a c  + 2087680a b c  + 388160a b c  + 208a b c  + 28b c )x
+--R         + 
+--R                    4   5           3 3 4        2 5 3          7 2      9   8
+--R           (2480640a b c  + 1338880a b c  + 7104a b c  - 1056a b c  - 70b c)x
+--R         + 
+--R                       5 5           4 2 4          3 4 3         2 6 2
+--R               1007616a c  + 2009600a b c  + 123520a b c  + 25024a b c
+--R             + 
+--R                         8        10
+--R               - 10840a b c - 210b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                         5   4         4 3 3          3 5 2         2 7
+--R                 1238528a b c  - 67840a b c  + 462848a b c  - 66480a b c
+--R               + 
+--R                           9
+--R                 - 10710a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      6 4           5 2 3           4 4 2          3 6
+--R               278528a c  - 1212672a b c  + 1312320a b c  + 106000a b c
+--R             + 
+--R                       2 8
+--R               - 94500a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                      6   3          5 3 2           4 5           3 7  4
+--R           (- 1501184a b c  + 718336a b c  + 1129600a b c - 319200a b )x
+--R         + 
+--R                     7 3           6 2 2           5 4           4 6  3
+--R           (- 458752a c  - 1057792a b c  + 2216960a b c - 504000a b )x
+--R         + 
+--R                      7   2           6 3           5 5  2
+--R           (- 1155072a b c  + 1720320a b c - 376320a b )x
+--R         + 
+--R                     8 2          7 2           6 4
+--R           (- 262144a c  + 471040a b c - 107520a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                     2 6            2 5         4 4  4
+--R             (122880a c  + 307200a b c  + 38400b c )x
+--R           + 
+--R                      2   5            3 4  3            3 5           2 2 4  2
+--R             (1474560a b c  + 614400a b c )x  + (1474560a c  + 2580480a b c )x
+--R           + 
+--R                     3   4            4 4
+--R             3932160a b c x + 1966080a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                       2   6            3 5        5 4  5
+--R             (- 307200a b c  - 153600a b c  - 3840b c )x
+--R           + 
+--R                       3 6           2 2 5            4 4  4
+--R             (- 614400a c  - 1536000a b c  - 192000a b c )x
+--R           + 
+--R                        3   5           2 3 4  3
+--R             (- 3686400a b c  - 1536000a b c )x
+--R           + 
+--R                        4 5           3 2 4  2           4   4            5 4
+--R             (- 2457600a c  - 4300800a b c )x  - 4915200a b c x - 1966080a c
+--R        *
+--R            +-+
+--R           \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 180
+
+--S 181 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                              6 7          5 2 6          4 4 5          3 6 4
+--R                       - 8192a c  - 135168a b c  - 253440a b c  - 118272a b c
+--R                     + 
+--R                               2 8 3         10 2     12
+--R                       - 15840a b c  - 528a b  c  - 2b  c
+--R                  *
+--R                      17
+--R                     x
+--R                 + 
+--R                                6   6           5 3 5           4 5 4
+--R                       - 643072a b c  - 2996224a b c  - 2762496a b c
+--R                     + 
+--R                                3 7 3         2 9 2         11     13
+--R                       - 718080a b c  - 53680a b c  - 888a b  c - b
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                7 6            6 2 5            5 4 4
+--R                       - 696320a c  - 11661312a b c  - 22330880a b c
+--R                     + 
+--R                                4 6 3           3 8 2         2 10          12
+--R                     - 10762752a b c  - 1523808a b c  - 57200a b  c - 338a b
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                                  7   5            6 3 4            5 5 3
+--R                       - 18235392a b c  - 83865600a b c  - 75851776a b c
+--R                     + 
+--R                                  4 7 2           3 9          2 11
+--R                       - 19109376a b c  - 1345344a b c - 18928a b
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                 8 5             7 2 4             6 4 3
+--R                       - 9863168a c  - 159129600a b c  - 288870400a b c
+--R                     + 
+--R                                   5 6 2            4 8           3 10
+--R                       - 128128000a b c  - 15649920a b c - 416416a b
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                   8   4             7 3 3             6 5 2
+--R                       - 147718144a b c  - 628490240a b c  - 505430016a b c
+--R                     + 
+--R                                   5 7            4 9
+--R                       - 104259584a b c - 4759040a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                  9 4             8 2 3              7 4 2
+--R                       - 53215232a c  - 779878400a b c  - 1228308480a b c
+--R                     + 
+--R                                   6 6             5 8
+--R                       - 430882816a b c - 32361472a b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                   9   3              8 3 2              7 5
+--R                       - 512753664a b c  - 1858338816a b c  - 1153105920a b c
+--R                     + 
+--R                                   6 7
+--R                       - 141213696a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                   10 3              9 2 2              8 4
+--R                       - 138412032a  c  - 1703411712a b c  - 2032140288a b c
+--R                     + 
+--R                                   7 6
+--R                       - 412778496a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                10   2              9 3              8 5  8
+--R                   (- 865075200a  b c  - 2340945920a b c - 825556992a b )x
+--R                 + 
+--R                                11 2              10 2               9 4  7
+--R                   (- 186646528a  c  - 1695547392a  b c - 1133117440a b )x
+--R                 + 
+--R                                11                 10 3  6
+--R                   (- 700448768a  b c - 1049624576a  b )x
+--R                 + 
+--R                                12              11 2  5             12   4
+--R                   (- 125829120a  c - 627048448a  b )x  - 218103808a  b x
+--R                 + 
+--R                              13 3
+--R                   - 33554432a  x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                             5   7          4 3 6          3 5 5         2 7 4
+--R                       49152a b c  + 225280a b c  + 202752a b c  + 50688a b c
+--R                     + 
+--R                              9 3      11 2
+--R                       3520a b c  + 48b  c
+--R                  *
+--R                      17
+--R                     x
+--R                 + 
+--R                              6 7           5 2 6           4 4 5
+--R                       106496a c  + 1781760a b c  + 3407360a b c
+--R                     + 
+--R                               3 6 4          2 8 3          10 2      12
+--R                       1638912a b c  + 231264a b c  + 8624a b  c  + 50b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                               6   6            5 3 5            4 5 4
+--R                       4177920a b c  + 19435520a b c  + 17864704a b c
+--R                     + 
+--R                               3 7 3          2 9 2          11
+--R                       4612608a b c  + 338624a b c  + 5200a b  c
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                               7 6            6 2 5            5 4 4
+--R                       2981888a c  + 49029120a b c  + 91320320a b c
+--R                     + 
+--R                                4 6 3           3 8 2          2 10
+--R                       42025984a b c  + 5436288a b c  + 160160a b  c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                7   5             6 3 4             5 5 3
+--R                       56197120a b c  + 246579200a b c  + 206868480a b c
+--R                     + 
+--R                                4 7 2           3 9
+--R                       45393920a b c  + 2288000a b c
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                8 5             7 2 4             6 4 3
+--R                       23855104a c  + 361496576a b c  + 595230720a b c
+--R                     + 
+--R                                 5 6 2            4 8
+--R                       222150656a b c  + 18304000a b c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                 8   4              7 3 3             6 5 2
+--R                       271581184a b c  + 1029439488a b c  + 678494208a b c
+--R                     + 
+--R                                5 7
+--R                       90521600a b c
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                9 4              8 2 3              7 4 2
+--R                       81788928a c  + 1052246016a b c  + 1330249728a b c
+--R                     + 
+--R                                 6 6
+--R                       292454400a b c
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                              9   3              8 3 2             7 5   9
+--R                   (585105408a b c  + 1673527296a b c  + 635043840a b c)x
+--R                 + 
+--R                              10 3              9 2 2             8 4   8
+--R                   (136314880a  c  + 1305477120a b c  + 933888000a b c)x
+--R                 + 
+--R                              10   2             9 3   7
+--R                   (574619648a  b c  + 917504000a b c)x
+--R                 + 
+--R                              11 2             10 2   6             11     5
+--R                   (109051904a  c  + 576716800a  b c)x  + 209715200a  b c x
+--R                 + 
+--R                            12   4
+--R                   33554432a  c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                         5   7          4 3 6          3 5 5         2 7 4
+--R                   49152a b c  + 225280a b c  + 202752a b c  + 50688a b c
+--R                 + 
+--R                          9 3      11 2
+--R                   3520a b c  + 48b  c
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                          6 7           5 2 6           4 4 5           3 6 4
+--R                   106496a c  + 1806336a b c  + 3520000a b c  + 1740288a b c
+--R                 + 
+--R                          2 8 3           10 2      12
+--R                   256608a b c  + 10384a b  c  + 74b  c
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                           6   6            5 3 5            4 5 4
+--R                   4284416a b c  + 20619264a b c  + 19897856a b c
+--R                 + 
+--R                           3 7 3          2 9 2          11       13
+--R                   5541888a b c  + 465696a b c  + 9824a b  c + 26b
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                           7 6            6 2 5             5 4 4
+--R                   3088384a c  + 53194752a b c  + 105797120a b c
+--R                 + 
+--R                            4 6 3           3 8 2          2 10           12
+--R                   53813760a b c  + 8277984a b c  + 359216a b  c + 2938a b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                            7   5             6 3 4             5 5 3
+--R                   62160896a b c  + 295321600a b c  + 279179264a b c
+--R                 + 
+--R                            4 7 2           3 9          2 11
+--R                   74973184a b c  + 5838976a b c + 99008a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                            8 5             7 2 4             6 4 3
+--R                   26836992a c  + 445505536a b c  + 839659520a b c
+--R                 + 
+--R                             5 6 2            4 8            3 10
+--R                   392211456a b c  + 51708800a b c + 1560416a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                             8   4              7 3 3              6 5 2
+--R                   343146496a b c  + 1508376576a b c  + 1266843648a b c
+--R                 + 
+--R                             5 7             4 9
+--R                   277741568a b c + 13911040a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             9 4              8 2 3              7 4 2
+--R                   105644032a c  + 1593573376a b c  + 2605350912a b c
+--R                 + 
+--R                             6 6             5 8
+--R                   961200128a b c + 77622272a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                             9   3              8 3 2              7 5
+--R                   912261120a b c  + 3416260608a b c  + 2212626432a b c
+--R                 + 
+--R                             6 7
+--R                   287440896a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             10 3              9 2 2              8 4
+--R                   218103808a  c  + 2763522048a b c  + 3421765632a b c
+--R                 + 
+--R                             7 6
+--R                   730300416a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                           10   2              9 3               8 5  8
+--R               (1256194048a  b c  + 3512729600a b c + 1292500992a b )x
+--R             + 
+--R                          11 2              10 2               9 4  7
+--R               (245366784a  c  + 2295332864a  b c + 1591869440a b )x
+--R             + 
+--R                          11                 10 3  6
+--R               (864026624a  b c + 1337982976a  b )x
+--R             + 
+--R                          12              11 2  5             12   4
+--R               (142606336a  c + 731906048a  b )x  + 234881024a  b x
+--R             + 
+--R                        13 3
+--R               33554432a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                      6 8          5 2 7          4 4 6          3 6 5
+--R               - 8192a c  - 135168a b c  - 253440a b c  - 118272a b c
+--R             + 
+--R                       2 8 4         10 3     12 2
+--R               - 15840a b c  - 528a b  c  - 2b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                        6   7           5 3 6           4 5 5          3 7 4
+--R               - 647168a b c  - 3063808a b c  - 2889216a b c  - 777216a b c
+--R             + 
+--R                       2 9 3          11 2     13
+--R               - 61600a b c  - 1152a b  c  - 2b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                        7 7            6 2 6            5 4 5            4 6 4
+--R               - 696320a c  - 11956224a b c  - 23682560a b c  - 11979264a b c
+--R             + 
+--R                         3 8 3         2 10 2         12
+--R               - 1827936a b c  - 78320a b  c  - 626a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                          7   6            6 3 5            5 5 4
+--R               - 18530304a b c  - 88657920a b c  - 84637696a b c
+--R             + 
+--R                          4 7 3           3 9 2         2 11
+--R               - 23063040a b c  - 1839552a b c  - 32656a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                         8 6             7 2 5             6 4 4
+--R               - 9863168a c  - 166010880a b c  - 318689280a b c
+--R             + 
+--R                           5 6 3            4 8 2          3 10
+--R               - 152728576a b c  - 20921472a b c  - 672672a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                           8   5             7 3 4             6 5 3
+--R               - 151158784a b c  - 680099840a b c  - 589295616a b c
+--R             + 
+--R                           5 7 2           4 9
+--R               - 135010304a b c  - 7230080a b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                          9 5             8 2 4              7 4 3
+--R               - 53215232a c  - 823918592a b c  - 1393459200a b c
+--R             + 
+--R                           6 6 2            5 8
+--R               - 538230784a b c  - 46418944a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           9   4              8 3 3              7 5 2
+--R               - 527433728a b c  - 2045509632a b c  - 1387069440a b c
+--R             + 
+--R                           6 7
+--R               - 191905792a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                           10 4              9 2 3              8 4 2
+--R               - 138412032a  c  - 1816657920a b c  - 2353004544a b c
+--R             + 
+--R                           7 6
+--R               - 533102592a b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        10   3              9 3 2              8 5   9
+--R           (- 893386752a  b c  - 2609905664a b c  - 1016070144a b c)x
+--R         + 
+--R                        11 3              10 2 2              9 4   8
+--R           (- 186646528a  c  - 1821376512a  b c  - 1332346880a b c)x
+--R         + 
+--R                        11   2              10 3   7
+--R           (- 725614592a  b c  - 1181745152a  b c)x
+--R         + 
+--R                        12 2             11 2   6             12     5
+--R           (- 125829120a  c  - 677380096a  b c)x  - 226492416a  b c x
+--R         + 
+--R                      13   4
+--R           - 33554432a  c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                           5   7          4 3 6          3 5 5         2 7 4
+--R                   - 49152a b c  - 225280a b c  - 202752a b c  - 50688a b c
+--R                 + 
+--R                            9 3      11 2
+--R                   - 3520a b c  - 48b  c
+--R              *
+--R                  19
+--R                 x
+--R             + 
+--R                            6 7           5 2 6           4 4 5           3 6 4
+--R                   - 106496a c  - 1806336a b c  - 3520000a b c  - 1740288a b c
+--R                 + 
+--R                            2 8 3           10 2      12
+--R                   - 256608a b c  - 10384a b  c  - 74b  c
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                             6   6            5 3 5            4 5 4
+--R                   - 4284416a b c  - 20619264a b c  - 19897856a b c
+--R                 + 
+--R                             3 7 3          2 9 2          11       13
+--R                   - 5541888a b c  - 465696a b c  - 9824a b  c - 26b
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                             7 6            6 2 5             5 4 4
+--R                   - 3088384a c  - 53194752a b c  - 105797120a b c
+--R                 + 
+--R                              4 6 3           3 8 2          2 10           12
+--R                   - 53813760a b c  - 8277984a b c  - 359216a b  c - 2938a b
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                              7   5             6 3 4             5 5 3
+--R                   - 62160896a b c  - 295321600a b c  - 279179264a b c
+--R                 + 
+--R                              4 7 2           3 9          2 11
+--R                   - 74973184a b c  - 5838976a b c - 99008a b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                              8 5             7 2 4             6 4 3
+--R                   - 26836992a c  - 445505536a b c  - 839659520a b c
+--R                 + 
+--R                               5 6 2            4 8            3 10
+--R                   - 392211456a b c  - 51708800a b c - 1560416a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                               8   4              7 3 3              6 5 2
+--R                   - 343146496a b c  - 1508376576a b c  - 1266843648a b c
+--R                 + 
+--R                               5 7             4 9
+--R                   - 277741568a b c - 13911040a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                               9 4              8 2 3              7 4 2
+--R                   - 105644032a c  - 1593573376a b c  - 2605350912a b c
+--R                 + 
+--R                               6 6             5 8
+--R                   - 961200128a b c - 77622272a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                               9   3              8 3 2              7 5
+--R                   - 912261120a b c  - 3416260608a b c  - 2212626432a b c
+--R                 + 
+--R                               6 7
+--R                   - 287440896a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                               10 3              9 2 2              8 4
+--R                   - 218103808a  c  - 2763522048a b c  - 3421765632a b c
+--R                 + 
+--R                               7 6
+--R                   - 730300416a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             10   2              9 3               8 5  9
+--R               (- 1256194048a  b c  - 3512729600a b c - 1292500992a b )x
+--R             + 
+--R                            11 2              10 2               9 4  8
+--R               (- 245366784a  c  - 2295332864a  b c - 1591869440a b )x
+--R             + 
+--R                            11                 10 3  7
+--R               (- 864026624a  b c - 1337982976a  b )x
+--R             + 
+--R                            12              11 2  6             12   5
+--R               (- 142606336a  c - 731906048a  b )x  - 234881024a  b x
+--R             + 
+--R                          13 4
+--R               - 33554432a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                    6 8          5 2 7          4 4 6          3 6 5
+--R               8192a c  + 135168a b c  + 253440a b c  + 118272a b c
+--R             + 
+--R                     2 8 4         10 3     12 2
+--R               15840a b c  + 528a b  c  + 2b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                      6   7           5 3 6           4 5 5          3 7 4
+--R               647168a b c  + 3063808a b c  + 2889216a b c  + 777216a b c
+--R             + 
+--R                     2 9 3          11 2     13
+--R               61600a b c  + 1152a b  c  + 2b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                      7 7            6 2 6            5 4 5            4 6 4
+--R               696320a c  + 11956224a b c  + 23682560a b c  + 11979264a b c
+--R             + 
+--R                       3 8 3         2 10 2         12
+--R               1827936a b c  + 78320a b  c  + 626a b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                        7   6            6 3 5            5 5 4            4 7 3
+--R               18530304a b c  + 88657920a b c  + 84637696a b c  + 23063040a b c
+--R             + 
+--R                       3 9 2         2 11
+--R               1839552a b c  + 32656a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                       8 6             7 2 5             6 4 4             5 6 3
+--R               9863168a c  + 166010880a b c  + 318689280a b c  + 152728576a b c
+--R             + 
+--R                        4 8 2          3 10
+--R               20921472a b c  + 672672a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                         8   5             7 3 4             6 5 3
+--R               151158784a b c  + 680099840a b c  + 589295616a b c
+--R             + 
+--R                         5 7 2           4 9
+--R               135010304a b c  + 7230080a b c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        9 5             8 2 4              7 4 3
+--R               53215232a c  + 823918592a b c  + 1393459200a b c
+--R             + 
+--R                         6 6 2            5 8
+--R               538230784a b c  + 46418944a b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         9   4              8 3 3              7 5 2
+--R               527433728a b c  + 2045509632a b c  + 1387069440a b c
+--R             + 
+--R                         6 7
+--R               191905792a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         10 4              9 2 3              8 4 2
+--R               138412032a  c  + 1816657920a b c  + 2353004544a b c
+--R             + 
+--R                         7 6
+--R               533102592a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                      10   3              9 3 2              8 5   10
+--R           (893386752a  b c  + 2609905664a b c  + 1016070144a b c)x
+--R         + 
+--R                      11 3              10 2 2              9 4   9
+--R           (186646528a  c  + 1821376512a  b c  + 1332346880a b c)x
+--R         + 
+--R                      11   2              10 3   8
+--R           (725614592a  b c  + 1181745152a  b c)x
+--R         + 
+--R                      12 2             11 2   7             12     6
+--R           (125829120a  c  + 677380096a  b c)x  + 226492416a  b c x
+--R         + 
+--R                    13   5
+--R           33554432a  c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                    6 8          5 2 7          4 4 6          3 6 5
+--R               8192a c  + 135168a b c  + 253440a b c  + 118272a b c
+--R             + 
+--R                     2 8 4         10 3     12 2
+--R               15840a b c  + 528a b  c  + 2b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                      6   7           5 3 6           4 5 5          3 7 4
+--R               651264a b c  + 3131392a b c  + 3015936a b c  + 836352a b c
+--R             + 
+--R                     2 9 3          11 2     13
+--R               69520a b c  + 1416a b  c  + 3b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                      7 7            6 2 6            5 4 5            4 6 4
+--R               704512a c  + 12439552a b c  + 25580544a b c  + 13643520a b c
+--R             + 
+--R                       3 8 3          2 10 2          12     14
+--R               2257728a b c  + 111408a b  c  + 1228a b  c + b
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                        7   6            6 3 5             5 5 4
+--R               19574784a b c  + 98523136a b c  + 100945152a b c
+--R             + 
+--R                        4 7 3           3 9 2         2 11          13
+--R               30590208a b c  + 2922832a b c  + 77016a b  c + 339a b
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                        8 6             7 2 5             6 4 4
+--R               10559488a c  + 189026304a b c  + 395066880a b c
+--R             + 
+--R                         5 6 3            4 8 2           3 10          2 12
+--R               214742528a b c  + 36283104a b c  + 1818960a b  c + 19266a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                         8   5             7 3 4             6 5 3
+--R               175816704a b c  + 871485440a b c  + 870152192a b c
+--R             + 
+--R                         5 7 2            4 9           3 11
+--R               251496960a b c  + 21754304a b c + 435344a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        9 5              8 2 4              7 4 3
+--R               63078400a c  + 1086726144a b c  + 2145669120a b c
+--R             + 
+--R                          6 6 2             5 8            4 10
+--R               1064440832a b c  + 152270976a b c + 5175456a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                         9   4              8 3 3              7 5 2
+--R               713687040a b c  + 3266707456a b c  + 2886844416a b c
+--R             + 
+--R                         6 7             5 9
+--R               676356096a b c + 37120512a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         10 4              9 2 3              8 4 2
+--R               191627264a  c  + 2996043776a b c  + 5118787584a b c
+--R             + 
+--R                          7 6              6 8
+--R               1996767232a b c + 173575168a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          10   3              9 3 2              8 5
+--R               1516240896a  b c  + 5902696448a b c  + 4010803200a b c
+--R             + 
+--R                         7 7
+--R               553992192a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         11 3              10 2 2              9 4
+--R               325058560a  c  + 4264034304a  b c  + 5506203648a b c
+--R             + 
+--R                          8 6
+--R               1238335488a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                       11   2              10 3               9 5  9
+--R           (1752170496a  b c  + 5086117888a  b c + 1958674432a b )x
+--R         + 
+--R                      12 2              11 2               10 4  8
+--R           (312475648a  c  + 3023044608a  b c + 2182742016a  b )x
+--R         + 
+--R                       12                 11 3  7
+--R           (1044381696a  b c + 1676673024a  b )x
+--R         + 
+--R                    13              12 2  6             13   5            14 4
+--R         (159383552a  c + 845152256a  b )x  + 251658240a  b x  + 33554432a  x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                       5   8          4 3 7          3 5 6         2 7 5
+--R               - 49152a b c  - 225280a b c  - 202752a b c  - 50688a b c
+--R             + 
+--R                        9 4      11 3
+--R               - 3520a b c  - 48b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                        6 8           5 2 7           4 4 6           3 6 5
+--R               - 106496a c  - 1830912a b c  - 3632640a b c  - 1841664a b c
+--R             + 
+--R                        2 8 4           10 3      12 2
+--R               - 281952a b c  - 12144a b  c  - 98b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                         6   7            5 3 6            4 5 5           3 7 4
+--R               - 4333568a b c  - 21442560a b c  - 21474816a b c  - 6302208a b c
+--R             + 
+--R                        2 9 3           11 2      13
+--R               - 573408a b c  - 13872a b  c  - 50b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                         7 7            6 2 6             5 4 5            4 6 4
+--R               - 3088384a c  - 54988800a b c  - 114163200a b c  - 61529600a b c
+--R             + 
+--R                          3 8 3          2 10 2          12
+--R               - 10280160a b c  - 507408a b  c  - 5250a b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                          7   6             6 3 5             5 5 4
+--R               - 63356928a b c  - 315043840a b c  - 316053504a b c
+--R             + 
+--R                          4 7 3           3 9 2          2 11
+--R               - 92032512a b c  - 8062912a b c  - 165360a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                          8 6             7 2 5             6 4 4
+--R               - 26836992a c  - 466722816a b c  - 933130240a b c
+--R             + 
+--R                           5 6 3            4 8 2           3 10
+--R               - 471045120a b c  - 69134208a b c  - 2448160a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                           8   5              7 3 4              6 5 3
+--R               - 351633408a b c  - 1637515264a b c  - 1480593408a b c
+--R             + 
+--R                           5 7 2            4 9
+--R               - 358066176a b c  - 20592000a b c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                           9 5              8 2 4              7 4 3
+--R               - 105644032a c  - 1685323776a b c  - 2954919936a b c
+--R             + 
+--R                            6 6 2             5 8
+--R               - 1193099264a b c  - 108825600a b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                           9   4              8 3 3              7 5 2
+--R               - 938475520a b c  - 3755212800a b c  - 2643787776a b c
+--R             + 
+--R                           6 7
+--R               - 382976000a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           10 4              9 2 3              8 4 2
+--R               - 218103808a  c  - 2942828544a b c  - 3937665024a b c
+--R             + 
+--R                           7 6
+--R               - 927498240a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         10   3              9 3 2              8 5   10
+--R           (- 1296039936a  b c  - 3896508416a b c  - 1568931840a b c)x
+--R         + 
+--R                        11 3              10 2 2              9 4   9
+--R           (- 245366784a  c  - 2456813568a  b c  - 1851392000a b c)x
+--R         + 
+--R                        11   2              10 3   8
+--R           (- 893386752a  b c  - 1494220800a  b c)x
+--R         + 
+--R                        12 2             11 2   7             12     6
+--R           (- 142606336a  c  - 786432000a  b c)x  - 243269632a  b c x
+--R         + 
+--R                      13   5
+--R           - 33554432a  c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                           5   6          4 3 5          3 5 4         2 7 3
+--R                     49152a b c  + 225280a b c  + 202752a b c  + 50688a b c
+--R                   + 
+--R                            9 2      11
+--R                     3520a b c  + 48b  c
+--R                *
+--R                    13
+--R                   x
+--R               + 
+--R                            6 6           5 2 5           4 4 4           3 6 3
+--R                     106496a c  + 1757184a b c  + 3294720a b c  + 1537536a b c
+--R                   + 
+--R                            2 8 2          10       12
+--R                     205920a b c  + 6864a b  c + 26b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                             6   5            5 3 4            4 5 3
+--R                     4128768a b c  + 18636800a b c  + 16400384a b c
+--R                   + 
+--R                             3 7 2          2 9           11
+--R                     3953664a b c  + 256256a b c + 2912a b
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                             7 5            6 2 4            5 4 3
+--R                     2981888a c  + 47308800a b c  + 83865600a b c
+--R                   + 
+--R                              4 6 2           3 8          2 10
+--R                     35875840a b c  + 4118400a b c + 96096a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              7   4             6 3 3             5 5 2
+--R                     55050240a b c  + 229376000a b c  + 178913280a b c
+--R                   + 
+--R                              4 7            3 9
+--R                     35143680a b c + 1464320a b
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                              8 4             7 2 3             6 4 2
+--R                     23855104a c  + 343146496a b c  + 526417920a b c
+--R                   + 
+--R                               5 6             4 8
+--R                     177422336a b c + 12446720a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                               8   3             7 3 2             6 5
+--R                     264241152a b c  + 935854080a b c  + 561512448a b c
+--R                   + 
+--R                              5 7
+--R                     65175552a b
+--R                *
+--R                    7
+--R                   x
+--R               + 
+--R                              9 3             8 2 2              7 4
+--R                     81788928a c  + 986185728a b c  + 1143078912a b c
+--R                   + 
+--R                               6 6
+--R                     222265344a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                            9   2              8 3              7 5  5
+--R                 (566231040a b c  + 1494220800a b c + 508035072a b )x
+--R               + 
+--R                            10 2              9 2              8 4  4
+--R                 (136314880a  c  + 1211105280a b c + 784465920a b )x
+--R               + 
+--R                            10                9 3  3
+--R                 (553648128a  b c + 807403520a b )x
+--R               + 
+--R                            11              10 2  2             11
+--R                 (109051904a  c + 530579456a  b )x  + 201326592a  b x
+--R               + 
+--R                          12
+--R                 33554432a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                        6 7          5 2 6          4 4 5          3 6 4
+--R                 - 8192a c  - 135168a b c  - 253440a b c  - 118272a b c
+--R               + 
+--R                         2 8 3         10 2     12
+--R                 - 15840a b c  - 528a b  c  - 2b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                          6   6           5 3 5           4 5 4          3 7 3
+--R                 - 638976a b c  - 2928640a b c  - 2635776a b c  - 658944a b c
+--R               + 
+--R                         2 9 2         11
+--R                 - 45760a b c  - 624a b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          7 6            6 2 5            5 4 4           4 6 3
+--R                 - 688128a c  - 11182080a b c  - 20500480a b c  - 9225216a b c
+--R               + 
+--R                           3 8 2         2 10
+--R                 - 1153152a b c  - 32032a b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                            7   5            6 3 4            5 5 3
+--R                 - 17203200a b c  - 74547200a b c  - 61501440a b c
+--R               + 
+--R                            4 7 2          3 9
+--R                 - 13178880a b c  - 640640a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           8 5             7 2 4             6 4 3
+--R                 - 9175040a c  - 137625600a b c  - 223641600a b c
+--R               + 
+--R                            5 6 2           4 8
+--R                 - 82001920a b c  - 6589440a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                             8   4             7 3 3             6 5 2
+--R                 - 124780544a b c  - 467927040a b c  - 304152576a b c
+--R               + 
+--R                            5 7
+--R                 - 39829504a b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            9 4             8 2 3             7 4 2
+--R                 - 44040192a c  - 561512448a b c  - 701890560a b c
+--R               + 
+--R                             6 6
+--R                 - 152076288a b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                          9   3              8 3 2             7 5   6
+--R             (- 358612992a b c  - 1016070144a b c  - 381026304a b c)x
+--R           + 
+--R                         10 3             9 2 2             8 4   5
+--R             (- 94371840a  c  - 896532480a b c  - 635043840a b c)x
+--R           + 
+--R                          10   2             9 3   4
+--R             (- 440401920a  b c  - 697303040a b c)x
+--R           + 
+--R                         11 2             10 2   3             11     2
+--R             (- 92274688a  c  - 484442112a  b c)x  - 192937984a  b c x
+--R           + 
+--R                        12
+--R             - 33554432a  c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                        6 7          5 2 6          4 4 5          3 6 4
+--R                 - 8192a c  - 135168a b c  - 253440a b c  - 118272a b c
+--R               + 
+--R                         2 8 3         10 2     12
+--R                 - 15840a b c  - 528a b  c  - 2b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                          6   6           5 3 5           4 5 4          3 7 3
+--R                 - 643072a b c  - 2996224a b c  - 2762496a b c  - 718080a b c
+--R               + 
+--R                         2 9 2         11     13
+--R                 - 53680a b c  - 888a b  c - b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                          7 6            6 2 5            5 4 4            4 6 3
+--R                 - 696320a c  - 11661312a b c  - 22330880a b c  - 10762752a b c
+--R               + 
+--R                           3 8 2         2 10          12
+--R                 - 1523808a b c  - 57200a b  c - 338a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            7   5            6 3 4            5 5 3
+--R                 - 18235392a b c  - 83865600a b c  - 75851776a b c
+--R               + 
+--R                            4 7 2           3 9          2 11
+--R                 - 19109376a b c  - 1345344a b c - 18928a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                           8 5             7 2 4             6 4 3
+--R                 - 9863168a c  - 159129600a b c  - 288870400a b c
+--R               + 
+--R                             5 6 2            4 8           3 10
+--R                 - 128128000a b c  - 15649920a b c - 416416a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                             8   4             7 3 3             6 5 2
+--R                 - 147718144a b c  - 628490240a b c  - 505430016a b c
+--R               + 
+--R                             5 7            4 9
+--R                 - 104259584a b c - 4759040a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                            9 4             8 2 3              7 4 2
+--R                 - 53215232a c  - 779878400a b c  - 1228308480a b c
+--R               + 
+--R                             6 6             5 8
+--R                 - 430882816a b c - 32361472a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             9   3              8 3 2              7 5
+--R                 - 512753664a b c  - 1858338816a b c  - 1153105920a b c
+--R               + 
+--R                             6 7
+--R                 - 141213696a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                             10 3              9 2 2              8 4
+--R                 - 138412032a  c  - 1703411712a b c  - 2032140288a b c
+--R               + 
+--R                             7 6
+--R                 - 412778496a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          10   2              9 3              8 5  5
+--R             (- 865075200a  b c  - 2340945920a b c - 825556992a b )x
+--R           + 
+--R                          11 2              10 2               9 4  4
+--R             (- 186646528a  c  - 1695547392a  b c - 1133117440a b )x
+--R           + 
+--R                          11                 10 3  3
+--R             (- 700448768a  b c - 1049624576a  b )x
+--R           + 
+--R                        12              11 2  2             12               13
+--R           (- 125829120a  c - 627048448a  b )x  - 218103808a  b x - 33554432a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                       5   7          4 3 6          3 5 5         2 7 4
+--R                 49152a b c  + 225280a b c  + 202752a b c  + 50688a b c
+--R               + 
+--R                        9 3      11 2
+--R                 3520a b c  + 48b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                        6 7           5 2 6           4 4 5           3 6 4
+--R                 106496a c  + 1781760a b c  + 3407360a b c  + 1638912a b c
+--R               + 
+--R                        2 8 3          10 2      12
+--R                 231264a b c  + 8624a b  c  + 50b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                         6   6            5 3 5            4 5 4           3 7 3
+--R                 4177920a b c  + 19435520a b c  + 17864704a b c  + 4612608a b c
+--R               + 
+--R                        2 9 2          11
+--R                 338624a b c  + 5200a b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                         7 6            6 2 5            5 4 4            4 6 3
+--R                 2981888a c  + 49029120a b c  + 91320320a b c  + 42025984a b c
+--R               + 
+--R                         3 8 2          2 10
+--R                 5436288a b c  + 160160a b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                          7   5             6 3 4             5 5 3
+--R                 56197120a b c  + 246579200a b c  + 206868480a b c
+--R               + 
+--R                          4 7 2           3 9
+--R                 45393920a b c  + 2288000a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          8 5             7 2 4             6 4 3
+--R                 23855104a c  + 361496576a b c  + 595230720a b c
+--R               + 
+--R                           5 6 2            4 8
+--R                 222150656a b c  + 18304000a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                           8   4              7 3 3             6 5 2
+--R                 271581184a b c  + 1029439488a b c  + 678494208a b c
+--R               + 
+--R                          5 7
+--R                 90521600a b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          9 4              8 2 3              7 4 2
+--R                 81788928a c  + 1052246016a b c  + 1330249728a b c
+--R               + 
+--R                           6 6
+--R                 292454400a b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                        9   3              8 3 2             7 5   6
+--R             (585105408a b c  + 1673527296a b c  + 635043840a b c)x
+--R           + 
+--R                        10 3              9 2 2             8 4   5
+--R             (136314880a  c  + 1305477120a b c  + 933888000a b c)x
+--R           + 
+--R                        10   2             9 3   4
+--R             (574619648a  b c  + 917504000a b c)x
+--R           + 
+--R                        11 2             10 2   3             11     2
+--R             (109051904a  c  + 576716800a  b c)x  + 209715200a  b c x
+--R           + 
+--R                      12
+--R             33554432a  c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      4 2 4         3 4 3         2 6 2          8        10  6
+--R               (57600a b c  - 19200a b c  - 14880a b c  + 3600a b c + 105b  )x
+--R             + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                   115200a b c  + 192000a b c  - 187200a b c  + 12000a b c
+--R                 + 
+--R                          9
+--R                   5250a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                       5 2 3          4 4 2          3 6          2 8  4
+--R               (691200a b c  - 288000a b c  - 139200a b c + 42000a b )x
+--R             + 
+--R                       6   3          5 3 2          4 5           3 7  3
+--R               (460800a b c  + 422400a b c  - 604800a b c + 117600a b )x
+--R             + 
+--R                       6 2 2          5 4           4 6  2
+--R               (921600a b c  - 768000a b c + 134400a b )x
+--R             + 
+--R                       7   2          6 3          5 5
+--R               (368640a b c  - 307200a b c + 53760a b )x
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b x + a
+--R         + 
+--R                           4   5         3 3 4         2 5 3          7 2
+--R                   - 23040a b c  - 38400a b c  + 37440a b c  - 2400a b c
+--R                 + 
+--R                          9
+--R                   - 1050b c
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            4 2 4         3 4 3         2 6 2           8
+--R                   - 299520a b c  + 76800a b c  + 93120a b c  - 19200a b c
+--R                 + 
+--R                          10
+--R                   - 1050b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            5   4          4 3 3          3 5 2         2 7
+--R                   - 299520a b c  - 568320a b c  + 515520a b c  - 17280a b c
+--R                 + 
+--R                             9
+--R                   - 17850a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                          5 2 3          4 4 2          3 6          2 8  4
+--R               (- 1290240a b c  + 476160a b c  + 311040a b c - 87360a b )x
+--R             + 
+--R                         6   3          5 3 2          4 5           3 7  3
+--R               (- 645120a b c  - 683520a b c  + 923520a b c - 178080a b )x
+--R             + 
+--R                          6 2 2          5 4           4 6  2
+--R               (- 1105920a b c  + 921600a b c - 161280a b )x
+--R             + 
+--R                         7   2          6 3          5 5
+--R               (- 368640a b c  + 307200a b c - 53760a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                      4   4         3 3 3         2 5 2          7         9  4
+--R               (46080a b c  + 76800a b c  - 74880a b c  + 4800a b c + 2100b )x
+--R             + 
+--R                       4 2 3          3 4 2          2 6            8  3
+--R               (552960a b c  - 230400a b c  - 111360a b c + 33600a b )x
+--R             + 
+--R                       5   3          4 3 2          3 5           2 7  2
+--R               (552960a b c  + 506880a b c  - 725760a b c + 141120a b )x
+--R             + 
+--R                        5 2 2           4 4           3 6            6   2
+--R               (1474560a b c  - 1228800a b c + 215040a b )x + 737280a b c
+--R             + 
+--R                        5 3           4 5
+--R               - 614400a b c + 107520a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                              4 2 4         3 4 3         2 6 2          8
+--R                     - 115200a b c  + 38400a b c  + 29760a b c  - 7200a b c
+--R                   + 
+--R                           10
+--R                     - 210b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                            5   4          4 3 3          3 5 2         2 7
+--R                   - 230400a b c  - 384000a b c  + 374400a b c  - 24000a b c
+--R                 + 
+--R                             9
+--R                   - 10500a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          5 2 3          4 4 2          3 6          2 8  3
+--R               (- 1382400a b c  + 576000a b c  + 278400a b c - 84000a b )x
+--R             + 
+--R                         6   3          5 3 2           4 5           3 7  2
+--R               (- 921600a b c  - 844800a b c  + 1209600a b c - 235200a b )x
+--R             + 
+--R                          6 2 2           5 4           4 6            7   2
+--R               (- 1843200a b c  + 1536000a b c - 268800a b )x - 737280a b c
+--R             + 
+--R                      6 3           5 5
+--R               614400a b c - 107520a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                        2   6           3 5       5 4  9
+--R               (- 61440a b c  - 30720a b c  - 768b c )x
+--R             + 
+--R                         3 6          2 2 5           4 4      6 3  8
+--R               (- 122880a c  - 314880a b c  - 42240a b c  - 96b c )x
+--R             + 
+--R                         3   5          2 3 4         5 3       7 2  7
+--R               (- 773120a b c  - 346880a b c  - 576a b c  + 112b c )x
+--R             + 
+--R                         4 5          3 2 4       2 4 3         6 2       8   6
+--R               (- 532480a c  - 999680a b c  + 960a b c  + 464a b c  - 140b c)x
+--R             + 
+--R                          4   4        3 3 3        2 5 2         7        9  5
+--R               (- 1175040a b c  + 7680a b c  - 7488a b c  + 480a b c + 210b )x
+--R             + 
+--R                            5 4          4 2 3         3 4 2         2 6
+--R                   - 491520a c  + 153600a b c  - 70400a b c  - 25600a b c
+--R                 + 
+--R                          8
+--R                   8400a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                       5   3          4 3 2          3 5          2 7  3
+--R               (215040a b c  + 166400a b c  - 256640a b c + 50400a b )x
+--R             + 
+--R                       5 2 2          4 4          3 6  2
+--R               (645120a b c  - 537600a b c + 94080a b )x
+--R             + 
+--R                       6   2          5 3          4 5
+--R               (368640a b c  - 307200a b c + 53760a b )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                      2 7           2 6        4 5  10
+--R               (24576a c  + 61440a b c  + 7680b c )x
+--R             + 
+--R                       2   6            3 5        5 4  9
+--R               (322560a b c  + 192000a b c  + 8640b c )x
+--R             + 
+--R                       3 6          2 2 5            4 4       6 3  8
+--R               (327680a c  + 929280a b c  + 147200a b c  - 160b c )x
+--R             + 
+--R                        3   5          2 3 4          5 3       7 2  7
+--R               (1507840a b c  + 730240a b c  - 1440a b c  + 280b c )x
+--R             + 
+--R                       4 5           3 2 4        2 4 3          6 2       8   6
+--R               (778240a c  + 1514240a b c  + 4800a b c  + 2320a b c  - 700b c)x
+--R             + 
+--R                             4   4         3 3 3         2 5 2          7
+--R                     1359360a b c  - 87040a b c  + 95808a b c  - 9920a b c
+--R                   + 
+--R                            9
+--R                     - 1890b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                          5 4          4 2 3          3 4 2         2 6
+--R                   491520a c  - 491520a b c  + 236800a b c  + 72320a b c
+--R                 + 
+--R                             8
+--R                   - 25200a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         5   3          4 3 2          3 5          2 7  3
+--R               (- 399360a b c  - 289280a b c  + 460160a b c - 90720a b )x
+--R             + 
+--R                         5 2 2          4 4           3 6  2
+--R               (- 829440a b c  + 691200a b c - 120960a b )x
+--R             + 
+--R                         6   2          5 3          4 5
+--R               (- 368640a b c  + 307200a b c - 53760a b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                    2 7           2 6        4 5  11
+--R           (- 24576a c  - 61440a b c  - 7680b c )x
+--R         + 
+--R                     2   6            3 5        5 4  10
+--R           (- 322560a b c  - 192000a b c  - 8640b c )x
+--R         + 
+--R                     3 6          2 2 5            4 4       6 3  9
+--R           (- 327680a c  - 929280a b c  - 147200a b c  + 160b c )x
+--R         + 
+--R                      3   5          2 3 4          5 3       7 2  8
+--R           (- 1507840a b c  - 730240a b c  + 1440a b c  - 280b c )x
+--R         + 
+--R                     4 5           3 2 4        2 4 3          6 2       8   7
+--R           (- 778240a c  - 1514240a b c  - 4800a b c  - 2320a b c  + 700b c)x
+--R         + 
+--R                           4   4         3 3 3          2 5 2           7
+--R                 - 1318400a b c  + 33920a b c  - 115296a b c  + 17400a b c
+--R               + 
+--R                      9
+--R                 2100b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          5 4          4 2 3          3 4 2         2 6
+--R                 - 409600a c  + 549120a b c  - 545600a b c  - 34320a b c
+--R               + 
+--R                         8
+--R                 35700a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                   5   3          4 3 2          3 5           2 7  4
+--R           (890880a b c  - 389120a b c  - 626560a b c + 174720a b )x
+--R         + 
+--R                   6 3          5 2 2           4 4           3 6  3
+--R           (327680a c  + 814080a b c  - 1587200a b c + 356160a b )x
+--R         + 
+--R                    6   2           5 3           4 5  2
+--R           (1024000a b c  - 1484800a b c + 322560a b )x
+--R         + 
+--R                   7 2          6 2           5 4
+--R           (262144a c  - 471040a b c + 107520a b )x
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                  2   7           3 6       5 5  12
+--R           (61440a b c  + 30720a b c  + 768b c )x
+--R         + 
+--R                   3 7          2 2 6           4 5       6 4  11
+--R           (122880a c  + 376320a b c  + 72960a b c  + 864b c )x
+--R         + 
+--R                   3   6          2 3 5           5 4      7 3  10
+--R           (957440a b c  + 692480a b c  + 43584a b c  - 16b c )x
+--R         + 
+--R                   4 6           3 2 5          2 4 4         6 3      8 2  9
+--R           (655360a c  + 2087680a b c  + 388160a b c  + 208a b c  + 28b c )x
+--R         + 
+--R                    4   5           3 3 4        2 5 3          7 2      9   8
+--R           (2480640a b c  + 1338880a b c  + 7104a b c  - 1056a b c  - 70b c)x
+--R         + 
+--R                       5 5           4 2 4          3 4 3         2 6 2
+--R               1007616a c  + 2009600a b c  + 123520a b c  + 25024a b c
+--R             + 
+--R                         8        10
+--R               - 10840a b c - 210b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                         5   4         4 3 3          3 5 2         2 7
+--R                 1238528a b c  - 67840a b c  + 462848a b c  - 66480a b c
+--R               + 
+--R                           9
+--R                 - 10710a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      6 4           5 2 3           4 4 2          3 6
+--R               278528a c  - 1212672a b c  + 1312320a b c  + 106000a b c
+--R             + 
+--R                       2 8
+--R               - 94500a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                      6   3          5 3 2           4 5           3 7  4
+--R           (- 1501184a b c  + 718336a b c  + 1129600a b c - 319200a b )x
+--R         + 
+--R                     7 3           6 2 2           5 4           4 6  3
+--R           (- 458752a c  - 1057792a b c  + 2216960a b c - 504000a b )x
+--R         + 
+--R                      7   2           6 3           5 5  2
+--R           (- 1155072a b c  + 1720320a b c - 376320a b )x
+--R         + 
+--R                     8 2          7 2           6 4
+--R           (- 262144a c  + 471040a b c - 107520a b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                     2 6            2 5         4 4  4
+--R             (122880a c  + 307200a b c  + 38400b c )x
+--R           + 
+--R                      2   5            3 4  3            3 5           2 2 4  2
+--R             (1474560a b c  + 614400a b c )x  + (1474560a c  + 2580480a b c )x
+--R           + 
+--R                     3   4            4 4
+--R             3932160a b c x + 1966080a c
+--R        *
+--R                          +--------------+
+--R            +---+ +-+ +-+ |   2
+--R           \|- c \|a \|c \|c x  + b x + a
+--R       + 
+--R                       2   6            3 5        5 4  5
+--R             (- 307200a b c  - 153600a b c  - 3840b c )x
+--R           + 
+--R                       3 6           2 2 5            4 4  4
+--R             (- 614400a c  - 1536000a b c  - 192000a b c )x
+--R           + 
+--R                        3   5           2 3 4  3
+--R             (- 3686400a b c  - 1536000a b c )x
+--R           + 
+--R                        4 5           3 2 4  2           4   4            5 4
+--R             (- 2457600a c  - 4300800a b c )x  - 4915200a b c x - 1966080a c
+--R        *
+--R            +---+ +-+
+--R           \|- c \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                       4   5         3 3 4        2 5 3         7 2      9   14
+--R               (- 5120a b c  - 15360a b c  - 8064a b c  - 960a b c  - 20b c)x
+--R             + 
+--R                           5 5          4 2 4          3 4 3         2 6 2
+--R                   - 10240a c  - 117760a b c  - 142080a b c  - 37632a b c
+--R                 + 
+--R                            8       10
+--R                   - 2280a b c - 20b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                            5   4          4 3 3          3 5 2         2 7
+--R                   - 261120a b c  - 803840a b c  - 438912a b c  - 55872a b c
+--R                 + 
+--R                            9
+--R                   - 1340a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                            6 4           5 2 3           4 4 2          3 6
+--R                   - 174080a c  - 1955840a b c  - 2266880a b c  - 553344a b c
+--R                 + 
+--R                           2 8
+--R                   - 26664a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                          6   3           5 3 2           4 5           3 7  10
+--R               (- 2129920a b c  - 6000640a b c  - 2793472a b c - 244992a b )x
+--R             + 
+--R                         7 3           6 2 2           5 4            4 6  9
+--R               (- 851968a c  - 8478720a b c  - 7987200a b c - 1244672a b )x
+--R             + 
+--R                          7   2            6 3            5 5  8
+--R               (- 6078464a b c  - 13475840a b c - 3820544a b )x
+--R             + 
+--R                          8 2            7 2            6 4  7
+--R               (- 1736704a c  - 13287424a b c - 7383040a b )x
+--R             + 
+--R                          8              7 3  6              9            8 2  5
+--R               (- 7077888a b c - 9043968a b )x  + (- 1572864a c - 6815744a b )x
+--R             + 
+--R                         9   4          10 3
+--R               - 2883584a b x  - 524288a  x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                    5 6         4 2 5         3 4 4        2 6 3         8 2
+--R               1024a c  + 11520a b c  + 13440a b c  + 3360a b c  + 180a b c
+--R             + 
+--R                10
+--R               b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                     5   5          4 3 4         3 5 3         2 7 2         9
+--R               52224a b c  + 165120a b c  + 94080a b c  + 12960a b c  + 380a b c
+--R             + 
+--R                11
+--R               b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                     6 5          5 2 4          4 4 3          3 6 2
+--R               52224a c  + 625920a b c  + 800640a b c  + 231840a b c
+--R             + 
+--R                     2 8          10
+--R               16380a b c + 201a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                      6   4           5 3 3           4 5 2          3 7
+--R               921600a b c  + 2969600a b c  + 1728000a b c  + 241920a b c
+--R             + 
+--R                    2 9
+--R               6800a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                      7 4           6 2 3           5 4 2           4 6
+--R               460800a c  + 5376000a b c  + 6547200a b c  + 1710720a b c
+--R             + 
+--R                     3 8
+--R               91080a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                    7   3            6 3 2           5 5           4 7  10
+--R           (4669440a b c  + 13701120a b c  + 6724608a b c + 633600a b )x
+--R         + 
+--R                    8 3            7 2 2            6 4            5 6  9
+--R           (1556480a c  + 16035840a b c  + 15774720a b c + 2599168a b )x
+--R         + 
+--R                    8   2            7 3            6 5  8
+--R           (9830400a b c  + 22609920a b c + 6709248a b )x
+--R         + 
+--R                    9 2            8 2             7 4  7
+--R           (2457600a c  + 19415040a b c + 11212800a b )x
+--R         + 
+--R                    9               8 3  6            10            9 2  5
+--R           (9175040a b c + 12124160a b )x  + (1835008a  c + 8192000a b )x
+--R         + 
+--R                   10   4          11 3
+--R           3145728a  b x  + 524288a  x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      5 6         4 2 5         3 4 4        2 6 3         8 2
+--R               - 1024a c  - 11520a b c  - 13440a b c  - 3360a b c  - 180a b c
+--R             + 
+--R                  10
+--R               - b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                       5   5          4 3 4         3 5 3         2 7 2
+--R               - 52224a b c  - 165120a b c  - 94080a b c  - 12960a b c
+--R             + 
+--R                       9     11
+--R               - 380a b c - b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                       6 5          5 2 4          4 4 3          3 6 2
+--R               - 52224a c  - 625920a b c  - 800640a b c  - 231840a b c
+--R             + 
+--R                       2 8          10
+--R               - 16380a b c - 201a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        6   4           5 3 3           4 5 2          3 7
+--R               - 921600a b c  - 2969600a b c  - 1728000a b c  - 241920a b c
+--R             + 
+--R                      2 9
+--R               - 6800a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                        7 4           6 2 3           5 4 2           4 6
+--R               - 460800a c  - 5376000a b c  - 6547200a b c  - 1710720a b c
+--R             + 
+--R                       3 8
+--R               - 91080a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                      7   3            6 3 2           5 5           4 7  11
+--R           (- 4669440a b c  - 13701120a b c  - 6724608a b c - 633600a b )x
+--R         + 
+--R                      8 3            7 2 2            6 4            5 6  10
+--R           (- 1556480a c  - 16035840a b c  - 15774720a b c - 2599168a b )x
+--R         + 
+--R                      8   2            7 3            6 5  9
+--R           (- 9830400a b c  - 22609920a b c - 6709248a b )x
+--R         + 
+--R                      9 2            8 2             7 4  8
+--R           (- 2457600a c  - 19415040a b c - 11212800a b )x
+--R         + 
+--R                      9               8 3  7              10            9 2  6
+--R           (- 9175040a b c - 12124160a b )x  + (- 1835008a  c - 8192000a b )x
+--R         + 
+--R                     10   5          11 4
+--R           - 3145728a  b x  - 524288a  x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 4   6         3 3 5        2 5 4         7 3      9 2  17
+--R           (5120a b c  + 15360a b c  + 8064a b c  + 960a b c  + 20b c )x
+--R         + 
+--R                     5 6          4 2 5          3 4 4         2 6 3
+--R               10240a c  + 122880a b c  + 157440a b c  + 45696a b c
+--R             + 
+--R                      8 2      10
+--R               3240a b c  + 40b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                      5   5          4 3 4          3 5 3         2 7 2
+--R               276480a b c  + 936960a b c  + 589056a b c  + 94464a b c
+--R             + 
+--R                      9       11
+--R               3640a b c + 20b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                      6 5           5 2 4           4 4 3           3 6 2
+--R               184320a c  + 2334720a b c  + 3212800a b c  + 1029888a b c
+--R             + 
+--R                     2 8           10
+--R               84816a b c + 1360a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                       6   4           5 3 3           4 5 2          3 7
+--R               2565120a b c  + 8760320a b c  + 5499264a b c  + 854208a b c
+--R             + 
+--R                     2 9
+--R               28004a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                       7 4            6 2 3            5 4 2           4 6
+--R               1026048a c  + 12564480a b c  + 16254720a b c  + 4591488a b c
+--R             + 
+--R                      3 8
+--R               271656a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                    7   3            6 3 2            5 5            4 7  11
+--R           (9060352a b c  + 27955200a b c  + 14601216a b c + 1489664a b )x
+--R         + 
+--R                    8 3            7 2 2            6 4            5 6  10
+--R           (2588672a c  + 27844608a b c  + 28846080a b c + 5065216a b )x
+--R         + 
+--R                     8   2            7 3             6 5  9
+--R           (14893056a b c  + 35807232a b c + 11203584a b )x
+--R         + 
+--R                    9 2            8 2             7 4  8
+--R           (3309568a c  + 27181056a b c + 16427008a b )x
+--R         + 
+--R                     9               8 3  7            10            9 2  6
+--R           (11534336a b c + 15859712a b )x  + (2097152a  c + 9699328a b )x
+--R         + 
+--R                   10   5          11 4
+--R           3407872a  b x  + 524288a  x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                      5 5         4 2 4         3 4 3        2 6 2         8
+--R                 1024a c  + 11520a b c  + 13440a b c  + 3360a b c  + 180a b c
+--R               + 
+--R                  10
+--R                 b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                    5   4          4 3 3         3 5 2        2 7          9  9
+--R             (51200a b c  + 153600a b c  + 80640a b c  + 9600a b c + 200a b )x
+--R           + 
+--R                         6 4          5 2 3          4 4 2          3 6
+--R                   51200a c  + 563200a b c  + 633600a b c  + 147840a b c
+--R                 + 
+--R                        2 8
+--R                   6600a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                     6   3           5 3 2           4 5          3 7  7
+--R             (819200a b c  + 2252800a b c  + 1013760a b c + 84480a b )x
+--R           + 
+--R                     7 3           6 2 2           5 4           4 6  6
+--R             (409600a c  + 3993600a b c  + 3660800a b c + 549120a b )x
+--R           + 
+--R                      7   2           6 3            5 5  5
+--R             (3440640a b c  + 7454720a b c + 2050048a b )x
+--R           + 
+--R                      8 2           7 2            6 4  4
+--R             (1146880a c  + 8601600a b c + 4659200a b )x
+--R           + 
+--R                      8              7 3  3            9            8 2  2
+--R             (5242880a b c + 6553600a b )x  + (1310720a c + 5570560a b )x
+--R           + 
+--R                     9             10
+--R             2621440a b x + 524288a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                     4   5         3 3 4        2 5 3         7 2      9   11
+--R             (- 5120a b c  - 15360a b c  - 8064a b c  - 960a b c  - 20b c)x
+--R           + 
+--R                         5 5          4 2 4          3 4 3         2 6 2
+--R                 - 10240a c  - 117760a b c  - 142080a b c  - 37632a b c
+--R               + 
+--R                          8       10
+--R                 - 2280a b c - 20b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                 - 261120a b c  - 803840a b c  - 438912a b c  - 55872a b c
+--R               + 
+--R                          9
+--R                 - 1340a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                          6 4           5 2 3           4 4 2          3 6
+--R                 - 174080a c  - 1955840a b c  - 2266880a b c  - 553344a b c
+--R               + 
+--R                         2 8
+--R                 - 26664a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                        6   3           5 3 2           4 5           3 7  7
+--R             (- 2129920a b c  - 6000640a b c  - 2793472a b c - 244992a b )x
+--R           + 
+--R                       7 3           6 2 2           5 4            4 6  6
+--R             (- 851968a c  - 8478720a b c  - 7987200a b c - 1244672a b )x
+--R           + 
+--R                        7   2            6 3            5 5  5
+--R             (- 6078464a b c  - 13475840a b c - 3820544a b )x
+--R           + 
+--R                        8 2            7 2            6 4  4
+--R             (- 1736704a c  - 13287424a b c - 7383040a b )x
+--R           + 
+--R                        8              7 3  3              9            8 2  2
+--R             (- 7077888a b c - 9043968a b )x  + (- 1572864a c - 6815744a b )x
+--R           + 
+--R                       9             10
+--R             - 2883584a b x - 524288a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 704
+t0:=x*sqrt(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R          +------------------+
+--R          |   4      3      2
+--R   (1)  x\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 704
+r0:=-1/128*(b^2-4*a*c)*(5*b^2-4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(c^(7/2)*sqrt(a*x^2+b*x^3+c*x^4))-_
+   1/96*(5*b^2-12*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/c^2+1/192*b*(15*b^2-52*a*c)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(c^3*x)+1/24*x*(b+6*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                      +--------------+
+--R               2 2        2       4   |   2
+--R         (- 48a c  + 72a b c - 15b )x\|c x  + b x + a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R              4 6         3 5          3     2 2  4             2      3   3
+--R           96c x  + 112b c x  + (144a c  - 4b c )x  + (- 40a b c  + 10b c)x
+--R         + 
+--R               2 2         2       4  2          2           3
+--R           (48a c  - 124a b c + 30b )x  + (- 104a b c + 30a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R               +------------------+
+--R         3 +-+ |   4      3      2
+--R     384c \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       3   3        2 3 2        5        7  3
+--R                 (1536a b c  - 1920a b c  - 96a b c + 120b )x
+--R               + 
+--R                       4 3       3 2 2        2 4           6  2
+--R                 (3072a c  - 768a b c  - 4800a b c + 1200a b )x
+--R               + 
+--R                       4   2         3 3         2 5          5 2        4 2
+--R                 (9216a b c  - 13824a b c + 2880a b )x + 6144a c  - 9216a b c
+--R               + 
+--R                      3 4
+--R                 1920a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                    4 4        2 4 2         6       8  4
+--R             (- 768a c  + 1440a b c  - 288a b c - 15b )x
+--R           + 
+--R                     4   3        3 3 2       2 5          7  3
+--R             (- 6144a b c  + 7680a b c  + 384a b c - 480a b )x
+--R           + 
+--R                     5 3        4 2 2        3 4         2 6  2
+--R             (- 6144a c  + 1536a b c  + 9600a b c - 2400a b )x
+--R           + 
+--R                      5   2         4 3         3 5          6 2        5 2
+--R             (- 12288a b c  + 18432a b c - 3840a b )x - 6144a c  + 9216a b c
+--R           + 
+--R                    4 4
+--R             - 1920a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                     2 5          2 4      4 3  7
+--R             (- 1536a c  - 2304a b c  - 96b c )x
+--R           + 
+--R                      2   4          3 3      5 2  6
+--R             (- 12544a b c  - 3456a b c  - 16b c )x
+--R           + 
+--R                      3 4         2 2 3        4 2      6   5
+--R             (- 13056a c  - 18240a b c  - 80a b c  + 20b c)x
+--R           + 
+--R                      3   3       2 3 2        5       7  4
+--R             (- 31104a b c  + 480a b c  + 24a b c - 30b )x
+--R           + 
+--R                      4 3       3 2 2        2 4          6  3
+--R             (- 18432a c  + 768a b c  + 2816a b c - 720a b )x
+--R           + 
+--R                     4   2         3 3         2 5  2
+--R             (- 7680a b c  + 11520a b c - 2400a b )x
+--R           + 
+--R                     5 2        4 2         3 4
+--R             (- 6144a c  + 9216a b c - 1920a b )x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                       5       3 4  8         2 5           2 4       4 3  7
+--R             (3072a b c  + 768b c )x  + (6144a c  + 11264a b c  + 896b c )x
+--R           + 
+--R                    2   4          3 3      5 2  6
+--R             (30208a b c  + 9984a b c  - 32b c )x
+--R           + 
+--R                    3 4         2 2 3         4 2      6   5
+--R             (21504a c  + 31488a b c  - 320a b c  + 80b c)x
+--R           + 
+--R                    3   3        2 3 2         5        7  4
+--R             (42624a b c  - 4896a b c  + 152a b c + 210b )x
+--R           + 
+--R                    4 3        3 2 2        2 4           6  3
+--R             (21504a c  - 2304a b c  - 6464a b c + 1680a b )x
+--R           + 
+--R                    4   2         3 3         2 5  2
+--R             (10752a b c  - 16128a b c + 3360a b )x
+--R           + 
+--R                   5 2        4 2         3 4
+--R             (6144a c  - 9216a b c + 1920a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                        4        3 3  3          2 4           2 3  2
+--R             (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R           + 
+--R                   2   3          3 3
+--R             73728a b c x + 49152a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                     2 5          2 4       4 3  4
+--R             (- 6144a c  - 9216a b c  - 384b c )x
+--R           + 
+--R                      2   4           3 3  3            3 4         2 2 3  2
+--R             (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R           + 
+--R                     3   3          4 3
+--R             - 98304a b c x - 49152a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                         3   3        2 3 2        5        7  3
+--R                 (- 1536a b c  + 1920a b c  + 96a b c - 120b )x
+--R               + 
+--R                         4 3       3 2 2        2 4           6  2
+--R                 (- 3072a c  + 768a b c  + 4800a b c - 1200a b )x
+--R               + 
+--R                         4   2         3 3         2 5          5 2        4 2
+--R                 (- 9216a b c  + 13824a b c - 2880a b )x - 6144a c  + 9216a b c
+--R               + 
+--R                        3 4
+--R                 - 1920a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                  4 4        2 4 2         6       8  4
+--R             (768a c  - 1440a b c  + 288a b c + 15b )x
+--R           + 
+--R                   4   3        3 3 2       2 5          7  3
+--R             (6144a b c  - 7680a b c  - 384a b c + 480a b )x
+--R           + 
+--R                   5 3        4 2 2        3 4         2 6  2
+--R             (6144a c  - 1536a b c  - 9600a b c + 2400a b )x
+--R           + 
+--R                    5   2         4 3         3 5          6 2        5 2
+--R             (12288a b c  - 18432a b c + 3840a b )x + 6144a c  - 9216a b c
+--R           + 
+--R                  4 4
+--R             1920a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                    2 5          2 4      4 3  7
+--R             (- 768a c  - 1152a b c  - 48b c )x
+--R           + 
+--R                     2   4          3 3     5 2  6
+--R             (- 6272a b c  - 1728a b c  - 8b c )x
+--R           + 
+--R                     3 4        2 2 3        4 2      6   5
+--R             (- 6528a c  - 9120a b c  - 40a b c  + 10b c)x
+--R           + 
+--R                      3   3       2 3 2        5       7  4
+--R             (- 15552a b c  + 240a b c  + 12a b c - 15b )x
+--R           + 
+--R                     4 3       3 2 2        2 4          6  3
+--R             (- 9216a c  + 384a b c  + 1408a b c - 360a b )x
+--R           + 
+--R                     4   2        3 3         2 5  2
+--R             (- 3840a b c  + 5760a b c - 1200a b )x
+--R           + 
+--R                     5 2        4 2        3 4
+--R             (- 3072a c  + 4608a b c - 960a b )x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                       5       3 4  8         2 5          2 4       4 3  7
+--R             (1536a b c  + 384b c )x  + (3072a c  + 5632a b c  + 448b c )x
+--R           + 
+--R                    2   4          3 3      5 2  6
+--R             (15104a b c  + 4992a b c  - 16b c )x
+--R           + 
+--R                    3 4         2 2 3         4 2      6   5
+--R             (10752a c  + 15744a b c  - 160a b c  + 40b c)x
+--R           + 
+--R                    3   3        2 3 2        5        7  4
+--R             (21312a b c  - 2448a b c  + 76a b c + 105b )x
+--R           + 
+--R                    4 3        3 2 2        2 4          6  3
+--R             (10752a c  - 1152a b c  - 3232a b c + 840a b )x
+--R           + 
+--R                   4   2        3 3         2 5  2
+--R             (5376a b c  - 8064a b c + 1680a b )x
+--R           + 
+--R                   5 2        4 2        3 4
+--R             (3072a c  - 4608a b c + 960a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                       4        3 3  3          2 4           2 3  2
+--R             (6144a b c  + 1536b c )x  + (12288a c  + 15360a b c )x
+--R           + 
+--R                   2   3          3 3
+--R             36864a b c x + 24576a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                     2 5          2 4       4 3  4
+--R             (- 3072a c  - 4608a b c  - 192b c )x
+--R           + 
+--R                      2   4          3 3  3            3 4         2 2 3  2
+--R             (- 24576a b c  - 6144a b c )x  + (- 24576a c  - 30720a b c )x
+--R           + 
+--R                     3   3          4 3
+--R             - 49152a b c x - 24576a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 186
+
+--S 187 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     3   3        2 3 2        5        7  3
+--R               (1536a b c  - 1920a b c  - 96a b c + 120b )x
+--R             + 
+--R                     4 3       3 2 2        2 4           6  2
+--R               (3072a c  - 768a b c  - 4800a b c + 1200a b )x
+--R             + 
+--R                     4   2         3 3         2 5          5 2        4 2
+--R               (9216a b c  - 13824a b c + 2880a b )x + 6144a c  - 9216a b c
+--R             + 
+--R                    3 4
+--R               1920a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                  4 4        2 4 2         6       8  4
+--R           (- 768a c  + 1440a b c  - 288a b c - 15b )x
+--R         + 
+--R                   4   3        3 3 2       2 5          7  3
+--R           (- 6144a b c  + 7680a b c  + 384a b c - 480a b )x
+--R         + 
+--R                   5 3        4 2 2        3 4         2 6  2
+--R           (- 6144a c  + 1536a b c  + 9600a b c - 2400a b )x
+--R         + 
+--R                    5   2         4 3         3 5          6 2        5 2
+--R           (- 12288a b c  + 18432a b c - 3840a b )x - 6144a c  + 9216a b c
+--R         + 
+--R                  4 4
+--R           - 1920a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                      4 4        2 4 2         6       8  5
+--R               (- 768a c  + 1440a b c  - 288a b c - 15b )x
+--R             + 
+--R                       4   3        3 3 2       2 5          7  4
+--R               (- 6144a b c  + 7680a b c  + 384a b c - 480a b )x
+--R             + 
+--R                       5 3        4 2 2        3 4         2 6  3
+--R               (- 6144a c  + 1536a b c  + 9600a b c - 2400a b )x
+--R             + 
+--R                        5   2         4 3         3 5  2
+--R               (- 12288a b c  + 18432a b c - 3840a b )x
+--R             + 
+--R                       6 2        5 2         4 4
+--R               (- 6144a c  + 9216a b c - 1920a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                     3   4        2 3 3        5 2       7   6
+--R               (1536a b c  - 1920a b c  - 96a b c  + 120b c)x
+--R             + 
+--R                     4 4       3 2 3        2 4 2          6        8  5
+--R               (3072a c  + 768a b c  - 6720a b c  + 1104a b c + 120b )x
+--R             + 
+--R                      4   3         3 3 2        2 5           7  4
+--R               (13824a b c  - 16512a b c  - 2016a b c + 1320a b )x
+--R             + 
+--R                     5 3       4 2 2         3 4         2 6  3
+--R               (9216a c  - 768a b c  - 16704a b c + 4080a b )x
+--R             + 
+--R                      5   2         4 3         3 5  2
+--R               (15360a b c  - 23040a b c + 4800a b )x
+--R             + 
+--R                     6 2        5 2         4 4
+--R               (6144a c  - 9216a b c + 1920a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                       2 5          2 4      4 3  7
+--R               (- 1536a c  - 2304a b c  - 96b c )x
+--R             + 
+--R                        2   4          3 3      5 2  6
+--R               (- 12544a b c  - 3456a b c  - 16b c )x
+--R             + 
+--R                        3 4         2 2 3        4 2      6   5
+--R               (- 13056a c  - 18240a b c  - 80a b c  + 20b c)x
+--R             + 
+--R                        3   3       2 3 2        5       7  4
+--R               (- 31104a b c  + 480a b c  + 24a b c - 30b )x
+--R             + 
+--R                        4 3       3 2 2        2 4          6  3
+--R               (- 18432a c  + 768a b c  + 2816a b c - 720a b )x
+--R             + 
+--R                       4   2         3 3         2 5  2
+--R               (- 7680a b c  + 11520a b c - 2400a b )x
+--R             + 
+--R                       5 2        4 2         3 4
+--R               (- 6144a c  + 9216a b c - 1920a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                         5       3 4  8         2 5           2 4       4 3  7
+--R               (3072a b c  + 768b c )x  + (6144a c  + 11264a b c  + 896b c )x
+--R             + 
+--R                      2   4          3 3      5 2  6
+--R               (30208a b c  + 9984a b c  - 32b c )x
+--R             + 
+--R                      3 4         2 2 3         4 2      6   5
+--R               (21504a c  + 31488a b c  - 320a b c  + 80b c)x
+--R             + 
+--R                      3   3        2 3 2         5        7  4
+--R               (42624a b c  - 4896a b c  + 152a b c + 210b )x
+--R             + 
+--R                      4 3        3 2 2        2 4           6  3
+--R               (21504a c  - 2304a b c  - 6464a b c + 1680a b )x
+--R             + 
+--R                      4   2         3 3         2 5  2
+--R               (10752a b c  - 16128a b c + 3360a b )x
+--R             + 
+--R                     5 2        4 2         3 4
+--R               (6144a c  - 9216a b c + 1920a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                       5       3 4  9           2 5           2 4       4 3  8
+--R           (- 3072a b c  - 768b c )x  + (- 6144a c  - 11264a b c  - 896b c )x
+--R         + 
+--R                    2   4          3 3      5 2  7
+--R           (- 30208a b c  - 9984a b c  + 32b c )x
+--R         + 
+--R                    3 4         2 2 3         4 2      6   6
+--R           (- 21504a c  - 31488a b c  + 320a b c  - 80b c)x
+--R         + 
+--R                    3   3        2 3 2         5        7  5
+--R           (- 40960a b c  + 6912a b c  - 768a b c - 240b )x
+--R         + 
+--R                    4 3         3 2 2        2 4           6  4
+--R           (- 21504a c  + 15616a b c  + 5952a b c - 2640a b )x
+--R         + 
+--R                 4   2         3 3         2 5  3
+--R           (2560a b c  + 28928a b c - 8160a b )x
+--R         + 
+--R                   5 2         4 2         3 4  2          5           4 3
+--R           (- 6144a c  + 35840a b c - 9600a b )x  + (13312a b c - 3840a b )x
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                 2 6          2 5      4 4  10
+--R           (1536a c  + 2304a b c  + 96b c )x
+--R         + 
+--R                  2   5          3 4       5 3  9
+--R           (14080a b c  + 5760a b c  + 112b c )x
+--R         + 
+--R                  3 5         2 2 4          4 3     6 2  8
+--R           (14592a c  + 33088a b c  + 3632a b c  - 4b c )x
+--R         + 
+--R                  3   4         2 3 3        5 2      7   7
+--R           (56704a b c  + 21216a b c  + 72a b c  + 10b c)x
+--R         + 
+--R                  4 4         3 2 3        2 4 2         6       8  6
+--R           (31488a c  + 45248a b c  - 3088a b c  + 916a b c + 30b )x
+--R         + 
+--R                  4   3         3 3 2        2 5          7  5
+--R           (50560a b c  - 22496a b c  + 2088a b c + 990a b )x
+--R         + 
+--R                  5 3         4 2 2         3 4         2 6  4
+--R           (24576a c  - 32256a b c  - 12928a b c + 5760a b )x
+--R         + 
+--R                   5   2         4 3          3 5  3
+--R           (- 6144a b c  - 43264a b c + 12480a b )x
+--R         + 
+--R                 6 2         5 2          4 4  2            6           5 3
+--R           (6144a c  - 42496a b c + 11520a b )x  + (- 13312a b c + 3840a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                        4        3 3  3          2 4           2 3  2
+--R             (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R           + 
+--R                   2   3          3 3
+--R             73728a b c x + 49152a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                     2 5          2 4       4 3  4
+--R             (- 6144a c  - 9216a b c  - 384b c )x
+--R           + 
+--R                      2   4           3 3  3            3 4         2 2 3  2
+--R             (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R           + 
+--R                     3   3          4 3
+--R             - 98304a b c x - 49152a c
+--R        *
+--R            +-+
+--R           \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                              5 6         4 2 5         3 4 4        2 6 3
+--R                       - 2048a c  - 23040a b c  - 26880a b c  - 6720a b c
+--R                     + 
+--R                               8 2     10
+--R                       - 360a b c  - 2b  c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                5   5          4 3 4          3 5 3
+--R                       - 113664a b c  - 349440a b c  - 190848a b c
+--R                     + 
+--R                               2 7 2         9     11
+--R                       - 24480a b c  - 620a b c - b
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                6 5           5 2 4           4 4 3
+--R                       - 124928a c  - 1436160a b c  - 1731840a b c
+--R                     + 
+--R                                3 6 2         2 8          10
+--R                       - 458304a b c  - 27720a b c - 242a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                 6   4           5 3 3           4 5 2
+--R                       - 2314240a b c  - 6983680a b c  - 3700224a b c
+--R                     + 
+--R                                3 7         2 9
+--R                       - 447744a b c - 9680a b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                 7 4            6 2 3            5 4 2
+--R                       - 1269760a c  - 13844480a b c  - 15375360a b c
+--R                     + 
+--R                                 4 6           3 8
+--R                       - 3514368a b c - 151008a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                  7   3            6 3 2            5 5
+--R                       - 13189120a b c  - 35409920a b c  - 15375360a b c
+--R                     + 
+--R                                 4 7
+--R                       - 1208064a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                 8 3            7 2 2            6 4
+--R                       - 4816896a c  - 45588480a b c  - 40069120a b c
+--R                     + 
+--R                                 5 6
+--R                       - 5637632a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                               8   2            7 3             6 5  7
+--R                   (- 30670848a b c  - 63569920a b c - 16400384a b )x
+--R                 + 
+--R                              9 2            8 2             7 4  6
+--R                   (- 8388608a c  - 60162048a b c - 30638080a b )x
+--R                 + 
+--R                               9               8 3  5
+--R                   (- 31195136a b c - 36765696a b )x
+--R                 + 
+--R                              10             9 2  4            10   3
+--R                   (- 6815744a  c - 27394048a b )x  - 11534336a  b x
+--R                 + 
+--R                             11 2
+--R                   - 2097152a  x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                               4   6         3 3 5         2 5 4          7 3
+--R                       - 10240a b c  - 30720a b c  - 16128a b c  - 1920a b c
+--R                     + 
+--R                            9 2
+--R                       - 40b c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                               5 6          4 2 5          3 4 4         2 6 3
+--R                       - 22528a c  - 258560a b c  - 311040a b c  - 81984a b c
+--R                     + 
+--R                                8 2      10
+--R                       - 4920a b c  - 42b  c
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                5   5           4 3 4           3 5 3
+--R                       - 624640a b c  - 1914880a b c  - 1039104a b c
+--R                     + 
+--R                                2 7 2          9
+--R                       - 130944a b c  - 3080a b c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                6 5           5 2 4           4 4 3
+--R                       - 450560a c  - 5038080a b c  - 5800960a b c
+--R                     + 
+--R                                 3 6 2         2 8
+--R                       - 1402368a b c  - 66528a b c
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                 6   4            5 3 3           4 5 2
+--R                       - 5898240a b c  - 16506880a b c  - 7614464a b c
+--R                     + 
+--R                                3 7
+--R                       - 658944a b c
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                 7 4            6 2 3            5 4 2
+--R                       - 2523136a c  - 24944640a b c  - 23296000a b c
+--R                     + 
+--R                                 4 6
+--R                       - 3587584a b c
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                               7   3            6 3 2            5 5   8
+--R                   (- 19038208a b c  - 41861120a b c  - 11741184a b c)x
+--R                 + 
+--R                              8 3            7 2 2            6 4   7
+--R                   (- 5767168a c  - 43778048a b c  - 24084480a b c)x
+--R                 + 
+--R                               8   2            7 3   6
+--R                   (- 24641536a b c  - 31195136a b c)x
+--R                 + 
+--R                              9 2            8 2   5            9     4
+--R                   (- 5767168a c  - 24772608a b c)x  - 11010048a b c x
+--R                 + 
+--R                             10   3
+--R                   - 2097152a  c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        4   6         3 3 5         2 5 4          7 3      9 2
+--R                 (10240a b c  + 30720a b c  + 16128a b c  + 1920a b c  + 40b c )
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                         5 6          4 2 5          3 4 4         2 6 3
+--R                   22528a c  + 263680a b c  + 326400a b c  + 90048a b c
+--R                 + 
+--R                          8 2      10
+--R                   5880a b c  + 62b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                          5   5           4 3 4           3 5 3          2 7 2
+--R                   647168a b c  + 2086400a b c  + 1224192a b c  + 177216a b c
+--R                 + 
+--R                          9       11
+--R                   5760a b c + 22b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                          6 5           5 2 4           4 4 3           3 6 2
+--R                   473088a c  + 5660160a b c  + 7223040a b c  + 2084544a b c
+--R                 + 
+--R                          2 8           10
+--R                   146520a b c + 1782a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                           6   4            5 3 3            4 5 2
+--R                   6799360a b c  + 21504000a b c  + 12187648a b c
+--R                 + 
+--R                           3 7          2 9
+--R                   1638912a b c + 42944a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                           7 4            6 2 3            5 4 2           4 6
+--R                   2973696a c  + 33751040a b c  + 39603200a b c  + 9810944a b c
+--R                 + 
+--R                          3 8
+--R                   480480a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                         7   3            6 3 2            5 5            4 7  9
+--R               (26607616a b c  + 74833920a b c  + 34664448a b c + 3001856a b )x
+--R             + 
+--R                        8 3            7 2 2            6 4             5 6  8
+--R               (8290304a c  + 81682432a b c  + 75765760a b c + 11508224a b )x
+--R             + 
+--R                         8   2             7 3             6 5  7
+--R               (47710208a b c  + 103546880a b c + 28442624a b )x
+--R             + 
+--R                         9 2            8 2             7 4  6
+--R               (11534336a c  + 86114304a b c + 46235648a b )x
+--R             + 
+--R                         9               8 3  5            10             9 2  4
+--R               (39845888a b c + 49152000a b )x  + (7864320a  c + 32899072a b )x
+--R             + 
+--R                        10   3           11 2
+--R               12582912a  b x  + 2097152a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                    5 7         4 2 6         3 4 5        2 6 4         8 3
+--R               2048a c  + 23040a b c  + 26880a b c  + 6720a b c  + 360a b c
+--R             + 
+--R                 10 2
+--R               2b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                      5   6          4 3 5          3 5 4         2 7 3
+--R               114688a b c  + 360960a b c  + 204288a b c  + 27840a b c
+--R             + 
+--R                     9 2     11
+--R               800a b c  + 2b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                      6 6           5 2 5           4 4 4          3 6 3
+--R               124928a c  + 1487360a b c  + 1885440a b c  + 538944a b c
+--R             + 
+--R                     2 8 2         10
+--R               37320a b c  + 442a b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                       6   5           5 3 4           4 5 3          3 7 2
+--R               2365440a b c  + 7546880a b c  + 4333824a b c  + 595584a b c
+--R             + 
+--R                     2 9
+--R               16280a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                       7 5            6 2 4            5 4 3           4 6 2
+--R               1269760a c  + 14663680a b c  + 17628160a b c  + 4528128a b c
+--R             + 
+--R                      3 8
+--R               235488a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                     7   4            6 3 3            5 5 2           4 7   10
+--R           (13598720a b c  + 39403520a b c  + 19036160a b c  + 1757184a b c)x
+--R         + 
+--R                    8 4            7 2 3            6 4 2           5 6   9
+--R           (4816896a c  + 49029120a b c  + 47523840a b c  + 7687680a b c)x
+--R         + 
+--R                     8   3            7 3 2            6 5   8
+--R           (31817728a b c  + 72171520a b c  + 21059584a b c)x
+--R         + 
+--R                    9 3            8 2 2            7 4   7
+--R           (8388608a c  + 65404928a b c  + 37191680a b c)x
+--R         + 
+--R                     9   2            8 3   6            10 2            9 2   5
+--R           (32505856a b c  + 42336256a b c)x  + (6815744a  c  + 30015488a b c)x
+--R         + 
+--R                    10     4           11   3
+--R           12058624a  b c x  + 2097152a  c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                             4   6         3 3 5         2 5 4          7 3
+--R                     - 10240a b c  - 30720a b c  - 16128a b c  - 1920a b c
+--R                   + 
+--R                          9 2
+--R                     - 40b c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                           5 6          4 2 5          3 4 4         2 6 3
+--R                   - 22528a c  - 263680a b c  - 326400a b c  - 90048a b c
+--R                 + 
+--R                            8 2      10
+--R                   - 5880a b c  - 62b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                            5   5           4 3 4           3 5 3          2 7 2
+--R                   - 647168a b c  - 2086400a b c  - 1224192a b c  - 177216a b c
+--R                 + 
+--R                            9       11
+--R                   - 5760a b c - 22b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                            6 5           5 2 4           4 4 3           3 6 2
+--R                   - 473088a c  - 5660160a b c  - 7223040a b c  - 2084544a b c
+--R                 + 
+--R                            2 8           10
+--R                   - 146520a b c - 1782a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                             6   4            5 3 3            4 5 2
+--R                   - 6799360a b c  - 21504000a b c  - 12187648a b c
+--R                 + 
+--R                             3 7          2 9
+--R                   - 1638912a b c - 42944a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             7 4            6 2 3            5 4 2
+--R                   - 2973696a c  - 33751040a b c  - 39603200a b c
+--R                 + 
+--R                             4 6           3 8
+--R                   - 9810944a b c - 480480a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                                7   3            6 3 2            5 5
+--R                     - 26607616a b c  - 74833920a b c  - 34664448a b c
+--R                   + 
+--R                               4 7
+--R                     - 3001856a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                          8 3            7 2 2            6 4             5 6  9
+--R               (- 8290304a c  - 81682432a b c  - 75765760a b c - 11508224a b )x
+--R             + 
+--R                           8   2             7 3             6 5  8
+--R               (- 47710208a b c  - 103546880a b c - 28442624a b )x
+--R             + 
+--R                           9 2            8 2             7 4  7
+--R               (- 11534336a c  - 86114304a b c - 46235648a b )x
+--R             + 
+--R                           9               8 3  6
+--R               (- 39845888a b c - 49152000a b )x
+--R             + 
+--R                        10             9 2  5            10   4           11 3
+--R             (- 7864320a  c - 32899072a b )x  - 12582912a  b x  - 2097152a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                      5 7         4 2 6         3 4 5        2 6 4         8 3
+--R               - 2048a c  - 23040a b c  - 26880a b c  - 6720a b c  - 360a b c
+--R             + 
+--R                   10 2
+--R               - 2b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                        5   6          4 3 5          3 5 4         2 7 3
+--R               - 114688a b c  - 360960a b c  - 204288a b c  - 27840a b c
+--R             + 
+--R                       9 2     11
+--R               - 800a b c  - 2b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        6 6           5 2 5           4 4 4          3 6 3
+--R               - 124928a c  - 1487360a b c  - 1885440a b c  - 538944a b c
+--R             + 
+--R                       2 8 2         10
+--R               - 37320a b c  - 442a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                         6   5           5 3 4           4 5 3          3 7 2
+--R               - 2365440a b c  - 7546880a b c  - 4333824a b c  - 595584a b c
+--R             + 
+--R                       2 9
+--R               - 16280a b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         7 5            6 2 4            5 4 3           4 6 2
+--R               - 1269760a c  - 14663680a b c  - 17628160a b c  - 4528128a b c
+--R             + 
+--R                        3 8
+--R               - 235488a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         7   4            6 3 3            5 5 2           4 7
+--R             (- 13598720a b c  - 39403520a b c  - 19036160a b c  - 1757184a b c)
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                      8 4            7 2 3            6 4 2           5 6   10
+--R           (- 4816896a c  - 49029120a b c  - 47523840a b c  - 7687680a b c)x
+--R         + 
+--R                       8   3            7 3 2            6 5   9
+--R           (- 31817728a b c  - 72171520a b c  - 21059584a b c)x
+--R         + 
+--R                      9 3            8 2 2            7 4   8
+--R           (- 8388608a c  - 65404928a b c  - 37191680a b c)x
+--R         + 
+--R                       9   2            8 3   7
+--R           (- 32505856a b c  - 42336256a b c)x
+--R         + 
+--R                    10 2            9 2   6            10     5           11   4
+--R         (- 6815744a  c  - 30015488a b c)x  - 12058624a  b c x  - 2097152a  c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                    5 7         4 2 6         3 4 5        2 6 4         8 3
+--R               2048a c  + 23040a b c  + 26880a b c  + 6720a b c  + 360a b c
+--R             + 
+--R                 10 2
+--R               2b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                      5   6          4 3 5          3 5 4         2 7 3
+--R               115712a b c  + 372480a b c  + 217728a b c  + 31200a b c
+--R             + 
+--R                     9 2     11
+--R               980a b c  + 3b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                      6 6           5 2 5           4 4 4          3 6 3
+--R               126976a c  + 1572864a b c  + 2108160a b c  + 655872a b c
+--R             + 
+--R                     2 8 2         10     12
+--R               52560a b c  + 864a b  c + b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                       6   5           5 3 4           4 5 3          3 7 2
+--R               2552832a b c  + 8769280a b c  + 5622912a b c  + 930528a b c
+--R             + 
+--R                     2 9          11
+--R               38020a b c + 243a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                       7 5            6 2 4            5 4 3           4 6 2
+--R               1394688a c  + 17594880a b c  + 24090880a b c  + 7672896a b c
+--R             + 
+--R                      3 8         2 10
+--R               626472a b c + 9922a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                        7   4            6 3 3            5 5 2           4 7
+--R               16773120a b c  + 56238080a b c  + 34450944a b c  + 5170176a b c
+--R             + 
+--R                      3 9
+--R               160688a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                       8 4            7 2 3            6 4 2            5 6
+--R               6086656a c  + 72622080a b c  + 90854400a b c  + 24527360a b c
+--R             + 
+--R                       4 8
+--R               1359072a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                     8   3             7 3 2            6 5            5 7  10
+--R           (48676864a b c  + 144568320a b c  + 71844864a b c + 6845696a b )x
+--R         + 
+--R                     9 3             8 2 2             7 4             6 6  9
+--R           (13205504a c  + 136421376a b c  + 134277120a b c + 22038016a b )x
+--R         + 
+--R                     9   2             8 3             7 5  8
+--R           (70254592a b c  + 160497664a b c + 47038464a b )x
+--R         + 
+--R                     10 2             9 2             8 4  7
+--R           (15204352a  c  + 118751232a b c + 67403776a b )x
+--R         + 
+--R                     10               9 3  6            11             10 2  5
+--R           (49545216a  b c + 64159744a b )x  + (8912896a  c + 38928384a  b )x
+--R         + 
+--R                    11   4           12 3
+--R           13631488a  b x  + 2097152a  x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                  4   7         3 3 6         2 5 5          7 4      9 3  17
+--R           (10240a b c  + 30720a b c  + 16128a b c  + 1920a b c  + 40b c )x
+--R         + 
+--R                     5 7          4 2 6          3 4 5         2 6 4
+--R               22528a c  + 268800a b c  + 341760a b c  + 98112a b c
+--R             + 
+--R                      8 3      10 2
+--R               6840a b c  + 82b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                      5   6           4 3 5           3 5 4          2 7 3
+--R               657408a b c  + 2204160a b c  + 1366272a b c  + 214848a b c
+--R             + 
+--R                      9 2      11
+--R               8040a b c  + 42b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                      6 6           5 2 5           4 4 4           3 6 3
+--R               473088a c  + 5921280a b c  + 8026880a b c  + 2523456a b c
+--R             + 
+--R                      2 8 2          10
+--R               202392a b c  + 3122a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                       6   5            5 3 4            4 5 3           3 7 2
+--R               6973440a b c  + 23459840a b c  + 14454528a b c  + 2192256a b c
+--R             + 
+--R                     2 9
+--R               69608a b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                       7 5            6 2 4            5 4 3            4 6 2
+--R               2973696a c  + 35880960a b c  + 45603840a b c  + 12604416a b c
+--R             + 
+--R                      3 8
+--R               725472a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                     7   4            6 3 3            5 5 2           4 7   11
+--R           (27459584a b c  + 83312640a b c  + 42651648a b c  + 4246528a b c)x
+--R         + 
+--R                    8 4            7 2 3            6 4 2            5 6   10
+--R           (8290304a c  + 87760896a b c  + 89241600a b c  + 15328768a b c)x
+--R         + 
+--R                     8   3             7 3 2            6 5   9
+--R           (49446912a b c  + 116834304a b c  + 35825664a b c)x
+--R         + 
+--R                     9 3            8 2 2            7 4   8
+--R           (11534336a c  + 93192192a b c  + 55279616a b c)x
+--R         + 
+--R                     9   2            8 3   7            10 2            9 2   6
+--R           (41418752a b c  + 55967744a b c)x  + (7864320a  c  + 35782656a b c)x
+--R         + 
+--R                    10     5           11   4
+--R           13107200a  b c x  + 2097152a  c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                             4   5         3 3 4         2 5 3          7 2
+--R                       10240a b c  + 30720a b c  + 16128a b c  + 1920a b c
+--R                     + 
+--R                          9
+--R                       40b c
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                           5 5          4 2 4          3 4 3         2 6 2
+--R                     22528a c  + 253440a b c  + 295680a b c  + 73920a b c
+--R                   + 
+--R                            8       10
+--R                     3960a b c + 22b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                            5   4           4 3 3          3 5 2          2 7
+--R                     614400a b c  + 1802240a b c  + 912384a b c  + 101376a b c
+--R                   + 
+--R                            9
+--R                     1760a b
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                            6 4           5 2 3           4 4 2           3 6
+--R                     450560a c  + 4792320a b c  + 5125120a b c  + 1098240a b c
+--R                   + 
+--R                           2 8
+--R                     41184a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                          6   3            5 3 2           4 5           3 7  7
+--R                 (5734400a b c  + 14909440a b c  + 6150144a b c + 439296a b )x
+--R               + 
+--R                          7 3            6 2 2            5 4            4 6  6
+--R                 (2523136a c  + 23224320a b c  + 19568640a b c + 2562560a b )x
+--R               + 
+--R                           7   2            6 3            5 5  5
+--R                 (18350080a b c  + 36700160a b c + 8945664a b )x
+--R               + 
+--R                          8 2            7 2             6 4  4
+--R                 (5767168a c  + 40108032a b c + 19496960a b )x
+--R               + 
+--R                           8               7 3  3
+--R                 (23592960a b c + 26738688a b )x
+--R               + 
+--R                          9             8 2  2            9              10
+--R                 (5767168a c + 22413312a b )x  + 10485760a b x + 2097152a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                      5 6         4 2 5         3 4 4        2 6 3         8 2
+--R                 2048a c  + 23040a b c  + 26880a b c  + 6720a b c  + 360a b c
+--R               + 
+--R                   10
+--R                 2b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                        5   5          4 3 4          3 5 3         2 7 2
+--R                 112640a b c  + 337920a b c  + 177408a b c  + 21120a b c
+--R               + 
+--R                       9
+--R                 440a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                        6 5           5 2 4           4 4 3          3 6 2
+--R                 122880a c  + 1351680a b c  + 1520640a b c  + 354816a b c
+--R               + 
+--R                       2 8
+--R                 15840a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                      6   4           5 3 3           4 5 2          3 7   8
+--R             (2129920a b c  + 5857280a b c  + 2635776a b c  + 219648a b c)x
+--R           + 
+--R                      7 4            6 2 3            5 4 2           4 6   7
+--R             (1146880a c  + 11182080a b c  + 10250240a b c  + 1537536a b c)x
+--R           + 
+--R                       7   3            6 3 2           5 5   6
+--R             (10321920a b c  + 22364160a b c  + 6150144a b c)x
+--R           + 
+--R                      8 3            7 2 2            6 4   5
+--R             (3670016a c  + 27525120a b c  + 14909440a b c)x
+--R           + 
+--R                       8   2            7 3   4
+--R             (17825792a b c  + 22282240a b c)x
+--R           + 
+--R                      9 2            8 2   3           9     2           10
+--R             (4718592a c  + 20054016a b c)x  + 9961472a b c x  + 2097152a  c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                        5 6         4 2 5         3 4 4        2 6 3         8 2
+--R                 - 2048a c  - 23040a b c  - 26880a b c  - 6720a b c  - 360a b c
+--R               + 
+--R                     10
+--R                 - 2b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          5   5          4 3 4          3 5 3         2 7 2
+--R                 - 113664a b c  - 349440a b c  - 190848a b c  - 24480a b c
+--R               + 
+--R                         9     11
+--R                 - 620a b c - b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                          6 5           5 2 4           4 4 3          3 6 2
+--R                 - 124928a c  - 1436160a b c  - 1731840a b c  - 458304a b c
+--R               + 
+--R                         2 8          10
+--R                 - 27720a b c - 242a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           6   4           5 3 3           4 5 2          3 7
+--R                 - 2314240a b c  - 6983680a b c  - 3700224a b c  - 447744a b c
+--R               + 
+--R                        2 9
+--R                 - 9680a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                           7 4            6 2 3            5 4 2           4 6
+--R                 - 1269760a c  - 13844480a b c  - 15375360a b c  - 3514368a b c
+--R               + 
+--R                          3 8
+--R                 - 151008a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                         7   3            6 3 2            5 5            4 7  7
+--R             (- 13189120a b c  - 35409920a b c  - 15375360a b c - 1208064a b )x
+--R           + 
+--R                        8 3            7 2 2            6 4            5 6  6
+--R             (- 4816896a c  - 45588480a b c  - 40069120a b c - 5637632a b )x
+--R           + 
+--R                         8   2            7 3             6 5  5
+--R             (- 30670848a b c  - 63569920a b c - 16400384a b )x
+--R           + 
+--R                        9 2            8 2             7 4  4
+--R             (- 8388608a c  - 60162048a b c - 30638080a b )x
+--R           + 
+--R                         9               8 3  3
+--R             (- 31195136a b c - 36765696a b )x
+--R           + 
+--R                        10             9 2  2            10              11
+--R             (- 6815744a  c - 27394048a b )x  - 11534336a  b x - 2097152a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                        4   6         3 3 5         2 5 4          7 3      9 2
+--R               (- 10240a b c  - 30720a b c  - 16128a b c  - 1920a b c  - 40b c )
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                         5 6          4 2 5          3 4 4         2 6 3
+--R                 - 22528a c  - 258560a b c  - 311040a b c  - 81984a b c
+--R               + 
+--R                          8 2      10
+--R                 - 4920a b c  - 42b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                          5   5           4 3 4           3 5 3          2 7 2
+--R                 - 624640a b c  - 1914880a b c  - 1039104a b c  - 130944a b c
+--R               + 
+--R                          9
+--R                 - 3080a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          6 5           5 2 4           4 4 3           3 6 2
+--R                 - 450560a c  - 5038080a b c  - 5800960a b c  - 1402368a b c
+--R               + 
+--R                         2 8
+--R                 - 66528a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                        6   4            5 3 3           4 5 2          3 7   8
+--R             (- 5898240a b c  - 16506880a b c  - 7614464a b c  - 658944a b c)x
+--R           + 
+--R                        7 4            6 2 3            5 4 2           4 6   7
+--R             (- 2523136a c  - 24944640a b c  - 23296000a b c  - 3587584a b c)x
+--R           + 
+--R                         7   3            6 3 2            5 5   6
+--R             (- 19038208a b c  - 41861120a b c  - 11741184a b c)x
+--R           + 
+--R                        8 3            7 2 2            6 4   5
+--R             (- 5767168a c  - 43778048a b c  - 24084480a b c)x
+--R           + 
+--R                         8   2            7 3   4
+--R             (- 24641536a b c  - 31195136a b c)x
+--R           + 
+--R                      9 2            8 2   3            9     2           10
+--R           (- 5767168a c  - 24772608a b c)x  - 11010048a b c x  - 2097152a  c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      4 4        2 4 2         6       8  5
+--R               (- 768a c  + 1440a b c  - 288a b c - 15b )x
+--R             + 
+--R                       4   3        3 3 2       2 5          7  4
+--R               (- 6144a b c  + 7680a b c  + 384a b c - 480a b )x
+--R             + 
+--R                       5 3        4 2 2        3 4         2 6  3
+--R               (- 6144a c  + 1536a b c  + 9600a b c - 2400a b )x
+--R             + 
+--R                        5   2         4 3         3 5  2
+--R               (- 12288a b c  + 18432a b c - 3840a b )x
+--R             + 
+--R                       6 2        5 2         4 4
+--R               (- 6144a c  + 9216a b c - 1920a b )x
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b x + a
+--R         + 
+--R                     3   4        2 3 3        5 2       7   6
+--R               (1536a b c  - 1920a b c  - 96a b c  + 120b c)x
+--R             + 
+--R                     4 4       3 2 3        2 4 2          6        8  5
+--R               (3072a c  + 768a b c  - 6720a b c  + 1104a b c + 120b )x
+--R             + 
+--R                      4   3         3 3 2        2 5           7  4
+--R               (13824a b c  - 16512a b c  - 2016a b c + 1320a b )x
+--R             + 
+--R                     5 3       4 2 2         3 4         2 6  3
+--R               (9216a c  - 768a b c  - 16704a b c + 4080a b )x
+--R             + 
+--R                      5   2         4 3         3 5  2
+--R               (15360a b c  - 23040a b c + 4800a b )x
+--R             + 
+--R                     6 2        5 2         4 4
+--R               (6144a c  - 9216a b c + 1920a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                       3   3        2 3 2         5        7  3
+--R               (- 3072a b c  + 3840a b c  + 192a b c - 240b )x
+--R             + 
+--R                       4 3        3 2 2        2 4           6  2
+--R               (- 6144a c  + 1536a b c  + 9600a b c - 2400a b )x
+--R             + 
+--R                        4   2         3 3         2 5           5 2         4 2
+--R               (- 18432a b c  + 27648a b c - 5760a b )x - 12288a c  + 18432a b c
+--R             + 
+--R                      3 4
+--R               - 3840a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                     4 4        2 4 2         6       8  4
+--R               (1536a c  - 2880a b c  + 576a b c + 30b )x
+--R             + 
+--R                      4   3         3 3 2       2 5          7  3
+--R               (12288a b c  - 15360a b c  - 768a b c + 960a b )x
+--R             + 
+--R                      5 3        4 2 2         3 4         2 6  2
+--R               (12288a c  - 3072a b c  - 19200a b c + 4800a b )x
+--R             + 
+--R                      5   2         4 3         3 5           6 2         5 2
+--R               (24576a b c  - 36864a b c + 7680a b )x + 12288a c  - 18432a b c
+--R             + 
+--R                    4 4
+--R               3840a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                       2 5          2 4      4 3  7
+--R               (- 1536a c  - 2304a b c  - 96b c )x
+--R             + 
+--R                        2   4          3 3      5 2  6
+--R               (- 12544a b c  - 3456a b c  - 16b c )x
+--R             + 
+--R                        3 4         2 2 3        4 2      6   5
+--R               (- 13056a c  - 18240a b c  - 80a b c  + 20b c)x
+--R             + 
+--R                        3   3       2 3 2        5       7  4
+--R               (- 31104a b c  + 480a b c  + 24a b c - 30b )x
+--R             + 
+--R                        4 3       3 2 2        2 4          6  3
+--R               (- 18432a c  + 768a b c  + 2816a b c - 720a b )x
+--R             + 
+--R                       4   2         3 3         2 5  2
+--R               (- 7680a b c  + 11520a b c - 2400a b )x
+--R             + 
+--R                       5 2        4 2         3 4
+--R               (- 6144a c  + 9216a b c - 1920a b )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                         5       3 4  8         2 5           2 4       4 3  7
+--R               (3072a b c  + 768b c )x  + (6144a c  + 11264a b c  + 896b c )x
+--R             + 
+--R                      2   4          3 3      5 2  6
+--R               (30208a b c  + 9984a b c  - 32b c )x
+--R             + 
+--R                      3 4         2 2 3         4 2      6   5
+--R               (21504a c  + 31488a b c  - 320a b c  + 80b c)x
+--R             + 
+--R                      3   3        2 3 2         5        7  4
+--R               (42624a b c  - 4896a b c  + 152a b c + 210b )x
+--R             + 
+--R                      4 3        3 2 2        2 4           6  3
+--R               (21504a c  - 2304a b c  - 6464a b c + 1680a b )x
+--R             + 
+--R                      4   2         3 3         2 5  2
+--R               (10752a b c  - 16128a b c + 3360a b )x
+--R             + 
+--R                     5 2        4 2         3 4
+--R               (6144a c  - 9216a b c + 1920a b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                       5       3 4  9           2 5           2 4       4 3  8
+--R           (- 3072a b c  - 768b c )x  + (- 6144a c  - 11264a b c  - 896b c )x
+--R         + 
+--R                    2   4          3 3      5 2  7
+--R           (- 30208a b c  - 9984a b c  + 32b c )x
+--R         + 
+--R                    3 4         2 2 3         4 2      6   6
+--R           (- 21504a c  - 31488a b c  + 320a b c  - 80b c)x
+--R         + 
+--R                    3   3        2 3 2         5        7  5
+--R           (- 40960a b c  + 6912a b c  - 768a b c - 240b )x
+--R         + 
+--R                    4 3         3 2 2        2 4           6  4
+--R           (- 21504a c  + 15616a b c  + 5952a b c - 2640a b )x
+--R         + 
+--R                 4   2         3 3         2 5  3
+--R           (2560a b c  + 28928a b c - 8160a b )x
+--R         + 
+--R                   5 2         4 2         3 4  2          5           4 3
+--R           (- 6144a c  + 35840a b c - 9600a b )x  + (13312a b c - 3840a b )x
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                 2 6          2 5      4 4  10
+--R           (1536a c  + 2304a b c  + 96b c )x
+--R         + 
+--R                  2   5          3 4       5 3  9
+--R           (14080a b c  + 5760a b c  + 112b c )x
+--R         + 
+--R                  3 5         2 2 4          4 3     6 2  8
+--R           (14592a c  + 33088a b c  + 3632a b c  - 4b c )x
+--R         + 
+--R                  3   4         2 3 3        5 2      7   7
+--R           (56704a b c  + 21216a b c  + 72a b c  + 10b c)x
+--R         + 
+--R                  4 4         3 2 3        2 4 2         6       8  6
+--R           (31488a c  + 45248a b c  - 3088a b c  + 916a b c + 30b )x
+--R         + 
+--R                  4   3         3 3 2        2 5          7  5
+--R           (50560a b c  - 22496a b c  + 2088a b c + 990a b )x
+--R         + 
+--R                  5 3         4 2 2         3 4         2 6  4
+--R           (24576a c  - 32256a b c  - 12928a b c + 5760a b )x
+--R         + 
+--R                   5   2         4 3          3 5  3
+--R           (- 6144a b c  - 43264a b c + 12480a b )x
+--R         + 
+--R                 6 2         5 2          4 4  2            6           5 3
+--R           (6144a c  - 42496a b c + 11520a b )x  + (- 13312a b c + 3840a b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                        4        3 3  3          2 4           2 3  2
+--R             (12288a b c  + 3072b c )x  + (24576a c  + 30720a b c )x
+--R           + 
+--R                   2   3          3 3
+--R             73728a b c x + 49152a c
+--R        *
+--R                          +--------------+
+--R            +---+ +-+ +-+ |   2
+--R           \|- c \|a \|c \|c x  + b x + a
+--R       + 
+--R                     2 5          2 4       4 3  4
+--R             (- 6144a c  - 9216a b c  - 384b c )x
+--R           + 
+--R                      2   4           3 3  3            3 4         2 2 3  2
+--R             (- 49152a b c  - 12288a b c )x  + (- 49152a c  - 61440a b c )x
+--R           + 
+--R                     3   3          4 3
+--R             - 98304a b c x - 49152a c
+--R        *
+--R            +---+ +-+
+--R           \|- c \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                       3   4        2 3 3         5 2      7   11
+--R               (- 1024a b c  - 1792a b c  - 448a b c  - 16b c)x
+--R             + 
+--R                       4 4         3 2 3        2 4 2          6       8  10
+--R               (- 2048a c  - 14848a b c  - 9856a b c  - 1120a b c - 16b )x
+--R             + 
+--R                        4   3         3 3 2         2 5          7  9
+--R               (- 33792a b c  - 61696a b c  - 16576a b c - 688a b )x
+--R             + 
+--R                        5 3          4 2 2         3 4         2 6  8
+--R               (- 22528a c  - 157184a b c  - 96384a b c - 8736a b )x
+--R             + 
+--R                         5   2          4 3          3 5  7
+--R               (- 174080a b c  - 271360a b c - 50304a b )x
+--R             + 
+--R                        6 2          5 2           4 4  6
+--R               (- 69632a c  - 395264a b c - 154880a b )x
+--R             + 
+--R                         6             5 3  5            7           6 2  4
+--R               (- 286720a b c - 272384a b )x  + (- 81920a c - 274432a b )x
+--R             + 
+--R                        7   3         8 2
+--R               - 147456a b x  - 32768a x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                4 5        3 2 4        2 4 3         6 2    8   12
+--R           (256a c  + 1792a b c  + 1120a b c  + 112a b c  + b c)x
+--R         + 
+--R                 4   4         3 3 3        2 5 2         7     9  11
+--R           (8448a b c  + 16128a b c  + 4704a b c  + 240a b c + b )x
+--R         + 
+--R                 5 4         4 2 3         3 4 2        2 6          8  10
+--R           (8448a c  + 65280a b c  + 47712a b c  + 6384a b c + 129a b )x
+--R         + 
+--R                  5   3          4 3 2         3 5         2 7  9
+--R           (98304a b c  + 192512a b c  + 57344a b c + 2816a b )x
+--R         + 
+--R                  6 3          5 2 2          4 4          3 6  8
+--R           (49152a c  + 362496a b c  + 239616a b c + 24192a b )x
+--R         + 
+--R                   6   2          5 3           4 5  7
+--R           (319488a b c  + 528384a b c + 105984a b )x
+--R         + 
+--R                   7 2          6 2           5 4  6
+--R           (106496a c  + 634880a b c + 264704a b )x
+--R         + 
+--R                   7             6 3  5          8           7 2  4
+--R           (393216a b c + 393216a b )x  + (98304a c + 344064a b )x
+--R         + 
+--R                  8   3         9 2
+--R           163840a b x  + 32768a x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  4 5        3 2 4        2 4 3         6 2    8   13
+--R           (- 256a c  - 1792a b c  - 1120a b c  - 112a b c  - b c)x
+--R         + 
+--R                   4   4         3 3 3        2 5 2         7     9  12
+--R           (- 8448a b c  - 16128a b c  - 4704a b c  - 240a b c - b )x
+--R         + 
+--R                   5 4         4 2 3         3 4 2        2 6          8  11
+--R           (- 8448a c  - 65280a b c  - 47712a b c  - 6384a b c - 129a b )x
+--R         + 
+--R                    5   3          4 3 2         3 5         2 7  10
+--R           (- 98304a b c  - 192512a b c  - 57344a b c - 2816a b )x
+--R         + 
+--R                    6 3          5 2 2          4 4          3 6  9
+--R           (- 49152a c  - 362496a b c  - 239616a b c - 24192a b )x
+--R         + 
+--R                     6   2          5 3           4 5  8
+--R           (- 319488a b c  - 528384a b c - 105984a b )x
+--R         + 
+--R                     7 2          6 2           5 4  7
+--R           (- 106496a c  - 634880a b c - 264704a b )x
+--R         + 
+--R                     7             6 3  6            8           7 2  5
+--R           (- 393216a b c - 393216a b )x  + (- 98304a c - 344064a b )x
+--R         + 
+--R                    8   4         9 3
+--R           - 163840a b x  - 32768a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 3   5        2 3 4         5 3      7 2  14
+--R           (1024a b c  + 1792a b c  + 448a b c  + 16b c )x
+--R         + 
+--R                 4 5         3 2 4         2 4 3          6 2      8   13
+--R           (2048a c  + 15872a b c  + 11648a b c  + 1568a b c  + 32b c)x
+--R         + 
+--R                  4   4         3 3 3         2 5 2          7       9  12
+--R           (36864a b c  + 78336a b c  + 26880a b c  + 1824a b c + 16b )x
+--R         + 
+--R                  5 4          4 2 3          3 4 2         2 6          8  11
+--R           (24576a c  + 205824a b c  + 167936a b c  + 26432a b c + 704a b )x
+--R         + 
+--R                   5   3          4 3 2          3 5         2 7  10
+--R           (230400a b c  + 490240a b c  + 163264a b c + 9424a b )x
+--R         + 
+--R                  6 3          5 2 2          4 4          3 6  9
+--R           (92160a c  + 726528a b c  + 522624a b c + 59040a b )x
+--R         + 
+--R                   6   2          5 3           4 5  8
+--R           (530432a b c  + 939008a b c + 205184a b )x
+--R         + 
+--R                   7 2          6 2           5 4  7
+--R           (151552a c  + 956416a b c + 427264a b )x
+--R         + 
+--R                   7             6 3  6           8           7 2  5
+--R           (516096a b c + 546816a b )x  + (114688a c + 421888a b )x
+--R         + 
+--R                  8   4         9 3
+--R           180224a b x  + 32768a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  4 4        3 2 3        2 4 2         6     8  8
+--R             (256a c  + 1792a b c  + 1120a b c  + 112a b c + b )x
+--R           + 
+--R                   4   3         3 3 2        2 5          7  7
+--R             (8192a b c  + 14336a b c  + 3584a b c + 128a b )x
+--R           + 
+--R                   5 3         4 2 2         3 4         2 6  6
+--R             (8192a c  + 55296a b c  + 32256a b c + 2688a b )x
+--R           + 
+--R                    5   2          4 3          3 5  5
+--R             (81920a b c  + 122880a b c + 21504a b )x
+--R           + 
+--R                    6 2          5 2          4 4  4
+--R             (40960a c  + 225280a b c + 84480a b )x
+--R           + 
+--R                     6             5 3  3          7           6 2  2
+--R             (196608a b c + 180224a b )x  + (65536a c + 212992a b )x
+--R           + 
+--R                    7            8
+--R             131072a b x + 32768a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                     3   4        2 3 3         5 2      7   9
+--R             (- 1024a b c  - 1792a b c  - 448a b c  - 16b c)x
+--R           + 
+--R                     4 4         3 2 3        2 4 2          6       8  8
+--R             (- 2048a c  - 14848a b c  - 9856a b c  - 1120a b c - 16b )x
+--R           + 
+--R                      4   3         3 3 2         2 5          7  7
+--R             (- 33792a b c  - 61696a b c  - 16576a b c - 688a b )x
+--R           + 
+--R                      5 3          4 2 2         3 4         2 6  6
+--R             (- 22528a c  - 157184a b c  - 96384a b c - 8736a b )x
+--R           + 
+--R                       5   2          4 3          3 5  5
+--R             (- 174080a b c  - 271360a b c - 50304a b )x
+--R           + 
+--R                      6 2          5 2           4 4  4
+--R             (- 69632a c  - 395264a b c - 154880a b )x
+--R           + 
+--R                       6             5 3  3            7           6 2  2
+--R             (- 286720a b c - 272384a b )x  + (- 81920a c - 274432a b )x
+--R           + 
+--R                      7            8
+--R             - 147456a b x - 32768a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 190
+
+)clear all
+
+--S 191 of 704
+t0:=sqrt(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R         +------------------+
+--R         |   4      3      2
+--R   (1)  \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 704
+r0:=-1/8*b*(b+2*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/(c^2*x)+1/3*(a+b*x+c*x^2)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(c*x)+1/16*b*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a*x^2+b*x^3+c*x^4)/(c^(5/2)*_
+   x*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                         +------------------+
+--R                      3  |   4      3      2              2c x + b
+--R       (- 12a b c + 3b )\|c x  + b x  + a x  atanh(----------------------)
+--R                                                         +--------------+
+--R                                                     +-+ |   2
+--R                                                   2\|c \|c x  + b x + a
+--R     + 
+--R                                         +--------------+ +------------------+
+--R         2 2                      2  +-+ |   2            |   4      3      2
+--R     (16c x  + 4b c x + 16a c - 6b )\|c \|c x  + b x + a \|c x  + b x  + a x
+--R  /
+--R               +--------------+
+--R        2  +-+ |   2
+--R     48c x\|c \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     2   2        3       5  2        2 2         4         3
+--R                 (96a b c  + 48a b c - 18b )x  + (384a b c - 96a b )x + 384a b c
+--R               + 
+--R                      2 3
+--R                 - 96a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                    2 2 2        4      6  3
+--R             (- 144a b c  + 24a b c + 3b )x
+--R           + 
+--R                    3   2       2 3         5  2          3 2        2 4
+--R             (- 288a b c  - 144a b c + 54a b )x  + (- 576a b c + 144a b )x
+--R           + 
+--R                   4         3 3
+--R             - 384a b c + 96a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                        3      3 2  5          2 3         2 2     4   4
+--R             (- 192a b c  - 16b c )x  + (- 384a c  - 336a b c  - 4b c)x
+--R           + 
+--R                     2   2        3      5  3
+--R             (- 1056a b c  - 16a b c + 6b )x
+--R           + 
+--R                    3 2       2 2         4  2          3         2 3
+--R             (- 768a c  - 288a b c + 72a b )x  + (- 384a b c + 96a b )x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                    4      2 3  6            3       3 2  5
+--R             (128a c  + 96b c )x  + (672a b c  + 120b c )x
+--R           + 
+--R                  2 3         2 2      4   4         2   2        3       5  3
+--R             (768a c  + 816a b c  - 12b c)x  + (1632a b c  + 64a b c - 30b )x
+--R           + 
+--R                  3 2       2 2          4  2        3         2 3
+--R             (768a c  + 480a b c - 120a b )x  + (384a b c - 96a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                   3       2 2  2            2         2 2  +-+ +-+
+--R           ((384a c  + 288b c )x  + 1536a b c x + 1536a c )\|a \|c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                        3      3 2  3           2 3         2 2  2        2   2
+--R             (- 576a b c  - 48b c )x  + (- 1152a c  - 864a b c )x  - 2304a b c x
+--R           + 
+--R                    3 2
+--R             - 1536a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                       2   2        3       5  2          2 2         4
+--R                 (- 96a b c  - 48a b c + 18b )x  + (- 384a b c + 96a b )x
+--R               + 
+--R                       3         2 3
+--R                 - 384a b c + 96a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                  2 2 2        4      6  3        3   2       2 3         5  2
+--R             (144a b c  - 24a b c - 3b )x  + (288a b c  + 144a b c - 54a b )x
+--R           + 
+--R                  3 2        2 4         4         3 3
+--R             (576a b c - 144a b )x + 384a b c - 96a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                       3     3 2  5          2 3         2 2     4   4
+--R             (- 96a b c  - 8b c )x  + (- 192a c  - 168a b c  - 2b c)x
+--R           + 
+--R                    2   2       3      5  3          3 2       2 2         4  2
+--R             (- 528a b c  - 8a b c + 3b )x  + (- 384a c  - 144a b c + 36a b )x
+--R           + 
+--R                    3         2 3
+--R             (- 192a b c + 48a b )x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                   4      2 3  6            3      3 2  5
+--R             (64a c  + 48b c )x  + (336a b c  + 60b c )x
+--R           + 
+--R                  2 3         2 2     4   4        2   2        3       5  3
+--R             (384a c  + 408a b c  - 6b c)x  + (816a b c  + 32a b c - 15b )x
+--R           + 
+--R                  3 2       2 2         4  2        3         2 3
+--R             (384a c  + 240a b c - 60a b )x  + (192a b c - 48a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                   3       2 2  2           2        2 2  +---+ +-+
+--R           ((192a c  + 144b c )x  + 768a b c x + 768a c )\|- c \|a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                        3      3 2  3          2 3         2 2  2        2   2
+--R             (- 288a b c  - 24b c )x  + (- 576a c  - 432a b c )x  - 1152a b c x
+--R           + 
+--R                   3 2
+--R             - 768a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 193
+
+--S 194 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    2 2 2        4      6  4        3   2       2 3         5  3
+--R               (144a b c  - 24a b c - 3b )x  + (288a b c  + 144a b c - 54a b )x
+--R             + 
+--R                    3 2        2 4  2        4         3 3
+--R               (576a b c - 144a b )x  + (384a b c - 96a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                     2   3        3 2      5   5
+--R               (- 96a b c  - 48a b c  + 18b c)x
+--R             + 
+--R                      2 2 2        4       6  4
+--R               (- 480a b c  + 48a b c + 18b )x
+--R             + 
+--R                      3   2       2 3          5  3          3 2        2 4  2
+--R               (- 480a b c  - 336a b c + 114a b )x  + (- 768a b c + 192a b )x
+--R             + 
+--R                      4         3 3
+--R               (- 384a b c + 96a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                     2   2        3       5  2          2 2         4
+--R               (- 96a b c  - 48a b c + 18b )x  + (- 384a b c + 96a b )x
+--R             + 
+--R                     3         2 3
+--R               - 384a b c + 96a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                2 2 2        4      6  3        3   2       2 3         5  2
+--R           (144a b c  - 24a b c - 3b )x  + (288a b c  + 144a b c - 54a b )x
+--R         + 
+--R                3 2        2 4         4         3 3
+--R           (576a b c - 144a b )x + 384a b c - 96a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2              2c x + b
+--R         \|c x  + b x  + a x  atanh(----------------------)
+--R                                          +--------------+
+--R                                      +-+ |   2
+--R                                    2\|c \|c x  + b x + a
+--R     + 
+--R                          3      3 2  5          2 3         2 2     4   4
+--R               (- 192a b c  - 16b c )x  + (- 384a c  - 336a b c  - 4b c)x
+--R             + 
+--R                       2   2        3      5  3
+--R               (- 1056a b c  - 16a b c + 6b )x
+--R             + 
+--R                      3 2       2 2          4  2          3          2 3
+--R               (- 896a c  - 336a b c + 108a b )x  + (- 896a b c + 288a b )x
+--R             + 
+--R                     4        3 2
+--R               - 512a c + 192a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                      4      2 3  6            3       3 2  5
+--R               (128a c  + 96b c )x  + (672a b c  + 120b c )x
+--R             + 
+--R                    2 3         2 2      4   4         2   2       3       5  3
+--R               (768a c  + 816a b c  - 12b c)x  + (1824a b c  + 8a b c - 36b )x
+--R             + 
+--R                     3 2       2 2          4  2         3          2 3
+--R               (1152a c  + 624a b c - 228a b )x  + (1152a b c - 384a b )x
+--R             + 
+--R                   4        3 2
+--R               512a c - 192a b
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                    4      2 3  7              3       3 2  6
+--R           (- 128a c  - 96b c )x  + (- 672a b c  - 120b c )x
+--R         + 
+--R                  2 3         2 2      4   5           2   2        3       5  4
+--R           (- 768a c  - 816a b c  + 12b c)x  + (- 1632a b c  - 64a b c + 30b )x
+--R         + 
+--R                  3 2       2 2          4  3          3         2 3  2
+--R           (- 768a c  - 480a b c + 120a b )x  + (- 384a b c + 96a b )x
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                    4      3 3  8        2 4         2 3      4 2  7
+--R           (192a b c  + 16b c )x  + (384a c  + 528a b c  + 20b c )x
+--R         + 
+--R                 2   3         3 2     5   6
+--R           (1632a b c  + 368a b c  - 2b c)x
+--R         + 
+--R                 3 3        2 2 2        4      6  5
+--R           (1152a c  + 1680a b c  - 52a b c - 6b )x
+--R         + 
+--R                 3   2       2 3         5  4        4 2       3 2        2 4  3
+--R           (2208a b c  + 208a b c - 78a b )x  + (768a c  + 672a b c - 168a b )x
+--R         + 
+--R                4         3 3  2
+--R           (384a b c - 96a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                    3      3 2  4         2 3         2 2  3        2   2 2
+--R           (576a b c  + 48b c )x  + (1152a c  + 864a b c )x  + 2304a b c x
+--R         + 
+--R                3 2
+--R           1536a c x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R     + 
+--R                    4       2 3  5               3       3 2  4
+--R           (- 384a c  - 288b c )x  + (- 1920a b c  - 288b c )x
+--R         + 
+--R                   2 3          2 2  3        2   2 2        3 2
+--R           (- 1920a c  - 1824a b c )x  - 3072a b c x  - 1536a c x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          4 5        3 2 4        2 4 3         6 2     8   11
+--R                   (- 512a c  - 3584a b c  - 2240a b c  - 224a b c  - 2b c)x
+--R                 + 
+--R                            4   4         3 3 3        2 5 2         7     9  10
+--R                   (- 18688a b c  - 34048a b c  - 9184a b c  - 400a b c - b )x
+--R                 + 
+--R                               5 4          4 2 3          3 4 2         2 6
+--R                       - 20992a c  - 152064a b c  - 100800a b c  - 11424a b c
+--R                     + 
+--R                               8
+--R                       - 162a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                             5   3          4 3 2          3 5         2 7  8
+--R                   (- 256000a b c  - 453120a b c  - 115584a b c - 4320a b )x
+--R                 + 
+--R                             6 3          5 2 2          4 4          3 6  7
+--R                   (- 143360a c  - 957440a b c  - 549120a b c - 44352a b )x
+--R                 + 
+--R                             6   2           5 3           4 5  6
+--R                   (- 946176a b c  - 1374208a b c - 228096a b )x
+--R                 + 
+--R                             7 2           6 2           5 4  5
+--R                   (- 352256a c  - 1863680a b c - 658944a b )x
+--R                 + 
+--R                              7              6 3  4
+--R                   (- 1294336a b c - 1118208a b )x
+--R                 + 
+--R                             8            7 2  3          8   2          9
+--R                   (- 360448a c - 1105920a b )x  - 589824a b x  - 131072a x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                           3   5        2 3 4         5 3      7 2  11
+--R                   (- 2048a b c  - 3584a b c  - 896a b c  - 32b c )x
+--R                 + 
+--R                                4 5         3 2 4         2 4 3          6 2
+--R                         - 4608a c  - 33280a b c  - 21952a b c  - 2464a b c
+--R                       + 
+--R                              8
+--R                         - 34b c
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                            4   4          3 3 3         2 5 2          7   9
+--R                   (- 83968a b c  - 152064a b c  - 40320a b c  - 1632a b c)x
+--R                 + 
+--R                            5 4          4 2 3          3 4 2         2 6   8
+--R                   (- 61440a c  - 424960a b c  - 257280a b c  - 22848a b c)x
+--R                 + 
+--R                             5   3          4 3 2          3 5   7
+--R                   (- 512000a b c  - 788480a b c  - 143616a b c)x
+--R                 + 
+--R                             6 3           5 2 2          4 4   6
+--R                   (- 221184a c  - 1241088a b c  - 478720a b c)x
+--R                 + 
+--R                             6   2          5 3   5
+--R                   (- 966656a b c  - 905216a b c)x
+--R                 + 
+--R                           7 2          6 2   4          7     3          8   2
+--R                 (- 294912a c  - 974848a b c)x  - 557056a b c x  - 131072a c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                     3   5        2 3 4         5 3      7 2  12
+--R               (2048a b c  + 3584a b c  + 896a b c  + 32b c )x
+--R             + 
+--R                     4 5         3 2 4         2 4 3          6 2      8   11
+--R               (4608a c  + 34304a b c  + 23744a b c  + 2912a b c  + 50b c)x
+--R             + 
+--R                      4   4          3 3 3         2 5 2          7       9  10
+--R               (88576a b c  + 174080a b c  + 53312a b c  + 3008a b c + 18b )x
+--R             + 
+--R                           5 4          4 2 3          3 4 2         2 6
+--R                     66048a c  + 508416a b c  + 369600a b c  + 49056a b c
+--R                   + 
+--R                           8
+--R                     978a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                       5   3           4 3 2          3 5          2 7  8
+--R               (634880a b c  + 1208320a b c  + 344832a b c + 15744a b )x
+--R             + 
+--R                       6 3           5 2 2           4 4           3 6  7
+--R               (282624a c  + 2003968a b c  + 1253120a b c + 116160a b )x
+--R             + 
+--R                        6   2           5 3           4 5  6
+--R               (1630208a b c  + 2539520a b c + 467456a b )x
+--R             + 
+--R                       7 2           6 2            5 4  5
+--R               (516096a c  + 2895872a b c + 1111552a b )x
+--R             + 
+--R                        7              6 3  4           8            7 2  3
+--R               (1736704a b c + 1605632a b )x  + (425984a c + 1384448a b )x
+--R             + 
+--R                      8   2          9
+--R               655360a b x  + 131072a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                4 6        3 2 5        2 4 4         6 3     8 2  12
+--R           (512a c  + 3584a b c  + 2240a b c  + 224a b c  + 2b c )x
+--R         + 
+--R                  4   5         3 3 4         2 5 3         7 2     9   11
+--R           (18944a b c  + 35840a b c  + 10304a b c  + 512a b c  + 2b c)x
+--R         + 
+--R                  5 5          4 2 4          3 4 3         2 6 2         8   10
+--R           (20992a c  + 160256a b c  + 115136a b c  + 15008a b c  + 290a b c)x
+--R         + 
+--R                   5   4          4 3 3          3 5 2        2 7   9
+--R           (264192a b c  + 508416a b c  + 147840a b c  + 7008a b c)x
+--R         + 
+--R                   6 4           5 2 3          4 4 2         3 6   8
+--R           (143360a c  + 1039360a b c  + 672000a b c  + 65856a b c)x
+--R         + 
+--R                   6   3           5 3 2          4 5   7
+--R           (987136a b c  + 1599488a b c  + 312576a b c)x
+--R         + 
+--R                   7 3           6 2 2          5 4   6
+--R           (352256a c  + 2060288a b c  + 839168a b c)x
+--R         + 
+--R                    7   2           6 3   5           8 2           7 2   4
+--R           (1359872a b c  + 1331200a b c)x  + (360448a c  + 1236992a b c)x
+--R         + 
+--R                  8     3          9   2
+--R           622592a b c x  + 131072a c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                       3   5        2 3 4         5 3      7 2  13
+--R               (- 2048a b c  - 3584a b c  - 896a b c  - 32b c )x
+--R             + 
+--R                       4 5         3 2 4         2 4 3          6 2      8   12
+--R               (- 4608a c  - 34304a b c  - 23744a b c  - 2912a b c  - 50b c)x
+--R             + 
+--R                          4   4          3 3 3         2 5 2          7       9
+--R                 (- 88576a b c  - 174080a b c  - 53312a b c  - 3008a b c - 18b )
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                           5 4          4 2 3          3 4 2         2 6
+--R                   - 66048a c  - 508416a b c  - 369600a b c  - 49056a b c
+--R                 + 
+--R                           8
+--R                   - 978a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                         5   3           4 3 2          3 5          2 7  9
+--R               (- 634880a b c  - 1208320a b c  - 344832a b c - 15744a b )x
+--R             + 
+--R                         6 3           5 2 2           4 4           3 6  8
+--R               (- 282624a c  - 2003968a b c  - 1253120a b c - 116160a b )x
+--R             + 
+--R                          6   2           5 3           4 5  7
+--R               (- 1630208a b c  - 2539520a b c - 467456a b )x
+--R             + 
+--R                         7 2           6 2            5 4  6
+--R               (- 516096a c  - 2895872a b c - 1111552a b )x
+--R             + 
+--R                          7              6 3  5             8            7 2  4
+--R               (- 1736704a b c - 1605632a b )x  + (- 425984a c - 1384448a b )x
+--R             + 
+--R                        8   3          9 2
+--R               - 655360a b x  - 131072a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                  4 6        3 2 5        2 4 4         6 3     8 2  13
+--R           (- 512a c  - 3584a b c  - 2240a b c  - 224a b c  - 2b c )x
+--R         + 
+--R                    4   5         3 3 4         2 5 3         7 2     9   12
+--R           (- 18944a b c  - 35840a b c  - 10304a b c  - 512a b c  - 2b c)x
+--R         + 
+--R                         5 5          4 2 4          3 4 3         2 6 2
+--R                 - 20992a c  - 160256a b c  - 115136a b c  - 15008a b c
+--R               + 
+--R                         8
+--R                 - 290a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                     5   4          4 3 3          3 5 2        2 7   10
+--R           (- 264192a b c  - 508416a b c  - 147840a b c  - 7008a b c)x
+--R         + 
+--R                     6 4           5 2 3          4 4 2         3 6   9
+--R           (- 143360a c  - 1039360a b c  - 672000a b c  - 65856a b c)x
+--R         + 
+--R                     6   3           5 3 2          4 5   8
+--R           (- 987136a b c  - 1599488a b c  - 312576a b c)x
+--R         + 
+--R                     7 3           6 2 2          5 4   7
+--R           (- 352256a c  - 2060288a b c  - 839168a b c)x
+--R         + 
+--R                      7   2           6 3   6             8 2           7 2   5
+--R           (- 1359872a b c  - 1331200a b c)x  + (- 360448a c  - 1236992a b c)x
+--R         + 
+--R                    8     4          9   3
+--R           - 622592a b c x  - 131072a c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                4 6        3 2 5        2 4 4         6 3     8 2  14
+--R           (512a c  + 3584a b c  + 2240a b c  + 224a b c  + 2b c )x
+--R         + 
+--R                  4   5         3 3 4         2 5 3         7 2     9   13
+--R           (19200a b c  + 37632a b c  + 11424a b c  + 624a b c  + 3b c)x
+--R         + 
+--R                     5 5          4 2 4          3 4 3         2 6 2         8
+--R               21504a c  + 174336a b c  + 137088a b c  + 20832a b c  + 564a b c
+--R             + 
+--R                10
+--R               b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                     5   4          4 3 3          3 5 2         2 7          9
+--R             (295680a b c  + 639232a b c  + 225568a b c  + 16144a b c + 163a b )
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        6 4           5 2 3           4 4 2          3 6
+--R                 164352a c  + 1365504a b c  + 1103040a b c  + 171360a b c
+--R               + 
+--R                      2 8
+--R                 4482a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                    6   3           5 3 2          4 5          3 7  9
+--R           (1345536a b c  + 2784768a b c  + 892800a b c + 48672a b )x
+--R         + 
+--R                   7 3           6 2 2           5 4           4 6  8
+--R           (495616a c  + 3767296a b c  + 2582272a b c + 272448a b )x
+--R         + 
+--R                    7   2           6 3           5 5  7
+--R           (2592768a b c  + 4356096a b c + 887040a b )x
+--R         + 
+--R                   8 2           7 2            6 4  6
+--R           (712704a c  + 4263936a b c + 1777152a b )x
+--R         + 
+--R                    8              7 3  5           9            8 2  4
+--R           (2244608a b c + 2224128a b )x  + (491520a c + 1695744a b )x
+--R         + 
+--R                  9   3          10 2
+--R           720896a b x  + 131072a  x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                 3   6        2 3 5         5 4      7 3  14
+--R           (2048a b c  + 3584a b c  + 896a b c  + 32b c )x
+--R         + 
+--R                 4 6         3 2 5         2 4 4          6 3      8 2  13
+--R           (4608a c  + 35328a b c  + 25536a b c  + 3360a b c  + 66b c )x
+--R         + 
+--R                  4   5          3 3 4         2 5 3          7 2      9   12
+--R           (90624a b c  + 188928a b c  + 63168a b c  + 4128a b c  + 34b c)x
+--R         + 
+--R                    5 5          4 2 4          3 4 3         2 6 2          8
+--R             (66048a c  + 542208a b c  + 431296a b c  + 65632a b c  + 1666a b c)
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                   5   4           4 3 3          3 5 2         2 7   10
+--R           (657408a b c  + 1365504a b c  + 441216a b c  + 24480a b c)x
+--R         + 
+--R                   6 4           5 2 3           4 4 2          3 6   9
+--R           (282624a c  + 2178048a b c  + 1524480a b c  + 166464a b c)x
+--R         + 
+--R                    6   3           5 3 2          4 5   8
+--R           (1699840a b c  + 2934784a b c  + 622336a b c)x
+--R         + 
+--R                   7 3           6 2 2           5 4   7
+--R           (516096a c  + 3182592a b c  + 1383936a b c)x
+--R         + 
+--R                    7   2           6 3   6           8 2           7 2   5
+--R           (1818624a b c  + 1880064a b c)x  + (425984a c  + 1531904a b c)x
+--R         + 
+--R                  8     4          9   3
+--R           688128a b c x  + 131072a c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                       3   4        2 3 3         5 2      7   9
+--R                 (2048a b c  + 3584a b c  + 896a b c  + 32b c)x
+--R               + 
+--R                       4 4         3 2 3         2 4 2          6       8  8
+--R                 (4608a c  + 32256a b c  + 20160a b c  + 2016a b c + 18b )x
+--R               + 
+--R                        4   3          3 3 2         2 5          7  7
+--R                 (81920a b c  + 138240a b c  + 32256a b c + 960a b )x
+--R               + 
+--R                        5 3          4 2 2          3 4          2 6  6
+--R                 (61440a c  + 394240a b c  + 211200a b c + 14784a b )x
+--R               + 
+--R                         5   2          4 3           3 5  5
+--R                 (491520a b c  + 675840a b c + 101376a b )x
+--R               + 
+--R                         6 2           5 2           4 4  4
+--R                 (221184a c  + 1118208a b c + 366080a b )x
+--R               + 
+--R                         6             5 3  3           7           6 2  2
+--R                 (917504a b c + 745472a b )x  + (294912a c + 860160a b )x
+--R               + 
+--R                        7             8
+--R                 524288a b x + 131072a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                  4 5        3 2 4        2 4 3         6 2     8   9
+--R             (512a c  + 3584a b c  + 2240a b c  + 224a b c  + 2b c)x
+--R           + 
+--R                    4   4         3 3 3        2 5 2         7   8
+--R             (18432a b c  + 32256a b c  + 8064a b c  + 288a b c)x
+--R           + 
+--R                    5 4          4 2 3         3 4 2        2 6   7
+--R             (20480a c  + 138240a b c  + 80640a b c  + 6720a b c)x
+--R           + 
+--R                     5   3          4 3 2         3 5   6
+--R             (225280a b c  + 337920a b c  + 59136a b c)x
+--R           + 
+--R                     6 3          5 2 2          4 4   5
+--R             (122880a c  + 675840a b c  + 253440a b c)x
+--R           + 
+--R                     6   2          5 3   4           7 2          6 2   3
+--R             (638976a b c  + 585728a b c)x  + (229376a c  + 745472a b c)x
+--R           + 
+--R                    7     2          8
+--R             491520a b c x  + 131072a c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    4 5        3 2 4        2 4 3         6 2     8   10
+--R             (- 512a c  - 3584a b c  - 2240a b c  - 224a b c  - 2b c)x
+--R           + 
+--R                      4   4         3 3 3        2 5 2         7     9  9
+--R             (- 18688a b c  - 34048a b c  - 9184a b c  - 400a b c - b )x
+--R           + 
+--R                           5 4          4 2 3          3 4 2         2 6
+--R                   - 20992a c  - 152064a b c  - 100800a b c  - 11424a b c
+--R                 + 
+--R                           8
+--R                   - 162a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                       5   3          4 3 2          3 5         2 7  7
+--R             (- 256000a b c  - 453120a b c  - 115584a b c - 4320a b )x
+--R           + 
+--R                       6 3          5 2 2          4 4          3 6  6
+--R             (- 143360a c  - 957440a b c  - 549120a b c - 44352a b )x
+--R           + 
+--R                       6   2           5 3           4 5  5
+--R             (- 946176a b c  - 1374208a b c - 228096a b )x
+--R           + 
+--R                       7 2           6 2           5 4  4
+--R             (- 352256a c  - 1863680a b c - 658944a b )x
+--R           + 
+--R                        7              6 3  3             8            7 2  2
+--R             (- 1294336a b c - 1118208a b )x  + (- 360448a c - 1105920a b )x
+--R           + 
+--R                      8             9
+--R             - 589824a b x - 131072a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                     3   5        2 3 4         5 3      7 2  10
+--R             (- 2048a b c  - 3584a b c  - 896a b c  - 32b c )x
+--R           + 
+--R                     4 5         3 2 4         2 4 3          6 2      8   9
+--R             (- 4608a c  - 33280a b c  - 21952a b c  - 2464a b c  - 34b c)x
+--R           + 
+--R                      4   4          3 3 3         2 5 2          7   8
+--R             (- 83968a b c  - 152064a b c  - 40320a b c  - 1632a b c)x
+--R           + 
+--R                      5 4          4 2 3          3 4 2         2 6   7
+--R             (- 61440a c  - 424960a b c  - 257280a b c  - 22848a b c)x
+--R           + 
+--R                       5   3          4 3 2          3 5   6
+--R             (- 512000a b c  - 788480a b c  - 143616a b c)x
+--R           + 
+--R                       6 3           5 2 2          4 4   5
+--R             (- 221184a c  - 1241088a b c  - 478720a b c)x
+--R           + 
+--R                       6   2          5 3   4             7 2          6 2   3
+--R             (- 966656a b c  - 905216a b c)x  + (- 294912a c  - 974848a b c)x
+--R           + 
+--R                      7     2          8
+--R             - 557056a b c x  - 131072a c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 195
+
+--S 196 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     2   2        3       5  2          2 2         4
+--R               (- 96a b c  - 48a b c + 18b )x  + (- 384a b c + 96a b )x
+--R             + 
+--R                     3         2 3
+--R               - 384a b c + 96a b
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + b x + a
+--R         + 
+--R                    2 2 2        4      6  3        3   2       2 3         5  2
+--R               (144a b c  - 24a b c - 3b )x  + (288a b c  + 144a b c - 54a b )x
+--R             + 
+--R                    3 2        2 4         4         3 3
+--R               (576a b c - 144a b )x + 384a b c - 96a b
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R          +------------------+
+--R          |   4      3      2              2c x + b
+--R         \|c x  + b x  + a x  atanh(----------------------)
+--R                                          +--------------+
+--R                                      +-+ |   2
+--R                                    2\|c \|c x  + b x + a
+--R     + 
+--R                      2 2 2        4      6  4
+--R               (- 288a b c  + 48a b c + 6b )x
+--R             + 
+--R                      3   2       2 3          5  3           3 2        2 4  2
+--R               (- 576a b c  - 288a b c + 108a b )x  + (- 1152a b c + 288a b )x
+--R             + 
+--R                      4          3 3
+--R               (- 768a b c + 192a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                    2   3        3 2      5   5        2 2 2        4       6  4
+--R               (192a b c  + 96a b c  - 36b c)x  + (960a b c  - 96a b c - 36b )x
+--R             + 
+--R                    3   2       2 3          5  3         3 2        2 4  2
+--R               (960a b c  + 672a b c - 228a b )x  + (1536a b c - 384a b )x
+--R             + 
+--R                    4          3 3
+--R               (768a b c - 192a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                     +--------------+
+--R               +---+ |   2               +---+ +-+
+--R              \|- c \|c x  + b x + a  - \|- c \|a
+--R         atan(------------------------------------)
+--R                               c x
+--R     + 
+--R                          3      3 2  5          2 3         2 2     4   4
+--R               (- 192a b c  - 16b c )x  + (- 384a c  - 336a b c  - 4b c)x
+--R             + 
+--R                       2   2        3      5  3
+--R               (- 1056a b c  - 16a b c + 6b )x
+--R             + 
+--R                      3 2       2 2          4  2          3          2 3
+--R               (- 896a c  - 336a b c + 108a b )x  + (- 896a b c + 288a b )x
+--R             + 
+--R                     4        3 2
+--R               - 512a c + 192a b
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                      4      2 3  6            3       3 2  5
+--R               (128a c  + 96b c )x  + (672a b c  + 120b c )x
+--R             + 
+--R                    2 3         2 2      4   4         2   2       3       5  3
+--R               (768a c  + 816a b c  - 12b c)x  + (1824a b c  + 8a b c - 36b )x
+--R             + 
+--R                     3 2       2 2          4  2         3          2 3
+--R               (1152a c  + 624a b c - 228a b )x  + (1152a b c - 384a b )x
+--R             + 
+--R                   4        3 2
+--R               512a c - 192a b
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                    4      2 3  7              3       3 2  6
+--R           (- 128a c  - 96b c )x  + (- 672a b c  - 120b c )x
+--R         + 
+--R                  2 3         2 2      4   5           2   2        3       5  4
+--R           (- 768a c  - 816a b c  + 12b c)x  + (- 1632a b c  - 64a b c + 30b )x
+--R         + 
+--R                  3 2       2 2          4  3          3         2 3  2
+--R           (- 768a c  - 480a b c + 120a b )x  + (- 384a b c + 96a b )x
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                    4      3 3  8        2 4         2 3      4 2  7
+--R           (192a b c  + 16b c )x  + (384a c  + 528a b c  + 20b c )x
+--R         + 
+--R                 2   3         3 2     5   6
+--R           (1632a b c  + 368a b c  - 2b c)x
+--R         + 
+--R                 3 3        2 2 2        4      6  5
+--R           (1152a c  + 1680a b c  - 52a b c - 6b )x
+--R         + 
+--R                 3   2       2 3         5  4        4 2       3 2        2 4  3
+--R           (2208a b c  + 208a b c - 78a b )x  + (768a c  + 672a b c - 168a b )x
+--R         + 
+--R                4         3 3  2
+--R           (384a b c - 96a b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                    3      3 2  4         2 3         2 2  3        2   2 2
+--R           (576a b c  + 48b c )x  + (1152a c  + 864a b c )x  + 2304a b c x
+--R         + 
+--R                3 2
+--R           1536a c x
+--R      *
+--R                    +--------------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b x + a
+--R     + 
+--R                    4       2 3  5               3       3 2  4
+--R           (- 384a c  - 288b c )x  + (- 1920a b c  - 288b c )x
+--R         + 
+--R                   2 3          2 2  3        2   2 2        3 2
+--R           (- 1920a c  - 1824a b c )x  - 3072a b c x  - 1536a c x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      2   3         3 2      5   8
+--R               (- 192a b c  - 160a b c  - 12b c)x
+--R             + 
+--R                      3 3        2 2 2         4       6  7
+--R               (- 384a c  - 1536a b c  - 440a b c - 12b )x
+--R             + 
+--R                       3   2        2 3          5  6
+--R               (- 3648a b c  - 3296a b c - 292a b )x
+--R             + 
+--R                       4 2        3 2         2 4  5
+--R               (- 2432a c  - 9024a b c - 2072a b )x
+--R             + 
+--R                        4           3 3  4           5         4 2  3
+--R               (- 10240a b c - 6400a b )x  + (- 4096a c - 9728a b )x
+--R             + 
+--R                      5   2        6
+--R               - 7168a b x  - 2048a x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               3 4       2 2 3        4 2    6   9
+--R           (64a c  + 240a b c  + 60a b c  + b c)x
+--R         + 
+--R                 3   3        2 3 2         5     7  8
+--R           (1216a b c  + 1200a b c  + 132a b c + b )x
+--R         + 
+--R                 4 3        3 2 2        2 4         6  7
+--R           (1216a c  + 5424a b c  + 1860a b c + 73a b )x
+--R         + 
+--R                 4   2        3 3        2 5  6
+--R           (8448a b c  + 8576a b c + 912a b )x
+--R         + 
+--R                 5 2         4 2         3 4  5          5            4 3  4
+--R           (4224a c  + 17088a b c + 4424a b )x  + (15360a b c + 10496a b )x
+--R         + 
+--R                 6          5 2  3        6   2        7
+--R           (5120a c + 13056a b )x  + 8192a b x  + 2048a x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 3 4       2 2 3        4 2    6   10
+--R           (- 64a c  - 240a b c  - 60a b c  - b c)x
+--R         + 
+--R                   3   3        2 3 2         5     7  9
+--R           (- 1216a b c  - 1200a b c  - 132a b c - b )x
+--R         + 
+--R                   4 3        3 2 2        2 4         6  8
+--R           (- 1216a c  - 5424a b c  - 1860a b c - 73a b )x
+--R         + 
+--R                   4   2        3 3        2 5  7
+--R           (- 8448a b c  - 8576a b c - 912a b )x
+--R         + 
+--R                   5 2         4 2         3 4  6            5            4 3  5
+--R           (- 4224a c  - 17088a b c - 4424a b )x  + (- 15360a b c - 10496a b )x
+--R         + 
+--R                   6          5 2  4        6   3        7 2
+--R           (- 5120a c - 13056a b )x  - 8192a b x  - 2048a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                2   4         3 3      5 2  11
+--R           (192a b c  + 160a b c  + 12b c )x
+--R         + 
+--R                3 4        2 2 3         4 2      6   10
+--R           (384a c  + 1728a b c  + 600a b c  + 24b c)x
+--R         + 
+--R                 3   3        2 3 2         5       7  9
+--R           (4224a b c  + 4992a b c  + 744a b c + 12b )x
+--R         + 
+--R                 4 3         3 2 2        2 4          6  8
+--R           (2816a c  + 14208a b c  + 5808a b c + 304a b )x
+--R         + 
+--R                  4   2         3 3         2 5  7
+--R           (16320a b c  + 18720a b c + 2364a b )x
+--R         + 
+--R                 5 2         4 2         3 4  6          5            4 3  5
+--R           (6528a c  + 28992a b c + 8472a b )x  + (21504a b c + 16128a b )x
+--R         + 
+--R                 6          5 2  4        6   3        7 2
+--R           (6144a c + 16896a b )x  + 9216a b x  + 2048a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 3 3       2 2 2        4     6  6
+--R             (64a c  + 240a b c  + 60a b c + b )x
+--R           + 
+--R                   3   2       2 3         5  5
+--R             (1152a b c  + 960a b c + 72a b )x
+--R           + 
+--R                   4 2        3 2        2 4  4         4           3 3  3
+--R             (1152a c  + 4032a b c + 840a b )x  + (6144a b c + 3584a b )x
+--R           + 
+--R                   5         4 2  2        5           6
+--R             (3072a c + 6912a b )x  + 6144a b x + 2048a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2   3         3 2      5   7
+--R             (- 192a b c  - 160a b c  - 12b c)x
+--R           + 
+--R                    3 3        2 2 2         4       6  6
+--R             (- 384a c  - 1536a b c  - 440a b c - 12b )x
+--R           + 
+--R                     3   2        2 3          5  5
+--R             (- 3648a b c  - 3296a b c - 292a b )x
+--R           + 
+--R                     4 2        3 2         2 4  4            4           3 3  3
+--R             (- 2432a c  - 9024a b c - 2072a b )x  + (- 10240a b c - 6400a b )x
+--R           + 
+--R                     5         4 2  2        5           6
+--R             (- 4096a c - 9728a b )x  - 7168a b x - 2048a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 197
+
+)clear all
+
+--S 198 of 704
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x
+--R 
+--R
+--R         +------------------+
+--R         |   4      3      2
+--R        \|c x  + b x  + a x
+--R   (1)  ---------------------
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 198
+
+--S 199 of 704
+r0:=-1/8*(b^2-4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(c^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))+1/4*(b+2*c*x)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(c*x)
+--R 
+--R
+--R   (2)
+--R                    +--------------+
+--R                2   |   2                        2c x + b
+--R       (4a c - b )x\|c x  + b x + a atanh(----------------------)
+--R                                                +--------------+
+--R                                            +-+ |   2
+--R                                          2\|c \|c x  + b x + a
+--R     + 
+--R          2 4         3             2  2           +-+
+--R       (4c x  + 6b c x  + (4a c + 2b )x  + 2a b x)\|c
+--R  /
+--R            +------------------+
+--R        +-+ |   4      3      2
+--R     8c\|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                    +--------------+
+--R                           3        2        2  +-+ |   2
+--R             ((16a b c - 4b )x + 32a c - 8a b )\|a \|c x  + b x + a
+--R           + 
+--R                   2 2    4  2         2          3        3      2 2
+--R             (- 16a c  + b )x  + (- 32a b c + 8a b )x - 32a c + 8a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                    2     2   3                  3  2         2        2    +-+
+--R           ((- 16a c  - 4b c)x  + (- 40a b c - 2b )x  + (- 32a c - 8a b )x)\|c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2 4         2      2   3                3  2
+--R               16b c x  + (32a c  + 24b c)x  + (56a b c + 6b )x
+--R             + 
+--R                   2        2
+--R               (32a c + 8a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                                   +--------------+
+--R                           +-+ +-+ |   2
+--R         (32b c x + 64a c)\|a \|c \|c x  + b x + a
+--R       + 
+--R                  2     2   2                  2   +-+
+--R         ((- 32a c  - 8b c)x  - 64a b c x - 64a c)\|c
+--R     ,
+--R
+--R                                                    +--------------+
+--R                           3        2        2  +-+ |   2
+--R             ((16a b c - 4b )x + 32a c - 8a b )\|a \|c x  + b x + a
+--R           + 
+--R                   2 2    4  2         2          3        3      2 2
+--R             (- 16a c  + b )x  + (- 32a b c + 8a b )x - 32a c + 8a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                   2     2   3                 3  2         2        2    +---+
+--R           ((- 8a c  - 2b c)x  + (- 20a b c - b )x  + (- 16a c - 4a b )x)\|- c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                2 4         2      2   3                3  2       2        2
+--R           (8b c x  + (16a c  + 12b c)x  + (28a b c + 3b )x  + (16a c + 4a b )x)
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                     +--------------+
+--R                           +---+ +-+ |   2
+--R         (16b c x + 32a c)\|- c \|a \|c x  + b x + a
+--R       + 
+--R                  2     2   2                  2   +---+
+--R         ((- 16a c  - 4b c)x  - 32a b c x - 32a c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 200
+
+--S 201 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                  +--------------+
+--R                         3        2        2  +-+ |   2
+--R           ((16a b c - 4b )x + 32a c - 8a b )\|a \|c x  + b x + a
+--R         + 
+--R                 2 2    4  2         2          3        3      2 2
+--R           (- 16a c  + b )x  + (- 32a b c + 8a b )x - 32a c + 8a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                  2 2    4  3       2          3  2       3      2 2
+--R             ((16a c  - b )x  + (32a b c - 8a b )x  + (32a c - 8a b )x)
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                         2     3   4         2 2       2      4  3
+--R               (- 16a b c  + 4b c)x  + (- 32a c  - 8a b c + 4b )x
+--R             + 
+--R                     2           3  2         3      2 2
+--R               (- 48a b c + 12a b )x  + (- 32a c + 8a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                      2     2   3                  3  2         2        2
+--R             ((- 16a c  - 4b c)x  + (- 40a b c - 2b )x  + (- 32a c - 8a b )x)
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                    2 4         2      2   3                3  2
+--R               16b c x  + (32a c  + 24b c)x  + (56a b c + 6b )x
+--R             + 
+--R                   2        2
+--R               (32a c + 8a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  2 5           2      2   4                  3  3
+--R           - 16b c x  + (- 32a c  - 24b c)x  + (- 64a b c - 8b )x
+--R         + 
+--R                 2         2  2      2
+--R           (- 32a c - 24a b )x  - 16a b x
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                 3     2 2  6           2     3   5       2 2        2      4  4
+--R           (16a c  + 4b c )x  + (56a b c  + 6b c)x  + (48a c  + 60a b c + 2b )x
+--R         + 
+--R               2           3  3       3       2 2  2      3
+--R           (88a b c + 18a b )x  + (32a c + 32a b )x  + 16a b x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                   +--------------+
+--R                           +-+ +-+ |   2
+--R         (32b c x + 64a c)\|a \|c \|c x  + b x + a
+--R       + 
+--R                  2     2   2                  2   +-+
+--R         ((- 32a c  - 8b c)x  - 64a b c x - 64a c)\|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          3 4       2 2 3         4 2     6   8
+--R                   (- 128a c  - 480a b c  - 120a b c  - 2b c)x
+--R                 + 
+--R                           3   3        2 3 2         5     7  7
+--R                   (- 2752a b c  - 2480a b c  - 228a b c - b )x
+--R                 + 
+--R                           4 3         3 2 2        2 4         6  6
+--R                   (- 3200a c  - 12768a b c  - 3640a b c - 98a b )x
+--R                 + 
+--R                            4   2         3 3         2 5  5
+--R                   (- 23040a b c  - 19712a b c - 1568a b )x
+--R                 + 
+--R                            5 2         4 2         3 4  4
+--R                   (- 13312a c  - 46080a b c - 9408a b )x
+--R                 + 
+--R                            5            4 3  3            6          5 2  2
+--R                   (- 48128a b c - 26880a b )x  + (- 18432a c - 39424a b )x
+--R                 + 
+--R                           6           7
+--R                   - 28672a b x - 8192a
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                        2   4         3 3      5 2  8
+--R                   (384a b c  + 320a b c  + 24b c )x
+--R                 + 
+--R                        3 4        2 2 3          4 2      6   7
+--R                   (896a c  + 3552a b c  + 1000a b c  + 26b c)x
+--R                 + 
+--R                         3   3        2 3 2         5   6
+--R                   (9600a b c  + 8512a b c  + 728a b c)x
+--R                 + 
+--R                         4 3         3 2 2        2 4   5
+--R                   (7168a c  + 26112a b c  + 5824a b c)x
+--R                 + 
+--R                          4   2         3 3   4          5 2         4 2   3
+--R                   (32768a b c  + 19968a b c)x  + (14336a c  + 33280a b c)x
+--R                 + 
+--R                         5     2        6
+--R                   26624a b c x  + 8192a c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2   4         3 3      5 2  9
+--R               (384a b c  + 320a b c  + 24b c )x
+--R             + 
+--R                    3 4        2 2 3          4 2      6   8
+--R               (896a c  + 3744a b c  + 1160a b c  + 38b c)x
+--R             + 
+--R                      3   3         2 3 2          5       7  7
+--R               (10496a b c  + 10848a b c  + 1312a b c + 14b )x
+--R             + 
+--R                     4 3         3 2 2         2 4          6  6
+--R               (8064a c  + 35616a b c  + 12040a b c + 462a b )x
+--R             + 
+--R                      4   2         3 3         2 5  5
+--R               (47104a b c  + 45568a b c + 4480a b )x
+--R             + 
+--R                      5 2         4 2          3 4  4
+--R               (21504a c  + 81920a b c + 19392a b )x
+--R             + 
+--R                      5            4 3  3          6          5 2  2
+--R               (69632a b c + 43520a b )x  + (22528a c + 52736a b )x
+--R             + 
+--R                     6           7
+--R               32768a b x + 8192a
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                  3 5       2 2 4         4 3     6 2  9
+--R           (- 128a c  - 480a b c  - 120a b c  - 2b c )x
+--R         + 
+--R                   3   4        2 3 3         5 2     7   8
+--R           (- 2816a b c  - 2720a b c  - 288a b c  - 2b c)x
+--R         + 
+--R                   4 4         3 2 3        2 4 2         6   7
+--R           (- 3200a c  - 13920a b c  - 4600a b c  - 170a b c)x
+--R         + 
+--R                    4   3         3 3 2        2 5   6
+--R           (- 24192a b c  - 23744a b c  - 2408a b c)x
+--R         + 
+--R                    5 3         4 2 2         3 4   5
+--R           (- 13312a c  - 52224a b c  - 12992a b c)x
+--R         + 
+--R                    5   2         4 3   4            6 2         5 2   3
+--R           (- 51200a b c  - 33792a b c)x  + (- 18432a c  - 45568a b c)x
+--R         + 
+--R                   6     2        7
+--R           - 30720a b c x  - 8192a c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      2   4         3 3      5 2  10
+--R               (- 384a b c  - 320a b c  - 24b c )x
+--R             + 
+--R                      3 4        2 2 3          4 2      6   9
+--R               (- 896a c  - 3744a b c  - 1160a b c  - 38b c)x
+--R             + 
+--R                        3   3         2 3 2          5       7  8
+--R               (- 10496a b c  - 10848a b c  - 1312a b c - 14b )x
+--R             + 
+--R                       4 3         3 2 2         2 4          6  7
+--R               (- 8064a c  - 35616a b c  - 12040a b c - 462a b )x
+--R             + 
+--R                        4   2         3 3         2 5  6
+--R               (- 47104a b c  - 45568a b c - 4480a b )x
+--R             + 
+--R                        5 2         4 2          3 4  5
+--R               (- 21504a c  - 81920a b c - 19392a b )x
+--R             + 
+--R                        5            4 3  4            6          5 2  3
+--R               (- 69632a b c - 43520a b )x  + (- 22528a c - 52736a b )x
+--R             + 
+--R                       6   2        7
+--R               - 32768a b x  - 8192a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                3 5       2 2 4         4 3     6 2  10
+--R           (128a c  + 480a b c  + 120a b c  + 2b c )x
+--R         + 
+--R                 3   4        2 3 3         5 2     7   9
+--R           (2816a b c  + 2720a b c  + 288a b c  + 2b c)x
+--R         + 
+--R                 4 4         3 2 3        2 4 2         6   8
+--R           (3200a c  + 13920a b c  + 4600a b c  + 170a b c)x
+--R         + 
+--R                  4   3         3 3 2        2 5   7
+--R           (24192a b c  + 23744a b c  + 2408a b c)x
+--R         + 
+--R                  5 3         4 2 2         3 4   6
+--R           (13312a c  + 52224a b c  + 12992a b c)x
+--R         + 
+--R                  5   2         4 3   5          6 2         5 2   4
+--R           (51200a b c  + 33792a b c)x  + (18432a c  + 45568a b c)x
+--R         + 
+--R                 6     3        7   2
+--R           30720a b c x  + 8192a c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                3 5       2 2 4         4 3     6 2  11
+--R           (128a c  + 480a b c  + 120a b c  + 2b c )x
+--R         + 
+--R                 3   4        2 3 3         5 2     7   10
+--R           (2880a b c  + 2960a b c  + 348a b c  + 3b c)x
+--R         + 
+--R                 4 4         3 2 3        2 4 2         6     8  9
+--R           (3328a c  + 16000a b c  + 6240a b c  + 328a b c + b )x
+--R         + 
+--R                  4   3         3 3 2        2 5         7  8
+--R           (28992a b c  + 34960a b c  + 5436a b c + 99a b )x
+--R         + 
+--R                  5 3         4 2 2         3 4         2 6  7
+--R           (16512a c  + 81888a b c  + 32760a b c + 1666a b )x
+--R         + 
+--R                  5   2         4 3          3 5  6
+--R           (84480a b c  + 92672a b c + 10976a b )x
+--R         + 
+--R                  6 2          5 2          4 4  5          6            5 3  4
+--R           (31744a c  + 133632a b c + 36288a b )x  + (95232a b c + 66304a b )x
+--R         + 
+--R                  7          6 2  3         7   2        8
+--R           (26624a c + 68096a b )x  + 36864a b x  + 8192a x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                  2   5         3 4      5 3  11
+--R           (- 384a b c  - 320a b c  - 24b c )x
+--R         + 
+--R                  3 5        2 2 4          4 3      6 2  10
+--R           (- 896a c  - 3936a b c  - 1320a b c  - 50b c )x
+--R         + 
+--R                    3   4         2 3 3          5 2      7   9
+--R           (- 10880a b c  - 12384a b c  - 1752a b c  - 26b c)x
+--R         + 
+--R                   4 4         3 2 3         2 4 2         6   8
+--R           (- 8064a c  - 39264a b c  - 15336a b c  - 754a b c)x
+--R         + 
+--R                    4   3         3 3 2        2 5   7
+--R           (- 49536a b c  - 54592a b c  - 6552a b c)x
+--R         + 
+--R                    5 3         4 2 2         3 4   6
+--R           (- 21504a c  - 92160a b c  - 25792a b c)x
+--R         + 
+--R                    5   2         4 3   5            6 2         5 2   4
+--R           (- 73728a b c  - 53248a b c)x  + (- 22528a c  - 59904a b c)x
+--R         + 
+--R                   6     3        7   2
+--R           - 34816a b c x  - 8192a c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                      2   3         3 2      5   7
+--R                 (384a b c  + 320a b c  + 24b c)x
+--R               + 
+--R                      3 3        2 2 2         4       6  6
+--R                 (896a c  + 3360a b c  + 840a b c + 14b )x
+--R               + 
+--R                       3   2        2 3          5  5
+--R                 (9216a b c  + 7168a b c + 448a b )x
+--R               + 
+--R                       4 2         3 2         2 4  4
+--R                 (7168a c  + 23040a b c + 4032a b )x
+--R               + 
+--R                        4            3 3  3          5          4 2  2
+--R                 (30720a b c + 15360a b )x  + (14336a c + 28160a b )x
+--R               + 
+--R                       5           6
+--R                 24576a b x + 8192a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                    3 4       2 2 3         4 2     6   7
+--R             (- 128a c  - 480a b c  - 120a b c  - 2b c)x
+--R           + 
+--R                     3   3        2 3 2         5   6
+--R             (- 2688a b c  - 2240a b c  - 168a b c)x
+--R           + 
+--R                     4 3         3 2 2        2 4   5
+--R             (- 3072a c  - 10752a b c  - 2240a b c)x
+--R           + 
+--R                      4   2         3 3   4            5 2         4 2   3
+--R             (- 18432a b c  - 10752a b c)x  + (- 10240a c  - 23040a b c)x
+--R           + 
+--R                     5     2        6
+--R             - 22528a b c x  - 8192a c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    3 4       2 2 3         4 2     6   8
+--R             (- 128a c  - 480a b c  - 120a b c  - 2b c)x
+--R           + 
+--R                     3   3        2 3 2         5     7  7
+--R             (- 2752a b c  - 2480a b c  - 228a b c - b )x
+--R           + 
+--R                     4 3         3 2 2        2 4         6  6
+--R             (- 3200a c  - 12768a b c  - 3640a b c - 98a b )x
+--R           + 
+--R                      4   2         3 3         2 5  5
+--R             (- 23040a b c  - 19712a b c - 1568a b )x
+--R           + 
+--R                      5 2         4 2         3 4  4
+--R             (- 13312a c  - 46080a b c - 9408a b )x
+--R           + 
+--R                      5            4 3  3            6          5 2  2
+--R             (- 48128a b c - 26880a b )x  + (- 18432a c - 39424a b )x
+--R           + 
+--R                     6           7
+--R             - 28672a b x - 8192a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                  2   4         3 3      5 2  8
+--R             (384a b c  + 320a b c  + 24b c )x
+--R           + 
+--R                  3 4        2 2 3          4 2      6   7
+--R             (896a c  + 3552a b c  + 1000a b c  + 26b c)x
+--R           + 
+--R                   3   3        2 3 2         5   6
+--R             (9600a b c  + 8512a b c  + 728a b c)x
+--R           + 
+--R                   4 3         3 2 2        2 4   5
+--R             (7168a c  + 26112a b c  + 5824a b c)x
+--R           + 
+--R                    4   2         3 3   4          5 2         4 2   3
+--R             (32768a b c  + 19968a b c)x  + (14336a c  + 33280a b c)x
+--R           + 
+--R                   5     2        6
+--R             26624a b c x  + 8192a c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                  2 2    4  3       2          3  2       3      2 2    +---+
+--R             ((16a c  - b )x  + (32a b c - 8a b )x  + (32a c - 8a b )x)\|- c
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                         2     3   4         2 2       2      4  3
+--R               (- 16a b c  + 4b c)x  + (- 32a c  - 8a b c + 4b )x
+--R             + 
+--R                     2           3  2         3      2 2
+--R               (- 48a b c + 12a b )x  + (- 32a c + 8a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                                                       +--------------+
+--R                         3        2         2  +-+ +-+ |   2
+--R           ((32a b c - 8b )x + 64a c - 16a b )\|a \|c \|c x  + b x + a
+--R         + 
+--R                  2 2     4  2         2           3        3       2 2  +-+
+--R           ((- 32a c  + 2b )x  + (- 64a b c + 16a b )x - 64a c + 16a b )\|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                      2     2   3                  3  2         2        2
+--R             ((- 16a c  - 4b c)x  + (- 40a b c - 2b )x  + (- 32a c - 8a b )x)
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                    2 4         2      2   3                3  2
+--R               16b c x  + (32a c  + 24b c)x  + (56a b c + 6b )x
+--R             + 
+--R                   2        2
+--R               (32a c + 8a b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  2 5           2      2   4                  3  3
+--R           - 16b c x  + (- 32a c  - 24b c)x  + (- 64a b c - 8b )x
+--R         + 
+--R                 2         2  2      2
+--R           (- 32a c - 24a b )x  - 16a b x
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                 3     2 2  6           2     3   5       2 2        2      4  4
+--R           (16a c  + 4b c )x  + (56a b c  + 6b c)x  + (48a c  + 60a b c + 2b )x
+--R         + 
+--R               2           3  3       3       2 2  2      3
+--R           (88a b c + 18a b )x  + (32a c + 32a b )x  + 16a b x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                                         +--------------+
+--R                           +---+ +-+ +-+ |   2
+--R         (32b c x + 64a c)\|- c \|a \|c \|c x  + b x + a
+--R       + 
+--R                  2     2   2                  2   +---+ +-+
+--R         ((- 32a c  - 8b c)x  - 64a b c x - 64a c)\|- c \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                         2     3   5         2 2         2      4  4
+--R               (- 32a b c  - 8b c)x  + (- 64a c  - 112a b c - 8b )x
+--R             + 
+--R                    2           3  3          3        2 2  2       3          4
+--R             (- 288a b c - 88a b )x  + (- 192a c - 272a b )x  - 320a b x - 128a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               2 3        2 2    4   6        2   2        3     5  5
+--R           (16a c  + 24a b c  + b c)x  + (144a b c  + 56a b c + b )x
+--R         + 
+--R                3 2       2 2         4  4        3          2 3  3
+--R           (144a c  + 312a b c + 33a b )x  + (512a b c + 192a b )x
+--R         + 
+--R                4        3 2  2       4          5
+--R           (256a c + 416a b )x  + 384a b x + 128a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 2 3        2 2    4   7          2   2        3     5  6
+--R           (- 16a c  - 24a b c  - b c)x  + (- 144a b c  - 56a b c - b )x
+--R         + 
+--R                  3 2       2 2         4  5          3          2 3  4
+--R           (- 144a c  - 312a b c - 33a b )x  + (- 512a b c - 192a b )x
+--R         + 
+--R                  4        3 2  3       4   2       5
+--R           (- 256a c - 416a b )x  - 384a b x  - 128a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   3     3 2  8       2 3         2 2      4   7
+--R           (32a b c  + 8b c )x  + (64a c  + 144a b c  + 16b c)x
+--R         + 
+--R                2   2         3      5  6        3 2       2 2         4  5
+--R           (384a b c  + 208a b c + 8b )x  + (256a c  + 672a b c + 96a b )x
+--R         + 
+--R                3          2 3  4        4        3 2  3       4   2       5
+--R           (800a b c + 360a b )x  + (320a c + 592a b )x  + 448a b x  + 128a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 2 2        2     4  4        2           3  3
+--R             (16a c  + 24a b c + b )x  + (128a b c + 32a b )x
+--R           + 
+--R                  3        2 2  2       3          4
+--R             (128a c + 160a b )x  + 256a b x + 128a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                       2     3   5         2 2         2      4  4
+--R             (- 32a b c  - 8b c)x  + (- 64a c  - 112a b c - 8b )x
+--R           + 
+--R                  2           3  3          3        2 2  2       3          4
+--R           (- 288a b c - 88a b )x  + (- 192a c - 272a b )x  - 320a b x - 128a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 704
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x^2
+--R 
+--R
+--R         +------------------+
+--R         |   4      3      2
+--R        \|c x  + b x  + a x
+--R   (1)  ---------------------
+--R                   2
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 704
+r0:=-x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a)*_
+   sqrt(a+b*x+c*x^2)/sqrt(a*x^2+b*x^3+c*x^4)+1/2*b*x*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(sqrt(c)*sqrt(a*x^2+_
+   b*x^3+c*x^4))+sqrt(a*x^2+b*x^3+c*x^4)/x
+--R 
+--R
+--R   (2)
+--R                    +--------------+
+--R            +-+ +-+ |   2                        b x + 2a
+--R       - 2x\|a \|c \|c x  + b x + a atanh(----------------------)
+--R                                                +--------------+
+--R                                            +-+ |   2
+--R                                          2\|a \|c x  + b x + a
+--R     + 
+--R           +--------------+
+--R           |   2                        2c x + b
+--R       b x\|c x  + b x + a atanh(----------------------)
+--R                                       +--------------+
+--R                                   +-+ |   2
+--R                                 2\|c \|c x  + b x + a
+--R     + 
+--R            3       2         +-+
+--R       (2c x  + 2b x  + 2a x)\|c
+--R  /
+--R           +------------------+
+--R       +-+ |   4      3      2
+--R     2\|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   +--------------+
+--R               +-+ |   2                            +-+ +-+
+--R           (4a\|c \|c x  + b x + a  + (- 2b x - 4a)\|a \|c )
+--R        *
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a  - b x - 2a
+--R           log(---------------------------------)
+--R                                +-+
+--R                             2x\|a
+--R       + 
+--R                   +--------------+
+--R               +-+ |   2               2
+--R           (2b\|a \|c x  + b x + a  - b x - 2a b)
+--R        *
+--R           log
+--R                            2              2  +-+            2           +-+
+--R                    ((4a c x  + 4a b x + 8a )\|c  + (- 2b c x  - 8a c x)\|a )
+--R                 *
+--R                     +--------------+
+--R                     |   2
+--R                    \|c x  + b x + a
+--R                + 
+--R                           3              2  2              2  +-+ +-+       2 3
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x - 8a )\|a \|c  + 4a c x
+--R                + 
+--R                          2     2
+--R                  6a b c x  + 8a c x
+--R             /
+--R                                 +--------------+
+--R                              2  |   2
+--R                  (4a b x + 8a )\|c x  + b x + a
+--R                + 
+--R                              2  2              2  +-+
+--R                  ((- 4a c - b )x  - 8a b x - 8a )\|a
+--R       + 
+--R                    +--------------+
+--R                +-+ |   2                   2         +-+ +-+
+--R         - 2b x\|c \|c x  + b x + a  + (4c x  + 2b x)\|a \|c
+--R    /
+--R                 +--------------+
+--R         +-+ +-+ |   2                            +-+
+--R       4\|a \|c \|c x  + b x + a  + (- 2b x - 4a)\|c
+--R     ,
+--R
+--R                     +--------------+
+--R               +---+ |   2                           +---+ +-+
+--R           (2a\|- c \|c x  + b x + a  + (- b x - 2a)\|- c \|a )
+--R        *
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a  - b x - 2a
+--R           log(---------------------------------)
+--R                                +-+
+--R                             2x\|a
+--R       + 
+--R                   +--------------+
+--R               +-+ |   2               2
+--R           (2b\|a \|c x  + b x + a  - b x - 2a b)
+--R        *
+--R                           +--------------+
+--R                 +---+ +-+ |   2                +---+
+--R                \|- c \|a \|c x  + b x + a  - a\|- c
+--R           atan(-------------------------------------)
+--R                                   +-+
+--R                               c x\|a
+--R       + 
+--R                     +--------------+
+--R               +---+ |   2                   2        +---+ +-+
+--R         - b x\|- c \|c x  + b x + a  + (2c x  + b x)\|- c \|a
+--R    /
+--R                   +--------------+
+--R         +---+ +-+ |   2                           +---+
+--R       2\|- c \|a \|c x  + b x + a  + (- b x - 2a)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 207
+
+--S 208 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 +--------------+                          +------------------+
+--R             +-+ |   2                            +-+ +-+  |   4      3      2
+--R         (4a\|c \|c x  + b x + a  + (- 2b x - 4a)\|a \|c )\|c x  + b x  + a x
+--R      *
+--R                   +--------------+
+--R               +-+ |   2
+--R             2\|a \|c x  + b x + a  - b x - 2a
+--R         log(---------------------------------)
+--R                              +-+
+--R                           2x\|a
+--R     + 
+--R                 +--------------+               +------------------+
+--R             +-+ |   2               2          |   4      3      2
+--R         (2b\|a \|c x  + b x + a  - b x - 2a b)\|c x  + b x  + a x
+--R      *
+--R         log
+--R                          2              2  +-+            2           +-+
+--R                  ((4a c x  + 4a b x + 8a )\|c  + (- 2b c x  - 8a c x)\|a )
+--R               *
+--R                   +--------------+
+--R                   |   2
+--R                  \|c x  + b x + a
+--R              + 
+--R                         3              2  2              2  +-+ +-+       2 3
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x - 8a )\|a \|c  + 4a c x
+--R              + 
+--R                        2     2
+--R                6a b c x  + 8a c x
+--R           /
+--R                               +--------------+
+--R                            2  |   2
+--R                (4a b x + 8a )\|c x  + b x + a
+--R              + 
+--R                            2  2              2  +-+
+--R                ((- 4a c - b )x  - 8a b x - 8a )\|a
+--R     + 
+--R                                    +--------------+
+--R                  2         +-+ +-+ |   2
+--R           (- 2b x  - 4a x)\|a \|c \|c x  + b x + a
+--R         + 
+--R                  3         2     2   +-+
+--R           (4a c x  + 4a b x  + 4a x)\|c
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                          +--------------+
+--R            2 2           |   2                       3     2 2           +-+
+--R         ((b x  + 2a b x)\|c x  + b x + a  + (- 2b c x  - 2b x  - 2a b x)\|a )
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                     +--------------+
+--R                 +-+ |   2                   2         +-+ +-+
+--R         (- 2b x\|c \|c x  + b x + a  + (4c x  + 2b x)\|a \|c )
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                        +--------------+
+--R              3       2         +-+ +-+ |   2
+--R       (- 4c x  - 4b x  - 4a x)\|a \|c \|c x  + b x + a
+--R     + 
+--R              4             2  3         2     2   +-+
+--R       (2b c x  + (4a c + 2b )x  + 6a b x  + 4a x)\|c
+--R  /
+--R                +--------------+                      +------------------+
+--R        +-+ +-+ |   2                            +-+  |   4      3      2
+--R     (4\|a \|c \|c x  + b x + a  + (- 2b x - 4a)\|c )\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          3   4        2 3 3         5 2     7   9
+--R                   (- 896a b c  - 1120a b c  - 168a b c  - 2b c)x
+--R                 + 
+--R                           4 4         3 2 3        2 4 2         6     8  8
+--R                   (- 2048a c  - 11200a b c  - 5040a b c  - 308a b c - b )x
+--R                 + 
+--R                            4   3         3 3 2        2 5          7  7
+--R                   (- 29696a b c  - 39424a b c  - 6720a b c - 128a b )x
+--R                 + 
+--R                            5 3          4 2 2         3 4         2 6  6
+--R                   (- 22528a c  - 119808a b c  - 51072a b c - 2688a b )x
+--R                 + 
+--R                             5   2          4 3          3 5  5
+--R                   (- 153600a b c  - 176640a b c - 21504a b )x
+--R                 + 
+--R                            6 2          5 2          4 4  4
+--R                   (- 69632a c  - 304128a b c - 84480a b )x
+--R                 + 
+--R                             6             5 3  3            7           6 2  2
+--R                   (- 253952a b c - 180224a b )x  + (- 81920a c - 212992a b )x
+--R                 + 
+--R                            7            8
+--R                   - 131072a b x - 32768a
+--R              *
+--R                  +-+ +-+
+--R                 \|a \|c
+--R             + 
+--R                    4 5        3 2 4       2 4 3        6 2  9
+--R               (256a c  + 1344a b c  + 560a b c  + 28a b c )x
+--R             + 
+--R                     4   4        3 3 3        2 5 2        7   8
+--R               (7296a b c  + 9632a b c  + 1624a b c  + 30a b c)x
+--R             + 
+--R                     5 4         4 2 3         3 4 2        2 6   7
+--R               (8192a c  + 44544a b c  + 19712a b c  + 1120a b c)x
+--R             + 
+--R                      5   3         4 3 2         3 5   6
+--R               (74752a b c  + 90624a b c  + 12096a b c)x
+--R             + 
+--R                      6 3          5 2 2         4 4   5
+--R               (40960a c  + 189440a b c  + 57600a b c)x
+--R             + 
+--R                       6   2          5 3   4          7 2          6 2   3
+--R               (182272a b c  + 140800a b c)x  + (65536a c  + 184320a b c)x
+--R             + 
+--R                      7     2         8
+--R               122880a b c x  + 32768a c x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    4 5        3 2 4       2 4 3        6 2  10
+--R               (256a c  + 1344a b c  + 560a b c  + 28a b c )x
+--R             + 
+--R                     4   4         3 3 3        2 5 2        7   9
+--R               (7424a b c  + 10304a b c  + 1904a b c  + 44a b c)x
+--R             + 
+--R                     5 4         4 2 3         3 4 2        2 6         8  8
+--R               (8448a c  + 49984a b c  + 25648a b c  + 2044a b c + 16a b )x
+--R             + 
+--R                      5   3          4 3 2         3 5        2 7  7
+--R               (87040a b c  + 127232a b c  + 25536a b c + 688a b )x
+--R             + 
+--R                      6 3          5 2 2          4 4         3 6  6
+--R               (49152a c  + 282112a b c  + 135168a b c + 8736a b )x
+--R             + 
+--R                       6   2          5 3          4 5  5
+--R               (284672a b c  + 358400a b c + 50304a b )x
+--R             + 
+--R                       7 2          6 2           5 4  4
+--R               (106496a c  + 500736a b c + 154880a b )x
+--R             + 
+--R                       7             6 3  3          8           7 2  2
+--R               (352256a b c + 272384a b )x  + (98304a c + 274432a b )x
+--R             + 
+--R                      8            9
+--R               147456a b x + 32768a
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                      3   5        2 3 4         5 3     7 2  10
+--R               (- 896a b c  - 1120a b c  - 168a b c  - 2b c )x
+--R             + 
+--R                       4 5         3 2 4        2 4 3         6 2     8   9
+--R               (- 2048a c  - 11648a b c  - 5600a b c  - 392a b c  - 2b c)x
+--R             + 
+--R                        4   4         3 3 3        2 5 2         7   8
+--R               (- 30592a b c  - 44128a b c  - 8680a b c  - 226a b c)x
+--R             + 
+--R                        5 4          4 2 3         3 4 2        2 6   7
+--R               (- 22528a c  - 130560a b c  - 63616a b c  - 4256a b c)x
+--R             + 
+--R                         5   3          4 3 2         3 5   6
+--R               (- 160768a b c  - 208896a b c  - 30912a b c)x
+--R             + 
+--R                        6 3          5 2 2          4 4   5
+--R               (- 69632a c  - 339968a b c  - 111360a b c)x
+--R             + 
+--R                         6   2          5 3   4            7 2          6 2   3
+--R               (- 268288a b c  - 219648a b c)x  + (- 81920a c  - 241664a b c)x
+--R             + 
+--R                        7     2         8
+--R               - 139264a b c x  - 32768a c x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      4 5        3 2 4       2 4 3        6 2  11
+--R               (- 256a c  - 1344a b c  - 560a b c  - 28a b c )x
+--R             + 
+--R                       4   4         3 3 3        2 5 2        7   10
+--R               (- 7424a b c  - 10304a b c  - 1904a b c  - 44a b c)x
+--R             + 
+--R                       5 4         4 2 3         3 4 2        2 6         8  9
+--R               (- 8448a c  - 49984a b c  - 25648a b c  - 2044a b c - 16a b )x
+--R             + 
+--R                        5   3          4 3 2         3 5        2 7  8
+--R               (- 87040a b c  - 127232a b c  - 25536a b c - 688a b )x
+--R             + 
+--R                        6 3          5 2 2          4 4         3 6  7
+--R               (- 49152a c  - 282112a b c  - 135168a b c - 8736a b )x
+--R             + 
+--R                         6   2          5 3          4 5  6
+--R               (- 284672a b c  - 358400a b c - 50304a b )x
+--R             + 
+--R                         7 2          6 2           5 4  5
+--R               (- 106496a c  - 500736a b c - 154880a b )x
+--R             + 
+--R                         7             6 3  4            8           7 2  3
+--R               (- 352256a b c - 272384a b )x  + (- 98304a c - 274432a b )x
+--R             + 
+--R                        8   2         9
+--R               - 147456a b x  - 32768a x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                    3   5        2 3 4         5 3     7 2  11
+--R               (896a b c  + 1120a b c  + 168a b c  + 2b c )x
+--R             + 
+--R                     4 5         3 2 4        2 4 3         6 2     8   10
+--R               (2048a c  + 11648a b c  + 5600a b c  + 392a b c  + 2b c)x
+--R             + 
+--R                      4   4         3 3 3        2 5 2         7   9
+--R               (30592a b c  + 44128a b c  + 8680a b c  + 226a b c)x
+--R             + 
+--R                      5 4          4 2 3         3 4 2        2 6   8
+--R               (22528a c  + 130560a b c  + 63616a b c  + 4256a b c)x
+--R             + 
+--R                       5   3          4 3 2         3 5   7
+--R               (160768a b c  + 208896a b c  + 30912a b c)x
+--R             + 
+--R                      6 3          5 2 2          4 4   6
+--R               (69632a c  + 339968a b c  + 111360a b c)x
+--R             + 
+--R                       6   2          5 3   5          7 2          6 2   4
+--R               (268288a b c  + 219648a b c)x  + (81920a c  + 241664a b c)x
+--R             + 
+--R                      7     3         8   2
+--R               139264a b c x  + 32768a c x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                3   5        2 3 4         5 3     7 2  12
+--R           (896a b c  + 1120a b c  + 168a b c  + 2b c )x
+--R         + 
+--R                 4 5         3 2 4        2 4 3         6 2     8   11
+--R           (2048a c  + 12096a b c  + 6160a b c  + 476a b c  + 3b c)x
+--R         + 
+--R                  4   4         3 3 3         2 5 2         7     9  10
+--R           (32640a b c  + 51744a b c  + 11928a b c  + 438a b c + b )x
+--R         + 
+--R                  5 4          4 2 3         3 4 2        2 6          8  9
+--R           (24576a c  + 160704a b c  + 95536a b c  + 9716a b c + 129a b )x
+--R         + 
+--R                   5   3          4 3 2         3 5         2 7  8
+--R           (205824a b c  + 335872a b c  + 79296a b c + 2816a b )x
+--R         + 
+--R                  6 3          5 2 2          4 4          3 6  7
+--R           (92160a c  + 577536a b c  + 312192a b c + 24192a b )x
+--R         + 
+--R                   6   2          5 3           4 5  6
+--R           (477184a b c  + 660992a b c + 105984a b )x
+--R         + 
+--R                   7 2          6 2           5 4  5
+--R           (151552a c  + 771072a b c + 264704a b )x
+--R         + 
+--R                   7             6 3  4           8           7 2  3
+--R           (466944a b c + 393216a b )x  + (114688a c + 344064a b )x
+--R         + 
+--R                  8   2         9
+--R           163840a b x  + 32768a x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R     + 
+--R              4 6        3 2 5       2 4 4        6 3  12
+--R       (- 256a c  - 1344a b c  - 560a b c  - 28a b c )x
+--R     + 
+--R               4   5         3 3 4        2 5 3        7 2  11
+--R       (- 7552a b c  - 10976a b c  - 2184a b c  - 58a b c )x
+--R     + 
+--R               5 5         4 2 4         3 4 3        2 6 2        8   10
+--R       (- 8448a c  - 53184a b c  - 29904a b c  - 2772a b c  - 30a b c)x
+--R     + 
+--R                5   4          4 3 3         3 5 2        2 7   9
+--R       (- 90240a b c  - 144800a b c  - 33432a b c  - 1150a b c)x
+--R     + 
+--R                6 4          5 2 3          4 4 2         3 6   8
+--R       (- 49152a c  - 308736a b c  - 167936a b c  - 13216a b c)x
+--R     + 
+--R                 6   3          5 3 2         4 5   7
+--R       (- 297984a b c  - 420864a b c  - 69696a b c)x
+--R     + 
+--R                 7 3          6 2 2          5 4   6
+--R       (- 106496a c  - 556032a b c  - 198400a b c)x
+--R     + 
+--R                 7   2          6 3   5            8 2          7 2   4
+--R       (- 370688a b c  - 325120a b c)x  + (- 98304a c  - 307200a b c)x
+--R     + 
+--R                8     3         9   2
+--R       - 155648a b c x  - 32768a c x
+--R  /
+--R                      4 4        3 2 3       2 4 2        6   9
+--R                 (256a c  + 1344a b c  + 560a b c  + 28a b c)x
+--R               + 
+--R                       4   3        3 3 2        2 5         7  8
+--R                 (7168a b c  + 8960a b c  + 1344a b c + 16a b )x
+--R               + 
+--R                       5 3         4 2 2         3 4        2 6  7
+--R                 (8192a c  + 41472a b c  + 16128a b c + 672a b )x
+--R               + 
+--R                        5   2         4 3         3 5  6
+--R                 (71680a b c  + 76800a b c + 8064a b )x
+--R               + 
+--R                        6 2          5 2          4 4  5
+--R                 (40960a c  + 168960a b c + 42240a b )x
+--R               + 
+--R                         6             5 3  4          7           6 2  3
+--R                 (172032a b c + 112640a b )x  + (65536a c + 159744a b )x
+--R               + 
+--R                        7   2         8
+--R                 114688a b x  + 32768a x
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                        3   4        2 3 3         5 2     7   9
+--R                 (- 896a b c  - 1120a b c  - 168a b c  - 2b c)x
+--R               + 
+--R                         4 4         3 2 3        2 4 2         6   8
+--R                 (- 2048a c  - 10752a b c  - 4480a b c  - 224a b c)x
+--R               + 
+--R                          4   3         3 3 2        2 5   7
+--R                 (- 27648a b c  - 32256a b c  - 4032a b c)x
+--R               + 
+--R                          5 3         4 2 2         3 4   6
+--R                 (- 20480a c  - 92160a b c  - 26880a b c)x
+--R               + 
+--R                           5   2         4 3   5            6 2          5 2   4
+--R                 (- 112640a b c  - 84480a b c)x  + (- 49152a c  - 135168a b c)x
+--R               + 
+--R                          6     3         7   2
+--R                 - 106496a b c x  - 32768a c x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    3   4        2 3 3         5 2     7   10
+--R             (- 896a b c  - 1120a b c  - 168a b c  - 2b c)x
+--R           + 
+--R                     4 4         3 2 3        2 4 2         6     8  9
+--R             (- 2048a c  - 11200a b c  - 5040a b c  - 308a b c - b )x
+--R           + 
+--R                      4   3         3 3 2        2 5          7  8
+--R             (- 29696a b c  - 39424a b c  - 6720a b c - 128a b )x
+--R           + 
+--R                      5 3          4 2 2         3 4         2 6  7
+--R             (- 22528a c  - 119808a b c  - 51072a b c - 2688a b )x
+--R           + 
+--R                       5   2          4 3          3 5  6
+--R             (- 153600a b c  - 176640a b c - 21504a b )x
+--R           + 
+--R                      6 2          5 2          4 4  5
+--R             (- 69632a c  - 304128a b c - 84480a b )x
+--R           + 
+--R                       6             5 3  4            7           6 2  3
+--R             (- 253952a b c - 180224a b )x  + (- 81920a c - 212992a b )x
+--R           + 
+--R                      7   2         8
+--R             - 131072a b x  - 32768a x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R       + 
+--R              4 5        3 2 4       2 4 3        6 2  10
+--R         (256a c  + 1344a b c  + 560a b c  + 28a b c )x
+--R       + 
+--R               4   4        3 3 3        2 5 2        7   9
+--R         (7296a b c  + 9632a b c  + 1624a b c  + 30a b c)x
+--R       + 
+--R               5 4         4 2 3         3 4 2        2 6   8
+--R         (8192a c  + 44544a b c  + 19712a b c  + 1120a b c)x
+--R       + 
+--R                5   3         4 3 2         3 5   7
+--R         (74752a b c  + 90624a b c  + 12096a b c)x
+--R       + 
+--R                6 3          5 2 2         4 4   6
+--R         (40960a c  + 189440a b c  + 57600a b c)x
+--R       + 
+--R                 6   2          5 3   5          7 2          6 2   4
+--R         (182272a b c  + 140800a b c)x  + (65536a c  + 184320a b c)x
+--R       + 
+--R                7     3         8   2
+--R         122880a b c x  + 32768a c x
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +--------------+
+--R             +---+ +-+ |   2                            +---+ +-+ +-+
+--R         (4a\|- c \|c \|c x  + b x + a  + (- 2b x - 4a)\|- c \|a \|c )
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                                          +--------------+
+--R                  2         +---+ +-+ +-+ |   2
+--R           (- 2b x  - 4a x)\|- c \|a \|c \|c x  + b x + a
+--R         + 
+--R                  3         2     2   +---+ +-+
+--R           (4a c x  + 4a b x  + 4a x)\|- c \|c
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                                 +--------------+
+--R             2 2           +---+ |   2
+--R           (b x  + 2a b x)\|- c \|c x  + b x + a
+--R         + 
+--R                    3     2 2           +---+ +-+
+--R           (- 2b c x  - 2b x  - 2a b x)\|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                     +--------------+
+--R             +-+ +-+ |   2                   2          +-+
+--R         (4b\|a \|c \|c x  + b x + a  + (- 2b x - 4a b)\|c )
+--R      *
+--R                                              +--------------+
+--R          +------------------+      +---+ +-+ |   2                +---+
+--R          |   4      3      2      \|- c \|a \|c x  + b x + a  - a\|- c
+--R         \|c x  + b x  + a x  atan(-------------------------------------)
+--R                                                      +-+
+--R                                                  c x\|a
+--R     + 
+--R                           +--------------+
+--R                 +---+ +-+ |   2                   2         +---+ +-+ +-+
+--R         (- 2b x\|- c \|c \|c x  + b x + a  + (4c x  + 2b x)\|- c \|a \|c )
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                              +--------------+
+--R              3       2         +---+ +-+ +-+ |   2
+--R       (- 4c x  - 4b x  - 4a x)\|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R              4             2  3         2     2   +---+ +-+
+--R       (2b c x  + (4a c + 2b )x  + 6a b x  + 4a x)\|- c \|c
+--R  /
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2                            +---+ +-+
+--R       (4\|- c \|a \|c \|c x  + b x + a  + (- 2b x - 4a)\|- c \|c )
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 210
+
+--S 211 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                                              +--------------+
+--R                    3               2  2               2  +-+ |   2
+--R           (- 4b c x  + (- 8a c - 4b )x  - 12a b x - 8a )\|a \|c x  + b x + a
+--R         + 
+--R              2    2   4               3  3       2        2  2      2        3
+--R         (4a c  + b c)x  + (12a b c + b )x  + (12a c + 9a b )x  + 16a b x + 8a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  2    2   5                 3  4         2        2  3
+--R           (- 4a c  - b c)x  + (- 12a b c - b )x  + (- 12a c - 9a b )x
+--R         + 
+--R                2   2     3
+--R           - 16a b x  - 8a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R               2 6        2     2   5                3  4       2         2  3
+--R           4b c x  + (8a c  + 8b c)x  + (24a b c + 4b )x  + (16a c + 16a b )x
+--R         + 
+--R              2   2     3
+--R           20a b x  + 8a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                          +--------------+
+--R                   2  3         2     2   |   2
+--R         ((4a c + b )x  + 8a b x  + 8a x)\|c x  + b x + a
+--R       + 
+--R                  4               2  3          2     2   +-+
+--R         (- 4b c x  + (- 8a c - 4b )x  - 12a b x  - 8a x)\|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+)clear all
+
+--S 212 of 704
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x^3
+--R 
+--R
+--R         +------------------+
+--R         |   4      3      2
+--R        \|c x  + b x  + a x
+--R   (1)  ---------------------
+--R                   3
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 704
+r0:=-1/2*b*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(sqrt(a)*sqrt(a*x^2+b*x^3+c*x^4))+x*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(c)*sqrt(a+b*x+c*x^2)/_
+   sqrt(a*x^2+b*x^3+c*x^4)-sqrt(a*x^2+b*x^3+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R             +--------------+
+--R             |   2                        b x + 2a
+--R       - b x\|c x  + b x + a atanh(----------------------)
+--R                                         +--------------+
+--R                                     +-+ |   2
+--R                                   2\|a \|c x  + b x + a
+--R     + 
+--R                  +--------------+
+--R          +-+ +-+ |   2                        2c x + b
+--R       2x\|a \|c \|c x  + b x + a atanh(----------------------)
+--R                                              +--------------+
+--R                                          +-+ |   2
+--R                                        2\|c \|c x  + b x + a
+--R     + 
+--R              2              +-+
+--R       (- 2c x  - 2b x - 2a)\|a
+--R  /
+--R           +------------------+
+--R       +-+ |   4      3      2
+--R     2\|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 213
+
+--S 214 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     +--------------+
+--R                 +-+ |   2                2 2
+--R           (4b x\|a \|c x  + b x + a  - 2b x  - 4a b x)
+--R        *
+--R                  +--------------+
+--R                  |   2                           +-+
+--R               2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R           log(--------------------------------------)
+--R                                2a x
+--R       + 
+--R                     +--------------+
+--R                 +-+ |   2                     2         +-+ +-+
+--R           (8a x\|c \|c x  + b x + a  + (- 4b x  - 8a x)\|a \|c )
+--R        *
+--R           log
+--R                                     +--------------+
+--R                        +-+     +-+  |   2                 +-+ +-+       2
+--R                  (- 2x\|c  + 2\|a )\|c x  + b x + a  + 2x\|a \|c  - 2c x  - b x
+--R                + 
+--R                  - 2a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                         +--------------+
+--R                     +-+ |   2                         2  2              2
+--R         (2b x + 8a)\|a \|c x  + b x + a  + (- 8a c + b )x  - 6a b x - 8a
+--R    /
+--R            +--------------+
+--R            |   2                     2         +-+
+--R       8a x\|c x  + b x + a  + (- 4b x  - 8a x)\|a
+--R     ,
+--R
+--R                     +--------------+
+--R                 +-+ |   2                2 2
+--R           (4b x\|a \|c x  + b x + a  - 2b x  - 4a b x)
+--R        *
+--R                  +--------------+
+--R                  |   2                           +-+
+--R               2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R           log(--------------------------------------)
+--R                                2a x
+--R       + 
+--R                        +--------------+
+--R                  +---+ |   2                     2          +---+ +-+
+--R           (16a x\|- c \|c x  + b x + a  + (- 8b x  - 16a x)\|- c \|a )
+--R        *
+--R                 +--------------+
+--R                 |   2               +-+
+--R                \|c x  + b x + a  - \|a
+--R           atan(------------------------)
+--R                           +---+
+--R                         x\|- c
+--R       + 
+--R                         +--------------+
+--R                     +-+ |   2                         2  2              2
+--R         (2b x + 8a)\|a \|c x  + b x + a  + (- 8a c + b )x  - 6a b x - 8a
+--R    /
+--R            +--------------+
+--R            |   2                     2         +-+
+--R       8a x\|c x  + b x + a  + (- 4b x  - 8a x)\|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 214
+
+--S 215 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 +--------------+                           +------------------+
+--R                 |   2                   2 2           +-+  |   4      3      2
+--R         (4a b x\|c x  + b x + a  + (- 2b x  - 4a b x)\|a )\|c x  + b x  + a x
+--R      *
+--R                +--------------+
+--R                |   2                           +-+
+--R             2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         log(--------------------------------------)
+--R                              2a x
+--R     + 
+--R                       +--------------+
+--R               +-+ +-+ |   2                       2     2   +-+
+--R         (8a x\|a \|c \|c x  + b x + a  + (- 4a b x  - 8a x)\|c )
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R                              +--------------+
+--R                 +-+     +-+  |   2                 +-+ +-+       2
+--R           (- 2x\|c  + 2\|a )\|c x  + b x + a  + 2x\|a \|c  - 2c x  - b x - 2a
+--R       log(-------------------------------------------------------------------)
+--R                                  +--------------+
+--R                              +-+ |   2
+--R                            2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                                   +--------------+
+--R                2 3         2  +-+ |   2                      4       2 3
+--R           (- 2b x  - 4a b x )\|a \|c x  + b x + a  + 4a b c x  + 4a b x
+--R         + 
+--R             2   2
+--R           4a b x
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                                 +--------------+
+--R                  3     2 2  +-+ |   2
+--R           (4a b x  + 8a x )\|c \|c x  + b x + a
+--R         + 
+--R                    4         3     2 2  +-+ +-+
+--R           (- 8a c x  - 8a b x  - 8a x )\|a \|c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                            +--------------+
+--R                         2  |   2
+--R             (2a b x + 8a )\|c x  + b x + a
+--R           + 
+--R                         2  2              2  +-+
+--R             ((- 8a c + b )x  - 6a b x - 8a )\|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                      +--------------+
+--R              3         2     2   +-+ |   2                      4
+--R       (8a c x  + 8a b x  + 8a x)\|a \|c x  + b x + a  - 4a b c x
+--R     + 
+--R            2        2  3      2   2     3
+--R       (- 8a c - 4a b )x  - 12a b x  - 8a x
+--R  /
+--R               +--------------+                   +------------------+
+--R           +-+ |   2                    2     2   |   4      3      2
+--R     (8a x\|a \|c x  + b x + a  - 4a b x  - 8a x)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         3 3       2 2 2        4   7
+--R                   (- 64a c  - 160a b c  - 20a b c)x
+--R                 + 
+--R                          3   2       2 3         5  6
+--R                   (- 992a b c  - 560a b c - 22a b )x
+--R                 + 
+--R                           4 2        3 2        2 4  5
+--R                   (- 1152a c  - 3072a b c - 440a b )x
+--R                 + 
+--R                           4           3 3  4           5         4 2  3
+--R                   (- 5504a b c - 2464a b )x  + (- 3072a c - 5632a b )x
+--R                 + 
+--R                          5   2        6
+--R                   - 5632a b x  - 2048a x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                        2   3        3 2     5   7
+--R                   (160a b c  + 80a b c  + 2b c)x
+--R                 + 
+--R                        3 3        2 2 2         4     6  6
+--R                   (384a c  + 1040a b c  + 160a b c + b )x
+--R                 + 
+--R                         3   2        2 3         5  5
+--R                   (3072a b c  + 1760a b c + 72a b )x
+--R                 + 
+--R                         4 2        3 2        2 4  4         4           3 3  3
+--R                   (2432a c  + 6272a b c + 840a b )x  + (8704a b c + 3584a b )x
+--R                 + 
+--R                         5         4 2  2        5           6
+--R                   (4096a c + 6912a b )x  + 6144a b x + 2048a
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2   3        3 2     5   8
+--R               (160a b c  + 80a b c  + 2b c)x
+--R             + 
+--R                    3 3        2 2 2         4      6  7
+--R               (384a c  + 1120a b c  + 200a b c + 2b )x
+--R             + 
+--R                     3   2        2 3          5  6
+--R               (3232a b c  + 2160a b c + 122a b )x
+--R             + 
+--R                     4 2        3 2         2 4  5         4           3 3  4
+--R               (2432a c  + 7232a b c + 1240a b )x  + (9344a b c + 4704a b )x
+--R             + 
+--R                     5         4 2  3        5   2        6
+--R               (4096a c + 8192a b )x  + 6656a b x  + 2048a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                 3 4       2 2 3        4 2  8
+--R           (- 64a c  - 160a b c  - 20a b c )x
+--R         + 
+--R                   3   3       2 3 2        5   7
+--R           (- 1024a b c  - 640a b c  - 32a b c)x
+--R         + 
+--R                   4 3        3 2 2       2 4         6  6
+--R           (- 1216a c  - 3808a b c  - 780a b c - 12a b )x
+--R         + 
+--R                   4   2        3 3        2 5  5
+--R           (- 7232a b c  - 4960a b c - 292a b )x
+--R         + 
+--R                   5 2         4 2         3 4  4            5           4 3  3
+--R           (- 4224a c  - 12416a b c - 2072a b )x  + (- 13312a b c - 6400a b )x
+--R         + 
+--R                   6         5 2  2        6           7
+--R           (- 5120a c - 9728a b )x  - 7168a b x - 2048a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      2   3        3 2     5   9
+--R               (- 160a b c  - 80a b c  - 2b c)x
+--R             + 
+--R                      3 3        2 2 2         4      6  8
+--R               (- 384a c  - 1120a b c  - 200a b c - 2b )x
+--R             + 
+--R                       3   2        2 3          5  7
+--R               (- 3232a b c  - 2160a b c - 122a b )x
+--R             + 
+--R                       4 2        3 2         2 4  6
+--R               (- 2432a c  - 7232a b c - 1240a b )x
+--R             + 
+--R                       4           3 3  5           5         4 2  4
+--R               (- 9344a b c - 4704a b )x  + (- 4096a c - 8192a b )x
+--R             + 
+--R                      5   3        6 2
+--R               - 6656a b x  - 2048a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R               3 4       2 2 3        4 2  9
+--R           (64a c  + 160a b c  + 20a b c )x
+--R         + 
+--R                 3   3       2 3 2        5   8
+--R           (1024a b c  + 640a b c  + 32a b c)x
+--R         + 
+--R                 4 3        3 2 2       2 4         6  7
+--R           (1216a c  + 3808a b c  + 780a b c + 12a b )x
+--R         + 
+--R                 4   2        3 3        2 5  6
+--R           (7232a b c  + 4960a b c + 292a b )x
+--R         + 
+--R                 5 2         4 2         3 4  5          5           4 3  4
+--R           (4224a c  + 12416a b c + 2072a b )x  + (13312a b c + 6400a b )x
+--R         + 
+--R                 6         5 2  3        6   2        7
+--R           (5120a c + 9728a b )x  + 7168a b x  + 2048a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R               3 4       2 2 3        4 2  10
+--R           (64a c  + 160a b c  + 20a b c )x
+--R         + 
+--R                 3   3       2 3 2        5   9
+--R           (1056a b c  + 720a b c  + 42a b c)x
+--R         + 
+--R                 4 3        3 2 2        2 4         6  8
+--R           (1216a c  + 4224a b c  + 1020a b c + 22a b )x
+--R         + 
+--R                 4   2        3 3        2 5  7
+--R           (7648a b c  + 6096a b c + 462a b )x
+--R         + 
+--R                 5 2         4 2         3 4  6          5           4 3  5
+--R           (4224a c  + 14208a b c + 2904a b )x  + (14208a b c + 8096a b )x
+--R         + 
+--R                 6          5 2  4        6   3        7 2
+--R           (5120a c + 11264a b )x  + 7680a b x  + 2048a x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                  2   4        3 3     5 2  10
+--R           (- 160a b c  - 80a b c  - 2b c )x
+--R         + 
+--R                  3 4        2 2 3         4 2     6   9
+--R           (- 384a c  - 1200a b c  - 240a b c  - 3b c)x
+--R         + 
+--R                   3   3        2 3 2         5     7  8
+--R           (- 3616a b c  - 2880a b c  - 234a b c - b )x
+--R         + 
+--R                   4 3         3 2 2        2 4         6  7
+--R           (- 2816a c  - 10384a b c  - 2760a b c - 73a b )x
+--R         + 
+--R                    4   2         3 3        2 5  6
+--R           (- 14208a b c  - 11616a b c - 912a b )x
+--R         + 
+--R                   5 2         4 2         3 4  5            5            4 3  4
+--R           (- 6528a c  - 21888a b c - 4424a b )x  + (- 18944a b c - 10496a b )x
+--R         + 
+--R                   6          5 2  3        6   2        7
+--R           (- 6144a c - 13056a b )x  - 8192a b x  - 2048a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                      2   2        3      5  8
+--R                 (160a b c  + 80a b c + 2b )x
+--R               + 
+--R                      3 2       2 2          4  7         3           2 3  6
+--R                 (384a c  + 960a b c + 120a b )x  + (2688a b c + 1120a b )x
+--R               + 
+--R                       4         3 2  5        4   4        5 3
+--R                 (2048a c + 3584a b )x  + 4608a b x  + 2048a x
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                   3 3       2 2 2        4   8
+--R             (- 64a c  - 160a b c  - 20a b c)x
+--R           + 
+--R                    3   2       2 3         5  7
+--R             (- 960a b c  - 480a b c - 12a b )x
+--R           + 
+--R                     4 2        3 2        2 4  6           4           3 3  5
+--R             (- 1152a c  - 2688a b c - 280a b )x  + (- 5120a b c - 1792a b )x
+--R           + 
+--R                     5         4 2  4        5   3        6 2
+--R             (- 3072a c - 4608a b )x  - 5120a b x  - 2048a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   3 3       2 2 2        4   9
+--R             (- 64a c  - 160a b c  - 20a b c)x
+--R           + 
+--R                    3   2       2 3         5  8
+--R             (- 992a b c  - 560a b c - 22a b )x
+--R           + 
+--R                     4 2        3 2        2 4  7           4           3 3  6
+--R             (- 1152a c  - 3072a b c - 440a b )x  + (- 5504a b c - 2464a b )x
+--R           + 
+--R                     5         4 2  5        5   4        6 3
+--R             (- 3072a c - 5632a b )x  - 5632a b x  - 2048a x
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                  2   3        3 2     5   9
+--R             (160a b c  + 80a b c  + 2b c)x
+--R           + 
+--R                  3 3        2 2 2         4     6  8
+--R             (384a c  + 1040a b c  + 160a b c + b )x
+--R           + 
+--R                   3   2        2 3         5  7
+--R             (3072a b c  + 1760a b c + 72a b )x
+--R           + 
+--R                   4 2        3 2        2 4  6         4           3 3  5
+--R             (2432a c  + 6272a b c + 840a b )x  + (8704a b c + 3584a b )x
+--R           + 
+--R                   5         4 2  4        5   3        6 2
+--R             (4096a c + 6912a b )x  + 6144a b x  + 2048a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 +--------------+                           +------------------+
+--R                 |   2                   2 2           +-+  |   4      3      2
+--R         (4a b x\|c x  + b x + a  + (- 2b x  - 4a b x)\|a )\|c x  + b x  + a x
+--R      *
+--R                +--------------+
+--R                |   2                           +-+
+--R             2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         log(--------------------------------------)
+--R                              2a x
+--R     + 
+--R                                   +--------------+
+--R                2 3         2  +-+ |   2                      4       2 3
+--R           (- 2b x  - 4a b x )\|a \|c x  + b x + a  + 4a b c x  + 4a b x
+--R         + 
+--R             2   2
+--R           4a b x
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                                 +--------------+
+--R                  3     2 2  +-+ |   2
+--R           (4a b x  + 8a x )\|c \|c x  + b x + a
+--R         + 
+--R                    4         3     2 2  +-+ +-+
+--R           (- 8a c x  - 8a b x  - 8a x )\|a \|c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                          +--------------+
+--R                +---+ +-+ |   2                       2      2   +---+
+--R         (16a x\|- c \|a \|c x  + b x + a  + (- 8a b x  - 16a x)\|- c )
+--R      *
+--R                                    +--------------+
+--R          +------------------+      |   2               +-+
+--R          |   4      3      2      \|c x  + b x + a  - \|a
+--R         \|c x  + b x  + a x  atan(------------------------)
+--R                                              +---+
+--R                                            x\|- c
+--R     + 
+--R                            +--------------+
+--R                         2  |   2
+--R             (2a b x + 8a )\|c x  + b x + a
+--R           + 
+--R                         2  2              2  +-+
+--R             ((- 8a c + b )x  - 6a b x - 8a )\|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                      +--------------+
+--R              3         2     2   +-+ |   2                      4
+--R       (8a c x  + 8a b x  + 8a x)\|a \|c x  + b x + a  - 4a b c x
+--R     + 
+--R            2        2  3      2   2     3
+--R       (- 8a c - 4a b )x  - 12a b x  - 8a x
+--R  /
+--R               +--------------+                   +------------------+
+--R           +-+ |   2                    2     2   |   4      3      2
+--R     (8a x\|a \|c x  + b x + a  - 4a b x  - 8a x)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                            3  3         2         2  2      2         3  +-+
+--R             ((- 12a b c - b )x  + (- 24a c - 18a b )x  - 48a b x - 32a )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R              2 2       2   4       2          3  3       3       2 2  2
+--R           (8a c  + 6a b c)x  + (40a b c + 6a b )x  + (40a c + 38a b )x
+--R         + 
+--R              3         4
+--R           64a b x + 32a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                2 2       2   5         2          3  4         3       2 2  3
+--R           (- 8a c  - 6a b c)x  + (- 40a b c - 6a b )x  + (- 40a c - 38a b )x
+--R         + 
+--R                3   2      4
+--R           - 64a b x  - 32a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   2    3   6       2 2        2     4  5       2           3  4
+--R           (12a b c  + b c)x  + (24a c  + 30a b c + b )x  + (84a b c + 19a b )x
+--R         + 
+--R               3       2 2  3      3   2      4
+--R           (56a c + 66a b )x  + 80a b x  + 32a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                +--------------+
+--R             2        2  4      2   3      3 2  |   2
+--R         ((8a c + 6a b )x  + 32a b x  + 32a x )\|c x  + b x + a
+--R       + 
+--R                        3  5         2         2  4      2   3      3 2  +-+
+--R         ((- 12a b c - b )x  + (- 24a c - 18a b )x  - 48a b x  - 32a x )\|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 218
+
+)clear all
+
+--S 219 of 704
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x^4
+--R 
+--R
+--R         +------------------+
+--R         |   4      3      2
+--R        \|c x  + b x  + a x
+--R   (1)  ---------------------
+--R                   4
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 704
+r0:=1/8*(b^2-4*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/2*sqrt(a*x^2+_
+   b*x^3+c*x^4)/x^3-1/4*b*sqrt(a*x^2+b*x^3+c*x^4)/(a*x^2)
+--R 
+--R
+--R   (2)
+--R                       +--------------+
+--R                  2  2 |   2                        b x + 2a
+--R       (- 4a c + b )x \|c x  + b x + a atanh(----------------------)
+--R                                                   +--------------+
+--R                                               +-+ |   2
+--R                                             2\|a \|c x  + b x + a
+--R     + 
+--R                3               2  2              2  +-+
+--R       (- 2b c x  + (- 4a c - 2b )x  - 6a b x - 4a )\|a
+--R  /
+--R              +------------------+
+--R          +-+ |   4      3      2
+--R     8a x\|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                        +--------------+
+--R                2           3  3        3       2 2  2  |   2
+--R           ((64a b c - 16a b )x  + (128a c - 32a b )x )\|c x  + b x + a
+--R         + 
+--R                     2 2     4  4          2           3  3
+--R               (- 64a c  + 4b )x  + (- 128a b c + 32a b )x
+--R             + 
+--R                      3       2 2  2
+--R               (- 128a c + 32a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +--------------+
+--R               +-+ |   2
+--R             2\|a \|c x  + b x + a  - b x - 2a
+--R         log(---------------------------------)
+--R                              +-+
+--R                           2x\|a
+--R     + 
+--R              2          3  3       3       2 2  2       3          4
+--R         ((32a b c + 4a b )x  + (64a c + 72a b )x  + 192a b x + 128a )
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   2     4  4          2           3  3          3        2 2  2
+--R           (- 28a b c + b )x  + (- 128a b c - 24a b )x  + (- 128a c - 152a b )x
+--R         + 
+--R                 3          4
+--R           - 256a b x - 128a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                 +--------------+
+--R            2   3       3 2  +-+ |   2                     3       2 2  4
+--R       (128a b x  + 256a x )\|a \|c x  + b x + a  + (- 128a c - 32a b )x
+--R     + 
+--R             3   3       4 2
+--R       - 256a b x  - 256a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 221
+
+--S 222 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +--------------+
+--R                          3  3        2         2  2  +-+ |   2
+--R           ((64a b c - 16b )x  + (128a c - 32a b )x )\|a \|c x  + b x + a
+--R         + 
+--R                 2 2     4  4          2           3  3          3       2 2  2
+--R           (- 64a c  + 4b )x  + (- 128a b c + 32a b )x  + (- 128a c + 32a b )x
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                     2 2     4  5          2           3  4
+--R               (- 64a c  + 4b )x  + (- 128a b c + 32a b )x
+--R             + 
+--R                      3       2 2  3
+--R               (- 128a c + 32a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       2      3   6        2 2        2       4  5
+--R               (64a b c  - 16b c)x  + (128a c  + 32a b c - 16b )x
+--R             + 
+--R                    2           3  4        3       2 2  3
+--R               (192a b c - 48a b )x  + (128a c - 32a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                           3  3       2         2  2       2          3  +-+
+--R             ((32a b c + 4b )x  + (64a c + 72a b )x  + 192a b x + 128a )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   2     4  4          2           3  3          3        2 2  2
+--R           (- 28a b c + b )x  + (- 128a b c - 24a b )x  + (- 128a c - 152a b )x
+--R         + 
+--R                 3          4
+--R           - 256a b x - 128a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                2   5        2           3  4        3        2 2  3       3   2
+--R           32a b c x  + (128a b c + 32a b )x  + (128a c + 160a b )x  + 256a b x
+--R         + 
+--R               4
+--R           128a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                     2     3   6         2 2         2      4  5
+--R           (- 32a b c  - 8b c)x  + (- 64a c  - 112a b c - 8b )x
+--R         + 
+--R                2           3  4          3        2 2  3       3   2       4
+--R         (- 288a b c - 88a b )x  + (- 192a c - 272a b )x  - 320a b x  - 128a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                               +--------------+
+--R              2   3       3 2  |   2
+--R         (128a b x  + 256a x )\|c x  + b x + a
+--R       + 
+--R                 2         2  4       2   3       3 2  +-+
+--R         ((- 128a c - 32a b )x  - 256a b x  - 256a x )\|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                         2     3   5         2 2         2      4  4
+--R               (- 32a b c  - 8b c)x  + (- 64a c  - 112a b c - 8b )x
+--R             + 
+--R                    2           3  3          3        2 2  2       3          4
+--R             (- 288a b c - 88a b )x  + (- 192a c - 272a b )x  - 320a b x - 128a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               2 3        2 2    4   6        2   2        3     5  5
+--R           (16a c  + 24a b c  + b c)x  + (144a b c  + 56a b c + b )x
+--R         + 
+--R                3 2       2 2         4  4        3          2 3  3
+--R           (144a c  + 312a b c + 33a b )x  + (512a b c + 192a b )x
+--R         + 
+--R                4        3 2  2       4          5
+--R           (256a c + 416a b )x  + 384a b x + 128a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 2 3        2 2    4   7          2   2        3     5  6
+--R           (- 16a c  - 24a b c  - b c)x  + (- 144a b c  - 56a b c - b )x
+--R         + 
+--R                  3 2       2 2         4  5          3          2 3  4
+--R           (- 144a c  - 312a b c - 33a b )x  + (- 512a b c - 192a b )x
+--R         + 
+--R                  4        3 2  3       4   2       5
+--R           (- 256a c - 416a b )x  - 384a b x  - 128a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   3     3 2  8       2 3         2 2      4   7
+--R           (32a b c  + 8b c )x  + (64a c  + 144a b c  + 16b c)x
+--R         + 
+--R                2   2         3      5  6        3 2       2 2         4  5
+--R           (384a b c  + 208a b c + 8b )x  + (256a c  + 672a b c + 96a b )x
+--R         + 
+--R                3          2 3  4        4        3 2  3       4   2       5
+--R           (800a b c + 360a b )x  + (320a c + 592a b )x  + 448a b x  + 128a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 2 2        2     4  7        2           3  6
+--R             (16a c  + 24a b c + b )x  + (128a b c + 32a b )x
+--R           + 
+--R                  3        2 2  5       3   4       4 3
+--R             (128a c + 160a b )x  + 256a b x  + 128a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                       2     3   8         2 2         2      4  7
+--R             (- 32a b c  - 8b c)x  + (- 64a c  - 112a b c - 8b )x
+--R           + 
+--R                    2           3  6          3        2 2  5       3   4
+--R             (- 288a b c - 88a b )x  + (- 192a c - 272a b )x  - 320a b x
+--R           + 
+--R                   4 3
+--R             - 128a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 223
+
+)clear all
+
+--S 224 of 704
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x^5
+--R 
+--R
+--R         +------------------+
+--R         |   4      3      2
+--R        \|c x  + b x  + a x
+--R   (1)  ---------------------
+--R                   5
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 704
+r0:=-1/16*b*(b^2-4*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/3*sqrt(a*x^2+_
+   b*x^3+c*x^4)/x^4-1/12*b*sqrt(a*x^2+b*x^3+c*x^4)/(a*x^3)+1/24*(3*b^2-_
+   8*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*x^2)
+--R 
+--R
+--R   (2)
+--R                         +--------------+
+--R                    3  3 |   2                        b x + 2a
+--R       (12a b c - 3b )x \|c x  + b x + a atanh(----------------------)
+--R                                                     +--------------+
+--R                                                 +-+ |   2
+--R                                               2\|a \|c x  + b x + a
+--R     + 
+--R                   2     2   4                  3  3         2        2  2
+--R           (- 16a c  + 6b c)x  + (- 20a b c + 6b )x  + (- 32a c + 2a b )x
+--R         + 
+--R                2         3
+--R           - 20a b x - 16a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                +------------------+
+--R        2 2 +-+ |   4      3      2
+--R     48a x \|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 225
+
+--S 226 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      2   2         3       5  5           2 2          4  4
+--R               (- 384a b c  - 192a b c + 72b )x  + (- 1536a b c + 384a b )x
+--R             + 
+--R                       3          2 3  3
+--R               (- 1536a b c + 384a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                2 2 2        4       6  6         3   2       2 3          5  5
+--R           (576a b c  - 96a b c - 12b )x  + (1152a b c  + 576a b c - 216a b )x
+--R         + 
+--R                 3 2        2 4  4         4          3 3  3
+--R           (2304a b c - 576a b )x  + (1536a b c - 384a b )x
+--R      *
+--R                +--------------+
+--R                |   2                           +-+
+--R             2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         log(--------------------------------------)
+--R                              2a x
+--R     + 
+--R                2   2         3      5  5         3 2       2 2          4  4
+--R           (672a b c  - 256a b c + 6b )x  + (1536a c  + 384a b c - 256a b )x
+--R         + 
+--R               3          2 3  3         4         3 2  2        4           5
+--R         (3840a b c - 640a b )x  + (3584a c + 1152a b )x  + 3584a b x + 2048a
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R              3 3      2 2 2        4      6  6
+--R       (- 512a c  - 48a b c  + 96a b c - 5b )x
+--R     + 
+--R               3   2       2 3         5  5
+--R       (- 2400a b c  + 576a b c + 54a b )x
+--R     + 
+--R               4 2        3 2        2 4  4           4          3 3  3
+--R       (- 3072a c  - 1920a b c + 576a b )x  + (- 6912a b c + 384a b )x
+--R     + 
+--R               5         4 2  2        5           6
+--R       (- 4608a c - 2688a b )x  - 4608a b x - 2048a
+--R  /
+--R                                                        +--------------+
+--R              4         3 2  5        4   4        5 3  |   2
+--R       ((1536a c + 1152a b )x  + 6144a b x  + 6144a x )\|c x  + b x + a
+--R     + 
+--R                   3          2 3  6           4         3 2  5        4   4
+--R           (- 2304a b c - 192a b )x  + (- 4608a c - 3456a b )x  - 9216a b x
+--R         + 
+--R                  5 3
+--R           - 6144a x
+--R      *
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 226
+
+--S 227 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      3   2       2 3         5  5           3 2        2 4  4
+--R               (- 384a b c  - 192a b c + 72a b )x  + (- 1536a b c + 384a b )x
+--R             + 
+--R                       4          3 3  3
+--R               (- 1536a b c + 384a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2 2 2        4       6  6
+--R               (576a b c  - 96a b c - 12b )x
+--R             + 
+--R                     3   2       2 3          5  5         3 2        2 4  4
+--R               (1152a b c  + 576a b c - 216a b )x  + (2304a b c - 576a b )x
+--R             + 
+--R                     4          3 3  3
+--R               (1536a b c - 384a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                                     +--------------+
+--R          +------------------+       |   2                           +-+
+--R          |   4      3      2     2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         \|c x  + b x  + a x  log(--------------------------------------)
+--R                                                   2a x
+--R     + 
+--R                    2 2 2        4       6  7
+--R               (576a b c  - 96a b c - 12b )x
+--R             + 
+--R                     3   2       2 3          5  6         3 2        2 4  5
+--R               (1152a b c  + 576a b c - 216a b )x  + (2304a b c - 576a b )x
+--R             + 
+--R                     4          3 3  4
+--R               (1536a b c - 384a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                  3   3       2 3 2        5   8
+--R           (- 384a b c  - 192a b c  + 72a b c)x
+--R         + 
+--R                   3 2 2       2 4         6  7
+--R           (- 1920a b c  + 192a b c + 72a b )x
+--R         + 
+--R                   4   2        3 3        2 5  6           4 2        3 4  5
+--R           (- 1920a b c  - 1344a b c + 456a b )x  + (- 3072a b c + 768a b )x
+--R         + 
+--R                   5          4 3  4
+--R           (- 1536a b c + 384a b )x
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                    3   2       2 3        5  5
+--R               (672a b c  - 256a b c + 6a b )x
+--R             + 
+--R                     4 2       3 2        2 4  4         4          3 3  3
+--R               (1536a c  + 384a b c - 256a b )x  + (3840a b c - 640a b )x
+--R             + 
+--R                     5         4 2  2        5           6
+--R               (3584a c + 1152a b )x  + 3584a b x + 2048a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      3 3      2 2 2        4      6  6
+--R               (- 512a c  - 48a b c  + 96a b c - 5b )x
+--R             + 
+--R                       3   2       2 3         5  5
+--R               (- 2400a b c  + 576a b c + 54a b )x
+--R             + 
+--R                       4 2        3 2        2 4  4           4          3 3  3
+--R               (- 3072a c  - 1920a b c + 576a b )x  + (- 6912a b c + 384a b )x
+--R             + 
+--R                       5         4 2  2        5           6
+--R               (- 4608a c - 2688a b )x  - 4608a b x - 2048a
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                3 3       2 2 2         4   7
+--R           (512a c  + 192a b c  - 144a b c)x
+--R         + 
+--R                 3   2       2 3          5  6
+--R           (2688a b c  - 480a b c - 144a b )x
+--R         + 
+--R                 4 2        3 2        2 4  5         4          3 3  4
+--R           (3072a c  + 2496a b c - 816a b )x  + (7296a b c - 544a b )x
+--R         + 
+--R                 5         4 2  3        5   2        6
+--R           (4608a c + 2688a b )x  + 4608a b x  + 2048a x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R              3   3       2 3 2        5   8
+--R       (- 768a b c  + 224a b c  + 24a b c)x
+--R     + 
+--R               4 3        3 2 2       2 4         6  7
+--R       (- 1536a c  - 1536a b c  + 640a b c + 24a b )x
+--R     + 
+--R               4   2       3 3        2 5  6
+--R       (- 6528a b c  + 256a b c + 440a b )x
+--R     + 
+--R               5 2        4 2         3 4  5            5          4 3  4
+--R       (- 5120a c  - 6144a b c + 1216a b )x  + (- 11392a b c - 352a b )x
+--R     + 
+--R               6         5 2  3        6   2        7
+--R       (- 5632a c - 4736a b )x  - 5632a b x  - 2048a x
+--R  /
+--R                                                              +--------------+
+--R                4         3 2  5        4   4        5 3  +-+ |   2
+--R         ((1536a c + 1152a b )x  + 6144a b x  + 6144a x )\|a \|c x  + b x + a
+--R       + 
+--R                 4          3 3  6           5         4 2  5        5   4
+--R         (- 2304a b c - 192a b )x  + (- 4608a c - 3456a b )x  - 9216a b x
+--R       + 
+--R                6 3
+--R         - 6144a x
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      3   3       2 3 2        5     7  7
+--R               (- 448a b c  - 560a b c  - 84a b c - b )x
+--R             + 
+--R                      4 3        3 2 2        2 4         6  6
+--R               (- 896a c  - 4704a b c  - 1960a b c - 98a b )x
+--R             + 
+--R                        4   2         3 3         2 5  5
+--R               (- 10752a b c  - 12544a b c - 1568a b )x
+--R             + 
+--R                       5 2         4 2         3 4  4
+--R               (- 7168a c  - 32256a b c - 9408a b )x
+--R             + 
+--R                        5            4 3  3            6          5 2  2
+--R               (- 35840a b c - 26880a b )x  + (- 14336a c - 39424a b )x
+--R             + 
+--R                       6           7
+--R               - 28672a b x - 8192a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                4 4       3 2 3       2 4 2        6   8
+--R           (128a c  + 672a b c  + 280a b c  + 14a b c)x
+--R         + 
+--R                 4   3        3 3 2       2 5         7  7
+--R           (3200a b c  + 4256a b c  + 728a b c + 14a b )x
+--R         + 
+--R                 5 3         4 2 2        3 4        2 6  6
+--R           (3200a c  + 17568a b c  + 7896a b c + 462a b )x
+--R         + 
+--R                  5   2         4 3         3 5  5
+--R           (26624a b c  + 32768a b c + 4480a b )x
+--R         + 
+--R                  6 2         5 2          4 4  4          6            5 3  3
+--R           (13312a c  + 62464a b c + 19392a b )x  + (55296a b c + 43520a b )x
+--R         + 
+--R                  7          6 2  2         7           8
+--R           (18432a c + 52736a b )x  + 32768a b x + 8192a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  4 4       3 2 3       2 4 2        6   9
+--R           (- 128a c  - 672a b c  - 280a b c  - 14a b c)x
+--R         + 
+--R                   4   3        3 3 2       2 5         7  8
+--R           (- 3200a b c  - 4256a b c  - 728a b c - 14a b )x
+--R         + 
+--R                   5 3         4 2 2        3 4        2 6  7
+--R           (- 3200a c  - 17568a b c  - 7896a b c - 462a b )x
+--R         + 
+--R                    5   2         4 3         3 5  6
+--R           (- 26624a b c  - 32768a b c - 4480a b )x
+--R         + 
+--R                    6 2         5 2          4 4  5
+--R           (- 13312a c  - 62464a b c - 19392a b )x
+--R         + 
+--R                    6            5 3  4            7          6 2  3
+--R           (- 55296a b c - 43520a b )x  + (- 18432a c - 52736a b )x
+--R         + 
+--R                   7   2        8
+--R           - 32768a b x  - 8192a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                3   4       2 3 3        5 2    7   10
+--R           (448a b c  + 560a b c  + 84a b c  + b c)x
+--R         + 
+--R                4 4        3 2 3        2 4 2         6     8  9
+--R           (896a c  + 5152a b c  + 2520a b c  + 182a b c + b )x
+--R         + 
+--R                  4   3         3 3 2        2 5         7  8
+--R           (12096a b c  + 17808a b c  + 3612a b c + 99a b )x
+--R         + 
+--R                 5 3         4 2 2         3 4         2 6  7
+--R           (8064a c  + 47712a b c  + 23912a b c + 1666a b )x
+--R         + 
+--R                  5   2         4 3          3 5  6
+--R           (53760a b c  + 71680a b c + 10976a b )x
+--R         + 
+--R                  6 2          5 2          4 4  5          6            5 3  4
+--R           (21504a c  + 107520a b c + 36288a b )x  + (78848a b c + 66304a b )x
+--R         + 
+--R                  7          6 2  3         7   2        8
+--R           (22528a c + 68096a b )x  + 36864a b x  + 8192a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  4 3       3 2 2       2 4         6  10
+--R             (128a c  + 672a b c  + 280a b c + 14a b )x
+--R           + 
+--R                   4   2        3 3        2 5  9
+--R             (3072a b c  + 3584a b c + 448a b )x
+--R           + 
+--R                   5 2         4 2         3 4  8          5            4 3  7
+--R             (3072a c  + 13824a b c + 4032a b )x  + (20480a b c + 15360a b )x
+--R           + 
+--R                    6          5 2  6         6   5        7 4
+--R             (10240a c + 28160a b )x  + 24576a b x  + 8192a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    3   3       2 3 2        5     7  11
+--R             (- 448a b c  - 560a b c  - 84a b c - b )x
+--R           + 
+--R                    4 3        3 2 2        2 4         6  10
+--R             (- 896a c  - 4704a b c  - 1960a b c - 98a b )x
+--R           + 
+--R                      4   2         3 3         2 5  9
+--R             (- 10752a b c  - 12544a b c - 1568a b )x
+--R           + 
+--R                     5 2         4 2         3 4  8
+--R             (- 7168a c  - 32256a b c - 9408a b )x
+--R           + 
+--R                      5            4 3  7            6          5 2  6
+--R             (- 35840a b c - 26880a b )x  + (- 14336a c - 39424a b )x
+--R           + 
+--R                     6   5        7 4
+--R             - 28672a b x  - 8192a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 704
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x^6
+--R 
+--R
+--R         +------------------+
+--R         |   4      3      2
+--R        \|c x  + b x  + a x
+--R   (1)  ---------------------
+--R                   6
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 704
+r0:=1/128*(b^2-4*a*c)*(5*b^2-4*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(a^(7/2)*sqrt(a*x^2+b*x^3+_
+   c*x^4))-1/4*sqrt(a*x^2+b*x^3+c*x^4)/x^5-1/24*b*sqrt(a*x^2+b*x^3+_
+   c*x^4)/(a*x^4)+1/96*(5*b^2-12*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*x^3)-_
+   1/192*b*(15*b^2-52*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^3*x^2)
+--R 
+--R
+--R   (2)
+--R                                   +--------------+
+--R           2 2        2       4  4 |   2                        b x + 2a
+--R       (48a c  - 72a b c + 15b )x \|c x  + b x + a atanh(----------------------)
+--R                                                               +--------------+
+--R                                                           +-+ |   2
+--R                                                         2\|a \|c x  + b x + a
+--R     + 
+--R                    2      3   5         2 2         2       4  4
+--R           (104a b c  - 30b c)x  + (- 48a c  + 124a b c - 30b )x
+--R         + 
+--R               2           3  3          3      2 2  2       3         4
+--R           (40a b c - 10a b )x  + (- 144a c + 4a b )x  - 112a b x - 96a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 +------------------+
+--R         3 3 +-+ |   4      3      2
+--R     384a x \|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        4   3         3 3 2       2 5          7  7
+--R               (- 12288a b c  + 15360a b c  + 768a b c - 960a b )x
+--R             + 
+--R                        5 3        4 2 2         3 4         2 6  6
+--R               (- 24576a c  + 6144a b c  + 38400a b c - 9600a b )x
+--R             + 
+--R                        5   2          4 3          3 5  5
+--R               (- 73728a b c  + 110592a b c - 23040a b )x
+--R             + 
+--R                        6 2         5 2          4 4  4
+--R               (- 49152a c  + 73728a b c - 15360a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                     4 4         2 4 2          6        8  8
+--R               (6144a c  - 11520a b c  + 2304a b c + 120b )x
+--R             + 
+--R                      4   3         3 3 2        2 5           7  7
+--R               (49152a b c  - 61440a b c  - 3072a b c + 3840a b )x
+--R             + 
+--R                      5 3         4 2 2         3 4          2 6  6
+--R               (49152a c  - 12288a b c  - 76800a b c + 19200a b )x
+--R             + 
+--R                      5   2          4 3          3 5  5
+--R               (98304a b c  - 147456a b c + 30720a b )x
+--R             + 
+--R                      6 2         5 2          4 4  4
+--R               (49152a c  - 73728a b c + 15360a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +--------------+
+--R               +-+ |   2
+--R             2\|a \|c x  + b x + a  - b x - 2a
+--R         log(---------------------------------)
+--R                              +-+
+--R                           2x\|a
+--R     + 
+--R                    4   3        3 3 2        2 5          7  7
+--R           (- 13312a b c  - 9984a b c  + 4576a b c - 232a b )x
+--R         + 
+--R                 5 3         4 2 2         3 4         2 6  6
+--R           (6144a c  - 87552a b c  + 12224a b c + 2800a b )x
+--R         + 
+--R                    5   2         4 3          3 5  5
+--R           (- 55296a b c  - 70656a b c + 22080a b )x
+--R         + 
+--R                  6 2          5 2          4 4  4           6            5 3  3
+--R           (61440a c  - 112640a b c + 33152a b )x  + (106496a b c + 34816a b )x
+--R         + 
+--R                   7           6 2  2          7            8
+--R           (147456a c + 135168a b )x  + 212992a b x + 98304a
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                  3 2 3        2 4 2         6       8  8
+--R           (23552a b c  - 4688a b c  - 696a b c + 59b )x
+--R         + 
+--R                  4   3         3 3 2         2 5         7  7
+--R           (40960a b c  + 55296a b c  - 17536a b c - 32a b )x
+--R         + 
+--R                    5 3          4 2 2        3 4          2 6  6
+--R           (- 24576a c  + 178176a b c  - 5248a b c - 10400a b )x
+--R         + 
+--R                  5   2          4 3          3 5  5
+--R           (16384a b c  + 122880a b c - 37120a b )x
+--R         + 
+--R                     6 2         5 2          4 4  4
+--R           (- 122880a c  + 45056a b c - 43136a b )x
+--R         + 
+--R                     6            5 3  3             7           6 2  2
+--R           (- 262144a b c - 81920a b )x  + (- 196608a c - 229376a b )x
+--R         + 
+--R                    7            8
+--R           - 262144a b x - 98304a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  5            4 3  7           6           5 2  6
+--R           (98304a b c + 24576a b )x  + (196608a c + 245760a b )x
+--R         + 
+--R                  6   5          7 4
+--R           589824a b x  + 393216a x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R                6 2         5 2         4 4  8             6            5 3  7
+--R       (- 49152a c  - 73728a b c - 3072a b )x  + (- 393216a b c - 98304a b )x
+--R     + 
+--R                 7           6 2  6          7   5          8 4
+--R       (- 393216a c - 491520a b )x  - 786432a b x  - 393216a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 231
+
+--S 232 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        3   3         2 3 2         5        7  7
+--R               (- 12288a b c  + 15360a b c  + 768a b c - 960b )x
+--R             + 
+--R                        4 3        3 2 2         2 4           6  6
+--R               (- 24576a c  + 6144a b c  + 38400a b c - 9600a b )x
+--R             + 
+--R                        4   2          3 3          2 5  5
+--R               (- 73728a b c  + 110592a b c - 23040a b )x
+--R             + 
+--R                        5 2         4 2          3 4  4
+--R               (- 49152a c  + 73728a b c - 15360a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                 4 4         2 4 2          6        8  8
+--R           (6144a c  - 11520a b c  + 2304a b c + 120b )x
+--R         + 
+--R                  4   3         3 3 2        2 5           7  7
+--R           (49152a b c  - 61440a b c  - 3072a b c + 3840a b )x
+--R         + 
+--R                  5 3         4 2 2         3 4          2 6  6
+--R           (49152a c  - 12288a b c  - 76800a b c + 19200a b )x
+--R         + 
+--R                  5   2          4 3          3 5  5
+--R           (98304a b c  - 147456a b c + 30720a b )x
+--R         + 
+--R                  6 2         5 2          4 4  4
+--R           (49152a c  - 73728a b c + 15360a b )x
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                     4 4         2 4 2          6        8  9
+--R               (6144a c  - 11520a b c  + 2304a b c + 120b )x
+--R             + 
+--R                      4   3         3 3 2        2 5           7  8
+--R               (49152a b c  - 61440a b c  - 3072a b c + 3840a b )x
+--R             + 
+--R                      5 3         4 2 2         3 4          2 6  7
+--R               (49152a c  - 12288a b c  - 76800a b c + 19200a b )x
+--R             + 
+--R                      5   2          4 3          3 5  6
+--R               (98304a b c  - 147456a b c + 30720a b )x
+--R             + 
+--R                      6 2         5 2          4 4  5
+--R               (49152a c  - 73728a b c + 15360a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        3   4         2 3 3         5 2       7   10
+--R               (- 12288a b c  + 15360a b c  + 768a b c  - 960b c)x
+--R             + 
+--R                        4 4        3 2 3         2 4 2          6        8  9
+--R               (- 24576a c  - 6144a b c  + 53760a b c  - 8832a b c - 960b )x
+--R             + 
+--R                         4   3          3 3 2         2 5            7  8
+--R               (- 110592a b c  + 132096a b c  + 16128a b c - 10560a b )x
+--R             + 
+--R                        5 3        4 2 2          3 4          2 6  7
+--R               (- 73728a c  + 6144a b c  + 133632a b c - 32640a b )x
+--R             + 
+--R                         5   2          4 3          3 5  6
+--R               (- 122880a b c  + 184320a b c - 38400a b )x
+--R             + 
+--R                        6 2         5 2          4 4  5
+--R               (- 49152a c  + 73728a b c - 15360a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                        3   3        2 3 2          5        7  7
+--R               (- 13312a b c  - 9984a b c  + 4576a b c - 232b )x
+--R             + 
+--R                     4 3         3 2 2         2 4           6  6
+--R               (6144a c  - 87552a b c  + 12224a b c + 2800a b )x
+--R             + 
+--R                        4   2         3 3          2 5  5
+--R               (- 55296a b c  - 70656a b c + 22080a b )x
+--R             + 
+--R                      5 2          4 2          3 4  4
+--R               (61440a c  - 112640a b c + 33152a b )x
+--R             + 
+--R                       5            4 3  3           6           5 2  2
+--R               (106496a b c + 34816a b )x  + (147456a c + 135168a b )x
+--R             + 
+--R                      6            7
+--R               212992a b x + 98304a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                  3 2 3        2 4 2         6       8  8
+--R           (23552a b c  - 4688a b c  - 696a b c + 59b )x
+--R         + 
+--R                  4   3         3 3 2         2 5         7  7
+--R           (40960a b c  + 55296a b c  - 17536a b c - 32a b )x
+--R         + 
+--R                    5 3          4 2 2        3 4          2 6  6
+--R           (- 24576a c  + 178176a b c  - 5248a b c - 10400a b )x
+--R         + 
+--R                  5   2          4 3          3 5  5
+--R           (16384a b c  + 122880a b c - 37120a b )x
+--R         + 
+--R                     6 2         5 2          4 4  4
+--R           (- 122880a c  + 45056a b c - 43136a b )x
+--R         + 
+--R                     6            5 3  3             7           6 2  2
+--R           (- 262144a b c - 81920a b )x  + (- 196608a c - 229376a b )x
+--R         + 
+--R                    7            8
+--R           - 262144a b x - 98304a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                    3 2 3        2 4 2          6   9
+--R           (- 26624a b c  + 1024a b c  + 1920a b c)x
+--R         + 
+--R                    4   3         3 3 2         2 5           7  8
+--R           (- 40960a b c  - 79872a b c  + 18944a b c + 1920a b )x
+--R         + 
+--R                  5 3          4 2 2         3 4          2 6  7
+--R           (24576a c  - 202752a b c  - 17920a b c + 19840a b )x
+--R         + 
+--R                    5   2          4 3          3 5  6
+--R           (- 16384a b c  - 172032a b c + 52224a b )x
+--R         + 
+--R                   6 2         5 2          4 4  5           6            5 3  4
+--R           (122880a c  - 69632a b c + 50688a b )x  + (262144a b c + 81920a b )x
+--R         + 
+--R                   7           6 2  3          7   2         8
+--R           (196608a c + 229376a b )x  + 262144a b x  + 98304a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                  3   4         2 3 3          5 2       7   10
+--R           (13312a b c  + 16128a b c  - 4928a b c  - 240b c)x
+--R         + 
+--R                   4 4          3 2 3         2 4 2           6        8  9
+--R           (- 6144a c  + 113152a b c  + 15488a b c  - 12448a b c - 240b )x
+--R         + 
+--R                  4   3          3 3 2         2 5           7  8
+--R           (62464a b c  + 223488a b c  - 38976a b c - 7760a b )x
+--R         + 
+--R                    5 3          4 2 2         3 4          2 6  7
+--R           (- 67584a c  + 292352a b c  + 66176a b c - 40928a b )x
+--R         + 
+--R                     5   2          4 3          3 5  6
+--R           (- 112640a b c  + 209920a b c - 74112a b )x
+--R         + 
+--R                     6 2          5 2          4 4  5
+--R           (- 208896a c  - 104448a b c - 75520a b )x
+--R         + 
+--R                     6             5 3  4             7           6 2  3
+--R           (- 466944a b c - 169984a b )x  + (- 245760a c - 348160a b )x
+--R         + 
+--R                    7   2         8
+--R           - 311296a b x  - 98304a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                    5            4 3  7           6           5 2  6
+--R             (98304a b c + 24576a b )x  + (196608a c + 245760a b )x
+--R           + 
+--R                    6   5          7 4
+--R             589824a b x  + 393216a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                      5 2         4 2         3 4  8
+--R             (- 49152a c  - 73728a b c - 3072a b )x
+--R           + 
+--R                       5            4 3  7             6           5 2  6
+--R             (- 393216a b c - 98304a b )x  + (- 393216a c - 491520a b )x
+--R           + 
+--R                      6   5          7 4
+--R             - 786432a b x  - 393216a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       3   4        2 3 3         5 2      7   9
+--R               (- 1024a b c  - 1792a b c  - 448a b c  - 16b c)x
+--R             + 
+--R                       4 4         3 2 3        2 4 2          6       8  8
+--R               (- 2048a c  - 14848a b c  - 9856a b c  - 1120a b c - 16b )x
+--R             + 
+--R                        4   3         3 3 2         2 5          7  7
+--R               (- 33792a b c  - 61696a b c  - 16576a b c - 688a b )x
+--R             + 
+--R                        5 3          4 2 2         3 4         2 6  6
+--R               (- 22528a c  - 157184a b c  - 96384a b c - 8736a b )x
+--R             + 
+--R                         5   2          4 3          3 5  5
+--R               (- 174080a b c  - 271360a b c - 50304a b )x
+--R             + 
+--R                        6 2          5 2           4 4  4
+--R               (- 69632a c  - 395264a b c - 154880a b )x
+--R             + 
+--R                         6             5 3  3            7           6 2  2
+--R               (- 286720a b c - 272384a b )x  + (- 81920a c - 274432a b )x
+--R             + 
+--R                        7            8
+--R               - 147456a b x - 32768a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                4 5        3 2 4        2 4 3         6 2    8   10
+--R           (256a c  + 1792a b c  + 1120a b c  + 112a b c  + b c)x
+--R         + 
+--R                 4   4         3 3 3        2 5 2         7     9  9
+--R           (8448a b c  + 16128a b c  + 4704a b c  + 240a b c + b )x
+--R         + 
+--R                 5 4         4 2 3         3 4 2        2 6          8  8
+--R           (8448a c  + 65280a b c  + 47712a b c  + 6384a b c + 129a b )x
+--R         + 
+--R                  5   3          4 3 2         3 5         2 7  7
+--R           (98304a b c  + 192512a b c  + 57344a b c + 2816a b )x
+--R         + 
+--R                  6 3          5 2 2          4 4          3 6  6
+--R           (49152a c  + 362496a b c  + 239616a b c + 24192a b )x
+--R         + 
+--R                   6   2          5 3           4 5  5
+--R           (319488a b c  + 528384a b c + 105984a b )x
+--R         + 
+--R                   7 2          6 2           5 4  4
+--R           (106496a c  + 634880a b c + 264704a b )x
+--R         + 
+--R                   7             6 3  3          8           7 2  2
+--R           (393216a b c + 393216a b )x  + (98304a c + 344064a b )x
+--R         + 
+--R                  8            9
+--R           163840a b x + 32768a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  4 5        3 2 4        2 4 3         6 2    8   11
+--R           (- 256a c  - 1792a b c  - 1120a b c  - 112a b c  - b c)x
+--R         + 
+--R                   4   4         3 3 3        2 5 2         7     9  10
+--R           (- 8448a b c  - 16128a b c  - 4704a b c  - 240a b c - b )x
+--R         + 
+--R                   5 4         4 2 3         3 4 2        2 6          8  9
+--R           (- 8448a c  - 65280a b c  - 47712a b c  - 6384a b c - 129a b )x
+--R         + 
+--R                    5   3          4 3 2         3 5         2 7  8
+--R           (- 98304a b c  - 192512a b c  - 57344a b c - 2816a b )x
+--R         + 
+--R                    6 3          5 2 2          4 4          3 6  7
+--R           (- 49152a c  - 362496a b c  - 239616a b c - 24192a b )x
+--R         + 
+--R                     6   2          5 3           4 5  6
+--R           (- 319488a b c  - 528384a b c - 105984a b )x
+--R         + 
+--R                     7 2          6 2           5 4  5
+--R           (- 106496a c  - 634880a b c - 264704a b )x
+--R         + 
+--R                     7             6 3  4            8           7 2  3
+--R           (- 393216a b c - 393216a b )x  + (- 98304a c - 344064a b )x
+--R         + 
+--R                    8   2         9
+--R           - 163840a b x  - 32768a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 3   5        2 3 4         5 3      7 2  12
+--R           (1024a b c  + 1792a b c  + 448a b c  + 16b c )x
+--R         + 
+--R                 4 5         3 2 4         2 4 3          6 2      8   11
+--R           (2048a c  + 15872a b c  + 11648a b c  + 1568a b c  + 32b c)x
+--R         + 
+--R                  4   4         3 3 3         2 5 2          7       9  10
+--R           (36864a b c  + 78336a b c  + 26880a b c  + 1824a b c + 16b )x
+--R         + 
+--R                  5 4          4 2 3          3 4 2         2 6          8  9
+--R           (24576a c  + 205824a b c  + 167936a b c  + 26432a b c + 704a b )x
+--R         + 
+--R                   5   3          4 3 2          3 5         2 7  8
+--R           (230400a b c  + 490240a b c  + 163264a b c + 9424a b )x
+--R         + 
+--R                  6 3          5 2 2          4 4          3 6  7
+--R           (92160a c  + 726528a b c  + 522624a b c + 59040a b )x
+--R         + 
+--R                   6   2          5 3           4 5  6
+--R           (530432a b c  + 939008a b c + 205184a b )x
+--R         + 
+--R                   7 2          6 2           5 4  5
+--R           (151552a c  + 956416a b c + 427264a b )x
+--R         + 
+--R                   7             6 3  4           8           7 2  3
+--R           (516096a b c + 546816a b )x  + (114688a c + 421888a b )x
+--R         + 
+--R                  8   2         9
+--R           180224a b x  + 32768a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  4 4        3 2 3        2 4 2         6     8  13
+--R             (256a c  + 1792a b c  + 1120a b c  + 112a b c + b )x
+--R           + 
+--R                   4   3         3 3 2        2 5          7  12
+--R             (8192a b c  + 14336a b c  + 3584a b c + 128a b )x
+--R           + 
+--R                   5 3         4 2 2         3 4         2 6  11
+--R             (8192a c  + 55296a b c  + 32256a b c + 2688a b )x
+--R           + 
+--R                    5   2          4 3          3 5  10
+--R             (81920a b c  + 122880a b c + 21504a b )x
+--R           + 
+--R                    6 2          5 2          4 4  9
+--R             (40960a c  + 225280a b c + 84480a b )x
+--R           + 
+--R                     6             5 3  8          7           6 2  7
+--R             (196608a b c + 180224a b )x  + (65536a c + 212992a b )x
+--R           + 
+--R                    7   6         8 5
+--R             131072a b x  + 32768a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                     3   4        2 3 3         5 2      7   14
+--R             (- 1024a b c  - 1792a b c  - 448a b c  - 16b c)x
+--R           + 
+--R                     4 4         3 2 3        2 4 2          6       8  13
+--R             (- 2048a c  - 14848a b c  - 9856a b c  - 1120a b c - 16b )x
+--R           + 
+--R                      4   3         3 3 2         2 5          7  12
+--R             (- 33792a b c  - 61696a b c  - 16576a b c - 688a b )x
+--R           + 
+--R                      5 3          4 2 2         3 4         2 6  11
+--R             (- 22528a c  - 157184a b c  - 96384a b c - 8736a b )x
+--R           + 
+--R                       5   2          4 3          3 5  10
+--R             (- 174080a b c  - 271360a b c - 50304a b )x
+--R           + 
+--R                      6 2          5 2           4 4  9
+--R             (- 69632a c  - 395264a b c - 154880a b )x
+--R           + 
+--R                       6             5 3  8            7           6 2  7
+--R             (- 286720a b c - 272384a b )x  + (- 81920a c - 274432a b )x
+--R           + 
+--R                      7   6         8 5
+--R             - 147456a b x  - 32768a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 233
+
+)clear all
+
+--S 234 of 704
+t0:=x*(a*x^2+b*x^3+c*x^4)^(3/2)
+--R 
+--R
+--R                             +------------------+
+--R            5      4      3  |   4      3      2
+--R   (1)  (c x  + b x  + a x )\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 704
+r0:=1/112*x*(3*b+14*c*x)*(a*x^2+b*x^3+c*x^4)^(3/2)/c+3/32768*(b^2-4*a*c)^2*_
+   (33*b^4-72*a*b^2*c+16*a^2*c^2)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(c^(13/2)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   1/286720*(1155*b^6-8988*a*b^4*c+18896*a^2*b^2*c^2-6720*a^3*c^3)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/c^5-1/573440*b*(3465*b^6-30660*a*b^4*c+81648*_
+   a^2*b^2*c^2-58816*a^3*c^3)*sqrt(a*x^2+b*x^3+c*x^4)/(c^6*x)-_
+   1/71680*b*(231*b^4-1560*a*b^2*c+2416*a^2*c^2)*x*sqrt(a*x^2+b*x^3+_
+   c*x^4)/c^4+1/35840*(99*b^4-568*a*b^2*c+560*a^2*c^2)*x^2*sqrt(a*x^2+_
+   b*x^3+c*x^4)/c^3-1/4480*x^3*(b*(11*b^2+68*a*c)+10*c*(11*b^2-28*a*c)*_
+   x)*sqrt(a*x^2+b*x^3+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                4 4          3 2 3          2 4 2           6         8
+--R         (26880a c  - 134400a b c  + 117600a b c  - 35280a b c + 3465b )x
+--R      *
+--R          +--------------+
+--R          |   2                        2c x + b
+--R         \|c x  + b x + a atanh(----------------------)
+--R                                      +--------------+
+--R                                  +-+ |   2
+--R                                2\|c \|c x  + b x + a
+--R     + 
+--R                  8 10            7 9             7          2 6  8
+--R           143360c x   + 317440b c x  + (358400a c  + 176640b c )x
+--R         + 
+--R                       6       3 5  7           2 6          2 5       4 4  6
+--R           (402432a b c  - 256b c )x  + (232960a c  - 2304a b c  + 352b c )x
+--R         + 
+--R                   2   5          3 4       5 3  5
+--R           (- 7424a b c  + 3968a b c  - 528b c )x
+--R         + 
+--R                   3 5         2 2 4          4 3       6 2  4
+--R           (- 8960a c  + 18752a b c  - 7824a b c  + 924b c )x
+--R         + 
+--R                  3   4         2 3 3           5 2        7   3
+--R           (52096a b c  - 62752a b c  + 21672a b c  - 2310b c)x
+--R         + 
+--R                    4 4          3 2 3          2 4 2           6         8  2
+--R           (- 26880a c  + 193216a b c  - 199248a b c  + 65940a b c - 6930b )x
+--R         + 
+--R                   4   3          3 3 2         2 5           7
+--R           (117632a b c  - 163296a b c  + 61320a b c - 6930a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                   +------------------+
+--R             6 +-+ |   4      3      2
+--R     1146880c \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 704
+--a0:=integrate(t0,x)
+--E 236
+
+--S 237 of 704
+--m0:=a0-r0
+--E 237
+
+--S 238 of 704
+--d0:=D(m0,x)
+--E 238
+
+)clear all
+
+--S 239 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)
+--R 
+--R
+--R                             +------------------+
+--R            4      3      2  |   4      3      2
+--R   (1)  (c x  + b x  + a x )\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 704
+r0:=1/7*x*(a*x^2+b*x^3+c*x^4)^(3/2)-3/2048*b*(b^2-4*a*c)^2*(3*b^2-4*a*c)*_
+   x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (c^(11/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/17920*b*(105*b^4-728*a*b^2*c+_
+   1168*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/c^4+1/35840*(315*b^6-2520*a*b^4*c+_
+   5488*a^2*b^2*c^2-2048*a^3*c^3)*sqrt(a*x^2+b*x^3+c*x^4)/(c^5*x)+_
+   1/4480*(7*b^2-32*a*c)*(3*b^2-4*a*c)*x*sqrt(a*x^2+b*x^3+c*x^4)/c^3-_
+   1/2240*b*(9*b^2-44*a*c)*x^2*sqrt(a*x^2+b*x^3+c*x^4)/c^2+1/280*x^3*_
+   (b^2+24*a*c+10*b*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                                        +--------------+
+--R               3   3        2 3 2          5        7   |   2
+--R         (6720a b c  - 8400a b c  + 2940a b c - 315b )x\|c x  + b x + a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                 7 9           6 8            6         2 5  7
+--R           10240c x  + 23040b c x  + (26624a c  + 13056b c )x
+--R         + 
+--R                      5      3 4  6          2 5         2 4      4 3  5
+--R           (30592a b c  - 32b c )x  + (18432a c  - 320a b c  + 48b c )x
+--R         + 
+--R                   2   4         3 3      5 2  4
+--R           (- 1216a b c  + 640a b c  - 84b c )x
+--R         + 
+--R                   3 4        2 2 3          4 2       6   3
+--R           (- 2048a c  + 4320a b c  - 1792a b c  + 210b c)x
+--R         + 
+--R                   3   3         2 3 2          5        7  2
+--R           (- 8768a b c  + 13888a b c  - 5460a b c + 630b )x
+--R         + 
+--R                   4 3         3 2 2        2 4          6
+--R           (- 4096a c  + 10976a b c  - 5040a b c + 630a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                 +------------------+
+--R           5 +-+ |   4      3      2
+--R     71680c \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 240
+
+--S 241 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            6   6           5 3 5           4 5 4          3 7 3
+--R                     860160a b c  + 3440640a b c  - 3386880a b c  - 322560a b c
+--R                   + 
+--R                            2 9 2           11         13
+--R                     493920a b c  - 47040a b  c - 4410b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                              6 2 5           5 4 4            4 6 3
+--R                     20643840a b c  - 1720320a b c  - 18063360a b c
+--R                   + 
+--R                             3 8 2          2 10             12
+--R                     5806080a b c  + 188160a b  c - 141120a b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                              7   5            6 3 4            5 5 3
+--R                     20643840a b c  + 67092480a b c  - 79994880a b c
+--R                   + 
+--R                             4 7 2           3 9            2 11
+--R                     5806080a b c  + 7499520a b c - 1270080a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                               7 2 4            6 4 3            5 6 2
+--R                     137625600a b c  - 68812800a b c  - 68812800a b c
+--R                   + 
+--R                              4 8            3 10
+--R                     38707200a b c - 4838400a b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                              8   4             7 3 3             6 5 2
+--R                     68812800a b c  + 103219200a b c  - 206438400a b c
+--R                   + 
+--R                              5 7            4 9
+--R                     79564800a b c - 8870400a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                               8 2 3             7 4 2            6 6
+--R                     165150720a b c  - 206438400a b c  + 72253440a b c
+--R                   + 
+--R                               5 8
+--R                     - 7741440a b
+--R                *
+--R                   x
+--R               + 
+--R                          9   3            8 3 2            7 5            6 7
+--R                 55050240a b c  - 68812800a b c  + 24084480a b c - 2580480a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                           6 2 6           4 6 4          3 8 3         2 10 2
+--R                 - 3010560a b c  + 2822400a b c  - 806400a b c  - 62160a b  c
+--R               + 
+--R                         12        14
+--R                 23520a b  c + 315b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                           7   6            6 3 5            5 5 4
+--R                 - 6021120a b c  - 24084480a b c  + 23708160a b c
+--R               + 
+--R                         4 7 3           3 9 2          2 11            13
+--R                 2257920a b c  - 3457440a b c  + 329280a b  c + 30870a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            7 2 5           6 4 4            5 6 3
+--R                 - 72253440a b c  + 6021120a b c  + 63221760a b c
+--R               + 
+--R                            4 8 2          3 10           2 12
+--R                 - 20321280a b c  - 658560a b  c + 493920a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                            8   5             7 3 4             6 5 3
+--R                 - 48168960a b c  - 156549120a b c  + 186654720a b c
+--R               + 
+--R                            5 7 2            4 9            3 11
+--R                 - 13547520a b c  - 17498880a b c + 2963520a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                             8 2 4             7 4 3             6 6 2
+--R                 - 240844800a b c  + 120422400a b c  + 120422400a b c
+--R               + 
+--R                            5 8            4 10
+--R                 - 67737600a b c + 8467200a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                            9   4             8 3 3             7 5 2
+--R                 - 96337920a b c  - 144506880a b c  + 289013760a b c
+--R               + 
+--R                             6 7             5 9
+--R                 - 111390720a b c + 12418560a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                               9 2 3             8 4 2            7 6
+--R                   - 192675840a b c  + 240844800a b c  - 84295680a b c
+--R                 + 
+--R                           6 8
+--R                   9031680a b
+--R            *
+--R               x
+--R           + 
+--R                        10   3            9 3 2            8 5            7 7
+--R             - 55050240a  b c  + 68812800a b c  - 24084480a b c + 2580480a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                        3   9           2 3 8            5 7         7 6  13
+--R             (- 4587520a b c  - 5734400a b c  - 860160a b c  - 10240b c )x
+--R           + 
+--R                           4 9            3 2 8            2 4 7             6 6
+--R                 - 9175040a c  - 53903360a b c  - 27238400a b c  - 2078720a b c
+--R               + 
+--R                         8 5
+--R                 - 12800b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                             4   8             3 3 7            2 5 6
+--R                 - 128909312a b c  - 197951488a b c  - 42663936a b c
+--R               + 
+--R                             7 5       9 4
+--R                 - 1292288a b c  - 256b c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                            5 8             4 2 7             3 4 6
+--R                 - 88080384a c  - 545857536a b c  - 290877440a b c
+--R               + 
+--R                            2 6 5          8 4       10 3
+--R                 - 22134784a b c  - 2304a b c  + 288b  c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                             5   7             4 3 6             3 5 5
+--R                 - 637091840a b c  - 903024640a b c  - 149940224a b c
+--R               + 
+--R                      2 7 4          9 3       11 2
+--R                 1536a b c  + 1984a b c  - 336b  c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                             6 7              5 2 6             4 4 5
+--R                 - 266076160a c  - 1413672960a b c  - 514698240a b c
+--R               + 
+--R                       3 6 4         2 8 3         10 2       12
+--R                 53760a b c  - 17280a b c  - 560a b  c  + 420b  c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                              6   6             5 3 5          4 5 4
+--R                 - 1090396160a b c  - 985169920a b c  - 483840a b c
+--R               + 
+--R                         3 7 3         2 9 2          11        13
+--R                 - 46080a b c  + 70560a b c  - 6720a b  c - 630b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                             7 6              6 2 5           5 4 4
+--R                 - 330301440a c  - 1060577280a b c  - 1505280a b c
+--R               + 
+--R                           4 6 3           3 8 2         2 10            12
+--R                 - 7375872a b c  + 2546432a b c  + 23520a b  c - 52920a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                             7   5            6 3 4            5 5 3
+--R                 - 603258880a b c  + 39567360a b c  - 49373184a b c
+--R               + 
+--R                         4 7 2           3 9           2 11
+--R                 5146624a b c  + 3951360a b c - 705600a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                             8 5             7 2 4            6 4 3
+--R                 - 146800640a c  + 103219200a b c  - 56770560a b c
+--R               + 
+--R                            5 6 2            4 8            3 10
+--R                 - 45158400a b c  + 26772480a b c - 3386880a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          8   4            7 3 3             6 5 2
+--R                 59637760a b c  + 80281600a b c  - 167444480a b c
+--R               + 
+--R                          5 7            4 9
+--R                 64942080a b c - 7257600a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        8 2 3             7 4 2            6 6            5 8  2
+--R             (151388160a b c  - 189235200a b c  + 66232320a b c - 7096320a b )x
+--R           + 
+--R                       9   3            8 3 2            7 5            6 7
+--R             (55050240a b c  - 68812800a b c  + 24084480a b c - 2580480a b )x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                      3 10           2 2 9             4 8          6 7  14
+--R             (1310720a c   + 6881280a b c  + 2867200a b c  + 143360b c )x
+--R           + 
+--R                       3   9            2 3 8              5 7          7 6  13
+--R             (34406400a b c  + 52183040a b c  + 11038720a b c  + 322560b c )x
+--R           + 
+--R                          4 9             3 2 8             2 4 7
+--R                 34865152a c  + 231899136a b c  + 140091392a b c
+--R               + 
+--R                            6 6          8 5
+--R                 14350336a b c  + 182784b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           4   8             3 3 7             2 5 6
+--R                 366198784a b c  + 631873536a b c  + 160161792a b c
+--R               + 
+--R                           7 5       9 4
+--R                 6268416a b c  - 448b c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                           5 8              4 2 7             3 4 6
+--R                 189005824a c  + 1274699776a b c  + 756224000a b c
+--R               + 
+--R                          2 6 5          8 4       10 3
+--R                 66433024a b c  - 5376a b c  + 672b  c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            5   7              4 3 6             3 5 5
+--R                 1183293440a b c  + 1812285440a b c  + 330781696a b c
+--R               + 
+--R                      2 7 4          9 3        11 2
+--R                 5376a b c  + 6944a b c  - 1176b  c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                           6 7              5 2 6             4 4 5
+--R                 412876800a c  + 2325442560a b c  + 906644480a b c
+--R               + 
+--R                        3 6 4          2 8 3          10 2        12
+--R                 376320a b c  - 120960a b c  - 3920a b  c  + 2940b  c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            6   6              5 3 5            4 5 4
+--R                 1524490240a b c  + 1442918400a b c  + 10547712a b c
+--R               + 
+--R                        3 7 3           2 9 2            11         13
+--R                 114176a b c  - 1240288a b c  + 146160a b  c + 8190b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                           7 6              6 2 5           5 4 4
+--R                 403701760a c  + 1315758080a b c  + 8816640a b c
+--R               + 
+--R                          4 6 3            3 8 2         2 10             12
+--R                 33567744a b c  - 12018944a b c  + 23520a b  c + 229320a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                           7   5             6 3 4             5 5 3
+--R                 653721600a b c  - 104939520a b c  + 132808704a b c
+--R               + 
+--R                            4 7 2            3 9            2 11
+--R                 - 15110144a b c  - 10080000a b c + 1834560a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                           8 5             7 2 4             6 4 3
+--R                 146800640a c  - 194969600a b c  + 109527040a b c
+--R               + 
+--R                          5 6 2            4 8            3 10
+--R                 82432000a b c  - 49566720a b c + 6289920a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            8   4             7 3 3             6 5 2
+--R                 - 87162880a b c  - 114688000a b c  + 241418240a b c
+--R               + 
+--R                            5 7             4 9
+--R                 - 93757440a b c + 10483200a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                               8 2 3             7 4 2            6 6
+--R                   - 178913280a b c  + 223641600a b c  - 78274560a b c
+--R                 + 
+--R                           5 8
+--R                   8386560a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         9   3            8 3 2            7 5            6 7
+--R             (- 55050240a b c  + 68812800a b c  - 24084480a b c + 2580480a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                      3 8            2 2 7              4 6           6 5  6
+--R             (9175040a c  + 48168960a b c  + 20070400a b c  + 1003520b c )x
+--R           + 
+--R                        3   7             2 3 6              5 5  5
+--R             (220200960a b c  + 256901120a b c  + 32112640a b c )x
+--R           + 
+--R                        4 7             3 2 6             2 4 5  4
+--R             (220200960a c  + 990904320a b c  + 289013760a b c )x
+--R           + 
+--R                         4   6              3 3 5  3
+--R             (1468006400a b c  + 1101004800a b c )x
+--R           + 
+--R                        5 6              4 2 5  2              5   5
+--R             (734003200a c  + 2018508800a b c )x  + 1761607680a b c x
+--R           + 
+--R                       6 5
+--R             587202560a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                         3   8            2 3 7             5 6         7 5  7
+--R             (- 32112640a b c  - 40140800a b c  - 6021120a b c  - 71680b c )x
+--R           + 
+--R                            4 8             3 2 7             2 4 6
+--R                 - 64225280a c  - 337182720a b c  - 140492800a b c
+--R               + 
+--R                             6 5
+--R                 - 7024640a b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          4   7             3 3 6             2 5 5  5
+--R             (- 770703360a b c  - 899153920a b c  - 112394240a b c )x
+--R           + 
+--R                          5 7              4 2 6             3 4 5  4
+--R             (- 513802240a c  - 2312110080a b c  - 674365440a b c )x
+--R           + 
+--R                           5   6              4 3 5  3
+--R             (- 2569011200a b c  - 1926758400a b c )x
+--R           + 
+--R                           6 6              5 2 5  2              6   5
+--R             (- 1027604480a c  - 2825912320a b c )x  - 2055208960a b c x
+--R           + 
+--R                         7 5
+--R             - 587202560a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                            6   6           5 3 5           4 5 4          3 7 3
+--R                     860160a b c  + 3440640a b c  - 3386880a b c  - 322560a b c
+--R                   + 
+--R                            2 9 2           11         13
+--R                     493920a b c  - 47040a b  c - 4410b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                              6 2 5           5 4 4            4 6 3
+--R                     20643840a b c  - 1720320a b c  - 18063360a b c
+--R                   + 
+--R                             3 8 2          2 10             12
+--R                     5806080a b c  + 188160a b  c - 141120a b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                              7   5            6 3 4            5 5 3
+--R                     20643840a b c  + 67092480a b c  - 79994880a b c
+--R                   + 
+--R                             4 7 2           3 9            2 11
+--R                     5806080a b c  + 7499520a b c - 1270080a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                               7 2 4            6 4 3            5 6 2
+--R                     137625600a b c  - 68812800a b c  - 68812800a b c
+--R                   + 
+--R                              4 8            3 10
+--R                     38707200a b c - 4838400a b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                              8   4             7 3 3             6 5 2
+--R                     68812800a b c  + 103219200a b c  - 206438400a b c
+--R                   + 
+--R                              5 7            4 9
+--R                     79564800a b c - 8870400a b
+--R                *
+--R                    2
+--R                   x
+--R               + 
+--R                               8 2 3             7 4 2            6 6
+--R                     165150720a b c  - 206438400a b c  + 72253440a b c
+--R                   + 
+--R                               5 8
+--R                     - 7741440a b
+--R                *
+--R                   x
+--R               + 
+--R                          9   3            8 3 2            7 5            6 7
+--R                 55050240a b c  - 68812800a b c  + 24084480a b c - 2580480a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                           6 2 6           4 6 4          3 8 3         2 10 2
+--R                 - 3010560a b c  + 2822400a b c  - 806400a b c  - 62160a b  c
+--R               + 
+--R                         12        14
+--R                 23520a b  c + 315b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                           7   6            6 3 5            5 5 4
+--R                 - 6021120a b c  - 24084480a b c  + 23708160a b c
+--R               + 
+--R                         4 7 3           3 9 2          2 11            13
+--R                 2257920a b c  - 3457440a b c  + 329280a b  c + 30870a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            7 2 5           6 4 4            5 6 3
+--R                 - 72253440a b c  + 6021120a b c  + 63221760a b c
+--R               + 
+--R                            4 8 2          3 10           2 12
+--R                 - 20321280a b c  - 658560a b  c + 493920a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                            8   5             7 3 4             6 5 3
+--R                 - 48168960a b c  - 156549120a b c  + 186654720a b c
+--R               + 
+--R                            5 7 2            4 9            3 11
+--R                 - 13547520a b c  - 17498880a b c + 2963520a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                             8 2 4             7 4 3             6 6 2
+--R                 - 240844800a b c  + 120422400a b c  + 120422400a b c
+--R               + 
+--R                            5 8            4 10
+--R                 - 67737600a b c + 8467200a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                            9   4             8 3 3             7 5 2
+--R                 - 96337920a b c  - 144506880a b c  + 289013760a b c
+--R               + 
+--R                             6 7             5 9
+--R                 - 111390720a b c + 12418560a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                               9 2 3             8 4 2            7 6
+--R                   - 192675840a b c  + 240844800a b c  - 84295680a b c
+--R                 + 
+--R                           6 8
+--R                   9031680a b
+--R            *
+--R               x
+--R           + 
+--R                        10   3            9 3 2            8 5            7 7
+--R             - 55050240a  b c  + 68812800a b c  - 24084480a b c + 2580480a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                        3   9           2 3 8            5 7        7 6  13
+--R             (- 2293760a b c  - 2867200a b c  - 430080a b c  - 5120b c )x
+--R           + 
+--R                           4 9            3 2 8            2 4 7             6 6
+--R                 - 4587520a c  - 26951680a b c  - 13619200a b c  - 1039360a b c
+--R               + 
+--R                        8 5
+--R                 - 6400b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            4   8            3 3 7            2 5 6
+--R                 - 64454656a b c  - 98975744a b c  - 21331968a b c
+--R               + 
+--R                            7 5       9 4
+--R                 - 646144a b c  - 128b c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                            5 8             4 2 7             3 4 6
+--R                 - 44040192a c  - 272928768a b c  - 145438720a b c
+--R               + 
+--R                            2 6 5          8 4       10 3
+--R                 - 11067392a b c  - 1152a b c  + 144b  c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                             5   7             4 3 6            3 5 5
+--R                 - 318545920a b c  - 451512320a b c  - 74970112a b c
+--R               + 
+--R                     2 7 4         9 3       11 2
+--R                 768a b c  + 992a b c  - 168b  c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                             6 7             5 2 6             4 4 5
+--R                 - 133038080a c  - 706836480a b c  - 257349120a b c
+--R               + 
+--R                       3 6 4        2 8 3         10 2       12
+--R                 26880a b c  - 8640a b c  - 280a b  c  + 210b  c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             6   6             5 3 5          4 5 4
+--R                 - 545198080a b c  - 492584960a b c  - 241920a b c
+--R               + 
+--R                         3 7 3         2 9 2          11        13
+--R                 - 23040a b c  + 35280a b c  - 3360a b  c - 315b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                             7 6             6 2 5          5 4 4
+--R                 - 165150720a c  - 530288640a b c  - 752640a b c
+--R               + 
+--R                           4 6 3           3 8 2         2 10            12
+--R                 - 3687936a b c  + 1273216a b c  + 11760a b  c - 26460a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                             7   5            6 3 4            5 5 3
+--R                 - 301629440a b c  + 19783680a b c  - 24686592a b c
+--R               + 
+--R                         4 7 2           3 9           2 11
+--R                 2573312a b c  + 1975680a b c - 352800a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                            8 5            7 2 4            6 4 3
+--R                 - 73400320a c  + 51609600a b c  - 28385280a b c
+--R               + 
+--R                            5 6 2            4 8            3 10
+--R                 - 22579200a b c  + 13386240a b c - 1693440a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          8   4            7 3 3            6 5 2
+--R                 29818880a b c  + 40140800a b c  - 83722240a b c
+--R               + 
+--R                          5 7            4 9
+--R                 32471040a b c - 3628800a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                       8 2 3            7 4 2            6 6            5 8  2
+--R             (75694080a b c  - 94617600a b c  + 33116160a b c - 3548160a b )x
+--R           + 
+--R                       9   3            8 3 2            7 5            6 7
+--R             (27525120a b c  - 34406400a b c  + 12042240a b c - 1290240a b )x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                     3 10           2 2 9             4 8         6 7  14
+--R             (655360a c   + 3440640a b c  + 1433600a b c  + 71680b c )x
+--R           + 
+--R                       3   9            2 3 8             5 7          7 6  13
+--R             (17203200a b c  + 26091520a b c  + 5519360a b c  + 161280b c )x
+--R           + 
+--R                          4 9             3 2 8            2 4 7             6 6
+--R                 17432576a c  + 115949568a b c  + 70045696a b c  + 7175168a b c
+--R               + 
+--R                       8 5
+--R                 91392b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           4   8             3 3 7            2 5 6
+--R                 183099392a b c  + 315936768a b c  + 80080896a b c
+--R               + 
+--R                           7 5       9 4
+--R                 3134208a b c  - 224b c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                          5 8             4 2 7             3 4 6
+--R                 94502912a c  + 637349888a b c  + 378112000a b c
+--R               + 
+--R                          2 6 5          8 4       10 3
+--R                 33216512a b c  - 2688a b c  + 336b  c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           5   7             4 3 6             3 5 5
+--R                 591646720a b c  + 906142720a b c  + 165390848a b c
+--R               + 
+--R                      2 7 4          9 3       11 2
+--R                 2688a b c  + 3472a b c  - 588b  c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                           6 7              5 2 6             4 4 5
+--R                 206438400a c  + 1162721280a b c  + 453322240a b c
+--R               + 
+--R                        3 6 4         2 8 3          10 2        12
+--R                 188160a b c  - 60480a b c  - 1960a b  c  + 1470b  c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                           6   6             5 3 5           4 5 4         3 7 3
+--R                 762245120a b c  + 721459200a b c  + 5273856a b c  + 57088a b c
+--R               + 
+--R                          2 9 2           11         13
+--R                 - 620144a b c  + 73080a b  c + 4095b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                           7 6             6 2 5           5 4 4
+--R                 201850880a c  + 657879040a b c  + 4408320a b c
+--R               + 
+--R                          4 6 3           3 8 2         2 10             12
+--R                 16783872a b c  - 6009472a b c  + 11760a b  c + 114660a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                           7   5            6 3 4            5 5 3
+--R                 326860800a b c  - 52469760a b c  + 66404352a b c
+--R               + 
+--R                           4 7 2           3 9           2 11
+--R                 - 7555072a b c  - 5040000a b c + 917280a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                          8 5            7 2 4            6 4 3            5 6 2
+--R                 73400320a c  - 97484800a b c  + 54763520a b c  + 41216000a b c
+--R               + 
+--R                            4 8            3 10
+--R                 - 24783360a b c + 3144960a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            8   4            7 3 3             6 5 2
+--R                 - 43581440a b c  - 57344000a b c  + 120709120a b c
+--R               + 
+--R                            5 7            4 9
+--R                 - 46878720a b c + 5241600a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                              8 2 3             7 4 2            6 6
+--R                   - 89456640a b c  + 111820800a b c  - 39137280a b c
+--R                 + 
+--R                           5 8
+--R                   4193280a b
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                         9   3            8 3 2            7 5            6 7
+--R             (- 27525120a b c  + 34406400a b c  - 12042240a b c + 1290240a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                      3 8            2 2 7              4 6          6 5  6
+--R             (4587520a c  + 24084480a b c  + 10035200a b c  + 501760b c )x
+--R           + 
+--R                        3   7             2 3 6              5 5  5
+--R             (110100480a b c  + 128450560a b c  + 16056320a b c )x
+--R           + 
+--R                        4 7             3 2 6             2 4 5  4
+--R             (110100480a c  + 495452160a b c  + 144506880a b c )x
+--R           + 
+--R                        4   6             3 3 5  3
+--R             (734003200a b c  + 550502400a b c )x
+--R           + 
+--R                        5 6              4 2 5  2             5   5
+--R             (367001600a c  + 1009254400a b c )x  + 880803840a b c x
+--R           + 
+--R                       6 5
+--R             293601280a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                         3   8            2 3 7             5 6         7 5  7
+--R             (- 16056320a b c  - 20070400a b c  - 3010560a b c  - 35840b c )x
+--R           + 
+--R                              4 8             3 2 7            2 4 6
+--R                   - 32112640a c  - 168591360a b c  - 70246400a b c
+--R                 + 
+--R                               6 5
+--R                   - 3512320a b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          4   7             3 3 6            2 5 5  5
+--R             (- 385351680a b c  - 449576960a b c  - 56197120a b c )x
+--R           + 
+--R                          5 7              4 2 6             3 4 5  4
+--R             (- 256901120a c  - 1156055040a b c  - 337182720a b c )x
+--R           + 
+--R                           5   6             4 3 5  3
+--R             (- 1284505600a b c  - 963379200a b c )x
+--R           + 
+--R                          6 6              5 2 5  2              6   5
+--R             (- 513802240a c  - 1412956160a b c )x  - 1027604480a b c x
+--R           + 
+--R                         7 5
+--R             - 293601280a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 241
+
+--S 242 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          6   6           5 3 5           4 5 4          3 7 3
+--R                   860160a b c  + 3440640a b c  - 3386880a b c  - 322560a b c
+--R                 + 
+--R                          2 9 2           11         13
+--R                   493920a b c  - 47040a b  c - 4410b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            6 2 5           5 4 4            4 6 3
+--R                   20643840a b c  - 1720320a b c  - 18063360a b c
+--R                 + 
+--R                           3 8 2          2 10             12
+--R                   5806080a b c  + 188160a b  c - 141120a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                            7   5            6 3 4            5 5 3
+--R                   20643840a b c  + 67092480a b c  - 79994880a b c
+--R                 + 
+--R                           4 7 2           3 9            2 11
+--R                   5806080a b c  + 7499520a b c - 1270080a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             7 2 4            6 4 3            5 6 2
+--R                   137625600a b c  - 68812800a b c  - 68812800a b c
+--R                 + 
+--R                            4 8            3 10
+--R                   38707200a b c - 4838400a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                            8   4             7 3 3             6 5 2
+--R                   68812800a b c  + 103219200a b c  - 206438400a b c
+--R                 + 
+--R                            5 7            4 9
+--R                   79564800a b c - 8870400a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                               8 2 3             7 4 2            6 6
+--R                     165150720a b c  - 206438400a b c  + 72253440a b c
+--R                   + 
+--R                               5 8
+--R                     - 7741440a b
+--R              *
+--R                 x
+--R             + 
+--R                        9   3            8 3 2            7 5            6 7
+--R               55050240a b c  - 68812800a b c  + 24084480a b c - 2580480a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                         6 2 6           4 6 4          3 8 3         2 10 2
+--R               - 3010560a b c  + 2822400a b c  - 806400a b c  - 62160a b  c
+--R             + 
+--R                       12        14
+--R               23520a b  c + 315b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                         7   6            6 3 5            5 5 4           4 7 3
+--R               - 6021120a b c  - 24084480a b c  + 23708160a b c  + 2257920a b c
+--R             + 
+--R                         3 9 2          2 11            13
+--R               - 3457440a b c  + 329280a b  c + 30870a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          7 2 5           6 4 4            5 6 3
+--R               - 72253440a b c  + 6021120a b c  + 63221760a b c
+--R             + 
+--R                          4 8 2          3 10           2 12
+--R               - 20321280a b c  - 658560a b  c + 493920a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                          8   5             7 3 4             6 5 3
+--R               - 48168960a b c  - 156549120a b c  + 186654720a b c
+--R             + 
+--R                          5 7 2            4 9            3 11
+--R               - 13547520a b c  - 17498880a b c + 2963520a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                           8 2 4             7 4 3             6 6 2
+--R               - 240844800a b c  + 120422400a b c  + 120422400a b c
+--R             + 
+--R                          5 8            4 10
+--R               - 67737600a b c + 8467200a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                          9   4             8 3 3             7 5 2
+--R               - 96337920a b c  - 144506880a b c  + 289013760a b c
+--R             + 
+--R                           6 7             5 9
+--R               - 111390720a b c + 12418560a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        9 2 3             8 4 2            7 6            6 8
+--R           (- 192675840a b c  + 240844800a b c  - 84295680a b c + 9031680a b )x
+--R         + 
+--R                      10   3            9 3 2            8 5            7 7
+--R           - 55050240a  b c  + 68812800a b c  - 24084480a b c + 2580480a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                           6 2 6           4 6 4          3 8 3         2 10 2
+--R                   3010560a b c  - 2822400a b c  + 806400a b c  + 62160a b  c
+--R                 + 
+--R                             12        14
+--R                   - 23520a b  c - 315b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           7   6            6 3 5            5 5 4
+--R                   6021120a b c  + 24084480a b c  - 23708160a b c
+--R                 + 
+--R                             4 7 3           3 9 2          2 11            13
+--R                   - 2257920a b c  + 3457440a b c  - 329280a b  c - 30870a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            7 2 5           6 4 4            5 6 3
+--R                   72253440a b c  - 6021120a b c  - 63221760a b c
+--R                 + 
+--R                            4 8 2          3 10           2 12
+--R                   20321280a b c  + 658560a b  c - 493920a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            8   5             7 3 4             6 5 3
+--R                   48168960a b c  + 156549120a b c  - 186654720a b c
+--R                 + 
+--R                            5 7 2            4 9            3 11
+--R                   13547520a b c  + 17498880a b c - 2963520a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             8 2 4             7 4 3             6 6 2
+--R                   240844800a b c  - 120422400a b c  - 120422400a b c
+--R                 + 
+--R                            5 8            4 10
+--R                   67737600a b c - 8467200a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            9   4             8 3 3             7 5 2
+--R                   96337920a b c  + 144506880a b c  - 289013760a b c
+--R                 + 
+--R                             6 7             5 9
+--R                   111390720a b c - 12418560a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                               9 2 3             8 4 2            7 6
+--R                     192675840a b c  - 240844800a b c  + 84295680a b c
+--R                   + 
+--R                               6 8
+--R                     - 9031680a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                       10   3            9 3 2            8 5            7 7
+--R             (55050240a  b c  - 68812800a b c  + 24084480a b c - 2580480a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                            6   7           5 3 6           4 5 5          3 7 4
+--R                   - 860160a b c  - 3440640a b c  + 3386880a b c  + 322560a b c
+--R                 + 
+--R                            2 9 3           11 2        13
+--R                   - 493920a b c  + 47040a b  c  + 4410b  c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                              6 2 6           5 4 5            4 6 4
+--R                   - 21504000a b c  - 1720320a b c  + 21450240a b c
+--R                 + 
+--R                             3 8 3          2 10 2            12         14
+--R                   - 5483520a b c  - 682080a b  c  + 188160a b  c + 4410b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              7   6            6 3 5            5 5 4
+--R                   - 21504000a b c  - 91176960a b c  + 85102080a b c
+--R                 + 
+--R                          4 7 3            3 9 2           2 11             13
+--R                 12579840a b c  - 13799520a b c  + 1128960a b  c + 145530a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                               7 2 5           6 4 4             5 6 3
+--R                   - 178913280a b c  + 3440640a b c  + 166871040a b c
+--R                 + 
+--R                              4 8 2           3 10            2 12
+--R                   - 50319360a b c  - 2849280a b  c + 1411200a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              8   5             7 3 4             6 5 3
+--R                   - 89456640a b c  - 307937280a b c  + 355246080a b c
+--R                 + 
+--R                              5 7 2            4 9            3 11
+--R                   - 16558080a b c  - 37336320a b c + 6108480a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                               8 2 4             7 4 3             6 6 2
+--R                   - 371589120a b c  + 172032000a b c  + 202997760a b c
+--R                 + 
+--R                               5 8             4 10
+--R                   - 110530560a b c + 13708800a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               9   4             8 3 3             7 5 2
+--R                   - 123863040a b c  - 199557120a b c  + 388792320a b c
+--R                 + 
+--R                               6 7             5 9
+--R                   - 149237760a b c + 16611840a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                               9 2 3             8 4 2            7 6
+--R                   - 220200960a b c  + 275251200a b c  - 96337920a b c
+--R                 + 
+--R                            6 8
+--R                   10321920a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         10   3            9 3 2            8 5            7 7
+--R             (- 55050240a  b c  + 68812800a b c  - 24084480a b c + 2580480a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                          3   9           2 3 8            5 7         7 6  13
+--R               (- 4587520a b c  - 5734400a b c  - 860160a b c  - 10240b c )x
+--R             + 
+--R                             4 9            3 2 8            2 4 7
+--R                   - 9175040a c  - 53903360a b c  - 27238400a b c
+--R                 + 
+--R                               6 6         8 5
+--R                   - 2078720a b c  - 12800b c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                               4   8             3 3 7            2 5 6
+--R                   - 128909312a b c  - 197951488a b c  - 42663936a b c
+--R                 + 
+--R                               7 5       9 4
+--R                   - 1292288a b c  - 256b c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                              5 8             4 2 7             3 4 6
+--R                   - 88080384a c  - 545857536a b c  - 290877440a b c
+--R                 + 
+--R                              2 6 5          8 4       10 3
+--R                   - 22134784a b c  - 2304a b c  + 288b  c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                               5   7             4 3 6             3 5 5
+--R                   - 637091840a b c  - 903024640a b c  - 149940224a b c
+--R                 + 
+--R                        2 7 4          9 3       11 2
+--R                   1536a b c  + 1984a b c  - 336b  c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                               6 7              5 2 6             4 4 5
+--R                   - 266076160a c  - 1413672960a b c  - 514698240a b c
+--R                 + 
+--R                         3 6 4         2 8 3         10 2       12
+--R                   53760a b c  - 17280a b c  - 560a b  c  + 420b  c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                6   6             5 3 5          4 5 4
+--R                   - 1090396160a b c  - 985169920a b c  - 483840a b c
+--R                 + 
+--R                           3 7 3         2 9 2          11        13
+--R                   - 46080a b c  + 70560a b c  - 6720a b  c - 630b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                               7 6              6 2 5           5 4 4
+--R                   - 330301440a c  - 1060577280a b c  - 1505280a b c
+--R                 + 
+--R                             4 6 3           3 8 2         2 10            12
+--R                   - 7375872a b c  + 2546432a b c  + 23520a b  c - 52920a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                               7   5            6 3 4            5 5 3
+--R                   - 603258880a b c  + 39567360a b c  - 49373184a b c
+--R                 + 
+--R                           4 7 2           3 9           2 11
+--R                   5146624a b c  + 3951360a b c - 705600a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                               8 5             7 2 4            6 4 3
+--R                   - 146800640a c  + 103219200a b c  - 56770560a b c
+--R                 + 
+--R                              5 6 2            4 8            3 10
+--R                   - 45158400a b c  + 26772480a b c - 3386880a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            8   4            7 3 3             6 5 2
+--R                   59637760a b c  + 80281600a b c  - 167444480a b c
+--R                 + 
+--R                            5 7            4 9
+--R                   64942080a b c - 7257600a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                               8 2 3             7 4 2            6 6
+--R                     151388160a b c  - 189235200a b c  + 66232320a b c
+--R                   + 
+--R                               5 8
+--R                     - 7096320a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         9   3            8 3 2            7 5            6 7
+--R               (55050240a b c  - 68812800a b c  + 24084480a b c - 2580480a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                        3 10           2 2 9             4 8          6 7  14
+--R               (1310720a c   + 6881280a b c  + 2867200a b c  + 143360b c )x
+--R             + 
+--R                           3   9            2 3 8              5 7          7 6
+--R                 (34406400a b c  + 52183040a b c  + 11038720a b c  + 322560b c )
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                            4 9             3 2 8             2 4 7
+--R                   34865152a c  + 231899136a b c  + 140091392a b c
+--R                 + 
+--R                              6 6          8 5
+--R                   14350336a b c  + 182784b c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             4   8             3 3 7             2 5 6
+--R                   366198784a b c  + 631873536a b c  + 160161792a b c
+--R                 + 
+--R                             7 5       9 4
+--R                   6268416a b c  - 448b c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                             5 8              4 2 7             3 4 6
+--R                   189005824a c  + 1274699776a b c  + 756224000a b c
+--R                 + 
+--R                            2 6 5          8 4       10 3
+--R                   66433024a b c  - 5376a b c  + 672b  c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              5   7              4 3 6             3 5 5
+--R                   1183293440a b c  + 1812285440a b c  + 330781696a b c
+--R                 + 
+--R                        2 7 4          9 3        11 2
+--R                   5376a b c  + 6944a b c  - 1176b  c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                             6 7              5 2 6             4 4 5
+--R                   412876800a c  + 2325442560a b c  + 906644480a b c
+--R                 + 
+--R                          3 6 4          2 8 3          10 2        12
+--R                   376320a b c  - 120960a b c  - 3920a b  c  + 2940b  c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              6   6              5 3 5            4 5 4
+--R                   1524490240a b c  + 1442918400a b c  + 10547712a b c
+--R                 + 
+--R                          3 7 3           2 9 2            11         13
+--R                   114176a b c  - 1240288a b c  + 146160a b  c + 8190b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                             7 6              6 2 5           5 4 4
+--R                   403701760a c  + 1315758080a b c  + 8816640a b c
+--R                 + 
+--R                            4 6 3            3 8 2         2 10             12
+--R                   33567744a b c  - 12018944a b c  + 23520a b  c + 229320a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             7   5             6 3 4             5 5 3
+--R                   653721600a b c  - 104939520a b c  + 132808704a b c
+--R                 + 
+--R                              4 7 2            3 9            2 11
+--R                   - 15110144a b c  - 10080000a b c + 1834560a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             8 5             7 2 4             6 4 3
+--R                   146800640a c  - 194969600a b c  + 109527040a b c
+--R                 + 
+--R                            5 6 2            4 8            3 10
+--R                   82432000a b c  - 49566720a b c + 6289920a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              8   4             7 3 3             6 5 2
+--R                   - 87162880a b c  - 114688000a b c  + 241418240a b c
+--R                 + 
+--R                              5 7             4 9
+--R                   - 93757440a b c + 10483200a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                               8 2 3             7 4 2            6 6
+--R                   - 178913280a b c  + 223641600a b c  - 78274560a b c
+--R                 + 
+--R                           5 8
+--R                   8386560a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         9   3            8 3 2            7 5            6 7
+--R             (- 55050240a b c  + 68812800a b c  - 24084480a b c + 2580480a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      3 10           2 2 9             4 8          6 7  15
+--R           (- 1310720a c   - 6881280a b c  - 2867200a b c  - 143360b c )x
+--R         + 
+--R                       3   9            2 3 8              5 7          7 6  14
+--R           (- 34406400a b c  - 52183040a b c  - 11038720a b c  - 322560b c )x
+--R         + 
+--R                          4 9             3 2 8             2 4 7
+--R               - 34865152a c  - 231899136a b c  - 140091392a b c
+--R             + 
+--R                            6 6          8 5
+--R               - 14350336a b c  - 182784b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                           4   8             3 3 7             2 5 6
+--R               - 366198784a b c  - 631873536a b c  - 160161792a b c
+--R             + 
+--R                           7 5       9 4
+--R               - 6268416a b c  + 448b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           5 8              4 2 7             3 4 6
+--R               - 189005824a c  - 1274699776a b c  - 756224000a b c
+--R             + 
+--R                          2 6 5          8 4       10 3
+--R               - 66433024a b c  + 5376a b c  - 672b  c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                            5   7              4 3 6             3 5 5
+--R               - 1183293440a b c  - 1812285440a b c  - 330781696a b c
+--R             + 
+--R                      2 7 4          9 3        11 2
+--R               - 5376a b c  - 6944a b c  + 1176b  c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                           6 7              5 2 6             4 4 5
+--R               - 412876800a c  - 2325442560a b c  - 906644480a b c
+--R             + 
+--R                        3 6 4          2 8 3          10 2        12
+--R               - 376320a b c  + 120960a b c  + 3920a b  c  - 2940b  c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                            6   6              5 3 5            4 5 4
+--R               - 1522655232a b c  - 1445541888a b c  - 14092288a b c
+--R             + 
+--R                       3 7 3           2 9 2            11         13
+--R               1508096a b c  + 1299872a b c  - 194040a b  c - 8820b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                           7 6              6 2 5            5 4 4
+--R               - 400031744a c  - 1306324992a b c  - 47903744a b c
+--R             + 
+--R                          4 6 3            3 8 2          2 10             12
+--R               - 31535616a b c  + 17858176a b c  - 764400a b  c - 291060a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                           7   5            6 3 4             5 5 3
+--R               - 609681408a b c  + 38305792a b c  - 209879040a b c
+--R             + 
+--R                        4 7 2            3 9            2 11
+--R               54347776a b c  + 10080000a b c - 2822400a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           8 5             7 2 4             6 4 3
+--R               - 117440512a c  + 248414208a b c  - 388907008a b c
+--R             + 
+--R                          5 6 2            4 8             3 10
+--R               - 27639808a b c  + 76661760a b c - 12216960a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                         8   4             7 3 3             6 5 2
+--R               233963520a b c  - 168591360a b c  - 355819520a b c
+--R             + 
+--R                         5 7             4 9
+--R               206653440a b c - 27417600a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        9 4             8 2 3             7 4 2             6 6
+--R               58720256a c  + 183042048a b c  - 584105984a b c  + 267939840a b c
+--R             + 
+--R                          5 8
+--R               - 33223680a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      9   3             8 3 2             7 5             6 7  2
+--R           (172490752a b c  - 383516672a b c  + 168591360a b c - 20643840a b )x
+--R         + 
+--R                     10 3            9 2 2            8 4            7 6
+--R           (33554432a  c  - 89915392a b c  + 41287680a b c - 5160960a b )x
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                    3   10           2 3 9            5 8         7 7  16
+--R           (4587520a b c   + 5734400a b c  + 860160a b c  + 10240b c )x
+--R         + 
+--R                       4 10            3 2 9            2 4 8             6 7
+--R               9175040a c   + 58490880a b c  + 32972800a b c  + 2938880a b c
+--R             + 
+--R                     8 6
+--R               23040b c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                         4   9             3 3 8            2 5 7
+--R               142671872a b c  + 257589248a b c  + 70762496a b c
+--R             + 
+--R                         7 6         9 5
+--R               3381248a b c  + 13056b c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        5 9             4 2 8             3 4 7            2 6 6
+--R               97255424a c  + 728670208a b c  + 516067328a b c  + 66877440a b c
+--R             + 
+--R                         8 5      10 4
+--R               1307392a b c  - 32b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         5   8              4 3 7             3 5 6
+--R               854081536a b c  + 1646833664a b c  + 483481600a b c
+--R             + 
+--R                        2 7 5         9 4      11 3
+--R               23425536a b c  + 576a b c  + 48b  c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         6 8              5 2 7              4 4 6
+--R               354156544a c  + 2596622336a b c  + 1708600320a b c
+--R             + 
+--R                         3 6 5         2 8 4          10 3      12 2
+--R               172021248a b c  + 18048a b c  - 1712a b  c  - 84b  c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          6   7              5 3 6             4 5 5
+--R               1993564160a b c  + 3301867520a b c  + 665122304a b c
+--R             + 
+--R                      3 7 4         2 9 3          11 2       13
+--R               - 9216a b c  - 55264a b c  + 7616a b  c  + 210b  c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         7 7              6 2 6              5 4 5
+--R               595853312a c  + 3563298816a b c  + 1506957312a b c
+--R             + 
+--R                     4 6 4           3 8 3         2 10 2           12        14
+--R             7515648a b c  - 3317248a b c  + 12320a b  c  + 68040a b  c + 630b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                          7   6              6 3 5            5 5 4
+--R               2010849280a b c  + 2023870464a b c  + 78966272a b c
+--R             + 
+--R                         4 7 3           3 9 2           2 11            13
+--R               - 9225728a b c  - 7402528a b c  + 1076880a b  c + 62370a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         8 6              7 2 5             6 4 4
+--R               463994880a c  + 1523781632a b c  + 163064832a b c
+--R             + 
+--R                         5 6 3            4 8 2           3 10            2 12
+--R               100154880a b c  - 58122624a b c  + 2058000a b  c + 1049580a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                         8   5            7 3 4             6 5 3
+--R               581369856a b c  - 65060864a b c  + 480714752a b c
+--R             + 
+--R                           5 7 2            4 9            3 11
+--R               - 124135424a b c  - 25401600a b c + 6914880a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        9 5             8 2 4             7 4 3            6 6 2
+--R               92274688a c  - 423985152a b c  + 704806912a b c  + 52785152a b c
+--R             + 
+--R                           5 8             4 10
+--R               - 143001600a b c + 22861440a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                           9   4             8 3 3             7 5 2
+--R               - 341180416a b c  + 265814016a b c  + 531578880a b c
+--R             + 
+--R                           6 7             5 9
+--R               - 313098240a b c + 41771520a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          10 4             9 2 3             8 4 2
+--R               - 75497472a  c  - 220135424a b c  + 743981056a b c
+--R             + 
+--R                           7 6             6 8
+--R               - 344494080a b c + 42900480a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                           10   3             9 3 2             8 5
+--R               - 189267968a  b c  + 428474368a b c  - 189235200a b c
+--R             + 
+--R                        7 7
+--R               23224320a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       11 3            10 2 2            9 4            8 6
+--R           (- 33554432a  c  + 89915392a  b c  - 41287680a b c + 5160960a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                      3 8            2 2 7              4 6           6 5  6
+--R             (9175040a c  + 48168960a b c  + 20070400a b c  + 1003520b c )x
+--R           + 
+--R                        3   7             2 3 6              5 5  5
+--R             (220200960a b c  + 256901120a b c  + 32112640a b c )x
+--R           + 
+--R                        4 7             3 2 6             2 4 5  4
+--R             (220200960a c  + 990904320a b c  + 289013760a b c )x
+--R           + 
+--R                         4   6              3 3 5  3
+--R             (1468006400a b c  + 1101004800a b c )x
+--R           + 
+--R                        5 6              4 2 5  2              5   5
+--R             (734003200a c  + 2018508800a b c )x  + 1761607680a b c x
+--R           + 
+--R                       6 5
+--R             587202560a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                         3   8            2 3 7             5 6         7 5  7
+--R             (- 32112640a b c  - 40140800a b c  - 6021120a b c  - 71680b c )x
+--R           + 
+--R                            4 8             3 2 7             2 4 6
+--R                 - 64225280a c  - 337182720a b c  - 140492800a b c
+--R               + 
+--R                             6 5
+--R                 - 7024640a b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          4   7             3 3 6             2 5 5  5
+--R             (- 770703360a b c  - 899153920a b c  - 112394240a b c )x
+--R           + 
+--R                          5 7              4 2 6             3 4 5  4
+--R             (- 513802240a c  - 2312110080a b c  - 674365440a b c )x
+--R           + 
+--R                           5   6              4 3 5  3
+--R             (- 2569011200a b c  - 1926758400a b c )x
+--R           + 
+--R                           6 6              5 2 5  2              6   5
+--R             (- 1027604480a c  - 2825912320a b c )x  - 2055208960a b c x
+--R           + 
+--R                         7 5
+--R             - 587202560a c
+--R        *
+--R            +-+
+--R           \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                8 10           7 2 9            6 4 8
+--R                       - 131072a c   - 3932160a b c  - 14909440a b c
+--R                     + 
+--R                                  5 6 7           4 8 6           3 10 5
+--R                       - 16400384a b c  - 6589440a b c  - 1025024a b  c
+--R                     + 
+--R                               2 12 4         14 3     16 2
+--R                       - 58240a b  c  - 960a b  c  - 2b  c
+--R                  *
+--R                      23
+--R                     x
+--R                 + 
+--R                                  8   9             7 3 8             6 5 7
+--R                       - 18022400a b c  - 161873920a b c  - 326516736a b c
+--R                     + 
+--R                                   5 7 6            4 9 5           3 11 4
+--R                       - 223748096a b c  - 59671040a b c  - 6289920a b  c
+--R                     + 
+--R                                2 13 3          15 2     17
+--R                       - 239680a b  c  - 2528a b  c  - 3b  c
+--R                  *
+--R                      22
+--R                     x
+--R                 + 
+--R                                  9 9             8 2 8              7 4 7
+--R                       - 19136512a c  - 596705280a b c  - 2376007680a b c
+--R                     + 
+--R                                    6 6 6              5 8 5             4 10 4
+--R                       - 2786574336a b c  - 1222121472a b c  - 215913984a b  c
+--R                     + 
+--R                                  3 12 3          2 14 2          16     18
+--R                       - 15025920a b  c  - 361920a b  c  - 2148a b  c - b
+--R                  *
+--R                      21
+--R                     x
+--R                 + 
+--R                                   9   8              8 3 7               7 5 6
+--R                       - 901971968a b c  - 8313241600a b c  - 17324654592a b c
+--R                     + 
+--R                                     6 7 5              5 9 4             4 11 3
+--R                       - 12387934208a b c  - 3500823040a b c  - 401296896a b  c
+--R                     + 
+--R                                  3 13 2          2 15          17
+--R                       - 17469760a b  c  - 236576a b  c - 579a b
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                   10 8               9 2 7               8 4 6
+--R                       - 478281728a  c  - 15037366272a b c  - 60460072960a b c
+--R                     + 
+--R                                     7 6 5               6 8 4
+--R                       - 71723466752a b c  - 31885102080a b c
+--R                     + 
+--R                                    5 10 3             4 12 2           3 14
+--R                       - 5723001856a b  c  - 405169024a b  c  - 9873600a b  c
+--R                     + 
+--R                               2 16
+--R                       - 56066a b
+--R                  *
+--R                      19
+--R                     x
+--R                 + 
+--R                                     10   7                9 3 6
+--R                       - 13523484672a  b c  - 123681374208a b c
+--R                     + 
+--R                                      8 5 5                7 7 4
+--R                       - 254856462336a b c  - 179119964160a b c
+--R                     + 
+--R                                     6 9 3              5 11 2             4 13
+--R                       - 49221120000a b c  - 5368157184a b  c  - 210998016a b  c
+--R                     + 
+--R                                 3 15
+--R                       - 2164032a b
+--R                  *
+--R                      18
+--R                     x
+--R                 + 
+--R                                    11 7                10 2 6
+--R                       - 4775215104a  c  - 146951110656a  b c
+--R                     + 
+--R                                      9 4 5                8 6 4
+--R                       - 574176755712a b c  - 654571438080a b c
+--R                     + 
+--R                                      7 8 3               6 10 2
+--R                       - 274458009600a b c  - 44881061888a b  c
+--R                     + 
+--R                                    5 12             4 14
+--R                       - 2685210112a b  c - 44279424a b
+--R                  *
+--R                      17
+--R                     x
+--R                 + 
+--R                                     11   6                10 3 5
+--R                       - 93748985856a  b c  - 821944123392a  b c
+--R                     + 
+--R                                       9 5 4                 8 7 3
+--R                       - 1599839797248a b c  - 1037026590720a b c
+--R                     + 
+--R                                    7 9 2               6 11              5 13
+--R                     - 251887493120a b c  - 22238441472a b  c - 553844224a b
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                     12 6                11 2 5
+--R                       - 24800919552a  c  - 723662143488a  b c
+--R                     + 
+--R                                       10 4 4                 9 6 3
+--R                       - 2634897162240a  b c  - 2723351887872a b c
+--R                     + 
+--R                                    8 8 2                7 10               6 12
+--R                     - 987096268800a b c  - 126794440704a b  c - 4605060096a b
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                                      12   5                 11 3 4
+--R                       - 357010767872a  b c  - 2885083463680a  b c
+--R                     + 
+--R                                       10 5 3                 9 7 2
+--R                       - 5022938038272a  b c  - 2766963212288a b c
+--R                     + 
+--R                                      8 9                7 11
+--R                       - 516343562240a b c - 26854416384a b
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                     13 5                 12 2 4
+--R                       - 75480694784a  c  - 2011818885120a  b c
+--R                     + 
+--R                                       11 4 3                 10 6 2
+--R                       - 6481028055040a  b c  - 5616581476352a  b c
+--R                     + 
+--R                                       9 8                 8 10
+--R                       - 1537669005312a b c - 113805148160a b
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                      13   4                 12 3 3
+--R                       - 808074608640a  b c  - 5725979934720a  b c
+--R                     + 
+--R                                       11 5 2                 10 7
+--R                       - 8268212600832a  b c  - 3394382069760a  b c
+--R                     + 
+--R                                      9 9
+--R                       - 358820937728a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                      14 4                 13 2 3
+--R                       - 142237237248a  c  - 3299239526400a  b c
+--R                     + 
+--R                                       12 4 2                 11 6
+--R                       - 8736420659200a  b c  - 5581454704640a  b c
+--R                     + 
+--R                                      10 8
+--R                       - 854067118080a  b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                       14   3                 13 3 2
+--R                       - 1116557279232a  b c  - 6454698311680a  b c
+--R                     + 
+--R                                       12 5                  11 7
+--R                       - 6809746145280a  b c - 1545674424320a  b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                      15 3                 14 2 2
+--R                       - 168309030912a  c  - 3164652699648a  b c
+--R                     + 
+--R                                       13 4                  12 6
+--R                       - 6076791521280a  b c - 2127330017280a  b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                      15   2                 14 3
+--R                       - 924760145920a  b c  - 3851914575872a  b c
+--R                     + 
+--R                                       13 5
+--R                       - 2210112995328a  b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                      16 2                 15 2
+--R                       - 121869697024a  c  - 1642019684352a  b c
+--R                     + 
+--R                                       14 4
+--R                       - 1703860502528a  b
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                   16                   15 3  6
+--R                   (- 421980536832a  b c - 944624369664a  b )x
+--R                 + 
+--R                                  17                 16 2  5
+--R                   (- 49392123904a  c - 355945414656a  b )x
+--R                 + 
+--R                                 17   4              18 3
+--R                   - 81604378624a  b x  - 8589934592a  x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                               7   10           6 3 9            5 5 8
+--R                       1048576a b c   + 9175040a b c  + 17891328a b c
+--R                     + 
+--R                                4 7 7           3 9 6          2 11 5
+--R                       11714560a b c  + 2928640a b c  + 279552a b  c
+--R                     + 
+--R                              13 4      15 3
+--R                       8960a b  c  + 64b  c
+--R                  *
+--R                      23
+--R                     x
+--R                 + 
+--R                               8 10            7 2 9             6 4 8
+--R                       2228224a c   + 68419584a b c  + 267223040a b c
+--R                     + 
+--R                                 5 6 7             4 8 6            3 10 5
+--R                       305643520a b c  + 129592320a b c  + 21818368a b  c
+--R                     + 
+--R                               2 12 4           14 3       16 2
+--R                       1409408a b  c  + 29760a b  c  + 130b  c
+--R                  *
+--R                      22
+--R                     x
+--R                 + 
+--R                                 8   9              7 3 8              6 5 7
+--R                       155320320a b c  + 1417936896a b c  + 2919727104a b c
+--R                     + 
+--R                                  5 7 6             4 9 5            3 11 4
+--R                       2055585792a b c  + 568888320a b c  + 63298560a b  c
+--R                     + 
+--R                               2 13 3           15 2      17
+--R                       2631552a b  c  + 32832a b  c  + 66b  c
+--R                  *
+--R                      21
+--R                     x
+--R                 + 
+--R                                 9 9              8 2 8               7 4 7
+--R                       109182976a c  + 3423338496a b c  + 13718749184a b c
+--R                     + 
+--R                                   6 6 6              5 8 5              4 10 4
+--R                       16208969728a b c  + 7169510400a b c  + 1278497792a b  c
+--R                     + 
+--R                                3 12 3           2 14 2           16
+--R                       89727872a b  c  + 2159808a b  c  + 12034a b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                  9   8               8 3 7               7 5 6
+--R                       3826253824a b c  + 35087187968a b c  + 72552087552a b c
+--R                     + 
+--R                                   6 7 5               5 9 4              4 11 3
+--R                       51231047680a b c  + 14171156480a b c  + 1560818688a b  c
+--R                     + 
+--R                                3 13 2          2 15
+--R                       62333696a b  c  + 658240a b  c
+--R                  *
+--R                      19
+--R                     x
+--R                 + 
+--R                                  10 8               9 2 7                8 4 6
+--R                       1604321280a  c  + 49710366720a b c  + 195893526528a b c
+--R                     + 
+--R                                    7 6 5               6 8 4
+--R                       225763098624a b c  + 96027402240a b c
+--R                     + 
+--R                                   5 10 3             4 12 2            3 14
+--R                       16015534080a b  c  + 986119680a b  c  + 17018496a b  c
+--R                  *
+--R                      18
+--R                     x
+--R                 + 
+--R                                   10   7                9 3 6
+--R                       36597399552a  b c  + 324730355712a b c
+--R                     + 
+--R                                    8 5 5                7 7 4
+--R                       641536229376a b c  + 423828258816a b c
+--R                     + 
+--R                                    6 9 3              5 11 2             4 13
+--R                       105562808320a b c  + 9648697344a b  c  + 252859904a b  c
+--R                  *
+--R                      17
+--R                     x
+--R                 + 
+--R                                   11 7                10 2 6
+--R                       10909384704a  c  + 322921562112a  b c
+--R                     + 
+--R                                     9 4 5                 8 6 4
+--R                       1196544491520a b c  + 1264036085760a b c
+--R                     + 
+--R                                  7 8 3               6 10 2              5 12
+--R                     471186653184a b c  + 62824357888a b  c  + 2403574784a b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                    11   6                 10 3 5
+--R                       176588587008a  b c  + 1454741913600a  b c
+--R                     + 
+--R                                     9 5 4                 8 7 3
+--R                       2593064484864a b c  + 1471254626304a b c
+--R                     + 
+--R                                    7 9 2               6 11
+--R                       285229940736a b c  + 15614140416a b  c
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                                   12 6                 11 2 5
+--R                       40785412096a  c  + 1109372436480a  b c
+--R                     + 
+--R                                     10 4 4                 9 6 3
+--R                       3662497710080a  b c  + 3271235731456a b c
+--R                     + 
+--R                                    8 8 2               7 10
+--R                       930342961152a b c  + 72357953536a b  c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                    12   5                 11 3 4
+--R                       481489321984a  b c  + 3498133422080a  b c
+--R                     + 
+--R                                     10 5 3                 9 7 2
+--R                       5206576201728a  b c  + 2219148574720a b c
+--R                     + 
+--R                                    8 9
+--R                       246039642112a b c
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                   13 5                 12 2 4
+--R                       90697629696a  c  + 2157315096576a  b c
+--R                     + 
+--R                                     11 4 3                 10 6 2
+--R                       5886978293760a  b c  + 3901350739968a  b c
+--R                     + 
+--R                                    9 8
+--R                       624856793088a b c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                    13   4                 12 3 3
+--R                       775107379200a  b c  + 4615647002624a  b c
+--R                     + 
+--R                                     11 5 2                 10 7
+--R                       5046125199360a  b c  + 1196456673280a  b c
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                    14 4                 13 2 3
+--R                       123211874304a  c  + 2385116135424a  b c
+--R                     + 
+--R                                     12 4 2                 11 6
+--R                       4740922474496a  b c  + 1730381086720a  b c
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                    14   3                 13 3 2
+--R                       730412875776a  b c  + 3145929326592a  b c
+--R                     + 
+--R                                     12 5
+--R                       1878528098304a  b c
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                    15 3                 14 2 2
+--R                       100394860544a  c  + 1397206548480a  b c
+--R                     + 
+--R                                     13 4
+--R                       1506292006912a  b c
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                 15   2                14 3   7
+--R                   (372588412928a  b c  + 865167474688a  b c)x
+--R                 + 
+--R                                16 2                15 2   6
+--R                   (45097156608a  c  + 336618061824a  b c)x
+--R                 + 
+--R                               16     5              17   4
+--R                   79456894976a  b c x  + 8589934592a  c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                           7   10           6 3 9            5 5 8
+--R                   1048576a b c   + 9175040a b c  + 17891328a b c
+--R                 + 
+--R                            4 7 7           3 9 6          2 11 5          13 4
+--R                   11714560a b c  + 2928640a b c  + 279552a b  c  + 8960a b  c
+--R                 + 
+--R                      15 3
+--R                   64b  c
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                           8 10            7 2 9             6 4 8
+--R                   2228224a c   + 68943872a b c  + 271810560a b c
+--R                 + 
+--R                             5 6 7             4 8 6            3 10 5
+--R                   314589184a b c  + 135449600a b c  + 23282688a b  c
+--R                 + 
+--R                           2 12 4           14 3       16 2
+--R                   1549184a b  c  + 34240a b  c  + 162b  c
+--R              *
+--R                  23
+--R                 x
+--R             + 
+--R                             8   9              7 3 8              6 5 7
+--R                   157548544a b c  + 1463287808a b c  + 3078684672a b c
+--R                 + 
+--R                              5 7 6             4 9 5            3 11 4
+--R                   2228322304a b c  + 639907840a b c  + 74999808a b  c
+--R                 + 
+--R                           2 13 3           15 2       17
+--R                   3374336a b  c  + 48256a b  c  + 132b  c
+--R              *
+--R                  22
+--R                 x
+--R             + 
+--R                             9 9              8 2 8               7 4 7
+--R                   111411200a c  + 3577872384a b c  + 14770307072a b c
+--R                 + 
+--R                               6 6 6              5 8 5              4 10 4
+--R                   18125062144a b c  + 8428812288a b c  + 1611484160a b  c
+--R                 + 
+--R                             3 12 3           2 14 2           16       18
+--R                   125535488a b  c  + 3606144a b  c  + 29572a b  c + 34b
+--R              *
+--R                  21
+--R                 x
+--R             + 
+--R                              9   8               8 3 7               7 5 6
+--R                   4044619776a b c  + 38476709888a b c  + 83347898368a b c
+--R                 + 
+--R                               6 7 5               5 9 4              4 11 3
+--R                   62556291072a b c  + 18820106240a b c  + 2347052032a b  c
+--R                 + 
+--R                             3 13 2           2 15           17
+--R                   115262976a b  c  + 1886656a b  c + 6596a b
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                              10 8               9 2 7                8 4 6
+--R                   1713504256a  c  + 55415930880a b c  + 230473564160a b c
+--R                 + 
+--R                                7 6 5                6 8 4               5 10 3
+--R                   284942221312a b c  + 133396024320a b c  + 25597924352a b  c
+--R                 + 
+--R                              4 12 2            3 14           2 16
+--R                   1983413120a b  c  + 55047360a b  c + 385186a b
+--R              *
+--R                  19
+--R                 x
+--R             + 
+--R                               10   7                9 3 6                8 5 5
+--R                   41410363392a  b c  + 390295191552a b c  + 833746894848a b c
+--R                 + 
+--R                                7 7 4                6 9 3               5 11 2
+--R                   612351049728a b c  + 177813667840a b c  + 20830377984a b  c
+--R                 + 
+--R                             4 13             3 15
+--R                   902395904a b  c + 10673280a b
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                               11 7                10 2 6                 9 4 5
+--R                   12513705984a  c  + 395686969344a  b c  + 1596289056768a b c
+--R                 + 
+--R                                 8 6 4                7 8 3
+--R                   1890863579136a b c  + 830867546112a b c
+--R                 + 
+--R                                6 10 2              5 12              4 14
+--R                   144113276928a b  c  + 9311164928a b  c + 170709376a b
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                                11   6                 10 3 5
+--R                   220226125824a  b c  + 1987175251968a  b c
+--R                 + 
+--R                                 9 5 4                 8 7 3
+--R                   4001271644160a b c  + 2701356957696a b c
+--R                 + 
+--R                                7 9 2               6 11               5 13
+--R                   689731698688a b c  + 64861790208a b  c + 1755631616a b
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                               12 6                 11 2 5
+--R                   51694796800a  c  + 1548371361792a  b c
+--R                 + 
+--R                                 10 4 4                 9 6 3
+--R                   5811898941440a  b c  + 6226756501504a b c
+--R                 + 
+--R                                 8 8 2                7 10                6 12
+--R                   2356628078592a b c  + 319286812672a b  c + 12412130304a b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                                12   5                 11 3 4
+--R                   685416382464a  b c  + 5694040309760a  b c
+--R                 + 
+--R                                  10 5 3                 9 7 2
+--R                   10237322985472a  b c  + 5858202746880a b c
+--R                 + 
+--R                                 8 9                7 11
+--R                   1144660295680a b c + 63033393152a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                                13 5                 12 2 4
+--R                   131483041792a  c  + 3594170400768a  b c
+--R                 + 
+--R                                  11 4 3                  10 6 2
+--R                   11920474112000a  b c  + 10687594627072a  b c
+--R                 + 
+--R                                 9 8                 8 10
+--R                   3046537494528a b c + 236824969216a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                                 13   4                 12 3 3
+--R                   1319293157376a  b c  + 9600292093952a  b c
+--R                 + 
+--R                                11 5 2                 10 7                 9 9
+--R                 14294490021888a  b c  + 6083093463040a  b c + 671249334272a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                14 4                 13 2 3
+--R                   213909504000a  c  + 5084603744256a  b c
+--R                 + 
+--R                                  12 4 2                 11 6
+--R                   13845720465408a  b c  + 9136462888960a  b c
+--R                 + 
+--R                                 10 8
+--R                   1452295454720a  b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                                 14   3                 13 3 2
+--R                   1592895995904a  b c  + 9447787200512a  b c
+--R                 + 
+--R                                  12 5                  11 7
+--R                   10264837619712a  b c + 2410864967680a  b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                                15 3                 14 2 2
+--R                   223606734848a  c  + 4305369169920a  b c
+--R                 + 
+--R                                 13 4                  12 6
+--R                   8492878397440a  b c + 3066594066432a  b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                                   15   2                 14 3
+--R                     1175747297280a  b c  + 5020548333568a  b c
+--R                   + 
+--R                                   13 5
+--R                     2963258998784a  b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             16 2                 15 2                  14 4  7
+--R               (145492017152a  c  + 2006018162688a  b c + 2136444239872a  b )x
+--R             + 
+--R                             16                    15 3  6
+--R               (485331304448a  b c + 1112933400576a  b )x
+--R             + 
+--R                            17                 16 2  5               17   4
+--R               (53687091200a  c + 395673862144a  b )x  + 85899345920a  b x
+--R             + 
+--R                          18 3
+--R               8589934592a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                        8 11           7 2 10            6 4 9            5 6 8
+--R               - 131072a c   - 3932160a b c   - 14909440a b c  - 16400384a b c
+--R             + 
+--R                         4 8 7           3 10 6         2 12 5         14 4
+--R               - 6589440a b c  - 1025024a b  c  - 58240a b  c  - 960a b  c
+--R             + 
+--R                   16 3
+--R               - 2b  c
+--R          *
+--R              24
+--R             x
+--R         + 
+--R                          8   10             7 3 9             6 5 8
+--R               - 18087936a b c   - 163840000a b c  - 333971456a b c
+--R             + 
+--R                           5 7 7            4 9 6           3 11 5
+--R               - 231948288a b c  - 62965760a b c  - 6802432a b  c
+--R             + 
+--R                        2 13 4          15 3     17 2
+--R               - 268800a b  c  - 3008a b  c  - 4b  c
+--R          *
+--R              23
+--R             x
+--R         + 
+--R                          9 10             8 2 9              7 4 8
+--R               - 19136512a c   - 605159424a b c  - 2451374080a b c
+--R             + 
+--R                            6 6 7              5 8 6             4 10 5
+--R               - 2937159680a b c  - 1324038144a b c  - 242637824a b  c
+--R             + 
+--R                          3 12 4          2 14 3          16 2     18
+--R               - 17774848a b  c  - 462720a b  c  - 3140a b  c  - 2b  c
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                           9   9              8 3 8               7 5 7
+--R               - 910426112a b c  - 8573157376a b c  - 18341363712a b c
+--R             + 
+--R                             6 7 6              5 9 5             4 11 4
+--R               - 13553106944a b c  - 3996129280a b c  - 484982784a b  c
+--R             + 
+--R                          3 13 3          2 15 2          17
+--R               - 22903552a b  c  - 352256a b  c  - 1092a b  c
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                           10 9               9 2 8               8 4 7
+--R               - 478281728a  c  - 15406465024a b c  - 63777767424a b c
+--R             + 
+--R                             7 6 6               6 8 5              5 10 4
+--R               - 78417575936a b c  - 36468689920a b c  - 6941316096a b  c
+--R             + 
+--R                           4 12 3            3 14 2          2 16
+--R               - 532325248a b  c  - 14575808a b  c  - 100098a b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                             10   8                9 3 7                8 5 6
+--R               - 13708034048a  b c  - 129303838720a b c  - 276568276992a b c
+--R             + 
+--R                              7 7 5               6 9 4              5 11 3
+--R               - 203530158080a b c  - 59287121920a b c  - 6981252096a b  c
+--R             + 
+--R                           4 13 2           3 15
+--R               - 305140480a b  c  - 3669824a b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                            11 8                10 2 7                9 4 6
+--R               - 4775215104a  c  - 151707451392a  b c  - 615662616576a b c
+--R             + 
+--R                              8 6 5                7 8 4               6 10 3
+--R               - 734867718144a b c  - 326197370880a b c  - 57373042688a b  c
+--R             + 
+--R                            5 12 2            4 14
+--R               - 3782331904a b  c  - 71540352a b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                             11   7                10 3 6                 9 5 5
+--R               - 95334432768a  b c  - 868186324992a  b c  - 1768238481408a b c
+--R             + 
+--R                               8 7 4                7 9 3               6 11 2
+--R               - 1211282620416a b c  - 315233116160a b c  - 30425214976a b  c
+--R             + 
+--R                           5 13
+--R               - 854828544a b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                             12 7                11 2 6                 10 4 5
+--R               - 24800919552a  c  - 751445213184a  b c  - 2860382945280a  b c
+--R             + 
+--R                               9 6 4                 8 8 3                7 10 2
+--R               - 3118304329728a b c  - 1206567419904a b c  - 168283971584a b  c
+--R             + 
+--R                            6 12
+--R               - 6806545408a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                              12   6                 11 3 5
+--R               - 363956535296a  b c  - 3071562219520a  b c
+--R             + 
+--R                               10 5 4                 9 7 3                8 9 2
+--R               - 5629371482112a  b c  - 3299144892416a b c  - 664562794496a b c
+--R             + 
+--R                             7 11
+--R               - 38094692352a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                             13 6                 12 2 5                 11 4 4
+--R               - 75480694784a  c  - 2098557091840a  b c  - 7102959452160a  b c
+--R             + 
+--R                             10 6 3                 9 8 2                8 10
+--R             - 6528301531136a  b c  - 1919432458240a b c  - 155252342784a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                              13   5                 12 3 4
+--R               - 825422249984a  b c  - 6133834055680a  b c
+--R             + 
+--R                             11 5 3                 10 7 2                9 9
+--R             - 9366512074752a  b c  - 4111194914816a  b c  - 471602233344a b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                              14 5                 13 2 4                 12 4 3
+--R               - 142237237248a  c  - 3453858349056a  b c  - 9646416855040a  b c
+--R             + 
+--R                               11 6 2                 10 8
+--R               - 6563123167232a  b c  - 1083277443072a  b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                               14   4                 13 3 3
+--R               - 1142327083008a  b c  - 6948351115264a  b c
+--R             + 
+--R                               12 5 2                 11 7
+--R               - 7779469230080a  b c  - 1894892175360a  b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                              15 4                 14 2 3                 13 4 2
+--R               - 168309030912a  c  - 3322492747776a  b c  - 6749490774016a  b c
+--R             + 
+--R                               12 6
+--R               - 2524278947840a  b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                                15   3                 14 3 2
+--R                 - 947308724224a  b c  - 4162762833920a  b c
+--R               + 
+--R                                 13 5
+--R                 - 2541697892352a  b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                           16 3                 15 2 2                 14 4   8
+--R           (- 121869697024a  c  - 1727919030272a  b c  - 1901428998144a  b c)x
+--R         + 
+--R                           16   2                 15 3   7
+--R           (- 432717955072a  b c  - 1024081264640a  b c)x
+--R         + 
+--R                          17 2                16 2   6               17     5
+--R           (- 49392123904a  c  - 375272767488a  b c)x  - 83751862272a  b c x
+--R         + 
+--R                        18   4
+--R           - 8589934592a  c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                             7   10           6 3 9            5 5 8
+--R                   - 1048576a b c   - 9175040a b c  - 17891328a b c
+--R                 + 
+--R                              4 7 7           3 9 6          2 11 5
+--R                   - 11714560a b c  - 2928640a b c  - 279552a b  c
+--R                 + 
+--R                            13 4      15 3
+--R                   - 8960a b  c  - 64b  c
+--R              *
+--R                  25
+--R                 x
+--R             + 
+--R                             8 10            7 2 9             6 4 8
+--R                   - 2228224a c   - 68943872a b c  - 271810560a b c
+--R                 + 
+--R                               5 6 7             4 8 6            3 10 5
+--R                   - 314589184a b c  - 135449600a b c  - 23282688a b  c
+--R                 + 
+--R                             2 12 4           14 3       16 2
+--R                   - 1549184a b  c  - 34240a b  c  - 162b  c
+--R              *
+--R                  24
+--R                 x
+--R             + 
+--R                               8   9              7 3 8              6 5 7
+--R                   - 157548544a b c  - 1463287808a b c  - 3078684672a b c
+--R                 + 
+--R                                5 7 6             4 9 5            3 11 4
+--R                   - 2228322304a b c  - 639907840a b c  - 74999808a b  c
+--R                 + 
+--R                             2 13 3           15 2       17
+--R                   - 3374336a b  c  - 48256a b  c  - 132b  c
+--R              *
+--R                  23
+--R                 x
+--R             + 
+--R                               9 9              8 2 8               7 4 7
+--R                   - 111411200a c  - 3577872384a b c  - 14770307072a b c
+--R                 + 
+--R                                 6 6 6              5 8 5              4 10 4
+--R                   - 18125062144a b c  - 8428812288a b c  - 1611484160a b  c
+--R                 + 
+--R                               3 12 3           2 14 2           16       18
+--R                   - 125535488a b  c  - 3606144a b  c  - 29572a b  c - 34b
+--R              *
+--R                  22
+--R                 x
+--R             + 
+--R                                9   8               8 3 7               7 5 6
+--R                   - 4044619776a b c  - 38476709888a b c  - 83347898368a b c
+--R                 + 
+--R                                 6 7 5               5 9 4              4 11 3
+--R                   - 62556291072a b c  - 18820106240a b c  - 2347052032a b  c
+--R                 + 
+--R                               3 13 2           2 15           17
+--R                   - 115262976a b  c  - 1886656a b  c - 6596a b
+--R              *
+--R                  21
+--R                 x
+--R             + 
+--R                                10 8               9 2 7                8 4 6
+--R                   - 1713504256a  c  - 55415930880a b c  - 230473564160a b c
+--R                 + 
+--R                                  7 6 5                6 8 4
+--R                   - 284942221312a b c  - 133396024320a b c
+--R                 + 
+--R                                 5 10 3              4 12 2            3 14
+--R                   - 25597924352a b  c  - 1983413120a b  c  - 55047360a b  c
+--R                 + 
+--R                            2 16
+--R                   - 385186a b
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                                 10   7                9 3 6
+--R                   - 41410363392a  b c  - 390295191552a b c
+--R                 + 
+--R                                  8 5 5                7 7 4
+--R                   - 833746894848a b c  - 612351049728a b c
+--R                 + 
+--R                                  6 9 3               5 11 2             4 13
+--R                   - 177813667840a b c  - 20830377984a b  c  - 902395904a b  c
+--R                 + 
+--R                              3 15
+--R                   - 10673280a b
+--R              *
+--R                  19
+--R                 x
+--R             + 
+--R                                 11 7                10 2 6
+--R                   - 12513705984a  c  - 395686969344a  b c
+--R                 + 
+--R                                   9 4 5                 8 6 4
+--R                   - 1596289056768a b c  - 1890863579136a b c
+--R                 + 
+--R                                  7 8 3                6 10 2              5 12
+--R                   - 830867546112a b c  - 144113276928a b  c  - 9311164928a b  c
+--R                 + 
+--R                               4 14
+--R                   - 170709376a b
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                                  11   6                 10 3 5
+--R                   - 220226125824a  b c  - 1987175251968a  b c
+--R                 + 
+--R                                   9 5 4                 8 7 3
+--R                   - 4001271644160a b c  - 2701356957696a b c
+--R                 + 
+--R                                  7 9 2               6 11               5 13
+--R                   - 689731698688a b c  - 64861790208a b  c - 1755631616a b
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                                 12 6                 11 2 5
+--R                   - 51694796800a  c  - 1548371361792a  b c
+--R                 + 
+--R                                   10 4 4                 9 6 3
+--R                   - 5811898941440a  b c  - 6226756501504a b c
+--R                 + 
+--R                                 8 8 2                7 10                6 12
+--R                 - 2356628078592a b c  - 319286812672a b  c - 12412130304a b
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                  12   5                 11 3 4
+--R                   - 685416382464a  b c  - 5694040309760a  b c
+--R                 + 
+--R                                    10 5 3                 9 7 2
+--R                   - 10237322985472a  b c  - 5858202746880a b c
+--R                 + 
+--R                                   8 9                7 11
+--R                   - 1144660295680a b c - 63033393152a b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                                  13 5                 12 2 4
+--R                   - 131483041792a  c  - 3594170400768a  b c
+--R                 + 
+--R                                    11 4 3                  10 6 2
+--R                   - 11920474112000a  b c  - 10687594627072a  b c
+--R                 + 
+--R                                   9 8                 8 10
+--R                   - 3046537494528a b c - 236824969216a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                                   13   4                 12 3 3
+--R                   - 1319293157376a  b c  - 9600292093952a  b c
+--R                 + 
+--R                                    11 5 2                 10 7
+--R                   - 14294490021888a  b c  - 6083093463040a  b c
+--R                 + 
+--R                                  9 9
+--R                   - 671249334272a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                                  14 4                 13 2 3
+--R                   - 213909504000a  c  - 5084603744256a  b c
+--R                 + 
+--R                                    12 4 2                 11 6
+--R                   - 13845720465408a  b c  - 9136462888960a  b c
+--R                 + 
+--R                                   10 8
+--R                   - 1452295454720a  b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                   14   3                 13 3 2
+--R                   - 1592895995904a  b c  - 9447787200512a  b c
+--R                 + 
+--R                                    12 5                  11 7
+--R                   - 10264837619712a  b c - 2410864967680a  b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                                  15 3                 14 2 2
+--R                   - 223606734848a  c  - 4305369169920a  b c
+--R                 + 
+--R                                   13 4                  12 6
+--R                   - 8492878397440a  b c - 3066594066432a  b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                                   15   2                 14 3
+--R                   - 1175747297280a  b c  - 5020548333568a  b c
+--R                 + 
+--R                                   13 5
+--R                   - 2963258998784a  b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                                    16 2                 15 2
+--R                     - 145492017152a  c  - 2006018162688a  b c
+--R                   + 
+--R                                     14 4
+--R                     - 2136444239872a  b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                               16                    15 3  7
+--R               (- 485331304448a  b c - 1112933400576a  b )x
+--R             + 
+--R                              17                 16 2  6               17   5
+--R               (- 53687091200a  c - 395673862144a  b )x  - 85899345920a  b x
+--R             + 
+--R                            18 4
+--R               - 8589934592a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                      8 11           7 2 10            6 4 9            5 6 8
+--R               131072a c   + 3932160a b c   + 14909440a b c  + 16400384a b c
+--R             + 
+--R                     4 8 7           3 10 6         2 12 5         14 4     16 3
+--R             6589440a b c  + 1025024a b  c  + 58240a b  c  + 960a b  c  + 2b  c
+--R          *
+--R              25
+--R             x
+--R         + 
+--R                        8   10             7 3 9             6 5 8
+--R               18087936a b c   + 163840000a b c  + 333971456a b c
+--R             + 
+--R                         5 7 7            4 9 6           3 11 5          2 13 4
+--R               231948288a b c  + 62965760a b c  + 6802432a b  c  + 268800a b  c
+--R             + 
+--R                      15 3     17 2
+--R               3008a b  c  + 4b  c
+--R          *
+--R              24
+--R             x
+--R         + 
+--R                        9 10             8 2 9              7 4 8
+--R               19136512a c   + 605159424a b c  + 2451374080a b c
+--R             + 
+--R                          6 6 7              5 8 6             4 10 5
+--R               2937159680a b c  + 1324038144a b c  + 242637824a b  c
+--R             + 
+--R                        3 12 4          2 14 3          16 2     18
+--R               17774848a b  c  + 462720a b  c  + 3140a b  c  + 2b  c
+--R          *
+--R              23
+--R             x
+--R         + 
+--R                         9   9              8 3 8               7 5 7
+--R               910426112a b c  + 8573157376a b c  + 18341363712a b c
+--R             + 
+--R                           6 7 6              5 9 5             4 11 4
+--R               13553106944a b c  + 3996129280a b c  + 484982784a b  c
+--R             + 
+--R                        3 13 3          2 15 2          17
+--R               22903552a b  c  + 352256a b  c  + 1092a b  c
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                         10 9               9 2 8               8 4 7
+--R               478281728a  c  + 15406465024a b c  + 63777767424a b c
+--R             + 
+--R                           7 6 6               6 8 5              5 10 4
+--R               78417575936a b c  + 36468689920a b c  + 6941316096a b  c
+--R             + 
+--R                         4 12 3            3 14 2          2 16
+--R               532325248a b  c  + 14575808a b  c  + 100098a b  c
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                           10   8                9 3 7                8 5 6
+--R               13708034048a  b c  + 129303838720a b c  + 276568276992a b c
+--R             + 
+--R                            7 7 5               6 9 4              5 11 3
+--R               203530158080a b c  + 59287121920a b c  + 6981252096a b  c
+--R             + 
+--R                         4 13 2           3 15
+--R               305140480a b  c  + 3669824a b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                          11 8                10 2 7                9 4 6
+--R               4775215104a  c  + 151707451392a  b c  + 615662616576a b c
+--R             + 
+--R                            8 6 5                7 8 4               6 10 3
+--R               734867718144a b c  + 326197370880a b c  + 57373042688a b  c
+--R             + 
+--R                          5 12 2            4 14
+--R               3782331904a b  c  + 71540352a b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                           11   7                10 3 6                 9 5 5
+--R               95334432768a  b c  + 868186324992a  b c  + 1768238481408a b c
+--R             + 
+--R                             8 7 4                7 9 3               6 11 2
+--R               1211282620416a b c  + 315233116160a b c  + 30425214976a b  c
+--R             + 
+--R                         5 13
+--R               854828544a b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                           12 7                11 2 6                 10 4 5
+--R               24800919552a  c  + 751445213184a  b c  + 2860382945280a  b c
+--R             + 
+--R                             9 6 4                 8 8 3                7 10 2
+--R               3118304329728a b c  + 1206567419904a b c  + 168283971584a b  c
+--R             + 
+--R                          6 12
+--R               6806545408a b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                            12   6                 11 3 5                 10 5 4
+--R               363956535296a  b c  + 3071562219520a  b c  + 5629371482112a  b c
+--R             + 
+--R                             9 7 3                8 9 2               7 11
+--R               3299144892416a b c  + 664562794496a b c  + 38094692352a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                           13 6                 12 2 5                 11 4 4
+--R               75480694784a  c  + 2098557091840a  b c  + 7102959452160a  b c
+--R             + 
+--R                             10 6 3                 9 8 2                8 10
+--R               6528301531136a  b c  + 1919432458240a b c  + 155252342784a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                            13   5                 12 3 4                 11 5 3
+--R               825422249984a  b c  + 6133834055680a  b c  + 9366512074752a  b c
+--R             + 
+--R                             10 7 2                9 9
+--R               4111194914816a  b c  + 471602233344a b c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                            14 5                 13 2 4                 12 4 3
+--R               142237237248a  c  + 3453858349056a  b c  + 9646416855040a  b c
+--R             + 
+--R                             11 6 2                 10 8
+--R               6563123167232a  b c  + 1083277443072a  b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                             14   4                 13 3 3
+--R               1142327083008a  b c  + 6948351115264a  b c
+--R             + 
+--R                             12 5 2                 11 7
+--R               7779469230080a  b c  + 1894892175360a  b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                            15 4                 14 2 3                 13 4 2
+--R               168309030912a  c  + 3322492747776a  b c  + 6749490774016a  b c
+--R             + 
+--R                             12 6
+--R               2524278947840a  b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         15   3                 14 3 2                 13 5   10
+--R           (947308724224a  b c  + 4162762833920a  b c  + 2541697892352a  b c)x
+--R         + 
+--R                         16 3                 15 2 2                 14 4   9
+--R           (121869697024a  c  + 1727919030272a  b c  + 1901428998144a  b c)x
+--R         + 
+--R                         16   2                 15 3   8
+--R           (432717955072a  b c  + 1024081264640a  b c)x
+--R         + 
+--R                        17 2                16 2   7               17     6
+--R           (49392123904a  c  + 375272767488a  b c)x  + 83751862272a  b c x
+--R         + 
+--R                      18   5
+--R           8589934592a  c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                      8 11           7 2 10            6 4 9            5 6 8
+--R               131072a c   + 3932160a b c   + 14909440a b c  + 16400384a b c
+--R             + 
+--R                     4 8 7           3 10 6         2 12 5         14 4     16 3
+--R             6589440a b c  + 1025024a b  c  + 58240a b  c  + 960a b  c  + 2b  c
+--R          *
+--R              26
+--R             x
+--R         + 
+--R                        8   10             7 3 9             6 5 8
+--R               18153472a b c   + 165806080a b c  + 341426176a b c
+--R             + 
+--R                         5 7 7            4 9 6           3 11 5          2 13 4
+--R               240148480a b c  + 66260480a b c  + 7314944a b  c  + 297920a b  c
+--R             + 
+--R                      15 3     17 2
+--R               3488a b  c  + 5b  c
+--R          *
+--R              25
+--R             x
+--R         + 
+--R                        9 10             8 2 9              7 4 8
+--R               19267584a c   + 618659840a b c  + 2552791040a b c
+--R             + 
+--R                          6 6 7              5 8 6             4 10 5
+--R               3129491456a b c  + 1452459008a b c  + 276610048a b  c
+--R             + 
+--R                        3 12 4          2 14 3          16 2     18
+--R               21374080a b  c  + 602560a b  c  + 4678a b  c  + 4b  c
+--R          *
+--R              24
+--R             x
+--R         + 
+--R                         9   9              8 3 8               7 5 7
+--R               939130880a b c  + 9071820800a b c  + 20027179008a b c
+--R             + 
+--R                           6 7 6              5 9 5             4 11 4
+--R               15398256640a b c  + 4782615552a b c  + 623500800a b  c
+--R             + 
+--R                        3 13 3          2 15 2          17     19
+--R               32735360a b  c  + 601024a b  c  + 2730a b  c + b
+--R          *
+--R              23
+--R             x
+--R         + 
+--R                         10 9               9 2 8               8 4 7
+--R               497418240a  c  + 16536043520a b c  + 71149322240a b c
+--R             + 
+--R                           7 6 6               6 8 5              5 10 4
+--R               91834695680a b c  + 45495157760a b c  + 9439738880a b  c
+--R             + 
+--R                         4 12 3            3 14 2          2 16          18
+--R               821491840a b  c  + 27705280a b  c  + 294790a b  c + 580a b
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                           10   8                9 3 7                8 5 6
+--R               14903738368a  b c  + 147031982080a b c  + 332641189888a b c
+--R             + 
+--R                            7 7 5               6 9 4               5 11 3
+--R               263231365120a b c  + 84607045120a b c  + 11492455936a b  c
+--R             + 
+--R                         4 13 2            3 15          2 17
+--R               633636800a b  c  + 12274208a b  c + 56645a b
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                          11 8                10 2 7                9 4 6
+--R               5253496832a  c  + 175511961600a  b c  + 758318202880a b c
+--R             + 
+--R                            8 6 5                7 8 4               6 10 3
+--R               981151367168a b c  + 485463075840a b c  + 99825183744a b  c
+--R             + 
+--R                          5 12 2             4 14            3 16
+--R               8458536320a b  c  + 265151040a b  c + 2220098a b
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                            11   7                 10 3 6                 9 5 5
+--R               112047685632a  b c  + 1092576608256a  b c  + 2428873015296a b c
+--R             + 
+--R                             8 7 4                7 9 3               6 11 2
+--R               1870717992960a b c  + 575566622720a b c  + 72487660544a b  c
+--R             + 
+--R                          5 13             4 15
+--R               3450052352a b  c + 46443456a b
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                           12 7                11 2 6                 10 4 5
+--R               29576134656a  c  + 964362240000a  b c  + 4031018041344a  b c
+--R             + 
+--R                             9 6 4                 8 8 3                7 10 2
+--R               4977763123200a b c  + 2298580869120a b c  + 423562995712a b  c
+--R             + 
+--R                           6 12              5 14
+--R               29528711680a b  c + 598123648a b
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                            12   6                 11 3 5                 10 5 4
+--R               475560673280a  b c  + 4430689730560a  b c  + 9257674997760a  b c
+--R             + 
+--R                             9 7 3                 8 9 2                7 11
+--R               6527341690880a b c  + 1755327324160a b c  + 175887298560a b  c
+--R             + 
+--R                          6 13
+--R               5158904320a b
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                            13 6                 12 2 5                  11 4 4
+--R               100281614336a  c  + 3092491796480a  b c  + 12001008680960a  b c
+--R             + 
+--R                              10 6 3                 9 8 2                8 10
+--R               13362871402496a  b c  + 5291728486400a b c  + 756943151104a b  c
+--R             + 
+--R                           7 12
+--R               31459476480a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                             13   5                  12 3 4
+--R               1240566071296a  b c  + 10622882283520a  b c
+--R             + 
+--R                              11 5 3                  10 7 2
+--R               19772178694144a  b c  + 11777926758400a  b c
+--R             + 
+--R                             9 9                 8 11
+--R               2412833505280a b c + 140659564544a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                            14 5                 13 2 4                  12 4 3
+--R               217717932032a  c  + 6119133020160a  b c  + 20943428648960a  b c
+--R             + 
+--R                              11 6 2                 10 8                 9 10
+--R               19466248781824a  b c  + 5786118193152a  b c + 472626085888a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                             14   4                  13 3 3
+--R               2066869125120a  b c  + 15479917772800a  b c
+--R             + 
+--R                            12 5 2                  11 7                  10 9
+--R             23814379405312a  b c  + 10521511198720a  b c + 1212888055808a  b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                            15 4                 14 2 3                  13 4 2
+--R               310546268160a  c  + 7580449505280a  b c  + 21267910492160a  b c
+--R             + 
+--R                              12 6                  11 8
+--R               14518530867200a  b c + 2399741542400a  b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                             15   3                  14 3 2
+--R               2209626456064a  b c  + 13471265587200a  b c
+--R             + 
+--R                              13 5                  12 7
+--R               15096650661888a  b c + 3673004441600a  b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                            16 3                 15 2 2                  14 4
+--R               290178727936a  c  + 5731432529920a  b c  + 11632566599680a  b c
+--R             + 
+--R                             13 6
+--R               4337443012608a  b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          16   2                 15 3                  14 5  9
+--R           (1468610379776a  b c  + 6438558629888a  b c + 3913973497856a  b )x
+--R         + 
+--R                         17 2                 16 2                  15 4  8
+--R           (171261820928a  c  + 2419945635840a  b c + 2648484872192a  b )x
+--R         + 
+--R                         17                    16 3  7
+--R           (552977039360a  b c + 1300569784320a  b )x
+--R         + 
+--R                        18                 17 2  6               18   5
+--R           (57982058496a  c + 437549793280a  b )x  + 90194313216a  b x
+--R         + 
+--R                      19 4
+--R           8589934592a  x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                         7   11           6 3 10            5 5 9
+--R               - 1048576a b c   - 9175040a b c   - 17891328a b c
+--R             + 
+--R                          4 7 8           3 9 7          2 11 6          13 5
+--R               - 11714560a b c  - 2928640a b c  - 279552a b  c  - 8960a b  c
+--R             + 
+--R                    15 4
+--R               - 64b  c
+--R          *
+--R              26
+--R             x
+--R         + 
+--R                         8 11            7 2 10             6 4 9
+--R               - 2228224a c   - 69468160a b c   - 276398080a b c
+--R             + 
+--R                           5 6 8             4 8 7            3 10 6
+--R               - 323534848a b c  - 141306880a b c  - 24747008a b  c
+--R             + 
+--R                         2 12 5           14 4       16 3
+--R               - 1688960a b  c  - 38720a b  c  - 194b  c
+--R          *
+--R              25
+--R             x
+--R         + 
+--R                           8   10              7 3 9              6 5 8
+--R               - 158597120a b c   - 1495531520a b c  - 3204841472a b c
+--R             + 
+--R                            5 7 7             4 9 6            3 11 5
+--R               - 2372943872a b c  - 701409280a b c  - 85396480a b  c
+--R             + 
+--R                         2 13 4           15 3       17 2
+--R               - 4049920a b  c  - 62656a b  c  - 196b  c
+--R          *
+--R              24
+--R             x
+--R         + 
+--R                           9 10              8 2 9               7 4 8
+--R               - 111411200a c   - 3647078400a b c  - 15403909120a b c
+--R             + 
+--R                             6 6 7              5 8 6              4 10 5
+--R               - 19434340352a b c  - 9354688512a b c  - 1869204480a b  c
+--R             + 
+--R                           3 12 4           2 14 3           16 2      18
+--R               - 154435840a b  c  - 4821120a b  c  - 44996a b  c  - 66b  c
+--R          *
+--R              23
+--R             x
+--R         + 
+--R                            9   9               8 3 8               7 5 7
+--R               - 4090757120a b c  - 39928463360a b c  - 89190563840a b c
+--R             + 
+--R                             6 7 6               5 9 5              4 11 4
+--R               - 69495603200a b c  - 21909555200a b c  - 2902615040a b  c
+--R             + 
+--R                           3 13 3           2 15 2           17
+--R               - 154693120a b  c  - 2850880a b  c  - 12100a b  c
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                            10 9               9 2 8                8 4 7
+--R               - 1713504256a  c  - 56959959040a b c  - 244699463680a b c
+--R             + 
+--R                              7 6 6                6 8 5               5 10 4
+--R               - 314524155904a b c  - 154427960320a b c  - 31465188352a b  c
+--R             + 
+--R                            4 12 3            3 14 2          2 16
+--R               - 2636666240a b  c  - 81512000a b  c  - 670274a b  c
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                             10   8                9 3 7                8 5 6
+--R               - 42027974656a  b c  - 409527910400a b c  - 909981843456a b c
+--R             + 
+--R                              7 7 5                6 9 4               5 11 3
+--R               - 700822405120a b c  - 215761367040a b c  - 27225050112a b  c
+--R             + 
+--R                            4 13 2            3 15
+--R               - 1301313280a b  c  - 17676736a b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                             11 8                10 2 7                 9 4 6
+--R               - 12513705984a  c  - 409229328384a  b c  - 1717168373760a b c
+--R             + 
+--R                               8 6 5                7 8 4                6 10 3
+--R               - 2131335413760a b c  - 991042314240a b c  - 184402700288a b  c
+--R             + 
+--R                             5 12 2             4 14
+--R               - 13038391808a b  c  - 269878400a b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                              11   7                 10 3 6
+--R               - 224095371264a  b c  - 2102393831424a  b c
+--R             + 
+--R                               9 5 5                 8 7 4                7 9 3
+--R               - 4431145205760a b c  - 3159118970880a b c  - 861979402240a b c
+--R             + 
+--R                             6 11 2              5 13
+--R               - 88087195648a b  c  - 2656434688a b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                             12 7                 11 2 6                 10 4 5
+--R               - 51694796800a  c  - 1608882585600a  b c  - 6313784115200a  b c
+--R             + 
+--R                               9 6 4                 8 8 3                7 10 2
+--R               - 7128336302080a b c  - 2872784240640a b c  - 420412252160a b  c
+--R             + 
+--R                             6 12
+--R               - 18017715200a b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                              12   6                 11 3 5
+--R               - 698863321088a  b c  - 6062247772160a  b c
+--R             + 
+--R                                10 5 4                 9 7 3
+--R               - 11462138396672a  b c  - 6961638932480a b c
+--R             + 
+--R                               8 9 2               7 11
+--R               - 1461612544000a b c  - 87972093952a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                              13 6                 12 2 5
+--R               - 131483041792a  c  - 3748176855040a  b c
+--R             + 
+--R                                11 4 4                  10 6 3
+--R               - 13047609425920a  b c  - 12379162673152a  b c
+--R             + 
+--R                               9 8 2                8 10
+--R               - 3774348328960a b c  - 318397595648a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                               13   5                  12 3 4
+--R               - 1347294330880a  b c  - 10271095521280a  b c
+--R             + 
+--R                              11 5 3                 10 7 2                9 9
+--R             - 16139679694848a  b c  - 7316955987968a  b c  - 870896435200a b c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                              14 5                 13 2 4
+--R               - 213909504000a  c  - 5317538611200a  b c
+--R             + 
+--R                                12 4 3                  11 6 2
+--R               - 15243547770880a  b c  - 10677857026048a  b c
+--R             + 
+--R                               10 8
+--R               - 1821313466368a  b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                               14   4                  13 3 3
+--R               - 1628732129280a  b c  - 10146692464640a  b c
+--R             + 
+--R                                12 5 2                 11 7
+--R               - 11665575772160a  b c  - 2926837760000a  b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                              15 4                 14 2 3                 13 4 2
+--R               - 223606734848a  c  - 4512735559680a  b c  - 9393143808000a  b c
+--R             + 
+--R                               12 6
+--R               - 3608909185024a  b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                                 15   3                 14 3 2
+--R                 - 1203396149248a  b c  - 5408303349760a  b c
+--R               + 
+--R                                 13 5
+--R                 - 3384820105216a  b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                           16 3                 15 2 2                 14 4   9
+--R           (- 145492017152a  c  - 2106413023232a  b c  - 2371459481600a  b c)x
+--R         + 
+--R                           16   2                 15 3   8
+--R           (- 497142464512a  b c  - 1201785536512a  b c)x
+--R         + 
+--R                          17 2                16 2   7               17     6
+--R           (- 53687091200a  c  - 416074956800a  b c)x  - 88046829568a  b c x
+--R         + 
+--R                        18   5
+--R           - 8589934592a  c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                             7   8           6 3 7            5 5 6
+--R                     1048576a b c  + 9175040a b c  + 17891328a b c
+--R                   + 
+--R                              4 7 5           3 9 4          2 11 3
+--R                     11714560a b c  + 2928640a b c  + 279552a b  c
+--R                   + 
+--R                            13 2      15
+--R                     8960a b  c  + 64b  c
+--R                *
+--R                    17
+--R                   x
+--R               + 
+--R                             8 8            7 2 7             6 4 6
+--R                     2228224a c  + 66846720a b c  + 253460480a b c
+--R                   + 
+--R                               5 6 5             4 8 4            3 10 3
+--R                     278806528a b c  + 112020480a b c  + 17425408a b  c
+--R                   + 
+--R                            2 12 2           14       16
+--R                     990080a b  c  + 16320a b  c + 34b
+--R                *
+--R                    16
+--R                   x
+--R               + 
+--R                               8   7              7 3 6              6 5 5
+--R                     150994944a b c  + 1310195712a b c  + 2526806016a b c
+--R                   + 
+--R                                5 7 4             4 9 3            3 11 2
+--R                     1629388800a b c  + 398295040a b c  + 36661248a b  c
+--R                   + 
+--R                             2 13           15
+--R                     1096704a b  c + 6528a b
+--R                *
+--R                    15
+--R                   x
+--R               + 
+--R                               9 7              8 2 6               7 4 5
+--R                     106954752a c  + 3137863680a b c  + 11557797888a b c
+--R                   + 
+--R                                 6 6 4              5 8 3             4 10 2
+--R                     12224593920a b c  + 4643758080a b c  + 662165504a b  c
+--R                   + 
+--R                              3 12           2 14
+--R                     32248320a b  c + 372096a b
+--R                *
+--R                    14
+--R                   x
+--R               + 
+--R                                9   6               8 3 5               7 5 4
+--R                     3523215360a b c  + 29286727680a b c  + 53343682560a b c
+--R                   + 
+--R                                 6 7 3              5 9 2             4 11
+--R                     31752192000a b c  + 6879641600a b c  + 515973120a b  c
+--R                   + 
+--R                             3 13
+--R                     9922560a b
+--R                *
+--R                    13
+--R                   x
+--R               + 
+--R                                10 6               9 2 5                8 4 4
+--R                     1497366528a  c  + 41617981440a b c  + 142772797440a b c
+--R                   + 
+--R                                  7 6 3               6 8 2              5 10
+--R                     136915451904a b c  + 45008732160a b c  + 5056536576a b  c
+--R                   + 
+--R                               4 12
+--R                     150492160a b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                                 10   5                9 3 4
+--R                     31004295168a  b c  + 237376634880a b c
+--R                   + 
+--R                                  8 5 3                7 7 2               6 9
+--R                     386584805376a b c  + 195593502720a b c  + 32598917120a b c
+--R                   + 
+--R                                5 11
+--R                     1444724736a b
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                                11 5                10 2 4                9 4 3
+--R                     9412018176a  c  + 238760755200a  b c  + 724240957440a b c
+--R                   + 
+--R                                  8 6 2                7 8               6 10
+--R                     582178308096a b c  + 144599482368a b c + 9372188672a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                                  11   4                10 3 3
+--R                     132875550720a  b c  + 891373486080a  b c
+--R                   + 
+--R                                   9 5 2                8 7                7 9
+--R                     1203354206208a b c  + 453645434880a b c + 42844291072a b
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                                 12 4                11 2 3
+--R                     31373393920a  c  + 692060160000a  b c
+--R                   + 
+--R                                 10 4 2                 9 6                 8 8
+--R                   1724383232000a  b c  + 1021365452800a b c + 141764198400a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                                  12   3                 11 3 2
+--R                     307090161664a  b c  + 1679399321600a  b c
+--R                   + 
+--R                                   10 5                 9 7
+--R                     1655407902720a  b c + 344876646400a b
+--R                *
+--R                    7
+--R                   x
+--R               + 
+--R                                 13 3                 12 2 2
+--R                     59324235776a  c  + 1059984506880a  b c
+--R                   + 
+--R                                   11 4                 10 6
+--R                     1913860915200a  b c + 620777963520a  b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                                    13   2                 12 3
+--R                       390842023936a  b c  + 1538940469248a  b c
+--R                     + 
+--R                                    11 5
+--R                       824432394240a  b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                              14 2                13 2                 12 4  4
+--R                 (63887638528a  c  + 817385963520a  b c + 796951314432a  b )x
+--R               + 
+--R                               14                   13 3  3
+--R                 (257698037760a  b c + 544923975680a  b )x
+--R               + 
+--R                              15                 14 2  2               15
+--R                 (36507222016a  c + 249644974080a  b )x  + 68719476736a  b x
+--R               + 
+--R                            16
+--R                 8589934592a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                          8 9           7 2 8            6 4 7            5 6 6
+--R                 - 131072a c  - 3932160a b c  - 14909440a b c  - 16400384a b c
+--R               + 
+--R                           4 8 5           3 10 4         2 12 3         14 2
+--R                 - 6589440a b c  - 1025024a b  c  - 58240a b  c  - 960a b  c
+--R               + 
+--R                     16
+--R                 - 2b  c
+--R            *
+--R                17
+--R               x
+--R           + 
+--R                            8   8             7 3 7             6 5 6
+--R                 - 17825792a b c  - 155975680a b c  - 304152576a b c
+--R               + 
+--R                             5 7 5            4 9 4           3 11 3
+--R                 - 199147520a b c  - 49786880a b c  - 4752384a b  c
+--R               + 
+--R                          2 13 2          15
+--R                 - 152320a b  c  - 1088a b  c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                            9 8             8 2 7              7 4 6
+--R                 - 18874368a c  - 561512448a b c  - 2105671680a b c
+--R               + 
+--R                              6 6 5             5 8 4             4 10 3
+--R                 - 2281144320a b c  - 896163840a b c  - 134424576a b  c
+--R               + 
+--R                           3 12 2         2 14
+--R                 - 7128576a b  c  - 97920a b  c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                             9   7              8 3 6               7 5 5
+--R                 - 836763648a b c  - 7112491008a b c  - 13335920640a b c
+--R               + 
+--R                              6 7 4              5 9 3             4 11 2
+--R                 - 8255569920a b c  - 1891901440a b c  - 154791936a b  c
+--R               + 
+--R                           3 13
+--R                 - 3472896a b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                             10 7               9 2 6               8 4 5
+--R                 - 440401920a  c  - 12551454720a b c  - 44453068800a b c
+--R               + 
+--R                               7 6 4               6 8 3              5 10 2
+--R                 - 44453068800a b c  - 15479193600a b c  - 1891901440a b  c
+--R               + 
+--R                            4 12
+--R                 - 64496640a b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                               10   6               9 3 5                8 5 4
+--R                 - 11098128384a  b c  - 87860183040a b c  - 149362311168a b c
+--R               + 
+--R                               7 7 3               6 9 2             5 11
+--R                 - 80015523840a b c  - 14447247360a b c  - 722362368a b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                              11 6                10 2 5                9 4 4
+--R                 - 3875536896a  c  - 101732843520a  b c  - 322154004480a b c
+--R               + 
+--R                                8 6 3               7 8 2              6 10
+--R                 - 273830903808a b c  - 73347563520a b c  - 5297324032a b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                               11   5                10 3 4                9 5 3
+--R                 - 63669534720a  b c  - 445686743040a  b c  - 635103608832a b c
+--R               + 
+--R                                8 7 2               7 9
+--R                 - 257065746432a b c  - 26777681920a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                               12 5                11 2 4                 10 4 3
+--R                 - 16609443840a  c  - 382017208320a  b c  - 1002795171840a  b c
+--R               + 
+--R                                9 6 2               8 8
+--R                 - 635103608832a b c  - 96399654912a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                                12   4                 11 3 3
+--R                 - 184549376000a  b c  - 1061158912000a  b c
+--R               + 
+--R                                 10 5 2                9 7
+--R                 - 1114216857600a  b c  - 252025241600a b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                               13 4                12 2 3                 11 4 2
+--R                 - 38386270208a  c  - 719742566400a  b c  - 1379506585600a  b c
+--R               + 
+--R                                10 6
+--R                 - 482827304960a  b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                                  13   3                 12 3 2
+--R                   - 282662535168a  b c  - 1177760563200a  b c
+--R                 + 
+--R                                  11 5
+--R                   - 677212323840a  b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            14 3                13 2 2                12 4   5
+--R             (- 48855252992a  c  - 659545915392a  b c  - 687026995200a  b c)x
+--R           + 
+--R                             14   2                13 3   4
+--R             (- 217969590272a  b c  - 490431578112a  b c)x
+--R           + 
+--R                            15 2                14 2   3               15     2
+--R             (- 32212254720a  c  - 233538846720a  b c)x  - 66571993088a  b c x
+--R           + 
+--R                          16
+--R             - 8589934592a  c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                          8 9           7 2 8            6 4 7            5 6 6
+--R                 - 131072a c  - 3932160a b c  - 14909440a b c  - 16400384a b c
+--R               + 
+--R                           4 8 5           3 10 4         2 12 3         14 2
+--R                 - 6589440a b c  - 1025024a b  c  - 58240a b  c  - 960a b  c
+--R               + 
+--R                     16
+--R                 - 2b  c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                            8   8             7 3 7             6 5 6
+--R                 - 17891328a b c  - 157941760a b c  - 311607296a b c
+--R               + 
+--R                             5 7 5            4 9 4           3 11 3
+--R                 - 207347712a b c  - 53081600a b c  - 5264896a b  c
+--R               + 
+--R                          2 13 2          15     17
+--R                 - 181440a b  c  - 1568a b  c - b
+--R            *
+--R                17
+--R               x
+--R           + 
+--R                            9 8             8 2 7              7 4 6
+--R                 - 19005440a c  - 574881792a b c  - 2203156480a b c
+--R               + 
+--R                              6 6 5              5 8 4             4 10 3
+--R                 - 2458566656a b c  - 1008184320a b c  - 161807360a b  c
+--R               + 
+--R                           3 12 2          2 14          16
+--R                 - 9702784a b  c  - 179520a b  c - 578a b
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                             9   7              8 3 6               7 5 5
+--R                 - 865075200a b c  - 7580418048a b c  - 14809890816a b c
+--R               + 
+--R                              6 7 4              5 9 3             4 11 2
+--R                 - 9722019840a b c  - 2439557120a b c  - 234224640a b  c
+--R               + 
+--R                           3 13          2 15
+--R                 - 7585536a b  c - 55488a b
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                             10 7               9 2 6               8 4 5
+--R                 - 459276288a  c  - 13597409280a b c  - 50676498432a b c
+--R               + 
+--R                               7 6 4               6 8 3              5 10 2
+--R                 - 54455009280a b c  - 21154897920a b c  - 3121637376a b  c
+--R               + 
+--R                             4 12            3 14
+--R                 - 161241600a b  c - 2108544a b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                               10   6                9 3 5                8 5 4
+--R                 - 12199133184a  b c  - 102503546880a b c  - 189370073088a b c
+--R               + 
+--R                                7 7 3               6 9 2              5 11
+--R                 - 114942935040a b c  - 25626664960a b c  - 2012295168a b  c
+--R               + 
+--R                            4 13
+--R                 - 42170880a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                              11 6                10 2 5                9 4 4
+--R                 - 4315938816a  c  - 121154568192a  b c  - 420996710400a b c
+--R               + 
+--R                                8 6 3                7 8 2               6 10
+--R                 - 410746355712a b c  - 138360176640a b c  - 16132759552a b  c
+--R               + 
+--R                             5 12
+--R                 - 511673344a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                               11   5                10 3 4                9 5 3
+--R                 - 77233913856a  b c  - 598286008320a  b c  - 989473013760a b c
+--R               + 
+--R                                8 7 2               7 9               6 11
+--R                 - 511337299968a b c  - 87900651520a b c - 4093386752a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                               12 5                11 2 4                 10 4 3
+--R                 - 20484980736a  c  - 525273661440a  b c  - 1615614443520a  b c
+--R               + 
+--R                                 9 6 2                8 8                7 10
+--R                 - 1323132518400a b c  - 337398792192a b c - 22761029632a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                                12   4                 11 3 3
+--R                 - 259291873280a  b c  - 1761523793920a  b c
+--R               + 
+--R                                 10 5 2                9 7                8 9
+--R                 - 2417850580992a  b c  - 932493393920a b c - 91044118528a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                               13 4                 12 2 3
+--R                 - 54995714048a  c  - 1227253350400a  b c
+--R               + 
+--R                               11 4 2                 10 6                 9 8
+--R               - 3103889817600a  b c  - 1875598376960a  b c - 267776819200a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                                13   3                 12 3 2
+--R                 - 493787021312a  b c  - 2737202790400a  b c
+--R               + 
+--R                                 11 5                 10 7
+--R                 - 2746472202240a  b c - 586290298880a  b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                               14 3                 13 2 2                 12 4
+--R                 - 87241523200a  c  - 1578199154688a  b c  - 2895328051200a  b c
+--R               + 
+--R                                11 6
+--R                 - 959384125440a  b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                                  14   2                 13 3
+--R                   - 535528734720a  b c  - 2139296366592a  b c
+--R                 + 
+--R                                   12 5
+--R                   - 1167945891840a  b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                            15 2                 14 2                  13 4  4
+--R             (- 81067507712a  c  - 1050924810240a  b c - 1042167103488a  b )x
+--R           + 
+--R                             15                   14 3  3
+--R             (- 308163903488a  b c - 661693399040a  b )x
+--R           + 
+--R                            16                 15 2  2               16
+--R             (- 40802189312a  c - 282930970624a  b )x  - 73014444032a  b x
+--R           + 
+--R                          17
+--R             - 8589934592a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                         7   9           6 3 8            5 5 7            4 7 6
+--R                 1048576a b c  + 9175040a b c  + 17891328a b c  + 11714560a b c
+--R               + 
+--R                         3 9 5          2 11 4          13 3      15 2
+--R                 2928640a b c  + 279552a b  c  + 8960a b  c  + 64b  c
+--R            *
+--R                18
+--R               x
+--R           + 
+--R                         8 9            7 2 8             6 4 7
+--R                 2228224a c  + 67371008a b c  + 258048000a b c
+--R               + 
+--R                           5 6 6             4 8 5            3 10 4
+--R                 287752192a b c  + 117877760a b c  + 18889728a b  c
+--R               + 
+--R                         2 12 3           14 2      16
+--R                 1129856a b  c  + 20800a b  c  + 66b  c
+--R            *
+--R                17
+--R               x
+--R           + 
+--R                           8   8              7 3 7              6 5 6
+--R                 152043520a b c  + 1341390848a b c  + 2643787776a b c
+--R               + 
+--R                            5 7 5             4 9 4            3 11 3
+--R                 1756119040a b c  + 448081920a b c  + 44129280a b  c
+--R               + 
+--R                         2 13 2           15
+--R                 1492736a b  c  + 11968a b  c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                           9 8              8 2 7               7 4 6
+--R                 106954752a c  + 3203923968a b c  + 12119310336a b c
+--R               + 
+--R                             6 6 5              5 8 4             4 10 3
+--R                 13277429760a b c  + 5295513600a b c  + 811526144a b  c
+--R               + 
+--R                          3 12 2          2 14
+--R                 44468736a b  c  + 646272a b  c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                            9   7               8 3 6               7 5 5
+--R                 3567255552a b c  + 30541873152a b c  + 57788989440a b c
+--R               + 
+--R                             6 7 4              5 9 3             4 11 2
+--R                 36197498880a b c  + 8427560960a b c  + 705163264a b  c
+--R               + 
+--R                          3 13
+--R                 16372224a b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                            10 7               9 2 6                8 4 5
+--R                 1497366528a  c  + 42939187200a b c  + 153232343040a b c
+--R               + 
+--R                              7 6 4               6 8 3              5 10 2
+--R                 154696679424a b c  + 54534389760a b c  + 6776446976a b  c
+--R               + 
+--R                           4 12
+--R                 236487680a b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                             10   6                9 3 5                8 5 4
+--R                 31532777472a  b c  + 251249295360a b c  + 430514896896a b c
+--R               + 
+--R                              7 7 3               6 9 2              5 11
+--R                 232934080512a b c  + 42600857600a b c  + 2167087104a b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            11 6                10 2 5                9 4 4
+--R                 9412018176a  c  + 248449597440a  b c  + 792062853120a b c
+--R               + 
+--R                              8 6 3                7 8 2               6 10
+--R                 678824509440a b c  + 183718182912a b c  + 13447053312a b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                              11   5                10 3 4                 9 5 3
+--R                 135643791360a  b c  + 955043020800a  b c  + 1370486734848a b c
+--R               + 
+--R                              8 7 2               7 9
+--R                 559496036352a b c  + 58910900224a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                             12 5                11 2 4                 10 4 3
+--R                 31373393920a  c  + 725279047680a  b c  + 1915391836160a  b c
+--R               + 
+--R                               9 6 2                8 8
+--R                 1221924487168a b c  + 187128741888a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                              12   4                 11 3 3
+--R                 314472136704a  b c  + 1817811353600a  b c
+--R               + 
+--R                               10 5 2                9 7
+--R                 1920697630720a  b c  + 437728051200a b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             13 4                 12 2 3                 11 4 2
+--R                 59324235776a  c  + 1117563912192a  b c  + 2153775104000a  b c
+--R               + 
+--R                              10 6
+--R                 758728622080a  b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                           13   3                 12 3 2                11 5   6
+--R             (401311006720a  b c  + 1680271736832a  b c  + 971652464640a  b c)x
+--R           + 
+--R                          14 3                13 2 2                12 4   5
+--R             (63887638528a  c  + 866241216512a  b c  + 906875633664a  b c)x
+--R           + 
+--R                           14   2                13 3   4
+--R             (265214230528a  b c  + 599416373248a  b c)x
+--R           + 
+--R                          15 2                14 2   3               15     2
+--R             (36507222016a  c  + 265751101440a  b c)x  + 70866960384a  b c x
+--R           + 
+--R                        16
+--R             8589934592a  c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 243
+
+--S 244 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                           6 2 6           4 6 4          3 8 3         2 10 2
+--R                   3010560a b c  - 2822400a b c  + 806400a b c  + 62160a b  c
+--R                 + 
+--R                             12        14
+--R                   - 23520a b  c - 315b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           7   6            6 3 5            5 5 4
+--R                   6021120a b c  + 24084480a b c  - 23708160a b c
+--R                 + 
+--R                             4 7 3           3 9 2          2 11            13
+--R                   - 2257920a b c  + 3457440a b c  - 329280a b  c - 30870a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            7 2 5           6 4 4            5 6 3
+--R                   72253440a b c  - 6021120a b c  - 63221760a b c
+--R                 + 
+--R                            4 8 2          3 10           2 12
+--R                   20321280a b c  + 658560a b  c - 493920a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            8   5             7 3 4             6 5 3
+--R                   48168960a b c  + 156549120a b c  - 186654720a b c
+--R                 + 
+--R                            5 7 2            4 9            3 11
+--R                   13547520a b c  + 17498880a b c - 2963520a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             8 2 4             7 4 3             6 6 2
+--R                   240844800a b c  - 120422400a b c  - 120422400a b c
+--R                 + 
+--R                            5 8            4 10
+--R                   67737600a b c - 8467200a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            9   4             8 3 3             7 5 2
+--R                   96337920a b c  + 144506880a b c  - 289013760a b c
+--R                 + 
+--R                             6 7             5 9
+--R                   111390720a b c - 12418560a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                               9 2 3             8 4 2            7 6
+--R                     192675840a b c  - 240844800a b c  + 84295680a b c
+--R                   + 
+--R                               6 8
+--R                     - 9031680a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                       10   3            9 3 2            8 5            7 7
+--R             (55050240a  b c  - 68812800a b c  + 24084480a b c - 2580480a b )x
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b x + a
+--R         + 
+--R                            6   7           5 3 6           4 5 5          3 7 4
+--R                   - 860160a b c  - 3440640a b c  + 3386880a b c  + 322560a b c
+--R                 + 
+--R                            2 9 3           11 2        13
+--R                   - 493920a b c  + 47040a b  c  + 4410b  c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                              6 2 6           5 4 5            4 6 4
+--R                   - 21504000a b c  - 1720320a b c  + 21450240a b c
+--R                 + 
+--R                             3 8 3          2 10 2            12         14
+--R                   - 5483520a b c  - 682080a b  c  + 188160a b  c + 4410b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              7   6            6 3 5            5 5 4
+--R                   - 21504000a b c  - 91176960a b c  + 85102080a b c
+--R                 + 
+--R                          4 7 3            3 9 2           2 11             13
+--R                 12579840a b c  - 13799520a b c  + 1128960a b  c + 145530a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                               7 2 5           6 4 4             5 6 3
+--R                   - 178913280a b c  + 3440640a b c  + 166871040a b c
+--R                 + 
+--R                              4 8 2           3 10            2 12
+--R                   - 50319360a b c  - 2849280a b  c + 1411200a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              8   5             7 3 4             6 5 3
+--R                   - 89456640a b c  - 307937280a b c  + 355246080a b c
+--R                 + 
+--R                              5 7 2            4 9            3 11
+--R                   - 16558080a b c  - 37336320a b c + 6108480a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                               8 2 4             7 4 3             6 6 2
+--R                   - 371589120a b c  + 172032000a b c  + 202997760a b c
+--R                 + 
+--R                               5 8             4 10
+--R                   - 110530560a b c + 13708800a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               9   4             8 3 3             7 5 2
+--R                   - 123863040a b c  - 199557120a b c  + 388792320a b c
+--R                 + 
+--R                               6 7             5 9
+--R                   - 149237760a b c + 16611840a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                               9 2 3             8 4 2            7 6
+--R                   - 220200960a b c  + 275251200a b c  - 96337920a b c
+--R                 + 
+--R                            6 8
+--R                   10321920a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         10   3            9 3 2            8 5            7 7
+--R             (- 55050240a  b c  + 68812800a b c  - 24084480a b c + 2580480a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                           6   6           5 3 5           4 5 4          3 7 3
+--R                   1720320a b c  + 6881280a b c  - 6773760a b c  - 645120a b c
+--R                 + 
+--R                          2 9 2           11         13
+--R                   987840a b c  - 94080a b  c - 8820b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            6 2 5           5 4 4            4 6 3
+--R                   41287680a b c  - 3440640a b c  - 36126720a b c
+--R                 + 
+--R                            3 8 2          2 10             12
+--R                   11612160a b c  + 376320a b  c - 282240a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                            7   5             6 3 4             5 5 3
+--R                   41287680a b c  + 134184960a b c  - 159989760a b c
+--R                 + 
+--R                            4 7 2            3 9            2 11
+--R                   11612160a b c  + 14999040a b c - 2540160a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             7 2 4             6 4 3             5 6 2
+--R                   275251200a b c  - 137625600a b c  - 137625600a b c
+--R                 + 
+--R                            4 8            3 10
+--R                   77414400a b c - 9676800a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                             8   4             7 3 3             6 5 2
+--R                   137625600a b c  + 206438400a b c  - 412876800a b c
+--R                 + 
+--R                             5 7             4 9
+--R                   159129600a b c - 17740800a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                             8 2 3             7 4 2             6 6
+--R                   330301440a b c  - 412876800a b c  + 144506880a b c
+--R                 + 
+--R                              5 8
+--R                   - 15482880a b
+--R              *
+--R                 x
+--R             + 
+--R                         9   3             8 3 2            7 5            6 7
+--R               110100480a b c  - 137625600a b c  + 48168960a b c - 5160960a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                             6 2 6           4 6 4           3 8 3
+--R                   - 6021120a b c  + 5644800a b c  - 1612800a b c
+--R                 + 
+--R                            2 10 2           12        14
+--R                   - 124320a b  c  + 47040a b  c + 630b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                              7   6            6 3 5            5 5 4
+--R                   - 12042240a b c  - 48168960a b c  + 47416320a b c
+--R                 + 
+--R                           4 7 3           3 9 2          2 11            13
+--R                   4515840a b c  - 6914880a b c  + 658560a b  c + 61740a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                               7 2 5            6 4 4             5 6 3
+--R                   - 144506880a b c  + 12042240a b c  + 126443520a b c
+--R                 + 
+--R                              4 8 2           3 10           2 12
+--R                   - 40642560a b c  - 1317120a b  c + 987840a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                              8   5             7 3 4             6 5 3
+--R                   - 96337920a b c  - 313098240a b c  + 373309440a b c
+--R                 + 
+--R                              5 7 2            4 9            3 11
+--R                   - 27095040a b c  - 34997760a b c + 5927040a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                               8 2 4             7 4 3             6 6 2
+--R                   - 481689600a b c  + 240844800a b c  + 240844800a b c
+--R                 + 
+--R                               5 8             4 10
+--R                   - 135475200a b c + 16934400a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                               9   4             8 3 3             7 5 2
+--R                   - 192675840a b c  - 289013760a b c  + 578027520a b c
+--R                 + 
+--R                               6 7             5 9
+--R                   - 222781440a b c + 24837120a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                               9 2 3             8 4 2             7 6
+--R                   - 385351680a b c  + 481689600a b c  - 168591360a b c
+--R                 + 
+--R                            6 8
+--R                   18063360a b
+--R              *
+--R                 x
+--R             + 
+--R                         10   3             9 3 2            8 5            7 7
+--R             - 110100480a  b c  + 137625600a b c  - 48168960a b c + 5160960a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                          3   9           2 3 8            5 7         7 6  13
+--R               (- 4587520a b c  - 5734400a b c  - 860160a b c  - 10240b c )x
+--R             + 
+--R                             4 9            3 2 8            2 4 7
+--R                   - 9175040a c  - 53903360a b c  - 27238400a b c
+--R                 + 
+--R                               6 6         8 5
+--R                   - 2078720a b c  - 12800b c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                               4   8             3 3 7            2 5 6
+--R                   - 128909312a b c  - 197951488a b c  - 42663936a b c
+--R                 + 
+--R                               7 5       9 4
+--R                   - 1292288a b c  - 256b c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                              5 8             4 2 7             3 4 6
+--R                   - 88080384a c  - 545857536a b c  - 290877440a b c
+--R                 + 
+--R                              2 6 5          8 4       10 3
+--R                   - 22134784a b c  - 2304a b c  + 288b  c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                               5   7             4 3 6             3 5 5
+--R                   - 637091840a b c  - 903024640a b c  - 149940224a b c
+--R                 + 
+--R                        2 7 4          9 3       11 2
+--R                   1536a b c  + 1984a b c  - 336b  c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                               6 7              5 2 6             4 4 5
+--R                   - 266076160a c  - 1413672960a b c  - 514698240a b c
+--R                 + 
+--R                         3 6 4         2 8 3         10 2       12
+--R                   53760a b c  - 17280a b c  - 560a b  c  + 420b  c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                6   6             5 3 5          4 5 4
+--R                   - 1090396160a b c  - 985169920a b c  - 483840a b c
+--R                 + 
+--R                           3 7 3         2 9 2          11        13
+--R                   - 46080a b c  + 70560a b c  - 6720a b  c - 630b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                               7 6              6 2 5           5 4 4
+--R                   - 330301440a c  - 1060577280a b c  - 1505280a b c
+--R                 + 
+--R                             4 6 3           3 8 2         2 10            12
+--R                   - 7375872a b c  + 2546432a b c  + 23520a b  c - 52920a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                               7   5            6 3 4            5 5 3
+--R                   - 603258880a b c  + 39567360a b c  - 49373184a b c
+--R                 + 
+--R                           4 7 2           3 9           2 11
+--R                   5146624a b c  + 3951360a b c - 705600a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                               8 5             7 2 4            6 4 3
+--R                   - 146800640a c  + 103219200a b c  - 56770560a b c
+--R                 + 
+--R                              5 6 2            4 8            3 10
+--R                   - 45158400a b c  + 26772480a b c - 3386880a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            8   4            7 3 3             6 5 2
+--R                   59637760a b c  + 80281600a b c  - 167444480a b c
+--R                 + 
+--R                            5 7            4 9
+--R                   64942080a b c - 7257600a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                               8 2 3             7 4 2            6 6
+--R                     151388160a b c  - 189235200a b c  + 66232320a b c
+--R                   + 
+--R                               5 8
+--R                     - 7096320a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         9   3            8 3 2            7 5            6 7
+--R               (55050240a b c  - 68812800a b c  + 24084480a b c - 2580480a b )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                        3 10           2 2 9             4 8          6 7  14
+--R               (1310720a c   + 6881280a b c  + 2867200a b c  + 143360b c )x
+--R             + 
+--R                           3   9            2 3 8              5 7          7 6
+--R                 (34406400a b c  + 52183040a b c  + 11038720a b c  + 322560b c )
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                            4 9             3 2 8             2 4 7
+--R                   34865152a c  + 231899136a b c  + 140091392a b c
+--R                 + 
+--R                              6 6          8 5
+--R                   14350336a b c  + 182784b c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             4   8             3 3 7             2 5 6
+--R                   366198784a b c  + 631873536a b c  + 160161792a b c
+--R                 + 
+--R                             7 5       9 4
+--R                   6268416a b c  - 448b c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                             5 8              4 2 7             3 4 6
+--R                   189005824a c  + 1274699776a b c  + 756224000a b c
+--R                 + 
+--R                            2 6 5          8 4       10 3
+--R                   66433024a b c  - 5376a b c  + 672b  c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              5   7              4 3 6             3 5 5
+--R                   1183293440a b c  + 1812285440a b c  + 330781696a b c
+--R                 + 
+--R                        2 7 4          9 3        11 2
+--R                   5376a b c  + 6944a b c  - 1176b  c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                             6 7              5 2 6             4 4 5
+--R                   412876800a c  + 2325442560a b c  + 906644480a b c
+--R                 + 
+--R                          3 6 4          2 8 3          10 2        12
+--R                   376320a b c  - 120960a b c  - 3920a b  c  + 2940b  c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              6   6              5 3 5            4 5 4
+--R                   1524490240a b c  + 1442918400a b c  + 10547712a b c
+--R                 + 
+--R                          3 7 3           2 9 2            11         13
+--R                   114176a b c  - 1240288a b c  + 146160a b  c + 8190b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                             7 6              6 2 5           5 4 4
+--R                   403701760a c  + 1315758080a b c  + 8816640a b c
+--R                 + 
+--R                            4 6 3            3 8 2         2 10             12
+--R                   33567744a b c  - 12018944a b c  + 23520a b  c + 229320a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             7   5             6 3 4             5 5 3
+--R                   653721600a b c  - 104939520a b c  + 132808704a b c
+--R                 + 
+--R                              4 7 2            3 9            2 11
+--R                   - 15110144a b c  - 10080000a b c + 1834560a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             8 5             7 2 4             6 4 3
+--R                   146800640a c  - 194969600a b c  + 109527040a b c
+--R                 + 
+--R                            5 6 2            4 8            3 10
+--R                   82432000a b c  - 49566720a b c + 6289920a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              8   4             7 3 3             6 5 2
+--R                   - 87162880a b c  - 114688000a b c  + 241418240a b c
+--R                 + 
+--R                              5 7             4 9
+--R                   - 93757440a b c + 10483200a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                               8 2 3             7 4 2            6 6
+--R                   - 178913280a b c  + 223641600a b c  - 78274560a b c
+--R                 + 
+--R                           5 8
+--R                   8386560a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         9   3            8 3 2            7 5            6 7
+--R             (- 55050240a b c  + 68812800a b c  - 24084480a b c + 2580480a b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      3 10           2 2 9             4 8          6 7  15
+--R           (- 1310720a c   - 6881280a b c  - 2867200a b c  - 143360b c )x
+--R         + 
+--R                       3   9            2 3 8              5 7          7 6  14
+--R           (- 34406400a b c  - 52183040a b c  - 11038720a b c  - 322560b c )x
+--R         + 
+--R                          4 9             3 2 8             2 4 7
+--R               - 34865152a c  - 231899136a b c  - 140091392a b c
+--R             + 
+--R                            6 6          8 5
+--R               - 14350336a b c  - 182784b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                           4   8             3 3 7             2 5 6
+--R               - 366198784a b c  - 631873536a b c  - 160161792a b c
+--R             + 
+--R                           7 5       9 4
+--R               - 6268416a b c  + 448b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           5 8              4 2 7             3 4 6
+--R               - 189005824a c  - 1274699776a b c  - 756224000a b c
+--R             + 
+--R                          2 6 5          8 4       10 3
+--R               - 66433024a b c  + 5376a b c  - 672b  c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                            5   7              4 3 6             3 5 5
+--R               - 1183293440a b c  - 1812285440a b c  - 330781696a b c
+--R             + 
+--R                      2 7 4          9 3        11 2
+--R               - 5376a b c  - 6944a b c  + 1176b  c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                           6 7              5 2 6             4 4 5
+--R               - 412876800a c  - 2325442560a b c  - 906644480a b c
+--R             + 
+--R                        3 6 4          2 8 3          10 2        12
+--R               - 376320a b c  + 120960a b c  + 3920a b  c  - 2940b  c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                            6   6              5 3 5            4 5 4
+--R               - 1522655232a b c  - 1445541888a b c  - 14092288a b c
+--R             + 
+--R                       3 7 3           2 9 2            11         13
+--R               1508096a b c  + 1299872a b c  - 194040a b  c - 8820b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                           7 6              6 2 5            5 4 4
+--R               - 400031744a c  - 1306324992a b c  - 47903744a b c
+--R             + 
+--R                          4 6 3            3 8 2          2 10             12
+--R               - 31535616a b c  + 17858176a b c  - 764400a b  c - 291060a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                           7   5            6 3 4             5 5 3
+--R               - 609681408a b c  + 38305792a b c  - 209879040a b c
+--R             + 
+--R                        4 7 2            3 9            2 11
+--R               54347776a b c  + 10080000a b c - 2822400a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                           8 5             7 2 4             6 4 3
+--R               - 117440512a c  + 248414208a b c  - 388907008a b c
+--R             + 
+--R                          5 6 2            4 8             3 10
+--R               - 27639808a b c  + 76661760a b c - 12216960a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                         8   4             7 3 3             6 5 2
+--R               233963520a b c  - 168591360a b c  - 355819520a b c
+--R             + 
+--R                         5 7             4 9
+--R               206653440a b c - 27417600a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        9 4             8 2 3             7 4 2             6 6
+--R               58720256a c  + 183042048a b c  - 584105984a b c  + 267939840a b c
+--R             + 
+--R                          5 8
+--R               - 33223680a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      9   3             8 3 2             7 5             6 7  2
+--R           (172490752a b c  - 383516672a b c  + 168591360a b c - 20643840a b )x
+--R         + 
+--R                     10 3            9 2 2            8 4            7 6
+--R           (33554432a  c  - 89915392a b c  + 41287680a b c - 5160960a b )x
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                    3   10           2 3 9            5 8         7 7  16
+--R           (4587520a b c   + 5734400a b c  + 860160a b c  + 10240b c )x
+--R         + 
+--R                       4 10            3 2 9            2 4 8             6 7
+--R               9175040a c   + 58490880a b c  + 32972800a b c  + 2938880a b c
+--R             + 
+--R                     8 6
+--R               23040b c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                         4   9             3 3 8            2 5 7
+--R               142671872a b c  + 257589248a b c  + 70762496a b c
+--R             + 
+--R                         7 6         9 5
+--R               3381248a b c  + 13056b c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        5 9             4 2 8             3 4 7            2 6 6
+--R               97255424a c  + 728670208a b c  + 516067328a b c  + 66877440a b c
+--R             + 
+--R                         8 5      10 4
+--R               1307392a b c  - 32b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         5   8              4 3 7             3 5 6
+--R               854081536a b c  + 1646833664a b c  + 483481600a b c
+--R             + 
+--R                        2 7 5         9 4      11 3
+--R               23425536a b c  + 576a b c  + 48b  c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         6 8              5 2 7              4 4 6
+--R               354156544a c  + 2596622336a b c  + 1708600320a b c
+--R             + 
+--R                         3 6 5         2 8 4          10 3      12 2
+--R               172021248a b c  + 18048a b c  - 1712a b  c  - 84b  c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          6   7              5 3 6             4 5 5
+--R               1993564160a b c  + 3301867520a b c  + 665122304a b c
+--R             + 
+--R                      3 7 4         2 9 3          11 2       13
+--R               - 9216a b c  - 55264a b c  + 7616a b  c  + 210b  c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         7 7              6 2 6              5 4 5
+--R               595853312a c  + 3563298816a b c  + 1506957312a b c
+--R             + 
+--R                     4 6 4           3 8 3         2 10 2           12        14
+--R             7515648a b c  - 3317248a b c  + 12320a b  c  + 68040a b  c + 630b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                          7   6              6 3 5            5 5 4
+--R               2010849280a b c  + 2023870464a b c  + 78966272a b c
+--R             + 
+--R                         4 7 3           3 9 2           2 11            13
+--R               - 9225728a b c  - 7402528a b c  + 1076880a b  c + 62370a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         8 6              7 2 5             6 4 4
+--R               463994880a c  + 1523781632a b c  + 163064832a b c
+--R             + 
+--R                         5 6 3            4 8 2           3 10            2 12
+--R               100154880a b c  - 58122624a b c  + 2058000a b  c + 1049580a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                         8   5            7 3 4             6 5 3
+--R               581369856a b c  - 65060864a b c  + 480714752a b c
+--R             + 
+--R                           5 7 2            4 9            3 11
+--R               - 124135424a b c  - 25401600a b c + 6914880a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        9 5             8 2 4             7 4 3            6 6 2
+--R               92274688a c  - 423985152a b c  + 704806912a b c  + 52785152a b c
+--R             + 
+--R                           5 8             4 10
+--R               - 143001600a b c + 22861440a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                           9   4             8 3 3             7 5 2
+--R               - 341180416a b c  + 265814016a b c  + 531578880a b c
+--R             + 
+--R                           6 7             5 9
+--R               - 313098240a b c + 41771520a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          10 4             9 2 3             8 4 2
+--R               - 75497472a  c  - 220135424a b c  + 743981056a b c
+--R             + 
+--R                           7 6             6 8
+--R               - 344494080a b c + 42900480a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                           10   3             9 3 2             8 5
+--R               - 189267968a  b c  + 428474368a b c  - 189235200a b c
+--R             + 
+--R                        7 7
+--R               23224320a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       11 3            10 2 2            9 4            8 6
+--R           (- 33554432a  c  + 89915392a  b c  - 41287680a b c + 5160960a b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                      3 8            2 2 7              4 6           6 5  6
+--R             (9175040a c  + 48168960a b c  + 20070400a b c  + 1003520b c )x
+--R           + 
+--R                        3   7             2 3 6              5 5  5
+--R             (220200960a b c  + 256901120a b c  + 32112640a b c )x
+--R           + 
+--R                        4 7             3 2 6             2 4 5  4
+--R             (220200960a c  + 990904320a b c  + 289013760a b c )x
+--R           + 
+--R                         4   6              3 3 5  3
+--R             (1468006400a b c  + 1101004800a b c )x
+--R           + 
+--R                        5 6              4 2 5  2              5   5
+--R             (734003200a c  + 2018508800a b c )x  + 1761607680a b c x
+--R           + 
+--R                       6 5
+--R             587202560a c
+--R        *
+--R                          +--------------+
+--R            +---+ +-+ +-+ |   2
+--R           \|- c \|a \|c \|c x  + b x + a
+--R       + 
+--R                         3   8            2 3 7             5 6         7 5  7
+--R             (- 32112640a b c  - 40140800a b c  - 6021120a b c  - 71680b c )x
+--R           + 
+--R                            4 8             3 2 7             2 4 6
+--R                 - 64225280a c  - 337182720a b c  - 140492800a b c
+--R               + 
+--R                             6 5
+--R                 - 7024640a b c
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          4   7             3 3 6             2 5 5  5
+--R             (- 770703360a b c  - 899153920a b c  - 112394240a b c )x
+--R           + 
+--R                          5 7              4 2 6             3 4 5  4
+--R             (- 513802240a c  - 2312110080a b c  - 674365440a b c )x
+--R           + 
+--R                           5   6              4 3 5  3
+--R             (- 2569011200a b c  - 1926758400a b c )x
+--R           + 
+--R                           6 6              5 2 5  2              6   5
+--R             (- 1027604480a c  - 2825912320a b c )x  - 2055208960a b c x
+--R           + 
+--R                         7 5
+--R             - 587202560a c
+--R        *
+--R            +---+ +-+
+--R           \|- c \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                            6   8          5 3 7           4 5 6          3 7 5
+--R                   - 114688a b c  - 745472a b c  - 1025024a b c  - 439296a b c
+--R                 + 
+--R                           2 9 4          11 3      13 2
+--R                   - 64064a b c  - 2912a b  c  - 28b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                            7 8           6 2 7            5 4 6
+--R                   - 229376a c  - 5390336a b c  - 15468544a b c
+--R                 + 
+--R                              4 6 5           3 8 4          2 10 3
+--R                   - 12300288a b c  - 3349632a b c  - 320320a b  c
+--R                 + 
+--R                            12 2      14
+--R                   - 9464a b  c  - 56b  c
+--R              *
+--R                  19
+--R                 x
+--R             + 
+--R                              7   7            6 3 6             5 5 5
+--R                   - 11698176a b c  - 80740352a b c  - 120207360a b c
+--R                 + 
+--R                              4 7 4           3 9 3          2 11 2
+--R                   - 57547776a b c  - 9902464a b c  - 594048a b  c
+--R                 + 
+--R                             13       15
+--R                   - 10248a b  c - 28b
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                             8 7             7 2 6             6 4 5
+--R                   - 7798784a c  - 188776448a b c  - 562171904a b c
+--R                 + 
+--R                               5 6 4             4 8 3            3 10 2
+--R                   - 468901888a b c  - 136145152a b c  - 14258816a b  c
+--R                 + 
+--R                            2 12           14
+--R                   - 484848a b  c - 3696a b
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                               8   6              7 3 5              6 5 4
+--R                   - 202424320a b c  - 1407508480a b c  - 2109420544a b c
+--R                 + 
+--R                                5 7 3             4 9 2            3 11
+--R                   - 1013482496a b c  - 173402944a b c  - 10038496a b  c
+--R                 + 
+--R                            2 13
+--R                   - 147084a b
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                              9 6              8 2 5              7 4 4
+--R                   - 80969728a c  - 1931919360a b c  - 5626349568a b c
+--R                 + 
+--R                                6 6 3              5 8 2             4 10
+--R                   - 4525287424a b c  - 1232340096a b c  - 113530560a b  c
+--R                 + 
+--R                             3 12
+--R                   - 2772536a b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                                9   5              8 3 4               7 5 3
+--R                   - 1368915968a b c  - 9111732224a b c  - 12801474560a b c
+--R                 + 
+--R                                6 7 2             5 9             4 11
+--R                   - 5548883968a b c  - 789215232a b c - 30011904a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                               10 5              9 2 4               8 4 3
+--R                   - 391118848a  c  - 8787853312a b c  - 23494524928a b c
+--R                 + 
+--R                                 7 6 2              6 8              5 10
+--R                   - 16584114176a b c  - 3614806016a b c - 207068160a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                                10   4               9 3 3               8 5 2
+--R                   - 4638375936a  b c  - 27888451584a b c  - 33686618112a b c
+--R                 + 
+--R                                 7 7              6 9
+--R                   - 11375640576a b c - 969521152a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                11 4               10 2 3               9 4 2
+--R                   - 1030750208a  c  - 20653801472a  b c  - 46725726208a b c
+--R                 + 
+--R                                 8 6               7 8
+--R                   - 25181356032a b c - 3203002368a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                                11   3               10 3 2               9 5
+--R                   - 8673820672a  b c  - 43576721408a  b c  - 39562772480a b c
+--R                 + 
+--R                                8 7
+--R                   - 7642939392a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                                12 3               11 2 2               10 4
+--R                   - 1577058304a  c  - 26134708224a  b c  - 43889197056a  b c
+--R                 + 
+--R                                 9 6
+--R                   - 13323993088a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                             12   2               11 3                10 5  8
+--R               (- 9105833984a  b c  - 33615249408a  b c - 16981426176a  b )x
+--R             + 
+--R                             13 2               12 2                11 4  7
+--R               (- 1400897536a  c  - 16915628032a  b c - 15648423936a  b )x
+--R             + 
+--R                             13                  12 3  6
+--R               (- 5033164800a  b c - 10150215680a  b )x
+--R             + 
+--R                            14               13 2  5              14   4
+--R               (- 671088640a  c - 4395630592a  b )x  - 1140850688a  b x
+--R             + 
+--R                           15 3
+--R               - 134217728a  x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                     7 9          6 2 8           5 4 7          4 6 6
+--R               16384a c  + 372736a b c  + 1025024a b c  + 768768a b c
+--R             + 
+--R                      3 8 5         2 10 4         12 3    14 2
+--R               192192a b c  + 16016a b  c  + 364a b  c  + b  c
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                       7   8            6 3 7            5 5 6           4 7 5
+--R               1638400a b c  + 11182080a b c  + 16400384a b c  + 7687680a b c
+--R             + 
+--R                       3 9 4         2 11 3          13 2     15
+--R               1281280a b c  + 72800a b  c  + 1120a b  c  + 2b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                       8 8            7 2 7             6 4 6             5 6 5
+--R               1638400a c  + 40099840a b c  + 121139200a b c  + 103014912a b c
+--R             + 
+--R                      4 8 4           3 10 3          2 12 2          14     16
+--R             30750720a b c  + 3363360a b  c  + 123760a b  c  + 1150a b  c + b
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                        8   7             7 3 6             6 5 5
+--R               57835520a b c  + 416604160a b c  + 654338048a b c
+--R             + 
+--R                         5 7 4            4 9 3           3 11 2         2 13
+--R               335695360a b c  + 63423360a b c  + 4353440a b  c  + 93240a b  c
+--R             + 
+--R                     15
+--R               394a b
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                        9 7             8 2 6              7 4 5
+--R               28917760a c  + 726118400a b c  + 2260751360a b c
+--R             + 
+--R                          6 6 4             5 8 3            4 10 2
+--R               1992856320a b c  + 621100480a b c  + 71511440a b  c
+--R             + 
+--R                       3 12          2 14
+--R               2782780a b  c + 26265a b
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                         9   6              8 3 5              7 5 4
+--R               621379584a b c  + 4488544256a b c  + 7043606528a b c
+--R             + 
+--R                        6 7 3             5 9 2            4 11           3 13
+--R             3581806592a b c  + 658706048a b c  + 41961920a b  c + 703640a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                         10 6              9 2 5               8 4 4
+--R               207126528a  c  + 5109923840a b c  + 15479797760a b c
+--R             + 
+--R                           7 6 3              6 8 2             5 10
+--R               13053286400a b c  + 3767021440a b c  + 373429056a b  c
+--R             + 
+--R                        4 12
+--R               10042760a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                          10   5               9 3 4               8 5 3
+--R               3097493504a  b c  + 21341143040a b c  + 31222661120a b c
+--R             + 
+--R                           7 7 2              6 9             5 11
+--R               14204600320a b c  + 2143232000a b c + 87779328a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                         11 5               10 2 4               9 4 3
+--R               774373376a  c  + 17941790720a  b c  + 49698897920a b c
+--R             + 
+--R                           8 6 2              7 8              6 10
+--R               36566548480a b c  + 8373422080a b c + 509297152a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                          11   4               10 3 3               9 5 2
+--R               8404336640a  b c  + 52150927360a  b c  + 65321697280a b c
+--R             + 
+--R                           8 7               7 9
+--R               23011983360a b c + 2062151680a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          12 4               11 2 3               10 4 2
+--R               1680867328a  c  + 34652291072a  b c  + 80966975488a  b c
+--R             + 
+--R                           9 6               8 8
+--R               45281116160a b c + 6013071360a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                           12   3               11 3 2               10 5
+--R               13212057600a  b c  + 68335697920a  b c  + 64118849536a  b c
+--R             + 
+--R                           9 7
+--R               12862750720a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          13 3               12 2 2               11 4
+--R               2202009600a  c  + 37470863360a  b c  + 64821657600a  b c
+--R             + 
+--R                           10 6
+--R               20349779968a  b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                        13   2               12 3                11 5  8
+--R           (12037652480a  b c  + 45654999040a  b c + 23770693632a  b )x
+--R         + 
+--R                       14 2               13 2                12 4  7
+--R           (1719664640a  c  + 21286092800a  b c + 20240138240a  b )x
+--R         + 
+--R                       14                  13 3  6
+--R           (5905580032a  b c + 12213813248a  b )x
+--R         + 
+--R                      15               14 2  5              15   4
+--R           (738197504a  c + 4949278720a  b )x  + 1207959552a  b x
+--R         + 
+--R                     16 3
+--R           134217728a  x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                       7 9          6 2 8           5 4 7          4 6 6
+--R               - 16384a c  - 372736a b c  - 1025024a b c  - 768768a b c
+--R             + 
+--R                        3 8 5         2 10 4         12 3    14 2
+--R               - 192192a b c  - 16016a b  c  - 364a b  c  - b  c
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                         7   8            6 3 7            5 5 6           4 7 5
+--R               - 1638400a b c  - 11182080a b c  - 16400384a b c  - 7687680a b c
+--R             + 
+--R                         3 9 4         2 11 3          13 2     15
+--R               - 1281280a b c  - 72800a b  c  - 1120a b  c  - 2b  c
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                         8 8            7 2 7             6 4 6
+--R               - 1638400a c  - 40099840a b c  - 121139200a b c
+--R             + 
+--R                           5 6 5            4 8 4           3 10 3
+--R               - 103014912a b c  - 30750720a b c  - 3363360a b  c
+--R             + 
+--R                        2 12 2          14     16
+--R               - 123760a b  c  - 1150a b  c - b
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                          8   7             7 3 6             6 5 5
+--R               - 57835520a b c  - 416604160a b c  - 654338048a b c
+--R             + 
+--R                           5 7 4            4 9 3           3 11 2         2 13
+--R               - 335695360a b c  - 63423360a b c  - 4353440a b  c  - 93240a b  c
+--R             + 
+--R                       15
+--R               - 394a b
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                          9 7             8 2 6              7 4 5
+--R               - 28917760a c  - 726118400a b c  - 2260751360a b c
+--R             + 
+--R                            6 6 4             5 8 3            4 10 2
+--R               - 1992856320a b c  - 621100480a b c  - 71511440a b  c
+--R             + 
+--R                         3 12          2 14
+--R               - 2782780a b  c - 26265a b
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                           9   6              8 3 5              7 5 4
+--R               - 621379584a b c  - 4488544256a b c  - 7043606528a b c
+--R             + 
+--R                          6 7 3             5 9 2            4 11           3 13
+--R             - 3581806592a b c  - 658706048a b c  - 41961920a b  c - 703640a b
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                           10 6              9 2 5               8 4 4
+--R               - 207126528a  c  - 5109923840a b c  - 15479797760a b c
+--R             + 
+--R                             7 6 3              6 8 2             5 10
+--R               - 13053286400a b c  - 3767021440a b c  - 373429056a b  c
+--R             + 
+--R                          4 12
+--R               - 10042760a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                            10   5               9 3 4               8 5 3
+--R               - 3097493504a  b c  - 21341143040a b c  - 31222661120a b c
+--R             + 
+--R                             7 7 2              6 9             5 11
+--R               - 14204600320a b c  - 2143232000a b c - 87779328a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                           11 5               10 2 4               9 4 3
+--R               - 774373376a  c  - 17941790720a  b c  - 49698897920a b c
+--R             + 
+--R                             8 6 2              7 8              6 10
+--R               - 36566548480a b c  - 8373422080a b c - 509297152a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                            11   4               10 3 3               9 5 2
+--R               - 8404336640a  b c  - 52150927360a  b c  - 65321697280a b c
+--R             + 
+--R                             8 7               7 9
+--R               - 23011983360a b c - 2062151680a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                            12 4               11 2 3               10 4 2
+--R               - 1680867328a  c  - 34652291072a  b c  - 80966975488a  b c
+--R             + 
+--R                             9 6               8 8
+--R               - 45281116160a b c - 6013071360a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                             12   3               11 3 2               10 5
+--R               - 13212057600a  b c  - 68335697920a  b c  - 64118849536a  b c
+--R             + 
+--R                             9 7
+--R               - 12862750720a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                            13 3               12 2 2               11 4
+--R               - 2202009600a  c  - 37470863360a  b c  - 64821657600a  b c
+--R             + 
+--R                             10 6
+--R               - 20349779968a  b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          13   2               12 3                11 5  9
+--R           (- 12037652480a  b c  - 45654999040a  b c - 23770693632a  b )x
+--R         + 
+--R                         14 2               13 2                12 4  8
+--R           (- 1719664640a  c  - 21286092800a  b c - 20240138240a  b )x
+--R         + 
+--R                         14                  13 3  7
+--R           (- 5905580032a  b c - 12213813248a  b )x
+--R         + 
+--R                        15               14 2  6              15   5
+--R           (- 738197504a  c - 4949278720a  b )x  - 1207959552a  b x
+--R         + 
+--R                       16 4
+--R           - 134217728a  x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                      6   9          5 3 8           4 5 7          3 7 6
+--R               114688a b c  + 745472a b c  + 1025024a b c  + 439296a b c
+--R             + 
+--R                     2 9 5          11 4      13 3
+--R               64064a b c  + 2912a b  c  + 28b  c
+--R          *
+--R              23
+--R             x
+--R         + 
+--R                      7 9           6 2 8            5 4 7            4 6 6
+--R               229376a c  + 5505024a b c  + 16214016a b c  + 13325312a b c
+--R             + 
+--R                       3 8 5          2 10 4           12 3      14 2
+--R               3788928a b c  + 384384a b  c  + 12376a b  c  + 84b  c
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                        7   8            6 3 7             5 5 6
+--R               12042240a b c  + 86876160a b c  + 136700928a b c
+--R             + 
+--R                        4 7 5            3 9 4          2 11 3           13 2
+--R               70287360a b c  + 13316160a b c  + 917280a b  c  + 19740a b  c
+--R             + 
+--R                  15
+--R               84b  c
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                       8 8             7 2 7             6 4 6             5 6 5
+--R               8028160a c  + 205864960a b c  + 658380800a b c  + 601409536a b c
+--R             + 
+--R                         4 8 4            3 10 3           2 12 2           14
+--R               197042560a b c  + 24481600a b  c  + 1088360a b  c  + 14000a b  c
+--R             + 
+--R                  16
+--R               28b
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                         8   7              7 3 6              6 5 5
+--R               221921280a b c  + 1677025280a b c  + 2791799808a b c
+--R             + 
+--R                          5 7 4             4 9 3            3 11 2
+--R               1539932160a b c  + 319450560a b c  + 24891360a b  c
+--R             + 
+--R                      2 13           15
+--R               642180a b  c + 3724a b
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                        9 7              8 2 6              7 4 5
+--R               88768512a c  + 2323120128a b c  + 7596029952a b c
+--R             + 
+--R                          6 6 4              5 8 3             4 10 2
+--R               7103609856a b c  + 2381967744a b c  + 301192320a b  c
+--R             + 
+--R                        3 12           2 14
+--R               13295880a b  c + 150780a b
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                          9   6               8 3 5               7 5 4
+--R               1652310016a b c  + 12451160064a b c  + 20537244672a b c
+--R             + 
+--R                           6 7 3              5 9 2             4 11
+--R               11087653888a b c  + 2194958272a b c  + 153580960a b  c
+--R             + 
+--R                       3 13
+--R               2919620a b
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                         10 6               9 2 5               8 4 4
+--R               472088576a  c  + 12088688640a b c  + 38232606720a b c
+--R             + 
+--R                           7 6 3               6 8 2              5 10
+--R               33910876160a b c  + 10396030080a b c  + 1109813952a b  c
+--R             + 
+--R                        4 12
+--R               32784440a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                          10   5               9 3 4               8 5 3
+--R               6398410752a  b c  + 45788037120a b c  + 69982617600a b c
+--R             + 
+--R                           7 7 2              6 9              5 11
+--R               33508638720a b c  + 5373542400a b c + 237080064a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                          11 5               10 2 4               9 4 3
+--R               1421869056a  c  + 34080030720a  b c  + 98108702720a b c
+--R             + 
+--R                           8 6 2               7 8               6 10
+--R               75452088320a b c  + 18193448960a b c + 1176589312a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                           11   4               10 3 3                9 5 2
+--R               14342946816a  b c  + 92118974464a  b c  + 119975116800a b c
+--R             + 
+--R                           8 7               7 9
+--R               44199936000a b c + 4172523520a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                          12 4               11 2 3                10 4 2
+--R               2607808512a  c  + 55462330368a  b c  + 134191644672a  b c
+--R             + 
+--R                           9 6                8 8
+--R               78068121600a b c + 10845941760a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           12   3                11 3 2                10 5
+--R               19356712960a  b c  + 103326679040a  b c  + 100433395712a  b c
+--R             + 
+--R                           9 7
+--R               20966932480a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          13 3               12 2 2               11 4
+--R               2977955840a  c  + 52156170240a  b c  + 93152870400a  b c
+--R             + 
+--R                           10 6
+--R               30305419264a  b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        13   2               12 3                11 5  9
+--R           (15539896320a  b c  + 60681093120a  b c + 32629850112a  b )x
+--R         + 
+--R                       14 2               13 2                12 4  8
+--R           (2071986176a  c  + 26344423424a  b c + 25798639616a  b )x
+--R         + 
+--R                       14                  13 3  7
+--R           (6845104128a  b c + 14545846272a  b )x
+--R         + 
+--R                      15               14 2  6              15   5
+--R           (805306368a  c + 5536481280a  b )x  + 1275068416a  b x
+--R         + 
+--R                     16 4
+--R           134217728a  x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                       7 7          6 2 6           5 4 5          4 6 4
+--R                 16384a c  + 372736a b c  + 1025024a b c  + 768768a b c
+--R               + 
+--R                        3 8 3         2 10 2         12     14
+--R                 192192a b c  + 16016a b  c  + 364a b  c + b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                         7   6            6 3 5            5 5 4           4 7 3
+--R                 1605632a b c  + 10436608a b c  + 14350336a b c  + 6150144a b c
+--R               + 
+--R                        3 9 2         2 11          13
+--R                 896896a b c  + 40768a b  c + 392a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                         8 6            7 2 5            6 4 4            5 6 3
+--R                 1605632a c  + 36126720a b c  + 97843200a b c  + 71751680a b c
+--R               + 
+--R                          4 8 2           3 10          2 12
+--R                 17297280a b c  + 1345344a b  c + 25480a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          8   5             7 3 4             6 5 3
+--R                 51380224a b c  + 321126400a b c  + 417464320a b c
+--R               + 
+--R                           5 7 2            4 9           3 11
+--R                 164003840a b c  + 20500480a b c + 652288a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                          9 5             8 2 4              7 4 3
+--R                 25690112a c  + 545914880a b c  + 1364787200a b c
+--R               + 
+--R                           6 6 2             5 8            4 10
+--R                 887111680a b c  + 174254080a b c + 8712704a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           9   4              8 3 3              7 5 2
+--R                 462422016a b c  + 2620391424a b c  + 2947940352a b c
+--R               + 
+--R                           6 7             5 9
+--R                 912457728a b c + 69701632a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                           10 4              9 2 3              8 4 2
+--R                 154140672a  c  + 2928672768a b c  + 6223429632a b c
+--R               + 
+--R                            7 6              6 8
+--R                 3111714816a b c + 361181184a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            10   3              9 3 2              8 5
+--R                 1761607680a  b c  + 8367636480a b c  + 7112491008a b c
+--R               + 
+--R                            7 7
+--R                 1270087680a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                           11 3              10 2 2               9 4
+--R                 440401920a  c  + 6936330240a  b c  + 10982522880a b c
+--R               + 
+--R                            8 6
+--R                 3111714816a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                         11   2               10 3               9 5  5
+--R             (3229614080a  b c  + 11303649280a  b c + 5369233408a b )x
+--R           + 
+--R                        12 2              11 2               10 4  4
+--R             (645922816a  c  + 7428112384a  b c + 6499598336a  b )x
+--R           + 
+--R                         12                 11 3  3
+--R             (2818572288a  b c + 5402263552a  b )x
+--R           + 
+--R                      13               12 2  2             13                14
+--R           (469762048a  c + 2936012800a  b )x  + 939524096a  b x + 134217728a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                          6   7          5 3 6           4 5 5          3 7 4
+--R                 - 114688a b c  - 745472a b c  - 1025024a b c  - 439296a b c
+--R               + 
+--R                         2 9 3          11 2      13
+--R                 - 64064a b c  - 2912a b  c  - 28b  c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                          7 7           6 2 6            5 4 5            4 6 4
+--R                 - 229376a c  - 5275648a b c  - 14723072a b c  - 11275264a b c
+--R               + 
+--R                           3 8 3          2 10 2          12       14
+--R                 - 2910336a b c  - 256256a b  c  - 6552a b  c - 28b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                            7   6            6 3 5             5 5 4
+--R                 - 11354112a b c  - 74719232a b c  - 104459264a b c
+--R               + 
+--R                            4 7 3           3 9 2          2 11           13
+--R                 - 45833216a b c  - 6928064a b c  - 334880a b  c - 3668a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                           8 6             7 2 5             6 4 4
+--R                 - 7569408a c  - 172146688a b c  - 472729600a b c
+--R               + 
+--R                           5 6 3            4 8 2           3 10           2 12
+--R               - 353167360a b c  - 87401600a b c  - 7074496a b  c - 143416a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                             8   5              7 3 4              6 5 3
+--R                 - 183500800a b c  - 1160642560a b c  - 1532231680a b c
+--R               + 
+--R                             5 7 2            4 9            3 11
+--R                 - 614481920a b c  - 79073280a b c - 2629120a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                            9 5              8 2 4              7 4 3
+--R                 - 73400320a c  - 1576271872a b c  - 3992977408a b c
+--R               + 
+--R                              6 6 2             5 8             4 10
+--R                 - 2639888384a b c  - 530456576a b c - 27382784a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                              9   4              8 3 3              7 5 2
+--R                 - 1112014848a b c  - 6374817792a b c  - 7276265472a b c
+--R               + 
+--R                              6 7              5 9
+--R                 - 2294513664a b c - 179685376a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                             10 4              9 2 3               8 4 2
+--R                 - 317718528a  c  - 6099566592a b c  - 13126729728a b c
+--R               + 
+--R                              7 6              6 8
+--R                 - 6667960320a b c - 789835776a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                              10   3               9 3 2               8 5
+--R                 - 3208642560a  b c  - 15414067200a b c  - 13283622912a b c
+--R               + 
+--R                              7 7
+--R                 - 2413166592a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                             11 3               10 2 2               9 4
+--R                 - 713031680a  c  - 11345592320a  b c  - 18184929280a b c
+--R               + 
+--R                              8 6
+--R                 - 5229772800a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                           11   2               10 3               9 5  5
+--R             (- 4752146432a  b c  - 16817061888a  b c - 8094220288a b )x
+--R           + 
+--R                          12 2               11 2               10 4  4
+--R             (- 864026624a  c  - 10036969472a  b c - 8887205888a  b )x
+--R           + 
+--R                           12                 11 3  3
+--R             (- 3489660928a  b c - 6761218048a  b )x
+--R           + 
+--R                          13               12 2  2              13
+--R             (- 536870912a  c - 3388997632a  b )x  - 1006632960a  b x
+--R           + 
+--R                         14
+--R             - 134217728a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 245
+
+)clear all
+
+--S 246 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x
+--R 
+--R
+--R                            +------------------+
+--R            3      2        |   4      3      2
+--R   (1)  (c x  + b x  + a x)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 704
+r0:=1/60*(3*b+10*c*x)*(a*x^2+b*x^3+c*x^4)^(3/2)/(c*x)+1/1024*(b^2-4*a*c)^2*_
+   (7*b^2-4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(c^(9/2)*sqrt(a*x^2+b*x^3+c*x^4))+1/3840*(35*b^4-_
+   216*a*b^2*c+240*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/c^3-1/7680*b*(105*b^4-_
+   760*a*b^2*c+1296*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/(c^4*x)-1/960*x*_
+   (b*(7*b^2+12*a*c)+6*c*(7*b^2-20*a*c)*x)*sqrt(a*x^2+b*x^3+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                                                      +--------------+
+--R                3 3        2 2 2         4        6   |   2
+--R         (- 960a c  + 2160a b c  - 900a b c + 105b )x\|c x  + b x + a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                6 8          5 7           5        2 4  6
+--R           2560c x  + 5888b c x  + (7040a c  + 3424b c )x
+--R         + 
+--R                     4      3 3  5         2 4         2 3      4 2  4
+--R           (8384a b c  - 16b c )x  + (5440a c  - 192a b c  + 28b c )x
+--R         + 
+--R                   2   3         3 2      5   3
+--R           (- 1056a b c  + 544a b c  - 70b c)x
+--R         + 
+--R                3 3        2 2 2          4        6  2
+--R           (960a c  - 3456a b c  + 1660a b c - 210b )x
+--R         + 
+--R                   3   2        2 3          5
+--R           (- 2592a b c  + 1520a b c - 210a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                 +------------------+
+--R           4 +-+ |   4      3      2
+--R     15360c \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                     184320a b c  - 261120a b c  - 161280a b c  + 97920a b c
+--R                   + 
+--R                              9         11
+--R                     - 6000a b c - 1260b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                            6 5          5 2 4           4 4 3          3 6 2
+--R                     368640a c  + 460800a b c  - 2288640a b c  + 564480a b c
+--R                   + 
+--R                            2 8            10
+--R                     110880a b c - 29400a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                             6   4           5 3 3           4 5 2
+--R                     2949120a b c  - 4915200a b c  - 1105920a b c
+--R                   + 
+--R                             3 7           2 9
+--R                     1290240a b c - 188160a b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                          7 4           5 4 2           4 6           3 8  2
+--R                 (1966080a c  - 8110080a b c  + 3932160a b c - 483840a b )x
+--R               + 
+--R                          7   3            6 3 2           5 5           4 7
+--R                 (4915200a b c  - 11059200a b c  + 4608000a b c - 537600a b )x
+--R               + 
+--R                         8 3           7 2 2           6 4           5 6
+--R                 1966080a c  - 4423680a b c  + 1843200a b c - 215040a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                         6 6         5 2 5          4 4 4         3 6 3
+--R                 - 61440a c  - 92160a b c  + 403200a b c  - 80640a b c
+--R               + 
+--R                         2 8 2          10        12
+--R                 - 26640a b c  + 5400a b  c + 105b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                           6   5           5 3 4          4 5 3          3 7 2
+--R                 - 1105920a b c  + 1566720a b c  + 967680a b c  - 587520a b c
+--R               + 
+--R                       2 9           11
+--R                 36000a b c + 7560a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                           7 5           6 2 4           5 4 3           4 6 2
+--R                 - 1105920a c  - 1382400a b c  + 6865920a b c  - 1693440a b c
+--R               + 
+--R                          3 8          2 10
+--R                 - 332640a b c + 88200a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           7   4           6 3 3           5 5 2           4 7
+--R                 - 5898240a b c  + 9830400a b c  + 2211840a b c  - 2580480a b c
+--R               + 
+--R                        3 9
+--R                 376320a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        8 4            6 4 2           5 6           4 8  2
+--R             (- 2949120a c  + 12165120a b c  - 5898240a b c + 725760a b )x
+--R           + 
+--R                        8   3            7 3 2           6 5           5 7
+--R             (- 5898240a b c  + 13271040a b c  - 5529600a b c + 645120a b )x
+--R           + 
+--R                       9 3           8 2 2           7 4           6 6
+--R             - 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                       3 8          2 2 7            4 6        6 5  11
+--R             (- 163840a c  - 614400a b c  - 153600a b c  - 2560b c )x
+--R           + 
+--R                        3   7           2 3 6            5 5        7 4  10
+--R             (- 3162112a b c  - 3256320a b c  - 384000a b c  - 3328b c )x
+--R           + 
+--R                           4 7            3 2 6           2 4 5            6 4
+--R                 - 3235840a c  - 15237120a b c  - 5637120a b c  - 249856a b c
+--R               + 
+--R                      8 3
+--R                 - 96b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                            4   6            3 3 5           2 5 4         7 3
+--R                 - 24760320a b c  - 27136000a b c  - 3217920a b c  - 768a b c
+--R               + 
+--R                     9 2
+--R                 112b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            5 6            4 2 5            3 4 4        2 6 3
+--R                 - 13086720a c  - 57154560a b c  - 16360960a b c  + 2688a b c
+--R               + 
+--R                       8 2       10
+--R                 528a b c  - 140b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                            5   5            4 3 4         3 5 3         2 7 2
+--R                 - 55080960a b c  - 41244160a b c  + 26880a b c  - 16320a b c
+--R               + 
+--R                        9        11
+--R                 1000a b c + 210b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            6 5            5 2 4           4 4 3          3 6 2
+--R                 - 20111360a c  - 55633920a b c  + 1090560a b c  - 296192a b c
+--R               + 
+--R                         2 8            10
+--R                 - 40800a b c + 12600a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                            6   4           5 3 3          4 5 2          3 7
+--R                 - 40017920a b c  + 3440640a b c  + 537600a b c  - 788480a b c
+--R               + 
+--R                        2 9
+--R                 117600a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                            7 4          6 2 3           5 4 2           4 6
+--R                 - 12124160a c  + 245760a b c  + 6205440a b c  - 3046400a b c
+--R               + 
+--R                        3 8
+--R                 376320a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        7   3           6 3 2           5 5           4 7  2
+--R             (- 4423680a b c  + 9953280a b c  - 4147200a b c + 483840a b )x
+--R           + 
+--R                        8 3           7 2 2           6 4           5 6
+--R             (- 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b )x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                     2   8            3 7         5 6  12
+--R             (491520a b c  + 409600a b c  + 30720b c )x
+--R           + 
+--R                     3 8           2 2 7             4 6         6 5  11
+--R             (983040a c  + 4571136a b c  + 1658880a b c  + 70656b c )x
+--R           + 
+--R                       3   7            2 3 6             5 5         7 4  10
+--R             (11476992a b c  + 14284800a b c  + 2280960a b c  + 41088b c )x
+--R           + 
+--R                         4 7            3 2 6            2 4 5             6 4
+--R                 7946240a c  + 42270720a b c  + 18462720a b c  + 1056768a b c
+--R               + 
+--R                       8 3
+--R                 - 192b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                          4   6            3 3 5           2 5 4          7 3
+--R                 51056640a b c  + 62361600a b c  + 8501760a b c  - 2304a b c
+--R               + 
+--R                     9 2
+--R                 336b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          5 6             4 2 5            3 4 4         2 6 3
+--R                 21749760a c  + 102389760a b c  + 31964160a b c  + 16128a b c
+--R               + 
+--R                        8 2       10
+--R                 3168a b c  - 840b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                          5   5            4 3 4          3 5 3          2 7 2
+--R                 81930240a b c  + 64094720a b c  - 341760a b c  + 254016a b c
+--R               + 
+--R                           9         11
+--R                 - 22200a b c - 2310b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          6 5            5 2 4           4 4 3           3 6 2
+--R                 25927680a c  + 73820160a b c  - 4254720a b c  + 1212672a b c
+--R               + 
+--R                        2 8            10
+--R                 133920a b c - 46200a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                          6   4           5 3 3           4 5 2           3 7
+--R                 47800320a b c  - 7864320a b c  - 1059840a b c  + 1720320a b c
+--R               + 
+--R                          2 9
+--R                 - 258720a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                          7 4          6 2 3           5 4 2           4 6
+--R                 13107200a c  - 491520a b c  - 9707520a b c  + 4782080a b c
+--R               + 
+--R                          3 8
+--R                 - 591360a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      7   3            6 3 2           5 5           4 7  2
+--R             (5406720a b c  - 12165120a b c  + 5068800a b c - 591360a b )x
+--R           + 
+--R                      8 3           7 2 2           6 4           5 6
+--R             (1966080a c  - 4423680a b c  + 1843200a b c - 215040a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                      2   6             3 5          5 4  5
+--R             (2949120a b c  + 2457600a b c  + 184320b c )x
+--R           + 
+--R                      3 6            2 2 5             4 4  4
+--R             (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R           + 
+--R                       3   5            2 3 4  3
+--R             (47185920a b c  + 27525120a b c )x
+--R           + 
+--R                       4 5            3 2 4  2            4   4             5 4
+--R             (31457280a c  + 70778880a b c )x  + 78643200a b c x + 31457280a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                       3 7           2 2 6            4 5         6 4  6
+--R             (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R           + 
+--R                         3   6            2 3 5             5 4  5
+--R             (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R           + 
+--R                         4 6            3 2 5            2 4 4  4
+--R             (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R           + 
+--R                         4   5            3 3 4  3
+--R             (- 94371840a b c  - 55050240a b c )x
+--R           + 
+--R                       5 5             4 2 4  2            5   4             6 4
+--R           (- 47185920a c  - 106168320a b c )x  - 94371840a b c x - 31457280a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                     - 184320a b c  + 261120a b c  + 161280a b c  - 97920a b c
+--R                   + 
+--R                            9         11
+--R                     6000a b c + 1260b
+--R                *
+--R                    5
+--R                   x
+--R               + 
+--R                              6 5          5 2 4           4 4 3          3 6 2
+--R                     - 368640a c  - 460800a b c  + 2288640a b c  - 564480a b c
+--R                   + 
+--R                              2 8            10
+--R                     - 110880a b c + 29400a b
+--R                *
+--R                    4
+--R                   x
+--R               + 
+--R                               6   4           5 3 3           4 5 2
+--R                     - 2949120a b c  + 4915200a b c  + 1105920a b c
+--R                   + 
+--R                               3 7           2 9
+--R                     - 1290240a b c + 188160a b
+--R                *
+--R                    3
+--R                   x
+--R               + 
+--R                            7 4           5 4 2           4 6           3 8  2
+--R                 (- 1966080a c  + 8110080a b c  - 3932160a b c + 483840a b )x
+--R               + 
+--R                            7   3            6 3 2           5 5           4 7
+--R                 (- 4915200a b c  + 11059200a b c  - 4608000a b c + 537600a b )x
+--R               + 
+--R                           8 3           7 2 2           6 4           5 6
+--R                 - 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                       6 6         5 2 5          4 4 4         3 6 3
+--R                 61440a c  + 92160a b c  - 403200a b c  + 80640a b c
+--R               + 
+--R                       2 8 2          10        12
+--R                 26640a b c  - 5400a b  c - 105b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                         6   5           5 3 4          4 5 3          3 7 2
+--R                 1105920a b c  - 1566720a b c  - 967680a b c  + 587520a b c
+--R               + 
+--R                         2 9           11
+--R                 - 36000a b c - 7560a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                         7 5           6 2 4           5 4 3           4 6 2
+--R                 1105920a c  + 1382400a b c  - 6865920a b c  + 1693440a b c
+--R               + 
+--R                        3 8          2 10
+--R                 332640a b c - 88200a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         7   4           6 3 3           5 5 2           4 7
+--R                 5898240a b c  - 9830400a b c  - 2211840a b c  + 2580480a b c
+--R               + 
+--R                          3 9
+--R                 - 376320a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      8 4            6 4 2           5 6           4 8  2
+--R             (2949120a c  - 12165120a b c  + 5898240a b c - 725760a b )x
+--R           + 
+--R                      8   3            7 3 2           6 5           5 7
+--R             (5898240a b c  - 13271040a b c  + 5529600a b c - 645120a b )x
+--R           + 
+--R                     9 3           8 2 2           7 4           6 6
+--R             1966080a c  - 4423680a b c  + 1843200a b c - 215040a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                      3 8          2 2 7           4 6        6 5  11
+--R             (- 81920a c  - 307200a b c  - 76800a b c  - 1280b c )x
+--R           + 
+--R                        3   7           2 3 6            5 5        7 4  10
+--R             (- 1581056a b c  - 1628160a b c  - 192000a b c  - 1664b c )x
+--R           + 
+--R                           4 7           3 2 6           2 4 5            6 4
+--R                 - 1617920a c  - 7618560a b c  - 2818560a b c  - 124928a b c
+--R               + 
+--R                      8 3
+--R                 - 48b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                            4   6            3 3 5           2 5 4         7 3
+--R                 - 12380160a b c  - 13568000a b c  - 1608960a b c  - 384a b c
+--R               + 
+--R                    9 2
+--R                 56b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                           5 6            4 2 5           3 4 4        2 6 3
+--R                 - 6543360a c  - 28577280a b c  - 8180480a b c  + 1344a b c
+--R               + 
+--R                       8 2      10
+--R                 264a b c  - 70b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                            5   5            4 3 4         3 5 3        2 7 2
+--R                 - 27540480a b c  - 20622080a b c  + 13440a b c  - 8160a b c
+--R               + 
+--R                       9        11
+--R                 500a b c + 105b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            6 5            5 2 4          4 4 3          3 6 2
+--R                 - 10055680a c  - 27816960a b c  + 545280a b c  - 148096a b c
+--R               + 
+--R                         2 8           10
+--R                 - 20400a b c + 6300a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                            6   4           5 3 3          4 5 2          3 7
+--R                 - 20008960a b c  + 1720320a b c  + 268800a b c  - 394240a b c
+--R               + 
+--R                       2 9
+--R                 58800a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                           7 4          6 2 3           5 4 2           4 6
+--R                 - 6062080a c  + 122880a b c  + 3102720a b c  - 1523200a b c
+--R               + 
+--R                        3 8
+--R                 188160a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        7   3           6 3 2           5 5           4 7  2
+--R             (- 2211840a b c  + 4976640a b c  - 2073600a b c + 241920a b )x
+--R           + 
+--R                       8 3           7 2 2          6 4           5 6
+--R             (- 983040a c  + 2211840a b c  - 921600a b c + 107520a b )x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                     2   8            3 7         5 6  12
+--R             (245760a b c  + 204800a b c  + 15360b c )x
+--R           + 
+--R                     3 8           2 2 7            4 6         6 5  11
+--R             (491520a c  + 2285568a b c  + 829440a b c  + 35328b c )x
+--R           + 
+--R                      3   7           2 3 6             5 5         7 4  10
+--R             (5738496a b c  + 7142400a b c  + 1140480a b c  + 20544b c )x
+--R           + 
+--R                         4 7            3 2 6           2 4 5            6 4
+--R                 3973120a c  + 21135360a b c  + 9231360a b c  + 528384a b c
+--R               + 
+--R                      8 3
+--R                 - 96b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                          4   6            3 3 5           2 5 4          7 3
+--R                 25528320a b c  + 31180800a b c  + 4250880a b c  - 1152a b c
+--R               + 
+--R                     9 2
+--R                 168b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          5 6            4 2 5            3 4 4        2 6 3
+--R                 10874880a c  + 51194880a b c  + 15982080a b c  + 8064a b c
+--R               + 
+--R                        8 2       10
+--R                 1584a b c  - 420b  c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                          5   5            4 3 4          3 5 3          2 7 2
+--R                 40965120a b c  + 32047360a b c  - 170880a b c  + 127008a b c
+--R               + 
+--R                           9         11
+--R                 - 11100a b c - 1155b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          6 5            5 2 4           4 4 3          3 6 2
+--R                 12963840a c  + 36910080a b c  - 2127360a b c  + 606336a b c
+--R               + 
+--R                       2 8            10
+--R                 66960a b c - 23100a b
+--R            *
+--R                5
+--R               x
+--R           + 
+--R                          6   4           5 3 3          4 5 2          3 7
+--R                 23900160a b c  - 3932160a b c  - 529920a b c  + 860160a b c
+--R               + 
+--R                          2 9
+--R                 - 129360a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                         7 4          6 2 3           5 4 2           4 6
+--R                 6553600a c  - 245760a b c  - 4853760a b c  + 2391040a b c
+--R               + 
+--R                          3 8
+--R                 - 295680a b
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                      7   3           6 3 2           5 5           4 7  2
+--R             (2703360a b c  - 6082560a b c  + 2534400a b c - 295680a b )x
+--R           + 
+--R                     8 3           7 2 2          6 4           5 6
+--R             (983040a c  - 2211840a b c  + 921600a b c - 107520a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                      2   6             3 5         5 4  5
+--R             (1474560a b c  + 1228800a b c  + 92160b c )x
+--R           + 
+--R                      3 6            2 2 5             4 4  4
+--R             (2949120a c  + 10321920a b c  + 2150400a b c )x
+--R           + 
+--R                       3   5            2 3 4  3
+--R             (23592960a b c  + 13762560a b c )x
+--R           + 
+--R                       4 5            3 2 4  2            4   4             5 4
+--R             (15728640a c  + 35389440a b c )x  + 39321600a b c x + 15728640a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                       3 7           2 2 6            4 5        6 4  6
+--R             (- 491520a c  - 1843200a b c  - 460800a b c  - 7680b c )x
+--R           + 
+--R                        3   6           2 3 5            5 4  5
+--R             (- 8847360a b c  - 7372800a b c  - 552960a b c )x
+--R           + 
+--R                        4 6            3 2 5           2 4 4  4
+--R             (- 8847360a c  - 30965760a b c  - 6451200a b c )x
+--R           + 
+--R                         4   5            3 3 4  3
+--R             (- 47185920a b c  - 27525120a b c )x
+--R           + 
+--R                       5 5            4 2 4  2            5   4             6 4
+--R           (- 23592960a c  - 53084160a b c )x  - 47185920a b c x - 15728640a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 248
+
+--S 249 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          5   5          4 3 4          3 5 3         2 7 2
+--R                   184320a b c  - 261120a b c  - 161280a b c  + 97920a b c
+--R                 + 
+--R                            9         11
+--R                   - 6000a b c - 1260b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                          6 5          5 2 4           4 4 3          3 6 2
+--R                   368640a c  + 460800a b c  - 2288640a b c  + 564480a b c
+--R                 + 
+--R                          2 8            10
+--R                   110880a b c - 29400a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           6   4           5 3 3           4 5 2           3 7
+--R                   2949120a b c  - 4915200a b c  - 1105920a b c  + 1290240a b c
+--R                 + 
+--R                            2 9
+--R                   - 188160a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                        7 4           5 4 2           4 6           3 8  2
+--R               (1966080a c  - 8110080a b c  + 3932160a b c - 483840a b )x
+--R             + 
+--R                        7   3            6 3 2           5 5           4 7
+--R               (4915200a b c  - 11059200a b c  + 4608000a b c - 537600a b )x
+--R             + 
+--R                       8 3           7 2 2           6 4           5 6
+--R               1966080a c  - 4423680a b c  + 1843200a b c - 215040a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                       6 6         5 2 5          4 4 4         3 6 3
+--R               - 61440a c  - 92160a b c  + 403200a b c  - 80640a b c
+--R             + 
+--R                       2 8 2          10        12
+--R               - 26640a b c  + 5400a b  c + 105b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                         6   5           5 3 4          4 5 3          3 7 2
+--R               - 1105920a b c  + 1566720a b c  + 967680a b c  - 587520a b c
+--R             + 
+--R                     2 9           11
+--R               36000a b c + 7560a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                         7 5           6 2 4           5 4 3           4 6 2
+--R               - 1105920a c  - 1382400a b c  + 6865920a b c  - 1693440a b c
+--R             + 
+--R                        3 8          2 10
+--R               - 332640a b c + 88200a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                         7   4           6 3 3           5 5 2           4 7
+--R               - 5898240a b c  + 9830400a b c  + 2211840a b c  - 2580480a b c
+--R             + 
+--R                      3 9
+--R               376320a b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      8 4            6 4 2           5 6           4 8  2
+--R           (- 2949120a c  + 12165120a b c  - 5898240a b c + 725760a b )x
+--R         + 
+--R                      8   3            7 3 2           6 5           5 7
+--R           (- 5898240a b c  + 13271040a b c  - 5529600a b c + 645120a b )x
+--R         + 
+--R                     9 3           8 2 2           7 4           6 6
+--R           - 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                           6 6         5 2 5          4 4 4         3 6 3
+--R                   - 61440a c  - 92160a b c  + 403200a b c  - 80640a b c
+--R                 + 
+--R                           2 8 2          10        12
+--R                   - 26640a b c  + 5400a b  c + 105b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                             6   5           5 3 4          4 5 3          3 7 2
+--R                   - 1105920a b c  + 1566720a b c  + 967680a b c  - 587520a b c
+--R                 + 
+--R                         2 9           11
+--R                   36000a b c + 7560a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             7 5           6 2 4           5 4 3           4 6 2
+--R                   - 1105920a c  - 1382400a b c  + 6865920a b c  - 1693440a b c
+--R                 + 
+--R                            3 8          2 10
+--R                   - 332640a b c + 88200a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             7   4           6 3 3           5 5 2
+--R                   - 5898240a b c  + 9830400a b c  + 2211840a b c
+--R                 + 
+--R                             4 7           3 9
+--R                   - 2580480a b c + 376320a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          8 4            6 4 2           5 6           4 8  3
+--R               (- 2949120a c  + 12165120a b c  - 5898240a b c + 725760a b )x
+--R             + 
+--R                          8   3            7 3 2           6 5           5 7  2
+--R               (- 5898240a b c  + 13271040a b c  - 5529600a b c + 645120a b )x
+--R             + 
+--R                          9 3           8 2 2           7 4           6 6
+--R               (- 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                          5   6          4 3 5          3 5 4         2 7 3
+--R                   184320a b c  - 261120a b c  - 161280a b c  + 97920a b c
+--R                 + 
+--R                            9 2        11
+--R                   - 6000a b c  - 1260b  c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          6 6          5 2 5           4 4 4          3 6 3
+--R                   368640a c  + 645120a b c  - 2549760a b c  + 403200a b c
+--R                 + 
+--R                          2 8 2           10         12
+--R                   208800a b c  - 35400a b  c - 1260b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                           6   5           5 3 4           4 5 3           3 7 2
+--R                   3502080a b c  - 4715520a b c  - 3555840a b c  + 1952640a b c
+--R                 + 
+--R                           2 9            11
+--R                   - 83280a b c - 30660a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                           7 5           6 2 4            5 4 3           4 6 2
+--R                   2334720a c  + 3409920a b c  - 15313920a b c  + 3390720a b c
+--R                 + 
+--R                          3 8           2 10
+--R                   917280a b c - 217560a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                           7   4            6 3 3           5 5 2           4 7
+--R                   9830400a b c  - 15974400a b c  - 4608000a b c  + 4684800a b c
+--R                 + 
+--R                            3 9
+--R                   - 672000a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           8 4          7 2 3            6 4 2           5 6
+--R                   3932160a c  + 491520a b c  - 17326080a b c  + 8325120a b c
+--R                 + 
+--R                             4 8
+--R                   - 1021440a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                        8   3            7 3 2           6 5           5 7  2
+--R               (6881280a b c  - 15482880a b c  + 6451200a b c - 752640a b )x
+--R             + 
+--R                        9 3           8 2 2           7 4           6 6
+--R               (1966080a c  - 4423680a b c  + 1843200a b c - 215040a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                         3 8          2 2 7            4 6        6 5  11
+--R               (- 163840a c  - 614400a b c  - 153600a b c  - 2560b c )x
+--R             + 
+--R                          3   7           2 3 6            5 5        7 4  10
+--R               (- 3162112a b c  - 3256320a b c  - 384000a b c  - 3328b c )x
+--R             + 
+--R                             4 7            3 2 6           2 4 5            6 4
+--R                   - 3235840a c  - 15237120a b c  - 5637120a b c  - 249856a b c
+--R                 + 
+--R                        8 3
+--R                   - 96b c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                              4   6            3 3 5           2 5 4         7 3
+--R                   - 24760320a b c  - 27136000a b c  - 3217920a b c  - 768a b c
+--R                 + 
+--R                       9 2
+--R                   112b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              5 6            4 2 5            3 4 4        2 6 3
+--R                   - 13086720a c  - 57154560a b c  - 16360960a b c  + 2688a b c
+--R                 + 
+--R                         8 2       10
+--R                   528a b c  - 140b  c
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                              5   5            4 3 4         3 5 3         2 7 2
+--R                   - 55080960a b c  - 41244160a b c  + 26880a b c  - 16320a b c
+--R                 + 
+--R                          9        11
+--R                   1000a b c + 210b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              6 5            5 2 4           4 4 3
+--R                   - 20111360a c  - 55633920a b c  + 1090560a b c
+--R                 + 
+--R                            3 6 2         2 8            10
+--R                   - 296192a b c  - 40800a b c + 12600a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                              6   4           5 3 3          4 5 2          3 7
+--R                   - 40017920a b c  + 3440640a b c  + 537600a b c  - 788480a b c
+--R                 + 
+--R                          2 9
+--R                   117600a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              7 4          6 2 3           5 4 2           4 6
+--R                   - 12124160a c  + 245760a b c  + 6205440a b c  - 3046400a b c
+--R                 + 
+--R                          3 8
+--R                   376320a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                          7   3           6 3 2           5 5           4 7  2
+--R               (- 4423680a b c  + 9953280a b c  - 4147200a b c + 483840a b )x
+--R             + 
+--R                          8 3           7 2 2           6 4           5 6
+--R               (- 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                       2   8            3 7         5 6  12
+--R               (491520a b c  + 409600a b c  + 30720b c )x
+--R             + 
+--R                       3 8           2 2 7             4 6         6 5  11
+--R               (983040a c  + 4571136a b c  + 1658880a b c  + 70656b c )x
+--R             + 
+--R                         3   7            2 3 6             5 5         7 4  10
+--R               (11476992a b c  + 14284800a b c  + 2280960a b c  + 41088b c )x
+--R             + 
+--R                           4 7            3 2 6            2 4 5             6 4
+--R                   7946240a c  + 42270720a b c  + 18462720a b c  + 1056768a b c
+--R                 + 
+--R                         8 3
+--R                   - 192b c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            4   6            3 3 5           2 5 4          7 3
+--R                   51056640a b c  + 62361600a b c  + 8501760a b c  - 2304a b c
+--R                 + 
+--R                       9 2
+--R                   336b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            5 6             4 2 5            3 4 4         2 6 3
+--R                   21749760a c  + 102389760a b c  + 31964160a b c  + 16128a b c
+--R                 + 
+--R                          8 2       10
+--R                   3168a b c  - 840b  c
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            5   5            4 3 4          3 5 3          2 7 2
+--R                   81930240a b c  + 64094720a b c  - 341760a b c  + 254016a b c
+--R                 + 
+--R                             9         11
+--R                   - 22200a b c - 2310b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            6 5            5 2 4           4 4 3           3 6 2
+--R                   25927680a c  + 73820160a b c  - 4254720a b c  + 1212672a b c
+--R                 + 
+--R                          2 8            10
+--R                   133920a b c - 46200a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                            6   4           5 3 3           4 5 2           3 7
+--R                   47800320a b c  - 7864320a b c  - 1059840a b c  + 1720320a b c
+--R                 + 
+--R                            2 9
+--R                   - 258720a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            7 4          6 2 3           5 4 2           4 6
+--R                   13107200a c  - 491520a b c  - 9707520a b c  + 4782080a b c
+--R                 + 
+--R                            3 8
+--R                   - 591360a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                        7   3            6 3 2           5 5           4 7  2
+--R               (5406720a b c  - 12165120a b c  + 5068800a b c - 591360a b )x
+--R             + 
+--R                        8 3           7 2 2           6 4           5 6
+--R               (1966080a c  - 4423680a b c  + 1843200a b c - 215040a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                     2   8            3 7         5 6  13
+--R           (- 491520a b c  - 409600a b c  - 30720b c )x
+--R         + 
+--R                     3 8           2 2 7             4 6         6 5  12
+--R           (- 983040a c  - 4571136a b c  - 1658880a b c  - 70656b c )x
+--R         + 
+--R                       3   7            2 3 6             5 5         7 4  11
+--R           (- 11476992a b c  - 14284800a b c  - 2280960a b c  - 41088b c )x
+--R         + 
+--R                         4 7            3 2 6            2 4 5             6 4
+--R               - 7946240a c  - 42270720a b c  - 18462720a b c  - 1056768a b c
+--R             + 
+--R                   8 3
+--R               192b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          4   6            3 3 5           2 5 4          7 3
+--R               - 51056640a b c  - 62361600a b c  - 8501760a b c  + 2304a b c
+--R             + 
+--R                     9 2
+--R               - 336b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                          5 6             4 2 5            3 4 4         2 6 3
+--R               - 21749760a c  - 102389760a b c  - 31964160a b c  - 16128a b c
+--R             + 
+--R                        8 2       10
+--R               - 3168a b c  + 840b  c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                          5   5            4 3 4          3 5 3          2 7 2
+--R               - 81764352a b c  - 63569920a b c  + 145920a b c  - 292224a b c
+--R             + 
+--R                       9         11
+--R               33280a b c + 2520b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                          6 5            5 2 4           4 4 3           3 6 2
+--R               - 25927680a c  - 70834176a b c  + 4992000a b c  - 2243328a b c
+--R             + 
+--R                       2 8            10
+--R               - 41760a b c + 61320a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          6   4            5 3 3           4 5 2           3 7
+--R               - 44814336a b c  + 16564224a b c  - 2649600a b c  - 2150400a b c
+--R             + 
+--R                      2 9
+--R               435120a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                          7 4            6 2 3           5 4 2           4 6
+--R               - 13107200a c  + 16416768a b c  + 9658368a b c  - 8939520a b c
+--R             + 
+--R                       3 8
+--R               1344000a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    7   3            6 3 2            5 5            4 7  3
+--R           (2555904a b c  + 25411584a b c  - 14929920a b c + 2042880a b )x
+--R         + 
+--R                      8 3            7 2 2            6 4            5 6  2
+--R           (- 1966080a c  + 20348928a b c  - 11182080a b c + 1505280a b )x
+--R         + 
+--R                    8   2           7 3           6 5
+--R           (5308416a b c  - 3112960a b c + 430080a b )x
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                   3 9          2 2 8            4 7        6 6  14
+--R           (163840a c  + 614400a b c  + 153600a b c  + 2560b c )x
+--R         + 
+--R                    3   8           2 3 7            5 6        7 5  13
+--R           (3325952a b c  + 3870720a b c  + 537600a b c  + 5888b c )x
+--R         + 
+--R                       4 8            3 2 7           2 4 6            6 5
+--R               3399680a c  + 19013632a b c  + 9047040a b c  + 636416a b c
+--R             + 
+--R                    8 4
+--R               3424b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        4   7            3 3 6           2 5 5            7 4
+--R               31158272a b c  + 45629440a b c  + 9239040a b c  + 253952a b c
+--R             + 
+--R                    9 3
+--R               - 16b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        5 7            4 2 6            3 4 5           2 6 4
+--R               16322560a c  + 97152000a b c  + 49134080a b c  + 3465088a b c
+--R             + 
+--R                     8 3      10 2
+--R               336a b c  + 28b  c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        5   6             4 3 5            3 5 4         2 7 3
+--R               92928000a b c  + 125534720a b c  + 19552000a b c  + 14400a b c
+--R             + 
+--R                        9 2      11
+--R               - 1640a b c  - 70b  c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                        6 6             5 2 5            4 4 4          3 6 3
+--R               33198080a c  + 167371776a b c  + 56391680a b c  + 438400a b c
+--R             + 
+--R                     2 8 2           10        12
+--R               41232a b c  - 15980a b  c - 210b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         6   5            5 3 4          4 5 3           3 7 2
+--R               114214912a b c  + 90039808a b c  - 541440a b c  + 1416128a b c
+--R             + 
+--R                        2 9            11
+--R               - 151960a b c - 15330a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                        7 5            6 2 4            5 4 3           4 6 2
+--R               32235520a c  + 85950464a b c  - 13734912a b c  + 6291968a b c
+--R             + 
+--R                      3 8           2 10
+--R               204640a b c - 191520a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        7   4            6 3 3           5 5 2           4 7
+--R               50262016a b c  - 33333248a b c  + 5239296a b c  + 4605440a b c
+--R             + 
+--R                        3 9
+--R               - 929040a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                        8 4            7 2 3            6 4 2            5 6
+--R               14090240a c  - 26787840a b c  - 15339520a b c  + 14556160a b c
+--R             + 
+--R                         4 8
+--R               - 2204160a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      8   3            7 3 2            6 5            5 7  3
+--R           (- 4227072a b c  - 33366016a b c  + 19916800a b c - 2741760a b )x
+--R         + 
+--R                    9 3            8 2 2            7 4            6 6  2
+--R           (1966080a c  - 23003136a b c  + 12738560a b c - 1720320a b )x
+--R         + 
+--R                      9   2           8 3           7 5
+--R           (- 5308416a b c  + 3112960a b c - 430080a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                      2   6             3 5          5 4  5
+--R             (2949120a b c  + 2457600a b c  + 184320b c )x
+--R           + 
+--R                      3 6            2 2 5             4 4  4
+--R             (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R           + 
+--R                       3   5            2 3 4  3
+--R             (47185920a b c  + 27525120a b c )x
+--R           + 
+--R                       4 5            3 2 4  2            4   4             5 4
+--R             (31457280a c  + 70778880a b c )x  + 78643200a b c x + 31457280a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                       3 7           2 2 6            4 5         6 4  6
+--R             (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R           + 
+--R                         3   6            2 3 5             5 4  5
+--R             (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R           + 
+--R                         4 6            3 2 5            2 4 4  4
+--R             (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R           + 
+--R                         4   5            3 3 4  3
+--R             (- 94371840a b c  - 55050240a b c )x
+--R           + 
+--R                       5 5             4 2 4  2            5   4             6 4
+--R           (- 47185920a c  - 106168320a b c )x  - 94371840a b c x - 31457280a c
+--R        *
+--R            +-+
+--R           \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 249
+
+--S 250 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                               7 9          6 2 8           5 4 7
+--R                       - 32768a c  - 745472a b c  - 2050048a b c
+--R                     + 
+--R                                 4 6 6          3 8 5         2 10 4
+--R                       - 1537536a b c  - 384384a b c  - 32032a b  c
+--R                     + 
+--R                               12 3     14 2
+--R                       - 728a b  c  - 2b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                 7   8            6 3 7            5 5 6
+--R                       - 3489792a b c  - 23482368a b c  - 33825792a b c
+--R                     + 
+--R                                  4 7 5           3 9 4          2 11 3
+--R                       - 15485184a b c  - 2498496a b c  - 135408a b  c
+--R                     + 
+--R                                13 2     15
+--R                       - 1932a b  c  - 3b  c
+--R                  *
+--R                      19
+--R                     x
+--R                 + 
+--R                                 8 8            7 2 7             6 4 6
+--R                       - 3735552a c  - 89358336a b c  - 262406144a b c
+--R                     + 
+--R                                   5 6 5            4 8 4           3 10 3
+--R                       - 215255040a b c  - 61281792a b c  - 6278272a b  c
+--R                     + 
+--R                                2 12 2          14     16
+--R                       - 209664a b  c  - 1656a b  c - b
+--R                  *
+--R                      18
+--R                     x
+--R                 + 
+--R                                   8   7             7 3 6              6 5 5
+--R                       - 137445376a b c  - 956583936a b c  - 1439785984a b c
+--R                     + 
+--R                                   5 7 4             4 9 3           3 11 2
+--R                       - 699615488a b c  - 123012032a b c  - 7636720a b  c
+--R                     + 
+--R                                2 13          15
+--R                       - 140364a b  c - 451a b
+--R                  *
+--R                      17
+--R                     x
+--R                 + 
+--R                                  9 7              8 2 6              7 4 5
+--R                       - 73433088a c  - 1775198208a b c  - 5278156800a b c
+--R                     + 
+--R                                    6 6 4              5 8 3             4 10 2
+--R                       - 4393858560a b c  - 1272585600a b c  - 132845856a b  c
+--R                     + 
+--R                                 3 12          2 14
+--R                       - 4496856a b  c - 34050a b
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                    9   6               8 3 5
+--R                       - 1620312064a b c  - 11158683648a b c
+--R                     + 
+--R                                     7 5 4              6 7 3              5 9 2
+--R                       - 16522297344a b c  - 7814250496a b c  - 1308662784a b c
+--R                     + 
+--R                                  4 11            3 13
+--R                       - 73442304a b  c - 1023680a b
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                                   10 6               9 2 5               8 4 4
+--R                       - 576192512a  c  - 13544194048a b c  - 38724861952a b c
+--R                     + 
+--R                                     7 6 3              6 8 2             5 10
+--R                       - 30426955776a b c  - 8035149824a b c  - 709463040a b  c
+--R                     + 
+--R                                  4 12
+--R                       - 16265600a b
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                    10   5               9 3 4
+--R                       - 8752988160a  b c  - 56968740864a b c
+--R                     + 
+--R                                     8 5 3               7 7 2              6 9
+--R                       - 77839663104a b c  - 32560201728a b c  - 4417001472a b c
+--R                     + 
+--R                                   5 11
+--R                       - 157168128a b
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                    11 5               10 2 4
+--R                       - 2330984448a  c  - 51081117696a  b c
+--R                     + 
+--R                                      9 4 3               8 6 2
+--R                       - 132470145024a b c  - 90017464320a b c
+--R                     + 
+--R                                     7 8               6 10
+--R                       - 18682195968a b c - 1001847808a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                     11   4                10 3 3
+--R                       - 25490882560a  b c  - 148452147200a  b c
+--R                     + 
+--R                                      9 5 2               8 7               7 9
+--R                       - 172443041792a b c  - 55439327232a b c - 4432076800a b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                    12 4                11 2 3
+--R                       - 5423235072a  c  - 105180561408a  b c
+--R                     + 
+--R                                    10 4 2                9 6                8 8
+--R                     - 228777787392a  b c  - 117460697088a b c - 14050344960a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                     12   3                11 3 2
+--R                       - 42685431808a  b c  - 206230781952a  b c
+--R                     + 
+--R                                      10 5                9 7
+--R                       - 178577473536a  b c - 32530432000a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                    13 3                12 2 2
+--R                       - 7558135808a  c  - 120517033984a  b c
+--R                     + 
+--R                                      11 4                10 6
+--R                       - 193287684096a  b c - 55478714368a  b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                     13   2                12 3
+--R                       - 41171288064a  b c  - 145357799424a  b c
+--R                     + 
+--R                                     11 5
+--R                       - 69602377728a  b
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                 14 2               13 2                12 4  6
+--R                   (- 6241124352a  c  - 72175583232a  b c - 63438848000a  b )x
+--R                 + 
+--R                                  14                  13 3  5
+--R                   (- 21273509888a  b c - 40852520960a  b )x
+--R                 + 
+--R                                 15                14 2  4              15   3
+--R                   (- 2818572288a  c - 17616076800a  b )x  - 4563402752a  b x
+--R                 + 
+--R                               16 2
+--R                   - 536870912a  x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                                6   9           5 3 8           4 5 7
+--R                       - 229376a b c  - 1490944a b c  - 2050048a b c
+--R                     + 
+--R                                3 7 6          2 9 5          11 4      13 3
+--R                       - 878592a b c  - 128128a b c  - 5824a b  c  - 56b  c
+--R                  *
+--R                      20
+--R                     x
+--R                 + 
+--R                                7 9            6 2 8            5 4 7
+--R                       - 491520a c  - 11526144a b c  - 32987136a b c
+--R                     + 
+--R                                  4 6 6           3 8 5          2 10 4
+--R                       - 26138112a b c  - 7083648a b c  - 672672a b  c
+--R                     + 
+--R                                 12 3       14 2
+--R                       - 19656a b  c  - 114b  c
+--R                  *
+--R                      19
+--R                     x
+--R                 + 
+--R                                  7   8             6 3 7             5 5 6
+--R                       - 26640384a b c  - 183099392a b c  - 271165440a b c
+--R                     + 
+--R                                   4 7 5            3 9 4           2 11 3
+--R                       - 128933376a b c  - 21983104a b c  - 1301664a b  c
+--R                     + 
+--R                                 13 2      15
+--R                       - 22008a b  c  - 58b  c
+--R                  *
+--R                      18
+--R                     x
+--R                 + 
+--R                                  8 8             7 2 7              6 4 6
+--R                       - 18841600a c  - 453763072a b c  - 1342953472a b c
+--R                     + 
+--R                                    5 6 5             4 8 4            3 10 3
+--R                       - 1111545344a b c  - 319569536a b c  - 33034144a b  c
+--R                     + 
+--R                                 2 12 2          14
+--R                       - 1102920a b  c  - 8178a b  c
+--R                  *
+--R                      17
+--R                     x
+--R                 + 
+--R                                   8   7              7 3 6              6 5 5
+--R                       - 514031616a b c  - 3550396416a b c  - 5278156800a b c
+--R                     + 
+--R                                    5 7 4             4 9 3            3 11 2
+--R                       - 2510776320a b c  - 424195200a b c  - 24153792a b  c
+--R                     + 
+--R                                2 13
+--R                       - 345912a b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                   9 7              8 2 6               7 4 5
+--R                       - 216530944a c  - 5130682368a b c  - 14820212736a b c
+--R                     + 
+--R                                     6 6 4              5 8 3             4 10 2
+--R                       - 11803230208a b c  - 3175790592a b c  - 288178176a b  c
+--R                     + 
+--R                                 3 12
+--R                       - 6900608a b  c
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                                    9   6               8 3 5
+--R                       - 3816816640a b c  - 25198329856a b c
+--R                     + 
+--R                                     7 5 4               6 7 3
+--R                       - 35063332864a b c  - 15024914432a b c
+--R                     + 
+--R                                    5 9 2            4 11
+--R                       - 2107342848a b c  - 78753792a b  c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                    10 6               9 2 5               8 4 4
+--R                       - 1141899264a  c  - 25449725952a b c  - 67406266368a b c
+--R                     + 
+--R                                   7 6 3               6 8 2             5 10
+--R                     - 47061762048a b c  - 10125398016a b c  - 570964992a b  c
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                     10   5               9 3 4
+--R                       - 14033092608a  b c  - 83610304512a b c
+--R                     + 
+--R                                   8 5 3               7 7 2              6 9
+--R                     - 99940958208a b c  - 33339801600a b c  - 2800807936a b c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                    11 5               10 2 4
+--R                       - 3250585600a  c  - 64560824320a  b c
+--R                     + 
+--R                                    9 4 3               8 6 2              7 8
+--R                     - 144598630400a b c  - 77034553344a b c  - 9668542464a b c
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                     11   4                10 3 3
+--R                       - 28210888704a  b c  - 140368674816a  b c
+--R                     + 
+--R                                      9 5 2               8 7
+--R                       - 126054039552a b c  - 24049483776a b c
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                    12 4               11 2 3
+--R                       - 5326766080a  c  - 87457529856a  b c
+--R                     + 
+--R                                      10 4 2               9 6
+--R                       - 145349935104a  b c  - 43609882624a b c
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                     12   3                11 3 2
+--R                       - 31599886336a  b c  - 115498549248a  b c
+--R                     + 
+--R                                     10 5
+--R                       - 57700515840a  b c
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                      13 3               12 2 2
+--R                         - 5033164800a  c  - 60196651008a  b c
+--R                       + 
+--R                                       11 4
+--R                         - 55100571648a  b c
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                  13   2               12 3   6
+--R                   (- 18522046464a  b c  - 36976984064a  b c)x
+--R                 + 
+--R                                 14 2               13 2   5
+--R                   (- 2550136832a  c  - 16542334976a  b c)x
+--R                 + 
+--R                                14     4             15   3
+--R                   - 4429185024a  b c x  - 536870912a  c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                          6   9           5 3 8           4 5 7          3 7 6
+--R                   229376a b c  + 1490944a b c  + 2050048a b c  + 878592a b c
+--R                 + 
+--R                          2 9 5          11 4      13 3
+--R                   128128a b c  + 5824a b  c  + 56b  c
+--R              *
+--R                  21
+--R                 x
+--R             + 
+--R                          7 9            6 2 8            5 4 7            4 6 6
+--R                   491520a c  + 11640832a b c  + 33732608a b c  + 27163136a b c
+--R                 + 
+--R                           3 8 5          2 10 4           12 3       14 2
+--R                   7522944a b c  + 736736a b  c  + 22568a b  c  + 142b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                            7   8             6 3 7             5 5 6
+--R                   27131904a b c  + 190726144a b c  + 290734080a b c
+--R                 + 
+--R                             4 7 5            3 9 4           2 11 3
+--R                   143649792a b c  + 25845248a b c  + 1659840a b  c
+--R                 + 
+--R                           13 2       15
+--R                   32256a b  c  + 116b  c
+--R              *
+--R                  19
+--R                 x
+--R             + 
+--R                            8 8             7 2 7              6 4 6
+--R                   19333120a c  + 480231424a b c  + 1478299648a b c
+--R                 + 
+--R                              5 6 5             4 8 4            3 10 3
+--R                   1288641536a b c  + 398038784a b c  + 45787456a b  c
+--R                 + 
+--R                           2 12 2           14       16
+--R                   1830192a b  c  + 20052a b  c + 30b
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                             8   7              7 3 6              6 5 5
+--R                   551714816a b c  + 3998482432a b c  + 6330103808a b c
+--R                 + 
+--R                              5 7 4             4 9 3            3 11 2
+--R                   3282353152a b c  + 629602688a b c  + 44230784a b  c
+--R                 + 
+--R                          2 13           15
+--R                   985992a b  c + 4540a b
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                             9 7              8 2 6               7 4 5
+--R                   235372544a c  + 5896052736a b c  + 18306054144a b c
+--R                 + 
+--R                               6 6 4              5 8 3             4 10 2
+--R                   16083511808a b c  + 4992653952a b c  + 572004576a b  c
+--R                 + 
+--R                            3 12           2 14
+--R                   22118824a b  c + 207006a b
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                              9   6               8 3 5               7 5 4
+--R                   4466409472a b c  + 31947489280a b c  + 49535352832a b c
+--R                 + 
+--R                               6 7 3              5 9 2             4 11
+--R                   24813633536a b c  + 4474988544a b c  + 277555200a b  c
+--R                 + 
+--R                           3 13
+--R                   4473984a b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                              10 6               9 2 5               8 4 4
+--R                   1358430208a  c  + 33028308992a b c  + 98313076736a b c
+--R                 + 
+--R                               7 6 3               6 8 2              5 10
+--R                   81126850560a b c  + 22777219072a b c  + 2177270784a b  c
+--R                 + 
+--R                            4 12
+--R                   55642496a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                               10   5                9 3 4                8 5 3
+--R                   18600689664a  b c  + 125470507008a b c  + 178916032512a b c
+--R                 + 
+--R                               7 7 2               6 9              5 11
+--R                   78842363904a b c  + 11418742784a b c + 442650624a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                              11 5               10 2 4                9 4 3
+--R                   4392484864a  c  + 99405266944a  b c  + 267726749696a b c
+--R                 + 
+--R                                8 6 2               7 8               6 10
+--R                   190350655488a b c  + 41758101504a b c + 2402251776a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                               11   4                10 3 3                9 5 2
+--R                   44463816704a  b c  + 267886002176a  b c  + 323867901952a b c
+--R                 + 
+--R                                8 7               7 9
+--R                   109242482688a b c + 9266348032a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                              12 4                11 2 3                10 4 2
+--R                   8577351680a  c  + 171555422208a  b c  + 386740518912a  b c
+--R                 + 
+--R                                9 6                8 8
+--R                   207135703040a b c + 26075086848a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                               12   3                11 3 2                10 5
+--R                   63560482816a  b c  + 317190045696a  b c  + 285215293440a  b c
+--R                 + 
+--R                               9 7
+--R                   54335373312a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                               13 3                12 2 2                11 4
+--R                   10359930880a  c  + 170148233216a  b c  + 282333806592a  b c
+--R                 + 
+--R                               10 6
+--R                   84328972288a  b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            13   2                12 3                11 5  7
+--R               (53754200064a  b c  + 195756556288a  b c + 97152663552a  b )x
+--R             + 
+--R                           14 2               13 2                12 4  6
+--R               (7583301632a  c  + 90227867648a  b c + 81927340032a  b )x
+--R             + 
+--R                            14                  13 3  5
+--R               (24830279680a  b c + 49123688448a  b )x
+--R             + 
+--R                           15                14 2  4              15   3
+--R               (3087007744a  c + 19830669312a  b )x  + 4831838208a  b x
+--R             + 
+--R                         16 2
+--R               536870912a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                     7 10          6 2 9           5 4 8           4 6 7
+--R               32768a c   + 745472a b c  + 2050048a b c  + 1537536a b c
+--R             + 
+--R                      3 8 6         2 10 5         12 4     14 3
+--R               384384a b c  + 32032a b  c  + 728a b  c  + 2b  c
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                       7   9            6 3 8            5 5 7            4 7 6
+--R               3506176a b c  + 23855104a b c  + 34850816a b c  + 16253952a b c
+--R             + 
+--R                       3 9 5          2 11 4          13 3     15 2
+--R               2690688a b c  + 151424a b  c  + 2296a b  c  + 4b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                       8 9            7 2 8             6 4 7             5 6 6
+--R               3735552a c  + 90980352a b c  + 273215488a b c  + 230630400a b c
+--R             + 
+--R                        4 8 5           3 10 4          2 12 3          14 2
+--R               68200704a b c  + 7367360a b  c  + 266448a b  c  + 2412a b  c
+--R             + 
+--R                 16
+--R               2b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                         8   8             7 3 7              6 5 6
+--R               139067392a b c  + 994689024a b c  + 1549090816a b c
+--R             + 
+--R                         5 7 5             4 9 4           3 11 3
+--R               786486272a b c  + 146651648a b c  + 9894976a b  c
+--R             + 
+--R                      2 13 2         15
+--R               206976a b  c  + 844a b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                        9 8              8 2 7              7 4 6
+--R               73433088a c  + 1829789696a b c  + 5645846528a b c
+--R             + 
+--R                          6 6 5              5 8 4             4 10 3
+--R               4923516416a b c  + 1514491264a b c  + 171540512a b  c
+--R             + 
+--R                       3 12 2         2 14
+--R               6535256a b  c  + 59922a b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                          9   7               8 3 6               7 5 5
+--R               1647607808a b c  + 11792105472a b c  + 18306054144a b c
+--R             + 
+--R                          6 7 4              5 9 3             4 11 2
+--R               9190578176a b c  + 1664217984a b c  + 104000832a b  c
+--R             + 
+--R                       3 13
+--R               1701448a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                         10 7               9 2 6               8 4 5
+--R               576192512a  c  + 14083686400a b c  + 42212294656a b c
+--R             + 
+--R                           7 6 4              6 8 3             5 10 2
+--R               35157147648a b c  + 9998723072a b c  + 973919232a b  c
+--R             + 
+--R                        4 12
+--R               25630592a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                          10   6               9 3 5               8 5 4
+--R               8932818944a  b c  + 60905750528a b c  + 88048271360a b c
+--R             + 
+--R                           7 7 3              6 9 2             5 11
+--R               39506968576a b c  + 5864894464a b c  + 235582464a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                          11 6               10 2 5                9 4 4
+--R               2330984448a  c  + 53459288064a  b c  + 146386845696a b c
+--R             + 
+--R                            8 6 3               7 8 2              6 10
+--R               106301325312a b c  + 23976456192a b c  + 1432730624a b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                           11   5                10 3 4                9 5 3
+--R               26085425152a  b c  + 160078757888a  b c  + 198016630784a b c
+--R             + 
+--R                           8 7 2              7 9
+--R               68775247872a b c  + 6063345664a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          12 5                11 2 4                10 4 3
+--R               5423235072a  c  + 110612185088a  b c  + 255385403392a  b c
+--R             + 
+--R                            9 6 2               8 8
+--R               140924944384a b c  + 18432147456a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                           12   4                11 3 3                10 5 2
+--R               43771756544a  b c  + 223824838656a  b c  + 207363244032a  b c
+--R             + 
+--R                           9 7
+--R               41011380224a b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          13 4                12 2 3                11 4 2
+--R               7558135808a  c  + 127211143168a  b c  + 217421709312a  b c
+--R             + 
+--R                           10 6
+--R               67347546112a  b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                        13   3                12 3 2               11 5   8
+--R           (42286972928a  b c  + 158540496896a  b c  + 81504239616a  b c)x
+--R         + 
+--R                       14 3               13 2 2               12 4   7
+--R           (6241124352a  c  + 76403441664a  b c  + 71777124352a  b c)x
+--R         + 
+--R                        14   2               13 3   6
+--R           (21877489664a  b c  + 44728057856a  b c)x
+--R         + 
+--R                       15 2               14 2   5              15     4
+--R           (2818572288a  c  + 18689818624a  b c)x  + 4697620480a  b c x
+--R         + 
+--R                     16   3
+--R           536870912a  c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                            6   9           5 3 8           4 5 7          3 7 6
+--R                   - 229376a b c  - 1490944a b c  - 2050048a b c  - 878592a b c
+--R                 + 
+--R                            2 9 5          11 4      13 3
+--R                   - 128128a b c  - 5824a b  c  - 56b  c
+--R              *
+--R                  22
+--R                 x
+--R             + 
+--R                            7 9            6 2 8            5 4 7
+--R                   - 491520a c  - 11640832a b c  - 33732608a b c
+--R                 + 
+--R                              4 6 6           3 8 5          2 10 4
+--R                   - 27163136a b c  - 7522944a b c  - 736736a b  c
+--R                 + 
+--R                             12 3       14 2
+--R                   - 22568a b  c  - 142b  c
+--R              *
+--R                  21
+--R                 x
+--R             + 
+--R                              7   8             6 3 7             5 5 6
+--R                   - 27131904a b c  - 190726144a b c  - 290734080a b c
+--R                 + 
+--R                               4 7 5            3 9 4           2 11 3
+--R                   - 143649792a b c  - 25845248a b c  - 1659840a b  c
+--R                 + 
+--R                             13 2       15
+--R                   - 32256a b  c  - 116b  c
+--R              *
+--R                  20
+--R                 x
+--R             + 
+--R                              8 8             7 2 7              6 4 6
+--R                   - 19333120a c  - 480231424a b c  - 1478299648a b c
+--R                 + 
+--R                                5 6 5             4 8 4            3 10 3
+--R                   - 1288641536a b c  - 398038784a b c  - 45787456a b  c
+--R                 + 
+--R                             2 12 2           14       16
+--R                   - 1830192a b  c  - 20052a b  c - 30b
+--R              *
+--R                  19
+--R                 x
+--R             + 
+--R                               8   7              7 3 6              6 5 5
+--R                   - 551714816a b c  - 3998482432a b c  - 6330103808a b c
+--R                 + 
+--R                                5 7 4             4 9 3            3 11 2
+--R                   - 3282353152a b c  - 629602688a b c  - 44230784a b  c
+--R                 + 
+--R                            2 13           15
+--R                   - 985992a b  c - 4540a b
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                               9 7              8 2 6               7 4 5
+--R                   - 235372544a c  - 5896052736a b c  - 18306054144a b c
+--R                 + 
+--R                                 6 6 4              5 8 3             4 10 2
+--R                   - 16083511808a b c  - 4992653952a b c  - 572004576a b  c
+--R                 + 
+--R                              3 12           2 14
+--R                   - 22118824a b  c - 207006a b
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                                9   6               8 3 5               7 5 4
+--R                   - 4466409472a b c  - 31947489280a b c  - 49535352832a b c
+--R                 + 
+--R                                 6 7 3              5 9 2             4 11
+--R                   - 24813633536a b c  - 4474988544a b c  - 277555200a b  c
+--R                 + 
+--R                             3 13
+--R                   - 4473984a b
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                                10 6               9 2 5               8 4 4
+--R                   - 1358430208a  c  - 33028308992a b c  - 98313076736a b c
+--R                 + 
+--R                                 7 6 3               6 8 2              5 10
+--R                   - 81126850560a b c  - 22777219072a b c  - 2177270784a b  c
+--R                 + 
+--R                              4 12
+--R                   - 55642496a b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                                 10   5                9 3 4
+--R                   - 18600689664a  b c  - 125470507008a b c
+--R                 + 
+--R                                  8 5 3               7 7 2               6 9
+--R                   - 178916032512a b c  - 78842363904a b c  - 11418742784a b c
+--R                 + 
+--R                               5 11
+--R                   - 442650624a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                                11 5               10 2 4                9 4 3
+--R                   - 4392484864a  c  - 99405266944a  b c  - 267726749696a b c
+--R                 + 
+--R                                  8 6 2               7 8               6 10
+--R                   - 190350655488a b c  - 41758101504a b c - 2402251776a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                                 11   4                10 3 3
+--R                   - 44463816704a  b c  - 267886002176a  b c
+--R                 + 
+--R                                  9 5 2                8 7               7 9
+--R                   - 323867901952a b c  - 109242482688a b c - 9266348032a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                12 4                11 2 3                10 4 2
+--R                   - 8577351680a  c  - 171555422208a  b c  - 386740518912a  b c
+--R                 + 
+--R                                  9 6                8 8
+--R                   - 207135703040a b c - 26075086848a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                                 12   3                11 3 2
+--R                   - 63560482816a  b c  - 317190045696a  b c
+--R                 + 
+--R                                  10 5                9 7
+--R                   - 285215293440a  b c - 54335373312a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                                 13 3                12 2 2                11 4
+--R                   - 10359930880a  c  - 170148233216a  b c  - 282333806592a  b c
+--R                 + 
+--R                                 10 6
+--R                   - 84328972288a  b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                              13   2                12 3                11 5  8
+--R               (- 53754200064a  b c  - 195756556288a  b c - 97152663552a  b )x
+--R             + 
+--R                             14 2               13 2                12 4  7
+--R               (- 7583301632a  c  - 90227867648a  b c - 81927340032a  b )x
+--R             + 
+--R                              14                  13 3  6
+--R               (- 24830279680a  b c - 49123688448a  b )x
+--R             + 
+--R                             15                14 2  5              15   4
+--R               (- 3087007744a  c - 19830669312a  b )x  - 4831838208a  b x
+--R             + 
+--R                           16 3
+--R               - 536870912a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                       7 10          6 2 9           5 4 8           4 6 7
+--R               - 32768a c   - 745472a b c  - 2050048a b c  - 1537536a b c
+--R             + 
+--R                        3 8 6         2 10 5         12 4     14 3
+--R               - 384384a b c  - 32032a b  c  - 728a b  c  - 2b  c
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                         7   9            6 3 8            5 5 7
+--R               - 3506176a b c  - 23855104a b c  - 34850816a b c
+--R             + 
+--R                          4 7 6           3 9 5          2 11 4          13 3
+--R               - 16253952a b c  - 2690688a b c  - 151424a b  c  - 2296a b  c
+--R             + 
+--R                   15 2
+--R               - 4b  c
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                         8 9            7 2 8             6 4 7
+--R               - 3735552a c  - 90980352a b c  - 273215488a b c
+--R             + 
+--R                           5 6 6            4 8 5           3 10 4
+--R               - 230630400a b c  - 68200704a b c  - 7367360a b  c
+--R             + 
+--R                        2 12 3          14 2     16
+--R               - 266448a b  c  - 2412a b  c  - 2b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                           8   8             7 3 7              6 5 6
+--R               - 139067392a b c  - 994689024a b c  - 1549090816a b c
+--R             + 
+--R                           5 7 5             4 9 4           3 11 3
+--R               - 786486272a b c  - 146651648a b c  - 9894976a b  c
+--R             + 
+--R                        2 13 2         15
+--R               - 206976a b  c  - 844a b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                          9 8              8 2 7              7 4 6
+--R               - 73433088a c  - 1829789696a b c  - 5645846528a b c
+--R             + 
+--R                            6 6 5              5 8 4             4 10 3
+--R               - 4923516416a b c  - 1514491264a b c  - 171540512a b  c
+--R             + 
+--R                         3 12 2         2 14
+--R               - 6535256a b  c  - 59922a b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                            9   7               8 3 6               7 5 5
+--R               - 1647607808a b c  - 11792105472a b c  - 18306054144a b c
+--R             + 
+--R                            6 7 4              5 9 3             4 11 2
+--R               - 9190578176a b c  - 1664217984a b c  - 104000832a b  c
+--R             + 
+--R                         3 13
+--R               - 1701448a b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                           10 7               9 2 6               8 4 5
+--R               - 576192512a  c  - 14083686400a b c  - 42212294656a b c
+--R             + 
+--R                             7 6 4              6 8 3             5 10 2
+--R               - 35157147648a b c  - 9998723072a b c  - 973919232a b  c
+--R             + 
+--R                          4 12
+--R               - 25630592a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                            10   6               9 3 5               8 5 4
+--R               - 8932818944a  b c  - 60905750528a b c  - 88048271360a b c
+--R             + 
+--R                             7 7 3              6 9 2             5 11
+--R               - 39506968576a b c  - 5864894464a b c  - 235582464a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                            11 6               10 2 5                9 4 4
+--R               - 2330984448a  c  - 53459288064a  b c  - 146386845696a b c
+--R             + 
+--R                              8 6 3               7 8 2              6 10
+--R               - 106301325312a b c  - 23976456192a b c  - 1432730624a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                             11   5                10 3 4                9 5 3
+--R               - 26085425152a  b c  - 160078757888a  b c  - 198016630784a b c
+--R             + 
+--R                             8 7 2              7 9
+--R               - 68775247872a b c  - 6063345664a b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                            12 5                11 2 4                10 4 3
+--R               - 5423235072a  c  - 110612185088a  b c  - 255385403392a  b c
+--R             + 
+--R                              9 6 2               8 8
+--R               - 140924944384a b c  - 18432147456a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                             12   4                11 3 3                10 5 2
+--R               - 43771756544a  b c  - 223824838656a  b c  - 207363244032a  b c
+--R             + 
+--R                             9 7
+--R               - 41011380224a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                            13 4                12 2 3                11 4 2
+--R               - 7558135808a  c  - 127211143168a  b c  - 217421709312a  b c
+--R             + 
+--R                             10 6
+--R               - 67347546112a  b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          13   3                12 3 2               11 5   9
+--R           (- 42286972928a  b c  - 158540496896a  b c  - 81504239616a  b c)x
+--R         + 
+--R                         14 3               13 2 2               12 4   8
+--R           (- 6241124352a  c  - 76403441664a  b c  - 71777124352a  b c)x
+--R         + 
+--R                          14   2               13 3   7
+--R           (- 21877489664a  b c  - 44728057856a  b c)x
+--R         + 
+--R                         15 2               14 2   6              15     5
+--R           (- 2818572288a  c  - 18689818624a  b c)x  - 4697620480a  b c x
+--R         + 
+--R                       16   4
+--R           - 536870912a  c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                     7 10          6 2 9           5 4 8           4 6 7
+--R               32768a c   + 745472a b c  + 2050048a b c  + 1537536a b c
+--R             + 
+--R                      3 8 6         2 10 5         12 4     14 3
+--R               384384a b c  + 32032a b  c  + 728a b  c  + 2b  c
+--R          *
+--R              23
+--R             x
+--R         + 
+--R                       7   9            6 3 8            5 5 7            4 7 6
+--R               3522560a b c  + 24227840a b c  + 35875840a b c  + 17022720a b c
+--R             + 
+--R                       3 9 5          2 11 4          13 3     15 2
+--R               2882880a b c  + 167440a b  c  + 2660a b  c  + 5b  c
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                       8 9            7 2 8             6 4 7             5 6 6
+--R               3768320a c  + 93593600a b c  + 287938560a b c  + 250618368a b c
+--R             + 
+--R                        4 8 5           3 10 4          2 12 3          14 2
+--R               77151360a b c  + 8808800a b  c  + 345800a b  c  + 3590a b  c
+--R             + 
+--R                 16
+--R               4b  c
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                         8   8              7 3 7              6 5 6
+--R               144670720a b c  + 1069424640a b c  + 1736017920a b c
+--R             + 
+--R                         5 7 5             4 9 4            3 11 3
+--R               930355712a b c  + 186792320a b c  + 14050400a b  c
+--R             + 
+--R                      2 13 2          15     17
+--R               351960a b  c  + 2110a b  c + b
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                        9 8              8 2 7              7 4 6
+--R               77168640a c  + 2002001920a b c  + 6497146880a b c
+--R             + 
+--R                          6 6 5              5 8 4             4 10 3
+--R               6048899584a b c  + 2033482880a b c  + 262136160a b  c
+--R             + 
+--R                        3 12 2          2 14          16
+--R               12343240a b  c  + 176070a b  c + 452a b
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                          9   7               8 3 6               7 5 5
+--R               1831190528a b c  + 13890465792a b c  + 23240240128a b c
+--R             + 
+--R                           6 7 4              5 9 3             4 11 2
+--R               12907724544a b c  + 2704260416a b c  + 213924880a b  c
+--R             + 
+--R                       3 13          2 15
+--R               5660900a b  c + 34501a b
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                         10 7               9 2 6               8 4 5
+--R               649625600a  c  + 16939704320a b c  + 55161702400a b c
+--R             + 
+--R                           7 6 4               6 8 3              5 10 2
+--R               51343111680a b c  + 17121985920a b c  + 2150971680a b  c
+--R             + 
+--R                        4 12            3 14
+--R               94204760a b  c + 1057730a b
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                           10   6               9 3 5                8 5 4
+--R               10949492736a  b c  + 81671618560a b c  + 133086822400a b c
+--R             + 
+--R                           7 7 3               6 9 2             5 11
+--R               70801408000a b c  + 13760814080a b c  + 940073472a b  c
+--R             + 
+--R                        4 13
+--R               17289280a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                          11 6               10 2 5                9 4 4
+--R               2907176960a  c  + 73378299904a  b c  + 228163747840a b c
+--R             + 
+--R                            8 6 3               7 8 2              6 10
+--R               198284083200a b c  + 59277547520a b c  + 6128312320a b  c
+--R             + 
+--R                         5 12
+--R               173433728a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                           11   5                10 3 4                9 5 3
+--R               36574855168a  b c  + 256502005760a  b c  + 382752849920a b c
+--R             + 
+--R                            8 7 2               7 9               6 11
+--R               178016993280a b c  + 27531274240a b c + 1159015936a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                          12 5                11 2 4                10 4 3
+--R               7754219520a  c  + 181752561664a  b c  + 509700079616a  b c
+--R             + 
+--R                            9 6 2               8 8               7 10
+--R               379921203200a b c  + 88171868160a b c + 5433924608a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                           12   4                11 3 3                10 5 2
+--R               73599549440a  b c  + 459863490560a  b c  + 579798302720a  b c
+--R             + 
+--R                            9 7                8 9
+--R               205430456320a b c + 18482421760a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           13 4                12 2 3                11 4 2
+--R               12981370880a  c  + 268383027200a  b c  + 628296253440a  b c
+--R             + 
+--R                            10 6                9 8
+--R               351516884992a  b c + 46580776960a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                           13   3                12 3 2                11 5
+--R               91414855680a  b c  + 472105615360a  b c  + 441467535360a  b c
+--R             + 
+--R                           10 7
+--R               88009146368a  b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                           14 3                13 2 2                12 4
+--R               13799260160a  c  + 233863905280a  b c  + 402084331520a  b c
+--R             + 
+--R                            11 6
+--R               125081092096a  b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                        14   2                13 3                 12 5  8
+--R           (68685922304a  b c  + 258385903616a  b c + 133041225728a  b )x
+--R         + 
+--R                       15 2                14 2                 13 4  7
+--R           (9059696640a  c  + 111065169920a  b c + 104291368960a  b )x
+--R         + 
+--R                        15                  14 3  6
+--R           (28655484928a  b c + 58468597760a  b )x
+--R         + 
+--R                       16                15 2  5              16   4
+--R           (3355443200a  c + 22179479552a  b )x  + 5100273664a  b x
+--R         + 
+--R                     17 3
+--R           536870912a  x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                      6   10           5 3 9           4 5 8          3 7 7
+--R               229376a b c   + 1490944a b c  + 2050048a b c  + 878592a b c
+--R             + 
+--R                      2 9 6          11 5      13 4
+--R               128128a b c  + 5824a b  c  + 56b  c
+--R          *
+--R              23
+--R             x
+--R         + 
+--R                      7 10            6 2 9            5 4 8            4 6 7
+--R               491520a c   + 11755520a b c  + 34478080a b c  + 28188160a b c
+--R             + 
+--R                       3 8 6          2 10 5           12 4       14 3
+--R               7962240a b c  + 800800a b  c  + 25480a b  c  + 170b  c
+--R          *
+--R              22
+--R             x
+--R         + 
+--R                        7   9             6 3 8             5 5 7
+--R               27361280a b c  + 196116480a b c  + 306202624a b c
+--R             + 
+--R                         4 7 6            3 9 5           2 11 4           13 3
+--R               155950080a b c  + 29194880a b c  + 1980160a b  c  + 41720a b  c
+--R             + 
+--R                   15 2
+--R               172b  c
+--R          *
+--R              21
+--R             x
+--R         + 
+--R                        8 9             7 2 8              6 4 7
+--R               19333120a c  + 491929600a b c  + 1559040000a b c
+--R             + 
+--R                          5 6 6             4 8 5            3 10 4
+--R               1408848896a b c  + 455586560a b c  + 55689920a b  c
+--R             + 
+--R                       2 12 3           14 2      16
+--R               2424240a b  c  + 30300a b  c  + 58b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                         8   8              7 3 7              6 5 6
+--R               559513600a b c  + 4187258880a b c  + 6892275712a b c
+--R             + 
+--R                          5 7 5             4 9 4            3 11 3
+--R               3751255040a b c  + 765747840a b c  + 58489600a b  c
+--R             + 
+--R                       2 13 2          15
+--R               1470840a b  c  + 8236a b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                         9 8              8 2 7               7 4 6
+--R               235372544a c  + 6098477056a b c  + 19713562624a b c
+--R             + 
+--R                           6 6 5              5 8 4             4 10 3
+--R               18192932352a b c  + 6006136448a b c  + 745407520a b  c
+--R             + 
+--R                        3 12 2          2 14
+--R               32157320a b  c  + 354090a b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                          9   7               8 3 6               7 5 5
+--R               4547379200a b c  + 33879408640a b c  + 55161702400a b c
+--R             + 
+--R                           6 7 4              5 9 3             4 11 2
+--R               29338920960a b c  + 5707328640a b c  + 391085760a b  c
+--R             + 
+--R                       3 13
+--R               7246520a b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                          10 7               9 2 6                8 4 5
+--R               1358430208a  c  + 34397224960a b c  + 107424808960a b c
+--R             + 
+--R                           7 6 4               6 8 3              5 10 2
+--R               93928325120a b c  + 28326103040a b c  + 2966486016a b  c
+--R             + 
+--R                        4 12
+--R               85654400a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                           10   6                9 3 5                8 5 4
+--R               18991808512a  b c  + 134258360320a b c  + 202410557440a b c
+--R             + 
+--R                           7 7 3               6 9 2             5 11
+--R               95426478080a b c  + 15033548800a b c  + 649718784a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                          11 6                10 2 5                9 4 4
+--R               4392484864a  c  + 104043642880a  b c  + 295615201280a b c
+--R             + 
+--R                            8 6 3               7 8 2              6 10
+--R               224037273600a b c  + 53133742080a b c  + 3371772928a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                           11   5                10 3 4                9 5 3
+--R               45494566912a  b c  + 288539803648a  b c  + 370593628160a b c
+--R             + 
+--R                            8 7 2               7 9
+--R               134423838720a b c  + 12469350400a b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                          12 5                11 2 4                10 4 3
+--R               8577351680a  c  + 180229242880a  b c  + 430317240320a  b c
+--R             + 
+--R                            9 6 2               8 8
+--R               246698475520a b c  + 33718026240a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           12   4                11 3 3                10 5 2
+--R               65137541120a  b c  + 343324753920a  b c  + 329104490496a  b c
+--R             + 
+--R                           9 7
+--R               67659366400a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                           13 4                12 2 3                11 4 2
+--R               10359930880a  c  + 179254067200a  b c  + 315949056000a  b c
+--R             + 
+--R                            10 6
+--R               101310398464a  b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        13   3                12 3 2                11 5   9
+--R           (55155097600a  b c  + 212672184320a  b c  + 112801087488a  b c)x
+--R         + 
+--R                       14 3               13 2 2               12 4   8
+--R           (7583301632a  c  + 95261032448a  b c  + 92077555712a  b c)x
+--R         + 
+--R                        14   2               13 3   7
+--R           (25501368320a  b c  + 53519319040a  b c)x
+--R         + 
+--R                       15 2               14 2   6              15     5
+--R           (3087007744a  c  + 20971520000a  b c)x  + 4966055936a  b c x
+--R         + 
+--R                     16   4
+--R           536870912a  c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                            6   7           5 3 6           4 5 5          3 7 4
+--R                     229376a b c  + 1490944a b c  + 2050048a b c  + 878592a b c
+--R                   + 
+--R                            2 9 3          11 2      13
+--R                     128128a b c  + 5824a b  c  + 56b  c
+--R                *
+--R                    15
+--R                   x
+--R               + 
+--R                            7 7            6 2 6            5 4 5
+--R                     491520a c  + 11182080a b c  + 30750720a b c
+--R                   + 
+--R                              4 6 4           3 8 3          2 10 2
+--R                     23063040a b c  + 5765760a b c  + 480480a b  c
+--R                   + 
+--R                             12       14
+--R                     10920a b  c + 30b
+--R                *
+--R                    14
+--R                   x
+--R               + 
+--R                              7   6             6 3 5             5 5 4
+--R                     25690112a b c  + 165150720a b c  + 223641600a b c
+--R                   + 
+--R                              4 7 3            3 9 2          2 11           13
+--R                     93716480a b c  + 13178880a b c  + 559104a b  c + 4480a b
+--R                *
+--R                    13
+--R                   x
+--R               + 
+--R                              8 6             7 2 5              6 4 4
+--R                     18350080a c  + 405536768a b c  + 1072332800a b c
+--R                   + 
+--R                               5 6 3             4 8 2            3 10
+--R                     760381440a b c  + 174254080a b c  + 12446720a b  c
+--R                   + 
+--R                            2 12
+--R                     198016a b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                               8   5              7 3 4              6 5 3
+--R                     462422016a b c  + 2807562240a b c  + 3509452800a b c
+--R                   + 
+--R                                5 7 2             4 9            3 11
+--R                     1303511040a b c  + 149360640a b c + 4073472a b
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                               9 5              8 2 4              7 4 3
+--R                     198180864a c  + 4079222784a b c  + 9779675136a b c
+--R                   + 
+--R                                6 6 2              5 8             4 10
+--R                     6001164288a b c  + 1083543552a b c + 47297536a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                                9   4               8 3 3               7 5 2
+--R                     3082813440a b c  + 16735272960a b c  + 17781227520a b c
+--R                   + 
+--R                                6 7              5 9
+--R                     5080350720a b c + 343982080a b
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                               10 4               9 2 3               8 4 2
+--R                     943718400a  c  + 17175674880a b c  + 34516500480a b c
+--R                   + 
+--R                                 7 6               6 8
+--R                     16003104768a b c + 1666990080a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                                10   3               9 3 2               8 5
+--R                     9688842240a  b c  + 43599790080a b c  + 34516500480a b c
+--R                   + 
+--R                                7 7
+--R                     5588385792a b
+--R                *
+--R                    7
+--R                   x
+--R               + 
+--R                                11 3               10 2 2               9 4
+--R                     2306867200a  c  + 34487664640a  b c  + 51068272640a b c
+--R                   + 
+--R                                 8 6
+--R                     13231325184a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                              11   2               10 3                9 5  5
+--R                 (15502147584a  b c  + 50935627776a  b c + 22284337152a b )x
+--R               + 
+--R                             12 2               11 2                10 4  4
+--R                 (3019898880a  c  + 32715571200a  b c + 26528972800a  b )x
+--R               + 
+--R                              12                  11 3  3
+--R                 (12213813248a  b c + 21810380800a  b )x
+--R               + 
+--R                             13                12 2  2              13
+--R                 (2013265920a  c + 11777605632a  b )x  + 3758096384a  b x
+--R               + 
+--R                           14
+--R                 536870912a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                       7 8          6 2 7           5 4 6           4 6 5
+--R                 32768a c  + 745472a b c  + 2050048a b c  + 1537536a b c
+--R               + 
+--R                        3 8 4         2 10 3         12 2     14
+--R                 384384a b c  + 32032a b  c  + 728a b  c  + 2b  c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                         7   7            6 3 6            5 5 5
+--R                 3440640a b c  + 22364160a b c  + 30750720a b c
+--R               + 
+--R                          4 7 4           3 9 3         2 11 2         13
+--R                 13178880a b c  + 1921920a b c  + 87360a b  c  + 840a b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                         8 7            7 2 6             6 4 5
+--R                 3670016a c  + 82575360a b c  + 223641600a b c
+--R               + 
+--R                         5 6 4            4 8 3           3 10 2         2 12
+--R               164003840a b c  + 39536640a b c  + 3075072a b  c  + 58240a b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                           8   6             7 3 5              6 5 4
+--R                 124780544a b c  + 779878400a b c  + 1013841920a b c
+--R               + 
+--R                           5 7 3            4 9 2           3 11
+--R                 398295040a b c  + 49786880a b c  + 1584128a b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          9 6              8 2 5              7 4 4
+--R                 66060288a c  + 1403781120a b c  + 3509452800a b c
+--R               + 
+--R                            6 6 3             5 8 2            4 10
+--R                 2281144320a b c  + 448081920a b c  + 22404096a b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                            9   5              8 3 4              7 5 3
+--R                 1255145472a b c  + 7112491008a b c  + 8001552384a b c
+--R               + 
+--R                            6 7 2             5 9
+--R                 2476670976a b c  + 189190144a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           10 5              9 2 4               8 4 3
+--R                 440401920a  c  + 8367636480a b c  + 17781227520a b c
+--R               + 
+--R                            7 6 2              6 8
+--R                 8890613760a b c  + 1031946240a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                            10   4               9 3 3               8 5 2
+--R                 5284823040a  b c  + 25102909440a b c  + 21337473024a b c
+--R               + 
+--R                            7 7
+--R                 3810263040a b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            11 4               10 2 3               9 4 2
+--R                 1384120320a  c  + 21799895040a  b c  + 34516500480a b c
+--R               + 
+--R                            8 6
+--R                 9779675136a b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                          11   3               10 3 2               9 5   6
+--R             (10611589120a  b c  + 37140561920a  b c  + 17641766912a b c)x
+--R           + 
+--R                         12 3               11 2 2               10 4   5
+--R             (2214592512a  c  + 25467813888a  b c  + 22284337152a  b c)x
+--R           + 
+--R                          12   2               11 3   4
+--R             (10066329600a  b c  + 19293798400a  b c)x
+--R           + 
+--R                         13 2               12 2   3              13     2
+--R             (1744830464a  c  + 10905190400a  b c)x  + 3623878656a  b c x
+--R           + 
+--R                       14
+--R             536870912a  c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                         7 8          6 2 7           5 4 6           4 6 5
+--R                 - 32768a c  - 745472a b c  - 2050048a b c  - 1537536a b c
+--R               + 
+--R                          3 8 4         2 10 3         12 2     14
+--R                 - 384384a b c  - 32032a b  c  - 728a b  c  - 2b  c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                           7   7            6 3 6            5 5 5
+--R                 - 3457024a b c  - 22736896a b c  - 31775744a b c
+--R               + 
+--R                            4 7 4           3 9 3          2 11 2          13
+--R                 - 13947648a b c  - 2114112a b c  - 103376a b  c  - 1204a b  c
+--R               + 
+--R                    15
+--R                 - b
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                           8 7            7 2 6             6 4 5
+--R                 - 3702784a c  - 85155840a b c  - 237619200a b c
+--R               + 
+--R                             5 6 4            4 8 3           3 10 2
+--R                 - 181941760a b c  - 46949760a b c  - 4132128a b  c
+--R               + 
+--R                          2 12          14
+--R                 - 105560a b  c - 450a b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                             8   6             7 3 5              6 5 4
+--R                 - 130285568a b c  - 848691200a b c  - 1170391040a b c
+--R               + 
+--R                           5 7 3            4 9 2           3 11          2 13
+--R               - 503726080a b c  - 73948160a b c  - 3401216a b  c - 33600a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                            9 6              8 2 5              7 4 4
+--R                 - 69730304a c  - 1559756800a b c  - 4191846400a b c
+--R               + 
+--R                              6 6 3             5 8 2            4 10
+--R                 - 3041525760a b c  - 721909760a b c  - 54765568a b  c
+--R               + 
+--R                          3 12
+--R                 - 990080a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                              9   5              8 3 4               7 5 3
+--R                 - 1420296192a b c  - 8750235648a b c  - 11160059904a b c
+--R               + 
+--R                              6 7 2             5 9             4 11
+--R                 - 4268998656a b c  - 512804864a b c - 15275520a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                             10 5               9 2 4               8 4 3
+--R                 - 506462208a  c  - 10564141056a b c  - 25782779904a b c
+--R               + 
+--R                               7 6 2              6 8              5 10
+--R                 - 16225370112a b c  - 3044241408a b c - 141892608a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                              10   4               9 3 3               8 5 2
+--R                 - 6826229760a  b c  - 37654364160a b c  - 40896823296a b c
+--R               + 
+--R                               7 7              6 9
+--R                 - 12065832960a b c - 859955200a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                              11 4               10 2 3               9 4 2
+--R                 - 1824522240a  c  - 33690746880a  b c  - 69033000960a b c
+--R               + 
+--R                               8 6               7 8
+--R                 - 32895270912a b c - 3572121600a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                               11   3               10 3 2               9 5
+--R                 - 16840130560a  b c  - 77107036160a  b c  - 62513217536a b c
+--R               + 
+--R                               8 7
+--R                 - 10478223360a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                              12 3               11 2 2               10 4
+--R                 - 3598712832a  c  - 54649683968a  b c  - 82637750272a  b c
+--R               + 
+--R                               9 6
+--R                 - 22052208640a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                            12   2               11 3                10 5  5
+--R             (- 22246588416a  b c  - 74474061824a  b c - 33426505728a  b )x
+--R           + 
+--R                           13 2               12 2                11 4  4
+--R             (- 3959422976a  c  - 43620761600a  b c - 36175872000a  b )x
+--R           + 
+--R                            13                  12 3  3
+--R             (- 14965276672a  b c - 27262976000a  b )x
+--R           + 
+--R                           14                13 2  2              14
+--R             (- 2281701376a  c - 13589544960a  b )x  - 4026531840a  b x
+--R           + 
+--R                         15
+--R             - 536870912a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                          6   8           5 3 7           4 5 6          3 7 5
+--R                 - 229376a b c  - 1490944a b c  - 2050048a b c  - 878592a b c
+--R               + 
+--R                          2 9 4          11 3      13 2
+--R                 - 128128a b c  - 5824a b  c  - 56b  c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                          7 8            6 2 7            5 4 6            4 6 5
+--R                 - 491520a c  - 11296768a b c  - 31496192a b c  - 24088064a b c
+--R               + 
+--R                           3 8 4          2 10 3           12 2      14
+--R                 - 6205056a b c  - 544544a b  c  - 13832a b  c  - 58b  c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                            7   7             6 3 6             5 5 5
+--R                 - 25919488a b c  - 170311680a b c  - 237619200a b c
+--R               + 
+--R                           4 7 4            3 9 3          2 11 2          13
+--R               - 103966720a b c  - 15649920a b c  - 751296a b  c  - 8120a b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                            8 7             7 2 6              6 4 5
+--R                 - 18350080a c  - 416546816a b c  - 1141145600a b c
+--R               + 
+--R                             5 6 4             4 8 3            3 10 2
+--R                 - 849838080a b c  - 209397760a b c  - 16839680a b  c
+--R               + 
+--R                          2 12
+--R                 - 337792a b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                             8   6              7 3 5              6 5 4
+--R                 - 469762048a b c  - 2963537920a b c  - 3899392000a b c
+--R               + 
+--R                              5 7 3             4 9 2           3 11
+--R                 - 1556971520a b c  - 199147520a b c  - 6562816a b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                             9 6              8 2 5               7 4 4
+--R                 - 198180864a c  - 4244373504a b c  - 10715529216a b c
+--R               + 
+--R                              6 6 3              5 8 2            4 10
+--R                 - 7054000128a b c  - 1409421312a b c  - 72190976a b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                              9   5               8 3 4               7 5 3
+--R                 - 3148873728a b c  - 17990418432a b c  - 20448411648a b c
+--R               + 
+--R                              6 7 2             5 9
+--R                 - 6413942784a b c  - 498774016a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                             10 5               9 2 4               8 4 3
+--R                 - 943718400a  c  - 18056478720a b c  - 38700318720a b c
+--R               + 
+--R                               7 6 2              6 8
+--R                 - 19559350272a b c  - 2302033920a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                              10   4               9 3 3               8 5 2
+--R                 - 9940500480a  b c  - 47563407360a b c  - 40792227840a b c
+--R               + 
+--R                              7 7
+--R                 - 7366508544a b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                              11 4               10 2 3               9 4 2
+--R                 - 2306867200a  c  - 36563845120a  b c  - 58334904320a b c
+--R               + 
+--R                               8 6
+--R                 - 16682975232a b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                            11   3               10 3 2               9 5   6
+--R             (- 15963521024a  b c  - 56241422336a  b c  - 26926907392a b c)x
+--R           + 
+--R                           12 3               11 2 2               10 4   5
+--R             (- 3019898880a  c  - 34930163712a  b c  - 30773608448a  b c)x
+--R           + 
+--R                            12   2               11 3   4
+--R             (- 12616466432a  b c  - 24326963200a  b c)x
+--R           + 
+--R                           13 2               12 2   3              13     2
+--R             (- 2013265920a  c  - 12650020864a  b c)x  - 3892314112a  b c x
+--R           + 
+--R                         14
+--R             - 536870912a  c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                           6 6         5 2 5          4 4 4         3 6 3
+--R                   - 61440a c  - 92160a b c  + 403200a b c  - 80640a b c
+--R                 + 
+--R                           2 8 2          10        12
+--R                   - 26640a b c  + 5400a b  c + 105b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                             6   5           5 3 4          4 5 3          3 7 2
+--R                   - 1105920a b c  + 1566720a b c  + 967680a b c  - 587520a b c
+--R                 + 
+--R                         2 9           11
+--R                   36000a b c + 7560a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             7 5           6 2 4           5 4 3           4 6 2
+--R                   - 1105920a c  - 1382400a b c  + 6865920a b c  - 1693440a b c
+--R                 + 
+--R                            3 8          2 10
+--R                   - 332640a b c + 88200a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                             7   4           6 3 3           5 5 2
+--R                   - 5898240a b c  + 9830400a b c  + 2211840a b c
+--R                 + 
+--R                             4 7           3 9
+--R                   - 2580480a b c + 376320a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          8 4            6 4 2           5 6           4 8  3
+--R               (- 2949120a c  + 12165120a b c  - 5898240a b c + 725760a b )x
+--R             + 
+--R                          8   3            7 3 2           6 5           5 7  2
+--R               (- 5898240a b c  + 13271040a b c  - 5529600a b c + 645120a b )x
+--R             + 
+--R                          9 3           8 2 2           7 4           6 6
+--R               (- 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b )x
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b x + a
+--R         + 
+--R                          5   6          4 3 5          3 5 4         2 7 3
+--R                   184320a b c  - 261120a b c  - 161280a b c  + 97920a b c
+--R                 + 
+--R                            9 2        11
+--R                   - 6000a b c  - 1260b  c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          6 6          5 2 5           4 4 4          3 6 3
+--R                   368640a c  + 645120a b c  - 2549760a b c  + 403200a b c
+--R                 + 
+--R                          2 8 2           10         12
+--R                   208800a b c  - 35400a b  c - 1260b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                           6   5           5 3 4           4 5 3           3 7 2
+--R                   3502080a b c  - 4715520a b c  - 3555840a b c  + 1952640a b c
+--R                 + 
+--R                           2 9            11
+--R                   - 83280a b c - 30660a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                           7 5           6 2 4            5 4 3           4 6 2
+--R                   2334720a c  + 3409920a b c  - 15313920a b c  + 3390720a b c
+--R                 + 
+--R                          3 8           2 10
+--R                   917280a b c - 217560a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                           7   4            6 3 3           5 5 2           4 7
+--R                   9830400a b c  - 15974400a b c  - 4608000a b c  + 4684800a b c
+--R                 + 
+--R                            3 9
+--R                   - 672000a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                           8 4          7 2 3            6 4 2           5 6
+--R                   3932160a c  + 491520a b c  - 17326080a b c  + 8325120a b c
+--R                 + 
+--R                             4 8
+--R                   - 1021440a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                        8   3            7 3 2           6 5           5 7  2
+--R               (6881280a b c  - 15482880a b c  + 6451200a b c - 752640a b )x
+--R             + 
+--R                        9 3           8 2 2           7 4           6 6
+--R               (1966080a c  - 4423680a b c  + 1843200a b c - 215040a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                            5   5          4 3 4          3 5 3          2 7 2
+--R                   - 368640a b c  + 522240a b c  + 322560a b c  - 195840a b c
+--R                 + 
+--R                           9         11
+--R                   12000a b c + 2520b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                            6 5          5 2 4           4 4 3           3 6 2
+--R                   - 737280a c  - 921600a b c  + 4577280a b c  - 1128960a b c
+--R                 + 
+--R                            2 8            10
+--R                   - 221760a b c + 58800a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                             6   4           5 3 3           4 5 2
+--R                   - 5898240a b c  + 9830400a b c  + 2211840a b c
+--R                 + 
+--R                             3 7           2 9
+--R                   - 2580480a b c + 376320a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                          7 4            5 4 2           4 6           3 8  2
+--R               (- 3932160a c  + 16220160a b c  - 7864320a b c + 967680a b )x
+--R             + 
+--R                          7   3            6 3 2           5 5            4 7
+--R               (- 9830400a b c  + 22118400a b c  - 9216000a b c + 1075200a b )x
+--R             + 
+--R                         8 3           7 2 2           6 4           5 6
+--R               - 3932160a c  + 8847360a b c  - 3686400a b c + 430080a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                          6 6          5 2 5          4 4 4          3 6 3
+--R                   122880a c  + 184320a b c  - 806400a b c  + 161280a b c
+--R                 + 
+--R                         2 8 2           10        12
+--R                   53280a b c  - 10800a b  c - 210b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                           6   5           5 3 4           4 5 3           3 7 2
+--R                   2211840a b c  - 3133440a b c  - 1935360a b c  + 1175040a b c
+--R                 + 
+--R                           2 9            11
+--R                   - 72000a b c - 15120a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                           7 5           6 2 4            5 4 3           4 6 2
+--R                   2211840a c  + 2764800a b c  - 13731840a b c  + 3386880a b c
+--R                 + 
+--R                          3 8           2 10
+--R                   665280a b c - 176400a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            7   4            6 3 3           5 5 2
+--R                   11796480a b c  - 19660800a b c  - 4423680a b c
+--R                 + 
+--R                           4 7           3 9
+--R                   5160960a b c - 752640a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                        8 4            6 4 2            5 6            4 8  2
+--R               (5898240a c  - 24330240a b c  + 11796480a b c - 1451520a b )x
+--R             + 
+--R                         8   3            7 3 2            6 5            5 7
+--R               (11796480a b c  - 26542080a b c  + 11059200a b c - 1290240a b )x
+--R             + 
+--R                       9 3           8 2 2           7 4           6 6
+--R               3932160a c  - 8847360a b c  + 3686400a b c - 430080a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                         3 8          2 2 7            4 6        6 5  11
+--R               (- 163840a c  - 614400a b c  - 153600a b c  - 2560b c )x
+--R             + 
+--R                          3   7           2 3 6            5 5        7 4  10
+--R               (- 3162112a b c  - 3256320a b c  - 384000a b c  - 3328b c )x
+--R             + 
+--R                             4 7            3 2 6           2 4 5            6 4
+--R                   - 3235840a c  - 15237120a b c  - 5637120a b c  - 249856a b c
+--R                 + 
+--R                        8 3
+--R                   - 96b c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                              4   6            3 3 5           2 5 4         7 3
+--R                   - 24760320a b c  - 27136000a b c  - 3217920a b c  - 768a b c
+--R                 + 
+--R                       9 2
+--R                   112b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              5 6            4 2 5            3 4 4        2 6 3
+--R                   - 13086720a c  - 57154560a b c  - 16360960a b c  + 2688a b c
+--R                 + 
+--R                         8 2       10
+--R                   528a b c  - 140b  c
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                              5   5            4 3 4         3 5 3         2 7 2
+--R                   - 55080960a b c  - 41244160a b c  + 26880a b c  - 16320a b c
+--R                 + 
+--R                          9        11
+--R                   1000a b c + 210b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                              6 5            5 2 4           4 4 3
+--R                   - 20111360a c  - 55633920a b c  + 1090560a b c
+--R                 + 
+--R                            3 6 2         2 8            10
+--R                   - 296192a b c  - 40800a b c + 12600a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                              6   4           5 3 3          4 5 2          3 7
+--R                   - 40017920a b c  + 3440640a b c  + 537600a b c  - 788480a b c
+--R                 + 
+--R                          2 9
+--R                   117600a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                              7 4          6 2 3           5 4 2           4 6
+--R                   - 12124160a c  + 245760a b c  + 6205440a b c  - 3046400a b c
+--R                 + 
+--R                          3 8
+--R                   376320a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                          7   3           6 3 2           5 5           4 7  2
+--R               (- 4423680a b c  + 9953280a b c  - 4147200a b c + 483840a b )x
+--R             + 
+--R                          8 3           7 2 2           6 4           5 6
+--R               (- 1966080a c  + 4423680a b c  - 1843200a b c + 215040a b )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                       2   8            3 7         5 6  12
+--R               (491520a b c  + 409600a b c  + 30720b c )x
+--R             + 
+--R                       3 8           2 2 7             4 6         6 5  11
+--R               (983040a c  + 4571136a b c  + 1658880a b c  + 70656b c )x
+--R             + 
+--R                         3   7            2 3 6             5 5         7 4  10
+--R               (11476992a b c  + 14284800a b c  + 2280960a b c  + 41088b c )x
+--R             + 
+--R                           4 7            3 2 6            2 4 5             6 4
+--R                   7946240a c  + 42270720a b c  + 18462720a b c  + 1056768a b c
+--R                 + 
+--R                         8 3
+--R                   - 192b c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            4   6            3 3 5           2 5 4          7 3
+--R                   51056640a b c  + 62361600a b c  + 8501760a b c  - 2304a b c
+--R                 + 
+--R                       9 2
+--R                   336b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            5 6             4 2 5            3 4 4         2 6 3
+--R                   21749760a c  + 102389760a b c  + 31964160a b c  + 16128a b c
+--R                 + 
+--R                          8 2       10
+--R                   3168a b c  - 840b  c
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            5   5            4 3 4          3 5 3          2 7 2
+--R                   81930240a b c  + 64094720a b c  - 341760a b c  + 254016a b c
+--R                 + 
+--R                             9         11
+--R                   - 22200a b c - 2310b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            6 5            5 2 4           4 4 3           3 6 2
+--R                   25927680a c  + 73820160a b c  - 4254720a b c  + 1212672a b c
+--R                 + 
+--R                          2 8            10
+--R                   133920a b c - 46200a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                            6   4           5 3 3           4 5 2           3 7
+--R                   47800320a b c  - 7864320a b c  - 1059840a b c  + 1720320a b c
+--R                 + 
+--R                            2 9
+--R                   - 258720a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            7 4          6 2 3           5 4 2           4 6
+--R                   13107200a c  - 491520a b c  - 9707520a b c  + 4782080a b c
+--R                 + 
+--R                            3 8
+--R                   - 591360a b
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                        7   3            6 3 2           5 5           4 7  2
+--R               (5406720a b c  - 12165120a b c  + 5068800a b c - 591360a b )x
+--R             + 
+--R                        8 3           7 2 2           6 4           5 6
+--R               (1966080a c  - 4423680a b c  + 1843200a b c - 215040a b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                     2   8            3 7         5 6  13
+--R           (- 491520a b c  - 409600a b c  - 30720b c )x
+--R         + 
+--R                     3 8           2 2 7             4 6         6 5  12
+--R           (- 983040a c  - 4571136a b c  - 1658880a b c  - 70656b c )x
+--R         + 
+--R                       3   7            2 3 6             5 5         7 4  11
+--R           (- 11476992a b c  - 14284800a b c  - 2280960a b c  - 41088b c )x
+--R         + 
+--R                         4 7            3 2 6            2 4 5             6 4
+--R               - 7946240a c  - 42270720a b c  - 18462720a b c  - 1056768a b c
+--R             + 
+--R                   8 3
+--R               192b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          4   6            3 3 5           2 5 4          7 3
+--R               - 51056640a b c  - 62361600a b c  - 8501760a b c  + 2304a b c
+--R             + 
+--R                     9 2
+--R               - 336b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                          5 6             4 2 5            3 4 4         2 6 3
+--R               - 21749760a c  - 102389760a b c  - 31964160a b c  - 16128a b c
+--R             + 
+--R                        8 2       10
+--R               - 3168a b c  + 840b  c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                          5   5            4 3 4          3 5 3          2 7 2
+--R               - 81764352a b c  - 63569920a b c  + 145920a b c  - 292224a b c
+--R             + 
+--R                       9         11
+--R               33280a b c + 2520b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                          6 5            5 2 4           4 4 3           3 6 2
+--R               - 25927680a c  - 70834176a b c  + 4992000a b c  - 2243328a b c
+--R             + 
+--R                       2 8            10
+--R               - 41760a b c + 61320a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                          6   4            5 3 3           4 5 2           3 7
+--R               - 44814336a b c  + 16564224a b c  - 2649600a b c  - 2150400a b c
+--R             + 
+--R                      2 9
+--R               435120a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                          7 4            6 2 3           5 4 2           4 6
+--R               - 13107200a c  + 16416768a b c  + 9658368a b c  - 8939520a b c
+--R             + 
+--R                       3 8
+--R               1344000a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    7   3            6 3 2            5 5            4 7  3
+--R           (2555904a b c  + 25411584a b c  - 14929920a b c + 2042880a b )x
+--R         + 
+--R                      8 3            7 2 2            6 4            5 6  2
+--R           (- 1966080a c  + 20348928a b c  - 11182080a b c + 1505280a b )x
+--R         + 
+--R                    8   2           7 3           6 5
+--R           (5308416a b c  - 3112960a b c + 430080a b )x
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                   3 9          2 2 8            4 7        6 6  14
+--R           (163840a c  + 614400a b c  + 153600a b c  + 2560b c )x
+--R         + 
+--R                    3   8           2 3 7            5 6        7 5  13
+--R           (3325952a b c  + 3870720a b c  + 537600a b c  + 5888b c )x
+--R         + 
+--R                       4 8            3 2 7           2 4 6            6 5
+--R               3399680a c  + 19013632a b c  + 9047040a b c  + 636416a b c
+--R             + 
+--R                    8 4
+--R               3424b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        4   7            3 3 6           2 5 5            7 4
+--R               31158272a b c  + 45629440a b c  + 9239040a b c  + 253952a b c
+--R             + 
+--R                    9 3
+--R               - 16b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        5 7            4 2 6            3 4 5           2 6 4
+--R               16322560a c  + 97152000a b c  + 49134080a b c  + 3465088a b c
+--R             + 
+--R                     8 3      10 2
+--R               336a b c  + 28b  c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        5   6             4 3 5            3 5 4         2 7 3
+--R               92928000a b c  + 125534720a b c  + 19552000a b c  + 14400a b c
+--R             + 
+--R                        9 2      11
+--R               - 1640a b c  - 70b  c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                        6 6             5 2 5            4 4 4          3 6 3
+--R               33198080a c  + 167371776a b c  + 56391680a b c  + 438400a b c
+--R             + 
+--R                     2 8 2           10        12
+--R               41232a b c  - 15980a b  c - 210b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         6   5            5 3 4          4 5 3           3 7 2
+--R               114214912a b c  + 90039808a b c  - 541440a b c  + 1416128a b c
+--R             + 
+--R                        2 9            11
+--R               - 151960a b c - 15330a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                        7 5            6 2 4            5 4 3           4 6 2
+--R               32235520a c  + 85950464a b c  - 13734912a b c  + 6291968a b c
+--R             + 
+--R                      3 8           2 10
+--R               204640a b c - 191520a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        7   4            6 3 3           5 5 2           4 7
+--R               50262016a b c  - 33333248a b c  + 5239296a b c  + 4605440a b c
+--R             + 
+--R                        3 9
+--R               - 929040a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                        8 4            7 2 3            6 4 2            5 6
+--R               14090240a c  - 26787840a b c  - 15339520a b c  + 14556160a b c
+--R             + 
+--R                         4 8
+--R               - 2204160a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      8   3            7 3 2            6 5            5 7  3
+--R           (- 4227072a b c  - 33366016a b c  + 19916800a b c - 2741760a b )x
+--R         + 
+--R                    9 3            8 2 2            7 4            6 6  2
+--R           (1966080a c  - 23003136a b c  + 12738560a b c - 1720320a b )x
+--R         + 
+--R                      9   2           8 3           7 5
+--R           (- 5308416a b c  + 3112960a b c - 430080a b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                      2   6             3 5          5 4  5
+--R             (2949120a b c  + 2457600a b c  + 184320b c )x
+--R           + 
+--R                      3 6            2 2 5             4 4  4
+--R             (5898240a c  + 20643840a b c  + 4300800a b c )x
+--R           + 
+--R                       3   5            2 3 4  3
+--R             (47185920a b c  + 27525120a b c )x
+--R           + 
+--R                       4 5            3 2 4  2            4   4             5 4
+--R             (31457280a c  + 70778880a b c )x  + 78643200a b c x + 31457280a c
+--R        *
+--R                          +--------------+
+--R            +---+ +-+ +-+ |   2
+--R           \|- c \|a \|c \|c x  + b x + a
+--R       + 
+--R                       3 7           2 2 6            4 5         6 4  6
+--R             (- 983040a c  - 3686400a b c  - 921600a b c  - 15360b c )x
+--R           + 
+--R                         3   6            2 3 5             5 4  5
+--R             (- 17694720a b c  - 14745600a b c  - 1105920a b c )x
+--R           + 
+--R                         4 6            3 2 5            2 4 4  4
+--R             (- 17694720a c  - 61931520a b c  - 12902400a b c )x
+--R           + 
+--R                         4   5            3 3 4  3
+--R             (- 94371840a b c  - 55050240a b c )x
+--R           + 
+--R                       5 5             4 2 4  2            5   4             6 4
+--R           (- 47185920a c  - 106168320a b c )x  - 94371840a b c x - 31457280a c
+--R        *
+--R            +---+ +-+
+--R           \|- c \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                           5   7          4 3 6          3 5 5         2 7 4
+--R                   - 24576a b c  - 112640a b c  - 101376a b c  - 25344a b c
+--R                 + 
+--R                            9 3      11 2
+--R                   - 1760a b c  - 24b  c
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                           6 7          5 2 6           4 4 5          3 6 4
+--R                   - 49152a c  - 847872a b c  - 1689600a b c  - 861696a b c
+--R                 + 
+--R                            2 8 3          10 2      12
+--R                   - 133056a b c  - 5808a b  c  - 48b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                             6   6           5 3 5           4 5 4
+--R                   - 1867776a b c  - 9302016a b c  - 9394176a b c
+--R                 + 
+--R                             3 7 3          2 9 2          11       13
+--R                   - 2787840a b c  - 257664a b c  - 6384a b  c - 24b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                             7 6            6 2 5            5 4 4
+--R                   - 1245184a c  - 22339584a b c  - 46817280a b c
+--R                 + 
+--R                              4 6 3           3 8 2          2 10           12
+--R                   - 25535488a b c  - 4333824a b c  - 218592a b  c - 2336a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                              7   5             6 3 4             5 5 3
+--R                   - 24207360a b c  - 121559040a b c  - 123423744a b c
+--R                 + 
+--R                              4 7 2           3 9          2 11
+--R                   - 36486912a b c  - 3259872a b c - 68664a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                             8 5             7 2 4             6 4 3
+--R                   - 9682944a c  - 170078208a b c  - 344094720a b c
+--R                 + 
+--R                               5 6 2            4 8           3 10
+--R                   - 176217600a b c  - 26330304a b c - 954096a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                               8   4             7 3 3             6 5 2
+--R                   - 121454592a b c  - 572178432a b c  - 524482560a b c
+--R                 + 
+--R                               5 7            4 9
+--R                   - 128953344a b c - 7568704a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                              9 4             8 2 3             7 4 2
+--R                   - 34701312a c  - 559841280a b c  - 994480128a b c
+--R                 + 
+--R                               6 6             5 8
+--R                   - 407758848a b c - 37884288a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                               9   3              8 3 2             7 5
+--R                   - 297271296a b c  - 1204420608a b c  - 860258304a b c
+--R                 + 
+--R                               6 7
+--R                   - 126738432a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                              10 3             9 2 2              8 4
+--R                   - 66060288a  c  - 902037504a b c  - 1223491584a b c
+--R                 + 
+--R                               7 6
+--R                   - 292732928a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            10   2              9 3              8 5  7
+--R               (- 380633088a  b c  - 1159200768a b c - 473628672a b )x
+--R             + 
+--R                           11 2             10 2              9 4  6
+--R               (- 69206016a  c  - 701497344a  b c - 535953408a b )x
+--R             + 
+--R                            11                10 3  5
+--R               (- 245366784a  b c - 415760384a  b )x
+--R             + 
+--R                           12              11 2  4            12   3
+--R               (- 37748736a  c - 210763776a  b )x  - 62914560a  b x
+--R             + 
+--R                         13 2
+--R               - 8388608a  x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                    6 8         5 2 7          4 4 6         3 6 5        2 8 4
+--R               4096a c  + 67584a b c  + 126720a b c  + 59136a b c  + 7920a b c
+--R             + 
+--R                     10 3    12 2
+--R               264a b  c  + b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                      6   7           5 3 6           4 5 5          3 7 4
+--R               303104a b c  + 1486848a b c  + 1469952a b c  + 422400a b c
+--R             + 
+--R                     2 9 3         11 2     13
+--R               36960a b c  + 816a b  c  + 2b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                      7 7           6 2 6            5 4 5           4 6 4
+--R               303104a c  + 5521408a b c  + 11810304a b c  + 6631680a b c
+--R             + 
+--R                       3 8 3         2 10 2         12     14
+--R               1177440a b c  + 64416a b  c  + 842a b  c + b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                       7   6            6 3 5            5 5 4            4 7 3
+--R               8069120a b c  + 42536960a b c  + 46210560a b c  + 15121920a b c
+--R             + 
+--R                       3 9 2         2 11          13
+--R               1606880a b c  + 49680a b  c + 290a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                       8 6            7 2 5             6 4 4            5 6 3
+--R               4034560a c  + 75909120a b c  + 168697600a b c  + 99137280a b c
+--R             + 
+--R                        4 8 2           3 10          2 12
+--R               18572400a b c  + 1076680a b  c + 14305a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        8   5             7 3 4             6 5 3
+--R               65568768a b c  + 345825280a b c  + 372887552a b c
+--R             + 
+--R                         5 7 2            4 9           3 11
+--R               118914048a b c  + 11735680a b c + 284000a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                        9 5             8 2 4             7 4 3
+--R               21856256a c  + 400465920a b c  + 852029440a b c
+--R             + 
+--R                         6 6 2            5 8            4 10
+--R               463909888a b c  + 74845056a b c + 2997280a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         9   4              8 3 3              7 5 2
+--R               244449280a b c  + 1202585600a b c  + 1160429568a b c
+--R             + 
+--R                         6 7             5 9
+--R               303620096a b c + 19255808a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        10 4              9 2 3              8 4 2
+--R               61112320a  c  + 1024163840a b c  + 1901506560a b c
+--R             + 
+--R                         7 6             6 8
+--R               821442560a b c + 81278080a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         10   3              9 3 2              8 5
+--R               482344960a  b c  + 2031616000a b c  + 1517813760a b c
+--R             + 
+--R                         7 7
+--R               235765760a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                          11 3              10 2 2              9 4
+--R                 96468992a  c  + 1363673088a  b c  + 1924136960a b c
+--R               + 
+--R                           8 6
+--R                 481853440a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      11   2              10 3              9 5  7
+--R           (522190848a  b c  + 1647312896a  b c + 700579840a b )x
+--R         + 
+--R                     12 2             11 2              10 4  6
+--R           (87031808a  c  + 910688256a  b c + 721092608a  b )x
+--R         + 
+--R                      12                11 3  5
+--R           (293601280a  b c + 513802240a  b )x
+--R         + 
+--R                     13              12 2  4            13   3           14 2
+--R           (41943040a  c + 241172480a  b )x  + 67108864a  b x  + 8388608a  x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      6 8         5 2 7          4 4 6         3 6 5
+--R               - 4096a c  - 67584a b c  - 126720a b c  - 59136a b c
+--R             + 
+--R                      2 8 4         10 3    12 2
+--R               - 7920a b c  - 264a b  c  - b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                        6   7           5 3 6           4 5 5          3 7 4
+--R               - 303104a b c  - 1486848a b c  - 1469952a b c  - 422400a b c
+--R             + 
+--R                       2 9 3         11 2     13
+--R               - 36960a b c  - 816a b  c  - 2b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                        7 7           6 2 6            5 4 5           4 6 4
+--R               - 303104a c  - 5521408a b c  - 11810304a b c  - 6631680a b c
+--R             + 
+--R                         3 8 3         2 10 2         12     14
+--R               - 1177440a b c  - 64416a b  c  - 842a b  c - b
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                         7   6            6 3 5            5 5 4
+--R               - 8069120a b c  - 42536960a b c  - 46210560a b c
+--R             + 
+--R                          4 7 3           3 9 2         2 11          13
+--R               - 15121920a b c  - 1606880a b c  - 49680a b  c - 290a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                         8 6            7 2 5             6 4 4            5 6 3
+--R               - 4034560a c  - 75909120a b c  - 168697600a b c  - 99137280a b c
+--R             + 
+--R                          4 8 2           3 10          2 12
+--R               - 18572400a b c  - 1076680a b  c - 14305a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                          8   5             7 3 4             6 5 3
+--R               - 65568768a b c  - 345825280a b c  - 372887552a b c
+--R             + 
+--R                           5 7 2            4 9           3 11
+--R               - 118914048a b c  - 11735680a b c - 284000a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                          9 5             8 2 4             7 4 3
+--R               - 21856256a c  - 400465920a b c  - 852029440a b c
+--R             + 
+--R                           6 6 2            5 8            4 10
+--R               - 463909888a b c  - 74845056a b c - 2997280a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                           9   4              8 3 3              7 5 2
+--R               - 244449280a b c  - 1202585600a b c  - 1160429568a b c
+--R             + 
+--R                           6 7             5 9
+--R               - 303620096a b c - 19255808a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          10 4              9 2 3              8 4 2
+--R               - 61112320a  c  - 1024163840a b c  - 1901506560a b c
+--R             + 
+--R                           7 6             6 8
+--R               - 821442560a b c - 81278080a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                           10   3              9 3 2              8 5
+--R               - 482344960a  b c  - 2031616000a b c  - 1517813760a b c
+--R             + 
+--R                           7 7
+--R               - 235765760a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          11 3              10 2 2              9 4
+--R               - 96468992a  c  - 1363673088a  b c  - 1924136960a b c
+--R             + 
+--R                           8 6
+--R               - 481853440a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                        11   2              10 3              9 5  8
+--R           (- 522190848a  b c  - 1647312896a  b c - 700579840a b )x
+--R         + 
+--R                       12 2             11 2              10 4  7
+--R           (- 87031808a  c  - 910688256a  b c - 721092608a  b )x
+--R         + 
+--R                        12                11 3  6
+--R           (- 293601280a  b c - 513802240a  b )x
+--R         + 
+--R                       13              12 2  5            13   4           14 3
+--R           (- 41943040a  c - 241172480a  b )x  - 67108864a  b x  - 8388608a  x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                     5   8          4 3 7          3 5 6         2 7 5
+--R               24576a b c  + 112640a b c  + 101376a b c  + 25344a b c
+--R             + 
+--R                      9 4      11 3
+--R               1760a b c  + 24b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                     6 8          5 2 7           4 4 6          3 6 5
+--R               49152a c  + 872448a b c  + 1802240a b c  + 963072a b c
+--R             + 
+--R                      2 8 4          10 3      12 2
+--R               158400a b c  + 7568a b  c  + 72b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                       6   7            5 3 6            4 5 5           3 7 4
+--R               1941504a b c  + 10262528a b c  + 11185152a b c  + 3674880a b c
+--R             + 
+--R                      2 9 3           11 2      13
+--R               392480a b c  + 12216a b  c  + 72b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                       7 7            6 2 6            5 4 5            4 6 4
+--R               1294336a c  + 25055232a b c  + 57808896a b c  + 35791360a b c
+--R             + 
+--R                       3 8 3          2 10 2          12       14
+--R               7254720a b c  + 482064a b  c  + 8768a b  c + 24b
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                        7   6             6 3 5             5 5 4
+--R               27320320a b c  + 153200640a b c  + 179635200a b c
+--R             + 
+--R                        4 7 3           3 9 2          2 11           13
+--R               64810240a b c  + 7851360a b c  + 293640a b  c + 2360a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                        8 6             7 2 5             6 4 4
+--R               10928128a c  + 216625152a b c  + 512471040a b c
+--R             + 
+--R                         5 6 3            4 8 2           3 10          2 12
+--R               325176832a b c  + 67151040a b c  + 4432560a b  c + 71000a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                         8   5             7 3 4             6 5 3
+--R               155344896a b c  + 863815680a b c  + 992001024a b c
+--R             + 
+--R                         5 7 2            4 9            3 11
+--R               341657856a b c  + 37158880a b c + 1022760a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        9 5             8 2 4              7 4 3
+--R               44384256a c  + 851374080a b c  + 1910753280a b c
+--R             + 
+--R                          6 6 2             5 8            4 10
+--R               1108459008a b c  + 193167936a b c + 8522800a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         9   4              8 3 3              7 5 2
+--R               453427200a b c  + 2336440320a b c  + 2379220992a b c
+--R             + 
+--R                         6 7             5 9
+--R               663450624a b c + 45452992a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         10 4              9 2 3              8 4 2
+--R               100761600a  c  + 1759150080a b c  + 3422392320a b c
+--R             + 
+--R                          7 6              6 8
+--R               1560750080a b c + 164622720a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         10   3              9 3 2              8 5
+--R               743964672a  b c  + 3265658880a b c  + 2557378560a b c
+--R             + 
+--R                         7 7
+--R               419471360a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         11 3              10 2 2              9 4
+--R               135266304a  c  + 1984167936a  b c  + 2918645760a b c
+--R             + 
+--R                         8 6
+--R               766361600a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                      11   2              10 3               9 5  8
+--R           (695205888a  b c  + 2276458496a  b c + 1009582080a b )x
+--R         + 
+--R                      12 2              11 2              10 4  7
+--R           (106954752a  c  + 1157627904a  b c + 951713792a  b )x
+--R         + 
+--R                      12                11 3  6
+--R           (346030080a  b c + 626524160a  b )x
+--R         + 
+--R                     13              12 2  5            13   4           14 3
+--R           (46137344a  c + 273678336a  b )x  + 71303168a  b x  + 8388608a  x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                      6 6         5 2 5          4 4 4         3 6 3
+--R                 4096a c  + 67584a b c  + 126720a b c  + 59136a b c
+--R               + 
+--R                      2 8 2         10     12
+--R                 7920a b c  + 264a b  c + b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                        6   5           5 3 4           4 5 3          3 7 2
+--R                 294912a b c  + 1351680a b c  + 1216512a b c  + 304128a b c
+--R               + 
+--R                       2 9          11
+--R                 21120a b c + 288a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                        7 5           6 2 4           5 4 3           4 6 2
+--R                 294912a c  + 4792320a b c  + 8785920a b c  + 3953664a b c
+--R               + 
+--R                        3 8          2 10
+--R                 494208a b c + 13728a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                         7   4            6 3 3            5 5 2           4 7
+--R                 6881280a b c  + 29818880a b c  + 24600576a b c  + 5271552a b c
+--R               + 
+--R                        3 9
+--R                 256256a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                         8 4            7 2 3            6 4 2            5 6
+--R                 3440640a c  + 51609600a b c  + 83865600a b c  + 30750720a b c
+--R               + 
+--R                         4 8
+--R                 2471040a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            8   3             7 3 2             6 5
+--R                   44040192a b c  + 165150720a b c  + 107347968a b c
+--R                 + 
+--R                            5 7
+--R                   14057472a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                       9 3             8 2 2             7 4             6 6  6
+--R             (14680064a c  + 187170816a b c  + 233963520a b c + 50692096a b )x
+--R           + 
+--R                        9   2             8 3              7 5  5
+--R             (113246208a b c  + 320864256a b c + 120324096a b )x
+--R           + 
+--R                       10 2             9 2              8 4  4
+--R             (28311552a  c  + 268959744a b c + 190513152a b )x
+--R           + 
+--R                        10                9 3  3
+--R             (125829120a  b c + 199229440a b )x
+--R           + 
+--R                       11              10 2  2            11              12
+--R             (25165824a  c + 132120576a  b )x  + 50331648a  b x + 8388608a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                         5   6          4 3 5          3 5 4         2 7 3
+--R                 - 24576a b c  - 112640a b c  - 101376a b c  - 25344a b c
+--R               + 
+--R                          9 2      11
+--R                 - 1760a b c  - 24b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                         6 6          5 2 5           4 4 4          3 6 3
+--R                 - 49152a c  - 823296a b c  - 1576960a b c  - 760320a b c
+--R               + 
+--R                          2 8 2          10       12
+--R                 - 107712a b c  - 4048a b  c - 24b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           6   5           5 3 4           4 5 3           3 7 2
+--R                 - 1794048a b c  - 8366080a b c  - 7715840a b c  - 2002176a b c
+--R               + 
+--R                          2 9           11
+--R                 - 148192a b c - 2312a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                           7 5            6 2 4            5 4 3
+--R                 - 1196032a c  - 19722240a b c  - 36874240a b c
+--R               + 
+--R                            4 6 2           3 8          2 10
+--R                 - 17059328a b c  - 2223936a b c - 66352a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            7   4            6 3 3            5 5 2
+--R                 - 21217280a b c  - 93470720a b c  - 78833664a b c
+--R               + 
+--R                            4 7           3 9
+--R                 - 17425408a b c - 887744a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                           8 4             7 2 3             6 4 2
+--R                 - 8486912a c  - 129138688a b c  - 213749760a b c
+--R               + 
+--R                            5 6            4 8
+--R                 - 80324608a b c - 6680960a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            8   3             7 3 2             6 5
+--R                 - 91750400a b c  - 349569024a b c  - 231899136a b c
+--R               + 
+--R                            5 7
+--R                 - 31203328a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                              9 3             8 2 2             7 4
+--R                   - 26214400a c  - 338952192a b c  - 431161344a b c
+--R                 + 
+--R                              6 6
+--R                   - 95535104a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          9   2             8 3              7 5  5
+--R             (- 179306496a b c  - 515899392a b c - 197197824a b )x
+--R           + 
+--R                         10 2             9 2              8 4  4
+--R             (- 39845888a  c  - 383778816a b c - 276430848a b )x
+--R           + 
+--R                          10                9 3  3
+--R             (- 161480704a  b c - 259522560a b )x
+--R           + 
+--R                         11              10 2  2            11              12
+--R             (- 29360128a  c - 156237824a  b )x  - 54525952a  b x - 8388608a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^2
+--R 
+--R
+--R                         +------------------+
+--R            2            |   4      3      2
+--R   (1)  (c x  + b x + a)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 704
+r0:=-1/16*b*(b+2*c*x)*(a*x^2+b*x^3+c*x^4)^(3/2)/(c^2*x^3)+1/5*(a*x^2+b*x^3+_
+   c*x^4)^(5/2)/(c*x^5)-3/256*b*(b^2-4*a*c)^2*x*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(c^(7/2)*sqrt(a*x^2+b*_
+   x^3+c*x^4))+3/128*b*(b^2-4*a*c)*(b+2*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/(c^3*x)
+--R 
+--R
+--R   (2)
+--R                                          +--------------+
+--R                2   2         3       5   |   2
+--R         (- 240a b c  + 120a b c - 15b )x\|c x  + b x + a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R               5 7         4 6          4       2 3  5            3     3 2  4
+--R           256c x  + 608b c x  + (768a c  + 368b c )x  + (976a b c  - 4b c )x
+--R         + 
+--R                2 3        2 2      4   3        2   2         3       5  2
+--R           (768a c  - 72a b c  + 10b c)x  + (368a b c  - 220a b c + 30b )x
+--R         + 
+--R                3 2       2 2         4
+--R           (256a c  - 200a b c + 30a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                +------------------+
+--R          3 +-+ |   4      3      2
+--R     1280c \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       4   4         3 3 3        2 5 2       9  4
+--R                 (7680a b c  + 15360a b c  - 6720a b c  + 150b )x
+--R               + 
+--R                        4 2 3        3 4 2         2 6           8  3
+--R                 (92160a b c  - 7680a b c  - 13440a b c + 2400a b )x
+--R               + 
+--R                        5   3          4 3 2         3 5          2 7  2
+--R                 (92160a b c  + 115200a b c  - 74880a b c + 10080a b )x
+--R               + 
+--R                         5 2 2          4 4          3 6            6   2
+--R                 (245760a b c  - 122880a b c + 15360a b )x + 122880a b c
+--R               + 
+--R                         5 3         4 5
+--R                 - 61440a b c + 7680a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                      4 2 4        2 6 2         8       10  5
+--R             (- 19200a b c  + 3360a b c  - 480a b c - 15b  )x
+--R           + 
+--R                      5   4         4 3 3         3 5 2         9  4
+--R             (- 38400a b c  - 76800a b c  + 33600a b c  - 750a b )x
+--R           + 
+--R                       5 2 3         4 4 2         3 6         2 8  3
+--R             (- 230400a b c  + 19200a b c  + 33600a b c - 6000a b )x
+--R           + 
+--R                       6   3          5 3 2          4 5          3 7  2
+--R             (- 153600a b c  - 192000a b c  + 124800a b c - 16800a b )x
+--R           + 
+--R                       6 2 2          5 4          4 6            7   2
+--R             (- 307200a b c  + 153600a b c - 19200a b )x - 122880a b c
+--R           + 
+--R                   6 3         5 5
+--R             61440a b c - 7680a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                      2   6           3 5       5 4  9
+--R             (- 20480a b c  - 10240a b c  - 256b c )x
+--R           + 
+--R                      3 6          2 2 5           4 4       6 3  8
+--R             (- 40960a c  - 130560a b c  - 26880a b c  - 352b c )x
+--R           + 
+--R                       3   5          2 3 4           5 3      7 2  7
+--R             (- 343040a b c  - 264960a b c  - 18752a b c  - 16b c )x
+--R           + 
+--R                       4 5          3 2 4          2 4 3         6 2      8   6
+--R             (- 245760a c  - 840960a b c  - 175680a b c  - 112a b c  + 20b c)x
+--R           + 
+--R                        4   4          3 3 3        2 5 2      9  5
+--R             (- 1082880a b c  - 650240a b c  + 1344a b c  - 30b )x
+--R           + 
+--R                            5 4           4 2 3        3 4 2        2 6
+--R                   - 491520a c  - 1198080a b c  + 6400a b c  + 6400a b c
+--R                 + 
+--R                            8
+--R                   - 1200a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                        5   3         4 3 2         3 5         2 7  3
+--R             (- 1054720a b c  - 79360a b c  + 53120a b c - 7200a b )x
+--R           + 
+--R                       6 3          5 2 2          4 4          3 6  2
+--R             (- 327680a c  - 215040a b c  + 107520a b c - 13440a b )x
+--R           + 
+--R                       6   2         5 3         4 5
+--R             (- 122880a b c  + 61440a b c - 7680a b )x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                   2 7           2 6        4 5  10
+--R             (8192a c  + 20480a b c  + 2560b c )x
+--R           + 
+--R                     2   6           3 5        5 4  9
+--R             (117760a b c  + 89600a b c  + 6080b c )x
+--R           + 
+--R                     3 6          2 2 5            4 4        6 3  8
+--R             (122880a c  + 478720a b c  + 134400a b c  + 3680b c )x
+--R           + 
+--R                     3   5          2 3 4           5 3      7 2  7
+--R             (821760a b c  + 750720a b c  + 68320a b c  - 40b c )x
+--R           + 
+--R                     4 5           3 2 4          2 4 3         6 2       8   6
+--R             (450560a c  + 1713920a b c  + 404160a b c  - 560a b c  + 100b c)x
+--R           + 
+--R                      4   4           3 3 3         2 5 2         7        9  5
+--R             (1758720a b c  + 1154560a b c  - 17984a b c  + 800a b c + 270b )x
+--R           + 
+--R                          5 4           4 2 3         3 4 2         2 6
+--R                   655360a c  + 1761280a b c  - 24320a b c  - 18560a b c
+--R                 + 
+--R                          8
+--R                   3600a b
+--R            *
+--R                4
+--R               x
+--R           + 
+--R                      5   3          4 3 2         3 5          2 7  3
+--R             (1280000a b c  + 140800a b c  - 95360a b c + 12960a b )x
+--R           + 
+--R                     6 3          5 2 2          4 4          3 6  2
+--R             (327680a c  + 276480a b c  - 138240a b c + 17280a b )x
+--R           + 
+--R                     6   2         5 3         4 5
+--R             (122880a b c  - 61440a b c + 7680a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                    2 5            2 4         4 3  4
+--R             (40960a c  + 102400a b c  + 12800b c )x
+--R           + 
+--R                     2   4            3 3  3           3 4          2 2 3  2
+--R             (491520a b c  + 204800a b c )x  + (491520a c  + 860160a b c )x
+--R           + 
+--R                     3   3           4 3
+--R             1310720a b c x + 655360a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                       2   5           3 4        5 3  5
+--R             (- 102400a b c  - 51200a b c  - 1280b c )x
+--R           + 
+--R                       3 5          2 2 4           4 3  4
+--R             (- 204800a c  - 512000a b c  - 64000a b c )x
+--R           + 
+--R                        3   4          2 3 3  3
+--R             (- 1228800a b c  - 512000a b c )x
+--R           + 
+--R                       4 4           3 2 3  2           4   3           5 3
+--R             (- 819200a c  - 1433600a b c )x  - 1638400a b c x - 655360a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                         4   4         3 3 3        2 5 2       9  4
+--R                 (- 7680a b c  - 15360a b c  + 6720a b c  - 150b )x
+--R               + 
+--R                          4 2 3        3 4 2         2 6           8  3
+--R                 (- 92160a b c  + 7680a b c  + 13440a b c - 2400a b )x
+--R               + 
+--R                          5   3          4 3 2         3 5          2 7  2
+--R                 (- 92160a b c  - 115200a b c  + 74880a b c - 10080a b )x
+--R               + 
+--R                           5 2 2          4 4          3 6            6   2
+--R                 (- 245760a b c  + 122880a b c - 15360a b )x - 122880a b c
+--R               + 
+--R                       5 3         4 5
+--R                 61440a b c - 7680a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                    4 2 4        2 6 2         8       10  5
+--R             (19200a b c  - 3360a b c  + 480a b c + 15b  )x
+--R           + 
+--R                    5   4         4 3 3         3 5 2         9  4
+--R             (38400a b c  + 76800a b c  - 33600a b c  + 750a b )x
+--R           + 
+--R                     5 2 3         4 4 2         3 6         2 8  3
+--R             (230400a b c  - 19200a b c  - 33600a b c + 6000a b )x
+--R           + 
+--R                     6   3          5 3 2          4 5          3 7  2
+--R             (153600a b c  + 192000a b c  - 124800a b c + 16800a b )x
+--R           + 
+--R                     6 2 2          5 4          4 6            7   2
+--R             (307200a b c  - 153600a b c + 19200a b )x + 122880a b c
+--R           + 
+--R                     6 3         5 5
+--R             - 61440a b c + 7680a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                      2   6          3 5       5 4  9
+--R             (- 10240a b c  - 5120a b c  - 128b c )x
+--R           + 
+--R                      3 6         2 2 5           4 4       6 3  8
+--R             (- 20480a c  - 65280a b c  - 13440a b c  - 176b c )x
+--R           + 
+--R                       3   5          2 3 4          5 3     7 2  7
+--R             (- 171520a b c  - 132480a b c  - 9376a b c  - 8b c )x
+--R           + 
+--R                       4 5          3 2 4         2 4 3        6 2      8   6
+--R             (- 122880a c  - 420480a b c  - 87840a b c  - 56a b c  + 10b c)x
+--R           + 
+--R                       4   4          3 3 3       2 5 2      9  5
+--R             (- 541440a b c  - 325120a b c  + 672a b c  - 15b )x
+--R           + 
+--R                       5 4          4 2 3        3 4 2        2 6          8  4
+--R             (- 245760a c  - 599040a b c  + 3200a b c  + 3200a b c - 600a b )x
+--R           + 
+--R                       5   3         4 3 2         3 5         2 7  3
+--R             (- 527360a b c  - 39680a b c  + 26560a b c - 3600a b )x
+--R           + 
+--R                       6 3          5 2 2         4 4         3 6  2
+--R             (- 163840a c  - 107520a b c  + 53760a b c - 6720a b )x
+--R           + 
+--R                      6   2         5 3         4 5
+--R             (- 61440a b c  + 30720a b c - 3840a b )x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                   2 7           2 6        4 5  10
+--R             (4096a c  + 10240a b c  + 1280b c )x
+--R           + 
+--R                    2   6           3 5        5 4  9
+--R             (58880a b c  + 44800a b c  + 3040b c )x
+--R           + 
+--R                    3 6          2 2 5           4 4        6 3  8
+--R             (61440a c  + 239360a b c  + 67200a b c  + 1840b c )x
+--R           + 
+--R                     3   5          2 3 4           5 3      7 2  7
+--R             (410880a b c  + 375360a b c  + 34160a b c  - 20b c )x
+--R           + 
+--R                     4 5          3 2 4          2 4 3         6 2      8   6
+--R             (225280a c  + 856960a b c  + 202080a b c  - 280a b c  + 50b c)x
+--R           + 
+--R                     4   4          3 3 3        2 5 2         7        9  5
+--R             (879360a b c  + 577280a b c  - 8992a b c  + 400a b c + 135b )x
+--R           + 
+--R                     5 4          4 2 3         3 4 2        2 6           8  4
+--R             (327680a c  + 880640a b c  - 12160a b c  - 9280a b c + 1800a b )x
+--R           + 
+--R                     5   3         4 3 2         3 5         2 7  3
+--R             (640000a b c  + 70400a b c  - 47680a b c + 6480a b )x
+--R           + 
+--R                     6 3          5 2 2         4 4         3 6  2
+--R             (163840a c  + 138240a b c  - 69120a b c + 8640a b )x
+--R           + 
+--R                    6   2         5 3         4 5
+--R             (61440a b c  - 30720a b c + 3840a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                    2 5           2 4        4 3  4
+--R             (20480a c  + 51200a b c  + 6400b c )x
+--R           + 
+--R                     2   4            3 3  3           3 4          2 2 3  2
+--R             (245760a b c  + 102400a b c )x  + (245760a c  + 430080a b c )x
+--R           + 
+--R                    3   3           4 3
+--R             655360a b c x + 327680a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                      2   5           3 4       5 3  5
+--R             (- 51200a b c  - 25600a b c  - 640b c )x
+--R           + 
+--R                       3 5          2 2 4           4 3  4
+--R             (- 102400a c  - 256000a b c  - 32000a b c )x
+--R           + 
+--R                       3   4          2 3 3  3             4 4          3 2 3  2
+--R             (- 614400a b c  - 256000a b c )x  + (- 409600a c  - 716800a b c )x
+--R           + 
+--R                      4   3           5 3
+--R             - 819200a b c x - 327680a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 255
+
+--S 256 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     4   4         3 3 3        2 5 2       9  4
+--R               (7680a b c  + 15360a b c  - 6720a b c  + 150b )x
+--R             + 
+--R                      4 2 3        3 4 2         2 6           8  3
+--R               (92160a b c  - 7680a b c  - 13440a b c + 2400a b )x
+--R             + 
+--R                      5   3          4 3 2         3 5          2 7  2
+--R               (92160a b c  + 115200a b c  - 74880a b c + 10080a b )x
+--R             + 
+--R                       5 2 2          4 4          3 6            6   2
+--R               (245760a b c  - 122880a b c + 15360a b )x + 122880a b c
+--R             + 
+--R                       5 3         4 5
+--R               - 61440a b c + 7680a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                    4 2 4        2 6 2         8       10  5
+--R           (- 19200a b c  + 3360a b c  - 480a b c - 15b  )x
+--R         + 
+--R                    5   4         4 3 3         3 5 2         9  4
+--R           (- 38400a b c  - 76800a b c  + 33600a b c  - 750a b )x
+--R         + 
+--R                     5 2 3         4 4 2         3 6         2 8  3
+--R           (- 230400a b c  + 19200a b c  + 33600a b c - 6000a b )x
+--R         + 
+--R                     6   3          5 3 2          4 5          3 7  2
+--R           (- 153600a b c  - 192000a b c  + 124800a b c - 16800a b )x
+--R         + 
+--R                     6 2 2          5 4          4 6            7   2
+--R           (- 307200a b c  + 153600a b c - 19200a b )x - 122880a b c
+--R         + 
+--R                 6 3         5 5
+--R           61440a b c - 7680a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                        4 2 4        2 6 2         8       10  6
+--R               (- 19200a b c  + 3360a b c  - 480a b c - 15b  )x
+--R             + 
+--R                        5   4         4 3 3         3 5 2         9  5
+--R               (- 38400a b c  - 76800a b c  + 33600a b c  - 750a b )x
+--R             + 
+--R                         5 2 3         4 4 2         3 6         2 8  4
+--R               (- 230400a b c  + 19200a b c  + 33600a b c - 6000a b )x
+--R             + 
+--R                         6   3          5 3 2          4 5          3 7  3
+--R               (- 153600a b c  - 192000a b c  + 124800a b c - 16800a b )x
+--R             + 
+--R                         6 2 2          5 4          4 6  2
+--R               (- 307200a b c  + 153600a b c - 19200a b )x
+--R             + 
+--R                         7   2         6 3         5 5
+--R               (- 122880a b c  + 61440a b c - 7680a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                     4   5         3 3 4        2 5 3       9   7
+--R               (7680a b c  + 15360a b c  - 6720a b c  + 150b c)x
+--R             + 
+--R                      4 2 4        3 4 3         2 6 2          8        10  6
+--R               (99840a b c  + 7680a b c  - 20160a b c  + 2400a b c + 150b  )x
+--R             + 
+--R                           5   4          4 3 3         3 5 2        2 7
+--R                     99840a b c  + 222720a b c  - 89280a b c  - 3360a b c
+--R                   + 
+--R                            9
+--R                     2550a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                       5 2 3         4 4 2         3 6          2 8  4
+--R               (430080a b c  - 15360a b c  - 72960a b c + 12480a b )x
+--R             + 
+--R                       6   3          5 3 2          4 5          3 7  3
+--R               (215040a b c  + 299520a b c  - 190080a b c + 25440a b )x
+--R             + 
+--R                       6 2 2          5 4          4 6  2
+--R               (368640a b c  - 184320a b c + 23040a b )x
+--R             + 
+--R                       7   2         6 3         5 5
+--R               (122880a b c  - 61440a b c + 7680a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                        2   6           3 5       5 4  9
+--R               (- 20480a b c  - 10240a b c  - 256b c )x
+--R             + 
+--R                        3 6          2 2 5           4 4       6 3  8
+--R               (- 40960a c  - 130560a b c  - 26880a b c  - 352b c )x
+--R             + 
+--R                         3   5          2 3 4           5 3      7 2  7
+--R               (- 343040a b c  - 264960a b c  - 18752a b c  - 16b c )x
+--R             + 
+--R                              4 5          3 2 4          2 4 3         6 2
+--R                     - 245760a c  - 840960a b c  - 175680a b c  - 112a b c
+--R                   + 
+--R                        8
+--R                     20b c
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          4   4          3 3 3        2 5 2      9  5
+--R               (- 1082880a b c  - 650240a b c  + 1344a b c  - 30b )x
+--R             + 
+--R                            5 4           4 2 3        3 4 2        2 6
+--R                   - 491520a c  - 1198080a b c  + 6400a b c  + 6400a b c
+--R                 + 
+--R                            8
+--R                   - 1200a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          5   3         4 3 2         3 5         2 7  3
+--R               (- 1054720a b c  - 79360a b c  + 53120a b c - 7200a b )x
+--R             + 
+--R                         6 3          5 2 2          4 4          3 6  2
+--R               (- 327680a c  - 215040a b c  + 107520a b c - 13440a b )x
+--R             + 
+--R                         6   2         5 3         4 5
+--R               (- 122880a b c  + 61440a b c - 7680a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                     2 7           2 6        4 5  10
+--R               (8192a c  + 20480a b c  + 2560b c )x
+--R             + 
+--R                       2   6           3 5        5 4  9
+--R               (117760a b c  + 89600a b c  + 6080b c )x
+--R             + 
+--R                       3 6          2 2 5            4 4        6 3  8
+--R               (122880a c  + 478720a b c  + 134400a b c  + 3680b c )x
+--R             + 
+--R                       3   5          2 3 4           5 3      7 2  7
+--R               (821760a b c  + 750720a b c  + 68320a b c  - 40b c )x
+--R             + 
+--R                            4 5           3 2 4          2 4 3         6 2
+--R                     450560a c  + 1713920a b c  + 404160a b c  - 560a b c
+--R                   + 
+--R                         8
+--R                     100b c
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             4   4           3 3 3         2 5 2         7
+--R                     1758720a b c  + 1154560a b c  - 17984a b c  + 800a b c
+--R                   + 
+--R                         9
+--R                     270b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                          5 4           4 2 3         3 4 2         2 6
+--R                   655360a c  + 1761280a b c  - 24320a b c  - 18560a b c
+--R                 + 
+--R                          8
+--R                   3600a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        5   3          4 3 2         3 5          2 7  3
+--R               (1280000a b c  + 140800a b c  - 95360a b c + 12960a b )x
+--R             + 
+--R                       6 3          5 2 2          4 4          3 6  2
+--R               (327680a c  + 276480a b c  - 138240a b c + 17280a b )x
+--R             + 
+--R                       6   2         5 3         4 5
+--R               (122880a b c  - 61440a b c + 7680a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                   2 7           2 6        4 5  11
+--R           (- 8192a c  - 20480a b c  - 2560b c )x
+--R         + 
+--R                     2   6           3 5        5 4  10
+--R           (- 117760a b c  - 89600a b c  - 6080b c )x
+--R         + 
+--R                     3 6          2 2 5            4 4        6 3  9
+--R           (- 122880a c  - 478720a b c  - 134400a b c  - 3680b c )x
+--R         + 
+--R                     3   5          2 3 4           5 3      7 2  8
+--R           (- 821760a b c  - 750720a b c  - 68320a b c  + 40b c )x
+--R         + 
+--R                     4 5           3 2 4          2 4 3         6 2       8   7
+--R           (- 450560a c  - 1713920a b c  - 404160a b c  + 560a b c  - 100b c)x
+--R         + 
+--R                      4   4           3 3 3         2 5 2          7        9  6
+--R           (- 1779200a b c  - 1148800a b c  + 23328a b c  - 1800a b c - 300b )x
+--R         + 
+--R                          5 4           4 2 3         3 4 2         2 6
+--R                 - 696320a c  - 1831680a b c  + 86720a b c  + 16560a b c
+--R               + 
+--R                          8
+--R                 - 5100a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                      5   3         4 3 2          3 5          2 7  4
+--R           (- 1525760a b c  - 51200a b c  + 146560a b c - 24960a b )x
+--R         + 
+--R                     6 3          5 2 2          4 4          3 6  3
+--R           (- 491520a c  - 435200a b c  + 343040a b c - 50880a b )x
+--R         + 
+--R                     6   2          5 3          4 5  2
+--R           (- 450560a b c  + 317440a b c - 46080a b )x
+--R         + 
+--R                     7 2          6 2          5 4
+--R           (- 131072a c  + 102400a b c - 15360a b )x
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                  2   7           3 6       5 5  12
+--R           (20480a b c  + 10240a b c  + 256b c )x
+--R         + 
+--R                  3 7          2 2 6           4 5       6 4  11
+--R           (40960a c  + 151040a b c  + 37120a b c  + 608b c )x
+--R         + 
+--R                   3   6          2 3 5           5 4       7 3  10
+--R           (404480a b c  + 405760a b c  + 45888a b c  + 368b c )x
+--R         + 
+--R                   4 6           3 2 5          2 4 4           6 3     8 2  9
+--R           (286720a c  + 1314560a b c  + 467520a b c  + 19216a b c  - 4b c )x
+--R         + 
+--R                    4   5           3 3 4          2 5 3         7 2      9   8
+--R           (1671680a b c  + 1756160a b c  + 193088a b c  + 128a b c  + 10b c)x
+--R         + 
+--R                      5 5           4 2 4          3 4 3        2 6 2
+--R               745472a c  + 3136000a b c  + 807040a b c  - 7232a b c
+--R             + 
+--R                      8       10
+--R               1480a b c + 30b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                         5   4           4 3 3         3 5 2        2 7
+--R                 2735616a b c  + 1905920a b c  - 93824a b c  + 6000a b c
+--R               + 
+--R                        9
+--R                 1530a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        6 4           5 2 3          4 4 2         3 6
+--R                 925696a c  + 2675456a b c  - 205760a b c  - 46000a b c
+--R               + 
+--R                       2 8
+--R                 13500a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    6   3         5 3 2          4 5          3 7  4
+--R           (1964032a b c  + 87552a b c  - 265600a b c + 45600a b )x
+--R         + 
+--R                   7 3          6 2 2          5 4          4 6  3
+--R           (557056a c  + 592896a b c  - 481280a b c + 72000a b )x
+--R         + 
+--R                   7   2          6 3          5 5  2
+--R           (516096a b c  - 368640a b c + 53760a b )x
+--R         + 
+--R                   8 2          7 2          6 4
+--R           (131072a c  - 102400a b c + 15360a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                    2 5            2 4         4 3  4
+--R             (40960a c  + 102400a b c  + 12800b c )x
+--R           + 
+--R                     2   4            3 3  3           3 4          2 2 3  2
+--R             (491520a b c  + 204800a b c )x  + (491520a c  + 860160a b c )x
+--R           + 
+--R                     3   3           4 3
+--R             1310720a b c x + 655360a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                       2   5           3 4        5 3  5
+--R             (- 102400a b c  - 51200a b c  - 1280b c )x
+--R           + 
+--R                       3 5          2 2 4           4 3  4
+--R             (- 204800a c  - 512000a b c  - 64000a b c )x
+--R           + 
+--R                        3   4          2 3 3  3
+--R             (- 1228800a b c  - 512000a b c )x
+--R           + 
+--R                       4 4           3 2 3  2           4   3           5 3
+--R             (- 819200a c  - 1433600a b c )x  - 1638400a b c x - 655360a c
+--R        *
+--R            +-+
+--R           \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                              6 8          5 2 7          4 4 6          3 6 5
+--R                       - 8192a c  - 135168a b c  - 253440a b c  - 118272a b c
+--R                     + 
+--R                               2 8 4         10 3     12 2
+--R                       - 15840a b c  - 528a b  c  - 2b  c
+--R                  *
+--R                      17
+--R                     x
+--R                 + 
+--R                                6   7           5 3 6           4 5 5
+--R                       - 651264a b c  - 3131392a b c  - 3015936a b c
+--R                     + 
+--R                                3 7 4         2 9 3          11 2     13
+--R                       - 836352a b c  - 69520a b c  - 1416a b  c  - 3b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                7 7            6 2 6            5 4 5
+--R                       - 704512a c  - 12439552a b c  - 25580544a b c
+--R                     + 
+--R                                  4 6 4           3 8 3          2 10 2
+--R                       - 13643520a b c  - 2257728a b c  - 111408a b  c
+--R                     + 
+--R                                12     14
+--R                       - 1228a b  c - b
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                                  7   6            6 3 5             5 5 4
+--R                       - 19574784a b c  - 98523136a b c  - 100945152a b c
+--R                     + 
+--R                                4 7 3           3 9 2         2 11          13
+--R                     - 30590208a b c  - 2922832a b c  - 77016a b  c - 339a b
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                  8 6             7 2 5             6 4 4
+--R                       - 10559488a c  - 189026304a b c  - 395066880a b c
+--R                     + 
+--R                                   5 6 3            4 8 2           3 10
+--R                       - 214742528a b c  - 36283104a b c  - 1818960a b  c
+--R                     + 
+--R                               2 12
+--R                       - 19266a b
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                   8   5             7 3 4             6 5 3
+--R                       - 175816704a b c  - 871485440a b c  - 870152192a b c
+--R                     + 
+--R                                   5 7 2            4 9           3 11
+--R                       - 251496960a b c  - 21754304a b c - 435344a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                  9 5              8 2 4              7 4 3
+--R                       - 63078400a c  - 1086726144a b c  - 2145669120a b c
+--R                     + 
+--R                                    6 6 2             5 8            4 10
+--R                       - 1064440832a b c  - 152270976a b c - 5175456a b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                   9   4              8 3 3              7 5 2
+--R                       - 713687040a b c  - 3266707456a b c  - 2886844416a b c
+--R                     + 
+--R                                   6 7             5 9
+--R                       - 676356096a b c - 37120512a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                   10 4              9 2 3              8 4 2
+--R                       - 191627264a  c  - 2996043776a b c  - 5118787584a b c
+--R                     + 
+--R                                    7 6              6 8
+--R                       - 1996767232a b c - 173575168a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                    10   3              9 3 2              8 5
+--R                       - 1516240896a  b c  - 5902696448a b c  - 4010803200a b c
+--R                     + 
+--R                                   7 7
+--R                       - 553992192a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                   11 3              10 2 2              9 4
+--R                       - 325058560a  c  - 4264034304a  b c  - 5506203648a b c
+--R                     + 
+--R                                    8 6
+--R                       - 1238335488a b
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                 11   2              10 3               9 5  6
+--R                   (- 1752170496a  b c  - 5086117888a  b c - 1958674432a b )x
+--R                 + 
+--R                                12 2              11 2               10 4  5
+--R                   (- 312475648a  c  - 3023044608a  b c - 2182742016a  b )x
+--R                 + 
+--R                                 12                 11 3  4
+--R                   (- 1044381696a  b c - 1676673024a  b )x
+--R                 + 
+--R                                13              12 2  3             13   2
+--R                   (- 159383552a  c - 845152256a  b )x  - 251658240a  b x
+--R                 + 
+--R                              14
+--R                   - 33554432a  x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                               5   8          4 3 7          3 5 6         2 7 5
+--R                       - 49152a b c  - 225280a b c  - 202752a b c  - 50688a b c
+--R                     + 
+--R                                9 4      11 3
+--R                       - 3520a b c  - 48b  c
+--R                  *
+--R                      17
+--R                     x
+--R                 + 
+--R                                6 8           5 2 7           4 4 6
+--R                       - 106496a c  - 1830912a b c  - 3632640a b c
+--R                     + 
+--R                                 3 6 5          2 8 4           10 3      12 2
+--R                       - 1841664a b c  - 281952a b c  - 12144a b  c  - 98b  c
+--R                  *
+--R                      16
+--R                     x
+--R                 + 
+--R                                 6   7            5 3 6            4 5 5
+--R                       - 4333568a b c  - 21442560a b c  - 21474816a b c
+--R                     + 
+--R                                 3 7 4          2 9 3           11 2      13
+--R                       - 6302208a b c  - 573408a b c  - 13872a b  c  - 50b  c
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                                 7 7            6 2 6             5 4 5
+--R                       - 3088384a c  - 54988800a b c  - 114163200a b c
+--R                     + 
+--R                                  4 6 4            3 8 3          2 10 2
+--R                       - 61529600a b c  - 10280160a b c  - 507408a b  c
+--R                     + 
+--R                                12
+--R                       - 5250a b  c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                  7   6             6 3 5             5 5 4
+--R                       - 63356928a b c  - 315043840a b c  - 316053504a b c
+--R                     + 
+--R                                  4 7 3           3 9 2          2 11
+--R                       - 92032512a b c  - 8062912a b c  - 165360a b  c
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                  8 6             7 2 5             6 4 4
+--R                       - 26836992a c  - 466722816a b c  - 933130240a b c
+--R                     + 
+--R                                   5 6 3            4 8 2           3 10
+--R                       - 471045120a b c  - 69134208a b c  - 2448160a b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                   8   5              7 3 4              6 5 3
+--R                       - 351633408a b c  - 1637515264a b c  - 1480593408a b c
+--R                     + 
+--R                                   5 7 2            4 9
+--R                       - 358066176a b c  - 20592000a b c
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                   9 5              8 2 4              7 4 3
+--R                       - 105644032a c  - 1685323776a b c  - 2954919936a b c
+--R                     + 
+--R                                    6 6 2             5 8
+--R                       - 1193099264a b c  - 108825600a b c
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                   9   4              8 3 3              7 5 2
+--R                       - 938475520a b c  - 3755212800a b c  - 2643787776a b c
+--R                     + 
+--R                                   6 7
+--R                       - 382976000a b c
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                   10 4              9 2 3              8 4 2
+--R                       - 218103808a  c  - 2942828544a b c  - 3937665024a b c
+--R                     + 
+--R                                   7 6
+--R                       - 927498240a b c
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                 10   3              9 3 2              8 5   7
+--R                   (- 1296039936a  b c  - 3896508416a b c  - 1568931840a b c)x
+--R                 + 
+--R                                11 3              10 2 2              9 4   6
+--R                   (- 245366784a  c  - 2456813568a  b c  - 1851392000a b c)x
+--R                 + 
+--R                                11   2              10 3   5
+--R                   (- 893386752a  b c  - 1494220800a  b c)x
+--R                 + 
+--R                                12 2             11 2   4             12     3
+--R                   (- 142606336a  c  - 786432000a  b c)x  - 243269632a  b c x
+--R                 + 
+--R                              13   2
+--R                   - 33554432a  c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                         5   8          4 3 7          3 5 6         2 7 5
+--R                   49152a b c  + 225280a b c  + 202752a b c  + 50688a b c
+--R                 + 
+--R                          9 4      11 3
+--R                   3520a b c  + 48b  c
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                          6 8           5 2 7           4 4 6           3 6 5
+--R                   106496a c  + 1855488a b c  + 3745280a b c  + 1943040a b c
+--R                 + 
+--R                          2 8 4           10 3       12 2
+--R                   307296a b c  + 13904a b  c  + 122b  c
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                           6   7            5 3 6            4 5 5
+--R                   4440064a b c  + 22650880a b c  + 23620608a b c
+--R                 + 
+--R                           3 7 4          2 9 3           11 2       13
+--R                   7332864a b c  + 725824a b c  + 20256a b  c  + 100b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                           7 7            6 2 6             5 4 5
+--R                   3194880a c  + 59285504a b c  + 129936384a b c
+--R                 + 
+--R                            4 6 4            3 8 3          2 10 2           12
+--R                   75451904a b c  + 14076480a b c  + 835296a b  c  + 12836a b  c
+--R                 + 
+--R                      14
+--R                   26b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                            7   6             6 3 5             5 5 4
+--R                   69533696a b c  + 369135616a b c  + 404874240a b c
+--R                 + 
+--R                             4 7 3            3 9 2          2 11           13
+--R                   134328832a b c  + 14582656a b c  + 468048a b  c + 2964a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                            8 6             7 2 5              6 4 4
+--R                   29925376a c  + 560861184a b c  + 1240778240a b c
+--R                 + 
+--R                           5 6 3             4 8 2           3 10           2 12
+--R                 725204480a b c  + 134959968a b c  + 7758608a b  c + 101946a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                             8   5              7 3 4              6 5 3
+--R                   432144384a b c  + 2249203712a b c  + 2385682432a b c
+--R                 + 
+--R                             5 7 2            4 9            3 11
+--R                   744926208a b c  + 71458816a b c + 1659424a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             9 5              8 2 4              7 4 3
+--R                   132481024a c  + 2382225408a b c  + 4953387008a b c
+--R                 + 
+--R                              6 6 2             5 8             4 10
+--R                   2620255232a b c  + 407072640a b c + 15471456a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                              9   4              8 3 3              7 5 2
+--R                   1361051648a b c  + 6518210560a b c  + 6084820992a b c
+--R                 + 
+--R                              6 7             5 9
+--R                   1526382592a b c + 91533312a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             10 4              9 2 3              8 4 2
+--R                   323747840a  c  + 5269356544a b c  + 9443377152a b c
+--R                 + 
+--R                              7 6              6 8
+--R                   3904126976a b c + 365063168a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                              10   3              9 3 2              8 5
+--R                   2386558976a  b c  + 9692512256a b c  + 6926893056a b c
+--R                 + 
+--R                              7 7
+--R                   1017741312a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             11 3              10 2 2              9 4
+--R                   463470592a  c  + 6315048960a  b c  + 8526364672a b c
+--R                 + 
+--R                              8 6
+--R                   2022801408a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                           11   2              10 3               9 5  6
+--R               (2365587456a  b c  + 7146045440a  b c + 2884370432a b )x
+--R             + 
+--R                          12 2              11 2               10 4  5
+--R               (387973120a  c  + 3891265536a  b c + 2929852416a  b )x
+--R             + 
+--R                           12                 11 3  4
+--R               (1241513984a  b c + 2069889024a  b )x
+--R             + 
+--R                          13              12 2  3             13   2
+--R               (176160768a  c + 966787072a  b )x  + 268435456a  b x
+--R             + 
+--R                        14
+--R               33554432a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                    6 9          5 2 8          4 4 7          3 6 6
+--R               8192a c  + 135168a b c  + 253440a b c  + 118272a b c
+--R             + 
+--R                     2 8 5         10 4     12 3
+--R               15840a b c  + 528a b  c  + 2b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                      6   8           5 3 7           4 5 6          3 7 5
+--R               655360a b c  + 3198976a b c  + 3142656a b c  + 895488a b c
+--R             + 
+--R                     2 9 4          11 3     13 2
+--R               77440a b c  + 1680a b  c  + 4b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                      7 8            6 2 7            5 4 6            4 6 5
+--R               704512a c  + 12738560a b c  + 26999808a b c  + 14986752a b c
+--R             + 
+--R                       3 8 4          2 10 3          12 2     14
+--R               2620992a b c  + 140448a b  c  + 1780a b  c  + 2b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                        7   7             6 3 6             5 5 5
+--R               19873792a b c  + 103677952a b c  + 111209472a b c
+--R             + 
+--R                        4 7 4           3 9 3          2 11 2         13
+--R               35819520a b c  + 3729088a b c  + 112128a b  c  + 628a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        8 7             7 2 6             6 4 5
+--R               10559488a c  + 196497408a b c  + 431029760a b c
+--R             + 
+--R                         5 6 4            4 8 3           3 10 2         2 12
+--R               249345536a b c  + 45812448a b c  + 2590544a b  c  + 33282a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                         8   6             7 3 5             6 5 4
+--R               179552256a b c  + 934768640a b c  + 992622592a b c
+--R             + 
+--R                         5 7 3            4 9 2          3 11
+--R               310801920a b c  + 29991104a b c  + 705328a b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                        9 6              8 2 5              7 4 4
+--R               63078400a c  + 1141088256a b c  + 2392248320a b c
+--R             + 
+--R                          6 6 3             5 8 2           4 10
+--R               1280254976a b c  + 202350720a b c  + 7902752a b  c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         9   5              8 3 4              7 5 3
+--R               731807744a b c  + 3549528064a b c  + 3369824256a b c
+--R             + 
+--R                         6 7 2            5 9
+--R               865146880a b c  + 53649024a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         10 5              9 2 4              8 4 3
+--R               191627264a  c  + 3168010240a b c  + 5791973376a b c
+--R             + 
+--R                          7 6 2             6 8
+--R               2458402816a b c  + 238324736a b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          10   4              9 3 3              8 5 2
+--R               1559232512a  b c  + 6472073216a b c  + 4756144128a b c
+--R             + 
+--R                         7 7
+--R               725008384a b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                         11 4              10 2 3              9 4 2
+--R               325058560a  c  + 4531421184a  b c  + 6295257088a b c
+--R             + 
+--R                          8 6
+--R               1549172736a b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                       11   3              10 3 2              9 5   7
+--R           (1805647872a  b c  + 5613027328a  b c  + 2348417024a b c)x
+--R         + 
+--R                      12 3              11 2 2              10 4   6
+--R           (312475648a  c  + 3224371200a  b c  + 2514092032a  b c)x
+--R         + 
+--R                       12   2              11 3   5
+--R           (1077936128a  b c  + 1859125248a  b c)x
+--R         + 
+--R                      13 2             12 2   4             13     3
+--R           (159383552a  c  + 903872512a  b c)x  + 260046848a  b c x
+--R         + 
+--R                    14   2
+--R           33554432a  c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                           5   8          4 3 7          3 5 6         2 7 5
+--R                   - 49152a b c  - 225280a b c  - 202752a b c  - 50688a b c
+--R                 + 
+--R                            9 4      11 3
+--R                   - 3520a b c  - 48b  c
+--R              *
+--R                  19
+--R                 x
+--R             + 
+--R                            6 8           5 2 7           4 4 6           3 6 5
+--R                   - 106496a c  - 1855488a b c  - 3745280a b c  - 1943040a b c
+--R                 + 
+--R                            2 8 4           10 3       12 2
+--R                   - 307296a b c  - 13904a b  c  - 122b  c
+--R              *
+--R                  18
+--R                 x
+--R             + 
+--R                             6   7            5 3 6            4 5 5
+--R                   - 4440064a b c  - 22650880a b c  - 23620608a b c
+--R                 + 
+--R                             3 7 4          2 9 3           11 2       13
+--R                   - 7332864a b c  - 725824a b c  - 20256a b  c  - 100b  c
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                             7 7            6 2 6             5 4 5
+--R                   - 3194880a c  - 59285504a b c  - 129936384a b c
+--R                 + 
+--R                              4 6 4            3 8 3          2 10 2
+--R                   - 75451904a b c  - 14076480a b c  - 835296a b  c
+--R                 + 
+--R                             12       14
+--R                   - 12836a b  c - 26b
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                              7   6             6 3 5             5 5 4
+--R                   - 69533696a b c  - 369135616a b c  - 404874240a b c
+--R                 + 
+--R                             4 7 3            3 9 2          2 11           13
+--R                 - 134328832a b c  - 14582656a b c  - 468048a b  c - 2964a b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                              8 6             7 2 5              6 4 4
+--R                   - 29925376a c  - 560861184a b c  - 1240778240a b c
+--R                 + 
+--R                               5 6 3             4 8 2           3 10
+--R                   - 725204480a b c  - 134959968a b c  - 7758608a b  c
+--R                 + 
+--R                            2 12
+--R                   - 101946a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                               8   5              7 3 4              6 5 3
+--R                   - 432144384a b c  - 2249203712a b c  - 2385682432a b c
+--R                 + 
+--R                               5 7 2            4 9            3 11
+--R                   - 744926208a b c  - 71458816a b c - 1659424a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                               9 5              8 2 4              7 4 3
+--R                   - 132481024a c  - 2382225408a b c  - 4953387008a b c
+--R                 + 
+--R                                6 6 2             5 8             4 10
+--R                   - 2620255232a b c  - 407072640a b c - 15471456a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                                9   4              8 3 3              7 5 2
+--R                   - 1361051648a b c  - 6518210560a b c  - 6084820992a b c
+--R                 + 
+--R                                6 7             5 9
+--R                   - 1526382592a b c - 91533312a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                               10 4              9 2 3              8 4 2
+--R                   - 323747840a  c  - 5269356544a b c  - 9443377152a b c
+--R                 + 
+--R                                7 6              6 8
+--R                   - 3904126976a b c - 365063168a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                                10   3              9 3 2              8 5
+--R                   - 2386558976a  b c  - 9692512256a b c  - 6926893056a b c
+--R                 + 
+--R                                7 7
+--R                   - 1017741312a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                               11 3              10 2 2              9 4
+--R                   - 463470592a  c  - 6315048960a  b c  - 8526364672a b c
+--R                 + 
+--R                                8 6
+--R                   - 2022801408a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             11   2              10 3               9 5  7
+--R               (- 2365587456a  b c  - 7146045440a  b c - 2884370432a b )x
+--R             + 
+--R                            12 2              11 2               10 4  6
+--R               (- 387973120a  c  - 3891265536a  b c - 2929852416a  b )x
+--R             + 
+--R                             12                 11 3  5
+--R               (- 1241513984a  b c - 2069889024a  b )x
+--R             + 
+--R                            13              12 2  4             13   3
+--R               (- 176160768a  c - 966787072a  b )x  - 268435456a  b x
+--R             + 
+--R                          14 2
+--R               - 33554432a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                      6 9          5 2 8          4 4 7          3 6 6
+--R               - 8192a c  - 135168a b c  - 253440a b c  - 118272a b c
+--R             + 
+--R                       2 8 5         10 4     12 3
+--R               - 15840a b c  - 528a b  c  - 2b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                        6   8           5 3 7           4 5 6          3 7 5
+--R               - 655360a b c  - 3198976a b c  - 3142656a b c  - 895488a b c
+--R             + 
+--R                       2 9 4          11 3     13 2
+--R               - 77440a b c  - 1680a b  c  - 4b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                        7 8            6 2 7            5 4 6            4 6 5
+--R               - 704512a c  - 12738560a b c  - 26999808a b c  - 14986752a b c
+--R             + 
+--R                         3 8 4          2 10 3          12 2     14
+--R               - 2620992a b c  - 140448a b  c  - 1780a b  c  - 2b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                          7   7             6 3 6             5 5 5
+--R               - 19873792a b c  - 103677952a b c  - 111209472a b c
+--R             + 
+--R                          4 7 4           3 9 3          2 11 2         13
+--R               - 35819520a b c  - 3729088a b c  - 112128a b  c  - 628a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                          8 7             7 2 6             6 4 5
+--R               - 10559488a c  - 196497408a b c  - 431029760a b c
+--R             + 
+--R                         5 6 4            4 8 3           3 10 2         2 12
+--R             - 249345536a b c  - 45812448a b c  - 2590544a b  c  - 33282a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                           8   6             7 3 5             6 5 4
+--R               - 179552256a b c  - 934768640a b c  - 992622592a b c
+--R             + 
+--R                           5 7 3            4 9 2          3 11
+--R               - 310801920a b c  - 29991104a b c  - 705328a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                          9 6              8 2 5              7 4 4
+--R               - 63078400a c  - 1141088256a b c  - 2392248320a b c
+--R             + 
+--R                            6 6 3             5 8 2           4 10
+--R               - 1280254976a b c  - 202350720a b c  - 7902752a b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                           9   5              8 3 4              7 5 3
+--R               - 731807744a b c  - 3549528064a b c  - 3369824256a b c
+--R             + 
+--R                           6 7 2            5 9
+--R               - 865146880a b c  - 53649024a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                           10 5              9 2 4              8 4 3
+--R               - 191627264a  c  - 3168010240a b c  - 5791973376a b c
+--R             + 
+--R                            7 6 2             6 8
+--R               - 2458402816a b c  - 238324736a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                            10   4              9 3 3              8 5 2
+--R               - 1559232512a  b c  - 6472073216a b c  - 4756144128a b c
+--R             + 
+--R                           7 7
+--R               - 725008384a b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                           11 4              10 2 3              9 4 2
+--R               - 325058560a  c  - 4531421184a  b c  - 6295257088a b c
+--R             + 
+--R                            8 6
+--R               - 1549172736a b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                         11   3              10 3 2              9 5   8
+--R           (- 1805647872a  b c  - 5613027328a  b c  - 2348417024a b c)x
+--R         + 
+--R                        12 3              11 2 2              10 4   7
+--R           (- 312475648a  c  - 3224371200a  b c  - 2514092032a  b c)x
+--R         + 
+--R                         12   2              11 3   6
+--R           (- 1077936128a  b c  - 1859125248a  b c)x
+--R         + 
+--R                        13 2             12 2   5             13     4
+--R           (- 159383552a  c  - 903872512a  b c)x  - 260046848a  b c x
+--R         + 
+--R                      14   3
+--R           - 33554432a  c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                    6 9          5 2 8          4 4 7          3 6 6
+--R               8192a c  + 135168a b c  + 253440a b c  + 118272a b c
+--R             + 
+--R                     2 8 5         10 4     12 3
+--R               15840a b c  + 528a b  c  + 2b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                      6   8           5 3 7           4 5 6          3 7 5
+--R               659456a b c  + 3266560a b c  + 3269376a b c  + 954624a b c
+--R             + 
+--R                     2 9 4          11 3     13 2
+--R               85360a b c  + 1944a b  c  + 5b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                      7 8            6 2 7            5 4 6            4 6 5
+--R               712704a c  + 13225984a b c  + 28965376a b c  + 16777728a b c
+--R             + 
+--R                       3 8 4          2 10 3          12 2     14
+--R               3109920a b c  + 181456a b  c  + 2646a b  c  + 4b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                        7   7             6 3 6             5 5 5
+--R               20930560a b c  + 114094080a b c  + 129541632a b c
+--R             + 
+--R                      4 7 4           3 9 3          2 11 2          13     15
+--R             45070080a b c  + 5250080a b c  + 189840a b  c  + 1570a b  c + b
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                        8 7             7 2 6             6 4 5
+--R               11264000a c  + 221040640a b c  + 519170560a b c
+--R             + 
+--R                         5 6 4            4 8 3           3 10 2         2 12
+--R               329331200a b c  + 69131040a b c  + 4853200a b  c  + 97510a b  c
+--R             + 
+--R                     14
+--R               340a b
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                         8   6              7 3 5              6 5 4
+--R               205950976a b c  + 1159034880a b c  + 1366164224a b c
+--R             + 
+--R                         5 7 3            4 9 2           3 11          2 13
+--R               496829696a b c  + 60960240a b c  + 2331320a b  c + 19605a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        9 6              8 2 5              7 4 4
+--R               73637888a c  + 1451569152a b c  + 3412221440a b c
+--R             + 
+--R                        6 6 3             5 8 2            4 10           3 12
+--R             2149335552a b c  + 440051040a b c  + 28748720a b  c + 454610a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                         9   5              8 3 4              7 5 3
+--R               952582144a b c  + 5224919040a b c  + 5902665728a b c
+--R             + 
+--R                          6 7 2             5 9            4 11
+--R               1992293888a b c  + 211145792a b c + 5610800a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         10 5              9 2 4               8 4 3
+--R               254705664a  c  + 4796456960a b c  + 10531164160a b c
+--R             + 
+--R                          7 6 2              6 8             5 10
+--R               5948052480a b c  + 1002202240a b c + 42295968a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          10   4               9 3 3               8 5 2
+--R               2421555200a  b c  + 12165447680a b c  + 12016435200a b c
+--R             + 
+--R                          7 7              6 9
+--R               3227115520a b c + 210695680a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         11 4              10 2 3               9 4 2
+--R               516685824a  c  + 8776318976a  b c  + 16527687680a b c
+--R             + 
+--R                          8 6              7 8
+--R               7245905920a b c + 727567360a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          11   3               10 3 2               9 5
+--R               3593469952a  b c  + 15252848640a  b c  + 11475681280a b c
+--R             + 
+--R                          8 7
+--R               1792327680a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                         12 3              11 2 2               10 4
+--R               637534208a  c  + 9039249408a  b c  + 12775063552a  b c
+--R             + 
+--R                          9 6
+--R               3197009920a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                       12   2              11 3               10 5  7
+--R           (3109027840a  b c  + 9785835520a  b c + 4141416448a  b )x
+--R         + 
+--R                      13 2              12 2               11 4  6
+--R           (471859200a  c  + 4912578560a  b c + 3859415040a  b )x
+--R         + 
+--R                       13                 12 3  5
+--R           (1455423488a  b c + 2521825280a  b )x
+--R         + 
+--R                    14               13 2  4             14   3            15 2
+--R         (192937984a  c + 1096810496a  b )x  + 285212672a  b x  + 33554432a  x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                     5   9          4 3 8          3 5 7         2 7 6
+--R               49152a b c  + 225280a b c  + 202752a b c  + 50688a b c
+--R             + 
+--R                      9 5      11 4
+--R               3520a b c  + 48b  c
+--R          *
+--R              20
+--R             x
+--R         + 
+--R                      6 9           5 2 8           4 4 7           3 6 6
+--R               106496a c  + 1880064a b c  + 3857920a b c  + 2044416a b c
+--R             + 
+--R                      2 8 5           10 4       12 3
+--R               332640a b c  + 15664a b  c  + 146b  c
+--R          *
+--R              19
+--R             x
+--R         + 
+--R                       6   8            5 3 7            4 5 6           3 7 5
+--R               4489216a b c  + 23498752a b c  + 25310208a b c  + 8194560a b c
+--R             + 
+--R                      2 9 4           11 3       13 2
+--R               858880a b c  + 26064a b  c  + 148b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                       7 8            6 2 7             5 4 6            4 6 5
+--R               3194880a c  + 61153280a b c  + 139238400a b c  + 84846080a b c
+--R             + 
+--R                        3 8 4           2 10 3           12 2      14
+--R               16864320a b c  + 1092960a b  c  + 19220a b  c  + 50b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                        7   7             6 3 6             5 5 5
+--R               70778880a b c  + 391475200a b c  + 451691520a b c
+--R             + 
+--R                         4 7 4            3 9 3          2 11 2          13
+--R               159864320a b c  + 18916480a b c  + 686640a b  c  + 5300a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                        8 7             7 2 6              6 4 5
+--R               29925376a c  + 585068544a b c  + 1362337280a b c
+--R             + 
+--R                       5 6 4             4 8 3            3 10 2          2 12
+--R             848628224a b c  + 171446880a b c  + 11018480a b  c  + 170610a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                         8   6              7 3 5              6 5 4
+--R               441827328a b c  + 2419281920a b c  + 2729777152a b c
+--R             + 
+--R                         5 7 3            4 9 2           3 11
+--R               921143808a b c  + 97789120a b c  + 2613520a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                         9 6              8 2 5              7 4 4
+--R               132481024a c  + 2503680000a b c  + 5525565440a b c
+--R             + 
+--R                          6 6 3             5 8 2            4 10
+--R               3144737792a b c  + 536025984a b c  + 23040160a b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                          9   5              8 3 4              7 5 3
+--R               1395752960a b c  + 7078051840a b c  + 7079301120a b c
+--R             + 
+--R                          6 7 2             5 9
+--R               1934141440a b c  + 129417600a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         10 5              9 2 4               8 4 3
+--R               323747840a  c  + 5566627840a b c  + 10647797760a b c
+--R             + 
+--R                          7 6 2             6 8
+--R               4764385280a b c  + 491801600a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          10   4               9 3 3              8 5 2
+--R               2452619264a  b c  + 10594549760a b c  + 8150384640a b c
+--R             + 
+--R                          7 7
+--R               1310474240a b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         11 4              10 2 3              9 4 2
+--R               463470592a  c  + 6695682048a  b c  + 9685565440a b c
+--R             + 
+--R                          8 6
+--R               2496430080a b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                       11   3              10 3 2              9 5   8
+--R           (2434793472a  b c  + 7847542784a  b c  + 3420323840a b c)x
+--R         + 
+--R                      12 3              11 2 2              10 4   7
+--R           (387973120a  c  + 4136632320a  b c  + 3345612800a  b c)x
+--R         + 
+--R                       12   2              11 3   6
+--R           (1279262720a  b c  + 2280652800a  b c)x
+--R         + 
+--R                      13 2              12 2   5             13     4
+--R           (176160768a  c  + 1029701632a  b c)x  + 276824064a  b c x
+--R         + 
+--R                    14   3
+--R           33554432a  c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                           5   6          4 3 5          3 5 4         2 7 3
+--R                     49152a b c  + 225280a b c  + 202752a b c  + 50688a b c
+--R                   + 
+--R                            9 2      11
+--R                     3520a b c  + 48b  c
+--R                *
+--R                    13
+--R                   x
+--R               + 
+--R                            6 6           5 2 5           4 4 4           3 6 3
+--R                     106496a c  + 1757184a b c  + 3294720a b c  + 1537536a b c
+--R                   + 
+--R                            2 8 2          10       12
+--R                     205920a b c  + 6864a b  c + 26b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                             6   5            5 3 4            4 5 3
+--R                     4128768a b c  + 18636800a b c  + 16400384a b c
+--R                   + 
+--R                             3 7 2          2 9           11
+--R                     3953664a b c  + 256256a b c + 2912a b
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                             7 5            6 2 4            5 4 3
+--R                     2981888a c  + 47308800a b c  + 83865600a b c
+--R                   + 
+--R                              4 6 2           3 8          2 10
+--R                     35875840a b c  + 4118400a b c + 96096a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              7   4             6 3 3             5 5 2
+--R                     55050240a b c  + 229376000a b c  + 178913280a b c
+--R                   + 
+--R                              4 7            3 9
+--R                     35143680a b c + 1464320a b
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                              8 4             7 2 3             6 4 2
+--R                     23855104a c  + 343146496a b c  + 526417920a b c
+--R                   + 
+--R                               5 6             4 8
+--R                     177422336a b c + 12446720a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                               8   3             7 3 2             6 5
+--R                     264241152a b c  + 935854080a b c  + 561512448a b c
+--R                   + 
+--R                              5 7
+--R                     65175552a b
+--R                *
+--R                    7
+--R                   x
+--R               + 
+--R                              9 3             8 2 2              7 4
+--R                     81788928a c  + 986185728a b c  + 1143078912a b c
+--R                   + 
+--R                               6 6
+--R                     222265344a b
+--R                *
+--R                    6
+--R                   x
+--R               + 
+--R                            9   2              8 3              7 5  5
+--R                 (566231040a b c  + 1494220800a b c + 508035072a b )x
+--R               + 
+--R                            10 2              9 2              8 4  4
+--R                 (136314880a  c  + 1211105280a b c + 784465920a b )x
+--R               + 
+--R                            10                9 3  3
+--R                 (553648128a  b c + 807403520a b )x
+--R               + 
+--R                            11              10 2  2             11
+--R                 (109051904a  c + 530579456a  b )x  + 201326592a  b x
+--R               + 
+--R                          12
+--R                 33554432a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                      6 7          5 2 6          4 4 5          3 6 4
+--R                 8192a c  + 135168a b c  + 253440a b c  + 118272a b c
+--R               + 
+--R                       2 8 3         10 2     12
+--R                 15840a b c  + 528a b  c  + 2b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                        6   6           5 3 5           4 5 4          3 7 3
+--R                 638976a b c  + 2928640a b c  + 2635776a b c  + 658944a b c
+--R               + 
+--R                       2 9 2         11
+--R                 45760a b c  + 624a b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                        7 6            6 2 5            5 4 4           4 6 3
+--R                 688128a c  + 11182080a b c  + 20500480a b c  + 9225216a b c
+--R               + 
+--R                         3 8 2         2 10
+--R                 1153152a b c  + 32032a b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                          7   5            6 3 4            5 5 3
+--R                 17203200a b c  + 74547200a b c  + 61501440a b c
+--R               + 
+--R                          4 7 2          3 9
+--R                 13178880a b c  + 640640a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                         8 5             7 2 4             6 4 3
+--R                 9175040a c  + 137625600a b c  + 223641600a b c
+--R               + 
+--R                          5 6 2           4 8
+--R                 82001920a b c  + 6589440a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                           8   4             7 3 3             6 5 2
+--R                 124780544a b c  + 467927040a b c  + 304152576a b c
+--R               + 
+--R                          5 7
+--R                 39829504a b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            9 4             8 2 3             7 4 2
+--R                   44040192a c  + 561512448a b c  + 701890560a b c
+--R                 + 
+--R                             6 6
+--R                   152076288a b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                        9   3              8 3 2             7 5   6
+--R             (358612992a b c  + 1016070144a b c  + 381026304a b c)x
+--R           + 
+--R                       10 3             9 2 2             8 4   5
+--R             (94371840a  c  + 896532480a b c  + 635043840a b c)x
+--R           + 
+--R                        10   2             9 3   4
+--R             (440401920a  b c  + 697303040a b c)x
+--R           + 
+--R                       11 2             10 2   3             11     2
+--R             (92274688a  c  + 484442112a  b c)x  + 192937984a  b c x
+--R           + 
+--R                      12
+--R             33554432a  c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                        6 7          5 2 6          4 4 5          3 6 4
+--R                 - 8192a c  - 135168a b c  - 253440a b c  - 118272a b c
+--R               + 
+--R                         2 8 3         10 2     12
+--R                 - 15840a b c  - 528a b  c  - 2b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                          6   6           5 3 5           4 5 4          3 7 3
+--R                 - 643072a b c  - 2996224a b c  - 2762496a b c  - 718080a b c
+--R               + 
+--R                         2 9 2         11     13
+--R                 - 53680a b c  - 888a b  c - b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                          7 6            6 2 5            5 4 4            4 6 3
+--R                 - 696320a c  - 11661312a b c  - 22330880a b c  - 10762752a b c
+--R               + 
+--R                           3 8 2         2 10          12
+--R                 - 1523808a b c  - 57200a b  c - 338a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            7   5            6 3 4            5 5 3
+--R                 - 18235392a b c  - 83865600a b c  - 75851776a b c
+--R               + 
+--R                            4 7 2           3 9          2 11
+--R                 - 19109376a b c  - 1345344a b c - 18928a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                           8 5             7 2 4             6 4 3
+--R                 - 9863168a c  - 159129600a b c  - 288870400a b c
+--R               + 
+--R                             5 6 2            4 8           3 10
+--R                 - 128128000a b c  - 15649920a b c - 416416a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                             8   4             7 3 3             6 5 2
+--R                 - 147718144a b c  - 628490240a b c  - 505430016a b c
+--R               + 
+--R                             5 7            4 9
+--R                 - 104259584a b c - 4759040a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                            9 4             8 2 3              7 4 2
+--R                 - 53215232a c  - 779878400a b c  - 1228308480a b c
+--R               + 
+--R                             6 6             5 8
+--R                 - 430882816a b c - 32361472a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                             9   3              8 3 2              7 5
+--R                 - 512753664a b c  - 1858338816a b c  - 1153105920a b c
+--R               + 
+--R                             6 7
+--R                 - 141213696a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                             10 3              9 2 2              8 4
+--R                 - 138412032a  c  - 1703411712a b c  - 2032140288a b c
+--R               + 
+--R                             7 6
+--R                 - 412778496a b
+--R            *
+--R                6
+--R               x
+--R           + 
+--R                          10   2              9 3              8 5  5
+--R             (- 865075200a  b c  - 2340945920a b c - 825556992a b )x
+--R           + 
+--R                          11 2              10 2               9 4  4
+--R             (- 186646528a  c  - 1695547392a  b c - 1133117440a b )x
+--R           + 
+--R                          11                 10 3  3
+--R             (- 700448768a  b c - 1049624576a  b )x
+--R           + 
+--R                        12              11 2  2             12               13
+--R           (- 125829120a  c - 627048448a  b )x  - 218103808a  b x - 33554432a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                         5   7          4 3 6          3 5 5         2 7 4
+--R                 - 49152a b c  - 225280a b c  - 202752a b c  - 50688a b c
+--R               + 
+--R                          9 3      11 2
+--R                 - 3520a b c  - 48b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                          6 7           5 2 6           4 4 5           3 6 4
+--R                 - 106496a c  - 1781760a b c  - 3407360a b c  - 1638912a b c
+--R               + 
+--R                          2 8 3          10 2      12
+--R                 - 231264a b c  - 8624a b  c  - 50b  c
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                           6   6            5 3 5            4 5 4
+--R                 - 4177920a b c  - 19435520a b c  - 17864704a b c
+--R               + 
+--R                           3 7 3          2 9 2          11
+--R                 - 4612608a b c  - 338624a b c  - 5200a b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           7 6            6 2 5            5 4 4
+--R                 - 2981888a c  - 49029120a b c  - 91320320a b c
+--R               + 
+--R                            4 6 3           3 8 2          2 10
+--R                 - 42025984a b c  - 5436288a b c  - 160160a b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                            7   5             6 3 4             5 5 3
+--R                 - 56197120a b c  - 246579200a b c  - 206868480a b c
+--R               + 
+--R                            4 7 2           3 9
+--R                 - 45393920a b c  - 2288000a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            8 5             7 2 4             6 4 3
+--R                 - 23855104a c  - 361496576a b c  - 595230720a b c
+--R               + 
+--R                             5 6 2            4 8
+--R                 - 222150656a b c  - 18304000a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                             8   4              7 3 3             6 5 2
+--R                 - 271581184a b c  - 1029439488a b c  - 678494208a b c
+--R               + 
+--R                            5 7
+--R                 - 90521600a b c
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                            9 4              8 2 3              7 4 2
+--R                 - 81788928a c  - 1052246016a b c  - 1330249728a b c
+--R               + 
+--R                             6 6
+--R                 - 292454400a b c
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                          9   3              8 3 2             7 5   6
+--R             (- 585105408a b c  - 1673527296a b c  - 635043840a b c)x
+--R           + 
+--R                          10 3              9 2 2             8 4   5
+--R             (- 136314880a  c  - 1305477120a b c  - 933888000a b c)x
+--R           + 
+--R                          10   2             9 3   4
+--R             (- 574619648a  b c  - 917504000a b c)x
+--R           + 
+--R                          11 2             10 2   3             11     2
+--R             (- 109051904a  c  - 576716800a  b c)x  - 209715200a  b c x
+--R           + 
+--R                        12
+--R             - 33554432a  c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        4 2 4        2 6 2         8       10  6
+--R               (- 19200a b c  + 3360a b c  - 480a b c - 15b  )x
+--R             + 
+--R                        5   4         4 3 3         3 5 2         9  5
+--R               (- 38400a b c  - 76800a b c  + 33600a b c  - 750a b )x
+--R             + 
+--R                         5 2 3         4 4 2         3 6         2 8  4
+--R               (- 230400a b c  + 19200a b c  + 33600a b c - 6000a b )x
+--R             + 
+--R                         6   3          5 3 2          4 5          3 7  3
+--R               (- 153600a b c  - 192000a b c  + 124800a b c - 16800a b )x
+--R             + 
+--R                         6 2 2          5 4          4 6  2
+--R               (- 307200a b c  + 153600a b c - 19200a b )x
+--R             + 
+--R                         7   2         6 3         5 5
+--R               (- 122880a b c  + 61440a b c - 7680a b )x
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b x + a
+--R         + 
+--R                     4   5         3 3 4        2 5 3       9   7
+--R               (7680a b c  + 15360a b c  - 6720a b c  + 150b c)x
+--R             + 
+--R                      4 2 4        3 4 3         2 6 2          8        10  6
+--R               (99840a b c  + 7680a b c  - 20160a b c  + 2400a b c + 150b  )x
+--R             + 
+--R                           5   4          4 3 3         3 5 2        2 7
+--R                     99840a b c  + 222720a b c  - 89280a b c  - 3360a b c
+--R                   + 
+--R                            9
+--R                     2550a b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                       5 2 3         4 4 2         3 6          2 8  4
+--R               (430080a b c  - 15360a b c  - 72960a b c + 12480a b )x
+--R             + 
+--R                       6   3          5 3 2          4 5          3 7  3
+--R               (215040a b c  + 299520a b c  - 190080a b c + 25440a b )x
+--R             + 
+--R                       6 2 2          5 4          4 6  2
+--R               (368640a b c  - 184320a b c + 23040a b )x
+--R             + 
+--R                       7   2         6 3         5 5
+--R               (122880a b c  - 61440a b c + 7680a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                        4   4         3 3 3         2 5 2       9  4
+--R               (- 15360a b c  - 30720a b c  + 13440a b c  - 300b )x
+--R             + 
+--R                         4 2 3         3 4 2         2 6           8  3
+--R               (- 184320a b c  + 15360a b c  + 26880a b c - 4800a b )x
+--R             + 
+--R                         5   3          4 3 2          3 5          2 7  2
+--R               (- 184320a b c  - 230400a b c  + 149760a b c - 20160a b )x
+--R             + 
+--R                         5 2 2          4 4          3 6            6   2
+--R               (- 491520a b c  + 245760a b c - 30720a b )x - 245760a b c
+--R             + 
+--R                      5 3          4 5
+--R               122880a b c - 15360a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                      4 2 4        2 6 2         8       10  5
+--R               (38400a b c  - 6720a b c  + 960a b c + 30b  )x
+--R             + 
+--R                      5   4          4 3 3         3 5 2          9  4
+--R               (76800a b c  + 153600a b c  - 67200a b c  + 1500a b )x
+--R             + 
+--R                       5 2 3         4 4 2         3 6          2 8  3
+--R               (460800a b c  - 38400a b c  - 67200a b c + 12000a b )x
+--R             + 
+--R                       6   3          5 3 2          4 5          3 7  2
+--R               (307200a b c  + 384000a b c  - 249600a b c + 33600a b )x
+--R             + 
+--R                       6 2 2          5 4          4 6            7   2
+--R               (614400a b c  - 307200a b c + 38400a b )x + 245760a b c
+--R             + 
+--R                        6 3          5 5
+--R               - 122880a b c + 15360a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                        2   6           3 5       5 4  9
+--R               (- 20480a b c  - 10240a b c  - 256b c )x
+--R             + 
+--R                        3 6          2 2 5           4 4       6 3  8
+--R               (- 40960a c  - 130560a b c  - 26880a b c  - 352b c )x
+--R             + 
+--R                         3   5          2 3 4           5 3      7 2  7
+--R               (- 343040a b c  - 264960a b c  - 18752a b c  - 16b c )x
+--R             + 
+--R                              4 5          3 2 4          2 4 3         6 2
+--R                     - 245760a c  - 840960a b c  - 175680a b c  - 112a b c
+--R                   + 
+--R                        8
+--R                     20b c
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          4   4          3 3 3        2 5 2      9  5
+--R               (- 1082880a b c  - 650240a b c  + 1344a b c  - 30b )x
+--R             + 
+--R                            5 4           4 2 3        3 4 2        2 6
+--R                   - 491520a c  - 1198080a b c  + 6400a b c  + 6400a b c
+--R                 + 
+--R                            8
+--R                   - 1200a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                          5   3         4 3 2         3 5         2 7  3
+--R               (- 1054720a b c  - 79360a b c  + 53120a b c - 7200a b )x
+--R             + 
+--R                         6 3          5 2 2          4 4          3 6  2
+--R               (- 327680a c  - 215040a b c  + 107520a b c - 13440a b )x
+--R             + 
+--R                         6   2         5 3         4 5
+--R               (- 122880a b c  + 61440a b c - 7680a b )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                     2 7           2 6        4 5  10
+--R               (8192a c  + 20480a b c  + 2560b c )x
+--R             + 
+--R                       2   6           3 5        5 4  9
+--R               (117760a b c  + 89600a b c  + 6080b c )x
+--R             + 
+--R                       3 6          2 2 5            4 4        6 3  8
+--R               (122880a c  + 478720a b c  + 134400a b c  + 3680b c )x
+--R             + 
+--R                       3   5          2 3 4           5 3      7 2  7
+--R               (821760a b c  + 750720a b c  + 68320a b c  - 40b c )x
+--R             + 
+--R                            4 5           3 2 4          2 4 3         6 2
+--R                     450560a c  + 1713920a b c  + 404160a b c  - 560a b c
+--R                   + 
+--R                         8
+--R                     100b c
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                             4   4           3 3 3         2 5 2         7
+--R                     1758720a b c  + 1154560a b c  - 17984a b c  + 800a b c
+--R                   + 
+--R                         9
+--R                     270b
+--R              *
+--R                  5
+--R                 x
+--R             + 
+--R                          5 4           4 2 3         3 4 2         2 6
+--R                   655360a c  + 1761280a b c  - 24320a b c  - 18560a b c
+--R                 + 
+--R                          8
+--R                   3600a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        5   3          4 3 2         3 5          2 7  3
+--R               (1280000a b c  + 140800a b c  - 95360a b c + 12960a b )x
+--R             + 
+--R                       6 3          5 2 2          4 4          3 6  2
+--R               (327680a c  + 276480a b c  - 138240a b c + 17280a b )x
+--R             + 
+--R                       6   2         5 3         4 5
+--R               (122880a b c  - 61440a b c + 7680a b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                   2 7           2 6        4 5  11
+--R           (- 8192a c  - 20480a b c  - 2560b c )x
+--R         + 
+--R                     2   6           3 5        5 4  10
+--R           (- 117760a b c  - 89600a b c  - 6080b c )x
+--R         + 
+--R                     3 6          2 2 5            4 4        6 3  9
+--R           (- 122880a c  - 478720a b c  - 134400a b c  - 3680b c )x
+--R         + 
+--R                     3   5          2 3 4           5 3      7 2  8
+--R           (- 821760a b c  - 750720a b c  - 68320a b c  + 40b c )x
+--R         + 
+--R                     4 5           3 2 4          2 4 3         6 2       8   7
+--R           (- 450560a c  - 1713920a b c  - 404160a b c  + 560a b c  - 100b c)x
+--R         + 
+--R                      4   4           3 3 3         2 5 2          7        9  6
+--R           (- 1779200a b c  - 1148800a b c  + 23328a b c  - 1800a b c - 300b )x
+--R         + 
+--R                          5 4           4 2 3         3 4 2         2 6
+--R                 - 696320a c  - 1831680a b c  + 86720a b c  + 16560a b c
+--R               + 
+--R                          8
+--R                 - 5100a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                      5   3         4 3 2          3 5          2 7  4
+--R           (- 1525760a b c  - 51200a b c  + 146560a b c - 24960a b )x
+--R         + 
+--R                     6 3          5 2 2          4 4          3 6  3
+--R           (- 491520a c  - 435200a b c  + 343040a b c - 50880a b )x
+--R         + 
+--R                     6   2          5 3          4 5  2
+--R           (- 450560a b c  + 317440a b c - 46080a b )x
+--R         + 
+--R                     7 2          6 2          5 4
+--R           (- 131072a c  + 102400a b c - 15360a b )x
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                  2   7           3 6       5 5  12
+--R           (20480a b c  + 10240a b c  + 256b c )x
+--R         + 
+--R                  3 7          2 2 6           4 5       6 4  11
+--R           (40960a c  + 151040a b c  + 37120a b c  + 608b c )x
+--R         + 
+--R                   3   6          2 3 5           5 4       7 3  10
+--R           (404480a b c  + 405760a b c  + 45888a b c  + 368b c )x
+--R         + 
+--R                   4 6           3 2 5          2 4 4           6 3     8 2  9
+--R           (286720a c  + 1314560a b c  + 467520a b c  + 19216a b c  - 4b c )x
+--R         + 
+--R                    4   5           3 3 4          2 5 3         7 2      9   8
+--R           (1671680a b c  + 1756160a b c  + 193088a b c  + 128a b c  + 10b c)x
+--R         + 
+--R                      5 5           4 2 4          3 4 3        2 6 2
+--R               745472a c  + 3136000a b c  + 807040a b c  - 7232a b c
+--R             + 
+--R                      8       10
+--R               1480a b c + 30b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                         5   4           4 3 3         3 5 2        2 7
+--R                 2735616a b c  + 1905920a b c  - 93824a b c  + 6000a b c
+--R               + 
+--R                        9
+--R                 1530a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        6 4           5 2 3          4 4 2         3 6
+--R                 925696a c  + 2675456a b c  - 205760a b c  - 46000a b c
+--R               + 
+--R                       2 8
+--R                 13500a b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    6   3         5 3 2          4 5          3 7  4
+--R           (1964032a b c  + 87552a b c  - 265600a b c + 45600a b )x
+--R         + 
+--R                   7 3          6 2 2          5 4          4 6  3
+--R           (557056a c  + 592896a b c  - 481280a b c + 72000a b )x
+--R         + 
+--R                   7   2          6 3          5 5  2
+--R           (516096a b c  - 368640a b c + 53760a b )x
+--R         + 
+--R                   8 2          7 2          6 4
+--R           (131072a c  - 102400a b c + 15360a b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                    2 5            2 4         4 3  4
+--R             (40960a c  + 102400a b c  + 12800b c )x
+--R           + 
+--R                     2   4            3 3  3           3 4          2 2 3  2
+--R             (491520a b c  + 204800a b c )x  + (491520a c  + 860160a b c )x
+--R           + 
+--R                     3   3           4 3
+--R             1310720a b c x + 655360a c
+--R        *
+--R                          +--------------+
+--R            +---+ +-+ +-+ |   2
+--R           \|- c \|a \|c \|c x  + b x + a
+--R       + 
+--R                       2   5           3 4        5 3  5
+--R             (- 102400a b c  - 51200a b c  - 1280b c )x
+--R           + 
+--R                       3 5          2 2 4           4 3  4
+--R             (- 204800a c  - 512000a b c  - 64000a b c )x
+--R           + 
+--R                        3   4          2 3 3  3
+--R             (- 1228800a b c  - 512000a b c )x
+--R           + 
+--R                       4 4           3 2 3  2           4   3           5 3
+--R             (- 819200a c  - 1433600a b c )x  - 1638400a b c x - 655360a c
+--R        *
+--R            +---+ +-+
+--R           \|- c \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 258
+
+--S 259 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                       4   6         3 3 5        2 5 4         7 3      9 2  14
+--R               (- 5120a b c  - 15360a b c  - 8064a b c  - 960a b c  - 20b c )x
+--R             + 
+--R                           5 6          4 2 5          3 4 4         2 6 3
+--R                   - 10240a c  - 122880a b c  - 157440a b c  - 45696a b c
+--R                 + 
+--R                            8 2      10
+--R                   - 3240a b c  - 40b  c
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                   - 276480a b c  - 936960a b c  - 589056a b c  - 94464a b c
+--R                 + 
+--R                            9       11
+--R                   - 3640a b c - 20b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                            6 5           5 2 4           4 4 3           3 6 2
+--R                   - 184320a c  - 2334720a b c  - 3212800a b c  - 1029888a b c
+--R                 + 
+--R                           2 8           10
+--R                   - 84816a b c - 1360a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                             6   4           5 3 3           4 5 2          3 7
+--R                   - 2565120a b c  - 8760320a b c  - 5499264a b c  - 854208a b c
+--R                 + 
+--R                           2 9
+--R                   - 28004a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             7 4            6 2 3            5 4 2
+--R                   - 1026048a c  - 12564480a b c  - 16254720a b c
+--R                 + 
+--R                             4 6           3 8
+--R                   - 4591488a b c - 271656a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                               7   3            6 3 2            5 5
+--R                     - 9060352a b c  - 27955200a b c  - 14601216a b c
+--R                   + 
+--R                               4 7
+--R                     - 1489664a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          8 3            7 2 2            6 4            5 6  7
+--R               (- 2588672a c  - 27844608a b c  - 28846080a b c - 5065216a b )x
+--R             + 
+--R                           8   2            7 3             6 5  6
+--R               (- 14893056a b c  - 35807232a b c - 11203584a b )x
+--R             + 
+--R                          9 2            8 2             7 4  5
+--R               (- 3309568a c  - 27181056a b c - 16427008a b )x
+--R             + 
+--R                           9               8 3  4
+--R               (- 11534336a b c - 15859712a b )x
+--R             + 
+--R                          10            9 2  3           10   2          11
+--R               (- 2097152a  c - 9699328a b )x  - 3407872a  b x  - 524288a  x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                    5 7         4 2 6         3 4 5        2 6 4         8 3
+--R               1024a c  + 11520a b c  + 13440a b c  + 3360a b c  + 180a b c
+--R             + 
+--R                10 2
+--R               b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                     5   6          4 3 5          3 5 4         2 7 3
+--R               53248a b c  + 176640a b c  + 107520a b c  + 16320a b c
+--R             + 
+--R                     9 2     11
+--R               560a b c  + 2b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                     6 6          5 2 5          4 4 4          3 6 3
+--R               53248a c  + 689664a b c  + 979200a b c  + 329280a b c
+--R             + 
+--R                     2 8 2         10     12
+--R               29520a b c  + 582a b  c + b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                       6   5           5 3 4           4 5 3          3 7 2
+--R               1026048a b c  + 3760640a b c  + 2622720a b c  + 486720a b c
+--R             + 
+--R                     2 9          11
+--R               23560a b c + 202a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                      7 5           6 2 4            5 4 3           4 6 2
+--R               513024a c  + 6923520a b c  + 10317440a b c  + 3670560a b c
+--R             + 
+--R                      3 8         2 10
+--R               349380a b c + 7001a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                       7   4            6 3 3            5 5 2           4 7
+--R               6051840a b c  + 22046720a b c  + 14999808a b c  + 2586240a b c
+--R             + 
+--R                     3 9
+--R               97880a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                       8 4            7 2 3            6 4 2            5 6
+--R               2017280a c  + 26081280a b c  + 36023040a b c  + 11034496a b c
+--R             + 
+--R                      4 8
+--R               724680a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                     8   3            7 3 2            6 5            5 7  8
+--R           (16056320a b c  + 52346880a b c  + 29208576a b c + 3232768a b )x
+--R         + 
+--R                    9 3            8 2 2            7 4            6 6  7
+--R           (4014080a c  + 45281280a b c  + 49597440a b c + 9308416a b )x
+--R         + 
+--R                     9   2            8 3             7 5  6
+--R           (21463040a b c  + 54149120a b c + 17922048a b )x
+--R         + 
+--R                    10 2            9 2             8 4  5
+--R           (4292608a  c  + 36782080a b c + 23336960a b )x
+--R         + 
+--R                     10               9 3  4            11             10 2  3
+--R           (14155776a  b c + 20316160a b )x  + (2359296a  c + 11337728a  b )x
+--R         + 
+--R                   11   2          12
+--R           3670016a  b x  + 524288a  x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      5 7         4 2 6         3 4 5        2 6 4         8 3
+--R               - 1024a c  - 11520a b c  - 13440a b c  - 3360a b c  - 180a b c
+--R             + 
+--R                  10 2
+--R               - b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                       5   6          4 3 5          3 5 4         2 7 3
+--R               - 53248a b c  - 176640a b c  - 107520a b c  - 16320a b c
+--R             + 
+--R                       9 2     11
+--R               - 560a b c  - 2b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                       6 6          5 2 5          4 4 4          3 6 3
+--R               - 53248a c  - 689664a b c  - 979200a b c  - 329280a b c
+--R             + 
+--R                       2 8 2         10     12
+--R               - 29520a b c  - 582a b  c - b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                         6   5           5 3 4           4 5 3          3 7 2
+--R               - 1026048a b c  - 3760640a b c  - 2622720a b c  - 486720a b c
+--R             + 
+--R                       2 9          11
+--R               - 23560a b c - 202a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                        7 5           6 2 4            5 4 3           4 6 2
+--R               - 513024a c  - 6923520a b c  - 10317440a b c  - 3670560a b c
+--R             + 
+--R                        3 8         2 10
+--R               - 349380a b c - 7001a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         7   4            6 3 3            5 5 2           4 7
+--R               - 6051840a b c  - 22046720a b c  - 14999808a b c  - 2586240a b c
+--R             + 
+--R                       3 9
+--R               - 97880a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         8 4            7 2 3            6 4 2            5 6
+--R               - 2017280a c  - 26081280a b c  - 36023040a b c  - 11034496a b c
+--R             + 
+--R                        4 8
+--R               - 724680a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                       8   3            7 3 2            6 5            5 7  9
+--R           (- 16056320a b c  - 52346880a b c  - 29208576a b c - 3232768a b )x
+--R         + 
+--R                      9 3            8 2 2            7 4            6 6  8
+--R           (- 4014080a c  - 45281280a b c  - 49597440a b c - 9308416a b )x
+--R         + 
+--R                       9   2            8 3             7 5  7
+--R           (- 21463040a b c  - 54149120a b c - 17922048a b )x
+--R         + 
+--R                      10 2            9 2             8 4  6
+--R           (- 4292608a  c  - 36782080a b c - 23336960a b )x
+--R         + 
+--R                       10               9 3  5
+--R           (- 14155776a  b c - 20316160a b )x
+--R         + 
+--R                      11             10 2  4           11   3          12 2
+--R           (- 2359296a  c - 11337728a  b )x  - 3670016a  b x  - 524288a  x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 4   7         3 3 6        2 5 5         7 4      9 3  17
+--R           (5120a b c  + 15360a b c  + 8064a b c  + 960a b c  + 20b c )x
+--R         + 
+--R                     5 7          4 2 6          3 4 5         2 6 4
+--R               10240a c  + 128000a b c  + 172800a b c  + 53760a b c
+--R             + 
+--R                      8 3      10 2
+--R               4200a b c  + 60b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                      5   6           4 3 5          3 5 4          2 7 3
+--R               291840a b c  + 1075200a b c  + 754560a b c  + 141120a b c
+--R             + 
+--R                      9 2      11
+--R               6900a b c  + 60b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                      6 6           5 2 5           4 4 4           3 6 3
+--R               194560a c  + 2734080a b c  + 4307200a b c  + 1664640a b c
+--R             + 
+--R                      2 8 2          10       12
+--R               182520a b c  + 5040a b  c + 20b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                       6   5            5 3 4           4 5 3           3 7 2
+--R               3025920a b c  + 12032000a b c  + 9301120a b c  + 1978560a b c
+--R             + 
+--R                      2 9           11
+--R               116460a b c + 1380a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                       7 5            6 2 4            5 4 3            4 6 2
+--R               1210368a c  + 17464320a b c  + 28227840a b c  + 11120640a b c
+--R             + 
+--R                       3 8          2 10
+--R               1210680a b c + 29364a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        7   4            6 3 3            5 5 2           4 7
+--R               12651520a b c  + 49280000a b c  + 36355200a b c  + 6935360a b c
+--R             + 
+--R                      3 9
+--R               299660a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                       8 4            7 2 3            6 4 2            5 6
+--R               3614720a c  + 49469440a b c  + 73056000a b c  + 24257920a b c
+--R             + 
+--R                       4 8
+--R               1761320a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                     8   3            7 3 2            6 5            5 7  9
+--R           (26542080a b c  + 91607040a b c  + 54650880a b c + 6554880a b )x
+--R         + 
+--R                    9 3            8 2 2            7 4             6 6  8
+--R           (5898240a c  + 69918720a b c  + 81080320a b c + 16268800a b )x
+--R         + 
+--R                     9   2            8 3             7 5  7
+--R           (29736960a b c  + 78848000a b c + 27630592a b )x
+--R         + 
+--R                    10 2            9 2             8 4  6
+--R           (5406720a  c  + 48414720a b c + 32286720a b )x
+--R         + 
+--R                     10               9 3  5            11             10 2  4
+--R           (17039360a  b c + 25559040a b )x  + (2621440a  c + 13107200a  b )x
+--R         + 
+--R                   11   3          12 2
+--R           3932160a  b x  + 524288a  x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                      5 5         4 2 4         3 4 3        2 6 2         8
+--R                 1024a c  + 11520a b c  + 13440a b c  + 3360a b c  + 180a b c
+--R               + 
+--R                  10
+--R                 b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                    5   4          4 3 3         3 5 2        2 7          9  9
+--R             (51200a b c  + 153600a b c  + 80640a b c  + 9600a b c + 200a b )x
+--R           + 
+--R                         6 4          5 2 3          4 4 2          3 6
+--R                   51200a c  + 563200a b c  + 633600a b c  + 147840a b c
+--R                 + 
+--R                        2 8
+--R                   6600a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                     6   3           5 3 2           4 5          3 7  7
+--R             (819200a b c  + 2252800a b c  + 1013760a b c + 84480a b )x
+--R           + 
+--R                     7 3           6 2 2           5 4           4 6  6
+--R             (409600a c  + 3993600a b c  + 3660800a b c + 549120a b )x
+--R           + 
+--R                      7   2           6 3            5 5  5
+--R             (3440640a b c  + 7454720a b c + 2050048a b )x
+--R           + 
+--R                      8 2           7 2            6 4  4
+--R             (1146880a c  + 8601600a b c + 4659200a b )x
+--R           + 
+--R                      8              7 3  3            9            8 2  2
+--R             (5242880a b c + 6553600a b )x  + (1310720a c + 5570560a b )x
+--R           + 
+--R                     9             10
+--R             2621440a b x + 524288a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                     4   5         3 3 4        2 5 3         7 2      9   11
+--R             (- 5120a b c  - 15360a b c  - 8064a b c  - 960a b c  - 20b c)x
+--R           + 
+--R                         5 5          4 2 4          3 4 3         2 6 2
+--R                 - 10240a c  - 117760a b c  - 142080a b c  - 37632a b c
+--R               + 
+--R                          8       10
+--R                 - 2280a b c - 20b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                 - 261120a b c  - 803840a b c  - 438912a b c  - 55872a b c
+--R               + 
+--R                          9
+--R                 - 1340a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                          6 4           5 2 3           4 4 2          3 6
+--R                 - 174080a c  - 1955840a b c  - 2266880a b c  - 553344a b c
+--R               + 
+--R                         2 8
+--R                 - 26664a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                        6   3           5 3 2           4 5           3 7  7
+--R             (- 2129920a b c  - 6000640a b c  - 2793472a b c - 244992a b )x
+--R           + 
+--R                       7 3           6 2 2           5 4            4 6  6
+--R             (- 851968a c  - 8478720a b c  - 7987200a b c - 1244672a b )x
+--R           + 
+--R                        7   2            6 3            5 5  5
+--R             (- 6078464a b c  - 13475840a b c - 3820544a b )x
+--R           + 
+--R                        8 2            7 2            6 4  4
+--R             (- 1736704a c  - 13287424a b c - 7383040a b )x
+--R           + 
+--R                        8              7 3  3              9            8 2  2
+--R             (- 7077888a b c - 9043968a b )x  + (- 1572864a c - 6815744a b )x
+--R           + 
+--R                       9             10
+--R             - 2883584a b x - 524288a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 259
+
+)clear all
+
+--S 260 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^3
+--R 
+--R
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R   (1)  -------------------------------------
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 704
+r0:=1/8*(b+2*c*x)*(a*x^2+b*x^3+c*x^4)^(3/2)/(c*x^3)+3/128*(b^2-4*a*c)^2*x*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (c^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))-3/64*(b^2-4*a*c)*(b+2*c*x)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(c^2*x)
+--R 
+--R
+--R   (2)
+--R                                 +--------------+
+--R           2 2        2      4   |   2                        2c x + b
+--R       (48a c  - 24a b c + 3b )x\|c x  + b x + a atanh(----------------------)
+--R                                                             +--------------+
+--R                                                         +-+ |   2
+--R                                                       2\|c \|c x  + b x + a
+--R     + 
+--R              4 6        3 5          3      2 2  4            2     3   3
+--R           32c x  + 80b c x  + (112a c  + 52b c )x  + (168a b c  - 2b c)x
+--R         + 
+--R               2 2        2      4  2       2          3
+--R           (80a c  + 44a b c - 6b )x  + (40a b c - 6a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R               +------------------+
+--R         2 +-+ |   4      3      2
+--R     128c \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       3   3       2 3 2        5       7  3
+--R                 (1536a b c  - 384a b c  - 96a b c + 24b )x
+--R               + 
+--R                       4 3        3 2 2        2 4          6  2
+--R                 (3072a c  + 2304a b c  - 1728a b c + 240a b )x
+--R               + 
+--R                       4   2        3 3        2 5          5 2        4 2
+--R                 (9216a b c  - 4608a b c + 576a b )x + 6144a c  - 3072a b c
+--R               + 
+--R                     3 4
+--R                 384a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                    4 4       3 2 3       2 4 2        6      8  4
+--R             (- 768a c  - 768a b c  + 480a b c  - 48a b c - 3b )x
+--R           + 
+--R                     4   3        3 3 2       2 5         7  3
+--R             (- 6144a b c  + 1536a b c  + 384a b c - 96a b )x
+--R           + 
+--R                     5 3        4 2 2        3 4        2 6  2
+--R             (- 6144a c  - 4608a b c  + 3456a b c - 480a b )x
+--R           + 
+--R                      5   2        4 3        3 5          6 2        5 2
+--R             (- 12288a b c  + 6144a b c - 768a b )x - 6144a c  + 3072a b c
+--R           + 
+--R                   4 4
+--R             - 384a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                    2 5         2 4      4 3  7
+--R             (- 512a c  - 768a b c  - 32b c )x
+--R           + 
+--R                     2   4          3 3      5 2  6
+--R             (- 4864a b c  - 2176a b c  - 48b c )x
+--R           + 
+--R                     3 4         2 2 3          4 2     6   5
+--R             (- 5376a c  - 13248a b c  - 1712a b c  - 4b c)x
+--R           + 
+--R                      3   3         2 3 2        5      7  4
+--R             (- 25216a b c  - 11616a b c  - 24a b c + 6b )x
+--R           + 
+--R                      4 3         3 2 2        2 4          6  3
+--R             (- 14336a c  - 29440a b c  - 1024a b c + 144a b )x
+--R           + 
+--R                      4   2        3 3        2 5  2
+--R             (- 29184a b c  - 3840a b c + 480a b )x
+--R           + 
+--R                      5 2        4 2        3 4
+--R             (- 10240a c  - 3072a b c + 384a b )x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                       5       3 4  8         2 5          2 4       4 3  7
+--R             (1024a b c  + 256b c )x  + (2048a c  + 5120a b c  + 640b c )x
+--R           + 
+--R                    2   4          3 3       5 2  6
+--R             (14848a b c  + 8960a b c  + 416b c )x
+--R           + 
+--R                    3 4         2 2 3          4 2      6   5
+--R             (11264a c  + 33024a b c  + 5440a b c  - 16b c)x
+--R           + 
+--R                    3   3         2 3 2         5       7  4
+--R             (44416a b c  + 24480a b c  + 104a b c - 42b )x
+--R           + 
+--R                    4 3         3 2 2        2 4          6  3
+--R             (19456a c  + 44288a b c  + 2368a b c - 336a b )x
+--R           + 
+--R                    4   2        3 3        2 5  2
+--R             (34304a b c  + 5376a b c - 672a b )x
+--R           + 
+--R                    5 2        4 2        3 4
+--R             (10240a c  + 3072a b c - 384a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                       3        3 2  3         2 3           2 2  2
+--R             (4096a b c  + 1024b c )x  + (8192a c  + 10240a b c )x
+--R           + 
+--R                   2   2          3 2
+--R             24576a b c x + 16384a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                     2 4          2 3       4 2  4
+--R             (- 2048a c  - 3072a b c  - 128b c )x
+--R           + 
+--R                      2   3          3 2  3            3 3         2 2 2  2
+--R             (- 16384a b c  - 4096a b c )x  + (- 16384a c  - 20480a b c )x
+--R           + 
+--R                     3   2          4 2
+--R             - 32768a b c x - 16384a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                       3   3       2 3 2        5       7  3
+--R                 (1536a b c  - 384a b c  - 96a b c + 24b )x
+--R               + 
+--R                       4 3        3 2 2        2 4          6  2
+--R                 (3072a c  + 2304a b c  - 1728a b c + 240a b )x
+--R               + 
+--R                       4   2        3 3        2 5          5 2        4 2
+--R                 (9216a b c  - 4608a b c + 576a b )x + 6144a c  - 3072a b c
+--R               + 
+--R                     3 4
+--R                 384a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                    4 4       3 2 3       2 4 2        6      8  4
+--R             (- 768a c  - 768a b c  + 480a b c  - 48a b c - 3b )x
+--R           + 
+--R                     4   3        3 3 2       2 5         7  3
+--R             (- 6144a b c  + 1536a b c  + 384a b c - 96a b )x
+--R           + 
+--R                     5 3        4 2 2        3 4        2 6  2
+--R             (- 6144a c  - 4608a b c  + 3456a b c - 480a b )x
+--R           + 
+--R                      5   2        4 3        3 5          6 2        5 2
+--R             (- 12288a b c  + 6144a b c - 768a b )x - 6144a c  + 3072a b c
+--R           + 
+--R                   4 4
+--R             - 384a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                    2 5         2 4      4 3  7
+--R             (- 256a c  - 384a b c  - 16b c )x
+--R           + 
+--R                     2   4          3 3      5 2  6
+--R             (- 2432a b c  - 1088a b c  - 24b c )x
+--R           + 
+--R                     3 4        2 2 3         4 2     6   5
+--R             (- 2688a c  - 6624a b c  - 856a b c  - 2b c)x
+--R           + 
+--R                      3   3        2 3 2        5      7  4
+--R             (- 12608a b c  - 5808a b c  - 12a b c + 3b )x
+--R           + 
+--R                     4 3         3 2 2       2 4         6  3
+--R             (- 7168a c  - 14720a b c  - 512a b c + 72a b )x
+--R           + 
+--R                      4   2        3 3        2 5  2
+--R             (- 14592a b c  - 1920a b c + 240a b )x
+--R           + 
+--R                     5 2        4 2        3 4
+--R             (- 5120a c  - 1536a b c + 192a b )x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                      5       3 4  8         2 5          2 4       4 3  7
+--R             (512a b c  + 128b c )x  + (1024a c  + 2560a b c  + 320b c )x
+--R           + 
+--R                   2   4          3 3       5 2  6
+--R             (7424a b c  + 4480a b c  + 208b c )x
+--R           + 
+--R                   3 4         2 2 3          4 2     6   5
+--R             (5632a c  + 16512a b c  + 2720a b c  - 8b c)x
+--R           + 
+--R                    3   3         2 3 2        5       7  4
+--R             (22208a b c  + 12240a b c  + 52a b c - 21b )x
+--R           + 
+--R                   4 3         3 2 2        2 4          6  3
+--R             (9728a c  + 22144a b c  + 1184a b c - 168a b )x
+--R           + 
+--R                    4   2        3 3        2 5  2
+--R             (17152a b c  + 2688a b c - 336a b )x
+--R           + 
+--R                   5 2        4 2        3 4
+--R             (5120a c  + 1536a b c - 192a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                       3       3 2  3         2 3          2 2  2         2   2
+--R             (2048a b c  + 512b c )x  + (4096a c  + 5120a b c )x  + 12288a b c x
+--R           + 
+--R                  3 2
+--R             8192a c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                     2 4          2 3      4 2  4
+--R             (- 1024a c  - 1536a b c  - 64b c )x
+--R           + 
+--R                     2   3          3 2  3           3 3         2 2 2  2
+--R             (- 8192a b c  - 2048a b c )x  + (- 8192a c  - 10240a b c )x
+--R           + 
+--R                     3   2         4 2
+--R             - 16384a b c x - 8192a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 262
+
+--S 263 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     3   3       2 3 2        5       7  3
+--R               (1536a b c  - 384a b c  - 96a b c + 24b )x
+--R             + 
+--R                     4 3        3 2 2        2 4          6  2
+--R               (3072a c  + 2304a b c  - 1728a b c + 240a b )x
+--R             + 
+--R                     4   2        3 3        2 5          5 2        4 2
+--R               (9216a b c  - 4608a b c + 576a b )x + 6144a c  - 3072a b c
+--R             + 
+--R                   3 4
+--R               384a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                  4 4       3 2 3       2 4 2        6      8  4
+--R           (- 768a c  - 768a b c  + 480a b c  - 48a b c - 3b )x
+--R         + 
+--R                   4   3        3 3 2       2 5         7  3
+--R           (- 6144a b c  + 1536a b c  + 384a b c - 96a b )x
+--R         + 
+--R                   5 3        4 2 2        3 4        2 6  2
+--R           (- 6144a c  - 4608a b c  + 3456a b c - 480a b )x
+--R         + 
+--R                  5   2        4 3        3 5          6 2        5 2        4 4
+--R         (- 12288a b c  + 6144a b c - 768a b )x - 6144a c  + 3072a b c - 384a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                    4 4       3 2 3       2 4 2        6      8  5
+--R               (768a c  + 768a b c  - 480a b c  + 48a b c + 3b )x
+--R             + 
+--R                     4   3        3 3 2       2 5         7  4
+--R               (6144a b c  - 1536a b c  - 384a b c + 96a b )x
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6  3
+--R               (6144a c  + 4608a b c  - 3456a b c + 480a b )x
+--R             + 
+--R                      5   2        4 3        3 5  2
+--R               (12288a b c  - 6144a b c + 768a b )x
+--R             + 
+--R                     6 2        5 2        4 4
+--R               (6144a c  - 3072a b c + 384a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       3   4       2 3 3        5 2      7   6
+--R               (- 1536a b c  + 384a b c  + 96a b c  - 24b c)x
+--R             + 
+--R                       4 4        3 2 3        2 4 2         6       8  5
+--R               (- 3072a c  - 3840a b c  + 2112a b c  - 144a b c - 24b )x
+--R             + 
+--R                        4   3        3 3 2        2 5          7  4
+--R               (- 13824a b c  + 2688a b c  + 1248a b c - 264a b )x
+--R             + 
+--R                       5 3        4 2 2        3 4        2 6  3
+--R               (- 9216a c  - 8448a b c  + 5952a b c - 816a b )x
+--R             + 
+--R                        5   2        4 3        3 5  2
+--R               (- 15360a b c  + 7680a b c - 960a b )x
+--R             + 
+--R                       6 2        5 2        4 4
+--R               (- 6144a c  + 3072a b c - 384a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                      2 5         2 4      4 3  7
+--R               (- 512a c  - 768a b c  - 32b c )x
+--R             + 
+--R                       2   4          3 3      5 2  6
+--R               (- 4864a b c  - 2176a b c  - 48b c )x
+--R             + 
+--R                       3 4         2 2 3          4 2     6   5
+--R               (- 5376a c  - 13248a b c  - 1712a b c  - 4b c)x
+--R             + 
+--R                        3   3         2 3 2        5      7  4
+--R               (- 25216a b c  - 11616a b c  - 24a b c + 6b )x
+--R             + 
+--R                        4 3         3 2 2        2 4          6  3
+--R               (- 14336a c  - 29440a b c  - 1024a b c + 144a b )x
+--R             + 
+--R                        4   2        3 3        2 5  2
+--R               (- 29184a b c  - 3840a b c + 480a b )x
+--R             + 
+--R                        5 2        4 2        3 4
+--R               (- 10240a c  - 3072a b c + 384a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                         5       3 4  8         2 5          2 4       4 3  7
+--R               (1024a b c  + 256b c )x  + (2048a c  + 5120a b c  + 640b c )x
+--R             + 
+--R                      2   4          3 3       5 2  6
+--R               (14848a b c  + 8960a b c  + 416b c )x
+--R             + 
+--R                      3 4         2 2 3          4 2      6   5
+--R               (11264a c  + 33024a b c  + 5440a b c  - 16b c)x
+--R             + 
+--R                      3   3         2 3 2         5       7  4
+--R               (44416a b c  + 24480a b c  + 104a b c - 42b )x
+--R             + 
+--R                      4 3         3 2 2        2 4          6  3
+--R               (19456a c  + 44288a b c  + 2368a b c - 336a b )x
+--R             + 
+--R                      4   2        3 3        2 5  2
+--R               (34304a b c  + 5376a b c - 672a b )x
+--R             + 
+--R                      5 2        4 2        3 4
+--R               (10240a c  + 3072a b c - 384a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                       5       3 4  9           2 5          2 4       4 3  8
+--R           (- 1024a b c  - 256b c )x  + (- 2048a c  - 5120a b c  - 640b c )x
+--R         + 
+--R                    2   4          3 3       5 2  7
+--R           (- 14848a b c  - 8960a b c  - 416b c )x
+--R         + 
+--R                    3 4         2 2 3          4 2      6   6
+--R           (- 11264a c  - 33024a b c  - 5440a b c  + 16b c)x
+--R         + 
+--R                    3   3         2 3 2      7  5
+--R           (- 45056a b c  - 25344a b c  + 48b )x
+--R         + 
+--R                    4 3         3 2 2        2 4          6  4
+--R           (- 19456a c  - 49408a b c  - 2880a b c + 528a b )x
+--R         + 
+--R                    4   2         3 3         2 5  3
+--R           (- 39424a b c  - 11008a b c + 1632a b )x
+--R         + 
+--R                    5 2         4 2         3 4  2           5          4 3
+--R           (- 10240a c  - 13312a b c + 1920a b )x  + (- 5120a b c + 768a b )x
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                2 6         2 5      4 4  10
+--R           (512a c  + 768a b c  + 32b c )x
+--R         + 
+--R                 2   5          3 4      5 3  9
+--R           (5376a b c  + 2944a b c  + 80b c )x
+--R         + 
+--R                 3 5         2 2 4          4 3      6 2  8
+--R           (5888a c  + 18880a b c  + 3920a b c  + 52b c )x
+--R         + 
+--R                  3   4         2 3 3          5 2     7   7
+--R           (35456a b c  + 27040a b c  + 1784a b c  - 2b c)x
+--R         + 
+--R                  4 4         3 2 3         2 4 2         6      8  6
+--R           (19712a c  + 69184a b c  + 14480a b c  - 164a b c - 6b )x
+--R         + 
+--R                  4   3         3 3 2       2 5          7  5
+--R           (71296a b c  + 48992a b c  + 216a b c - 198a b )x
+--R         + 
+--R                  5 3         4 2 2        3 4         2 6  4
+--R           (24576a c  + 73216a b c  + 6272a b c - 1152a b )x
+--R         + 
+--R                  5   2         4 3         3 5  3
+--R           (47104a b c  + 16640a b c - 2496a b )x
+--R         + 
+--R                  6 2         5 2         4 4  2         6          5 3
+--R           (10240a c  + 15872a b c - 2304a b )x  + (5120a b c - 768a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                       3        3 2  3         2 3           2 2  2
+--R             (4096a b c  + 1024b c )x  + (8192a c  + 10240a b c )x
+--R           + 
+--R                   2   2          3 2
+--R             24576a b c x + 16384a c
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                     2 4          2 3       4 2  4
+--R             (- 2048a c  - 3072a b c  - 128b c )x
+--R           + 
+--R                      2   3          3 2  3            3 3         2 2 2  2
+--R             (- 16384a b c  - 4096a b c )x  + (- 16384a c  - 20480a b c )x
+--R           + 
+--R                     3   2          4 2
+--R             - 32768a b c x - 16384a c
+--R        *
+--R            +-+
+--R           \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                              5 7         4 2 6         3 4 5        2 6 4
+--R                       - 2048a c  - 23040a b c  - 26880a b c  - 6720a b c
+--R                     + 
+--R                               8 3     10 2
+--R                       - 360a b c  - 2b  c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                5   6          4 3 5          3 5 4
+--R                       - 115712a b c  - 372480a b c  - 217728a b c
+--R                     + 
+--R                               2 7 3         9 2     11
+--R                       - 31200a b c  - 980a b c  - 3b  c
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                6 6           5 2 5           4 4 4
+--R                       - 126976a c  - 1572864a b c  - 2108160a b c
+--R                     + 
+--R                                3 6 3         2 8 2         10     12
+--R                       - 655872a b c  - 52560a b c  - 864a b  c - b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                 6   5           5 3 4           4 5 3
+--R                       - 2552832a b c  - 8769280a b c  - 5622912a b c
+--R                     + 
+--R                                3 7 2         2 9          11
+--R                       - 930528a b c  - 38020a b c - 243a b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                 7 5            6 2 4            5 4 3
+--R                       - 1394688a c  - 17594880a b c  - 24090880a b c
+--R                     + 
+--R                                 4 6 2          3 8         2 10
+--R                       - 7672896a b c  - 626472a b c - 9922a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                  7   4            6 3 3            5 5 2
+--R                       - 16773120a b c  - 56238080a b c  - 34450944a b c
+--R                     + 
+--R                                 4 7           3 9
+--R                       - 5170176a b c - 160688a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                 8 4            7 2 3            6 4 2
+--R                       - 6086656a c  - 72622080a b c  - 90854400a b c
+--R                     + 
+--R                                  5 6            4 8
+--R                       - 24527360a b c - 1359072a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                  8   3             7 3 2            6 5
+--R                       - 48676864a b c  - 144568320a b c  - 71844864a b c
+--R                     + 
+--R                                 5 7
+--R                       - 6845696a b
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                  9 3             8 2 2             7 4
+--R                       - 13205504a c  - 136421376a b c  - 134277120a b c
+--R                     + 
+--R                                  6 6
+--R                       - 22038016a b
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                               9   2             8 3             7 5  5
+--R                   (- 70254592a b c  - 160497664a b c - 47038464a b )x
+--R                 + 
+--R                               10 2             9 2             8 4  4
+--R                   (- 15204352a  c  - 118751232a b c - 67403776a b )x
+--R                 + 
+--R                               10               9 3  3
+--R                   (- 49545216a  b c - 64159744a b )x
+--R                 + 
+--R                            11             10 2  2            11              12
+--R                 (- 8912896a  c - 38928384a  b )x  - 13631488a  b x - 2097152a
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                             4   7         3 3 6         2 5 5          7 4
+--R                       10240a b c  + 30720a b c  + 16128a b c  + 1920a b c
+--R                     + 
+--R                          9 3
+--R                       40b c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                             5 7          4 2 6          3 4 5         2 6 4
+--R                       22528a c  + 268800a b c  + 341760a b c  + 98112a b c
+--R                     + 
+--R                              8 3      10 2
+--R                       6840a b c  + 82b  c
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                              5   6           4 3 5           3 5 4
+--R                       657408a b c  + 2204160a b c  + 1366272a b c
+--R                     + 
+--R                              2 7 3          9 2      11
+--R                       214848a b c  + 8040a b c  + 42b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                              6 6           5 2 5           4 4 4
+--R                       473088a c  + 5921280a b c  + 8026880a b c
+--R                     + 
+--R                               3 6 3          2 8 2          10
+--R                       2523456a b c  + 202392a b c  + 3122a b  c
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                               6   5            5 3 4            4 5 3
+--R                       6973440a b c  + 23459840a b c  + 14454528a b c
+--R                     + 
+--R                               3 7 2         2 9
+--R                       2192256a b c  + 69608a b c
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                               7 5            6 2 4            5 4 3
+--R                       2973696a c  + 35880960a b c  + 45603840a b c
+--R                     + 
+--R                                4 6 2          3 8
+--R                       12604416a b c  + 725472a b c
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                7   4            6 3 3            5 5 2
+--R                       27459584a b c  + 83312640a b c  + 42651648a b c
+--R                     + 
+--R                               4 7
+--R                       4246528a b c
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                               8 4            7 2 3            6 4 2
+--R                       8290304a c  + 87760896a b c  + 89241600a b c
+--R                     + 
+--R                                5 6
+--R                       15328768a b c
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                             8   3             7 3 2            6 5   6
+--R                   (49446912a b c  + 116834304a b c  + 35825664a b c)x
+--R                 + 
+--R                             9 3            8 2 2            7 4   5
+--R                   (11534336a c  + 93192192a b c  + 55279616a b c)x
+--R                 + 
+--R                             9   2            8 3   4
+--R                   (41418752a b c  + 55967744a b c)x
+--R                 + 
+--R                            10 2            9 2   3            10     2
+--R                   (7864320a  c  + 35782656a b c)x  + 13107200a  b c x
+--R                 + 
+--R                           11
+--R                   2097152a  c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        4   7         3 3 6         2 5 5          7 4      9 3
+--R                 (10240a b c  + 30720a b c  + 16128a b c  + 1920a b c  + 40b c )
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                         5 7          4 2 6          3 4 5          2 6 4
+--R                   22528a c  + 273920a b c  + 357120a b c  + 106176a b c
+--R                 + 
+--R                          8 3       10 2
+--R                   7800a b c  + 102b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                          5   6           4 3 5           3 5 4          2 7 3
+--R                   679936a b c  + 2380800a b c  + 1566720a b c  + 269184a b c
+--R                 + 
+--R                           9 2      11
+--R                   11680a b c  + 84b  c
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                          6 6           5 2 5           4 4 4           3 6 3
+--R                   495616a c  + 6571008a b c  + 9635840a b c  + 3398784a b c
+--R                 + 
+--R                          2 8 2          10       12
+--R                   329616a b c  + 7604a b  c + 22b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                           6   5            5 3 4            4 5 3
+--R                   7919616a b c  + 29250560a b c  + 20634880a b c
+--R                 + 
+--R                           3 7 2          2 9           11
+--R                   3900672a b c  + 195224a b c + 1804a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                           7 5            6 2 4            5 4 3
+--R                   3446784a c  + 46210560a b c  + 68330240a b c
+--R                 + 
+--R                            4 6 2           3 8          2 10
+--R                   24083136a b c  + 2265912a b c + 44726a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            7   4             6 3 3            5 5 2
+--R                   36380672a b c  + 130088960a b c  + 86455296a b c
+--R                 + 
+--R                            4 7           3 9
+--R                   14451712a b c + 523424a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            8 4             7 2 3             6 4 2
+--R                   11264000a c  + 142041088a b c  + 190202880a b c
+--R                 + 
+--R                            5 6            4 8
+--R                   55983616a b c + 3482336a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            8   3             7 3 2             6 5
+--R                   82608128a b c  + 260063232a b c  + 138872832a b c
+--R                 + 
+--R                            5 7
+--R                   14510080a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                              9 3             8 2 2             7 4
+--R                     19824640a c  + 215506944a b c  + 225548288a b c
+--R                   + 
+--R                              6 6
+--R                     39950848a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         9   2             8 3             7 5  5
+--R               (99090432a b c  + 238813184a b c + 74678272a b )x
+--R             + 
+--R                         10 2             9 2             8 4  4
+--R               (19398656a  c  + 158859264a b c + 95387648a b )x
+--R             + 
+--R                         10               9 3  3
+--R               (60293120a  b c + 82051072a b )x
+--R             + 
+--R                        11             10 2  2            11              12
+--R               (9961472a  c + 45481984a  b )x  + 14680064a  b x + 2097152a
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                      5 8         4 2 7         3 4 6        2 6 5         8 4
+--R               - 2048a c  - 23040a b c  - 26880a b c  - 6720a b c  - 360a b c
+--R             + 
+--R                   10 3
+--R               - 2b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        5   7          4 3 6          3 5 5         2 7 4
+--R               - 116736a b c  - 384000a b c  - 231168a b c  - 34560a b c
+--R             + 
+--R                        9 3     11 2
+--R               - 1160a b c  - 4b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        6 7           5 2 6           4 4 5          3 6 4
+--R               - 126976a c  - 1625088a b c  - 2273280a b c  - 749952a b c
+--R             + 
+--R                       2 8 3          10 2     12
+--R               - 65520a b c  - 1244a b  c  - 2b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         6   6           5 3 5           4 5 4           3 7 3
+--R               - 2605056a b c  - 9395200a b c  - 6423552a b c  - 1162368a b c
+--R             + 
+--R                       2 9 2         11
+--R               - 54400a b c  - 444a b  c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         7 6            6 2 5            5 4 4           4 6 3
+--R               - 1394688a c  - 18516480a b c  - 27060480a b c  - 9400896a b c
+--R             + 
+--R                        3 8 2         2 10
+--R               - 868392a b c  - 16722a b  c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          7   5            6 3 4            5 5 3
+--R               - 17233920a b c  - 61614080a b c  - 40998144a b c
+--R             + 
+--R                         4 7 2          3 9
+--R               - 6880896a b c  - 251768a b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         8 5            7 2 4             6 4 3            5 6 2
+--R               - 6086656a c  - 77291520a b c  - 104555520a b c  - 31251968a b c
+--R             + 
+--R                         4 8
+--R               - 1992672a b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                            8   4             7 3 3            6 5 2
+--R                 - 50233344a b c  - 160604160a b c  - 87619584a b c
+--R               + 
+--R                           5 7
+--R                 - 9444864a b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                            9 4             8 2 3             7 4 2
+--R                 - 13205504a c  - 146251776a b c  - 156887040a b c
+--R               + 
+--R                            6 6
+--R                 - 28747264a b c
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                       9   3             8 3 2            7 5   6
+--R           (- 72712192a b c  - 179912704a b c  - 58251264a b c)x
+--R         + 
+--R                       10 3             9 2 2            8 4   5
+--R           (- 15204352a  c  - 127926272a b c  - 79527936a b c)x
+--R         + 
+--R                       10   2            9 3   4
+--R           (- 51380224a  b c  - 72351744a b c)x
+--R         + 
+--R                    11 2            10 2   3            11     2           12
+--R         (- 8912896a  c  - 42074112a  b c)x  - 14155776a  b c x  - 2097152a  c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                             4   7         3 3 6         2 5 5          7 4
+--R                     - 10240a b c  - 30720a b c  - 16128a b c  - 1920a b c
+--R                   + 
+--R                          9 3
+--R                     - 40b c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                           5 7          4 2 6          3 4 5          2 6 4
+--R                   - 22528a c  - 273920a b c  - 357120a b c  - 106176a b c
+--R                 + 
+--R                            8 3       10 2
+--R                   - 7800a b c  - 102b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                            5   6           4 3 5           3 5 4          2 7 3
+--R                   - 679936a b c  - 2380800a b c  - 1566720a b c  - 269184a b c
+--R                 + 
+--R                             9 2      11
+--R                   - 11680a b c  - 84b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                            6 6           5 2 5           4 4 4           3 6 3
+--R                   - 495616a c  - 6571008a b c  - 9635840a b c  - 3398784a b c
+--R                 + 
+--R                            2 8 2          10       12
+--R                   - 329616a b c  - 7604a b  c - 22b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                             6   5            5 3 4            4 5 3
+--R                   - 7919616a b c  - 29250560a b c  - 20634880a b c
+--R                 + 
+--R                             3 7 2          2 9           11
+--R                   - 3900672a b c  - 195224a b c - 1804a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             7 5            6 2 4            5 4 3
+--R                   - 3446784a c  - 46210560a b c  - 68330240a b c
+--R                 + 
+--R                              4 6 2           3 8          2 10
+--R                   - 24083136a b c  - 2265912a b c - 44726a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                              7   4             6 3 3            5 5 2
+--R                   - 36380672a b c  - 130088960a b c  - 86455296a b c
+--R                 + 
+--R                              4 7           3 9
+--R                   - 14451712a b c - 523424a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              8 4             7 2 3             6 4 2
+--R                   - 11264000a c  - 142041088a b c  - 190202880a b c
+--R                 + 
+--R                              5 6            4 8
+--R                   - 55983616a b c - 3482336a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                              8   3             7 3 2             6 5
+--R                   - 82608128a b c  - 260063232a b c  - 138872832a b c
+--R                 + 
+--R                              5 7
+--R                   - 14510080a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              9 3             8 2 2             7 4
+--R                   - 19824640a c  - 215506944a b c  - 225548288a b c
+--R                 + 
+--R                              6 6
+--R                   - 39950848a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                           9   2             8 3             7 5  6
+--R               (- 99090432a b c  - 238813184a b c - 74678272a b )x
+--R             + 
+--R                           10 2             9 2             8 4  5
+--R               (- 19398656a  c  - 158859264a b c - 95387648a b )x
+--R             + 
+--R                           10               9 3  4
+--R               (- 60293120a  b c - 82051072a b )x
+--R             + 
+--R                        11             10 2  3            11   2           12
+--R             (- 9961472a  c - 45481984a  b )x  - 14680064a  b x  - 2097152a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                    5 8         4 2 7         3 4 6        2 6 5         8 4
+--R               2048a c  + 23040a b c  + 26880a b c  + 6720a b c  + 360a b c
+--R             + 
+--R                 10 3
+--R               2b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                      5   7          4 3 6          3 5 5         2 7 4
+--R               116736a b c  + 384000a b c  + 231168a b c  + 34560a b c
+--R             + 
+--R                      9 3     11 2
+--R               1160a b c  + 4b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                      6 7           5 2 6           4 4 5          3 6 4
+--R               126976a c  + 1625088a b c  + 2273280a b c  + 749952a b c
+--R             + 
+--R                     2 8 3          10 2     12
+--R               65520a b c  + 1244a b  c  + 2b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                       6   6           5 3 5           4 5 4           3 7 3
+--R               2605056a b c  + 9395200a b c  + 6423552a b c  + 1162368a b c
+--R             + 
+--R                     2 9 2         11
+--R               54400a b c  + 444a b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                       7 6            6 2 5            5 4 4           4 6 3
+--R               1394688a c  + 18516480a b c  + 27060480a b c  + 9400896a b c
+--R             + 
+--R                      3 8 2         2 10
+--R               868392a b c  + 16722a b  c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        7   5            6 3 4            5 5 3           4 7 2
+--R               17233920a b c  + 61614080a b c  + 40998144a b c  + 6880896a b c
+--R             + 
+--R                      3 9
+--R               251768a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                       8 5            7 2 4             6 4 3            5 6 2
+--R               6086656a c  + 77291520a b c  + 104555520a b c  + 31251968a b c
+--R             + 
+--R                       4 8
+--R               1992672a b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                     8   4             7 3 3            6 5 2           5 7   9
+--R           (50233344a b c  + 160604160a b c  + 87619584a b c  + 9444864a b c)x
+--R         + 
+--R                     9 4             8 2 3             7 4 2            6 6   8
+--R           (13205504a c  + 146251776a b c  + 156887040a b c  + 28747264a b c)x
+--R         + 
+--R                     9   3             8 3 2            7 5   7
+--R           (72712192a b c  + 179912704a b c  + 58251264a b c)x
+--R         + 
+--R                     10 3             9 2 2            8 4   6
+--R           (15204352a  c  + 127926272a b c  + 79527936a b c)x
+--R         + 
+--R                     10   2            9 3   5
+--R           (51380224a  b c  + 72351744a b c)x
+--R         + 
+--R                  11 2            10 2   4            11     3           12   2
+--R         (8912896a  c  + 42074112a  b c)x  + 14155776a  b c x  + 2097152a  c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                    5 8         4 2 7         3 4 6        2 6 5         8 4
+--R               2048a c  + 23040a b c  + 26880a b c  + 6720a b c  + 360a b c
+--R             + 
+--R                 10 3
+--R               2b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                      5   7          4 3 6          3 5 5         2 7 4
+--R               117760a b c  + 395520a b c  + 244608a b c  + 37920a b c
+--R             + 
+--R                      9 3     11 2
+--R               1340a b c  + 5b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                      6 7           5 2 6           4 4 5          3 6 4
+--R               129024a c  + 1711616a b c  + 2507520a b c  + 880320a b c
+--R             + 
+--R                     2 8 3          10 2     12
+--R               84120a b c  + 1846a b  c  + 4b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                       6   6            5 3 5           4 5 4           3 7 3
+--R               2795520a b c  + 10714624a b c  + 7948800a b c  + 1617600a b c
+--R             + 
+--R                     2 9 2          11     13
+--R               91560a b c  + 1110a b  c + b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                       7 6            6 2 5            5 4 4            4 6 3
+--R               1521664a c  + 21720576a b c  + 34968320a b c  + 13951680a b c
+--R             + 
+--R                       3 8 2         2 10          12
+--R               1609560a b c  + 48806a b  c + 244a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                        7   5            6 3 4            5 5 3            4 7 2
+--R               20720640a b c  + 82602240a b c  + 64164736a b c  + 13773600a b c
+--R             + 
+--R                      3 9          2 11
+--R               825180a b c + 10165a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                       8 5             7 2 4             6 4 3            5 6 2
+--R               7481344a c  + 106990080a b c  + 171183360a b c  + 66651200a b c
+--R             + 
+--R                       4 8           3 10
+--R               7155720a b c + 170610a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        8   4             7 3 3             6 5 2
+--R               71536640a b c  + 273428480a b c  + 197150208a b c
+--R             + 
+--R                        5 7            4 9
+--R               36543232a b c + 1519760a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        9 4             8 2 3             7 4 2             6 6
+--R               19292160a c  + 257720320a b c  + 369699840a b c  + 118410240a b c
+--R             + 
+--R                       5 8
+--R               8204768a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                      9   3             8 3 2             7 5             6 7  8
+--R           (132136960a b c  + 441487360a b c  + 253160448a b c + 28883712a b )x
+--R         + 
+--R                     10 3             9 2 2             8 4             7 6  7
+--R           (28409856a  c  + 325427200a b c  + 362178560a b c + 69076480a b )x
+--R         + 
+--R                      10   2             9 3              8 5  6
+--R           (135004160a  b c  + 343408640a b c + 114442240a b )x
+--R         + 
+--R                     11 2             10 2              9 4  5
+--R           (24117248a  c  + 207224832a  b c + 131563520a b )x
+--R         + 
+--R                     11                10 3  4
+--R           (72089600a  b c + 103088128a  b )x
+--R         + 
+--R                     12             11 2  3            12   2           13
+--R           (11010048a  c + 52559872a  b )x  + 15728640a  b x  + 2097152a  x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                    4   8         3 3 7         2 5 6          7 5      9 4  17
+--R           (- 10240a b c  - 30720a b c  - 16128a b c  - 1920a b c  - 40b c )x
+--R         + 
+--R                       5 8          4 2 7          3 4 6          2 6 5
+--R               - 22528a c  - 279040a b c  - 372480a b c  - 114240a b c
+--R             + 
+--R                        8 4       10 3
+--R               - 8760a b c  - 122b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                        5   7           4 3 6           3 5 5          2 7 4
+--R               - 690176a b c  - 2503680a b c  - 1724160a b c  - 314880a b c
+--R             + 
+--R                         9 3       11 2
+--R               - 14920a b c  - 124b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        6 7           5 2 6            4 4 5           3 6 4
+--R               - 495616a c  - 6847488a b c  - 10572800a b c  - 3987840a b c
+--R             + 
+--R                        2 8 3           10 2      12
+--R               - 424080a b c  - 11244a b  c  - 42b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                         6   6            5 3 5            4 5 4           3 7 3
+--R               - 8103936a b c  - 31585280a b c  - 23847680a b c  - 4930560a b c
+--R             + 
+--R                        2 9 2          11
+--R               - 280040a b c  - 3164a b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         7 6            6 2 5            5 4 4            4 6 3
+--R               - 3446784a c  - 48775680a b c  - 77090560a b c  - 29582400a b c
+--R             + 
+--R                         3 8 2         2 10
+--R               - 3120120a b c  - 72730a b  c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          7   5             6 3 4             5 5 3
+--R               - 37406720a b c  - 142653440a b c  - 102710016a b c
+--R             + 
+--R                          4 7 2          3 9
+--R               - 19043200a b c  - 795080a b c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          8 5             7 2 4             6 4 3
+--R               - 11264000a c  - 151101440a b c  - 218158080a b c
+--R             + 
+--R                          5 6 2           4 8
+--R               - 70584832a b c  - 4972000a b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                          8   4             7 3 3             6 5 2
+--R               - 85196800a b c  - 287907840a b c  - 167718912a b c
+--R             + 
+--R                          5 7
+--R               - 19575296a b c
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                            9 4             8 2 3             7 4 2
+--R                 - 19824640a c  - 230400000a b c  - 261355520a b c
+--R               + 
+--R                            6 6
+--R                 - 51154432a b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                        9   3             8 3 2            7 5   7
+--R           (- 102400000a b c  - 265994240a b c  - 91105280a b c)x
+--R         + 
+--R                       10 3             9 2 2             8 4   6
+--R           (- 19398656a  c  - 170393600a b c  - 111247360a b c)x
+--R         + 
+--R                       10   2            9 3   5
+--R           (- 62390272a  b c  - 91750400a b c)x
+--R         + 
+--R                      11 2            10 2   4            11     3
+--R           (- 9961472a  c  - 48889856a  b c)x  - 15204352a  b c x
+--R         + 
+--R                     12   2
+--R           - 2097152a  c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                             4   5         3 3 4         2 5 3          7 2
+--R                       10240a b c  + 30720a b c  + 16128a b c  + 1920a b c
+--R                     + 
+--R                          9
+--R                       40b c
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                           5 5          4 2 4          3 4 3         2 6 2
+--R                     22528a c  + 253440a b c  + 295680a b c  + 73920a b c
+--R                   + 
+--R                            8       10
+--R                     3960a b c + 22b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                            5   4           4 3 3          3 5 2          2 7
+--R                     614400a b c  + 1802240a b c  + 912384a b c  + 101376a b c
+--R                   + 
+--R                            9
+--R                     1760a b
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                            6 4           5 2 3           4 4 2           3 6
+--R                     450560a c  + 4792320a b c  + 5125120a b c  + 1098240a b c
+--R                   + 
+--R                           2 8
+--R                     41184a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                          6   3            5 3 2           4 5           3 7  7
+--R                 (5734400a b c  + 14909440a b c  + 6150144a b c + 439296a b )x
+--R               + 
+--R                          7 3            6 2 2            5 4            4 6  6
+--R                 (2523136a c  + 23224320a b c  + 19568640a b c + 2562560a b )x
+--R               + 
+--R                           7   2            6 3            5 5  5
+--R                 (18350080a b c  + 36700160a b c + 8945664a b )x
+--R               + 
+--R                          8 2            7 2             6 4  4
+--R                 (5767168a c  + 40108032a b c + 19496960a b )x
+--R               + 
+--R                           8               7 3  3
+--R                 (23592960a b c + 26738688a b )x
+--R               + 
+--R                          9             8 2  2            9              10
+--R                 (5767168a c + 22413312a b )x  + 10485760a b x + 2097152a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                        5 6         4 2 5         3 4 4        2 6 3         8 2
+--R                 - 2048a c  - 23040a b c  - 26880a b c  - 6720a b c  - 360a b c
+--R               + 
+--R                     10
+--R                 - 2b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                          5   5          4 3 4          3 5 3         2 7 2
+--R                 - 112640a b c  - 337920a b c  - 177408a b c  - 21120a b c
+--R               + 
+--R                         9
+--R                 - 440a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          6 5           5 2 4           4 4 3          3 6 2
+--R                 - 122880a c  - 1351680a b c  - 1520640a b c  - 354816a b c
+--R               + 
+--R                         2 8
+--R                 - 15840a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                        6   4           5 3 3           4 5 2          3 7   8
+--R             (- 2129920a b c  - 5857280a b c  - 2635776a b c  - 219648a b c)x
+--R           + 
+--R                        7 4            6 2 3            5 4 2           4 6   7
+--R             (- 1146880a c  - 11182080a b c  - 10250240a b c  - 1537536a b c)x
+--R           + 
+--R                         7   3            6 3 2           5 5   6
+--R             (- 10321920a b c  - 22364160a b c  - 6150144a b c)x
+--R           + 
+--R                        8 3            7 2 2            6 4   5
+--R             (- 3670016a c  - 27525120a b c  - 14909440a b c)x
+--R           + 
+--R                         8   2            7 3   4
+--R             (- 17825792a b c  - 22282240a b c)x
+--R           + 
+--R                      9 2            8 2   3           9     2           10
+--R           (- 4718592a c  - 20054016a b c)x  - 9961472a b c x  - 2097152a  c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                        5 6         4 2 5         3 4 4        2 6 3         8 2
+--R                 - 2048a c  - 23040a b c  - 26880a b c  - 6720a b c  - 360a b c
+--R               + 
+--R                     10
+--R                 - 2b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          5   5          4 3 4          3 5 3         2 7 2
+--R                 - 113664a b c  - 349440a b c  - 190848a b c  - 24480a b c
+--R               + 
+--R                         9     11
+--R                 - 620a b c - b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                          6 5           5 2 4           4 4 3          3 6 2
+--R                 - 124928a c  - 1436160a b c  - 1731840a b c  - 458304a b c
+--R               + 
+--R                         2 8          10
+--R                 - 27720a b c - 242a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           6   4           5 3 3           4 5 2          3 7
+--R                 - 2314240a b c  - 6983680a b c  - 3700224a b c  - 447744a b c
+--R               + 
+--R                        2 9
+--R                 - 9680a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                           7 4            6 2 3            5 4 2           4 6
+--R                 - 1269760a c  - 13844480a b c  - 15375360a b c  - 3514368a b c
+--R               + 
+--R                          3 8
+--R                 - 151008a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                         7   3            6 3 2            5 5            4 7  7
+--R             (- 13189120a b c  - 35409920a b c  - 15375360a b c - 1208064a b )x
+--R           + 
+--R                        8 3            7 2 2            6 4            5 6  6
+--R             (- 4816896a c  - 45588480a b c  - 40069120a b c - 5637632a b )x
+--R           + 
+--R                         8   2            7 3             6 5  5
+--R             (- 30670848a b c  - 63569920a b c - 16400384a b )x
+--R           + 
+--R                        9 2            8 2             7 4  4
+--R             (- 8388608a c  - 60162048a b c - 30638080a b )x
+--R           + 
+--R                         9               8 3  3
+--R             (- 31195136a b c - 36765696a b )x
+--R           + 
+--R                        10             9 2  2            10              11
+--R             (- 6815744a  c - 27394048a b )x  - 11534336a  b x - 2097152a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                    4   6         3 3 5         2 5 4          7 3      9 2  12
+--R             (10240a b c  + 30720a b c  + 16128a b c  + 1920a b c  + 40b c )x
+--R           + 
+--R                       5 6          4 2 5          3 4 4         2 6 3
+--R                 22528a c  + 258560a b c  + 311040a b c  + 81984a b c
+--R               + 
+--R                        8 2      10
+--R                 4920a b c  + 42b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                        5   5           4 3 4           3 5 3          2 7 2
+--R                 624640a b c  + 1914880a b c  + 1039104a b c  + 130944a b c
+--R               + 
+--R                        9
+--R                 3080a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                        6 5           5 2 4           4 4 3           3 6 2
+--R                 450560a c  + 5038080a b c  + 5800960a b c  + 1402368a b c
+--R               + 
+--R                       2 8
+--R                 66528a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                      6   4            5 3 3           4 5 2          3 7   8
+--R             (5898240a b c  + 16506880a b c  + 7614464a b c  + 658944a b c)x
+--R           + 
+--R                      7 4            6 2 3            5 4 2           4 6   7
+--R             (2523136a c  + 24944640a b c  + 23296000a b c  + 3587584a b c)x
+--R           + 
+--R                       7   3            6 3 2            5 5   6
+--R             (19038208a b c  + 41861120a b c  + 11741184a b c)x
+--R           + 
+--R                      8 3            7 2 2            6 4   5
+--R             (5767168a c  + 43778048a b c  + 24084480a b c)x
+--R           + 
+--R                       8   2            7 3   4
+--R             (24641536a b c  + 31195136a b c)x
+--R           + 
+--R                      9 2            8 2   3            9     2           10
+--R             (5767168a c  + 24772608a b c)x  + 11010048a b c x  + 2097152a  c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    4 4       3 2 3       2 4 2        6      8  5
+--R               (768a c  + 768a b c  - 480a b c  + 48a b c + 3b )x
+--R             + 
+--R                     4   3        3 3 2       2 5         7  4
+--R               (6144a b c  - 1536a b c  - 384a b c + 96a b )x
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6  3
+--R               (6144a c  + 4608a b c  - 3456a b c + 480a b )x
+--R             + 
+--R                      5   2        4 3        3 5  2
+--R               (12288a b c  - 6144a b c + 768a b )x
+--R             + 
+--R                     6 2        5 2        4 4
+--R               (6144a c  - 3072a b c + 384a b )x
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b x + a
+--R         + 
+--R                       3   4       2 3 3        5 2      7   6
+--R               (- 1536a b c  + 384a b c  + 96a b c  - 24b c)x
+--R             + 
+--R                       4 4        3 2 3        2 4 2         6       8  5
+--R               (- 3072a c  - 3840a b c  + 2112a b c  - 144a b c - 24b )x
+--R             + 
+--R                        4   3        3 3 2        2 5          7  4
+--R               (- 13824a b c  + 2688a b c  + 1248a b c - 264a b )x
+--R             + 
+--R                       5 3        4 2 2        3 4        2 6  3
+--R               (- 9216a c  - 8448a b c  + 5952a b c - 816a b )x
+--R             + 
+--R                        5   2        4 3        3 5  2
+--R               (- 15360a b c  + 7680a b c - 960a b )x
+--R             + 
+--R                       6 2        5 2        4 4
+--R               (- 6144a c  + 3072a b c - 384a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                     3   3       2 3 2         5       7  3
+--R               (3072a b c  - 768a b c  - 192a b c + 48b )x
+--R             + 
+--R                     4 3        3 2 2        2 4          6  2
+--R               (6144a c  + 4608a b c  - 3456a b c + 480a b )x
+--R             + 
+--R                      4   2        3 3         2 5           5 2        4 2
+--R               (18432a b c  - 9216a b c + 1152a b )x + 12288a c  - 6144a b c
+--R             + 
+--R                   3 4
+--R               768a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                       4 4        3 2 3       2 4 2        6      8  4
+--R               (- 1536a c  - 1536a b c  + 960a b c  - 96a b c - 6b )x
+--R             + 
+--R                        4   3        3 3 2       2 5          7  3
+--R               (- 12288a b c  + 3072a b c  + 768a b c - 192a b )x
+--R             + 
+--R                        5 3        4 2 2        3 4        2 6  2
+--R               (- 12288a c  - 9216a b c  + 6912a b c - 960a b )x
+--R             + 
+--R                        5   2         4 3         3 5           6 2        5 2
+--R               (- 24576a b c  + 12288a b c - 1536a b )x - 12288a c  + 6144a b c
+--R             + 
+--R                     4 4
+--R               - 768a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                      2 5         2 4      4 3  7
+--R               (- 512a c  - 768a b c  - 32b c )x
+--R             + 
+--R                       2   4          3 3      5 2  6
+--R               (- 4864a b c  - 2176a b c  - 48b c )x
+--R             + 
+--R                       3 4         2 2 3          4 2     6   5
+--R               (- 5376a c  - 13248a b c  - 1712a b c  - 4b c)x
+--R             + 
+--R                        3   3         2 3 2        5      7  4
+--R               (- 25216a b c  - 11616a b c  - 24a b c + 6b )x
+--R             + 
+--R                        4 3         3 2 2        2 4          6  3
+--R               (- 14336a c  - 29440a b c  - 1024a b c + 144a b )x
+--R             + 
+--R                        4   2        3 3        2 5  2
+--R               (- 29184a b c  - 3840a b c + 480a b )x
+--R             + 
+--R                        5 2        4 2        3 4
+--R               (- 10240a c  - 3072a b c + 384a b )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                         5       3 4  8         2 5          2 4       4 3  7
+--R               (1024a b c  + 256b c )x  + (2048a c  + 5120a b c  + 640b c )x
+--R             + 
+--R                      2   4          3 3       5 2  6
+--R               (14848a b c  + 8960a b c  + 416b c )x
+--R             + 
+--R                      3 4         2 2 3          4 2      6   5
+--R               (11264a c  + 33024a b c  + 5440a b c  - 16b c)x
+--R             + 
+--R                      3   3         2 3 2         5       7  4
+--R               (44416a b c  + 24480a b c  + 104a b c - 42b )x
+--R             + 
+--R                      4 3         3 2 2        2 4          6  3
+--R               (19456a c  + 44288a b c  + 2368a b c - 336a b )x
+--R             + 
+--R                      4   2        3 3        2 5  2
+--R               (34304a b c  + 5376a b c - 672a b )x
+--R             + 
+--R                      5 2        4 2        3 4
+--R               (10240a c  + 3072a b c - 384a b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                       5       3 4  9           2 5          2 4       4 3  8
+--R           (- 1024a b c  - 256b c )x  + (- 2048a c  - 5120a b c  - 640b c )x
+--R         + 
+--R                    2   4          3 3       5 2  7
+--R           (- 14848a b c  - 8960a b c  - 416b c )x
+--R         + 
+--R                    3 4         2 2 3          4 2      6   6
+--R           (- 11264a c  - 33024a b c  - 5440a b c  + 16b c)x
+--R         + 
+--R                    3   3         2 3 2      7  5
+--R           (- 45056a b c  - 25344a b c  + 48b )x
+--R         + 
+--R                    4 3         3 2 2        2 4          6  4
+--R           (- 19456a c  - 49408a b c  - 2880a b c + 528a b )x
+--R         + 
+--R                    4   2         3 3         2 5  3
+--R           (- 39424a b c  - 11008a b c + 1632a b )x
+--R         + 
+--R                    5 2         4 2         3 4  2           5          4 3
+--R           (- 10240a c  - 13312a b c + 1920a b )x  + (- 5120a b c + 768a b )x
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                2 6         2 5      4 4  10
+--R           (512a c  + 768a b c  + 32b c )x
+--R         + 
+--R                 2   5          3 4      5 3  9
+--R           (5376a b c  + 2944a b c  + 80b c )x
+--R         + 
+--R                 3 5         2 2 4          4 3      6 2  8
+--R           (5888a c  + 18880a b c  + 3920a b c  + 52b c )x
+--R         + 
+--R                  3   4         2 3 3          5 2     7   7
+--R           (35456a b c  + 27040a b c  + 1784a b c  - 2b c)x
+--R         + 
+--R                  4 4         3 2 3         2 4 2         6      8  6
+--R           (19712a c  + 69184a b c  + 14480a b c  - 164a b c - 6b )x
+--R         + 
+--R                  4   3         3 3 2       2 5          7  5
+--R           (71296a b c  + 48992a b c  + 216a b c - 198a b )x
+--R         + 
+--R                  5 3         4 2 2        3 4         2 6  4
+--R           (24576a c  + 73216a b c  + 6272a b c - 1152a b )x
+--R         + 
+--R                  5   2         4 3         3 5  3
+--R           (47104a b c  + 16640a b c - 2496a b )x
+--R         + 
+--R                  6 2         5 2         4 4  2         6          5 3
+--R           (10240a c  + 15872a b c - 2304a b )x  + (5120a b c - 768a b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                       3        3 2  3         2 3           2 2  2
+--R             (4096a b c  + 1024b c )x  + (8192a c  + 10240a b c )x
+--R           + 
+--R                   2   2          3 2
+--R             24576a b c x + 16384a c
+--R        *
+--R                          +--------------+
+--R            +---+ +-+ +-+ |   2
+--R           \|- c \|a \|c \|c x  + b x + a
+--R       + 
+--R                     2 4          2 3       4 2  4
+--R             (- 2048a c  - 3072a b c  - 128b c )x
+--R           + 
+--R                      2   3          3 2  3            3 3         2 2 2  2
+--R             (- 16384a b c  - 4096a b c )x  + (- 16384a c  - 20480a b c )x
+--R           + 
+--R                     3   2          4 2
+--R             - 32768a b c x - 16384a c
+--R        *
+--R            +---+ +-+
+--R           \|- c \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                       3   5        2 3 4         5 3      7 2  11
+--R               (- 1024a b c  - 1792a b c  - 448a b c  - 16b c )x
+--R             + 
+--R                       4 5         3 2 4         2 4 3          6 2      8   10
+--R               (- 2048a c  - 15872a b c  - 11648a b c  - 1568a b c  - 32b c)x
+--R             + 
+--R                        4   4         3 3 3         2 5 2          7       9  9
+--R               (- 36864a b c  - 78336a b c  - 26880a b c  - 1824a b c - 16b )x
+--R             + 
+--R                           5 4          4 2 3          3 4 2         2 6
+--R                   - 24576a c  - 205824a b c  - 167936a b c  - 26432a b c
+--R                 + 
+--R                           8
+--R                   - 704a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                         5   3          4 3 2          3 5         2 7  7
+--R               (- 230400a b c  - 490240a b c  - 163264a b c - 9424a b )x
+--R             + 
+--R                        6 3          5 2 2          4 4          3 6  6
+--R               (- 92160a c  - 726528a b c  - 522624a b c - 59040a b )x
+--R             + 
+--R                         6   2          5 3           4 5  5
+--R               (- 530432a b c  - 939008a b c - 205184a b )x
+--R             + 
+--R                         7 2          6 2           5 4  4
+--R               (- 151552a c  - 956416a b c - 427264a b )x
+--R             + 
+--R                         7             6 3  3             8           7 2  2
+--R               (- 516096a b c - 546816a b )x  + (- 114688a c - 421888a b )x
+--R             + 
+--R                        8            9
+--R               - 180224a b x - 32768a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                4 6        3 2 5        2 4 4         6 3    8 2  12
+--R           (256a c  + 1792a b c  + 1120a b c  + 112a b c  + b c )x
+--R         + 
+--R                 4   5         3 3 4        2 5 3         7 2     9   11
+--R           (8704a b c  + 17920a b c  + 5824a b c  + 352a b c  + 2b c)x
+--R         + 
+--R                      5 5         4 2 4         3 4 3         2 6 2         8
+--R                 8704a c  + 75520a b c  + 64960a b c  + 11200a b c  + 370a b c
+--R               + 
+--R                  10
+--R                 b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                   5   4          4 3 3          3 5 2        2 7          9  9
+--R           (115200a b c  + 273920a b c  + 109760a b c  + 9440a b c + 130a b )x
+--R         + 
+--R                  6 4          5 2 3          4 4 2         3 6         2 8  8
+--R           (57600a c  + 526080a b c  + 479840a b c  + 87920a b c + 2945a b )x
+--R         + 
+--R                   6   3           5 3 2          4 5          3 7  7
+--R           (466944a b c  + 1083392a b c  + 402944a b c + 27008a b )x
+--R         + 
+--R                   7 3           6 2 2           5 4           4 6  6
+--R           (155648a c  + 1316864a b c  + 1032704a b c + 130176a b )x
+--R         + 
+--R                   7   2           6 3           5 5  5
+--R           (819200a b c  + 1556480a b c + 370688a b )x
+--R         + 
+--R                   8 2           7 2           6 4  4
+--R           (204800a c  + 1372160a b c + 657920a b )x
+--R         + 
+--R                   8             7 3  3           9           8 2  2
+--R           (655360a b c + 737280a b )x  + (131072a c + 507904a b )x
+--R         + 
+--R                  9            10
+--R           196608a b x + 32768a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  4 6        3 2 5        2 4 4         6 3    8 2  13
+--R           (- 256a c  - 1792a b c  - 1120a b c  - 112a b c  - b c )x
+--R         + 
+--R                   4   5         3 3 4        2 5 3         7 2     9   12
+--R           (- 8704a b c  - 17920a b c  - 5824a b c  - 352a b c  - 2b c)x
+--R         + 
+--R                      5 5         4 2 4         3 4 3         2 6 2         8
+--R               - 8704a c  - 75520a b c  - 64960a b c  - 11200a b c  - 370a b c
+--R             + 
+--R                  10
+--R               - b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          5   4          4 3 3          3 5 2        2 7
+--R                 - 115200a b c  - 273920a b c  - 109760a b c  - 9440a b c
+--R               + 
+--R                         9
+--R                 - 130a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                    6 4          5 2 3          4 4 2         3 6         2 8  9
+--R           (- 57600a c  - 526080a b c  - 479840a b c  - 87920a b c - 2945a b )x
+--R         + 
+--R                     6   3           5 3 2          4 5          3 7  8
+--R           (- 466944a b c  - 1083392a b c  - 402944a b c - 27008a b )x
+--R         + 
+--R                     7 3           6 2 2           5 4           4 6  7
+--R           (- 155648a c  - 1316864a b c  - 1032704a b c - 130176a b )x
+--R         + 
+--R                     7   2           6 3           5 5  6
+--R           (- 819200a b c  - 1556480a b c - 370688a b )x
+--R         + 
+--R                     8 2           7 2           6 4  5
+--R           (- 204800a c  - 1372160a b c - 657920a b )x
+--R         + 
+--R                     8             7 3  4             9           8 2  3
+--R           (- 655360a b c - 737280a b )x  + (- 131072a c - 507904a b )x
+--R         + 
+--R                    9   2         10
+--R           - 196608a b x  - 32768a  x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 3   6        2 3 5         5 4      7 3  14
+--R           (1024a b c  + 1792a b c  + 448a b c  + 16b c )x
+--R         + 
+--R                 4 6         3 2 5         2 4 4          6 3      8 2  13
+--R           (2048a c  + 16896a b c  + 13440a b c  + 2016a b c  + 48b c )x
+--R         + 
+--R                  4   5         3 3 4         2 5 3          7 2      9   12
+--R           (39936a b c  + 96000a b c  + 38976a b c  + 3408a b c  + 48b c)x
+--R         + 
+--R                     5 5          4 2 4          3 4 3         2 6 2          8
+--R               26624a c  + 258560a b c  + 257920a b c  + 54880a b c  + 2560a b c
+--R             + 
+--R                  10
+--R               16b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                     5   4          4 3 3          3 5 2         2 7          9
+--R             (291840a b c  + 774400a b c  + 358080a b c  + 37680a b c + 720a b )
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                      6 4           5 2 3           4 4 2          3 6
+--R               116736a c  + 1162752a b c  + 1180800a b c  + 248736a b c
+--R             + 
+--R                     2 8
+--R               10128a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                   6   3           5 3 2          4 5          3 7  8
+--R           (852992a b c  + 2155776a b c  + 891072a b c + 68464a b )x
+--R         + 
+--R                   7 3           6 2 2           5 4           4 6  7
+--R           (243712a c  + 2213376a b c  + 1888896a b c + 264224a b )x
+--R         + 
+--R                    7   2           6 3           5 5  6
+--R           (1198080a b c  + 2442240a b c + 632448a b )x
+--R         + 
+--R                   8 2           7 2           6 4  5
+--R           (266240a c  + 1894400a b c + 974080a b )x
+--R         + 
+--R                   8             7 3  4           9           8 2  3
+--R           (811008a b c + 968704a b )x  + (147456a c + 602112a b )x
+--R         + 
+--R                  9   2         10
+--R           212992a b x  + 32768a  x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  4 4        3 2 3        2 4 2         6     8  8
+--R             (256a c  + 1792a b c  + 1120a b c  + 112a b c + b )x
+--R           + 
+--R                   4   3         3 3 2        2 5          7  7
+--R             (8192a b c  + 14336a b c  + 3584a b c + 128a b )x
+--R           + 
+--R                   5 3         4 2 2         3 4         2 6  6
+--R             (8192a c  + 55296a b c  + 32256a b c + 2688a b )x
+--R           + 
+--R                    5   2          4 3          3 5  5
+--R             (81920a b c  + 122880a b c + 21504a b )x
+--R           + 
+--R                    6 2          5 2          4 4  4
+--R             (40960a c  + 225280a b c + 84480a b )x
+--R           + 
+--R                     6             5 3  3          7           6 2  2
+--R             (196608a b c + 180224a b )x  + (65536a c + 212992a b )x
+--R           + 
+--R                    7            8
+--R             131072a b x + 32768a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                     3   4        2 3 3         5 2      7   9
+--R             (- 1024a b c  - 1792a b c  - 448a b c  - 16b c)x
+--R           + 
+--R                     4 4         3 2 3        2 4 2          6       8  8
+--R             (- 2048a c  - 14848a b c  - 9856a b c  - 1120a b c - 16b )x
+--R           + 
+--R                      4   3         3 3 2         2 5          7  7
+--R             (- 33792a b c  - 61696a b c  - 16576a b c - 688a b )x
+--R           + 
+--R                      5 3          4 2 2         3 4         2 6  6
+--R             (- 22528a c  - 157184a b c  - 96384a b c - 8736a b )x
+--R           + 
+--R                       5   2          4 3          3 5  5
+--R             (- 174080a b c  - 271360a b c - 50304a b )x
+--R           + 
+--R                      6 2          5 2           4 4  4
+--R             (- 69632a c  - 395264a b c - 154880a b )x
+--R           + 
+--R                       6             5 3  3            7           6 2  2
+--R             (- 286720a b c - 272384a b )x  + (- 81920a c - 274432a b )x
+--R           + 
+--R                      7            8
+--R             - 147456a b x - 32768a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 266
+
+)clear all
+
+--S 267 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^4
+--R 
+--R
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R   (1)  -------------------------------------
+--R                           2
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 704
+r0:=1/3*(a*x^2+b*x^3+c*x^4)^(3/2)/x^3-a^(3/2)*x*atanh(1/2*(2*a+b*x)/_
+   (sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/sqrt(a*x^2+b*x^3+c*x^4)-_
+   1/16*b*(b^2-12*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(c^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))+1/8*(b^2+8*a*c+_
+   2*b*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/(c*x)
+--R 
+--R
+--R   (2)
+--R                         +--------------+
+--R                 +-+ +-+ |   2                        b x + 2a
+--R       - 48a c x\|a \|c \|c x  + b x + a atanh(----------------------)
+--R                                                     +--------------+
+--R                                                 +-+ |   2
+--R                                               2\|a \|c x  + b x + a
+--R     + 
+--R                        +--------------+
+--R                    3   |   2                        2c x + b
+--R       (36a b c - 3b )x\|c x  + b x + a atanh(----------------------)
+--R                                                    +--------------+
+--R                                                +-+ |   2
+--R                                              2\|c \|c x  + b x + a
+--R     + 
+--R              3 5        2 4         2      2   3                3  2
+--R           16c x  + 44b c x  + (80a c  + 34b c)x  + (92a b c + 6b )x
+--R         + 
+--R               2        2
+--R           (64a c + 6a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R             +------------------+
+--R         +-+ |   4      3      2
+--R     48c\|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     3 2       2 2   2        3             4   +-+
+--R               ((384a c  + 288a b c)x  + 1536a b c x + 1536a c)\|c
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                        2   2        3   3           3 2       2 2   2
+--R                 (- 576a b c  - 48a b c)x  + (- 1152a c  - 864a b c)x
+--R               + 
+--R                        3             4
+--R                 - 2304a b c x - 1536a c
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R        *
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a  - b x - 2a
+--R           log(---------------------------------)
+--R                                +-+
+--R                             2x\|a
+--R       + 
+--R                      2   2         3       5  2         2 2         4
+--R                 (288a b c  + 192a b c - 18b )x  + (1152a b c - 96a b )x
+--R               + 
+--R                      3         2 3
+--R                 1152a b c - 96a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                    2 2 2     6  3          3   2       2 3         5  2
+--R             (- 432a b c  + 3b )x  + (- 864a b c  - 576a b c + 54a b )x
+--R           + 
+--R                     3 2        2 4          4         3 3
+--R             (- 1728a b c + 144a b )x - 1152a b c + 96a b
+--R        *
+--R           log
+--R                            2              2  +-+            2           +-+
+--R                    ((4a c x  + 4a b x + 8a )\|c  + (- 2b c x  - 8a c x)\|a )
+--R                 *
+--R                     +--------------+
+--R                     |   2
+--R                    \|c x  + b x + a
+--R                + 
+--R                           3              2  2              2  +-+ +-+       2 3
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x - 8a )\|a \|c  + 4a c x
+--R                + 
+--R                          2     2
+--R                  6a b c x  + 8a c x
+--R             /
+--R                                 +--------------+
+--R                              2  |   2
+--R                  (4a b x + 8a )\|c x  + b x + a
+--R                + 
+--R                              2  2              2  +-+
+--R                  ((- 4a c - b )x  - 8a b x - 8a )\|a
+--R       + 
+--R                        3      3 2  5          2 3         2 2      4   4
+--R             (- 192a b c  - 16b c )x  + (- 384a c  - 624a b c  - 28b c)x
+--R           + 
+--R                     2   2         3      5  3
+--R             (- 2208a b c  - 640a b c - 6b )x
+--R           + 
+--R                     3 2        2 2         4  2           3         2 3
+--R             (- 1536a c  - 2208a b c - 72a b )x  + (- 1920a b c - 96a b )x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                    4      2 3  6            3       3 2  5
+--R             (128a c  + 96b c )x  + (864a b c  + 264b c )x
+--R           + 
+--R                   2 3          2 2       4   4
+--R             (1152a c  + 2160a b c  + 204b c)x
+--R           + 
+--R                   2   2          3       5  3
+--R             (3936a b c  + 1552a b c + 30b )x
+--R           + 
+--R                   3 2        2 2          4  2         3         2 3
+--R             (1536a c  + 3168a b c + 120a b )x  + (1920a b c + 96a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                                                                +--------------+
+--R                 2       2   2                      2   +-+ +-+ |   2
+--R         ((384a c  + 288b c)x  + 1536a b c x + 1536a c)\|a \|c \|c x  + b x + a
+--R       + 
+--R                        2      3   3           2 2         2   2        2
+--R             (- 576a b c  - 48b c)x  + (- 1152a c  - 864a b c)x  - 2304a b c x
+--R           + 
+--R                    3
+--R             - 1536a c
+--R        *
+--R            +-+
+--R           \|c
+--R     ,
+--R
+--R                     3 2       2 2   2       3            4   +---+
+--R               ((192a c  + 144a b c)x  + 768a b c x + 768a c)\|- c
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                        2   2        3   3          3 2       2 2   2
+--R                 (- 288a b c  - 24a b c)x  + (- 576a c  - 432a b c)x
+--R               + 
+--R                        3            4
+--R                 - 1152a b c x - 768a c
+--R            *
+--R                +---+ +-+
+--R               \|- c \|a
+--R        *
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a  - b x - 2a
+--R           log(---------------------------------)
+--R                                +-+
+--R                             2x\|a
+--R       + 
+--R                      2   2         3       5  2         2 2         4
+--R                 (288a b c  + 192a b c - 18b )x  + (1152a b c - 96a b )x
+--R               + 
+--R                      3         2 3
+--R                 1152a b c - 96a b
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                    2 2 2     6  3          3   2       2 3         5  2
+--R             (- 432a b c  + 3b )x  + (- 864a b c  - 576a b c + 54a b )x
+--R           + 
+--R                     3 2        2 4          4         3 3
+--R             (- 1728a b c + 144a b )x - 1152a b c + 96a b
+--R        *
+--R                           +--------------+
+--R                 +---+ +-+ |   2                +---+
+--R                \|- c \|a \|c x  + b x + a  - a\|- c
+--R           atan(-------------------------------------)
+--R                                   +-+
+--R                               c x\|a
+--R       + 
+--R                       3     3 2  5          2 3         2 2      4   4
+--R             (- 96a b c  - 8b c )x  + (- 192a c  - 312a b c  - 14b c)x
+--R           + 
+--R                     2   2         3      5  3
+--R             (- 1104a b c  - 320a b c - 3b )x
+--R           + 
+--R                    3 2        2 2         4  2          3         2 3
+--R             (- 768a c  - 1104a b c - 36a b )x  + (- 960a b c - 48a b )x
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                   4      2 3  6            3       3 2  5
+--R             (64a c  + 48b c )x  + (432a b c  + 132b c )x
+--R           + 
+--R                  2 3          2 2       4   4
+--R             (576a c  + 1080a b c  + 102b c)x
+--R           + 
+--R                   2   2         3       5  3        3 2        2 2         4  2
+--R             (1968a b c  + 776a b c + 15b )x  + (768a c  + 1584a b c + 60a b )x
+--R           + 
+--R                  3         2 3
+--R             (960a b c + 48a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                                                +--------------+
+--R                 2       2   2                    2   +---+ +-+ |   2
+--R         ((192a c  + 144b c)x  + 768a b c x + 768a c)\|- c \|a \|c x  + b x + a
+--R       + 
+--R                        2      3   3          2 2         2   2        2
+--R             (- 288a b c  - 24b c)x  + (- 576a c  - 432a b c)x  - 1152a b c x
+--R           + 
+--R                   3
+--R             - 768a c
+--R        *
+--R            +---+
+--R           \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 269
+
+--S 270 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                                +--------------+
+--R                 3 2       2 2   2        3             4   +-+ |   2
+--R           ((384a c  + 288a b c)x  + 1536a b c x + 1536a c)\|c \|c x  + b x + a
+--R         + 
+--R                      2   2        3   3           3 2       2 2   2
+--R               (- 576a b c  - 48a b c)x  + (- 1152a c  - 864a b c)x
+--R             + 
+--R                      3             4
+--R               - 2304a b c x - 1536a c
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                    2   2         3       5  2         2 2         4
+--R               (288a b c  + 192a b c - 18b )x  + (1152a b c - 96a b )x
+--R             + 
+--R                    3         2 3
+--R               1152a b c - 96a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                  2 2 2     6  3          3   2       2 3         5  2
+--R           (- 432a b c  + 3b )x  + (- 864a b c  - 576a b c + 54a b )x
+--R         + 
+--R                   3 2        2 4          4         3 3
+--R           (- 1728a b c + 144a b )x - 1152a b c + 96a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                          2              2  +-+            2           +-+
+--R                  ((4a c x  + 4a b x + 8a )\|c  + (- 2b c x  - 8a c x)\|a )
+--R               *
+--R                   +--------------+
+--R                   |   2
+--R                  \|c x  + b x + a
+--R              + 
+--R                         3              2  2              2  +-+ +-+       2 3
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x - 8a )\|a \|c  + 4a c x
+--R              + 
+--R                        2     2
+--R                6a b c x  + 8a c x
+--R           /
+--R                               +--------------+
+--R                            2  |   2
+--R                (4a b x + 8a )\|c x  + b x + a
+--R              + 
+--R                            2  2              2  +-+
+--R                ((- 4a c - b )x  - 8a b x - 8a )\|a
+--R     + 
+--R                      2   2        3   4           3 2       2 2   3
+--R               (- 576a b c  - 48a b c)x  + (- 1152a c  - 864a b c)x
+--R             + 
+--R                      3     2        4
+--R               - 2304a b c x  - 1536a c x
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                    3 3       2 2 2  5         3   2       2 3   4
+--R               (384a c  + 288a b c )x  + (1920a b c  + 288a b c)x
+--R             + 
+--R                     4 2        3 2   3        4     2        5
+--R               (1920a c  + 1824a b c)x  + 3072a b c x  + 1536a c x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                    2 2 2     6  4        3   2       2 3         5  3
+--R               (432a b c  - 3b )x  + (864a b c  + 576a b c - 54a b )x
+--R             + 
+--R                     3 2        2 4  2         4         3 3
+--R               (1728a b c - 144a b )x  + (1152a b c - 96a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      2   3         3 2      5   5
+--R               (- 288a b c  - 192a b c  + 18b c)x
+--R             + 
+--R                       2 2 2        4       6  4
+--R               (- 1440a b c  - 96a b c + 18b )x
+--R             + 
+--R                       3   2        2 3          5  3
+--R               (- 1440a b c  - 1248a b c + 114a b )x
+--R             + 
+--R                       3 2        2 4  2           4         3 3
+--R               (- 2304a b c + 192a b )x  + (- 1152a b c + 96a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                          3      3 2  5          2 3         2 2      4   4
+--R               (- 192a b c  - 16b c )x  + (- 384a c  - 624a b c  - 28b c)x
+--R             + 
+--R                       2   2         3      5  3
+--R               (- 2208a b c  - 640a b c - 6b )x
+--R             + 
+--R                       3 2        2 2         4  2           3         2 3
+--R               (- 1536a c  - 2208a b c - 72a b )x  + (- 1920a b c - 96a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                      4      2 3  6            3       3 2  5
+--R               (128a c  + 96b c )x  + (864a b c  + 264b c )x
+--R             + 
+--R                     2 3          2 2       4   4
+--R               (1152a c  + 2160a b c  + 204b c)x
+--R             + 
+--R                     2   2          3       5  3
+--R               (3936a b c  + 1552a b c + 30b )x
+--R             + 
+--R                     3 2        2 2          4  2         3         2 3
+--R               (1536a c  + 3168a b c + 120a b )x  + (1920a b c + 96a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                    4      2 3  7              3       3 2  6
+--R           (- 128a c  - 96b c )x  + (- 864a b c  - 264b c )x
+--R         + 
+--R                   2 3          2 2       4   5
+--R           (- 1152a c  - 2160a b c  - 204b c)x
+--R         + 
+--R                   2   2          3       5  4
+--R           (- 4704a b c  - 1688a b c - 36b )x
+--R         + 
+--R                   3 2        2 2          4  3           3          2 3  2
+--R           (- 3072a c  - 4464a b c - 228a b )x  + (- 4992a b c - 384a b )x
+--R         + 
+--R                   4        3 2
+--R           (- 2048a c - 192a b )x
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                    4      3 3  8        2 4         2 3      4 2  7
+--R           (192a b c  + 16b c )x  + (384a c  + 816a b c  + 44b c )x
+--R         + 
+--R                 2   3          3 2      5   6
+--R           (2784a b c  + 1280a b c  + 34b c)x
+--R         + 
+--R                 3 3        2 2 2         4      6  5
+--R           (2432a c  + 5472a b c  + 776a b c + 6b )x
+--R         + 
+--R                 3   2        2 3          5  4
+--R           (8224a b c  + 3568a b c + 114a b )x
+--R         + 
+--R                 4 2        3 2        2 4  3         4          3 3  2
+--R           (4096a c  + 6800a b c + 396a b )x  + (6016a b c + 480a b )x
+--R         + 
+--R                 5        4 2
+--R           (2048a c + 192a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                                                +--------------+
+--R                 2       2   2                      2   +-+ +-+ |   2
+--R         ((384a c  + 288b c)x  + 1536a b c x + 1536a c)\|a \|c \|c x  + b x + a
+--R       + 
+--R                        2      3   3           2 2         2   2        2
+--R             (- 576a b c  - 48b c)x  + (- 1152a c  - 864a b c)x  - 2304a b c x
+--R           + 
+--R                    3
+--R             - 1536a c
+--R        *
+--R            +-+
+--R           \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 270
+
+--S 271 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                               5   7         4 3 6         3 5 5         2 7 4
+--R                       - 22528a b c  - 84480a b c  - 59136a b c  - 10560a b c
+--R                     + 
+--R                               9 3     11 2
+--R                       - 440a b c  - 2b  c
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                               6 7          5 2 6           4 4 5          3 6 4
+--R                       - 49152a c  - 709632a b c  - 1140480a b c  - 443520a b c
+--R                     + 
+--R                               2 8 3          10 2     12
+--R                       - 47520a b c  - 1188a b  c  - 3b  c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                 6   6           5 3 5           4 5 4
+--R                       - 1718272a b c  - 7079424a b c  - 5677056a b c
+--R                     + 
+--R                                 3 7 3         2 9 2          11     13
+--R                       - 1256640a b c  - 77880a b c  - 1038a b  c - b
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                 7 6            6 2 5            5 4 4
+--R                       - 1245184a c  - 18840576a b c  - 32257280a b c
+--R                     + 
+--R                                4 6 3           3 8 2         2 10          12
+--R                     - 13732224a b c  - 1694880a b c  - 54956a b  c - 289a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                  7   5            6 3 4            5 5 3
+--R                       - 22339584a b c  - 93634560a b c  - 76606464a b c
+--R                     + 
+--R                                  4 7 2           3 9          2 11
+--R                       - 17335296a b c  - 1092960a b c - 14016a b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                 8 5             7 2 4             6 4 3
+--R                       - 9682944a c  - 144384000a b c  - 241080320a b c
+--R                     + 
+--R                                  5 6 2            4 8           3 10
+--R                       - 97963008a b c  - 10954944a b c - 269984a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                   8   4             7 3 3             6 5 2
+--R                       - 112394240a b c  - 445276160a b c  - 332666880a b c
+--R                     + 
+--R                                  5 7            4 9
+--R                       - 63771136a b c - 2727296a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                  9 4             8 2 3             7 4 2
+--R                       - 34701312a c  - 478003200a b c  - 706682880a b c
+--R                     + 
+--R                                   6 6             5 8
+--R                       - 232866816a b c - 16528512a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                   9   3             8 3 2             7 5
+--R                       - 275775488a b c  - 945684480a b c  - 555712512a b c
+--R                     + 
+--R                                  6 7
+--R                       - 64749568a b
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                  10 3             9 2 2             8 4
+--R                       - 66060288a  c  - 774111232a b c  - 880148480a b c
+--R                     + 
+--R                                   7 6
+--R                       - 171016192a b
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                10   2             9 3              8 5  5
+--R                   (- 353894400a  b c  - 917372928a b c - 310837248a b )x
+--R                 + 
+--R                               11 2             10 2              9 4  4
+--R                   (- 69206016a  c  - 604766208a  b c - 389742592a b )x
+--R                 + 
+--R                                11                10 3  3
+--R                   (- 228589568a  b c - 331350016a  b )x
+--R                 + 
+--R                               12              11 2  2            12
+--R                   (- 37748736a  c - 182452224a  b )x  - 58720256a  b x
+--R                 + 
+--R                             13
+--R                   - 8388608a
+--R              *
+--R                  +-+ +-+
+--R                 \|a \|c
+--R             + 
+--R                        6 8         5 2 7         4 4 6         3 6 5
+--R                   4096a c  + 56320a b c  + 84480a b c  + 29568a b c
+--R                 + 
+--R                        2 8 4        10 3
+--R                   2640a b c  + 44a b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                          6   7           5 3 6          4 5 5          3 7 4
+--R                   276480a b c  + 1098240a b c  + 836352a b c  + 171072a b c
+--R                 + 
+--R                        2 9 3        11 2
+--R                   9240a b c  + 90a b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                          7 7           6 2 6           5 4 5           4 6 4
+--R                   299008a c  + 4445184a b c  + 7434240a b c  + 3062400a b c
+--R                 + 
+--R                          3 8 3         2 10 2        12
+--R                   359568a b c  + 10692a b  c  + 46a b  c
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                           7   6            6 3 5            5 5 4
+--R                   6998016a b c  + 29120000a b c  + 23606528a b c
+--R                 + 
+--R                           4 7 3          3 9 2        2 11
+--R                   5277888a b c  + 327272a b c  + 4094a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                           8 6            7 2 5            6 4 4
+--R                   3735552a c  + 55848960a b c  + 93634560a b c
+--R                 + 
+--R                            5 6 3           4 8 2          3 10
+--R                   38303232a b c  + 4333824a b c  + 109296a b  c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                            8   5             7 3 4             6 5 3
+--R                   51388416a b c  + 206028800a b c  + 156509184a b c
+--R                 + 
+--R                            5 7 2           4 9
+--R                   30750720a b c  + 1368224a b c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            9 5             8 2 4             7 4 3
+--R                   18120704a c  + 253804544a b c  + 383631360a b c
+--R                 + 
+--R                             6 6 2           5 8
+--R                   130364416a b c  + 9682816a b c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                             9   4             8 3 3             7 5 2
+--R                   163676160a b c  + 575594496a b c  + 349784064a b c
+--R                 + 
+--R                            6 7
+--R                   42711552a b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            10 4             9 2 3             8 4 2
+--R                   42991616a  c  + 517472256a b c  + 609091584a b c
+--R                 + 
+--R                             7 6
+--R                   123977728a b c
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                          10   3             9 3 2             8 5   6
+--R               (255852544a  b c  + 686686208a b c  + 243433472a b c)x
+--R             + 
+--R                         11 3             10 2 2             9 4   5
+--R               (53477376a  c  + 483655680a  b c  + 325582848a b c)x
+--R             + 
+--R                          11   2             10 3   4
+--R               (193462272a  b c  + 292421632a  b c)x
+--R             + 
+--R                         12 2             11 2   3            12     2
+--R               (33554432a  c  + 168820736a  b c)x  + 56623104a  b c x
+--R             + 
+--R                       13
+--R               8388608a  c x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        6 8         5 2 7         4 4 6         3 6 5
+--R                   4096a c  + 56320a b c  + 84480a b c  + 29568a b c
+--R                 + 
+--R                        2 8 4        10 3
+--R                   2640a b c  + 44a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                          6   7           5 3 6          4 5 5          3 7 4
+--R                   278528a b c  + 1126400a b c  + 878592a b c  + 185856a b c
+--R                 + 
+--R                         2 9 3         11 2
+--R                   10560a b c  + 112a b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                          7 7           6 2 6           5 4 5           4 6 4
+--R                   303104a c  + 4651008a b c  + 8110080a b c  + 3539712a b c
+--R                 + 
+--R                          3 8 3         2 10 2        12
+--R                   453024a b c  + 15576a b  c  + 92a b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                           7   6            6 3 5            5 5 4
+--R                   7446528a b c  + 32761856a b c  + 28666880a b c
+--R                 + 
+--R                           4 7 3          3 9 2        2 11         13
+--R                   7172352a b c  + 536096a b c  + 9992a b  c + 24a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                           8 6            7 2 5             6 4 4
+--R                   4034560a c  + 64502784a b c  + 118458880a b c
+--R                 + 
+--R                            5 6 3           4 8 2          3 10         2 12
+--R                   55335808a b c  + 7779024a b c  + 308044a b  c + 2336a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                            8   5             7 3 4             6 5 3
+--R                   60727296a b c  + 269916160a b c  + 237929472a b c
+--R                 + 
+--R                            5 7 2           4 9          3 11
+--R                   59431680a b c  + 4306720a b c + 68664a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                            9 5             8 2 4             7 4 3
+--R                   21856256a c  + 342781952a b c  + 609116160a b c
+--R                 + 
+--R                             6 6 2            5 8           4 10
+--R                   267923968a b c  + 33294976a b c + 954096a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             9   4             8 3 3             7 5 2
+--R                   227098624a b c  + 949075968a b c  + 757413888a b c
+--R                 + 
+--R                             6 7            5 9
+--R                   157973504a b c + 7568704a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            10 4             9 2 3              8 4 2
+--R                   61112320a  c  + 882130944a b c  + 1379868672a b c
+--R                 + 
+--R                             7 6             6 8
+--R                   487660544a b c + 37884288a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             10   3              9 3 2              8 5
+--R                   449314816a  b c  + 1618608128a b c  + 1009614848a b c
+--R                 + 
+--R                             7 7
+--R                   126738432a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            11 3              10 2 2              9 4
+--R                   96468992a  c  + 1180958720a  b c  + 1414266880a b c
+--R                 + 
+--R                             8 6
+--R                   292732928a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          11   2              10 3              9 5  5
+--R               (487587840a  b c  + 1323302912a  b c + 473628672a b )x
+--R             + 
+--R                         12 2             11 2              10 4  4
+--R               (87031808a  c  + 792461312a  b c + 535953408a  b )x
+--R             + 
+--R                          12                11 3  3
+--R               (274726912a  b c + 415760384a  b )x
+--R             + 
+--R                         13              12 2  2            13              14
+--R               (41943040a  c + 210763776a  b )x  + 62914560a  b x + 8388608a
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                           5   8         4 3 7         3 5 6         2 7 5
+--R                   - 22528a b c  - 84480a b c  - 59136a b c  - 10560a b c
+--R                 + 
+--R                           9 4     11 3
+--R                   - 440a b c  - 2b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                           6 8          5 2 7           4 4 6          3 6 5
+--R                   - 49152a c  - 720896a b c  - 1182720a b c  - 473088a b c
+--R                 + 
+--R                           2 8 4          10 3     12 2
+--R                   - 52800a b c  - 1408a b  c  - 4b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                             6   7           5 3 6           4 5 5
+--R                   - 1740800a b c  - 7400448a b c  - 6183936a b c
+--R                 + 
+--R                             3 7 4         2 9 3          11 2     13
+--R                   - 1448832a b c  - 97680a b c  - 1500a b  c  - 2b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                             7 7            6 2 6            5 4 5
+--R                   - 1245184a c  - 19550208a b c  - 35087360a b c
+--R                 + 
+--R                              4 6 4           3 8 3         2 10 2         12
+--R                   - 15899136a b c  - 2141568a b c  - 79376a b  c  - 532a b  c
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                              7   6             6 3 5            5 5 4
+--R                   - 22812672a b c  - 100477440a b c  - 87602944a b c
+--R                 + 
+--R                              4 7 3           3 9 2         2 11
+--R                   - 21586752a b c  - 1537272a b c  - 23938a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             8 6             7 2 5             6 4 4
+--R                   - 9682944a c  - 151818240a b c  - 269916160a b c
+--R                 + 
+--R                               5 6 3            4 8 2          3 10
+--R                   - 118964736a b c  - 14857920a b c  - 430672a b  c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                               8   5             7 3 4             6 5 3
+--R                   - 115367936a b c  - 485826560a b c  - 391971840a b c
+--R                 + 
+--R                              5 7 2           4 9
+--R                   - 83100160a b c  - 4086368a b c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              9 5             8 2 4             7 4 3
+--R                   - 34701312a c  - 507019264a b c  - 806031360a b c
+--R                 + 
+--R                               6 6 2            5 8
+--R                   - 291293184a b c  - 23374208a b c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                               9   4              8 3 3             7 5 2
+--R                   - 284065792a b c  - 1043275776a b c  - 667564032a b c
+--R                 + 
+--R                              6 7
+--R                   - 86787584a b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              10 4             9 2 3              8 4 2
+--R                   - 66060288a  c  - 826015744a b c  - 1016397824a b c
+--R                 + 
+--R                               7 6
+--R                   - 218054656a b c
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            10   3              9 3 2             8 5   6
+--R               (- 365428736a  b c  - 1019740160a b c  - 378241024a b c)x
+--R             + 
+--R                           11 3             10 2 2             9 4   5
+--R               (- 69206016a  c  - 648019968a  b c  - 453902336a b c)x
+--R             + 
+--R                            11   2             10 3   4
+--R               (- 236453888a  b c  - 370278400a  b c)x
+--R             + 
+--R                           12 2             11 2   3            12     2
+--R               (- 37748736a  c  - 196083712a  b c)x  - 60817408a  b c x
+--R             + 
+--R                         13
+--R               - 8388608a  c x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                          6 8         5 2 7         4 4 6         3 6 5
+--R                   - 4096a c  - 56320a b c  - 84480a b c  - 29568a b c
+--R                 + 
+--R                          2 8 4        10 3
+--R                   - 2640a b c  - 44a b  c
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                            6   7           5 3 6          4 5 5          3 7 4
+--R                   - 278528a b c  - 1126400a b c  - 878592a b c  - 185856a b c
+--R                 + 
+--R                           2 9 3         11 2
+--R                   - 10560a b c  - 112a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                            7 7           6 2 6           5 4 5           4 6 4
+--R                   - 303104a c  - 4651008a b c  - 8110080a b c  - 3539712a b c
+--R                 + 
+--R                            3 8 3         2 10 2        12
+--R                   - 453024a b c  - 15576a b  c  - 92a b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                             7   6            6 3 5            5 5 4
+--R                   - 7446528a b c  - 32761856a b c  - 28666880a b c
+--R                 + 
+--R                             4 7 3          3 9 2        2 11         13
+--R                   - 7172352a b c  - 536096a b c  - 9992a b  c - 24a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                             8 6            7 2 5             6 4 4
+--R                   - 4034560a c  - 64502784a b c  - 118458880a b c
+--R                 + 
+--R                              5 6 3           4 8 2          3 10         2 12
+--R                   - 55335808a b c  - 7779024a b c  - 308044a b  c - 2336a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                              8   5             7 3 4             6 5 3
+--R                   - 60727296a b c  - 269916160a b c  - 237929472a b c
+--R                 + 
+--R                              5 7 2           4 9          3 11
+--R                   - 59431680a b c  - 4306720a b c - 68664a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                              9 5             8 2 4             7 4 3
+--R                   - 21856256a c  - 342781952a b c  - 609116160a b c
+--R                 + 
+--R                               6 6 2            5 8           4 10
+--R                   - 267923968a b c  - 33294976a b c - 954096a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                               9   4             8 3 3             7 5 2
+--R                   - 227098624a b c  - 949075968a b c  - 757413888a b c
+--R                 + 
+--R                               6 7            5 9
+--R                   - 157973504a b c - 7568704a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              10 4             9 2 3              8 4 2
+--R                   - 61112320a  c  - 882130944a b c  - 1379868672a b c
+--R                 + 
+--R                               7 6             6 8
+--R                   - 487660544a b c - 37884288a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                               10   3              9 3 2              8 5
+--R                   - 449314816a  b c  - 1618608128a b c  - 1009614848a b c
+--R                 + 
+--R                               7 7
+--R                   - 126738432a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              11 3              10 2 2              9 4
+--R                   - 96468992a  c  - 1180958720a  b c  - 1414266880a b c
+--R                 + 
+--R                               8 6
+--R                   - 292732928a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            11   2              10 3              9 5  6
+--R               (- 487587840a  b c  - 1323302912a  b c - 473628672a b )x
+--R             + 
+--R                           12 2             11 2              10 4  5
+--R               (- 87031808a  c  - 792461312a  b c - 535953408a  b )x
+--R             + 
+--R                            12                11 3  4
+--R               (- 274726912a  b c - 415760384a  b )x
+--R             + 
+--R                         13              12 2  3            13   2           14
+--R             (- 41943040a  c - 210763776a  b )x  - 62914560a  b x  - 8388608a  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                         5   8         4 3 7         3 5 6         2 7 5
+--R                   22528a b c  + 84480a b c  + 59136a b c  + 10560a b c
+--R                 + 
+--R                         9 4     11 3
+--R                   440a b c  + 2b  c
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                         6 8          5 2 7           4 4 6          3 6 5
+--R                   49152a c  + 720896a b c  + 1182720a b c  + 473088a b c
+--R                 + 
+--R                         2 8 4          10 3     12 2
+--R                   52800a b c  + 1408a b  c  + 4b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                           6   7           5 3 6           4 5 5           3 7 4
+--R                   1740800a b c  + 7400448a b c  + 6183936a b c  + 1448832a b c
+--R                 + 
+--R                         2 9 3          11 2     13
+--R                   97680a b c  + 1500a b  c  + 2b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                           7 7            6 2 6            5 4 5
+--R                   1245184a c  + 19550208a b c  + 35087360a b c
+--R                 + 
+--R                            4 6 4           3 8 3         2 10 2         12
+--R                   15899136a b c  + 2141568a b c  + 79376a b  c  + 532a b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                            7   6             6 3 5            5 5 4
+--R                   22812672a b c  + 100477440a b c  + 87602944a b c
+--R                 + 
+--R                            4 7 3           3 9 2         2 11
+--R                   21586752a b c  + 1537272a b c  + 23938a b  c
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                           8 6             7 2 5             6 4 4
+--R                   9682944a c  + 151818240a b c  + 269916160a b c
+--R                 + 
+--R                             5 6 3            4 8 2          3 10
+--R                   118964736a b c  + 14857920a b c  + 430672a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             8   5             7 3 4             6 5 3
+--R                   115367936a b c  + 485826560a b c  + 391971840a b c
+--R                 + 
+--R                            5 7 2           4 9
+--R                   83100160a b c  + 4086368a b c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                            9 5             8 2 4             7 4 3
+--R                   34701312a c  + 507019264a b c  + 806031360a b c
+--R                 + 
+--R                             6 6 2            5 8
+--R                   291293184a b c  + 23374208a b c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             9   4              8 3 3             7 5 2
+--R                   284065792a b c  + 1043275776a b c  + 667564032a b c
+--R                 + 
+--R                            6 7
+--R                   86787584a b c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            10 4             9 2 3              8 4 2
+--R                   66060288a  c  + 826015744a b c  + 1016397824a b c
+--R                 + 
+--R                             7 6
+--R                   218054656a b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          10   3              9 3 2             8 5   7
+--R               (365428736a  b c  + 1019740160a b c  + 378241024a b c)x
+--R             + 
+--R                         11 3             10 2 2             9 4   6
+--R               (69206016a  c  + 648019968a  b c  + 453902336a b c)x
+--R             + 
+--R                          11   2             10 3   5
+--R               (236453888a  b c  + 370278400a  b c)x
+--R             + 
+--R                         12 2             11 2   4            12     3
+--R               (37748736a  c  + 196083712a  b c)x  + 60817408a  b c x
+--R             + 
+--R                       13   2
+--R               8388608a  c x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                     5   8         4 3 7         3 5 6         2 7 5         9 4
+--R               22528a b c  + 84480a b c  + 59136a b c  + 10560a b c  + 440a b c
+--R             + 
+--R                 11 3
+--R               2b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                     6 8          5 2 7           4 4 6          3 6 5
+--R               49152a c  + 732160a b c  + 1224960a b c  + 502656a b c
+--R             + 
+--R                     2 8 4          10 3     12 2
+--R               58080a b c  + 1628a b  c  + 5b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                       6   7           5 3 6           4 5 5           3 7 4
+--R               1789952a b c  + 7873536a b c  + 6876672a b c  + 1710720a b c
+--R             + 
+--R                      2 9 3          11 2     13
+--R               125840a b c  + 2228a b  c  + 4b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                       7 7            6 2 6            5 4 5            4 6 4
+--R               1294336a c  + 21268480a b c  + 40477184a b c  + 19852800a b c
+--R             + 
+--R                       3 8 3          2 10 2          12     14
+--R               2999040a b c  + 134024a b  c  + 1330a b  c + b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        7   6             6 3 5             5 5 4
+--R               25303040a b c  + 119554560a b c  + 114540800a b c
+--R             + 
+--R                        4 7 3           3 9 2         2 11          13
+--R               32324160a b c  + 2865720a b c  + 70010a b  c + 290a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        8 6             7 2 5             6 4 4
+--R               10928128a c  + 185564160a b c  + 366972160a b c
+--R             + 
+--R                         5 6 3            4 8 2           3 10          2 12
+--R               188301696a b c  + 29985120a b c  + 1417900a b  c + 14305a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         8   5             7 3 4             6 5 3
+--R               144416768a b c  + 683294720a b c  + 650353664a b c
+--R             + 
+--R                         5 7 2            4 9           3 11
+--R               179069440a b c  + 14775200a b c + 284000a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        9 5             8 2 4              7 4 3
+--R               44384256a c  + 734781440a b c  + 1393039360a b c
+--R             + 
+--R                         6 6 2            5 8            4 10
+--R               663496704a b c  + 91254592a b c + 2997280a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         9   4              8 3 3              7 5 2
+--R               422871040a b c  + 1868963840a b c  + 1595062272a b c
+--R             + 
+--R                         6 7             5 9
+--R               361387520a b c + 19255808a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         10 4              9 2 3              8 4 2
+--R               100761600a  c  + 1527889920a b c  + 2532515840a b c
+--R             + 
+--R                         7 6             6 8
+--R               959595520a b c + 81278080a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                         10   3              9 3 2              8 5
+--R               695730176a  b c  + 2637168640a b c  + 1746698240a b c
+--R             + 
+--R                         7 7
+--R               235765760a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         11 3              10 2 2              9 4
+--R               135266304a  c  + 1732771840a  b c  + 2187264000a b c
+--R             + 
+--R                         8 6
+--R               481853440a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                      11   2              10 3              9 5  6
+--R           (651689984a  b c  + 1853489152a  b c + 700579840a b )x
+--R         + 
+--R                      12 2              11 2              10 4  5
+--R           (106954752a  c  + 1015808000a  b c + 721092608a  b )x
+--R         + 
+--R                      12                11 3  4
+--R           (325058560a  b c + 513802240a  b )x
+--R         + 
+--R                     13              12 2  3            13   2           14
+--R           (46137344a  c + 241172480a  b )x  + 67108864a  b x  + 8388608a  x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R     + 
+--R                  6 9         5 2 8         4 4 7         3 6 6        2 8 5
+--R           - 4096a c  - 56320a b c  - 84480a b c  - 29568a b c  - 2640a b c
+--R         + 
+--R                  10 4
+--R           - 44a b  c
+--R      *
+--R          18
+--R         x
+--R     + 
+--R                    6   8           5 3 7          4 5 6          3 7 5
+--R           - 280576a b c  - 1154560a b c  - 920832a b c  - 200640a b c
+--R         + 
+--R                   2 9 4         11 3
+--R           - 11880a b c  - 134a b  c
+--R      *
+--R          17
+--R         x
+--R     + 
+--R                    7 8           6 2 7           5 4 6           4 6 5
+--R           - 303104a c  - 4777984a b c  - 8616960a b c  - 3928320a b c
+--R         + 
+--R                    3 8 4         2 10 3         12 2
+--R           - 533280a b c  - 19976a b  c  - 136a b  c
+--R      *
+--R          16
+--R         x
+--R     + 
+--R                     7   7            6 3 6            5 5 5           4 7 4
+--R           - 7573504a b c  - 34663424a b c  - 31877120a b c  - 8511360a b c
+--R         + 
+--R                    3 9 3         2 11 2        13
+--R           - 696080a b c  - 14876a b  c  - 46a b  c
+--R      *
+--R          15
+--R         x
+--R     + 
+--R                     8 7            7 2 6             6 4 5            5 6 4
+--R           - 4034560a c  - 67292160a b c  - 130188800a b c  - 64972160a b c
+--R         + 
+--R                     4 8 3          3 10 2        2 12
+--R           - 9971280a b c  - 447260a b  c  - 4140a b  c
+--R      *
+--R          14
+--R         x
+--R     + 
+--R                      8   6             7 3 5             6 5 4            5 7 3
+--R           - 62121984a b c  - 290997760a b c  - 273750272a b c  - 74331840a b c
+--R         + 
+--R                     4 9 2          3 11
+--R           - 6029320a b c  - 113390a b  c
+--R      *
+--R          13
+--R         x
+--R     + 
+--R                      9 6             8 2 5             7 4 4             6 6 3
+--R           - 21856256a c  - 361041920a b c  - 683294720a b c  - 325176832a b c
+--R         + 
+--R                      5 8 2           4 10
+--R           - 44767360a b c  - 1477520a b  c
+--R      *
+--R          12
+--R         x
+--R     + 
+--R                       9   5              8 3 4             7 5 3
+--R           - 233185280a b c  - 1035427840a b c  - 889924608a b c
+--R         + 
+--R                       6 7 2            5 9
+--R           - 203826688a b c  - 11051040a b c
+--R      *
+--R          11
+--R         x
+--R     + 
+--R                      10 5             9 2 4              8 4 3
+--R           - 61112320a  c  - 934952960a b c  - 1568317440a b c
+--R         + 
+--R                       7 6 2            6 8
+--R           - 604126208a b c  - 52394368a b c
+--R      *
+--R          10
+--R         x
+--R     + 
+--R                       10   4              9 3 3              8 5 2
+--R           - 462520320a  b c  - 1779752960a b c  - 1202309120a b c
+--R         + 
+--R                       7 7
+--R           - 166689280a b c
+--R      *
+--R          9
+--R         x
+--R     + 
+--R                        11 4              10 2 3              9 4 2
+--R             - 96468992a  c  - 1256980480a  b c  - 1621360640a b c
+--R           + 
+--R                         8 6
+--R             - 367411200a b c
+--R      *
+--R          8
+--R         x
+--R     + 
+--R                    11   3              10 3 2             9 5   7
+--R       (- 502792192a  b c  - 1462763520a  b c  - 569016320a b c)x
+--R     + 
+--R                   12 3             11 2 2             10 4   6
+--R       (- 87031808a  c  - 845938688a  b c  - 618004480a  b c)x
+--R     + 
+--R                    12   2             11 3   5
+--R       (- 283639808a  b c  - 461242368a  b c)x
+--R     + 
+--R                 13 2             12 2   4            13     3           14   2
+--R     (- 41943040a  c  - 225443840a  b c)x  - 65011712a  b c x  - 8388608a  c x
+--R  /
+--R                          6 6         5 2 5         4 4 4         3 6 3
+--R                     4096a c  + 56320a b c  + 84480a b c  + 29568a b c
+--R                   + 
+--R                          2 8 2        10
+--R                     2640a b c  + 44a b  c
+--R                *
+--R                    13
+--R                   x
+--R               + 
+--R                            6   5           5 3 4          4 5 3          3 7 2
+--R                     270336a b c  + 1013760a b c  + 709632a b c  + 126720a b c
+--R                   + 
+--R                          2 9         11
+--R                     5280a b c + 24a b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                            7 5           6 2 4           5 4 3           4 6 2
+--R                     294912a c  + 3993600a b c  + 5857280a b c  + 1976832a b c
+--R                   + 
+--R                            3 8         2 10
+--R                     164736a b c + 2288a b
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                             7   4            6 3 3            5 5 2
+--R                     6307840a b c  + 22364160a b c  + 14350336a b c
+--R                   + 
+--R                             4 7          3 9
+--R                     2196480a b c + 64064a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                             8 4            7 2 3            6 4 2
+--R                     3440640a c  + 43008000a b c  + 55910400a b c
+--R                   + 
+--R                              5 6           4 8
+--R                     15375360a b c + 823680a b
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                              8   3             7 3 2            6 5
+--R                     40370176a b c  + 123863040a b c  + 62619648a b c
+--R                   + 
+--R                             5 7
+--R                     5857280a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                              9 3             8 2 2             7 4
+--R                     14680064a c  + 155975680a b c  + 155975680a b c
+--R                   + 
+--R                              6 6
+--R                     25346048a b
+--R                *
+--R                    7
+--R                   x
+--R               + 
+--R                            9   2             8 3             7 5  6
+--R                 (103809024a b c  + 240648192a b c + 70189056a b )x
+--R               + 
+--R                           10 2             9 2              8 4  5
+--R                 (28311552a  c  + 224133120a b c + 127008768a b )x
+--R               + 
+--R                            10                9 3  4
+--R                 (115343360a  b c + 149422080a b )x
+--R               + 
+--R                         11              10 2  3            11   2           12
+--R               (25165824a  c + 110100480a  b )x  + 46137344a  b x  + 8388608a  x
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                             5   6         4 3 5         3 5 4         2 7 3
+--R                     - 22528a b c  - 84480a b c  - 59136a b c  - 10560a b c
+--R                   + 
+--R                             9 2     11
+--R                     - 440a b c  - 2b  c
+--R                *
+--R                    13
+--R                   x
+--R               + 
+--R                             6 6          5 2 5           4 4 4          3 6 3
+--R                     - 49152a c  - 675840a b c  - 1013760a b c  - 354816a b c
+--R                   + 
+--R                             2 8 2         10
+--R                     - 31680a b c  - 528a b  c
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                               6   5           5 3 4           4 5 3
+--R                     - 1597440a b c  - 5857280a b c  - 3953664a b c
+--R                   + 
+--R                              3 7 2         2 9
+--R                     - 658944a b c  - 22880a b c
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                               7 5            6 2 4            5 4 3
+--R                     - 1146880a c  - 14909440a b c  - 20500480a b c
+--R                   + 
+--R                               4 6 2          3 8
+--R                     - 6150144a b c  - 384384a b c
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                                7   4            6 3 3            5 5 2
+--R                     - 17203200a b c  - 55910400a b c  - 30750720a b c
+--R                   + 
+--R                               4 7
+--R                     - 3294720a b c
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                               8 4            7 2 3            6 4 2
+--R                     - 7340032a c  - 82575360a b c  - 89456640a b c
+--R                   + 
+--R                                5 6
+--R                     - 16400384a b c
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                             8   3             7 3 2            6 5   7
+--R                 (- 62390272a b c  - 155975680a b c  - 50692096a b c)x
+--R               + 
+--R                             9 3             8 2 2             7 4   6
+--R                 (- 18874368a c  - 160432128a b c  - 100270080a b c)x
+--R               + 
+--R                             9   2             8 3   5
+--R                 (- 89653248a b c  - 127008768a b c)x
+--R               + 
+--R                             10 2            9 2   4            10     3
+--R                 (- 20971520a  c  - 99614720a b c)x  - 44040192a  b c x
+--R               + 
+--R                           11   2
+--R                 - 8388608a  c x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                         5   6         4 3 5         3 5 4         2 7 3
+--R                 - 22528a b c  - 84480a b c  - 59136a b c  - 10560a b c
+--R               + 
+--R                         9 2     11
+--R                 - 440a b c  - 2b  c
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                         6 6          5 2 5           4 4 4          3 6 3
+--R                 - 49152a c  - 687104a b c  - 1056000a b c  - 384384a b c
+--R               + 
+--R                         2 8 2         10     12
+--R                 - 36960a b c  - 748a b  c - b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                           6   5           5 3 4           4 5 3          3 7 2
+--R                 - 1646592a b c  - 6307840a b c  - 4561920a b c  - 861696a b c
+--R               + 
+--R                         2 9          11
+--R                 - 40480a b c - 288a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           7 5            6 2 4            5 4 3           4 6 2
+--R                 - 1196032a c  - 16506880a b c  - 24893440a b c  - 8785920a b c
+--R               + 
+--R                          3 8          2 10
+--R                 - 796224a b c - 13728a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                            7   4            6 3 3            5 5 2
+--R                 - 19496960a b c  - 70819840a b c  - 47151104a b c
+--R               + 
+--R                           4 7           3 9
+--R                 - 7687680a b c - 256256a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           8 4             7 2 3             6 4 2
+--R                 - 8486912a c  - 108380160a b c  - 145367040a b c
+--R               + 
+--R                            5 6            4 8
+--R                 - 42025984a b c - 2471040a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                            8   3             7 3 2             6 5
+--R                 - 84410368a b c  - 266076160a b c  - 140148736a b c
+--R               + 
+--R                            5 7
+--R                 - 14057472a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                              9 3             8 2 2             7 4
+--R                   - 26214400a c  - 285212672a b c  - 295239680a b c
+--R                 + 
+--R                              6 6
+--R                   - 50692096a b
+--R            *
+--R                7
+--R               x
+--R           + 
+--R                          9   2             8 3              7 5  6
+--R             (- 165150720a b c  - 394395648a b c - 120324096a b )x
+--R           + 
+--R                         10 2             9 2              8 4  5
+--R             (- 39845888a  c  - 323747840a b c - 190513152a b )x
+--R           + 
+--R                          10                9 3  4
+--R             (- 148897792a  b c - 199229440a b )x
+--R           + 
+--R                       11              10 2  3            11   2           12
+--R           (- 29360128a  c - 132120576a  b )x  - 50331648a  b x  - 8388608a  x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R       + 
+--R                  6 7         5 2 6         4 4 5         3 6 4        2 8 3
+--R             4096a c  + 56320a b c  + 84480a b c  + 29568a b c  + 2640a b c
+--R           + 
+--R                  10 2
+--R             44a b  c
+--R        *
+--R            14
+--R           x
+--R       + 
+--R                    6   6           5 3 5          4 5 4          3 7 3
+--R             272384a b c  + 1041920a b c  + 751872a b c  + 141504a b c
+--R           + 
+--R                  2 9 2        11
+--R             6600a b c  + 46a b  c
+--R        *
+--R            13
+--R           x
+--R       + 
+--R                    7 6           6 2 5           5 4 4           4 6 3
+--R             294912a c  + 4116480a b c  + 6307840a b c  + 2280960a b c
+--R           + 
+--R                    3 8 2        2 10
+--R             215424a b c  + 4048a b  c
+--R        *
+--R            12
+--R           x
+--R       + 
+--R                     7   5            6 3 4            5 5 3           4 7 2
+--R             6430720a b c  + 23961600a b c  + 16546816a b c  + 2855424a b c
+--R           + 
+--R                    3 9
+--R             105248a b c
+--R        *
+--R            11
+--R           x
+--R       + 
+--R                     8 5            7 2 4            6 4 3            5 6 2
+--R             3440640a c  + 45301760a b c  + 63365120a b c  + 19475456a b c
+--R           + 
+--R                     4 8
+--R             1262976a b c
+--R        *
+--R            10
+--R           x
+--R       + 
+--R                   8   4             7 3 3            6 5 2           5 7   9
+--R         (41517056a b c  + 136765440a b c  + 76597248a b c  + 8419840a b c)x
+--R       + 
+--R                   9 4             8 2 3             7 4 2            6 6   8
+--R         (14680064a c  + 166985728a b c  + 183500800a b c  + 34291712a b c)x
+--R       + 
+--R                    9   3             8 3 2            7 5   7
+--R         (107479040a b c  + 271843328a b c  + 89686016a b c)x
+--R       + 
+--R                   10 3             9 2 2             8 4   6
+--R         (28311552a  c  + 243007488a b c  + 153747456a b c)x
+--R       + 
+--R                    10   2             9 3   5
+--R         (120061952a  b c  + 171835392a b c)x
+--R       + 
+--R                 11 2             10 2   4            11     3           12   2
+--R       (25165824a  c  + 120586240a  b c)x  + 48234496a  b c x  + 8388608a  c x
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                   3 2       2 2   2        3             4   +---+ +-+
+--R             ((384a c  + 288a b c)x  + 1536a b c x + 1536a c)\|- c \|c
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      2   2        3   3           3 2       2 2   2
+--R               (- 576a b c  - 48a b c)x  + (- 1152a c  - 864a b c)x
+--R             + 
+--R                      3             4
+--R               - 2304a b c x - 1536a c
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                      2   2        3   4           3 2       2 2   3
+--R               (- 576a b c  - 48a b c)x  + (- 1152a c  - 864a b c)x
+--R             + 
+--R                      3     2        4
+--R               - 2304a b c x  - 1536a c x
+--R          *
+--R                            +--------------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|a \|c \|c x  + b x + a
+--R         + 
+--R                    3 3       2 2 2  5         3   2       2 3   4
+--R               (384a c  + 288a b c )x  + (1920a b c  + 288a b c)x
+--R             + 
+--R                     4 2        3 2   3        4     2        5
+--R               (1920a c  + 1824a b c)x  + 3072a b c x  + 1536a c x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                    2 2 2     6  4        3   2       2 3         5  3
+--R               (432a b c  - 3b )x  + (864a b c  + 576a b c - 54a b )x
+--R             + 
+--R                     3 2        2 4  2         4         3 3
+--R               (1728a b c - 144a b )x  + (1152a b c - 96a b )x
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b x + a
+--R         + 
+--R                      2   3         3 2      5   5
+--R               (- 288a b c  - 192a b c  + 18b c)x
+--R             + 
+--R                       2 2 2        4       6  4
+--R               (- 1440a b c  - 96a b c + 18b )x
+--R             + 
+--R                       3   2        2 3          5  3
+--R               (- 1440a b c  - 1248a b c + 114a b )x
+--R             + 
+--R                       3 2        2 4  2           4         3 3
+--R               (- 2304a b c + 192a b )x  + (- 1152a b c + 96a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                    2   2         3       5  2         2 2          4
+--R               (576a b c  + 384a b c - 36b )x  + (2304a b c - 192a b )x
+--R             + 
+--R                    3          2 3
+--R               2304a b c - 192a b
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                      2 2 2     6  3           3   2        2 3          5  2
+--R               (- 864a b c  + 6b )x  + (- 1728a b c  - 1152a b c + 108a b )x
+--R             + 
+--R                       3 2        2 4          4          3 3
+--R               (- 3456a b c + 288a b )x - 2304a b c + 192a b
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                              +--------------+
+--R          +------------------+      +---+ +-+ |   2                +---+
+--R          |   4      3      2      \|- c \|a \|c x  + b x + a  - a\|- c
+--R         \|c x  + b x  + a x  atan(-------------------------------------)
+--R                                                      +-+
+--R                                                  c x\|a
+--R     + 
+--R                          3      3 2  5          2 3         2 2      4   4
+--R               (- 192a b c  - 16b c )x  + (- 384a c  - 624a b c  - 28b c)x
+--R             + 
+--R                       2   2         3      5  3
+--R               (- 2208a b c  - 640a b c - 6b )x
+--R             + 
+--R                       3 2        2 2         4  2           3         2 3
+--R               (- 1536a c  - 2208a b c - 72a b )x  + (- 1920a b c - 96a b )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                      4      2 3  6            3       3 2  5
+--R               (128a c  + 96b c )x  + (864a b c  + 264b c )x
+--R             + 
+--R                     2 3          2 2       4   4
+--R               (1152a c  + 2160a b c  + 204b c)x
+--R             + 
+--R                     2   2          3       5  3
+--R               (3936a b c  + 1552a b c + 30b )x
+--R             + 
+--R                     3 2        2 2          4  2         3         2 3
+--R               (1536a c  + 3168a b c + 120a b )x  + (1920a b c + 96a b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                    4      2 3  7              3       3 2  6
+--R           (- 128a c  - 96b c )x  + (- 864a b c  - 264b c )x
+--R         + 
+--R                   2 3          2 2       4   5
+--R           (- 1152a c  - 2160a b c  - 204b c)x
+--R         + 
+--R                   2   2          3       5  4
+--R           (- 4704a b c  - 1688a b c - 36b )x
+--R         + 
+--R                   3 2        2 2          4  3           3          2 3  2
+--R           (- 3072a c  - 4464a b c - 228a b )x  + (- 4992a b c - 384a b )x
+--R         + 
+--R                   4        3 2
+--R           (- 2048a c - 192a b )x
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                    4      3 3  8        2 4         2 3      4 2  7
+--R           (192a b c  + 16b c )x  + (384a c  + 816a b c  + 44b c )x
+--R         + 
+--R                 2   3          3 2      5   6
+--R           (2784a b c  + 1280a b c  + 34b c)x
+--R         + 
+--R                 3 3        2 2 2         4      6  5
+--R           (2432a c  + 5472a b c  + 776a b c + 6b )x
+--R         + 
+--R                 3   2        2 3          5  4
+--R           (8224a b c  + 3568a b c + 114a b )x
+--R         + 
+--R                 4 2        3 2        2 4  3         4          3 3  2
+--R           (4096a c  + 6800a b c + 396a b )x  + (6016a b c + 480a b )x
+--R         + 
+--R                 5        4 2
+--R           (2048a c + 192a b )x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                   2       2   2                      2   +---+ +-+ +-+
+--R           ((384a c  + 288b c)x  + 1536a b c x + 1536a c)\|- c \|a \|c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                        2      3   3           2 2         2   2        2
+--R             (- 576a b c  - 48b c)x  + (- 1152a c  - 864a b c)x  - 2304a b c x
+--R           + 
+--R                    3
+--R             - 1536a c
+--R        *
+--R            +---+ +-+
+--R           \|- c \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      2   4         3 3      5 2  9
+--R               (- 192a b c  - 160a b c  - 12b c )x
+--R             + 
+--R                      3 4        2 2 3         4 2      6   8
+--R               (- 384a c  - 1728a b c  - 600a b c  - 24b c)x
+--R             + 
+--R                       3   3        2 3 2         5       7  7
+--R               (- 4224a b c  - 4992a b c  - 744a b c - 12b )x
+--R             + 
+--R                       4 3         3 2 2        2 4          6  6
+--R               (- 2816a c  - 14208a b c  - 5808a b c - 304a b )x
+--R             + 
+--R                        4   2         3 3         2 5  5
+--R               (- 16320a b c  - 18720a b c - 2364a b )x
+--R             + 
+--R                       5 2         4 2         3 4  4
+--R               (- 6528a c  - 28992a b c - 8472a b )x
+--R             + 
+--R                        5            4 3  3           6          5 2  2
+--R               (- 21504a b c - 16128a b )x  + (- 6144a c - 16896a b )x
+--R             + 
+--R                      6           7
+--R               - 9216a b x - 2048a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               3 5       2 2 4        4 3    6 2  10
+--R           (64a c  + 240a b c  + 60a b c  + b c )x
+--R         + 
+--R                 3   4        2 3 3         5 2     7   9
+--R           (1280a b c  + 1440a b c  + 192a b c  + 2b c)x
+--R         + 
+--R                 4 4        3 2 3        2 4 2         6     8  8
+--R           (1280a c  + 6880a b c  + 3120a b c  + 206a b c + b )x
+--R         + 
+--R                  4   3         3 3 2        2 5         7  7
+--R           (10880a b c  + 15200a b c  + 2904a b c + 74a b )x
+--R         + 
+--R                 5 3         4 2 2         3 4        2 6  6
+--R           (5440a c  + 30960a b c  + 14860a b c + 985a b )x
+--R         + 
+--R                  5   2         4 3         3 5  5
+--R           (28032a b c  + 36160a b c + 5336a b )x
+--R         + 
+--R                 6 2         5 2          4 4  4          6            5 3  3
+--R           (9344a c  + 45504a b c + 14920a b )x  + (28672a b c + 23552a b )x
+--R         + 
+--R                 7          6 2  2         7           8
+--R           (7168a c + 21248a b )x  + 10240a b x + 2048a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 3 5       2 2 4        4 3    6 2  11
+--R           (- 64a c  - 240a b c  - 60a b c  - b c )x
+--R         + 
+--R                   3   4        2 3 3         5 2     7   10
+--R           (- 1280a b c  - 1440a b c  - 192a b c  - 2b c)x
+--R         + 
+--R                   4 4        3 2 3        2 4 2         6     8  9
+--R           (- 1280a c  - 6880a b c  - 3120a b c  - 206a b c - b )x
+--R         + 
+--R                    4   3         3 3 2        2 5         7  8
+--R           (- 10880a b c  - 15200a b c  - 2904a b c - 74a b )x
+--R         + 
+--R                   5 3         4 2 2         3 4        2 6  7
+--R           (- 5440a c  - 30960a b c  - 14860a b c - 985a b )x
+--R         + 
+--R                    5   2         4 3         3 5  6
+--R           (- 28032a b c  - 36160a b c - 5336a b )x
+--R         + 
+--R                   6 2         5 2          4 4  5
+--R           (- 9344a c  - 45504a b c - 14920a b )x
+--R         + 
+--R                    6            5 3  4           7          6 2  3
+--R           (- 28672a b c - 23552a b )x  + (- 7168a c - 21248a b )x
+--R         + 
+--R                   7   2        8
+--R           - 10240a b x  - 2048a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                2   5         3 4      5 3  12
+--R           (192a b c  + 160a b c  + 12b c )x
+--R         + 
+--R                3 5        2 2 4         4 3      6 2  11
+--R           (384a c  + 1920a b c  + 760a b c  + 36b c )x
+--R         + 
+--R                 3   4        2 3 3          5 2      7   10
+--R           (4800a b c  + 6880a b c  + 1356a b c  + 36b c)x
+--R         + 
+--R                 4 4         3 2 3         2 4 2          6       8  9
+--R           (3200a c  + 20160a b c  + 11400a b c  + 1072a b c + 12b )x
+--R         + 
+--R                  4   3         3 3 2        2 5          7  8
+--R           (23360a b c  + 37920a b c  + 8916a b c + 316a b )x
+--R         + 
+--R                 5 3         4 2 2         3 4         2 6  7
+--R           (9344a c  + 59520a b c  + 33000a b c + 2668a b )x
+--R         + 
+--R                  5   2         4 3          3 5  6
+--R           (44352a b c  + 63840a b c + 10836a b )x
+--R         + 
+--R                  6 2         5 2          4 4  5          6            5 3  4
+--R           (12672a c  + 67392a b c + 24600a b )x  + (36864a b c + 33024a b )x
+--R         + 
+--R                 7          6 2  3         7   2        8
+--R           (8192a c + 26112a b )x  + 11264a b x  + 2048a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 3 3       2 2 2        4     6  7
+--R             (64a c  + 240a b c  + 60a b c + b )x
+--R           + 
+--R                   3   2       2 3         5  6
+--R             (1152a b c  + 960a b c + 72a b )x
+--R           + 
+--R                   4 2        3 2        2 4  5         4           3 3  4
+--R             (1152a c  + 4032a b c + 840a b )x  + (6144a b c + 3584a b )x
+--R           + 
+--R                   5         4 2  3        5   2        6
+--R             (3072a c + 6912a b )x  + 6144a b x  + 2048a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2   3         3 2      5   8
+--R             (- 192a b c  - 160a b c  - 12b c)x
+--R           + 
+--R                    3 3        2 2 2         4       6  7
+--R             (- 384a c  - 1536a b c  - 440a b c - 12b )x
+--R           + 
+--R                     3   2        2 3          5  6
+--R             (- 3648a b c  - 3296a b c - 292a b )x
+--R           + 
+--R                     4 2        3 2         2 4  5            4           3 3  4
+--R             (- 2432a c  - 9024a b c - 2072a b )x  + (- 10240a b c - 6400a b )x
+--R           + 
+--R                     5         4 2  3        5   2        6
+--R             (- 4096a c - 9728a b )x  - 7168a b x  - 2048a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^5
+--R 
+--R
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R   (1)  -------------------------------------
+--R                           3
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 704
+r0:=-(a*x^2+b*x^3+c*x^4)^(3/2)/x^4-3/2*b*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a)*sqrt(a+b*x+c*x^2)/sqrt(a*x^2+b*x^3+c*x^4)+_
+   3/8*(b^2+4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(sqrt(c)*sqrt(a*x^2+b*x^3+c*x^4))+3/4*(3*b+2*c*x)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/x
+--R 
+--R
+--R   (2)
+--R                       +--------------+
+--R               +-+ +-+ |   2                        b x + 2a
+--R       - 12b x\|a \|c \|c x  + b x + a atanh(----------------------)
+--R                                                   +--------------+
+--R                                               +-+ |   2
+--R                                             2\|a \|c x  + b x + a
+--R     + 
+--R                      +--------------+
+--R                  2   |   2                        2c x + b
+--R       (12a c + 3b )x\|c x  + b x + a atanh(----------------------)
+--R                                                  +--------------+
+--R                                              +-+ |   2
+--R                                            2\|c \|c x  + b x + a
+--R     + 
+--R          2 4          3                2  2              2  +-+
+--R       (4c x  + 14b c x  + (- 4a c + 10b )x  + 2a b x - 8a )\|c
+--R  /
+--R           +------------------+
+--R       +-+ |   4      3      2
+--R     8\|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2           3  3       2 2 2       3     +-+ +-+
+--R               ((96a b c + 72a b )x  + 384a b x  + 384a b x)\|a \|c
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                        2 2         4  4          3          2 3  3       3 2 2
+--R                 (- 144a b c - 12a b )x  + (- 288a b c - 216a b )x  - 576a b x
+--R               + 
+--R                       4
+--R                 - 384a b x
+--R            *
+--R                +-+
+--R               \|c
+--R        *
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a  - b x - 2a
+--R           log(---------------------------------)
+--R                                +-+
+--R                             2x\|a
+--R       + 
+--R                     3 2      2 2         4  3        3         2 3  2
+--R                 (96a c  + 96a b c + 18a b )x  + (384a b c + 96a b )x
+--R               + 
+--R                      4       3 2
+--R                 (384a c + 96a b )x
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                        2   2        3      5  4
+--R                 (- 144a b c  - 48a b c - 3b )x
+--R               + 
+--R                        3 2       2 2         4  3          3          2 3  2
+--R                 (- 288a c  - 288a b c - 54a b )x  + (- 576a b c - 144a b )x
+--R               + 
+--R                        4       3 2
+--R                 (- 384a c - 96a b )x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R           log
+--R                            2              2  +-+            2           +-+
+--R                    ((4a c x  + 4a b x + 8a )\|c  + (- 2b c x  - 8a c x)\|a )
+--R                 *
+--R                     +--------------+
+--R                     |   2
+--R                    \|c x  + b x + a
+--R                + 
+--R                           3              2  2              2  +-+ +-+       2 3
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x - 8a )\|a \|c  + 4a c x
+--R                + 
+--R                          2     2
+--R                  6a b c x  + 8a c x
+--R             /
+--R                                 +--------------+
+--R                              2  |   2
+--R                  (4a b x + 8a )\|c x  + b x + a
+--R                + 
+--R                              2  2              2  +-+
+--R                  ((- 4a c - b )x  - 8a b x - 8a )\|a
+--R       + 
+--R                       2     3   5         2 2         2       4  4
+--R             (- 48a b c  - 4b c)x  + (- 96a c  - 192a b c - 10b )x
+--R           + 
+--R                    2            3  3       3       2 2  2       3          4
+--R             (- 272a b c - 124a b )x  + (64a c - 80a b )x  + 320a b x + 256a
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                 2 3        2 2  6        2   2        3   5
+--R             (32a c  + 24a b c )x  + (240a b c  + 84a b c)x
+--R           + 
+--R                 3 2       2 2         4  4        3          2 3  3
+--R             (96a c  + 408a b c + 52a b )x  + (144a b c + 188a b )x
+--R           + 
+--R                    4       3 2  2       4          5
+--R             (- 192a c - 48a b )x  - 448a b x - 256a
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                                                       +--------------+
+--R              2         2  3       2   2       3   +-+ |   2
+--R         ((64a c + 48a b )x  + 256a b x  + 256a x)\|c \|c x  + b x + a
+--R       + 
+--R                           3  4          2          2  3       2   2       3
+--R           ((- 96a b c - 8b )x  + (- 192a c - 144a b )x  - 384a b x  - 256a x)
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R     ,
+--R
+--R                    2           3  3       2 2 2       3     +---+ +-+
+--R               ((48a b c + 36a b )x  + 192a b x  + 192a b x)\|- c \|a
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                       2 2        4  4          3          2 3  3       3 2 2
+--R                 (- 72a b c - 6a b )x  + (- 144a b c - 108a b )x  - 288a b x
+--R               + 
+--R                       4
+--R                 - 192a b x
+--R            *
+--R                +---+
+--R               \|- c
+--R        *
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a  - b x - 2a
+--R           log(---------------------------------)
+--R                                +-+
+--R                             2x\|a
+--R       + 
+--R                     3 2      2 2         4  3        3         2 3  2
+--R                 (96a c  + 96a b c + 18a b )x  + (384a b c + 96a b )x
+--R               + 
+--R                      4       3 2
+--R                 (384a c + 96a b )x
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                        2   2        3      5  4
+--R                 (- 144a b c  - 48a b c - 3b )x
+--R               + 
+--R                        3 2       2 2         4  3          3          2 3  2
+--R                 (- 288a c  - 288a b c - 54a b )x  + (- 576a b c - 144a b )x
+--R               + 
+--R                        4       3 2
+--R                 (- 384a c - 96a b )x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                           +--------------+
+--R                 +---+ +-+ |   2                +---+
+--R                \|- c \|a \|c x  + b x + a  - a\|- c
+--R           atan(-------------------------------------)
+--R                                   +-+
+--R                               c x\|a
+--R       + 
+--R                       2     3   5         2 2        2      4  4
+--R             (- 24a b c  - 2b c)x  + (- 48a c  - 96a b c - 5b )x
+--R           + 
+--R                    2           3  3       3       2 2  2       3          4
+--R             (- 136a b c - 62a b )x  + (32a c - 40a b )x  + 160a b x + 128a
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                 2 3        2 2  6        2   2        3   5
+--R             (16a c  + 12a b c )x  + (120a b c  + 42a b c)x
+--R           + 
+--R                 3 2       2 2         4  4       3         2 3  3
+--R             (48a c  + 204a b c + 26a b )x  + (72a b c + 94a b )x
+--R           + 
+--R                   4       3 2  2       4          5
+--R             (- 96a c - 24a b )x  - 224a b x - 128a
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                                                         +--------------+
+--R              2         2  3       2   2       3   +---+ |   2
+--R         ((32a c + 24a b )x  + 128a b x  + 128a x)\|- c \|c x  + b x + a
+--R       + 
+--R                           3  4         2         2  3       2   2       3
+--R           ((- 48a b c - 4b )x  + (- 96a c - 72a b )x  - 192a b x  - 128a x)
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 276
+
+--S 277 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2           3  3       2 2 2       3     +-+ +-+
+--R             ((96a b c + 72a b )x  + 384a b x  + 384a b x)\|a \|c
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      2 2         4  4          3          2 3  3       3 2 2
+--R               (- 144a b c - 12a b )x  + (- 288a b c - 216a b )x  - 576a b x
+--R             + 
+--R                     4
+--R               - 384a b x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                   3 2      2 2         4  3        3         2 3  2
+--R               (96a c  + 96a b c + 18a b )x  + (384a b c + 96a b )x
+--R             + 
+--R                    4       3 2
+--R               (384a c + 96a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      2   2        3      5  4
+--R               (- 144a b c  - 48a b c - 3b )x
+--R             + 
+--R                      3 2       2 2         4  3          3          2 3  2
+--R               (- 288a c  - 288a b c - 54a b )x  + (- 576a b c - 144a b )x
+--R             + 
+--R                      4       3 2
+--R               (- 384a c - 96a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                          2              2  +-+            2           +-+
+--R                  ((4a c x  + 4a b x + 8a )\|c  + (- 2b c x  - 8a c x)\|a )
+--R               *
+--R                   +--------------+
+--R                   |   2
+--R                  \|c x  + b x + a
+--R              + 
+--R                         3              2  2              2  +-+ +-+       2 3
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x - 8a )\|a \|c  + 4a c x
+--R              + 
+--R                        2     2
+--R                6a b c x  + 8a c x
+--R           /
+--R                               +--------------+
+--R                            2  |   2
+--R                (4a b x + 8a )\|c x  + b x + a
+--R              + 
+--R                            2  2              2  +-+
+--R                ((- 4a c - b )x  - 8a b x - 8a )\|a
+--R     + 
+--R                      2 2         4  5          3          2 3  4       3 2 3
+--R               (- 144a b c - 12a b )x  + (- 288a b c - 216a b )x  - 576a b x
+--R             + 
+--R                     4   2
+--R               - 384a b x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                   2   2        3   6        2 2         4  5
+--R               (96a b c  + 72a b c)x  + (480a b c + 72a b )x
+--R             + 
+--R                    3          2 3  4       3 2 3       4   2
+--R               (480a b c + 456a b )x  + 768a b x  + 384a b x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                    2   2        3      5  5        3 2       2 2         4  4
+--R               (144a b c  + 48a b c + 3b )x  + (288a c  + 288a b c + 54a b )x
+--R             + 
+--R                    3          2 3  3        4       3 2  2
+--R               (576a b c + 144a b )x  + (384a c + 96a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                 3 3      2 2 2        4   6
+--R           (- 96a c  - 96a b c  - 18a b c)x
+--R         + 
+--R                  3   2       2 3         5  5
+--R           (- 480a b c  - 192a b c - 18a b )x
+--R         + 
+--R                  4 2       3 2        2 4  4          4          3 3  3
+--R           (- 480a c  - 576a b c - 114a b )x  + (- 768a b c - 192a b )x
+--R         + 
+--R                  5       4 2  2
+--R           (- 384a c - 96a b )x
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                         2     3   5         2 2         2       4  4
+--R               (- 48a b c  - 4b c)x  + (- 96a c  - 192a b c - 10b )x
+--R             + 
+--R                      2            3  3       3       2 2  2       3          4
+--R               (- 272a b c - 124a b )x  + (64a c - 80a b )x  + 320a b x + 256a
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                   2 3        2 2  6        2   2        3   5
+--R               (32a c  + 24a b c )x  + (240a b c  + 84a b c)x
+--R             + 
+--R                   3 2       2 2         4  4        3          2 3  3
+--R               (96a c  + 408a b c + 52a b )x  + (144a b c + 188a b )x
+--R             + 
+--R                      4       3 2  2       4          5
+--R               (- 192a c - 48a b )x  - 448a b x - 256a
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 2 3        2 2  7          2   2        3   6
+--R           (- 32a c  - 24a b c )x  + (- 240a b c  - 84a b c)x
+--R         + 
+--R                 3 2       2 2         4  5          3          2 3  4
+--R           (- 96a c  - 504a b c - 60a b )x  + (- 336a b c - 332a b )x
+--R         + 
+--R                4        3 2  3       4   2       5
+--R           (192a c - 336a b )x  + 192a b x  + 256a x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R     + 
+--R                   3     3 2  8       2 3         2 2      4   7
+--R           (48a b c  + 4b c )x  + (96a c  + 240a b c  + 14b c)x
+--R         + 
+--R                2   2         3       5  6       3 2       2 2          4  5
+--R           (480a b c  + 368a b c + 10b )x  + (32a c  + 864a b c + 182a b )x
+--R         + 
+--R                3          2 3  4          4        3 2  3       4   2       5
+--R           (208a b c + 508a b )x  + (- 320a c + 272a b )x  - 320a b x  - 256a x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                                                       +--------------+
+--R              2         2  3       2   2       3   +-+ |   2
+--R         ((64a c + 48a b )x  + 256a b x  + 256a x)\|c \|c x  + b x + a
+--R       + 
+--R                           3  4          2          2  3       2   2       3
+--R           ((- 96a b c - 8b )x  + (- 192a c - 144a b )x  - 384a b x  - 256a x)
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                               5   7         4 3 6         3 5 5         2 7 4
+--R                       - 22528a b c  - 84480a b c  - 59136a b c  - 10560a b c
+--R                     + 
+--R                               9 3     11 2
+--R                       - 440a b c  - 2b  c
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                               6 7          5 2 6           4 4 5          3 6 4
+--R                       - 49152a c  - 709632a b c  - 1140480a b c  - 443520a b c
+--R                     + 
+--R                               2 8 3          10 2     12
+--R                       - 47520a b c  - 1188a b  c  - 3b  c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                 6   6           5 3 5           4 5 4
+--R                       - 1718272a b c  - 7079424a b c  - 5677056a b c
+--R                     + 
+--R                                 3 7 3         2 9 2          11     13
+--R                       - 1256640a b c  - 77880a b c  - 1038a b  c - b
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                 7 6            6 2 5            5 4 4
+--R                       - 1245184a c  - 18840576a b c  - 32257280a b c
+--R                     + 
+--R                                4 6 3           3 8 2         2 10          12
+--R                     - 13732224a b c  - 1694880a b c  - 54956a b  c - 289a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                  7   5            6 3 4            5 5 3
+--R                       - 22339584a b c  - 93634560a b c  - 76606464a b c
+--R                     + 
+--R                                  4 7 2           3 9          2 11
+--R                       - 17335296a b c  - 1092960a b c - 14016a b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                 8 5             7 2 4             6 4 3
+--R                       - 9682944a c  - 144384000a b c  - 241080320a b c
+--R                     + 
+--R                                  5 6 2            4 8           3 10
+--R                       - 97963008a b c  - 10954944a b c - 269984a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                   8   4             7 3 3             6 5 2
+--R                       - 112394240a b c  - 445276160a b c  - 332666880a b c
+--R                     + 
+--R                                  5 7            4 9
+--R                       - 63771136a b c - 2727296a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                  9 4             8 2 3             7 4 2
+--R                       - 34701312a c  - 478003200a b c  - 706682880a b c
+--R                     + 
+--R                                   6 6             5 8
+--R                       - 232866816a b c - 16528512a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                   9   3             8 3 2             7 5
+--R                       - 275775488a b c  - 945684480a b c  - 555712512a b c
+--R                     + 
+--R                                  6 7
+--R                       - 64749568a b
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                  10 3             9 2 2             8 4
+--R                       - 66060288a  c  - 774111232a b c  - 880148480a b c
+--R                     + 
+--R                                   7 6
+--R                       - 171016192a b
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                                10   2             9 3              8 5  5
+--R                   (- 353894400a  b c  - 917372928a b c - 310837248a b )x
+--R                 + 
+--R                               11 2             10 2              9 4  4
+--R                   (- 69206016a  c  - 604766208a  b c - 389742592a b )x
+--R                 + 
+--R                                11                10 3  3
+--R                   (- 228589568a  b c - 331350016a  b )x
+--R                 + 
+--R                               12              11 2  2            12
+--R                   (- 37748736a  c - 182452224a  b )x  - 58720256a  b x
+--R                 + 
+--R                             13
+--R                   - 8388608a
+--R              *
+--R                  +-+ +-+
+--R                 \|a \|c
+--R             + 
+--R                        6 8         5 2 7         4 4 6         3 6 5
+--R                   4096a c  + 56320a b c  + 84480a b c  + 29568a b c
+--R                 + 
+--R                        2 8 4        10 3
+--R                   2640a b c  + 44a b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                          6   7           5 3 6          4 5 5          3 7 4
+--R                   276480a b c  + 1098240a b c  + 836352a b c  + 171072a b c
+--R                 + 
+--R                        2 9 3        11 2
+--R                   9240a b c  + 90a b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                          7 7           6 2 6           5 4 5           4 6 4
+--R                   299008a c  + 4445184a b c  + 7434240a b c  + 3062400a b c
+--R                 + 
+--R                          3 8 3         2 10 2        12
+--R                   359568a b c  + 10692a b  c  + 46a b  c
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                           7   6            6 3 5            5 5 4
+--R                   6998016a b c  + 29120000a b c  + 23606528a b c
+--R                 + 
+--R                           4 7 3          3 9 2        2 11
+--R                   5277888a b c  + 327272a b c  + 4094a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                           8 6            7 2 5            6 4 4
+--R                   3735552a c  + 55848960a b c  + 93634560a b c
+--R                 + 
+--R                            5 6 3           4 8 2          3 10
+--R                   38303232a b c  + 4333824a b c  + 109296a b  c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                            8   5             7 3 4             6 5 3
+--R                   51388416a b c  + 206028800a b c  + 156509184a b c
+--R                 + 
+--R                            5 7 2           4 9
+--R                   30750720a b c  + 1368224a b c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            9 5             8 2 4             7 4 3
+--R                   18120704a c  + 253804544a b c  + 383631360a b c
+--R                 + 
+--R                             6 6 2           5 8
+--R                   130364416a b c  + 9682816a b c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                             9   4             8 3 3             7 5 2
+--R                   163676160a b c  + 575594496a b c  + 349784064a b c
+--R                 + 
+--R                            6 7
+--R                   42711552a b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            10 4             9 2 3             8 4 2
+--R                   42991616a  c  + 517472256a b c  + 609091584a b c
+--R                 + 
+--R                             7 6
+--R                   123977728a b c
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                          10   3             9 3 2             8 5   6
+--R               (255852544a  b c  + 686686208a b c  + 243433472a b c)x
+--R             + 
+--R                         11 3             10 2 2             9 4   5
+--R               (53477376a  c  + 483655680a  b c  + 325582848a b c)x
+--R             + 
+--R                          11   2             10 3   4
+--R               (193462272a  b c  + 292421632a  b c)x
+--R             + 
+--R                         12 2             11 2   3            12     2
+--R               (33554432a  c  + 168820736a  b c)x  + 56623104a  b c x
+--R             + 
+--R                       13
+--R               8388608a  c x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        6 8         5 2 7         4 4 6         3 6 5
+--R                   4096a c  + 56320a b c  + 84480a b c  + 29568a b c
+--R                 + 
+--R                        2 8 4        10 3
+--R                   2640a b c  + 44a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                          6   7           5 3 6          4 5 5          3 7 4
+--R                   278528a b c  + 1126400a b c  + 878592a b c  + 185856a b c
+--R                 + 
+--R                         2 9 3         11 2
+--R                   10560a b c  + 112a b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                          7 7           6 2 6           5 4 5           4 6 4
+--R                   303104a c  + 4651008a b c  + 8110080a b c  + 3539712a b c
+--R                 + 
+--R                          3 8 3         2 10 2        12
+--R                   453024a b c  + 15576a b  c  + 92a b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                           7   6            6 3 5            5 5 4
+--R                   7446528a b c  + 32761856a b c  + 28666880a b c
+--R                 + 
+--R                           4 7 3          3 9 2        2 11         13
+--R                   7172352a b c  + 536096a b c  + 9992a b  c + 24a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                           8 6            7 2 5             6 4 4
+--R                   4034560a c  + 64502784a b c  + 118458880a b c
+--R                 + 
+--R                            5 6 3           4 8 2          3 10         2 12
+--R                   55335808a b c  + 7779024a b c  + 308044a b  c + 2336a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                            8   5             7 3 4             6 5 3
+--R                   60727296a b c  + 269916160a b c  + 237929472a b c
+--R                 + 
+--R                            5 7 2           4 9          3 11
+--R                   59431680a b c  + 4306720a b c + 68664a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                            9 5             8 2 4             7 4 3
+--R                   21856256a c  + 342781952a b c  + 609116160a b c
+--R                 + 
+--R                             6 6 2            5 8           4 10
+--R                   267923968a b c  + 33294976a b c + 954096a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             9   4             8 3 3             7 5 2
+--R                   227098624a b c  + 949075968a b c  + 757413888a b c
+--R                 + 
+--R                             6 7            5 9
+--R                   157973504a b c + 7568704a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            10 4             9 2 3              8 4 2
+--R                   61112320a  c  + 882130944a b c  + 1379868672a b c
+--R                 + 
+--R                             7 6             6 8
+--R                   487660544a b c + 37884288a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             10   3              9 3 2              8 5
+--R                   449314816a  b c  + 1618608128a b c  + 1009614848a b c
+--R                 + 
+--R                             7 7
+--R                   126738432a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            11 3              10 2 2              9 4
+--R                   96468992a  c  + 1180958720a  b c  + 1414266880a b c
+--R                 + 
+--R                             8 6
+--R                   292732928a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          11   2              10 3              9 5  5
+--R               (487587840a  b c  + 1323302912a  b c + 473628672a b )x
+--R             + 
+--R                         12 2             11 2              10 4  4
+--R               (87031808a  c  + 792461312a  b c + 535953408a  b )x
+--R             + 
+--R                          12                11 3  3
+--R               (274726912a  b c + 415760384a  b )x
+--R             + 
+--R                         13              12 2  2            13              14
+--R               (41943040a  c + 210763776a  b )x  + 62914560a  b x + 8388608a
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                           5   8         4 3 7         3 5 6         2 7 5
+--R                   - 22528a b c  - 84480a b c  - 59136a b c  - 10560a b c
+--R                 + 
+--R                           9 4     11 3
+--R                   - 440a b c  - 2b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                           6 8          5 2 7           4 4 6          3 6 5
+--R                   - 49152a c  - 720896a b c  - 1182720a b c  - 473088a b c
+--R                 + 
+--R                           2 8 4          10 3     12 2
+--R                   - 52800a b c  - 1408a b  c  - 4b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                             6   7           5 3 6           4 5 5
+--R                   - 1740800a b c  - 7400448a b c  - 6183936a b c
+--R                 + 
+--R                             3 7 4         2 9 3          11 2     13
+--R                   - 1448832a b c  - 97680a b c  - 1500a b  c  - 2b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                             7 7            6 2 6            5 4 5
+--R                   - 1245184a c  - 19550208a b c  - 35087360a b c
+--R                 + 
+--R                              4 6 4           3 8 3         2 10 2         12
+--R                   - 15899136a b c  - 2141568a b c  - 79376a b  c  - 532a b  c
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                              7   6             6 3 5            5 5 4
+--R                   - 22812672a b c  - 100477440a b c  - 87602944a b c
+--R                 + 
+--R                              4 7 3           3 9 2         2 11
+--R                   - 21586752a b c  - 1537272a b c  - 23938a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             8 6             7 2 5             6 4 4
+--R                   - 9682944a c  - 151818240a b c  - 269916160a b c
+--R                 + 
+--R                               5 6 3            4 8 2          3 10
+--R                   - 118964736a b c  - 14857920a b c  - 430672a b  c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                               8   5             7 3 4             6 5 3
+--R                   - 115367936a b c  - 485826560a b c  - 391971840a b c
+--R                 + 
+--R                              5 7 2           4 9
+--R                   - 83100160a b c  - 4086368a b c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              9 5             8 2 4             7 4 3
+--R                   - 34701312a c  - 507019264a b c  - 806031360a b c
+--R                 + 
+--R                               6 6 2            5 8
+--R                   - 291293184a b c  - 23374208a b c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                               9   4              8 3 3             7 5 2
+--R                   - 284065792a b c  - 1043275776a b c  - 667564032a b c
+--R                 + 
+--R                              6 7
+--R                   - 86787584a b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              10 4             9 2 3              8 4 2
+--R                   - 66060288a  c  - 826015744a b c  - 1016397824a b c
+--R                 + 
+--R                               7 6
+--R                   - 218054656a b c
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            10   3              9 3 2             8 5   6
+--R               (- 365428736a  b c  - 1019740160a b c  - 378241024a b c)x
+--R             + 
+--R                           11 3             10 2 2             9 4   5
+--R               (- 69206016a  c  - 648019968a  b c  - 453902336a b c)x
+--R             + 
+--R                            11   2             10 3   4
+--R               (- 236453888a  b c  - 370278400a  b c)x
+--R             + 
+--R                           12 2             11 2   3            12     2
+--R               (- 37748736a  c  - 196083712a  b c)x  - 60817408a  b c x
+--R             + 
+--R                         13
+--R               - 8388608a  c x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                          6 8         5 2 7         4 4 6         3 6 5
+--R                   - 4096a c  - 56320a b c  - 84480a b c  - 29568a b c
+--R                 + 
+--R                          2 8 4        10 3
+--R                   - 2640a b c  - 44a b  c
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                            6   7           5 3 6          4 5 5          3 7 4
+--R                   - 278528a b c  - 1126400a b c  - 878592a b c  - 185856a b c
+--R                 + 
+--R                           2 9 3         11 2
+--R                   - 10560a b c  - 112a b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                            7 7           6 2 6           5 4 5           4 6 4
+--R                   - 303104a c  - 4651008a b c  - 8110080a b c  - 3539712a b c
+--R                 + 
+--R                            3 8 3         2 10 2        12
+--R                   - 453024a b c  - 15576a b  c  - 92a b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                             7   6            6 3 5            5 5 4
+--R                   - 7446528a b c  - 32761856a b c  - 28666880a b c
+--R                 + 
+--R                             4 7 3          3 9 2        2 11         13
+--R                   - 7172352a b c  - 536096a b c  - 9992a b  c - 24a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                             8 6            7 2 5             6 4 4
+--R                   - 4034560a c  - 64502784a b c  - 118458880a b c
+--R                 + 
+--R                              5 6 3           4 8 2          3 10         2 12
+--R                   - 55335808a b c  - 7779024a b c  - 308044a b  c - 2336a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                              8   5             7 3 4             6 5 3
+--R                   - 60727296a b c  - 269916160a b c  - 237929472a b c
+--R                 + 
+--R                              5 7 2           4 9          3 11
+--R                   - 59431680a b c  - 4306720a b c - 68664a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                              9 5             8 2 4             7 4 3
+--R                   - 21856256a c  - 342781952a b c  - 609116160a b c
+--R                 + 
+--R                               6 6 2            5 8           4 10
+--R                   - 267923968a b c  - 33294976a b c - 954096a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                               9   4             8 3 3             7 5 2
+--R                   - 227098624a b c  - 949075968a b c  - 757413888a b c
+--R                 + 
+--R                               6 7            5 9
+--R                   - 157973504a b c - 7568704a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                              10 4             9 2 3              8 4 2
+--R                   - 61112320a  c  - 882130944a b c  - 1379868672a b c
+--R                 + 
+--R                               7 6             6 8
+--R                   - 487660544a b c - 37884288a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                               10   3              9 3 2              8 5
+--R                   - 449314816a  b c  - 1618608128a b c  - 1009614848a b c
+--R                 + 
+--R                               7 7
+--R                   - 126738432a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                              11 3              10 2 2              9 4
+--R                   - 96468992a  c  - 1180958720a  b c  - 1414266880a b c
+--R                 + 
+--R                               8 6
+--R                   - 292732928a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            11   2              10 3              9 5  6
+--R               (- 487587840a  b c  - 1323302912a  b c - 473628672a b )x
+--R             + 
+--R                           12 2             11 2              10 4  5
+--R               (- 87031808a  c  - 792461312a  b c - 535953408a  b )x
+--R             + 
+--R                            12                11 3  4
+--R               (- 274726912a  b c - 415760384a  b )x
+--R             + 
+--R                         13              12 2  3            13   2           14
+--R             (- 41943040a  c - 210763776a  b )x  - 62914560a  b x  - 8388608a  x
+--R          *
+--R              +-+
+--R             \|c
+--R         + 
+--R                         5   8         4 3 7         3 5 6         2 7 5
+--R                   22528a b c  + 84480a b c  + 59136a b c  + 10560a b c
+--R                 + 
+--R                         9 4     11 3
+--R                   440a b c  + 2b  c
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                         6 8          5 2 7           4 4 6          3 6 5
+--R                   49152a c  + 720896a b c  + 1182720a b c  + 473088a b c
+--R                 + 
+--R                         2 8 4          10 3     12 2
+--R                   52800a b c  + 1408a b  c  + 4b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                           6   7           5 3 6           4 5 5           3 7 4
+--R                   1740800a b c  + 7400448a b c  + 6183936a b c  + 1448832a b c
+--R                 + 
+--R                         2 9 3          11 2     13
+--R                   97680a b c  + 1500a b  c  + 2b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                           7 7            6 2 6            5 4 5
+--R                   1245184a c  + 19550208a b c  + 35087360a b c
+--R                 + 
+--R                            4 6 4           3 8 3         2 10 2         12
+--R                   15899136a b c  + 2141568a b c  + 79376a b  c  + 532a b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                            7   6             6 3 5            5 5 4
+--R                   22812672a b c  + 100477440a b c  + 87602944a b c
+--R                 + 
+--R                            4 7 3           3 9 2         2 11
+--R                   21586752a b c  + 1537272a b c  + 23938a b  c
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                           8 6             7 2 5             6 4 4
+--R                   9682944a c  + 151818240a b c  + 269916160a b c
+--R                 + 
+--R                             5 6 3            4 8 2          3 10
+--R                   118964736a b c  + 14857920a b c  + 430672a b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             8   5             7 3 4             6 5 3
+--R                   115367936a b c  + 485826560a b c  + 391971840a b c
+--R                 + 
+--R                            5 7 2           4 9
+--R                   83100160a b c  + 4086368a b c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                            9 5             8 2 4             7 4 3
+--R                   34701312a c  + 507019264a b c  + 806031360a b c
+--R                 + 
+--R                             6 6 2            5 8
+--R                   291293184a b c  + 23374208a b c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             9   4              8 3 3             7 5 2
+--R                   284065792a b c  + 1043275776a b c  + 667564032a b c
+--R                 + 
+--R                            6 7
+--R                   86787584a b c
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            10 4             9 2 3              8 4 2
+--R                   66060288a  c  + 826015744a b c  + 1016397824a b c
+--R                 + 
+--R                             7 6
+--R                   218054656a b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          10   3              9 3 2             8 5   7
+--R               (365428736a  b c  + 1019740160a b c  + 378241024a b c)x
+--R             + 
+--R                         11 3             10 2 2             9 4   6
+--R               (69206016a  c  + 648019968a  b c  + 453902336a b c)x
+--R             + 
+--R                          11   2             10 3   5
+--R               (236453888a  b c  + 370278400a  b c)x
+--R             + 
+--R                         12 2             11 2   4            12     3
+--R               (37748736a  c  + 196083712a  b c)x  + 60817408a  b c x
+--R             + 
+--R                       13   2
+--R               8388608a  c x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                     5   8         4 3 7         3 5 6         2 7 5         9 4
+--R               22528a b c  + 84480a b c  + 59136a b c  + 10560a b c  + 440a b c
+--R             + 
+--R                 11 3
+--R               2b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                     6 8          5 2 7           4 4 6          3 6 5
+--R               49152a c  + 732160a b c  + 1224960a b c  + 502656a b c
+--R             + 
+--R                     2 8 4          10 3     12 2
+--R               58080a b c  + 1628a b  c  + 5b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                       6   7           5 3 6           4 5 5           3 7 4
+--R               1789952a b c  + 7873536a b c  + 6876672a b c  + 1710720a b c
+--R             + 
+--R                      2 9 3          11 2     13
+--R               125840a b c  + 2228a b  c  + 4b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                       7 7            6 2 6            5 4 5            4 6 4
+--R               1294336a c  + 21268480a b c  + 40477184a b c  + 19852800a b c
+--R             + 
+--R                       3 8 3          2 10 2          12     14
+--R               2999040a b c  + 134024a b  c  + 1330a b  c + b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        7   6             6 3 5             5 5 4
+--R               25303040a b c  + 119554560a b c  + 114540800a b c
+--R             + 
+--R                        4 7 3           3 9 2         2 11          13
+--R               32324160a b c  + 2865720a b c  + 70010a b  c + 290a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        8 6             7 2 5             6 4 4
+--R               10928128a c  + 185564160a b c  + 366972160a b c
+--R             + 
+--R                         5 6 3            4 8 2           3 10          2 12
+--R               188301696a b c  + 29985120a b c  + 1417900a b  c + 14305a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         8   5             7 3 4             6 5 3
+--R               144416768a b c  + 683294720a b c  + 650353664a b c
+--R             + 
+--R                         5 7 2            4 9           3 11
+--R               179069440a b c  + 14775200a b c + 284000a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        9 5             8 2 4              7 4 3
+--R               44384256a c  + 734781440a b c  + 1393039360a b c
+--R             + 
+--R                         6 6 2            5 8            4 10
+--R               663496704a b c  + 91254592a b c + 2997280a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         9   4              8 3 3              7 5 2
+--R               422871040a b c  + 1868963840a b c  + 1595062272a b c
+--R             + 
+--R                         6 7             5 9
+--R               361387520a b c + 19255808a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         10 4              9 2 3              8 4 2
+--R               100761600a  c  + 1527889920a b c  + 2532515840a b c
+--R             + 
+--R                         7 6             6 8
+--R               959595520a b c + 81278080a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                         10   3              9 3 2              8 5
+--R               695730176a  b c  + 2637168640a b c  + 1746698240a b c
+--R             + 
+--R                         7 7
+--R               235765760a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         11 3              10 2 2              9 4
+--R               135266304a  c  + 1732771840a  b c  + 2187264000a b c
+--R             + 
+--R                         8 6
+--R               481853440a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                      11   2              10 3              9 5  6
+--R           (651689984a  b c  + 1853489152a  b c + 700579840a b )x
+--R         + 
+--R                      12 2              11 2              10 4  5
+--R           (106954752a  c  + 1015808000a  b c + 721092608a  b )x
+--R         + 
+--R                      12                11 3  4
+--R           (325058560a  b c + 513802240a  b )x
+--R         + 
+--R                     13              12 2  3            13   2           14
+--R           (46137344a  c + 241172480a  b )x  + 67108864a  b x  + 8388608a  x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R     + 
+--R                  6 9         5 2 8         4 4 7         3 6 6        2 8 5
+--R           - 4096a c  - 56320a b c  - 84480a b c  - 29568a b c  - 2640a b c
+--R         + 
+--R                  10 4
+--R           - 44a b  c
+--R      *
+--R          18
+--R         x
+--R     + 
+--R                    6   8           5 3 7          4 5 6          3 7 5
+--R           - 280576a b c  - 1154560a b c  - 920832a b c  - 200640a b c
+--R         + 
+--R                   2 9 4         11 3
+--R           - 11880a b c  - 134a b  c
+--R      *
+--R          17
+--R         x
+--R     + 
+--R                    7 8           6 2 7           5 4 6           4 6 5
+--R           - 303104a c  - 4777984a b c  - 8616960a b c  - 3928320a b c
+--R         + 
+--R                    3 8 4         2 10 3         12 2
+--R           - 533280a b c  - 19976a b  c  - 136a b  c
+--R      *
+--R          16
+--R         x
+--R     + 
+--R                     7   7            6 3 6            5 5 5           4 7 4
+--R           - 7573504a b c  - 34663424a b c  - 31877120a b c  - 8511360a b c
+--R         + 
+--R                    3 9 3         2 11 2        13
+--R           - 696080a b c  - 14876a b  c  - 46a b  c
+--R      *
+--R          15
+--R         x
+--R     + 
+--R                     8 7            7 2 6             6 4 5            5 6 4
+--R           - 4034560a c  - 67292160a b c  - 130188800a b c  - 64972160a b c
+--R         + 
+--R                     4 8 3          3 10 2        2 12
+--R           - 9971280a b c  - 447260a b  c  - 4140a b  c
+--R      *
+--R          14
+--R         x
+--R     + 
+--R                      8   6             7 3 5             6 5 4            5 7 3
+--R           - 62121984a b c  - 290997760a b c  - 273750272a b c  - 74331840a b c
+--R         + 
+--R                     4 9 2          3 11
+--R           - 6029320a b c  - 113390a b  c
+--R      *
+--R          13
+--R         x
+--R     + 
+--R                      9 6             8 2 5             7 4 4             6 6 3
+--R           - 21856256a c  - 361041920a b c  - 683294720a b c  - 325176832a b c
+--R         + 
+--R                      5 8 2           4 10
+--R           - 44767360a b c  - 1477520a b  c
+--R      *
+--R          12
+--R         x
+--R     + 
+--R                       9   5              8 3 4             7 5 3
+--R           - 233185280a b c  - 1035427840a b c  - 889924608a b c
+--R         + 
+--R                       6 7 2            5 9
+--R           - 203826688a b c  - 11051040a b c
+--R      *
+--R          11
+--R         x
+--R     + 
+--R                      10 5             9 2 4              8 4 3
+--R           - 61112320a  c  - 934952960a b c  - 1568317440a b c
+--R         + 
+--R                       7 6 2            6 8
+--R           - 604126208a b c  - 52394368a b c
+--R      *
+--R          10
+--R         x
+--R     + 
+--R                       10   4              9 3 3              8 5 2
+--R           - 462520320a  b c  - 1779752960a b c  - 1202309120a b c
+--R         + 
+--R                       7 7
+--R           - 166689280a b c
+--R      *
+--R          9
+--R         x
+--R     + 
+--R                        11 4              10 2 3              9 4 2
+--R             - 96468992a  c  - 1256980480a  b c  - 1621360640a b c
+--R           + 
+--R                         8 6
+--R             - 367411200a b c
+--R      *
+--R          8
+--R         x
+--R     + 
+--R                    11   3              10 3 2             9 5   7
+--R       (- 502792192a  b c  - 1462763520a  b c  - 569016320a b c)x
+--R     + 
+--R                   12 3             11 2 2             10 4   6
+--R       (- 87031808a  c  - 845938688a  b c  - 618004480a  b c)x
+--R     + 
+--R                    12   2             11 3   5
+--R       (- 283639808a  b c  - 461242368a  b c)x
+--R     + 
+--R                 13 2             12 2   4            13     3           14   2
+--R     (- 41943040a  c  - 225443840a  b c)x  - 65011712a  b c x  - 8388608a  c x
+--R  /
+--R                          6 6         5 2 5         4 4 4         3 6 3
+--R                     4096a c  + 56320a b c  + 84480a b c  + 29568a b c
+--R                   + 
+--R                          2 8 2        10
+--R                     2640a b c  + 44a b  c
+--R                *
+--R                    14
+--R                   x
+--R               + 
+--R                            6   5           5 3 4          4 5 3          3 7 2
+--R                     270336a b c  + 1013760a b c  + 709632a b c  + 126720a b c
+--R                   + 
+--R                          2 9         11
+--R                     5280a b c + 24a b
+--R                *
+--R                    13
+--R                   x
+--R               + 
+--R                            7 5           6 2 4           5 4 3           4 6 2
+--R                     294912a c  + 3993600a b c  + 5857280a b c  + 1976832a b c
+--R                   + 
+--R                            3 8         2 10
+--R                     164736a b c + 2288a b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                             7   4            6 3 3            5 5 2
+--R                     6307840a b c  + 22364160a b c  + 14350336a b c
+--R                   + 
+--R                             4 7          3 9
+--R                     2196480a b c + 64064a b
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                             8 4            7 2 3            6 4 2
+--R                     3440640a c  + 43008000a b c  + 55910400a b c
+--R                   + 
+--R                              5 6           4 8
+--R                     15375360a b c + 823680a b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                              8   3             7 3 2            6 5
+--R                     40370176a b c  + 123863040a b c  + 62619648a b c
+--R                   + 
+--R                             5 7
+--R                     5857280a b
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                              9 3             8 2 2             7 4
+--R                     14680064a c  + 155975680a b c  + 155975680a b c
+--R                   + 
+--R                              6 6
+--R                     25346048a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                            9   2             8 3             7 5  7
+--R                 (103809024a b c  + 240648192a b c + 70189056a b )x
+--R               + 
+--R                           10 2             9 2              8 4  6
+--R                 (28311552a  c  + 224133120a b c + 127008768a b )x
+--R               + 
+--R                            10                9 3  5
+--R                 (115343360a  b c + 149422080a b )x
+--R               + 
+--R                           11              10 2  4            11   3
+--R                 (25165824a  c + 110100480a  b )x  + 46137344a  b x
+--R               + 
+--R                         12 2
+--R                 8388608a  x
+--R            *
+--R                +-+
+--R               \|c
+--R           + 
+--R                             5   6         4 3 5         3 5 4         2 7 3
+--R                     - 22528a b c  - 84480a b c  - 59136a b c  - 10560a b c
+--R                   + 
+--R                             9 2     11
+--R                     - 440a b c  - 2b  c
+--R                *
+--R                    14
+--R                   x
+--R               + 
+--R                             6 6          5 2 5           4 4 4          3 6 3
+--R                     - 49152a c  - 675840a b c  - 1013760a b c  - 354816a b c
+--R                   + 
+--R                             2 8 2         10
+--R                     - 31680a b c  - 528a b  c
+--R                *
+--R                    13
+--R                   x
+--R               + 
+--R                               6   5           5 3 4           4 5 3
+--R                     - 1597440a b c  - 5857280a b c  - 3953664a b c
+--R                   + 
+--R                              3 7 2         2 9
+--R                     - 658944a b c  - 22880a b c
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                               7 5            6 2 4            5 4 3
+--R                     - 1146880a c  - 14909440a b c  - 20500480a b c
+--R                   + 
+--R                               4 6 2          3 8
+--R                     - 6150144a b c  - 384384a b c
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                                7   4            6 3 3            5 5 2
+--R                     - 17203200a b c  - 55910400a b c  - 30750720a b c
+--R                   + 
+--R                               4 7
+--R                     - 3294720a b c
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                               8 4            7 2 3            6 4 2
+--R                     - 7340032a c  - 82575360a b c  - 89456640a b c
+--R                   + 
+--R                                5 6
+--R                     - 16400384a b c
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                             8   3             7 3 2            6 5   8
+--R                 (- 62390272a b c  - 155975680a b c  - 50692096a b c)x
+--R               + 
+--R                             9 3             8 2 2             7 4   7
+--R                 (- 18874368a c  - 160432128a b c  - 100270080a b c)x
+--R               + 
+--R                             9   2             8 3   6
+--R                 (- 89653248a b c  - 127008768a b c)x
+--R               + 
+--R                             10 2            9 2   5            10     4
+--R                 (- 20971520a  c  - 99614720a b c)x  - 44040192a  b c x
+--R               + 
+--R                           11   3
+--R                 - 8388608a  c x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                         5   6         4 3 5         3 5 4         2 7 3
+--R                 - 22528a b c  - 84480a b c  - 59136a b c  - 10560a b c
+--R               + 
+--R                         9 2     11
+--R                 - 440a b c  - 2b  c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                         6 6          5 2 5           4 4 4          3 6 3
+--R                 - 49152a c  - 687104a b c  - 1056000a b c  - 384384a b c
+--R               + 
+--R                         2 8 2         10     12
+--R                 - 36960a b c  - 748a b  c - b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                           6   5           5 3 4           4 5 3          3 7 2
+--R                 - 1646592a b c  - 6307840a b c  - 4561920a b c  - 861696a b c
+--R               + 
+--R                         2 9          11
+--R                 - 40480a b c - 288a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                           7 5            6 2 4            5 4 3           4 6 2
+--R                 - 1196032a c  - 16506880a b c  - 24893440a b c  - 8785920a b c
+--R               + 
+--R                          3 8          2 10
+--R                 - 796224a b c - 13728a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                            7   4            6 3 3            5 5 2
+--R                 - 19496960a b c  - 70819840a b c  - 47151104a b c
+--R               + 
+--R                           4 7           3 9
+--R                 - 7687680a b c - 256256a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                           8 4             7 2 3             6 4 2
+--R                 - 8486912a c  - 108380160a b c  - 145367040a b c
+--R               + 
+--R                            5 6            4 8
+--R                 - 42025984a b c - 2471040a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                            8   3             7 3 2             6 5
+--R                 - 84410368a b c  - 266076160a b c  - 140148736a b c
+--R               + 
+--R                            5 7
+--R                 - 14057472a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                              9 3             8 2 2             7 4
+--R                   - 26214400a c  - 285212672a b c  - 295239680a b c
+--R                 + 
+--R                              6 6
+--R                   - 50692096a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                          9   2             8 3              7 5  7
+--R             (- 165150720a b c  - 394395648a b c - 120324096a b )x
+--R           + 
+--R                         10 2             9 2              8 4  6
+--R             (- 39845888a  c  - 323747840a b c - 190513152a b )x
+--R           + 
+--R                          10                9 3  5
+--R             (- 148897792a  b c - 199229440a b )x
+--R           + 
+--R                       11              10 2  4            11   3           12 2
+--R           (- 29360128a  c - 132120576a  b )x  - 50331648a  b x  - 8388608a  x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R       + 
+--R                  6 7         5 2 6         4 4 5         3 6 4        2 8 3
+--R             4096a c  + 56320a b c  + 84480a b c  + 29568a b c  + 2640a b c
+--R           + 
+--R                  10 2
+--R             44a b  c
+--R        *
+--R            15
+--R           x
+--R       + 
+--R                    6   6           5 3 5          4 5 4          3 7 3
+--R             272384a b c  + 1041920a b c  + 751872a b c  + 141504a b c
+--R           + 
+--R                  2 9 2        11
+--R             6600a b c  + 46a b  c
+--R        *
+--R            14
+--R           x
+--R       + 
+--R                    7 6           6 2 5           5 4 4           4 6 3
+--R             294912a c  + 4116480a b c  + 6307840a b c  + 2280960a b c
+--R           + 
+--R                    3 8 2        2 10
+--R             215424a b c  + 4048a b  c
+--R        *
+--R            13
+--R           x
+--R       + 
+--R                     7   5            6 3 4            5 5 3           4 7 2
+--R             6430720a b c  + 23961600a b c  + 16546816a b c  + 2855424a b c
+--R           + 
+--R                    3 9
+--R             105248a b c
+--R        *
+--R            12
+--R           x
+--R       + 
+--R                     8 5            7 2 4            6 4 3            5 6 2
+--R             3440640a c  + 45301760a b c  + 63365120a b c  + 19475456a b c
+--R           + 
+--R                     4 8
+--R             1262976a b c
+--R        *
+--R            11
+--R           x
+--R       + 
+--R                   8   4             7 3 3            6 5 2           5 7   10
+--R         (41517056a b c  + 136765440a b c  + 76597248a b c  + 8419840a b c)x
+--R       + 
+--R                   9 4             8 2 3             7 4 2            6 6   9
+--R         (14680064a c  + 166985728a b c  + 183500800a b c  + 34291712a b c)x
+--R       + 
+--R                    9   3             8 3 2            7 5   8
+--R         (107479040a b c  + 271843328a b c  + 89686016a b c)x
+--R       + 
+--R                   10 3             9 2 2             8 4   7
+--R         (28311552a  c  + 243007488a b c  + 153747456a b c)x
+--R       + 
+--R                    10   2             9 3   6
+--R         (120061952a  b c  + 171835392a b c)x
+--R       + 
+--R                 11 2             10 2   5            11     4           12   3
+--R       (25165824a  c  + 120586240a  b c)x  + 48234496a  b c x  + 8388608a  c x
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                  2           3  3       2 2 2       3     +---+ +-+ +-+
+--R             ((96a b c + 72a b )x  + 384a b x  + 384a b x)\|- c \|a \|c
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      2 2         4  4          3          2 3  3       3 2 2
+--R               (- 144a b c - 12a b )x  + (- 288a b c - 216a b )x  - 576a b x
+--R             + 
+--R                     4
+--R               - 384a b x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                      2 2         4  5          3          2 3  4       3 2 3
+--R               (- 144a b c - 12a b )x  + (- 288a b c - 216a b )x  - 576a b x
+--R             + 
+--R                     4   2
+--R               - 384a b x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                   2   2        3   6        2 2         4  5
+--R               (96a b c  + 72a b c)x  + (480a b c + 72a b )x
+--R             + 
+--R                    3          2 3  4       3 2 3       4   2
+--R               (480a b c + 456a b )x  + 768a b x  + 384a b x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                    2   2        3      5  5        3 2       2 2         4  4
+--R               (144a b c  + 48a b c + 3b )x  + (288a c  + 288a b c + 54a b )x
+--R             + 
+--R                    3          2 3  3        4       3 2  2
+--R               (576a b c + 144a b )x  + (384a c + 96a b )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + b x + a
+--R         + 
+--R                     3 3      2 2 2        4   6
+--R               (- 96a c  - 96a b c  - 18a b c)x
+--R             + 
+--R                      3   2       2 3         5  5
+--R               (- 480a b c  - 192a b c - 18a b )x
+--R             + 
+--R                      4 2       3 2        2 4  4          4          3 3  3
+--R               (- 480a c  - 576a b c - 114a b )x  + (- 768a b c - 192a b )x
+--R             + 
+--R                      5       4 2  2
+--R               (- 384a c - 96a b )x
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                    3 2       2 2         4  3        3          2 3  2
+--R               (192a c  + 192a b c + 36a b )x  + (768a b c + 192a b )x
+--R             + 
+--R                    4        3 2
+--R               (768a c + 192a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                      2   2        3      5  4
+--R               (- 288a b c  - 96a b c - 6b )x
+--R             + 
+--R                      3 2       2 2          4  3           3          2 3  2
+--R               (- 576a c  - 576a b c - 108a b )x  + (- 1152a b c - 288a b )x
+--R             + 
+--R                      4        3 2
+--R               (- 768a c - 192a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                                              +--------------+
+--R          +------------------+      +---+ +-+ |   2                +---+
+--R          |   4      3      2      \|- c \|a \|c x  + b x + a  - a\|- c
+--R         \|c x  + b x  + a x  atan(-------------------------------------)
+--R                                                      +-+
+--R                                                  c x\|a
+--R     + 
+--R                         2     3   5         2 2         2       4  4
+--R               (- 48a b c  - 4b c)x  + (- 96a c  - 192a b c - 10b )x
+--R             + 
+--R                      2            3  3       3       2 2  2       3          4
+--R               (- 272a b c - 124a b )x  + (64a c - 80a b )x  + 320a b x + 256a
+--R          *
+--R                            +--------------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|a \|c \|c x  + b x + a
+--R         + 
+--R                   2 3        2 2  6        2   2        3   5
+--R               (32a c  + 24a b c )x  + (240a b c  + 84a b c)x
+--R             + 
+--R                   3 2       2 2         4  4        3          2 3  3
+--R               (96a c  + 408a b c + 52a b )x  + (144a b c + 188a b )x
+--R             + 
+--R                      4       3 2  2       4          5
+--R               (- 192a c - 48a b )x  - 448a b x - 256a
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 2 3        2 2  7          2   2        3   6
+--R           (- 32a c  - 24a b c )x  + (- 240a b c  - 84a b c)x
+--R         + 
+--R                 3 2       2 2         4  5          3          2 3  4
+--R           (- 96a c  - 504a b c - 60a b )x  + (- 336a b c - 332a b )x
+--R         + 
+--R                4        3 2  3       4   2       5
+--R           (192a c - 336a b )x  + 192a b x  + 256a x
+--R      *
+--R                    +--------------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b x + a
+--R     + 
+--R                   3     3 2  8       2 3         2 2      4   7
+--R           (48a b c  + 4b c )x  + (96a c  + 240a b c  + 14b c)x
+--R         + 
+--R                2   2         3       5  6       3 2       2 2          4  5
+--R           (480a b c  + 368a b c + 10b )x  + (32a c  + 864a b c + 182a b )x
+--R         + 
+--R                3          2 3  4          4        3 2  3       4   2       5
+--R           (208a b c + 508a b )x  + (- 320a c + 272a b )x  - 320a b x  - 256a x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                                                             +--------------+
+--R              2         2  3       2   2       3   +---+ +-+ |   2
+--R         ((64a c + 48a b )x  + 256a b x  + 256a x)\|- c \|c \|c x  + b x + a
+--R       + 
+--R                           3  4          2          2  3       2   2       3
+--R           ((- 96a b c - 8b )x  + (- 192a c - 144a b )x  - 384a b x  - 256a x)
+--R        *
+--R            +---+ +-+ +-+
+--R           \|- c \|a \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      2   4         3 3      5 2  9
+--R               (- 192a b c  - 160a b c  - 12b c )x
+--R             + 
+--R                      3 4        2 2 3         4 2      6   8
+--R               (- 384a c  - 1728a b c  - 600a b c  - 24b c)x
+--R             + 
+--R                       3   3        2 3 2         5       7  7
+--R               (- 4224a b c  - 4992a b c  - 744a b c - 12b )x
+--R             + 
+--R                       4 3         3 2 2        2 4          6  6
+--R               (- 2816a c  - 14208a b c  - 5808a b c - 304a b )x
+--R             + 
+--R                        4   2         3 3         2 5  5
+--R               (- 16320a b c  - 18720a b c - 2364a b )x
+--R             + 
+--R                       5 2         4 2         3 4  4
+--R               (- 6528a c  - 28992a b c - 8472a b )x
+--R             + 
+--R                        5            4 3  3           6          5 2  2
+--R               (- 21504a b c - 16128a b )x  + (- 6144a c - 16896a b )x
+--R             + 
+--R                      6           7
+--R               - 9216a b x - 2048a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               3 5       2 2 4        4 3    6 2  10
+--R           (64a c  + 240a b c  + 60a b c  + b c )x
+--R         + 
+--R                 3   4        2 3 3         5 2     7   9
+--R           (1280a b c  + 1440a b c  + 192a b c  + 2b c)x
+--R         + 
+--R                 4 4        3 2 3        2 4 2         6     8  8
+--R           (1280a c  + 6880a b c  + 3120a b c  + 206a b c + b )x
+--R         + 
+--R                  4   3         3 3 2        2 5         7  7
+--R           (10880a b c  + 15200a b c  + 2904a b c + 74a b )x
+--R         + 
+--R                 5 3         4 2 2         3 4        2 6  6
+--R           (5440a c  + 30960a b c  + 14860a b c + 985a b )x
+--R         + 
+--R                  5   2         4 3         3 5  5
+--R           (28032a b c  + 36160a b c + 5336a b )x
+--R         + 
+--R                 6 2         5 2          4 4  4          6            5 3  3
+--R           (9344a c  + 45504a b c + 14920a b )x  + (28672a b c + 23552a b )x
+--R         + 
+--R                 7          6 2  2         7           8
+--R           (7168a c + 21248a b )x  + 10240a b x + 2048a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 3 5       2 2 4        4 3    6 2  11
+--R           (- 64a c  - 240a b c  - 60a b c  - b c )x
+--R         + 
+--R                   3   4        2 3 3         5 2     7   10
+--R           (- 1280a b c  - 1440a b c  - 192a b c  - 2b c)x
+--R         + 
+--R                   4 4        3 2 3        2 4 2         6     8  9
+--R           (- 1280a c  - 6880a b c  - 3120a b c  - 206a b c - b )x
+--R         + 
+--R                    4   3         3 3 2        2 5         7  8
+--R           (- 10880a b c  - 15200a b c  - 2904a b c - 74a b )x
+--R         + 
+--R                   5 3         4 2 2         3 4        2 6  7
+--R           (- 5440a c  - 30960a b c  - 14860a b c - 985a b )x
+--R         + 
+--R                    5   2         4 3         3 5  6
+--R           (- 28032a b c  - 36160a b c - 5336a b )x
+--R         + 
+--R                   6 2         5 2          4 4  5
+--R           (- 9344a c  - 45504a b c - 14920a b )x
+--R         + 
+--R                    6            5 3  4           7          6 2  3
+--R           (- 28672a b c - 23552a b )x  + (- 7168a c - 21248a b )x
+--R         + 
+--R                   7   2        8
+--R           - 10240a b x  - 2048a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                2   5         3 4      5 3  12
+--R           (192a b c  + 160a b c  + 12b c )x
+--R         + 
+--R                3 5        2 2 4         4 3      6 2  11
+--R           (384a c  + 1920a b c  + 760a b c  + 36b c )x
+--R         + 
+--R                 3   4        2 3 3          5 2      7   10
+--R           (4800a b c  + 6880a b c  + 1356a b c  + 36b c)x
+--R         + 
+--R                 4 4         3 2 3         2 4 2          6       8  9
+--R           (3200a c  + 20160a b c  + 11400a b c  + 1072a b c + 12b )x
+--R         + 
+--R                  4   3         3 3 2        2 5          7  8
+--R           (23360a b c  + 37920a b c  + 8916a b c + 316a b )x
+--R         + 
+--R                 5 3         4 2 2         3 4         2 6  7
+--R           (9344a c  + 59520a b c  + 33000a b c + 2668a b )x
+--R         + 
+--R                  5   2         4 3          3 5  6
+--R           (44352a b c  + 63840a b c + 10836a b )x
+--R         + 
+--R                  6 2         5 2          4 4  5          6            5 3  4
+--R           (12672a c  + 67392a b c + 24600a b )x  + (36864a b c + 33024a b )x
+--R         + 
+--R                 7          6 2  3         7   2        8
+--R           (8192a c + 26112a b )x  + 11264a b x  + 2048a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 3 3       2 2 2        4     6  8
+--R             (64a c  + 240a b c  + 60a b c + b )x
+--R           + 
+--R                   3   2       2 3         5  7
+--R             (1152a b c  + 960a b c + 72a b )x
+--R           + 
+--R                   4 2        3 2        2 4  6         4           3 3  5
+--R             (1152a c  + 4032a b c + 840a b )x  + (6144a b c + 3584a b )x
+--R           + 
+--R                   5         4 2  4        5   3        6 2
+--R             (3072a c + 6912a b )x  + 6144a b x  + 2048a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2   3         3 2      5   9
+--R             (- 192a b c  - 160a b c  - 12b c)x
+--R           + 
+--R                    3 3        2 2 2         4       6  8
+--R             (- 384a c  - 1536a b c  - 440a b c - 12b )x
+--R           + 
+--R                     3   2        2 3          5  7
+--R             (- 3648a b c  - 3296a b c - 292a b )x
+--R           + 
+--R                     4 2        3 2         2 4  6            4           3 3  5
+--R             (- 2432a c  - 9024a b c - 2072a b )x  + (- 10240a b c - 6400a b )x
+--R           + 
+--R                     5         4 2  4        5   3        6 2
+--R             (- 4096a c - 9728a b )x  - 7168a b x  - 2048a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^6
+--R 
+--R
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R   (1)  -------------------------------------
+--R                           4
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 704
+r0:=-1/2*(a*x^2+b*x^3+c*x^4)^(3/2)/x^5-3/8*(b^2+4*a*c)*x*atanh(1/2*_
+   (2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(sqrt(a)*_
+   sqrt(a*x^2+b*x^3+c*x^4))+3/2*b*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+_
+   b*x+c*x^2)))*sqrt(c)*sqrt(a+b*x+c*x^2)/sqrt(a*x^2+b*x^3+c*x^4)-_
+   3/4*(b-2*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                         +--------------+
+--R                    2  2 |   2                        b x + 2a
+--R       (- 12a c - 3b )x \|c x  + b x + a atanh(----------------------)
+--R                                                     +--------------+
+--R                                                 +-+ |   2
+--R                                               2\|a \|c x  + b x + a
+--R     + 
+--R                      +--------------+
+--R            2 +-+ +-+ |   2                        2c x + b
+--R       12b x \|a \|c \|c x  + b x + a atanh(----------------------)
+--R                                                  +--------------+
+--R                                              +-+ |   2
+--R                                            2\|c \|c x  + b x + a
+--R     + 
+--R          2 4         3              2  2               2  +-+
+--R       (8c x  - 2b c x  + (4a c - 10b )x  - 14a b x - 4a )\|a
+--R  /
+--R            +------------------+
+--R        +-+ |   4      3      2
+--R     8x\|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3 2       2 2         4  4         3          2 3  3
+--R                 (384a c  + 384a b c + 72a b )x  + (1536a b c + 384a b )x
+--R               + 
+--R                       4        3 2  2
+--R                 (1536a c + 384a b )x
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                        2   2         3       5  5
+--R                 (- 576a b c  - 192a b c - 12b )x
+--R               + 
+--R                         3 2        2 2          4  4
+--R                 (- 1152a c  - 1152a b c - 216a b )x
+--R               + 
+--R                         3          2 3  3           4        3 2  2
+--R                 (- 2304a b c - 576a b )x  + (- 1536a c - 384a b )x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a  - b x - 2a
+--R           log(---------------------------------)
+--R                                +-+
+--R                             2x\|a
+--R       + 
+--R                     2            3  4        2 2 3        3   2  +-+ +-+
+--R               ((384a b c + 288a b )x  + 1536a b x  + 1536a b x )\|a \|c
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                        2 2         4  5           3          2 3  4
+--R                 (- 576a b c - 48a b )x  + (- 1152a b c - 864a b )x
+--R               + 
+--R                        3 2 3        4   2
+--R                 - 2304a b x  - 1536a b x
+--R            *
+--R                +-+
+--R               \|c
+--R        *
+--R           log
+--R                            2         +-+ +-+         2              2
+--R                    ((- 2b x  - 8a x)\|a \|c  + 4a c x  + 4a b x + 8a )
+--R                 *
+--R                     +--------------+
+--R                     |   2
+--R                    \|c x  + b x + a
+--R                + 
+--R                         3         2     2   +-+
+--R                  (4a c x  + 6a b x  + 8a x)\|c
+--R                + 
+--R                           3              2  2              2  +-+
+--R                  (- 2b c x  + (- 8a c - b )x  - 8a b x - 8a )\|a
+--R             /
+--R                                 +--------------+
+--R                              2  |   2
+--R                  (4a b x + 8a )\|c x  + b x + a
+--R                + 
+--R                              2  2              2  +-+
+--R                  ((- 4a c - b )x  - 8a b x - 8a )\|a
+--R       + 
+--R                    2   2        3   5          3 2      2 2         4  4
+--R             (- 384a b c  - 32a b c)x  + (- 512a c  + 24a b c - 14a b )x
+--R           + 
+--R                  3          2 3  3        4         3 2  2        4          5
+--R             (640a b c + 448a b )x  + (384a c + 1920a b )x  + 2048a b x + 512a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                  2 3         2 2  6        2   2        3      5  5
+--R             (256a c  + 192a b c )x  + (576a b c  + 28a b c + 9b )x
+--R           + 
+--R                  3 2       2 2         4  4           3           2 3  3
+--R             (384a c  - 840a b c - 78a b )x  + (- 1728a b c - 1184a b )x
+--R           + 
+--R                    4         3 2  2        4          5
+--R             (- 640a c - 2880a b )x  - 2304a b x - 512a
+--R        *
+--R            +-+
+--R           \|a
+--R    /
+--R                                                            +--------------+
+--R               2          2  4        2   3        3 2  +-+ |   2
+--R         ((256a c + 192a b )x  + 1024a b x  + 1024a x )\|a \|c x  + b x + a
+--R       + 
+--R              2           3  5          3        2 2  4        3   3        4 2
+--R       (- 384a b c - 32a b )x  + (- 768a c - 576a b )x  - 1536a b x  - 1024a x
+--R     ,
+--R
+--R                      3 2       2 2         4  4         3          2 3  3
+--R                 (384a c  + 384a b c + 72a b )x  + (1536a b c + 384a b )x
+--R               + 
+--R                       4        3 2  2
+--R                 (1536a c + 384a b )x
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                        2   2         3       5  5
+--R                 (- 576a b c  - 192a b c - 12b )x
+--R               + 
+--R                         3 2        2 2          4  4
+--R                 (- 1152a c  - 1152a b c - 216a b )x
+--R               + 
+--R                         3          2 3  3           4        3 2  2
+--R                 (- 2304a b c - 576a b )x  + (- 1536a c - 384a b )x
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a  - b x - 2a
+--R           log(---------------------------------)
+--R                                +-+
+--R                             2x\|a
+--R       + 
+--R                     2            3  4        2 2 3        3   2  +---+ +-+
+--R               ((768a b c + 576a b )x  + 3072a b x  + 3072a b x )\|- c \|a
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                         2 2         4  5           3           2 3  4
+--R                 (- 1152a b c - 96a b )x  + (- 2304a b c - 1728a b )x
+--R               + 
+--R                        3 2 3        4   2
+--R                 - 4608a b x  - 3072a b x
+--R            *
+--R                +---+
+--R               \|- c
+--R        *
+--R                     +--------------+
+--R                 +-+ |   2
+--R                \|a \|c x  + b x + a  - a
+--R           atan(-------------------------)
+--R                         +---+ +-+
+--R                       x\|- c \|a
+--R       + 
+--R                    2   2        3   5          3 2      2 2         4  4
+--R             (- 384a b c  - 32a b c)x  + (- 512a c  + 24a b c - 14a b )x
+--R           + 
+--R                  3          2 3  3        4         3 2  2        4          5
+--R             (640a b c + 448a b )x  + (384a c + 1920a b )x  + 2048a b x + 512a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                  2 3         2 2  6        2   2        3      5  5
+--R             (256a c  + 192a b c )x  + (576a b c  + 28a b c + 9b )x
+--R           + 
+--R                  3 2       2 2         4  4           3           2 3  3
+--R             (384a c  - 840a b c - 78a b )x  + (- 1728a b c - 1184a b )x
+--R           + 
+--R                    4         3 2  2        4          5
+--R             (- 640a c - 2880a b )x  - 2304a b x - 512a
+--R        *
+--R            +-+
+--R           \|a
+--R    /
+--R                                                            +--------------+
+--R               2          2  4        2   3        3 2  +-+ |   2
+--R         ((256a c + 192a b )x  + 1024a b x  + 1024a x )\|a \|c x  + b x + a
+--R       + 
+--R              2           3  5          3        2 2  4        3   3        4 2
+--R       (- 384a b c - 32a b )x  + (- 768a c - 576a b )x  - 1536a b x  - 1024a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 283
+
+--S 284 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    2 2         2       4  4         2            3  3
+--R               (384a c  + 384a b c + 72b )x  + (1536a b c + 384a b )x
+--R             + 
+--R                     3        2 2  2
+--R               (1536a c + 384a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                  2   2         3       5  5
+--R           (- 576a b c  - 192a b c - 12b )x
+--R         + 
+--R                   3 2        2 2          4  4           3          2 3  3
+--R           (- 1152a c  - 1152a b c - 216a b )x  + (- 2304a b c - 576a b )x
+--R         + 
+--R                   4        3 2  2
+--R           (- 1536a c - 384a b )x
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                   2            3  4        2 2 3        3   2  +-+
+--R             ((384a b c + 288a b )x  + 1536a b x  + 1536a b x )\|c
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        2       4  5           2            3  4        2 2 3
+--R               (- 576a b c - 48b )x  + (- 1152a b c - 864a b )x  - 2304a b x
+--R             + 
+--R                      3   2
+--R               - 1536a b x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                          2         +-+ +-+         2              2
+--R                  ((- 2b x  - 8a x)\|a \|c  + 4a c x  + 4a b x + 8a )
+--R               *
+--R                   +--------------+
+--R                   |   2
+--R                  \|c x  + b x + a
+--R              + 
+--R                       3         2     2   +-+
+--R                (4a c x  + 6a b x  + 8a x)\|c
+--R              + 
+--R                         3              2  2              2  +-+
+--R                (- 2b c x  + (- 8a c - b )x  - 8a b x - 8a )\|a
+--R           /
+--R                               +--------------+
+--R                            2  |   2
+--R                (4a b x + 8a )\|c x  + b x + a
+--R              + 
+--R                            2  2              2  +-+
+--R                ((- 4a c - b )x  - 8a b x - 8a )\|a
+--R     + 
+--R                      2   2         3       5  6
+--R               (- 576a b c  - 192a b c - 12b )x
+--R             + 
+--R                       3 2        2 2          4  5           3          2 3  4
+--R               (- 1152a c  - 1152a b c - 216a b )x  + (- 2304a b c - 576a b )x
+--R             + 
+--R                       4        3 2  3
+--R               (- 1536a c - 384a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2 3         2 2      4   7
+--R               (384a c  + 384a b c  + 72b c)x
+--R             + 
+--R                     2   2         3       5  6
+--R               (1920a b c  + 768a b c + 72b )x
+--R             + 
+--R                     3 2        2 2          4  5         3          2 3  4
+--R               (1920a c  + 2304a b c + 456a b )x  + (3072a b c + 768a b )x
+--R             + 
+--R                     4        3 2  3
+--R               (1536a c + 384a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                      2       4  6         2            3  5        2 2 4
+--R               (576a b c + 48b )x  + (1152a b c + 864a b )x  + 2304a b x
+--R             + 
+--R                    3   3
+--R               1536a b x
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                      2   2         3   7           2 2          4  6
+--R               (- 384a b c  - 288a b c)x  + (- 1920a b c - 288a b )x
+--R             + 
+--R                       3           2 3  5        3 2 4        4   3
+--R               (- 1920a b c - 1824a b )x  - 3072a b x  - 1536a b x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                          2      3   5          2 2        2       4  4
+--R               (- 384a b c  - 32b c)x  + (- 512a c  + 24a b c - 14b )x
+--R             + 
+--R                  2            3  3        3         2 2  2        3          4
+--R             (640a b c + 448a b )x  + (384a c + 1920a b )x  + 2048a b x + 512a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                2 3         2 2  6        2   2        3      5  5
+--R           (256a c  + 192a b c )x  + (576a b c  + 28a b c + 9b )x
+--R         + 
+--R                3 2       2 2         4  4           3           2 3  3
+--R           (384a c  - 840a b c - 78a b )x  + (- 1728a b c - 1184a b )x
+--R         + 
+--R                  4         3 2  2        4          5
+--R           (- 640a c - 2880a b )x  - 2304a b x - 512a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  2 3         2 2  7          2   2        3   6
+--R           (- 256a c  - 192a b c )x  + (- 960a b c  + 48a b c)x
+--R         + 
+--R                   3 2       2 2          4  5        3           2 3  4
+--R           (- 1152a c  + 480a b c + 240a b )x  + (192a b c + 1616a b )x
+--R         + 
+--R                  4         3 2  3        4   2       5
+--R           (- 384a c + 3168a b )x  + 2304a b x  + 512a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                    3      3 2  8        2 3         2 2     4   7
+--R           (384a b c  + 32b c )x  + (768a c  + 480a b c  - 8b c)x
+--R         + 
+--R                 2   2         3       5  6         3 2        2 2          4  5
+--R           (1536a b c  - 608a b c - 40b )x  + (1408a c  - 1728a b c - 776a b )x
+--R         + 
+--R                   3           2 3  4        4         3 2  3        4   2
+--R           (- 1024a b c - 2944a b )x  + (128a c - 4256a b )x  - 2560a b x
+--R         + 
+--R                 5
+--R           - 512a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                        +--------------+
+--R               2          2  4        2   3        3 2  |   2
+--R         ((256a c + 192a b )x  + 1024a b x  + 1024a x )\|c x  + b x + a
+--R       + 
+--R                              3  5          2          2  4        2   3
+--R             (- 384a b c - 32b )x  + (- 768a c - 576a b )x  - 1536a b x
+--R           + 
+--R                    3 2
+--R             - 1024a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                              6 7         5 2 6         4 4 5         3 6 4
+--R                       - 4096a c  - 56320a b c  - 84480a b c  - 29568a b c
+--R                     + 
+--R                              2 8 3        10 2
+--R                       - 2640a b c  - 44a b  c
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                                6   6           5 3 5          4 5 4
+--R                       - 276480a b c  - 1098240a b c  - 836352a b c
+--R                     + 
+--R                                3 7 3        2 9 2        11
+--R                       - 171072a b c  - 9240a b c  - 90a b  c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                                7 6           6 2 5           5 4 4
+--R                       - 299008a c  - 4445184a b c  - 7434240a b c
+--R                     + 
+--R                                 4 6 3          3 8 2         2 10         12
+--R                       - 3062400a b c  - 359568a b c  - 10692a b  c - 46a b
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                                 7   5            6 3 4            5 5 3
+--R                       - 6998016a b c  - 29120000a b c  - 23606528a b c
+--R                     + 
+--R                                 4 7 2          3 9         2 11
+--R                       - 5277888a b c  - 327272a b c - 4094a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                 8 5            7 2 4            6 4 3
+--R                       - 3735552a c  - 55848960a b c  - 93634560a b c
+--R                     + 
+--R                                  5 6 2           4 8           3 10
+--R                       - 38303232a b c  - 4333824a b c - 109296a b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                  8   4             7 3 3             6 5 2
+--R                       - 51388416a b c  - 206028800a b c  - 156509184a b c
+--R                     + 
+--R                                  5 7            4 9
+--R                       - 30750720a b c - 1368224a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                  9 4             8 2 3             7 4 2
+--R                       - 18120704a c  - 253804544a b c  - 383631360a b c
+--R                     + 
+--R                                   6 6            5 8
+--R                       - 130364416a b c - 9682816a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                   9   3             8 3 2             7 5
+--R                       - 163676160a b c  - 575594496a b c  - 349784064a b c
+--R                     + 
+--R                                  6 7
+--R                       - 42711552a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                  10 3             9 2 2             8 4
+--R                       - 42991616a  c  - 517472256a b c  - 609091584a b c
+--R                     + 
+--R                                   7 6
+--R                       - 123977728a b
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                10   2             9 3              8 5  6
+--R                   (- 255852544a  b c  - 686686208a b c - 243433472a b )x
+--R                 + 
+--R                               11 2             10 2              9 4  5
+--R                   (- 53477376a  c  - 483655680a  b c - 325582848a b )x
+--R                 + 
+--R                                11                10 3  4
+--R                   (- 193462272a  b c - 292421632a  b )x
+--R                 + 
+--R                               12              11 2  3            12   2
+--R                   (- 33554432a  c - 168820736a  b )x  - 56623104a  b x
+--R                 + 
+--R                             13
+--R                   - 8388608a  x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                             5   7         4 3 6         3 5 5         2 7 4
+--R                       22528a b c  + 84480a b c  + 59136a b c  + 10560a b c
+--R                     + 
+--R                             9 3     11 2
+--R                       440a b c  + 2b  c
+--R                  *
+--R                      15
+--R                     x
+--R                 + 
+--R                             6 7          5 2 6           4 4 5          3 6 4
+--R                       49152a c  + 709632a b c  + 1140480a b c  + 443520a b c
+--R                     + 
+--R                             2 8 3          10 2     12
+--R                       47520a b c  + 1188a b  c  + 3b  c
+--R                  *
+--R                      14
+--R                     x
+--R                 + 
+--R                               6   6           5 3 5           4 5 4
+--R                       1718272a b c  + 7079424a b c  + 5677056a b c
+--R                     + 
+--R                               3 7 3         2 9 2          11     13
+--R                       1256640a b c  + 77880a b c  + 1038a b  c + b
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                               7 6            6 2 5            5 4 4
+--R                       1245184a c  + 18840576a b c  + 32257280a b c
+--R                     + 
+--R                                4 6 3           3 8 2         2 10          12
+--R                       13732224a b c  + 1694880a b c  + 54956a b  c + 289a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                                7   5            6 3 4            5 5 3
+--R                       22339584a b c  + 93634560a b c  + 76606464a b c
+--R                     + 
+--R                                4 7 2           3 9          2 11
+--R                       17335296a b c  + 1092960a b c + 14016a b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                               8 5             7 2 4             6 4 3
+--R                       9682944a c  + 144384000a b c  + 241080320a b c
+--R                     + 
+--R                                5 6 2            4 8           3 10
+--R                       97963008a b c  + 10954944a b c + 269984a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                 8   4             7 3 3             6 5 2
+--R                       112394240a b c  + 445276160a b c  + 332666880a b c
+--R                     + 
+--R                                5 7            4 9
+--R                       63771136a b c + 2727296a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                9 4             8 2 3             7 4 2
+--R                       34701312a c  + 478003200a b c  + 706682880a b c
+--R                     + 
+--R                                 6 6             5 8
+--R                       232866816a b c + 16528512a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                 9   3             8 3 2             7 5
+--R                       275775488a b c  + 945684480a b c  + 555712512a b c
+--R                     + 
+--R                                6 7
+--R                       64749568a b
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                10 3             9 2 2             8 4
+--R                       66060288a  c  + 774111232a b c  + 880148480a b c
+--R                     + 
+--R                                 7 6
+--R                       171016192a b
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                              10   2             9 3              8 5  5
+--R                   (353894400a  b c  + 917372928a b c + 310837248a b )x
+--R                 + 
+--R                             11 2             10 2              9 4  4
+--R                   (69206016a  c  + 604766208a  b c + 389742592a b )x
+--R                 + 
+--R                              11                10 3  3
+--R                   (228589568a  b c + 331350016a  b )x
+--R                 + 
+--R                           12              11 2  2            12              13
+--R                 (37748736a  c + 182452224a  b )x  + 58720256a  b x + 8388608a
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                         5   7         4 3 6         3 5 5         2 7 4
+--R                   22528a b c  + 84480a b c  + 59136a b c  + 10560a b c
+--R                 + 
+--R                         9 3     11 2
+--R                   440a b c  + 2b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                         6 7          5 2 6           4 4 5          3 6 4
+--R                   49152a c  + 720896a b c  + 1182720a b c  + 473088a b c
+--R                 + 
+--R                         2 8 3          10 2     12
+--R                   52800a b c  + 1408a b  c  + 4b  c
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                           6   6           5 3 5           4 5 4           3 7 3
+--R                   1740800a b c  + 7400448a b c  + 6183936a b c  + 1448832a b c
+--R                 + 
+--R                         2 9 2          11      13
+--R                   97680a b c  + 1500a b  c + 2b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                           7 6            6 2 5            5 4 4
+--R                   1245184a c  + 19550208a b c  + 35087360a b c
+--R                 + 
+--R                            4 6 3           3 8 2         2 10          12
+--R                   15899136a b c  + 2141568a b c  + 79376a b  c + 532a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                            7   5             6 3 4            5 5 3
+--R                   22812672a b c  + 100477440a b c  + 87602944a b c
+--R                 + 
+--R                            4 7 2           3 9          2 11
+--R                   21586752a b c  + 1537272a b c + 23938a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                           8 5             7 2 4             6 4 3
+--R                   9682944a c  + 151818240a b c  + 269916160a b c
+--R                 + 
+--R                             5 6 2            4 8           3 10
+--R                   118964736a b c  + 14857920a b c + 430672a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                             8   4             7 3 3             6 5 2
+--R                   115367936a b c  + 485826560a b c  + 391971840a b c
+--R                 + 
+--R                            5 7            4 9
+--R                   83100160a b c + 4086368a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            9 4             8 2 3             7 4 2
+--R                   34701312a c  + 507019264a b c  + 806031360a b c
+--R                 + 
+--R                             6 6             5 8
+--R                   291293184a b c + 23374208a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                             9   3              8 3 2             7 5
+--R                   284065792a b c  + 1043275776a b c  + 667564032a b c
+--R                 + 
+--R                            6 7
+--R                   86787584a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            10 3             9 2 2              8 4
+--R                   66060288a  c  + 826015744a b c  + 1016397824a b c
+--R                 + 
+--R                             7 6
+--R                   218054656a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                          10   2              9 3              8 5  6
+--R               (365428736a  b c  + 1019740160a b c + 378241024a b )x
+--R             + 
+--R                         11 2             10 2              9 4  5
+--R               (69206016a  c  + 648019968a  b c + 453902336a b )x
+--R             + 
+--R                          11                10 3  4
+--R               (236453888a  b c + 370278400a  b )x
+--R             + 
+--R                       12              11 2  3            12   2           13
+--R             (37748736a  c + 196083712a  b )x  + 60817408a  b x  + 8388608a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                      6 8         5 2 7         4 4 6         3 6 5        2 8 4
+--R               - 4096a c  - 56320a b c  - 84480a b c  - 29568a b c  - 2640a b c
+--R             + 
+--R                      10 3
+--R               - 44a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                        6   7           5 3 6          4 5 5          3 7 4
+--R               - 278528a b c  - 1126400a b c  - 878592a b c  - 185856a b c
+--R             + 
+--R                       2 9 3         11 2
+--R               - 10560a b c  - 112a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        7 7           6 2 6           5 4 5           4 6 4
+--R               - 303104a c  - 4651008a b c  - 8110080a b c  - 3539712a b c
+--R             + 
+--R                        3 8 3         2 10 2        12
+--R               - 453024a b c  - 15576a b  c  - 92a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                         7   6            6 3 5            5 5 4           4 7 3
+--R               - 7446528a b c  - 32761856a b c  - 28666880a b c  - 7172352a b c
+--R             + 
+--R                        3 9 2        2 11         13
+--R               - 536096a b c  - 9992a b  c - 24a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         8 6            7 2 5             6 4 4            5 6 3
+--R               - 4034560a c  - 64502784a b c  - 118458880a b c  - 55335808a b c
+--R             + 
+--R                         4 8 2          3 10         2 12
+--R               - 7779024a b c  - 308044a b  c - 2336a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          8   5             7 3 4             6 5 3
+--R               - 60727296a b c  - 269916160a b c  - 237929472a b c
+--R             + 
+--R                          5 7 2           4 9          3 11
+--R               - 59431680a b c  - 4306720a b c - 68664a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          9 5             8 2 4             7 4 3
+--R               - 21856256a c  - 342781952a b c  - 609116160a b c
+--R             + 
+--R                           6 6 2            5 8           4 10
+--R               - 267923968a b c  - 33294976a b c - 954096a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                           9   4             8 3 3             7 5 2
+--R               - 227098624a b c  - 949075968a b c  - 757413888a b c
+--R             + 
+--R                           6 7            5 9
+--R               - 157973504a b c - 7568704a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                          10 4             9 2 3              8 4 2
+--R               - 61112320a  c  - 882130944a b c  - 1379868672a b c
+--R             + 
+--R                           7 6             6 8
+--R               - 487660544a b c - 37884288a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                           10   3              9 3 2              8 5
+--R               - 449314816a  b c  - 1618608128a b c  - 1009614848a b c
+--R             + 
+--R                           7 7
+--R               - 126738432a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                          11 3              10 2 2              9 4
+--R               - 96468992a  c  - 1180958720a  b c  - 1414266880a b c
+--R             + 
+--R                           8 6
+--R               - 292732928a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                        11   2              10 3              9 5  5
+--R           (- 487587840a  b c  - 1323302912a  b c - 473628672a b )x
+--R         + 
+--R                       12 2             11 2              10 4  4
+--R           (- 87031808a  c  - 792461312a  b c - 535953408a  b )x
+--R         + 
+--R                        12                11 3  3
+--R           (- 274726912a  b c - 415760384a  b )x
+--R         + 
+--R                       13              12 2  2            13              14
+--R           (- 41943040a  c - 210763776a  b )x  - 62914560a  b x - 8388608a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                           5   7         4 3 6         3 5 5         2 7 4
+--R                   - 22528a b c  - 84480a b c  - 59136a b c  - 10560a b c
+--R                 + 
+--R                           9 3     11 2
+--R                   - 440a b c  - 2b  c
+--R              *
+--R                  17
+--R                 x
+--R             + 
+--R                           6 7          5 2 6           4 4 5          3 6 4
+--R                   - 49152a c  - 720896a b c  - 1182720a b c  - 473088a b c
+--R                 + 
+--R                           2 8 3          10 2     12
+--R                   - 52800a b c  - 1408a b  c  - 4b  c
+--R              *
+--R                  16
+--R                 x
+--R             + 
+--R                             6   6           5 3 5           4 5 4
+--R                   - 1740800a b c  - 7400448a b c  - 6183936a b c
+--R                 + 
+--R                             3 7 3         2 9 2          11      13
+--R                   - 1448832a b c  - 97680a b c  - 1500a b  c - 2b
+--R              *
+--R                  15
+--R                 x
+--R             + 
+--R                             7 6            6 2 5            5 4 4
+--R                   - 1245184a c  - 19550208a b c  - 35087360a b c
+--R                 + 
+--R                              4 6 3           3 8 2         2 10          12
+--R                   - 15899136a b c  - 2141568a b c  - 79376a b  c - 532a b
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                              7   5             6 3 4            5 5 3
+--R                   - 22812672a b c  - 100477440a b c  - 87602944a b c
+--R                 + 
+--R                              4 7 2           3 9          2 11
+--R                   - 21586752a b c  - 1537272a b c - 23938a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                             8 5             7 2 4             6 4 3
+--R                   - 9682944a c  - 151818240a b c  - 269916160a b c
+--R                 + 
+--R                               5 6 2            4 8           3 10
+--R                   - 118964736a b c  - 14857920a b c - 430672a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                               8   4             7 3 3             6 5 2
+--R                   - 115367936a b c  - 485826560a b c  - 391971840a b c
+--R                 + 
+--R                              5 7            4 9
+--R                   - 83100160a b c - 4086368a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                              9 4             8 2 3             7 4 2
+--R                   - 34701312a c  - 507019264a b c  - 806031360a b c
+--R                 + 
+--R                               6 6             5 8
+--R                   - 291293184a b c - 23374208a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                               9   3              8 3 2             7 5
+--R                   - 284065792a b c  - 1043275776a b c  - 667564032a b c
+--R                 + 
+--R                              6 7
+--R                   - 86787584a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                              10 3             9 2 2              8 4
+--R                   - 66060288a  c  - 826015744a b c  - 1016397824a b c
+--R                 + 
+--R                               7 6
+--R                   - 218054656a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            10   2              9 3              8 5  7
+--R               (- 365428736a  b c  - 1019740160a b c - 378241024a b )x
+--R             + 
+--R                           11 2             10 2              9 4  6
+--R               (- 69206016a  c  - 648019968a  b c - 453902336a b )x
+--R             + 
+--R                            11                10 3  5
+--R               (- 236453888a  b c - 370278400a  b )x
+--R             + 
+--R                           12              11 2  4            12   3
+--R               (- 37748736a  c - 196083712a  b )x  - 60817408a  b x
+--R             + 
+--R                         13 2
+--R               - 8388608a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                    6 8         5 2 7         4 4 6         3 6 5        2 8 4
+--R               4096a c  + 56320a b c  + 84480a b c  + 29568a b c  + 2640a b c
+--R             + 
+--R                    10 3
+--R               44a b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                      6   7           5 3 6          4 5 5          3 7 4
+--R               278528a b c  + 1126400a b c  + 878592a b c  + 185856a b c
+--R             + 
+--R                     2 9 3         11 2
+--R               10560a b c  + 112a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                      7 7           6 2 6           5 4 5           4 6 4
+--R               303104a c  + 4651008a b c  + 8110080a b c  + 3539712a b c
+--R             + 
+--R                      3 8 3         2 10 2        12
+--R               453024a b c  + 15576a b  c  + 92a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                       7   6            6 3 5            5 5 4           4 7 3
+--R               7446528a b c  + 32761856a b c  + 28666880a b c  + 7172352a b c
+--R             + 
+--R                      3 9 2        2 11         13
+--R               536096a b c  + 9992a b  c + 24a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                       8 6            7 2 5             6 4 4            5 6 3
+--R               4034560a c  + 64502784a b c  + 118458880a b c  + 55335808a b c
+--R             + 
+--R                       4 8 2          3 10         2 12
+--R               7779024a b c  + 308044a b  c + 2336a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                        8   5             7 3 4             6 5 3
+--R               60727296a b c  + 269916160a b c  + 237929472a b c
+--R             + 
+--R                        5 7 2           4 9          3 11
+--R               59431680a b c  + 4306720a b c + 68664a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        9 5             8 2 4             7 4 3
+--R               21856256a c  + 342781952a b c  + 609116160a b c
+--R             + 
+--R                         6 6 2            5 8           4 10
+--R               267923968a b c  + 33294976a b c + 954096a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         9   4             8 3 3             7 5 2
+--R               227098624a b c  + 949075968a b c  + 757413888a b c
+--R             + 
+--R                         6 7            5 9
+--R               157973504a b c + 7568704a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        10 4             9 2 3              8 4 2
+--R               61112320a  c  + 882130944a b c  + 1379868672a b c
+--R             + 
+--R                         7 6             6 8
+--R               487660544a b c + 37884288a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                         10   3              9 3 2              8 5
+--R               449314816a  b c  + 1618608128a b c  + 1009614848a b c
+--R             + 
+--R                         7 7
+--R               126738432a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                          11 3              10 2 2              9 4
+--R                 96468992a  c  + 1180958720a  b c  + 1414266880a b c
+--R               + 
+--R                           8 6
+--R                 292732928a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                      11   2              10 3              9 5  6
+--R           (487587840a  b c  + 1323302912a  b c + 473628672a b )x
+--R         + 
+--R                     12 2             11 2              10 4  5
+--R           (87031808a  c  + 792461312a  b c + 535953408a  b )x
+--R         + 
+--R                      12                11 3  4
+--R           (274726912a  b c + 415760384a  b )x
+--R         + 
+--R                     13              12 2  3            13   2           14
+--R           (41943040a  c + 210763776a  b )x  + 62914560a  b x  + 8388608a  x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                    6 8         5 2 7         4 4 6         3 6 5        2 8 4
+--R               4096a c  + 56320a b c  + 84480a b c  + 29568a b c  + 2640a b c
+--R             + 
+--R                    10 3
+--R               44a b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                      6   7           5 3 6          4 5 5          3 7 4
+--R               280576a b c  + 1154560a b c  + 920832a b c  + 200640a b c
+--R             + 
+--R                     2 9 3         11 2
+--R               11880a b c  + 134a b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                      7 7           6 2 6           5 4 5           4 6 4
+--R               303104a c  + 4777984a b c  + 8616960a b c  + 3928320a b c
+--R             + 
+--R                      3 8 3         2 10 2         12
+--R               533280a b c  + 19976a b  c  + 136a b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                       7   6            6 3 5            5 5 4           4 7 3
+--R               7573504a b c  + 34663424a b c  + 31877120a b c  + 8511360a b c
+--R             + 
+--R                      3 9 2         2 11         13
+--R               696080a b c  + 14876a b  c + 46a b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                       8 6            7 2 5             6 4 4            5 6 3
+--R               4034560a c  + 67292160a b c  + 130188800a b c  + 64972160a b c
+--R             + 
+--R                       4 8 2          3 10         2 12
+--R               9971280a b c  + 447260a b  c + 4140a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        8   5             7 3 4             6 5 3
+--R               62121984a b c  + 290997760a b c  + 273750272a b c
+--R             + 
+--R                        5 7 2           4 9           3 11
+--R               74331840a b c  + 6029320a b c + 113390a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                        9 5             8 2 4             7 4 3
+--R               21856256a c  + 361041920a b c  + 683294720a b c
+--R             + 
+--R                         6 6 2            5 8            4 10
+--R               325176832a b c  + 44767360a b c + 1477520a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         9   4              8 3 3             7 5 2
+--R               233185280a b c  + 1035427840a b c  + 889924608a b c
+--R             + 
+--R                         6 7             5 9
+--R               203826688a b c + 11051040a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        10 4             9 2 3              8 4 2
+--R               61112320a  c  + 934952960a b c  + 1568317440a b c
+--R             + 
+--R                         7 6             6 8
+--R               604126208a b c + 52394368a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         10   3              9 3 2              8 5
+--R               462520320a  b c  + 1779752960a b c  + 1202309120a b c
+--R             + 
+--R                         7 7
+--R               166689280a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                          11 3              10 2 2              9 4
+--R                 96468992a  c  + 1256980480a  b c  + 1621360640a b c
+--R               + 
+--R                           8 6
+--R                 367411200a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      11   2              10 3              9 5  7
+--R           (502792192a  b c  + 1462763520a  b c + 569016320a b )x
+--R         + 
+--R                     12 2             11 2              10 4  6
+--R           (87031808a  c  + 845938688a  b c + 618004480a  b )x
+--R         + 
+--R                      12                11 3  5
+--R           (283639808a  b c + 461242368a  b )x
+--R         + 
+--R                     13              12 2  4            13   3           14 2
+--R           (41943040a  c + 225443840a  b )x  + 65011712a  b x  + 8388608a  x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                       5   8         4 3 7         3 5 6         2 7 5
+--R               - 22528a b c  - 84480a b c  - 59136a b c  - 10560a b c
+--R             + 
+--R                       9 4     11 3
+--R               - 440a b c  - 2b  c
+--R          *
+--R              18
+--R             x
+--R         + 
+--R                       6 8          5 2 7           4 4 6          3 6 5
+--R               - 49152a c  - 732160a b c  - 1224960a b c  - 502656a b c
+--R             + 
+--R                       2 8 4          10 3     12 2
+--R               - 58080a b c  - 1628a b  c  - 5b  c
+--R          *
+--R              17
+--R             x
+--R         + 
+--R                         6   7           5 3 6           4 5 5           3 7 4
+--R               - 1789952a b c  - 7873536a b c  - 6876672a b c  - 1710720a b c
+--R             + 
+--R                        2 9 3          11 2     13
+--R               - 125840a b c  - 2228a b  c  - 4b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                         7 7            6 2 6            5 4 5            4 6 4
+--R               - 1294336a c  - 21268480a b c  - 40477184a b c  - 19852800a b c
+--R             + 
+--R                         3 8 3          2 10 2          12     14
+--R               - 2999040a b c  - 134024a b  c  - 1330a b  c - b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                          7   6             6 3 5             5 5 4
+--R               - 25303040a b c  - 119554560a b c  - 114540800a b c
+--R             + 
+--R                          4 7 3           3 9 2         2 11          13
+--R               - 32324160a b c  - 2865720a b c  - 70010a b  c - 290a b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                          8 6             7 2 5             6 4 4
+--R               - 10928128a c  - 185564160a b c  - 366972160a b c
+--R             + 
+--R                           5 6 3            4 8 2           3 10          2 12
+--R               - 188301696a b c  - 29985120a b c  - 1417900a b  c - 14305a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                           8   5             7 3 4             6 5 3
+--R               - 144416768a b c  - 683294720a b c  - 650353664a b c
+--R             + 
+--R                           5 7 2            4 9           3 11
+--R               - 179069440a b c  - 14775200a b c - 284000a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                          9 5             8 2 4              7 4 3
+--R               - 44384256a c  - 734781440a b c  - 1393039360a b c
+--R             + 
+--R                           6 6 2            5 8            4 10
+--R               - 663496704a b c  - 91254592a b c - 2997280a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                           9   4              8 3 3              7 5 2
+--R               - 422871040a b c  - 1868963840a b c  - 1595062272a b c
+--R             + 
+--R                           6 7             5 9
+--R               - 361387520a b c - 19255808a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                           10 4              9 2 3              8 4 2
+--R               - 100761600a  c  - 1527889920a b c  - 2532515840a b c
+--R             + 
+--R                           7 6             6 8
+--R               - 959595520a b c - 81278080a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                           10   3              9 3 2              8 5
+--R               - 695730176a  b c  - 2637168640a b c  - 1746698240a b c
+--R             + 
+--R                           7 7
+--R               - 235765760a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                           11 3              10 2 2              9 4
+--R               - 135266304a  c  - 1732771840a  b c  - 2187264000a b c
+--R             + 
+--R                           8 6
+--R               - 481853440a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                        11   2              10 3              9 5  6
+--R           (- 651689984a  b c  - 1853489152a  b c - 700579840a b )x
+--R         + 
+--R                        12 2              11 2              10 4  5
+--R           (- 106954752a  c  - 1015808000a  b c - 721092608a  b )x
+--R         + 
+--R                        12                11 3  4
+--R           (- 325058560a  b c - 513802240a  b )x
+--R         + 
+--R                       13              12 2  3            13   2           14
+--R           (- 46137344a  c - 241172480a  b )x  - 67108864a  b x  - 8388608a  x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                           5   5         4 3 4         3 5 3         2 7 2
+--R                     22528a b c  + 84480a b c  + 59136a b c  + 10560a b c
+--R                   + 
+--R                           9      11
+--R                     440a b c + 2b
+--R                *
+--R                    15
+--R                   x
+--R               + 
+--R                           6 5          5 2 4           4 4 3          3 6 2
+--R                     49152a c  + 675840a b c  + 1013760a b c  + 354816a b c
+--R                   + 
+--R                           2 8          10
+--R                     31680a b c + 528a b
+--R                *
+--R                    14
+--R                   x
+--R               + 
+--R                             6   4           5 3 3           4 5 2          3 7
+--R                     1597440a b c  + 5857280a b c  + 3953664a b c  + 658944a b c
+--R                   + 
+--R                           2 9
+--R                     22880a b
+--R                *
+--R                    13
+--R                   x
+--R               + 
+--R                             7 4            6 2 3            5 4 2
+--R                     1146880a c  + 14909440a b c  + 20500480a b c
+--R                   + 
+--R                             4 6           3 8
+--R                     6150144a b c + 384384a b
+--R                *
+--R                    12
+--R                   x
+--R               + 
+--R                                7   3            6 3 2            5 5
+--R                       17203200a b c  + 55910400a b c  + 30750720a b c
+--R                     + 
+--R                               4 7
+--R                       3294720a b
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                            8 3            7 2 2            6 4             5 6
+--R                   (7340032a c  + 82575360a b c  + 89456640a b c + 16400384a b )
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                           8   2             7 3             6 5  9
+--R                 (62390272a b c  + 155975680a b c + 50692096a b )x
+--R               + 
+--R                           9 2             8 2              7 4  8
+--R                 (18874368a c  + 160432128a b c + 100270080a b )x
+--R               + 
+--R                           9                8 3  7
+--R                 (89653248a b c + 127008768a b )x
+--R               + 
+--R                         10             9 2  6            10   5           11 4
+--R               (20971520a  c + 99614720a b )x  + 44040192a  b x  + 8388608a  x
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                        6 6         5 2 5         4 4 4         3 6 3
+--R                 - 4096a c  - 56320a b c  - 84480a b c  - 29568a b c
+--R               + 
+--R                        2 8 2        10
+--R                 - 2640a b c  - 44a b  c
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                          6   5           5 3 4          4 5 3          3 7 2
+--R                 - 270336a b c  - 1013760a b c  - 709632a b c  - 126720a b c
+--R               + 
+--R                        2 9         11
+--R                 - 5280a b c - 24a b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                          7 5           6 2 4           5 4 3           4 6 2
+--R                 - 294912a c  - 3993600a b c  - 5857280a b c  - 1976832a b c
+--R               + 
+--R                          3 8         2 10
+--R                 - 164736a b c - 2288a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                           7   4            6 3 3            5 5 2
+--R                 - 6307840a b c  - 22364160a b c  - 14350336a b c
+--R               + 
+--R                           4 7          3 9
+--R                 - 2196480a b c - 64064a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                           8 4            7 2 3            6 4 2            5 6
+--R                 - 3440640a c  - 43008000a b c  - 55910400a b c  - 15375360a b c
+--R               + 
+--R                          4 8
+--R                 - 823680a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                              8   3             7 3 2            6 5
+--R                   - 40370176a b c  - 123863040a b c  - 62619648a b c
+--R                 + 
+--R                             5 7
+--R                   - 5857280a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                              9 3             8 2 2             7 4
+--R                   - 14680064a c  - 155975680a b c  - 155975680a b c
+--R                 + 
+--R                              6 6
+--R                   - 25346048a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                          9   2             8 3             7 5  8
+--R             (- 103809024a b c  - 240648192a b c - 70189056a b )x
+--R           + 
+--R                         10 2             9 2              8 4  7
+--R             (- 28311552a  c  - 224133120a b c - 127008768a b )x
+--R           + 
+--R                          10                9 3  6
+--R             (- 115343360a  b c - 149422080a b )x
+--R           + 
+--R                       11              10 2  5            11   4           12 3
+--R           (- 25165824a  c - 110100480a  b )x  - 46137344a  b x  - 8388608a  x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                        6 6         5 2 5         4 4 4         3 6 3
+--R                 - 4096a c  - 56320a b c  - 84480a b c  - 29568a b c
+--R               + 
+--R                        2 8 2        10
+--R                 - 2640a b c  - 44a b  c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                          6   5           5 3 4          4 5 3          3 7 2
+--R                 - 272384a b c  - 1041920a b c  - 751872a b c  - 141504a b c
+--R               + 
+--R                        2 9         11
+--R                 - 6600a b c - 46a b
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                          7 5           6 2 4           5 4 3           4 6 2
+--R                 - 294912a c  - 4116480a b c  - 6307840a b c  - 2280960a b c
+--R               + 
+--R                          3 8         2 10
+--R                 - 215424a b c - 4048a b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                           7   4            6 3 3            5 5 2
+--R                 - 6430720a b c  - 23961600a b c  - 16546816a b c
+--R               + 
+--R                           4 7           3 9
+--R                 - 2855424a b c - 105248a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                           8 4            7 2 3            6 4 2            5 6
+--R                 - 3440640a c  - 45301760a b c  - 63365120a b c  - 19475456a b c
+--R               + 
+--R                           4 8
+--R                 - 1262976a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                              8   3             7 3 2            6 5
+--R                   - 41517056a b c  - 136765440a b c  - 76597248a b c
+--R                 + 
+--R                             5 7
+--R                   - 8419840a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                              9 3             8 2 2             7 4
+--R                   - 14680064a c  - 166985728a b c  - 183500800a b c
+--R                 + 
+--R                              6 6
+--R                   - 34291712a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          9   2             8 3             7 5  9
+--R             (- 107479040a b c  - 271843328a b c - 89686016a b )x
+--R           + 
+--R                         10 2             9 2              8 4  8
+--R             (- 28311552a  c  - 243007488a b c - 153747456a b )x
+--R           + 
+--R                          10                9 3  7
+--R             (- 120061952a  b c - 171835392a b )x
+--R           + 
+--R                       11              10 2  6            11   5           12 4
+--R           (- 25165824a  c - 120586240a  b )x  - 48234496a  b x  - 8388608a  x
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                       5   6         4 3 5         3 5 4         2 7 3
+--R                 22528a b c  + 84480a b c  + 59136a b c  + 10560a b c
+--R               + 
+--R                       9 2     11
+--R                 440a b c  + 2b  c
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                       6 6          5 2 5           4 4 4          3 6 3
+--R                 49152a c  + 687104a b c  + 1056000a b c  + 384384a b c
+--R               + 
+--R                       2 8 2         10     12
+--R                 36960a b c  + 748a b  c + b
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                         6   5           5 3 4           4 5 3          3 7 2
+--R                 1646592a b c  + 6307840a b c  + 4561920a b c  + 861696a b c
+--R               + 
+--R                       2 9          11
+--R                 40480a b c + 288a b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                         7 5            6 2 4            5 4 3           4 6 2
+--R                 1196032a c  + 16506880a b c  + 24893440a b c  + 8785920a b c
+--R               + 
+--R                        3 8          2 10
+--R                 796224a b c + 13728a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                          7   4            6 3 3            5 5 2           4 7
+--R                 19496960a b c  + 70819840a b c  + 47151104a b c  + 7687680a b c
+--R               + 
+--R                        3 9
+--R                 256256a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                         8 4             7 2 3             6 4 2            5 6
+--R                 8486912a c  + 108380160a b c  + 145367040a b c  + 42025984a b c
+--R               + 
+--R                         4 8
+--R                 2471040a b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                            8   3             7 3 2             6 5
+--R                   84410368a b c  + 266076160a b c  + 140148736a b c
+--R                 + 
+--R                            5 7
+--R                   14057472a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                       9 3             8 2 2             7 4             6 6  9
+--R             (26214400a c  + 285212672a b c  + 295239680a b c + 50692096a b )x
+--R           + 
+--R                        9   2             8 3              7 5  8
+--R             (165150720a b c  + 394395648a b c + 120324096a b )x
+--R           + 
+--R                       10 2             9 2              8 4  7
+--R             (39845888a  c  + 323747840a b c + 190513152a b )x
+--R           + 
+--R                        10                9 3  6
+--R             (148897792a  b c + 199229440a b )x
+--R           + 
+--R                       11              10 2  5            11   4           12 3
+--R             (29360128a  c + 132120576a  b )x  + 50331648a  b x  + 8388608a  x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 285
+
+--S 286 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    2 2         2       4  4         2            3  3
+--R               (384a c  + 384a b c + 72b )x  + (1536a b c + 384a b )x
+--R             + 
+--R                     3        2 2  2
+--R               (1536a c + 384a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                  2   2         3       5  5
+--R           (- 576a b c  - 192a b c - 12b )x
+--R         + 
+--R                   3 2        2 2          4  4           3          2 3  3
+--R           (- 1152a c  - 1152a b c - 216a b )x  + (- 2304a b c - 576a b )x
+--R         + 
+--R                   4        3 2  2
+--R           (- 1536a c - 384a b )x
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                      2   2         3       5  6
+--R               (- 576a b c  - 192a b c - 12b )x
+--R             + 
+--R                       3 2        2 2          4  5           3          2 3  4
+--R               (- 1152a c  - 1152a b c - 216a b )x  + (- 2304a b c - 576a b )x
+--R             + 
+--R                       4        3 2  3
+--R               (- 1536a c - 384a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2 3         2 2      4   7
+--R               (384a c  + 384a b c  + 72b c)x
+--R             + 
+--R                     2   2         3       5  6
+--R               (1920a b c  + 768a b c + 72b )x
+--R             + 
+--R                     3 2        2 2          4  5         3          2 3  4
+--R               (1920a c  + 2304a b c + 456a b )x  + (3072a b c + 768a b )x
+--R             + 
+--R                     4        3 2  3
+--R               (1536a c + 384a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                      2       4  6         2            3  5        2 2 4
+--R               (576a b c + 48b )x  + (1152a b c + 864a b )x  + 2304a b x
+--R             + 
+--R                    3   3
+--R               1536a b x
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                      2   2         3   7           2 2          4  6
+--R               (- 384a b c  - 288a b c)x  + (- 1920a b c - 288a b )x
+--R             + 
+--R                       3           2 3  5        3 2 4        4   3
+--R               (- 1920a b c - 1824a b )x  - 3072a b x  - 1536a b x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                   2            3  4        2 2 3        3   2  +---+
+--R             ((768a b c + 576a b )x  + 3072a b x  + 3072a b x )\|- c
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                         2       4  5           2             3  4        2 2 3
+--R               (- 1152a b c - 96b )x  + (- 2304a b c - 1728a b )x  - 4608a b x
+--R             + 
+--R                      3   2
+--R               - 3072a b x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2      \|a \|c x  + b x + a  - a
+--R         \|c x  + b x  + a x  atan(-------------------------)
+--R                                            +---+ +-+
+--R                                          x\|- c \|a
+--R     + 
+--R                          2      3   5          2 2        2       4  4
+--R               (- 384a b c  - 32b c)x  + (- 512a c  + 24a b c - 14b )x
+--R             + 
+--R                  2            3  3        3         2 2  2        3          4
+--R             (640a b c + 448a b )x  + (384a c + 1920a b )x  + 2048a b x + 512a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                2 3         2 2  6        2   2        3      5  5
+--R           (256a c  + 192a b c )x  + (576a b c  + 28a b c + 9b )x
+--R         + 
+--R                3 2       2 2         4  4           3           2 3  3
+--R           (384a c  - 840a b c - 78a b )x  + (- 1728a b c - 1184a b )x
+--R         + 
+--R                  4         3 2  2        4          5
+--R           (- 640a c - 2880a b )x  - 2304a b x - 512a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  2 3         2 2  7          2   2        3   6
+--R           (- 256a c  - 192a b c )x  + (- 960a b c  + 48a b c)x
+--R         + 
+--R                   3 2       2 2          4  5        3           2 3  4
+--R           (- 1152a c  + 480a b c + 240a b )x  + (192a b c + 1616a b )x
+--R         + 
+--R                  4         3 2  3        4   2       5
+--R           (- 384a c + 3168a b )x  + 2304a b x  + 512a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                    3      3 2  8        2 3         2 2     4   7
+--R           (384a b c  + 32b c )x  + (768a c  + 480a b c  - 8b c)x
+--R         + 
+--R                 2   2         3       5  6         3 2        2 2          4  5
+--R           (1536a b c  - 608a b c - 40b )x  + (1408a c  - 1728a b c - 776a b )x
+--R         + 
+--R                   3           2 3  4        4         3 2  3        4   2
+--R           (- 1024a b c - 2944a b )x  + (128a c - 4256a b )x  - 2560a b x
+--R         + 
+--R                 5
+--R           - 512a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                        +--------------+
+--R               2          2  4        2   3        3 2  |   2
+--R         ((256a c + 192a b )x  + 1024a b x  + 1024a x )\|c x  + b x + a
+--R       + 
+--R                              3  5          2          2  4        2   3
+--R             (- 384a b c - 32b )x  + (- 768a c - 576a b )x  - 1536a b x
+--R           + 
+--R                    3 2
+--R             - 1024a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      2   4         3 3      5 2  9
+--R               (- 192a b c  - 160a b c  - 12b c )x
+--R             + 
+--R                      3 4        2 2 3         4 2      6   8
+--R               (- 384a c  - 1728a b c  - 600a b c  - 24b c)x
+--R             + 
+--R                       3   3        2 3 2         5       7  7
+--R               (- 4224a b c  - 4992a b c  - 744a b c - 12b )x
+--R             + 
+--R                       4 3         3 2 2        2 4          6  6
+--R               (- 2816a c  - 14208a b c  - 5808a b c - 304a b )x
+--R             + 
+--R                        4   2         3 3         2 5  5
+--R               (- 16320a b c  - 18720a b c - 2364a b )x
+--R             + 
+--R                       5 2         4 2         3 4  4
+--R               (- 6528a c  - 28992a b c - 8472a b )x
+--R             + 
+--R                        5            4 3  3           6          5 2  2
+--R               (- 21504a b c - 16128a b )x  + (- 6144a c - 16896a b )x
+--R             + 
+--R                      6           7
+--R               - 9216a b x - 2048a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               3 5       2 2 4        4 3    6 2  10
+--R           (64a c  + 240a b c  + 60a b c  + b c )x
+--R         + 
+--R                 3   4        2 3 3         5 2     7   9
+--R           (1280a b c  + 1440a b c  + 192a b c  + 2b c)x
+--R         + 
+--R                 4 4        3 2 3        2 4 2         6     8  8
+--R           (1280a c  + 6880a b c  + 3120a b c  + 206a b c + b )x
+--R         + 
+--R                  4   3         3 3 2        2 5         7  7
+--R           (10880a b c  + 15200a b c  + 2904a b c + 74a b )x
+--R         + 
+--R                 5 3         4 2 2         3 4        2 6  6
+--R           (5440a c  + 30960a b c  + 14860a b c + 985a b )x
+--R         + 
+--R                  5   2         4 3         3 5  5
+--R           (28032a b c  + 36160a b c + 5336a b )x
+--R         + 
+--R                 6 2         5 2          4 4  4          6            5 3  3
+--R           (9344a c  + 45504a b c + 14920a b )x  + (28672a b c + 23552a b )x
+--R         + 
+--R                 7          6 2  2         7           8
+--R           (7168a c + 21248a b )x  + 10240a b x + 2048a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 3 5       2 2 4        4 3    6 2  11
+--R           (- 64a c  - 240a b c  - 60a b c  - b c )x
+--R         + 
+--R                   3   4        2 3 3         5 2     7   10
+--R           (- 1280a b c  - 1440a b c  - 192a b c  - 2b c)x
+--R         + 
+--R                   4 4        3 2 3        2 4 2         6     8  9
+--R           (- 1280a c  - 6880a b c  - 3120a b c  - 206a b c - b )x
+--R         + 
+--R                    4   3         3 3 2        2 5         7  8
+--R           (- 10880a b c  - 15200a b c  - 2904a b c - 74a b )x
+--R         + 
+--R                   5 3         4 2 2         3 4        2 6  7
+--R           (- 5440a c  - 30960a b c  - 14860a b c - 985a b )x
+--R         + 
+--R                    5   2         4 3         3 5  6
+--R           (- 28032a b c  - 36160a b c - 5336a b )x
+--R         + 
+--R                   6 2         5 2          4 4  5
+--R           (- 9344a c  - 45504a b c - 14920a b )x
+--R         + 
+--R                    6            5 3  4           7          6 2  3
+--R           (- 28672a b c - 23552a b )x  + (- 7168a c - 21248a b )x
+--R         + 
+--R                   7   2        8
+--R           - 10240a b x  - 2048a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                2   5         3 4      5 3  12
+--R           (192a b c  + 160a b c  + 12b c )x
+--R         + 
+--R                3 5        2 2 4         4 3      6 2  11
+--R           (384a c  + 1920a b c  + 760a b c  + 36b c )x
+--R         + 
+--R                 3   4        2 3 3          5 2      7   10
+--R           (4800a b c  + 6880a b c  + 1356a b c  + 36b c)x
+--R         + 
+--R                 4 4         3 2 3         2 4 2          6       8  9
+--R           (3200a c  + 20160a b c  + 11400a b c  + 1072a b c + 12b )x
+--R         + 
+--R                  4   3         3 3 2        2 5          7  8
+--R           (23360a b c  + 37920a b c  + 8916a b c + 316a b )x
+--R         + 
+--R                 5 3         4 2 2         3 4         2 6  7
+--R           (9344a c  + 59520a b c  + 33000a b c + 2668a b )x
+--R         + 
+--R                  5   2         4 3          3 5  6
+--R           (44352a b c  + 63840a b c + 10836a b )x
+--R         + 
+--R                  6 2         5 2          4 4  5          6            5 3  4
+--R           (12672a c  + 67392a b c + 24600a b )x  + (36864a b c + 33024a b )x
+--R         + 
+--R                 7          6 2  3         7   2        8
+--R           (8192a c + 26112a b )x  + 11264a b x  + 2048a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 3 3       2 2 2        4     6  9
+--R             (64a c  + 240a b c  + 60a b c + b )x
+--R           + 
+--R                   3   2       2 3         5  8
+--R             (1152a b c  + 960a b c + 72a b )x
+--R           + 
+--R                   4 2        3 2        2 4  7         4           3 3  6
+--R             (1152a c  + 4032a b c + 840a b )x  + (6144a b c + 3584a b )x
+--R           + 
+--R                   5         4 2  5        5   4        6 3
+--R             (3072a c + 6912a b )x  + 6144a b x  + 2048a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2   3         3 2      5   10
+--R             (- 192a b c  - 160a b c  - 12b c)x
+--R           + 
+--R                    3 3        2 2 2         4       6  9
+--R             (- 384a c  - 1536a b c  - 440a b c - 12b )x
+--R           + 
+--R                     3   2        2 3          5  8
+--R             (- 3648a b c  - 3296a b c - 292a b )x
+--R           + 
+--R                     4 2        3 2         2 4  7            4           3 3  6
+--R             (- 2432a c  - 9024a b c - 2072a b )x  + (- 10240a b c - 6400a b )x
+--R           + 
+--R                     5         4 2  5        5   4        6 3
+--R             (- 4096a c - 9728a b )x  - 7168a b x  - 2048a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 287
+
+)clear all
+
+--S 288 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^7
+--R 
+--R
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R   (1)  -------------------------------------
+--R                           5
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 288
+
+--S 289 of 704
+r0:=-1/3*(a*x^2+b*x^3+c*x^4)^(3/2)/x^6-1/4*b*(a*x^2+b*x^3+c*x^4)^(3/2)/_
+   (a*x^5)+1/16*b*(b^2-12*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+_
+   b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(a^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   c^(3/2)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+_
+   b*x+c*x^2)/sqrt(a*x^2+b*x^3+c*x^4)+1/8*(b^2-8*a*c+2*b*c*x)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a*x^2)
+--R 
+--R
+--R   (2)
+--R                           +--------------+
+--R                      3  3 |   2                        b x + 2a
+--R       (- 36a b c + 3b )x \|c x  + b x + a atanh(----------------------)
+--R                                                       +--------------+
+--R                                                   +-+ |   2
+--R                                                 2\|a \|c x  + b x + a
+--R     + 
+--R                        +--------------+
+--R              3 +-+ +-+ |   2                        2c x + b
+--R       48a c x \|a \|c \|c x  + b x + a atanh(----------------------)
+--R                                                    +--------------+
+--R                                                +-+ |   2
+--R                                              2\|c \|c x  + b x + a
+--R     + 
+--R                   2     2   4                  3  3         2         2  2
+--R           (- 64a c  - 6b c)x  + (- 92a b c - 6b )x  + (- 80a c - 34a b )x
+--R         + 
+--R                2         3
+--R           - 44a b x - 16a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                +------------------+
+--R          2 +-+ |   4      3      2
+--R     48a x \|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       2   2         3       5  5         2 2          4  4
+--R                 (1152a b c  + 768a b c - 72b )x  + (4608a b c - 384a b )x
+--R               + 
+--R                       3          2 3  3
+--R                 (4608a b c - 384a b )x
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                     2 2 2      6  6           3   2        2 3          5  5
+--R             (- 1728a b c  + 12b )x  + (- 3456a b c  - 2304a b c + 216a b )x
+--R           + 
+--R                     3 2        2 4  4           4          3 3  3
+--R             (- 6912a b c + 576a b )x  + (- 4608a b c + 384a b )x
+--R        *
+--R                  +--------------+
+--R                  |   2                           +-+
+--R               2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R           log(--------------------------------------)
+--R                                2a x
+--R       + 
+--R                      3 2        2 2   5        3     4        4   3  +-+
+--R               ((1536a c  + 1152a b c)x  + 6144a b c x  + 6144a c x )\|c
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                         2   2         3   6           3 2        2 2   5
+--R                 (- 2304a b c  - 192a b c)x  + (- 4608a c  - 3456a b c)x
+--R               + 
+--R                        3     4        4   3
+--R                 - 9216a b c x  - 6144a c x
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R        *
+--R           log
+--R                                     +--------------+
+--R                        +-+     +-+  |   2                 +-+ +-+       2
+--R                  (- 2x\|c  + 2\|a )\|c x  + b x + a  + 2x\|a \|c  - 2c x  - b x
+--R                + 
+--R                  - 2a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                   2   2         3       5  5
+--R             (2592a b c  + 176a b c + 18b )x
+--R           + 
+--R                   3 2        2 2          4  4          3           2 3  3
+--R             (6144a c  + 4608a b c + 512a b )x  + (13824a b c + 3200a b )x
+--R           + 
+--R                   4         3 2  2        4           5
+--R             (9728a c + 7296a b )x  + 6656a b x + 2048a
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|a \|c x  + b x + a
+--R       + 
+--R                 3 3        2 2 2        4     6  6
+--R         (- 2048a c  - 1008a b c  - 72a b c + b )x
+--R       + 
+--R                 3   2        2 3          5  5
+--R         (- 9696a b c  - 2064a b c - 126a b )x
+--R       + 
+--R                  4 2         3 2         2 4  4            4           3 3  3
+--R         (- 10752a c  - 12672a b c - 1536a b )x  + (- 21504a b c - 6144a b )x
+--R       + 
+--R                  5          4 2  2        5           6
+--R         (- 10752a c - 10368a b )x  - 7680a b x - 2048a
+--R    /
+--R                                                          +--------------+
+--R                3         2 2  5        3   4        4 3  |   2
+--R         ((1536a c + 1152a b )x  + 6144a b x  + 6144a x )\|c x  + b x + a
+--R       + 
+--R                     2            3  6           3         2 2  5        3   4
+--R             (- 2304a b c - 192a b )x  + (- 4608a c - 3456a b )x  - 9216a b x
+--R           + 
+--R                    4 3
+--R             - 6144a x
+--R        *
+--R            +-+
+--R           \|a
+--R     ,
+--R
+--R                       2   2         3       5  5         2 2          4  4
+--R                 (1152a b c  + 768a b c - 72b )x  + (4608a b c - 384a b )x
+--R               + 
+--R                       3          2 3  3
+--R                 (4608a b c - 384a b )x
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|a \|c x  + b x + a
+--R           + 
+--R                     2 2 2      6  6           3   2        2 3          5  5
+--R             (- 1728a b c  + 12b )x  + (- 3456a b c  - 2304a b c + 216a b )x
+--R           + 
+--R                     3 2        2 4  4           4          3 3  3
+--R             (- 6912a b c + 576a b )x  + (- 4608a b c + 384a b )x
+--R        *
+--R                  +--------------+
+--R                  |   2                           +-+
+--R               2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R           log(--------------------------------------)
+--R                                2a x
+--R       + 
+--R                      3 2        2 2   5         3     4         4   3  +---+
+--R               ((3072a c  + 2304a b c)x  + 12288a b c x  + 12288a c x )\|- c
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                         2   2         3   6           3 2        2 2   5
+--R                 (- 4608a b c  - 384a b c)x  + (- 9216a c  - 6912a b c)x
+--R               + 
+--R                         3     4         4   3
+--R                 - 18432a b c x  - 12288a c x
+--R            *
+--R                +---+ +-+
+--R               \|- c \|a
+--R        *
+--R                 +--------------+
+--R                 |   2               +-+
+--R                \|c x  + b x + a  - \|a
+--R           atan(------------------------)
+--R                           +---+
+--R                         x\|- c
+--R       + 
+--R                   2   2         3       5  5
+--R             (2592a b c  + 176a b c + 18b )x
+--R           + 
+--R                   3 2        2 2          4  4          3           2 3  3
+--R             (6144a c  + 4608a b c + 512a b )x  + (13824a b c + 3200a b )x
+--R           + 
+--R                   4         3 2  2        4           5
+--R             (9728a c + 7296a b )x  + 6656a b x + 2048a
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|a \|c x  + b x + a
+--R       + 
+--R                 3 3        2 2 2        4     6  6
+--R         (- 2048a c  - 1008a b c  - 72a b c + b )x
+--R       + 
+--R                 3   2        2 3          5  5
+--R         (- 9696a b c  - 2064a b c - 126a b )x
+--R       + 
+--R                  4 2         3 2         2 4  4            4           3 3  3
+--R         (- 10752a c  - 12672a b c - 1536a b )x  + (- 21504a b c - 6144a b )x
+--R       + 
+--R                  5          4 2  2        5           6
+--R         (- 10752a c - 10368a b )x  - 7680a b x - 2048a
+--R    /
+--R                                                          +--------------+
+--R                3         2 2  5        3   4        4 3  |   2
+--R         ((1536a c + 1152a b )x  + 6144a b x  + 6144a x )\|c x  + b x + a
+--R       + 
+--R                     2            3  6           3         2 2  5        3   4
+--R             (- 2304a b c - 192a b )x  + (- 4608a c - 3456a b )x  - 9216a b x
+--R           + 
+--R                    4 3
+--R             - 6144a x
+--R        *
+--R            +-+
+--R           \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 290
+
+--S 291 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     3   2       2 3         5  5         3 2        2 4  4
+--R               (1152a b c  + 768a b c - 72a b )x  + (4608a b c - 384a b )x
+--R             + 
+--R                     4          3 3  3
+--R               (4608a b c - 384a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       2 2 2      6  6           3   2        2 3          5  5
+--R               (- 1728a b c  + 12b )x  + (- 3456a b c  - 2304a b c + 216a b )x
+--R             + 
+--R                       3 2        2 4  4           4          3 3  3
+--R               (- 6912a b c + 576a b )x  + (- 4608a b c + 384a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                                     +--------------+
+--R          +------------------+       |   2                           +-+
+--R          |   4      3      2     2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         \|c x  + b x  + a x  log(--------------------------------------)
+--R                                                   2a x
+--R     + 
+--R                    3 2        2 2   5        3     4        4   3  +-+ +-+
+--R             ((1536a c  + 1152a b c)x  + 6144a b c x  + 6144a c x )\|a \|c
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       3   2       2 3   6           4 2        3 2   5
+--R               (- 2304a b c  - 192a b c)x  + (- 4608a c  - 3456a b c)x
+--R             + 
+--R                      4     4        5   3
+--R               - 9216a b c x  - 6144a c x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R                              +--------------+
+--R                 +-+     +-+  |   2                 +-+ +-+       2
+--R           (- 2x\|c  + 2\|a )\|c x  + b x + a  + 2x\|a \|c  - 2c x  - b x - 2a
+--R       log(-------------------------------------------------------------------)
+--R                                  +--------------+
+--R                              +-+ |   2
+--R                            2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                       2 2 2      6  7           3   2        2 3          5  6
+--R               (- 1728a b c  + 12b )x  + (- 3456a b c  - 2304a b c + 216a b )x
+--R             + 
+--R                       3 2        2 4  5           4          3 3  4
+--R               (- 6912a b c + 576a b )x  + (- 4608a b c + 384a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                 3   3       2 3 2        5   8
+--R           (1152a b c  + 768a b c  - 72a b c)x
+--R         + 
+--R                 3 2 2       2 4         6  7
+--R           (5760a b c  + 384a b c - 72a b )x
+--R         + 
+--R                 4   2        3 3        2 5  6         4 2        3 4  5
+--R           (5760a b c  + 4992a b c - 456a b )x  + (9216a b c - 768a b )x
+--R         + 
+--R                 5          4 3  4
+--R           (4608a b c - 384a b )x
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                     3   2       2 3   7         4 2        3 2   6
+--R               (2304a b c  + 192a b c)x  + (4608a c  + 3456a b c)x
+--R             + 
+--R                    4     5        5   4
+--R               9216a b c x  + 6144a c x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                       3 3        2 2 2  8           3   2        2 3   7
+--R               (- 1536a c  - 1152a b c )x  + (- 7680a b c  - 1152a b c)x
+--R             + 
+--R                       4 2        3 2   6         4     5        5   4
+--R               (- 7680a c  - 7296a b c)x  - 12288a b c x  - 6144a c x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                     3   2       2 3         5  5
+--R               (2592a b c  + 176a b c + 18a b )x
+--R             + 
+--R                     4 2        3 2        2 4  4          4           3 3  3
+--R               (6144a c  + 4608a b c + 512a b )x  + (13824a b c + 3200a b )x
+--R             + 
+--R                     5         4 2  2        5           6
+--R               (9728a c + 7296a b )x  + 6656a b x + 2048a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       3 3        2 2 2        4     6  6
+--R               (- 2048a c  - 1008a b c  - 72a b c + b )x
+--R             + 
+--R                       3   2        2 3          5  5
+--R               (- 9696a b c  - 2064a b c - 126a b )x
+--R             + 
+--R                        4 2         3 2         2 4  4
+--R               (- 10752a c  - 12672a b c - 1536a b )x
+--R             + 
+--R                        4           3 3  3            5          4 2  2
+--R               (- 21504a b c - 6144a b )x  + (- 10752a c - 10368a b )x
+--R             + 
+--R                      5           6
+--R               - 7680a b x - 2048a
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 3 3        2 2 2         4   7
+--R           (2048a c  + 1728a b c  + 144a b c)x
+--R         + 
+--R                  3   2        2 3          5  6
+--R           (11136a b c  + 3168a b c + 144a b )x
+--R         + 
+--R                  4 2         3 2         2 4  5          4           3 3  4
+--R           (10752a c  + 15552a b c + 1584a b )x  + (23424a b c + 6176a b )x
+--R         + 
+--R                  5          4 2  3        5   2        6
+--R           (10752a c + 10368a b )x  + 7680a b x  + 2048a x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R               3   3       2 3 2        5   8
+--R       (- 3072a b c  - 544a b c  - 24a b c)x
+--R     + 
+--R               4 3        3 2 2        2 4         6  7
+--R       (- 6144a c  - 9600a b c  - 1088a b c - 24a b )x
+--R     + 
+--R                4   2         3 3        2 5  6
+--R       (- 24960a b c  - 10304a b c - 568a b )x
+--R     + 
+--R                5 2         4 2         3 4  5            5            4 3  4
+--R       (- 15872a c  - 29568a b c - 3776a b )x  + (- 32128a b c - 10528a b )x
+--R     + 
+--R                6          5 2  3        6   2        7
+--R       (- 11776a c - 13952a b )x  - 8704a b x  - 2048a x
+--R  /
+--R                                                              +--------------+
+--R                3         2 2  5        3   4        4 3  +-+ |   2
+--R         ((1536a c + 1152a b )x  + 6144a b x  + 6144a x )\|a \|c x  + b x + a
+--R       + 
+--R                 3          2 3  6           4         3 2  5        4   4
+--R         (- 2304a b c - 192a b )x  + (- 4608a c - 3456a b )x  - 9216a b x
+--R       + 
+--R                5 3
+--R         - 6144a x
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                              5 6        4 2 5        3 4 4        2 6 3
+--R                       - 1024a c  - 9216a b c  - 8064a b c  - 1344a b c
+--R                     + 
+--R                              8 2
+--R                       - 36a b c
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                               5   5          4 3 4         3 5 3        2 7 2
+--R                       - 47616a b c  - 121344a b c  - 52416a b c  - 4896a b c
+--R                     + 
+--R                              9
+--R                       - 74a b c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                               6 5          5 2 4          4 4 3          3 6 2
+--R                       - 52224a c  - 526848a b c  - 546432a b c  - 120960a b c
+--R                     + 
+--R                              2 8         10
+--R                       - 5868a b c - 38a b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                                6   4           5 3 3           4 5 2
+--R                       - 855552a b c  - 2329088a b c  - 1104192a b c
+--R                     + 
+--R                                3 7         2 9
+--R                       - 118944a b c - 2318a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                                7 4           6 2 3           5 4 2
+--R                       - 460800a c  - 4669440a b c  - 4819200a b c
+--R                     + 
+--R                                 4 6          3 8
+--R                       - 1029888a b c - 42408a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                                 7   3            6 3 2           5 5
+--R                       - 4386816a b c  - 11203584a b c  - 4671744a b c
+--R                     + 
+--R                                4 7
+--R                       - 361152a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                 8 3            7 2 2            6 4
+--R                       - 1556480a c  - 14229504a b c  - 12205056a b c
+--R                     + 
+--R                                 5 6
+--R                       - 1712128a b
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                              8   2            7 3            6 5  6
+--R                   (- 9314304a b c  - 19034112a b c - 4932096a b )x
+--R                 + 
+--R                              9 2            8 2            7 4  5
+--R                   (- 2457600a c  - 17498112a b c - 8988672a b )x
+--R                 + 
+--R                              9               8 3  4
+--R                   (- 8749056a b c - 10428416a b )x
+--R                 + 
+--R                            10            9 2  3           10   2          11
+--R                 (- 1835008a  c - 7471104a b )x  - 3014656a  b x  - 524288a  x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                           4   6         3 3 5        2 5 4         7 3     9 2
+--R                     (4608a b c  + 10752a b c  + 4032a b c  + 288a b c  + 2b c )
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                             5 6         4 2 5         3 4 4         2 6 3
+--R                       10240a c  + 99072a b c  + 96768a b c  + 19488a b c
+--R                     + 
+--R                             8 2     10
+--R                       792a b c  + 3b  c
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                              5   5          4 3 4          3 5 3         2 7 2
+--R                       250368a b c  + 673536a b c  + 315840a b c  + 33984a b c
+--R                     + 
+--R                             9     11
+--R                       706a b c + b
+--R                  *
+--R                      11
+--R                     x
+--R                 + 
+--R                              6 5           5 2 4           4 4 3          3 6 2
+--R                       184320a c  + 1906944a b c  + 2048256a b c  + 477792a b c
+--R                     + 
+--R                             2 8          10
+--R                       25344a b c + 201a b
+--R                  *
+--R                      10
+--R                     x
+--R                 + 
+--R                               6   4           5 3 3           4 5 2
+--R                       2334720a b c  + 6425600a b c  + 3089664a b c
+--R                     + 
+--R                              3 7         2 9
+--R                       339264a b c + 6800a b
+--R                  *
+--R                      9
+--R                     x
+--R                 + 
+--R                               7 4            6 2 3            5 4 2
+--R                       1026048a c  + 10371072a b c  + 10652928a b c
+--R                     + 
+--R                               4 6          3 8
+--R                       2255616a b c + 91080a b
+--R                  *
+--R                      8
+--R                     x
+--R                 + 
+--R                                 7   3            6 3 2           5 5
+--R                         8282112a b c  + 20840448a b c  + 8498688a b c
+--R                       + 
+--R                                4 7
+--R                         633600a b
+--R                  *
+--R                      7
+--R                     x
+--R                 + 
+--R                                 8 3            7 2 2            6 4
+--R                         2588672a c  + 23187456a b c  + 19329024a b c
+--R                       + 
+--R                                 5 6
+--R                         2599168a b
+--R                  *
+--R                      6
+--R                     x
+--R                 + 
+--R                             8   2            7 3            6 5  5
+--R                   (13664256a b c  + 27058176a b c + 6709248a b )x
+--R                 + 
+--R                            9 2            8 2             7 4  4
+--R                   (3309568a c  + 22806528a b c + 11212800a b )x
+--R                 + 
+--R                             9               8 3  3
+--R                   (10616832a b c + 12124160a b )x
+--R                 + 
+--R                            10            9 2  2           10             11
+--R                   (2097152a  c + 8192000a b )x  + 3145728a  b x + 524288a
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                     4   6         3 3 5        2 5 4         7 3     9 2  14
+--R               (4608a b c  + 10752a b c  + 4032a b c  + 288a b c  + 2b c )x
+--R             + 
+--R                         5 6          4 2 5          3 4 4         2 6 3
+--R                   10240a c  + 101376a b c  + 102144a b c  + 21504a b c
+--R                 + 
+--R                         8 2     10
+--R                   936a b c  + 4b  c
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                          5   5          4 3 4          3 5 3         2 7 2
+--R                   254976a b c  + 717312a b c  + 357504a b c  + 42048a b c
+--R                 + 
+--R                          9      11
+--R                   1012a b c + 2b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                          6 5           5 2 4           4 4 3          3 6 2
+--R                   184320a c  + 2006016a b c  + 2302464a b c  + 588672a b c
+--R                 + 
+--R                         2 8          10
+--R                   35856a b c + 364a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                           6   4           5 3 3           4 5 2          3 7
+--R                   2400768a b c  + 7066112a b c  + 3713472a b c  + 462240a b c
+--R                 + 
+--R                         2 9
+--R                   11282a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                           7 4            6 2 3            5 4 2           4 6
+--R                   1026048a c  + 11077632a b c  + 12380928a b c  + 2936448a b c
+--R                 + 
+--R                          3 8
+--R                   139752a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                        7   3            6 3 2            5 5           4 7  8
+--R               (8564736a b c  + 23337984a b c  + 10551552a b c + 906048a b )x
+--R             + 
+--R                        8 3            7 2 2            6 4            5 6  7
+--R               (2588672a c  + 24993792a b c  + 22898688a b c + 3486208a b )x
+--R             + 
+--R                         8   2            7 3            6 5  6
+--R               (14180352a b c  + 30633984a b c + 8486400a b )x
+--R             + 
+--R                        9 2            8 2             7 4  5
+--R               (3309568a c  + 24723456a b c + 13436928a b )x
+--R             + 
+--R                         9               8 3  4            10            9 2  3
+--R               (11042816a b c + 13819904a b )x  + (2097152a  c + 8912896a b )x
+--R             + 
+--R                       10   2          11
+--R               3276800a  b x  + 524288a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                   5 7        4 2 6        3 4 5        2 6 4        8 3  14
+--R           (- 1024a c  - 9216a b c  - 8064a b c  - 1344a b c  - 36a b c )x
+--R         + 
+--R                         5   6          4 3 5         3 5 4        2 7 3
+--R                 - 48128a b c  - 125952a b c  - 56448a b c  - 5568a b c
+--R               + 
+--R                        9 2
+--R                 - 92a b c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                       6 6          5 2 5          4 4 4          3 6 3
+--R               - 53248a c  - 562176a b c  - 620544a b c  - 150528a b c
+--R             + 
+--R                      2 8 2        10
+--R               - 8496a b c  - 76a b  c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                        6   5           5 3 4           4 5 3          3 7 2
+--R               - 933888a b c  - 2757632a b c  - 1471488a b c  - 192384a b c
+--R             + 
+--R                      2 9         11
+--R               - 5632a b c - 20a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        7 5           6 2 4           5 4 3           4 6 2
+--R               - 513024a c  - 5723136a b c  - 6784384a b c  - 1813824a b c
+--R             + 
+--R                        3 8         2 10
+--R               - 118260a b c - 1360a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         7   4            6 3 3           5 5 2           4 7
+--R               - 5538816a b c  - 16507904a b c  - 8809344a b c  - 1118016a b c
+--R             + 
+--R                       3 9
+--R               - 28004a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                         8 4            7 2 3            6 4 2           5 6
+--R               - 2017280a c  - 21798912a b c  - 24354048a b c  - 5758720a b c
+--R             + 
+--R                        4 8
+--R               - 271656a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                       8   3            7 3 2            6 5            5 7  7
+--R           (- 14761984a b c  - 39849984a b c  - 17759232a b c - 1489664a b )x
+--R         + 
+--R                      9 3            8 2 2            7 4            6 6  6
+--R           (- 4014080a c  - 38191104a b c  - 34280448a b c - 5065216a b )x
+--R         + 
+--R                       9   2            8 3             7 5  5
+--R           (- 19808256a b c  - 41787392a b c - 11203584a b )x
+--R         + 
+--R                      10 2            9 2             8 4  4
+--R           (- 4292608a  c  - 31260672a b c - 16427008a b )x
+--R         + 
+--R                       10               9 3  3
+--R           (- 13107200a  b c - 15859712a b )x
+--R         + 
+--R                      11            10 2  2           11             12
+--R           (- 2359296a  c - 9699328a  b )x  - 3407872a  b x - 524288a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                       4   6         3 3 5        2 5 4         7 3     9 2  15
+--R               (- 4608a b c  - 10752a b c  - 4032a b c  - 288a b c  - 2b c )x
+--R             + 
+--R                           5 6          4 2 5          3 4 4         2 6 3
+--R                   - 10240a c  - 101376a b c  - 102144a b c  - 21504a b c
+--R                 + 
+--R                           8 2     10
+--R                   - 936a b c  - 4b  c
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                            5   5          4 3 4          3 5 3         2 7 2
+--R                   - 254976a b c  - 717312a b c  - 357504a b c  - 42048a b c
+--R                 + 
+--R                            9      11
+--R                   - 1012a b c - 2b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                            6 5           5 2 4           4 4 3          3 6 2
+--R                   - 184320a c  - 2006016a b c  - 2302464a b c  - 588672a b c
+--R                 + 
+--R                           2 8          10
+--R                   - 35856a b c - 364a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                             6   4           5 3 3           4 5 2          3 7
+--R                   - 2400768a b c  - 7066112a b c  - 3713472a b c  - 462240a b c
+--R                 + 
+--R                           2 9
+--R                   - 11282a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                             7 4            6 2 3            5 4 2
+--R                   - 1026048a c  - 11077632a b c  - 12380928a b c
+--R                 + 
+--R                             4 6           3 8
+--R                   - 2936448a b c - 139752a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                          7   3            6 3 2            5 5           4 7  9
+--R               (- 8564736a b c  - 23337984a b c  - 10551552a b c - 906048a b )x
+--R             + 
+--R                          8 3            7 2 2            6 4            5 6  8
+--R               (- 2588672a c  - 24993792a b c  - 22898688a b c - 3486208a b )x
+--R             + 
+--R                           8   2            7 3            6 5  7
+--R               (- 14180352a b c  - 30633984a b c - 8486400a b )x
+--R             + 
+--R                          9 2            8 2             7 4  6
+--R               (- 3309568a c  - 24723456a b c - 13436928a b )x
+--R             + 
+--R                           9               8 3  5
+--R               (- 11042816a b c - 13819904a b )x
+--R             + 
+--R                          10            9 2  4           10   3          11 2
+--R               (- 2097152a  c - 8912896a b )x  - 3276800a  b x  - 524288a  x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                 5 7        4 2 6        3 4 5        2 6 4        8 3  15
+--R           (1024a c  + 9216a b c  + 8064a b c  + 1344a b c  + 36a b c )x
+--R         + 
+--R                  5   6          4 3 5         3 5 4        2 7 3        9 2  14
+--R           (48128a b c  + 125952a b c  + 56448a b c  + 5568a b c  + 92a b c )x
+--R         + 
+--R                     6 6          5 2 5          4 4 4          3 6 3
+--R               53248a c  + 562176a b c  + 620544a b c  + 150528a b c
+--R             + 
+--R                    2 8 2        10
+--R               8496a b c  + 76a b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                      6   5           5 3 4           4 5 3          3 7 2
+--R               933888a b c  + 2757632a b c  + 1471488a b c  + 192384a b c
+--R             + 
+--R                    2 9         11
+--R               5632a b c + 20a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                      7 5           6 2 4           5 4 3           4 6 2
+--R               513024a c  + 5723136a b c  + 6784384a b c  + 1813824a b c
+--R             + 
+--R                      3 8         2 10
+--R               118260a b c + 1360a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                       7   4            6 3 3           5 5 2           4 7
+--R               5538816a b c  + 16507904a b c  + 8809344a b c  + 1118016a b c
+--R             + 
+--R                     3 9
+--R               28004a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                       8 4            7 2 3            6 4 2           5 6
+--R               2017280a c  + 21798912a b c  + 24354048a b c  + 5758720a b c
+--R             + 
+--R                      4 8
+--R               271656a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                     8   3            7 3 2            6 5            5 7  8
+--R           (14761984a b c  + 39849984a b c  + 17759232a b c + 1489664a b )x
+--R         + 
+--R                    9 3            8 2 2            7 4            6 6  7
+--R           (4014080a c  + 38191104a b c  + 34280448a b c + 5065216a b )x
+--R         + 
+--R                     9   2            8 3             7 5  6
+--R           (19808256a b c  + 41787392a b c + 11203584a b )x
+--R         + 
+--R                    10 2            9 2             8 4  5
+--R           (4292608a  c  + 31260672a b c + 16427008a b )x
+--R         + 
+--R                     10               9 3  4            11            10 2  3
+--R           (13107200a  b c + 15859712a b )x  + (2359296a  c + 9699328a  b )x
+--R         + 
+--R                   11   2          12
+--R           3407872a  b x  + 524288a  x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 5 7        4 2 6        3 4 5        2 6 4        8 3  16
+--R           (1024a c  + 9216a b c  + 8064a b c  + 1344a b c  + 36a b c )x
+--R         + 
+--R                    5   6          4 3 5         3 5 4        2 7 3         9 2
+--R             (48640a b c  + 130560a b c  + 60480a b c  + 6240a b c  + 110a b c )
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                     6 6          5 2 5          4 4 4          3 6 3
+--R               53248a c  + 583680a b c  + 675840a b c  + 174720a b c
+--R             + 
+--R                     2 8 2         10
+--R               10800a b c  + 112a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                      6   5           5 3 4           4 5 3          3 7 2
+--R               955392a b c  + 2977280a b c  + 1703040a b c  + 244800a b c
+--R             + 
+--R                    2 9         11
+--R               8260a b c + 38a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                      7 5           6 2 4           5 4 3           4 6 2
+--R               513024a c  + 6051840a b c  + 7694720a b c  + 2255040a b c
+--R             + 
+--R                      3 8         2 10
+--R               167220a b c + 2356a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                       7   4            6 3 3            5 5 2           4 7
+--R               5703168a b c  + 18202112a b c  + 10595136a b c  + 1509984a b c
+--R             + 
+--R                     3 9
+--R               44726a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                       8 4            7 2 3            6 4 2           5 6
+--R               2017280a c  + 23285760a b c  + 28227840a b c  + 7413760a b c
+--R             + 
+--R                      4 8
+--R               403560a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                     8   3            7 3 2            6 5            5 7  9
+--R           (15257600a b c  + 44467200a b c  + 21808896a b c + 2073280a b )x
+--R         + 
+--R                    9 3            8 2 2            7 4            6 6  8
+--R           (4014080a c  + 41041920a b c  + 40227840a b c + 6644224a b )x
+--R         + 
+--R                     9   2            8 3             7 5  7
+--R           (20520960a b c  + 46960640a b c + 13920768a b )x
+--R         + 
+--R                    10 2            9 2             8 4  6
+--R           (4292608a  c  + 33718272a b c + 19417088a b )x
+--R         + 
+--R                     10               9 3  5            11             10 2  4
+--R           (13598720a  b c + 17899520a b )x  + (2359296a  c + 10485760a  b )x
+--R         + 
+--R                   11   3          12 2
+--R           3538944a  b x  + 524288a  x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                   4   7         3 3 6        2 5 5         7 4     9 3  16
+--R           (- 4608a b c  - 10752a b c  - 4032a b c  - 288a b c  - 2b c )x
+--R         + 
+--R                       5 7          4 2 6          3 4 5         2 6 4
+--R               - 10240a c  - 103680a b c  - 107520a b c  - 23520a b c
+--R             + 
+--R                        8 3     10 2
+--R               - 1080a b c  - 5b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        5   6          4 3 5          3 5 4         2 7 3
+--R               - 265216a b c  - 783360a b c  - 416640a b c  - 53760a b c
+--R             + 
+--R                        9 2     11
+--R               - 1500a b c  - 4b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        6 6           5 2 5           4 4 4          3 6 3
+--R               - 194560a c  - 2256384a b c  - 2818560a b c  - 813120a b c
+--R             + 
+--R                       2 8 2         10     12
+--R               - 60120a b c  - 910a b  c - b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         6   5           5 3 4           4 5 3          3 7 2
+--R               - 2769408a b c  - 9006080a b c  - 5453760a b c  - 851040a b c
+--R             + 
+--R                       2 9          11
+--R               - 32850a b c - 202a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         7 5            6 2 4            5 4 3           4 6 2
+--R               - 1210368a c  - 14612736a b c  - 19126784a b c  - 5823072a b c
+--R             + 
+--R                        3 8         2 10
+--R               - 455688a b c - 7001a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          7   4            6 3 3            5 5 2           4 7
+--R               - 11642880a b c  - 37637120a b c  - 22241280a b c  - 3228480a b c
+--R             + 
+--R                       3 9
+--R               - 97880a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         8 4            7 2 3            6 4 2            5 6
+--R               - 3614720a c  - 41840640a b c  - 50822400a b c  - 13353472a b c
+--R             + 
+--R                        4 8
+--R               - 724680a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                       8   3            7 3 2            6 5            5 7  8
+--R           (- 24535040a b c  - 71086080a b c  - 34536960a b c - 3232768a b )x
+--R         + 
+--R                      9 3            8 2 2            7 4            6 6  7
+--R           (- 5898240a c  - 59658240a b c  - 57600000a b c - 9308416a b )x
+--R         + 
+--R                       9   2            8 3             7 5  6
+--R           (- 27590656a b c  - 61988864a b c - 17922048a b )x
+--R         + 
+--R                      10 2            9 2             8 4  5
+--R           (- 5406720a  c  - 41615360a b c - 23336960a b )x
+--R         + 
+--R                       10               9 3  4
+--R           (- 15859712a  b c - 20316160a b )x
+--R         + 
+--R                      11             10 2  3           11   2          12
+--R           (- 2621440a  c - 11337728a  b )x  - 3670016a  b x  - 524288a  x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                       4   4         3 3 3        2 5 2         7      9  14
+--R                 (4608a b c  + 10752a b c  + 4032a b c  + 288a b c + 2b )x
+--R               + 
+--R                             5 4         4 2 3         3 4 2         2 6
+--R                       10240a c  + 92160a b c  + 80640a b c  + 13440a b c
+--R                     + 
+--R                             8
+--R                       360a b
+--R                *
+--R                    13
+--R                   x
+--R               + 
+--R                         5   3          4 3 2          3 5          2 7  12
+--R                 (225280a b c  + 506880a b c  + 177408a b c + 10560a b )x
+--R               + 
+--R                         6 3           5 2 2           4 4           3 6  11
+--R                 (163840a c  + 1351680a b c  + 1013760a b c + 118272a b )x
+--R               + 
+--R                          6   2           5 3           4 5  10
+--R                 (1597440a b c  + 2928640a b c + 658944a b )x
+--R               + 
+--R                         7 2           6 2            5 4  9
+--R                 (688128a c  + 4472832a b c + 2050048a b )x
+--R               + 
+--R                          7              6 3  8            8            7 2  7
+--R                 (3440640a b c + 3727360a b )x  + (1048576a c + 3932160a b )x
+--R               + 
+--R                         8   6          9 5
+--R                 2228224a b x  + 524288a x
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                     5 5        4 2 4        3 4 3        2 6 2        8   14
+--R             (- 1024a c  - 9216a b c  - 8064a b c  - 1344a b c  - 36a b c)x
+--R           + 
+--R                        5   4          4 3 3         3 5 2        2 7         9
+--R               (- 46080a b c  - 107520a b c  - 40320a b c  - 2880a b c - 20a b )
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                           6 4          5 2 3          4 4 2         3 6
+--R                   - 51200a c  - 450560a b c  - 380160a b c  - 59136a b c
+--R                 + 
+--R                          2 8
+--R                   - 1320a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                       6   3           5 3 2          4 5          3 7  11
+--R             (- 737280a b c  - 1576960a b c  - 506880a b c - 25344a b )x
+--R           + 
+--R                       7 3           6 2 2           5 4           4 6  10
+--R             (- 409600a c  - 3194880a b c  - 2196480a b c - 219648a b )x
+--R           + 
+--R                        7   2           6 3            5 5  9
+--R             (- 3096576a b c  - 5218304a b c - 1025024a b )x
+--R           + 
+--R                        8 2           7 2            6 4  8
+--R             (- 1146880a c  - 6881280a b c - 2795520a b )x
+--R           + 
+--R                        8              7 3  7              9            8 2  6
+--R             (- 4718592a b c - 4587520a b )x  + (- 1310720a c - 4456448a b )x
+--R           + 
+--R                       9   5          10 4
+--R             - 2359296a b x  - 524288a  x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                     5 5        4 2 4        3 4 3        2 6 2        8   15
+--R             (- 1024a c  - 9216a b c  - 8064a b c  - 1344a b c  - 36a b c)x
+--R           + 
+--R                        5   4          4 3 3         3 5 2        2 7         9
+--R               (- 46592a b c  - 112128a b c  - 44352a b c  - 3552a b c - 38a b )
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                           6 4          5 2 3          4 4 2         3 6
+--R                   - 51200a c  - 471040a b c  - 426240a b c  - 75264a b c
+--R                 + 
+--R                          2 8
+--R                   - 2280a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                       6   3           5 3 2          4 5          3 7  12
+--R             (- 757760a b c  - 1745920a b c  - 633600a b c - 40128a b )x
+--R           + 
+--R                       7 3           6 2 2           5 4           4 6  11
+--R             (- 409600a c  - 3440640a b c  - 2647040a b c - 321024a b )x
+--R           + 
+--R                        7   2           6 3            5 5  10
+--R             (- 3219456a b c  - 6017024a b c - 1391104a b )x
+--R           + 
+--R                        8 2           7 2            6 4  9
+--R             (- 1146880a c  - 7569408a b c - 3540992a b )x
+--R           + 
+--R                        8              7 3  8              9            8 2  7
+--R             (- 4947968a b c - 5447680a b )x  + (- 1310720a c - 4980736a b )x
+--R           + 
+--R                       9   6          10 5
+--R             - 2490368a b x  - 524288a  x
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                   4   5         3 3 4        2 5 3         7 2     9   15
+--R             (4608a b c  + 10752a b c  + 4032a b c  + 288a b c  + 2b c)x
+--R           + 
+--R                       5 5         4 2 4         3 4 3         2 6 2         8
+--R                 10240a c  + 94464a b c  + 86016a b c  + 15456a b c  + 504a b c
+--R               + 
+--R                  10
+--R                 b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                          5   4          4 3 3          3 5 2         2 7
+--R                   235520a b c  + 568320a b c  + 225792a b c  + 18240a b c
+--R                 + 
+--R                         9
+--R                   200a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                        6 4           5 2 3           4 4 2          3 6
+--R                 174080a c  + 1576960a b c  + 1393920a b c  + 236544a b c
+--R               + 
+--R                      2 8
+--R                 6600a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                      6   3           5 3 2           4 5          3 7  11
+--R             (1925120a b c  + 4280320a b c  + 1469952a b c + 84480a b )x
+--R           + 
+--R                     7 3           6 2 2           5 4           4 6  10
+--R             (851968a c  + 6868992a b c  + 4978688a b c + 549120a b )x
+--R           + 
+--R                      7   2           6 3            5 5  9
+--R             (5505024a b c  + 9691136a b c + 2050048a b )x
+--R           + 
+--R                      8 2            7 2            6 4  8
+--R             (1736704a c  + 10813440a b c + 4659200a b )x
+--R           + 
+--R                      8              7 3  7            9            8 2  6
+--R             (6422528a b c + 6553600a b )x  + (1572864a c + 5570560a b )x
+--R           + 
+--R                     9   5          10 4
+--R             2621440a b x  + 524288a  x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     3   2       2 3         5  5         3 2        2 4  4
+--R               (1152a b c  + 768a b c - 72a b )x  + (4608a b c - 384a b )x
+--R             + 
+--R                     4          3 3  3
+--R               (4608a b c - 384a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       2 2 2      6  6           3   2        2 3          5  5
+--R               (- 1728a b c  + 12b )x  + (- 3456a b c  - 2304a b c + 216a b )x
+--R             + 
+--R                       3 2        2 4  4           4          3 3  3
+--R               (- 6912a b c + 576a b )x  + (- 4608a b c + 384a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                                     +--------------+
+--R          +------------------+       |   2                           +-+
+--R          |   4      3      2     2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         \|c x  + b x  + a x  log(--------------------------------------)
+--R                                                   2a x
+--R     + 
+--R                       2 2 2      6  7           3   2        2 3          5  6
+--R               (- 1728a b c  + 12b )x  + (- 3456a b c  - 2304a b c + 216a b )x
+--R             + 
+--R                       3 2        2 4  5           4          3 3  4
+--R               (- 6912a b c + 576a b )x  + (- 4608a b c + 384a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                 3   3       2 3 2        5   8
+--R           (1152a b c  + 768a b c  - 72a b c)x
+--R         + 
+--R                 3 2 2       2 4         6  7
+--R           (5760a b c  + 384a b c - 72a b )x
+--R         + 
+--R                 4   2        3 3        2 5  6         4 2        3 4  5
+--R           (5760a b c  + 4992a b c - 456a b )x  + (9216a b c - 768a b )x
+--R         + 
+--R                 5          4 3  4
+--R           (4608a b c - 384a b )x
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                     3   2       2 3   7         4 2        3 2   6
+--R               (2304a b c  + 192a b c)x  + (4608a c  + 3456a b c)x
+--R             + 
+--R                    4     5        5   4
+--R               9216a b c x  + 6144a c x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                       3 3        2 2 2  8           3   2        2 3   7
+--R               (- 1536a c  - 1152a b c )x  + (- 7680a b c  - 1152a b c)x
+--R             + 
+--R                       4 2        3 2   6         4     5        5   4
+--R               (- 7680a c  - 7296a b c)x  - 12288a b c x  - 6144a c x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                    3 2        2 2   5         3     4         4   3  +---+ +-+
+--R             ((3072a c  + 2304a b c)x  + 12288a b c x  + 12288a c x )\|- c \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       3   2       2 3   6           4 2        3 2   5
+--R               (- 4608a b c  - 384a b c)x  + (- 9216a c  - 6912a b c)x
+--R             + 
+--R                       4     4         5   3
+--R               - 18432a b c x  - 12288a c x
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                                    +--------------+
+--R          +------------------+      |   2               +-+
+--R          |   4      3      2      \|c x  + b x + a  - \|a
+--R         \|c x  + b x  + a x  atan(------------------------)
+--R                                              +---+
+--R                                            x\|- c
+--R     + 
+--R                     3   2       2 3         5  5
+--R               (2592a b c  + 176a b c + 18a b )x
+--R             + 
+--R                     4 2        3 2        2 4  4          4           3 3  3
+--R               (6144a c  + 4608a b c + 512a b )x  + (13824a b c + 3200a b )x
+--R             + 
+--R                     5         4 2  2        5           6
+--R               (9728a c + 7296a b )x  + 6656a b x + 2048a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       3 3        2 2 2        4     6  6
+--R               (- 2048a c  - 1008a b c  - 72a b c + b )x
+--R             + 
+--R                       3   2        2 3          5  5
+--R               (- 9696a b c  - 2064a b c - 126a b )x
+--R             + 
+--R                        4 2         3 2         2 4  4
+--R               (- 10752a c  - 12672a b c - 1536a b )x
+--R             + 
+--R                        4           3 3  3            5          4 2  2
+--R               (- 21504a b c - 6144a b )x  + (- 10752a c - 10368a b )x
+--R             + 
+--R                      5           6
+--R               - 7680a b x - 2048a
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 3 3        2 2 2         4   7
+--R           (2048a c  + 1728a b c  + 144a b c)x
+--R         + 
+--R                  3   2        2 3          5  6
+--R           (11136a b c  + 3168a b c + 144a b )x
+--R         + 
+--R                  4 2         3 2         2 4  5          4           3 3  4
+--R           (10752a c  + 15552a b c + 1584a b )x  + (23424a b c + 6176a b )x
+--R         + 
+--R                  5          4 2  3        5   2        6
+--R           (10752a c + 10368a b )x  + 7680a b x  + 2048a x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R               3   3       2 3 2        5   8
+--R       (- 3072a b c  - 544a b c  - 24a b c)x
+--R     + 
+--R               4 3        3 2 2        2 4         6  7
+--R       (- 6144a c  - 9600a b c  - 1088a b c - 24a b )x
+--R     + 
+--R                4   2         3 3        2 5  6
+--R       (- 24960a b c  - 10304a b c - 568a b )x
+--R     + 
+--R                5 2         4 2         3 4  5            5            4 3  4
+--R       (- 15872a c  - 29568a b c - 3776a b )x  + (- 32128a b c - 10528a b )x
+--R     + 
+--R                6          5 2  3        6   2        7
+--R       (- 11776a c - 13952a b )x  - 8704a b x  - 2048a x
+--R  /
+--R                                                              +--------------+
+--R                3         2 2  5        3   4        4 3  +-+ |   2
+--R         ((1536a c + 1152a b )x  + 6144a b x  + 6144a x )\|a \|c x  + b x + a
+--R       + 
+--R                 3          2 3  6           4         3 2  5        4   4
+--R         (- 2304a b c - 192a b )x  + (- 4608a c - 3456a b )x  - 9216a b x
+--R       + 
+--R                5 3
+--R         - 6144a x
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      3   4       2 3 3        5 2    7   9
+--R               (- 448a b c  - 560a b c  - 84a b c  - b c)x
+--R             + 
+--R                      4 4        3 2 3        2 4 2         6     8  8
+--R               (- 896a c  - 5152a b c  - 2520a b c  - 182a b c - b )x
+--R             + 
+--R                        4   3         3 3 2        2 5         7  7
+--R               (- 12096a b c  - 17808a b c  - 3612a b c - 99a b )x
+--R             + 
+--R                       5 3         4 2 2         3 4         2 6  6
+--R               (- 8064a c  - 47712a b c  - 23912a b c - 1666a b )x
+--R             + 
+--R                        5   2         4 3          3 5  5
+--R               (- 53760a b c  - 71680a b c - 10976a b )x
+--R             + 
+--R                        6 2          5 2          4 4  4
+--R               (- 21504a c  - 107520a b c - 36288a b )x
+--R             + 
+--R                        6            5 3  3            7          6 2  2
+--R               (- 78848a b c - 66304a b )x  + (- 22528a c - 68096a b )x
+--R             + 
+--R                       7           8
+--R               - 36864a b x - 8192a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                4 5       3 2 4       2 4 3        6 2  10
+--R           (128a c  + 672a b c  + 280a b c  + 14a b c )x
+--R         + 
+--R                 4   4        3 3 3        2 5 2        7   9
+--R           (3328a b c  + 4928a b c  + 1008a b c  + 28a b c)x
+--R         + 
+--R                 5 4         4 2 3         3 4 2        2 6         8  8
+--R           (3328a c  + 21440a b c  + 12432a b c  + 1204a b c + 14a b )x
+--R         + 
+--R                  5   3         4 3 2         3 5        2 7  7
+--R           (33024a b c  + 54592a b c  + 13104a b c + 476a b )x
+--R         + 
+--R                  6 3          5 2 2         4 4         3 6  6
+--R           (16512a c  + 106656a b c  + 60056a b c + 4942a b )x
+--R         + 
+--R                  6   2          5 3          4 5  5
+--R           (95232a b c  + 138752a b c + 23872a b )x
+--R         + 
+--R                  7 2          6 2          5 4  4           7            6 3  3
+--R           (31744a c  + 170496a b c + 62912a b )x  + (106496a b c + 96256a b )x
+--R         + 
+--R                  8          7 2  2         8           9
+--R           (26624a c + 85504a b )x  + 40960a b x + 8192a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  4 5       3 2 4       2 4 3        6 2  11
+--R           (- 128a c  - 672a b c  - 280a b c  - 14a b c )x
+--R         + 
+--R                   4   4        3 3 3        2 5 2        7   10
+--R           (- 3328a b c  - 4928a b c  - 1008a b c  - 28a b c)x
+--R         + 
+--R                   5 4         4 2 3         3 4 2        2 6         8  9
+--R           (- 3328a c  - 21440a b c  - 12432a b c  - 1204a b c - 14a b )x
+--R         + 
+--R                    5   3         4 3 2         3 5        2 7  8
+--R           (- 33024a b c  - 54592a b c  - 13104a b c - 476a b )x
+--R         + 
+--R                    6 3          5 2 2         4 4         3 6  7
+--R           (- 16512a c  - 106656a b c  - 60056a b c - 4942a b )x
+--R         + 
+--R                    6   2          5 3          4 5  6
+--R           (- 95232a b c  - 138752a b c - 23872a b )x
+--R         + 
+--R                    7 2          6 2          5 4  5
+--R           (- 31744a c  - 170496a b c - 62912a b )x
+--R         + 
+--R                     7            6 3  4            8          7 2  3
+--R           (- 106496a b c - 96256a b )x  + (- 26624a c - 85504a b )x
+--R         + 
+--R                   8   2        9
+--R           - 40960a b x  - 8192a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                3   5       2 3 4        5 3    7 2  12
+--R           (448a b c  + 560a b c  + 84a b c  + b c )x
+--R         + 
+--R                4 5        3 2 4        2 4 3         6 2     8   11
+--R           (896a c  + 5600a b c  + 3080a b c  + 266a b c  + 2b c)x
+--R         + 
+--R                  4   4         3 3 3        2 5 2         7     9  10
+--R           (13440a b c  + 23520a b c  + 6216a b c  + 282a b c + b )x
+--R         + 
+--R                 5 4         4 2 3         3 4 2        2 6          8  9
+--R           (8960a c  + 64960a b c  + 44240a b c  + 5460a b c + 100a b )x
+--R         + 
+--R                  5   3          4 3 2         3 5         2 7  8
+--R           (73920a b c  + 137200a b c  + 38500a b c + 1765a b )x
+--R         + 
+--R                  6 3          5 2 2          4 4          3 6  7
+--R           (29568a c  + 208992a b c  + 131880a b c + 12642a b )x
+--R         + 
+--R                   6   2          5 3          4 5  6
+--R           (154112a b c  + 245504a b c + 47264a b )x
+--R         + 
+--R                  7 2          6 2           5 4  5
+--R           (44032a c  + 254464a b c + 102592a b )x
+--R         + 
+--R                   7             6 3  4          8           7 2  3
+--R           (138240a b c + 134400a b )x  + (30720a c + 104960a b )x
+--R         + 
+--R                 8   2        9
+--R           45056a b x  + 8192a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  4 3       3 2 2       2 4         6  10
+--R             (128a c  + 672a b c  + 280a b c + 14a b )x
+--R           + 
+--R                   4   2        3 3        2 5  9
+--R             (3072a b c  + 3584a b c + 448a b )x
+--R           + 
+--R                   5 2         4 2         3 4  8          5            4 3  7
+--R             (3072a c  + 13824a b c + 4032a b )x  + (20480a b c + 15360a b )x
+--R           + 
+--R                    6          5 2  6         6   5        7 4
+--R             (10240a c + 28160a b )x  + 24576a b x  + 8192a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    3   3       2 3 2        5     7  11
+--R             (- 448a b c  - 560a b c  - 84a b c - b )x
+--R           + 
+--R                    4 3        3 2 2        2 4         6  10
+--R             (- 896a c  - 4704a b c  - 1960a b c - 98a b )x
+--R           + 
+--R                      4   2         3 3         2 5  9
+--R             (- 10752a b c  - 12544a b c - 1568a b )x
+--R           + 
+--R                     5 2         4 2         3 4  8
+--R             (- 7168a c  - 32256a b c - 9408a b )x
+--R           + 
+--R                      5            4 3  7            6          5 2  6
+--R             (- 35840a b c - 26880a b )x  + (- 14336a c - 39424a b )x
+--R           + 
+--R                     6   5        7 4
+--R             - 28672a b x  - 8192a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^8
+--R 
+--R
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R   (1)  -------------------------------------
+--R                           6
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 704
+r0:=-1/4*(a*x^2+b*x^3+c*x^4)^(3/2)/x^7-3/128*(b^2-4*a*c)^2*x*atanh(1/2*_
+   (2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(a^(5/2)*_
+   sqrt(a*x^2+b*x^3+c*x^4))-1/32*(b^2-12*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/_
+   (a*x^3)+1/64*b*(3*b^2-20*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*x^2)-_
+   1/8*(b+6*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/x^4
+--R 
+--R
+--R   (2)
+--R                                      +--------------+
+--R               2 2        2      4  4 |   2
+--R         (- 48a c  + 24a b c - 3b )x \|c x  + b x + a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                     2     3   5         2 2        2      4  4
+--R           (- 40a b c  + 6b c)x  + (- 80a c  - 44a b c + 6b )x
+--R         + 
+--R                  2          3  3          3       2 2  2      3         4
+--R           (- 168a b c + 2a b )x  + (- 112a c - 52a b )x  - 80a b x - 32a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 +------------------+
+--R         2 3 +-+ |   4      3      2
+--R     128a x \|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      4   3        3 3 2       2 5          7  7
+--R               (12288a b c  - 3072a b c  - 768a b c + 192a b )x
+--R             + 
+--R                      5 3         4 2 2         3 4         2 6  6
+--R               (24576a c  + 18432a b c  - 13824a b c + 1920a b )x
+--R             + 
+--R                      5   2         4 3         3 5  5
+--R               (73728a b c  - 36864a b c + 4608a b )x
+--R             + 
+--R                      6 2         5 2         4 4  4
+--R               (49152a c  - 24576a b c + 3072a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       4 4        3 2 3        2 4 2         6       8  8
+--R               (- 6144a c  - 6144a b c  + 3840a b c  - 384a b c - 24b )x
+--R             + 
+--R                        4   3         3 3 2        2 5          7  7
+--R               (- 49152a b c  + 12288a b c  + 3072a b c - 768a b )x
+--R             + 
+--R                        5 3         4 2 2         3 4         2 6  6
+--R               (- 49152a c  - 36864a b c  + 27648a b c - 3840a b )x
+--R             + 
+--R                        5   2         4 3         3 5  5
+--R               (- 98304a b c  + 49152a b c - 6144a b )x
+--R             + 
+--R                        6 2         5 2         4 4  4
+--R               (- 49152a c  + 24576a b c - 3072a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +--------------+
+--R               +-+ |   2
+--R             2\|a \|c x  + b x + a  - b x - 2a
+--R         log(---------------------------------)
+--R                              +-+
+--R                           2x\|a
+--R     + 
+--R                 4   3        3 3 2       2 5        7  7
+--R           (5120a b c  + 5888a b c  - 864a b c + 8a b )x
+--R         + 
+--R                  5 3         4 2 2        3 4        2 6  6
+--R           (10240a c  + 54784a b c  + 3392a b c - 944a b )x
+--R         + 
+--R                   5   2         4 3         3 5  5
+--R           (129024a b c  + 72704a b c - 4928a b )x
+--R         + 
+--R                  6 2          5 2         4 4  4           6            5 3  3
+--R           (86016a c  + 239616a b c + 6272a b )x  + (286720a b c + 71680a b )x
+--R         + 
+--R                   7           6 2  2          7            8
+--R           (114688a c + 143360a b )x  + 114688a b x + 32768a
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   3 2 3       2 4 2         6      8  8
+--R           (- 9728a b c  - 368a b c  + 248a b c - 7b )x
+--R         + 
+--R                    4   3         3 3 2        2 5          7  7
+--R           (- 40960a b c  - 34816a b c  + 2688a b c + 160a b )x
+--R         + 
+--R                    5 3          4 2 2         3 4         2 6  6
+--R           (- 40960a c  - 174080a b c  - 21888a b c + 2848a b )x
+--R         + 
+--R                     5   2          4 3         3 5  5
+--R           (- 278528a b c  - 180224a b c + 5376a b )x
+--R         + 
+--R                     6 2          5 2          4 4  4
+--R           (- 139264a c  - 417792a b c - 30080a b )x
+--R         + 
+--R                     6             5 3  3             7           6 2  2
+--R           (- 393216a b c - 131072a b )x  + (- 131072a c - 196608a b )x
+--R         + 
+--R                    7            8
+--R           - 131072a b x - 32768a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  4           3 3  7          5          4 2  6          5   5
+--R           (32768a b c + 8192a b )x  + (65536a c + 81920a b )x  + 196608a b x
+--R         + 
+--R                  6 4
+--R           131072a x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R                5 2         4 2         3 4  8             5            4 3  7
+--R       (- 16384a c  - 24576a b c - 1024a b )x  + (- 131072a b c - 32768a b )x
+--R     + 
+--R                 6           5 2  6          6   5          7 4
+--R       (- 131072a c - 163840a b )x  - 262144a b x  - 131072a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 297
+
+--S 298 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      3   3        2 3 2         5        7  7
+--R               (12288a b c  - 3072a b c  - 768a b c + 192b )x
+--R             + 
+--R                      4 3         3 2 2         2 4           6  6
+--R               (24576a c  + 18432a b c  - 13824a b c + 1920a b )x
+--R             + 
+--R                      4   2         3 3         2 5  5
+--R               (73728a b c  - 36864a b c + 4608a b )x
+--R             + 
+--R                      5 2         4 2         3 4  4
+--R               (49152a c  - 24576a b c + 3072a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                   4 4        3 2 3        2 4 2         6       8  8
+--R           (- 6144a c  - 6144a b c  + 3840a b c  - 384a b c - 24b )x
+--R         + 
+--R                    4   3         3 3 2        2 5          7  7
+--R           (- 49152a b c  + 12288a b c  + 3072a b c - 768a b )x
+--R         + 
+--R                    5 3         4 2 2         3 4         2 6  6
+--R           (- 49152a c  - 36864a b c  + 27648a b c - 3840a b )x
+--R         + 
+--R                    5   2         4 3         3 5  5
+--R           (- 98304a b c  + 49152a b c - 6144a b )x
+--R         + 
+--R                    6 2         5 2         4 4  4
+--R           (- 49152a c  + 24576a b c - 3072a b )x
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                       4 4        3 2 3        2 4 2         6       8  9
+--R               (- 6144a c  - 6144a b c  + 3840a b c  - 384a b c - 24b )x
+--R             + 
+--R                        4   3         3 3 2        2 5          7  8
+--R               (- 49152a b c  + 12288a b c  + 3072a b c - 768a b )x
+--R             + 
+--R                        5 3         4 2 2         3 4         2 6  7
+--R               (- 49152a c  - 36864a b c  + 27648a b c - 3840a b )x
+--R             + 
+--R                        5   2         4 3         3 5  6
+--R               (- 98304a b c  + 49152a b c - 6144a b )x
+--R             + 
+--R                        6 2         5 2         4 4  5
+--R               (- 49152a c  + 24576a b c - 3072a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      3   4        2 3 3         5 2       7   10
+--R               (12288a b c  - 3072a b c  - 768a b c  + 192b c)x
+--R             + 
+--R                      4 4         3 2 3         2 4 2          6        8  9
+--R               (24576a c  + 30720a b c  - 16896a b c  + 1152a b c + 192b )x
+--R             + 
+--R                       4   3         3 3 2        2 5           7  8
+--R               (110592a b c  - 21504a b c  - 9984a b c + 2112a b )x
+--R             + 
+--R                      5 3         4 2 2         3 4         2 6  7
+--R               (73728a c  + 67584a b c  - 47616a b c + 6528a b )x
+--R             + 
+--R                       5   2         4 3         3 5  6
+--R               (122880a b c  - 61440a b c + 7680a b )x
+--R             + 
+--R                      6 2         5 2         4 4  5
+--R               (49152a c  - 24576a b c + 3072a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                     3   3        2 3 2         5      7  7
+--R               (5120a b c  + 5888a b c  - 864a b c + 8b )x
+--R             + 
+--R                      4 3         3 2 2        2 4          6  6
+--R               (10240a c  + 54784a b c  + 3392a b c - 944a b )x
+--R             + 
+--R                       4   2         3 3         2 5  5
+--R               (129024a b c  + 72704a b c - 4928a b )x
+--R             + 
+--R                      5 2          4 2         3 4  4
+--R               (86016a c  + 239616a b c + 6272a b )x
+--R             + 
+--R                       5            4 3  3           6           5 2  2
+--R               (286720a b c + 71680a b )x  + (114688a c + 143360a b )x
+--R             + 
+--R                      6            7
+--R               114688a b x + 32768a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                   3 2 3       2 4 2         6      8  8
+--R           (- 9728a b c  - 368a b c  + 248a b c - 7b )x
+--R         + 
+--R                    4   3         3 3 2        2 5          7  7
+--R           (- 40960a b c  - 34816a b c  + 2688a b c + 160a b )x
+--R         + 
+--R                    5 3          4 2 2         3 4         2 6  6
+--R           (- 40960a c  - 174080a b c  - 21888a b c + 2848a b )x
+--R         + 
+--R                     5   2          4 3         3 5  5
+--R           (- 278528a b c  - 180224a b c + 5376a b )x
+--R         + 
+--R                     6 2          5 2          4 4  4
+--R           (- 139264a c  - 417792a b c - 30080a b )x
+--R         + 
+--R                     6             5 3  3             7           6 2  2
+--R           (- 393216a b c - 131072a b )x  + (- 131072a c - 196608a b )x
+--R         + 
+--R                    7            8
+--R           - 131072a b x - 32768a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  3 2 3        2 4 2         6   9
+--R           (10240a b c  + 1024a b c  - 384a b c)x
+--R         + 
+--R                  4   3         3 3 2        2 5          7  8
+--R           (40960a b c  + 38912a b c  - 2560a b c - 384a b )x
+--R         + 
+--R                  5 3          4 2 2         3 4         2 6  7
+--R           (40960a c  + 178176a b c  + 26112a b c - 3968a b )x
+--R         + 
+--R                   5   2          4 3         3 5  6
+--R           (278528a b c  + 188416a b c - 7168a b )x
+--R         + 
+--R                   6 2          5 2          4 4  5
+--R           (139264a c  + 421888a b c + 29184a b )x
+--R         + 
+--R                   6             5 3  4           7           6 2  3
+--R           (393216a b c + 131072a b )x  + (131072a c + 196608a b )x
+--R         + 
+--R                  7   2         8
+--R           131072a b x  + 32768a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   3   4        2 3 3         5 2      7   10
+--R           (- 5120a b c  - 6912a b c  + 832a b c  + 48b c)x
+--R         + 
+--R                    4 4         3 2 3         2 4 2          6       8  9
+--R           (- 10240a c  - 61952a b c  - 12416a b c  + 2336a b c + 48b )x
+--R         + 
+--R                     4   3          3 3 2        2 5           7  8
+--R           (- 144384a b c  - 142592a b c  + 1600a b c + 1552a b )x
+--R         + 
+--R                    5 3          4 2 2         3 4         2 6  7
+--R           (- 96256a c  - 429568a b c  - 89728a b c + 7776a b )x
+--R         + 
+--R                     5   2          4 3        3 5  6
+--R           (- 501760a b c  - 394240a b c + 896a b )x
+--R         + 
+--R                     6 2          5 2          4 4  5
+--R           (- 200704a c  - 673792a b c - 77056a b )x
+--R         + 
+--R                     6             5 3  4             7           6 2  3
+--R           (- 516096a b c - 215040a b )x  + (- 147456a c - 258048a b )x
+--R         + 
+--R                    7   2         8
+--R           - 147456a b x  - 32768a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                    4           3 3  7          5          4 2  6          5   5
+--R             (32768a b c + 8192a b )x  + (65536a c + 81920a b )x  + 196608a b x
+--R           + 
+--R                    6 4
+--R             131072a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                      4 2         3 2         2 4  8
+--R             (- 16384a c  - 24576a b c - 1024a b )x
+--R           + 
+--R                       4            3 3  7             5           4 2  6
+--R             (- 131072a b c - 32768a b )x  + (- 131072a c - 163840a b )x
+--R           + 
+--R                      5   5          6 4
+--R             - 262144a b x  - 131072a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       3   5        2 3 4         5 3      7 2  11
+--R               (- 1024a b c  - 1792a b c  - 448a b c  - 16b c )x
+--R             + 
+--R                       4 5         3 2 4         2 4 3          6 2      8   10
+--R               (- 2048a c  - 15872a b c  - 11648a b c  - 1568a b c  - 32b c)x
+--R             + 
+--R                        4   4         3 3 3         2 5 2          7       9  9
+--R               (- 36864a b c  - 78336a b c  - 26880a b c  - 1824a b c - 16b )x
+--R             + 
+--R                           5 4          4 2 3          3 4 2         2 6
+--R                   - 24576a c  - 205824a b c  - 167936a b c  - 26432a b c
+--R                 + 
+--R                           8
+--R                   - 704a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                         5   3          4 3 2          3 5         2 7  7
+--R               (- 230400a b c  - 490240a b c  - 163264a b c - 9424a b )x
+--R             + 
+--R                        6 3          5 2 2          4 4          3 6  6
+--R               (- 92160a c  - 726528a b c  - 522624a b c - 59040a b )x
+--R             + 
+--R                         6   2          5 3           4 5  5
+--R               (- 530432a b c  - 939008a b c - 205184a b )x
+--R             + 
+--R                         7 2          6 2           5 4  4
+--R               (- 151552a c  - 956416a b c - 427264a b )x
+--R             + 
+--R                         7             6 3  3             8           7 2  2
+--R               (- 516096a b c - 546816a b )x  + (- 114688a c - 421888a b )x
+--R             + 
+--R                        8            9
+--R               - 180224a b x - 32768a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                4 6        3 2 5        2 4 4         6 3    8 2  12
+--R           (256a c  + 1792a b c  + 1120a b c  + 112a b c  + b c )x
+--R         + 
+--R                 4   5         3 3 4        2 5 3         7 2     9   11
+--R           (8704a b c  + 17920a b c  + 5824a b c  + 352a b c  + 2b c)x
+--R         + 
+--R                      5 5         4 2 4         3 4 3         2 6 2         8
+--R                 8704a c  + 75520a b c  + 64960a b c  + 11200a b c  + 370a b c
+--R               + 
+--R                  10
+--R                 b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                   5   4          4 3 3          3 5 2        2 7          9  9
+--R           (115200a b c  + 273920a b c  + 109760a b c  + 9440a b c + 130a b )x
+--R         + 
+--R                  6 4          5 2 3          4 4 2         3 6         2 8  8
+--R           (57600a c  + 526080a b c  + 479840a b c  + 87920a b c + 2945a b )x
+--R         + 
+--R                   6   3           5 3 2          4 5          3 7  7
+--R           (466944a b c  + 1083392a b c  + 402944a b c + 27008a b )x
+--R         + 
+--R                   7 3           6 2 2           5 4           4 6  6
+--R           (155648a c  + 1316864a b c  + 1032704a b c + 130176a b )x
+--R         + 
+--R                   7   2           6 3           5 5  5
+--R           (819200a b c  + 1556480a b c + 370688a b )x
+--R         + 
+--R                   8 2           7 2           6 4  4
+--R           (204800a c  + 1372160a b c + 657920a b )x
+--R         + 
+--R                   8             7 3  3           9           8 2  2
+--R           (655360a b c + 737280a b )x  + (131072a c + 507904a b )x
+--R         + 
+--R                  9            10
+--R           196608a b x + 32768a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  4 6        3 2 5        2 4 4         6 3    8 2  13
+--R           (- 256a c  - 1792a b c  - 1120a b c  - 112a b c  - b c )x
+--R         + 
+--R                   4   5         3 3 4        2 5 3         7 2     9   12
+--R           (- 8704a b c  - 17920a b c  - 5824a b c  - 352a b c  - 2b c)x
+--R         + 
+--R                      5 5         4 2 4         3 4 3         2 6 2         8
+--R               - 8704a c  - 75520a b c  - 64960a b c  - 11200a b c  - 370a b c
+--R             + 
+--R                  10
+--R               - b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          5   4          4 3 3          3 5 2        2 7
+--R                 - 115200a b c  - 273920a b c  - 109760a b c  - 9440a b c
+--R               + 
+--R                         9
+--R                 - 130a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                    6 4          5 2 3          4 4 2         3 6         2 8  9
+--R           (- 57600a c  - 526080a b c  - 479840a b c  - 87920a b c - 2945a b )x
+--R         + 
+--R                     6   3           5 3 2          4 5          3 7  8
+--R           (- 466944a b c  - 1083392a b c  - 402944a b c - 27008a b )x
+--R         + 
+--R                     7 3           6 2 2           5 4           4 6  7
+--R           (- 155648a c  - 1316864a b c  - 1032704a b c - 130176a b )x
+--R         + 
+--R                     7   2           6 3           5 5  6
+--R           (- 819200a b c  - 1556480a b c - 370688a b )x
+--R         + 
+--R                     8 2           7 2           6 4  5
+--R           (- 204800a c  - 1372160a b c - 657920a b )x
+--R         + 
+--R                     8             7 3  4             9           8 2  3
+--R           (- 655360a b c - 737280a b )x  + (- 131072a c - 507904a b )x
+--R         + 
+--R                    9   2         10
+--R           - 196608a b x  - 32768a  x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 3   6        2 3 5         5 4      7 3  14
+--R           (1024a b c  + 1792a b c  + 448a b c  + 16b c )x
+--R         + 
+--R                 4 6         3 2 5         2 4 4          6 3      8 2  13
+--R           (2048a c  + 16896a b c  + 13440a b c  + 2016a b c  + 48b c )x
+--R         + 
+--R                  4   5         3 3 4         2 5 3          7 2      9   12
+--R           (39936a b c  + 96000a b c  + 38976a b c  + 3408a b c  + 48b c)x
+--R         + 
+--R                     5 5          4 2 4          3 4 3         2 6 2          8
+--R               26624a c  + 258560a b c  + 257920a b c  + 54880a b c  + 2560a b c
+--R             + 
+--R                  10
+--R               16b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                     5   4          4 3 3          3 5 2         2 7          9
+--R             (291840a b c  + 774400a b c  + 358080a b c  + 37680a b c + 720a b )
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                      6 4           5 2 3           4 4 2          3 6
+--R               116736a c  + 1162752a b c  + 1180800a b c  + 248736a b c
+--R             + 
+--R                     2 8
+--R               10128a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                   6   3           5 3 2          4 5          3 7  8
+--R           (852992a b c  + 2155776a b c  + 891072a b c + 68464a b )x
+--R         + 
+--R                   7 3           6 2 2           5 4           4 6  7
+--R           (243712a c  + 2213376a b c  + 1888896a b c + 264224a b )x
+--R         + 
+--R                    7   2           6 3           5 5  6
+--R           (1198080a b c  + 2442240a b c + 632448a b )x
+--R         + 
+--R                   8 2           7 2           6 4  5
+--R           (266240a c  + 1894400a b c + 974080a b )x
+--R         + 
+--R                   8             7 3  4           9           8 2  3
+--R           (811008a b c + 968704a b )x  + (147456a c + 602112a b )x
+--R         + 
+--R                  9   2         10
+--R           212992a b x  + 32768a  x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  4 4        3 2 3        2 4 2         6     8  13
+--R             (256a c  + 1792a b c  + 1120a b c  + 112a b c + b )x
+--R           + 
+--R                   4   3         3 3 2        2 5          7  12
+--R             (8192a b c  + 14336a b c  + 3584a b c + 128a b )x
+--R           + 
+--R                   5 3         4 2 2         3 4         2 6  11
+--R             (8192a c  + 55296a b c  + 32256a b c + 2688a b )x
+--R           + 
+--R                    5   2          4 3          3 5  10
+--R             (81920a b c  + 122880a b c + 21504a b )x
+--R           + 
+--R                    6 2          5 2          4 4  9
+--R             (40960a c  + 225280a b c + 84480a b )x
+--R           + 
+--R                     6             5 3  8          7           6 2  7
+--R             (196608a b c + 180224a b )x  + (65536a c + 212992a b )x
+--R           + 
+--R                    7   6         8 5
+--R             131072a b x  + 32768a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                     3   4        2 3 3         5 2      7   14
+--R             (- 1024a b c  - 1792a b c  - 448a b c  - 16b c)x
+--R           + 
+--R                     4 4         3 2 3        2 4 2          6       8  13
+--R             (- 2048a c  - 14848a b c  - 9856a b c  - 1120a b c - 16b )x
+--R           + 
+--R                      4   3         3 3 2         2 5          7  12
+--R             (- 33792a b c  - 61696a b c  - 16576a b c - 688a b )x
+--R           + 
+--R                      5 3          4 2 2         3 4         2 6  11
+--R             (- 22528a c  - 157184a b c  - 96384a b c - 8736a b )x
+--R           + 
+--R                       5   2          4 3          3 5  10
+--R             (- 174080a b c  - 271360a b c - 50304a b )x
+--R           + 
+--R                      6 2          5 2           4 4  9
+--R             (- 69632a c  - 395264a b c - 154880a b )x
+--R           + 
+--R                       6             5 3  8            7           6 2  7
+--R             (- 286720a b c - 272384a b )x  + (- 81920a c - 274432a b )x
+--R           + 
+--R                      7   6         8 5
+--R             - 147456a b x  - 32768a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 299
+
+)clear all
+
+--S 300 of 704
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^9
+--R 
+--R
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R   (1)  -------------------------------------
+--R                           7
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 300
+
+--S 301 of 704
+r0:=-1/5*(a*x^2+b*x^3+c*x^4)^(3/2)/x^8+3/256*b*(b^2-4*a*c)^2*x*_
+   atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (a^(7/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/80*(b^2-8*a*c)*sqrt(a*x^2+b*x^3+_
+   c*x^4)/(a*x^4)+1/320*b*(5*b^2-28*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*x^3)-_
+   1/640*(15*b^4-100*a*b^2*c+128*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/_
+   (a^3*x^2)-3/40*(b+4*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/x^5
+--R 
+--R
+--R   (2)
+--R                                         +--------------+
+--R              2   2         3       5  5 |   2
+--R         (240a b c  - 120a b c + 15b )x \|c x  + b x + a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                  2 3         2 2      4   6          2   2         3       5  5
+--R           (- 256a c  + 200a b c  - 30b c)x  + (- 368a b c  + 220a b c - 30b )x
+--R         + 
+--R                  3 2      2 2         4  4          3        2 3  3
+--R           (- 768a c  + 72a b c - 10a b )x  + (- 976a b c + 4a b )x
+--R         + 
+--R                  4        3 2  2       4          5
+--R           (- 768a c - 368a b )x  - 608a b x - 256a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  +------------------+
+--R          3 4 +-+ |   4      3      2
+--R     1280a x \|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        4   4          3 3 3         2 5 2        9  9
+--R               (- 61440a b c  - 122880a b c  + 53760a b c  - 1200b )x
+--R             + 
+--R                         4 2 3         3 4 2          2 6            8  8
+--R               (- 737280a b c  + 61440a b c  + 107520a b c - 19200a b )x
+--R             + 
+--R                         5   3          4 3 2          3 5          2 7  7
+--R               (- 737280a b c  - 921600a b c  + 599040a b c - 80640a b )x
+--R             + 
+--R                          5 2 2          4 4           3 6  6
+--R               (- 1966080a b c  + 983040a b c - 122880a b )x
+--R             + 
+--R                         6   2          5 3          4 5  5
+--R               (- 983040a b c  + 491520a b c - 61440a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                   4 2 4         2 6 2          8        10  10
+--R           (153600a b c  - 26880a b c  + 3840a b c + 120b  )x
+--R         + 
+--R                   5   4          4 3 3          3 5 2          9  9
+--R           (307200a b c  + 614400a b c  - 268800a b c  + 6000a b )x
+--R         + 
+--R                    5 2 3          4 4 2          3 6          2 8  8
+--R           (1843200a b c  - 153600a b c  - 268800a b c + 48000a b )x
+--R         + 
+--R                    6   3           5 3 2          4 5           3 7  7
+--R           (1228800a b c  + 1536000a b c  - 998400a b c + 134400a b )x
+--R         + 
+--R                    6 2 2           5 4           4 6  6
+--R           (2457600a b c  - 1228800a b c + 153600a b )x
+--R         + 
+--R                   7   2          6 3          5 5  5
+--R           (983040a b c  - 491520a b c + 61440a b )x
+--R      *
+--R                +--------------+
+--R                |   2                           +-+
+--R             2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         log(--------------------------------------)
+--R                              2a x
+--R     + 
+--R                   4   4         3 3 3         2 5 2          7        9  9
+--R           (153600a b c  - 62720a b c  - 25056a b c  + 7040a b c - 230b )x
+--R         + 
+--R                   5 4          4 2 3          3 4 2         2 6           8  8
+--R           (327680a c  + 512000a b c  - 419840a b c  + 37248a b c + 4320a b )x
+--R         + 
+--R                    5   3          4 3 2          3 5          2 7  7
+--R           (2314240a b c  - 317440a b c  - 249472a b c + 56544a b )x
+--R         + 
+--R                    6 3           5 2 2          4 4           3 6  6
+--R           (1966080a c  + 3686400a b c  - 778240a b c + 165888a b )x
+--R         + 
+--R                    6   2           5 3           4 5  5
+--R           (7577600a b c  + 1966080a b c + 297984a b )x
+--R         + 
+--R                    7 2           6 2            5 4  4
+--R           (3997696a c  + 8519680a b c + 1290240a b )x
+--R         + 
+--R                    7              6 3  3            8            7 2  2
+--R           (9469952a b c + 4055040a b )x  + (3407872a c + 5963776a b )x
+--R         + 
+--R                   8              9
+--R           4063232a b x + 1048576a
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R                   5 5         4 2 4         3 4 3         2 6 2         8
+--R           - 65536a c  - 87040a b c  + 90240a b c  - 10320a b c  - 800a b c
+--R         + 
+--R              10
+--R           47b
+--R      *
+--R          10
+--R         x
+--R     + 
+--R                 5   4          4 3 3          3 5 2         2 7         9  9
+--R       (- 829440a b c  + 190720a b c  + 179040a b c  - 35200a b c - 50a b )x
+--R     + 
+--R                 6 4           5 2 3           4 4 2         3 6          2 8  8
+--R       (- 983040a c  - 2058240a b c  + 1029120a b c  - 39360a b c - 20400a b )x
+--R     + 
+--R                  6   3          5 3 2          4 5           3 7  7
+--R       (- 5632000a b c  - 870400a b c  + 547200a b c - 121120a b )x
+--R     + 
+--R                  7 3           6 2 2          5 4           4 6  6
+--R       (- 3604480a c  - 9277440a b c  + 143360a b c - 263680a b )x
+--R     + 
+--R                   7   2           6 3           5 5  5
+--R       (- 13148160a b c  - 6389760a b c - 678912a b )x
+--R     + 
+--R                  8 2            7 2            6 4  4
+--R       (- 5570560a c  - 14991360a b c - 2785280a b )x
+--R     + 
+--R                   8              7 3  3              9            8 2  2
+--R       (- 12943360a b c - 6594560a b )x  + (- 3932160a c - 7864320a b )x
+--R     + 
+--R                 9              10
+--R       - 4587520a b x - 1048576a
+--R  /
+--R                   6 2          5 2           4 4  9
+--R           (327680a c  + 819200a b c + 102400a b )x
+--R         + 
+--R                    6              5 3  8            7            6 2  7
+--R           (3932160a b c + 1638400a b )x  + (3932160a c + 6881280a b )x
+--R         + 
+--R                    7   6           8 5
+--R           10485760a b x  + 5242880a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                     5   2          4 3          3 5  10
+--R           (- 819200a b c  - 409600a b c - 10240a b )x
+--R         + 
+--R                      6 2           5 2           4 4  9
+--R           (- 1638400a c  - 4096000a b c - 512000a b )x
+--R         + 
+--R                      6              5 3  8              7             6 2  7
+--R           (- 9830400a b c - 4096000a b )x  + (- 6553600a c - 11468800a b )x
+--R         + 
+--R                      7   6           8 5
+--R           - 13107200a b x  - 5242880a x
+--R      *
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 302
+
+--S 303 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        5   4          4 3 3         3 5 2          9  9
+--R               (- 61440a b c  - 122880a b c  + 53760a b c  - 1200a b )x
+--R             + 
+--R                         5 2 3         4 4 2          3 6          2 8  8
+--R               (- 737280a b c  + 61440a b c  + 107520a b c - 19200a b )x
+--R             + 
+--R                         6   3          5 3 2          4 5          3 7  7
+--R               (- 737280a b c  - 921600a b c  + 599040a b c - 80640a b )x
+--R             + 
+--R                          6 2 2          5 4           4 6  6
+--R               (- 1966080a b c  + 983040a b c - 122880a b )x
+--R             + 
+--R                         7   2          6 3          5 5  5
+--R               (- 983040a b c  + 491520a b c - 61440a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       4 2 4         2 6 2          8        10  10
+--R               (153600a b c  - 26880a b c  + 3840a b c + 120b  )x
+--R             + 
+--R                       5   4          4 3 3          3 5 2          9  9
+--R               (307200a b c  + 614400a b c  - 268800a b c  + 6000a b )x
+--R             + 
+--R                        5 2 3          4 4 2          3 6          2 8  8
+--R               (1843200a b c  - 153600a b c  - 268800a b c + 48000a b )x
+--R             + 
+--R                        6   3           5 3 2          4 5           3 7  7
+--R               (1228800a b c  + 1536000a b c  - 998400a b c + 134400a b )x
+--R             + 
+--R                        6 2 2           5 4           4 6  6
+--R               (2457600a b c  - 1228800a b c + 153600a b )x
+--R             + 
+--R                       7   2          6 3          5 5  5
+--R               (983040a b c  - 491520a b c + 61440a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                                     +--------------+
+--R          +------------------+       |   2                           +-+
+--R          |   4      3      2     2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         \|c x  + b x  + a x  log(--------------------------------------)
+--R                                                   2a x
+--R     + 
+--R                       4 2 4         2 6 2          8        10  11
+--R               (153600a b c  - 26880a b c  + 3840a b c + 120b  )x
+--R             + 
+--R                       5   4          4 3 3          3 5 2          9  10
+--R               (307200a b c  + 614400a b c  - 268800a b c  + 6000a b )x
+--R             + 
+--R                        5 2 3          4 4 2          3 6          2 8  9
+--R               (1843200a b c  - 153600a b c  - 268800a b c + 48000a b )x
+--R             + 
+--R                        6   3           5 3 2          4 5           3 7  8
+--R               (1228800a b c  + 1536000a b c  - 998400a b c + 134400a b )x
+--R             + 
+--R                        6 2 2           5 4           4 6  7
+--R               (2457600a b c  - 1228800a b c + 153600a b )x
+--R             + 
+--R                       7   2          6 3          5 5  6
+--R               (983040a b c  - 491520a b c + 61440a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                    5   5          4 3 4         3 5 3          9   12
+--R           (- 61440a b c  - 122880a b c  + 53760a b c  - 1200a b c)x
+--R         + 
+--R                        5 2 4         4 4 3          3 6 2         2 8
+--R               - 798720a b c  - 61440a b c  + 161280a b c  - 19200a b c
+--R             + 
+--R                        10
+--R               - 1200a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        6   4           5 3 3          4 5 2         3 7
+--R               - 798720a b c  - 1781760a b c  + 714240a b c  + 26880a b c
+--R             + 
+--R                       2 9
+--R               - 20400a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                      6 2 3          5 4 2          4 6          3 8  9
+--R           (- 3440640a b c  + 122880a b c  + 583680a b c - 99840a b )x
+--R         + 
+--R                      7   3           6 3 2           5 5           4 7  8
+--R           (- 1720320a b c  - 2396160a b c  + 1520640a b c - 203520a b )x
+--R         + 
+--R                      7 2 2           6 4           5 6  7
+--R           (- 2949120a b c  + 1474560a b c - 184320a b )x
+--R         + 
+--R                     8   2          7 3          6 5  6
+--R           (- 983040a b c  + 491520a b c - 61440a b )x
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                            5   4         4 3 3         3 5 2        2 7
+--R                     153600a b c  - 62720a b c  - 25056a b c  + 7040a b c
+--R                   + 
+--R                             9
+--R                     - 230a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                          6 4          5 2 3          4 4 2         3 6
+--R                   327680a c  + 512000a b c  - 419840a b c  + 37248a b c
+--R                 + 
+--R                        2 8
+--R                   4320a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                        6   3          5 3 2          4 5          3 7  7
+--R               (2314240a b c  - 317440a b c  - 249472a b c + 56544a b )x
+--R             + 
+--R                        7 3           6 2 2          5 4           4 6  6
+--R               (1966080a c  + 3686400a b c  - 778240a b c + 165888a b )x
+--R             + 
+--R                        7   2           6 3           5 5  5
+--R               (7577600a b c  + 1966080a b c + 297984a b )x
+--R             + 
+--R                        8 2           7 2            6 4  4
+--R               (3997696a c  + 8519680a b c + 1290240a b )x
+--R             + 
+--R                        8              7 3  3            9            8 2  2
+--R               (9469952a b c + 4055040a b )x  + (3407872a c + 5963776a b )x
+--R             + 
+--R                       9              10
+--R               4063232a b x + 1048576a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                           5 5         4 2 4         3 4 3         2 6 2
+--R                   - 65536a c  - 87040a b c  + 90240a b c  - 10320a b c
+--R                 + 
+--R                           8       10
+--R                   - 800a b c + 47b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            5   4          4 3 3          3 5 2         2 7
+--R                   - 829440a b c  + 190720a b c  + 179040a b c  - 35200a b c
+--R                 + 
+--R                          9
+--R                   - 50a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            6 4           5 2 3           4 4 2         3 6
+--R                   - 983040a c  - 2058240a b c  + 1029120a b c  - 39360a b c
+--R                 + 
+--R                           2 8
+--R                   - 20400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          6   3          5 3 2          4 5           3 7  7
+--R               (- 5632000a b c  - 870400a b c  + 547200a b c - 121120a b )x
+--R             + 
+--R                          7 3           6 2 2          5 4           4 6  6
+--R               (- 3604480a c  - 9277440a b c  + 143360a b c - 263680a b )x
+--R             + 
+--R                           7   2           6 3           5 5  5
+--R               (- 13148160a b c  - 6389760a b c - 678912a b )x
+--R             + 
+--R                          8 2            7 2            6 4  4
+--R               (- 5570560a c  - 14991360a b c - 2785280a b )x
+--R             + 
+--R                           8              7 3  3
+--R               (- 12943360a b c - 6594560a b )x
+--R             + 
+--R                          9            8 2  2           9              10
+--R               (- 3932160a c - 7864320a b )x  - 4587520a b x - 1048576a
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  5 5          4 2 4         3 4 3        2 6 2          8   11
+--R           (65536a c  + 112640a b c  - 99840a b c  + 3200a b c  + 2400a b c)x
+--R         + 
+--R                        5   4          4 3 3          3 5 2         2 7
+--R                 880640a b c  - 107520a b c  - 267520a b c  + 40000a b c
+--R               + 
+--R                        9
+--R                 2400a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        6 4           5 2 3           4 4 2         3 6
+--R                 983040a c  + 2365440a b c  - 1169920a b c  - 27520a b c
+--R               + 
+--R                       2 8
+--R                 39200a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                    6   3           5 3 2          4 5           3 7  8
+--R           (5836800a b c  + 1049600a b c  - 830720a b c + 173760a b )x
+--R         + 
+--R                    7 3           6 2 2          5 4           4 6  7
+--R           (3604480a c  + 9687040a b c  - 501760a b c + 323840a b )x
+--R         + 
+--R                     7   2           6 3           5 5  6
+--R           (13312000a b c  + 6246400a b c + 702976a b )x
+--R         + 
+--R                    8 2            7 2            6 4  5
+--R           (5570560a c  + 14991360a b c + 2785280a b )x
+--R         + 
+--R                     8              7 3  4            9            8 2  3
+--R           (12943360a b c + 6594560a b )x  + (3932160a c + 7864320a b )x
+--R         + 
+--R                   9   2           10
+--R           4587520a b x  + 1048576a  x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R                 5   5         4 3 4         3 5 3        2 7 2         9   12
+--R       (- 163840a b c  + 46080a b c  + 42752a b c  - 8000a b c  - 240a b c)x
+--R     + 
+--R                    6 5          5 2 4          4 4 3         3 6 2         2 8
+--R           - 327680a c  - 798720a b c  + 522240a b c  + 32256a b c  - 19840a b c
+--R         + 
+--R                   10
+--R           - 240a b
+--R      *
+--R          11
+--R         x
+--R     + 
+--R                       6   4          5 3 3          4 5 2          3 7
+--R             - 2928640a b c  - 378880a b c  + 938496a b c  - 106624a b c
+--R           + 
+--R                     2 9
+--R             - 12080a b
+--R      *
+--R          10
+--R         x
+--R     + 
+--R                       7 4           6 2 3           5 4 2          4 6
+--R             - 2293760a c  - 7086080a b c  + 1751040a b c  + 195072a b c
+--R           + 
+--R                     3 8
+--R             - 99968a b
+--R      *
+--R          9
+--R         x
+--R     + 
+--R                   7   3           6 3 2           5 5           4 7  8
+--R       (- 12144640a b c  - 5626880a b c  + 1162496a b c - 302144a b )x
+--R     + 
+--R                  8 3            7 2 2           6 4           5 6  7
+--R       (- 5963776a c  - 20275200a b c  - 2048000a b c - 536064a b )x
+--R     + 
+--R                   8   2            7 3            6 5  6
+--R       (- 21209088a b c  - 14397440a b c - 1612288a b )x
+--R     + 
+--R                  9 2            8 2            7 4  5
+--R       (- 7405568a c  - 23953408a b c - 5345280a b )x
+--R     + 
+--R                   9               8 3  4              10             9 2  3
+--R       (- 16941056a b c - 10018816a b )x  + (- 4456448a  c - 10027008a b )x
+--R     + 
+--R                 10   2           11
+--R       - 5111808a  b x  - 1048576a  x
+--R  /
+--R                     6 2          5 2           4 4  9
+--R             (327680a c  + 819200a b c + 102400a b )x
+--R           + 
+--R                      6              5 3  8            7            6 2  7
+--R             (3932160a b c + 1638400a b )x  + (3932160a c + 6881280a b )x
+--R           + 
+--R                      7   6           8 5
+--R             10485760a b x  + 5242880a x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|a \|c x  + b x + a
+--R       + 
+--R                   6   2          5 3          4 5  10
+--R         (- 819200a b c  - 409600a b c - 10240a b )x
+--R       + 
+--R                    7 2           6 2           5 4  9
+--R         (- 1638400a c  - 4096000a b c - 512000a b )x
+--R       + 
+--R                    7              6 3  8              8             7 2  7
+--R         (- 9830400a b c - 4096000a b )x  + (- 6553600a c - 11468800a b )x
+--R       + 
+--R                    8   6           9 5
+--R         - 13107200a b x  - 5242880a x
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 303
+
+--S 304 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                           5   6         4 3 5         3 5 4        2 7 3
+--R                   - 11264a b c  - 42240a b c  - 29568a b c  - 5280a b c
+--R                 + 
+--R                           9 2    11
+--R                   - 220a b c  - b  c
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                           6 6          5 2 5          4 4 4          3 6 3
+--R                   - 22528a c  - 321024a b c  - 506880a b c  - 192192a b c
+--R                 + 
+--R                           2 8 2         10     12
+--R                   - 19800a b c  - 462a b  c - b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                            6   5           5 3 4           4 5 3          3 7 2
+--R                   - 709632a b c  - 2830080a b c  - 2166912a b c  - 446688a b c
+--R                 + 
+--R                           2 9          11
+--R                   - 24420a b c - 243a b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                            7 5           6 2 4            5 4 3           4 6 2
+--R                   - 473088a c  - 6842880a b c  - 10996480a b c  - 4251456a b c
+--R                 + 
+--R                            3 8         2 10
+--R                   - 444312a b c - 9922a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             7   4            6 3 3            5 5 2
+--R                   - 7434240a b c  - 28835840a b c  - 21001728a b c
+--R                 + 
+--R                             4 7           3 9
+--R                   - 3902976a b c - 160688a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                             8 4            7 2 3            6 4 2
+--R                   - 2973696a c  - 40550400a b c  - 59304960a b c
+--R                 + 
+--R                              5 6            4 8
+--R                   - 19329024a b c - 1359072a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                                8   3            7 3 2            6 5
+--R                     - 29016064a b c  - 99348480a b c  - 58426368a b c
+--R                   + 
+--R                               5 7
+--R                     - 6845696a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                               9 3            8 2 2             7 4
+--R                     - 8290304a c  - 97591296a b c  - 111851520a b c
+--R                   + 
+--R                                6 6
+--R                     - 22038016a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                           9   2             8 3             7 5  5
+--R               (- 51904512a b c  - 136249344a b c - 47038464a b )x
+--R             + 
+--R                           10 2             9 2             8 4  4
+--R               (- 11534336a  c  - 102367232a b c - 67403776a b )x
+--R             + 
+--R                           10               9 3  3
+--R               (- 43253760a  b c - 64159744a b )x
+--R             + 
+--R                          11             10 2  2            11              12
+--R               (- 7864320a  c - 38928384a  b )x  - 13631488a  b x - 2097152a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                    6 7         5 2 6         4 4 5         3 6 4        2 8 3
+--R               2048a c  + 28160a b c  + 42240a b c  + 14784a b c  + 1320a b c
+--R             + 
+--R                    10 2
+--R               22a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                      6   6          5 3 5          4 5 4         3 7 3
+--R               126976a b c  + 506880a b c  + 388608a b c  + 80256a b c
+--R             + 
+--R                    2 9 2        11
+--R               4400a b c  + 44a b  c
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                      7 6           6 2 5           5 4 4           4 6 3
+--R               126976a c  + 1901568a b c  + 3210240a b c  + 1339008a b c
+--R             + 
+--R                      3 8 2        2 10         12
+--R               159984a b c  + 4884a b  c + 22a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                       7   5            6 3 4           5 5 3           4 7 2
+--R               2789376a b c  + 11729920a b c  + 9636352a b c  + 2192256a b c
+--R             + 
+--R                      3 9         2 11
+--R               139216a b c + 1804a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                       8 5            7 2 4            6 4 3            5 6 2
+--R               1394688a c  + 21081600a b c  + 35820800a b c  + 14900160a b c
+--R             + 
+--R                       4 8          3 10
+--R               1722600a b c + 44726a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        8   4            7 3 3            6 5 2            5 7
+--R               18259968a b c  + 74178560a b c  + 57252864a b c  + 11472384a b c
+--R             + 
+--R                      4 9
+--R               523424a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                       9 4            8 2 3             7 4 2            6 6
+--R               6086656a c  + 86351872a b c  + 132510720a b c  + 45853184a b c
+--R             + 
+--R                       5 8
+--R               3482336a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                     9   3             8 3 2             7 5             6 7  7
+--R           (52822016a b c  + 188448768a b c  + 116465664a b c + 14510080a b )x
+--R         + 
+--R                     10 3             9 2 2             8 4             7 6  6
+--R           (13205504a  c  + 161144832a b c  + 192694272a b c + 39950848a b )x
+--R         + 
+--R                     10   2             9 3             8 5  5
+--R           (76021760a  b c  + 207093760a b c + 74678272a b )x
+--R         + 
+--R                     11 2             10 2             9 4  4
+--R           (15204352a  c  + 139460608a  b c + 95387648a b )x
+--R         + 
+--R                     11               10 3  3            12             11 2  2
+--R           (53477376a  b c + 82051072a  b )x  + (8912896a  c + 45481984a  b )x
+--R         + 
+--R                    12              13
+--R           14680064a  b x + 2097152a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      6 7         5 2 6         4 4 5         3 6 4        2 8 3
+--R               - 2048a c  - 28160a b c  - 42240a b c  - 14784a b c  - 1320a b c
+--R             + 
+--R                      10 2
+--R               - 22a b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                        6   6          5 3 5          4 5 4         3 7 3
+--R               - 126976a b c  - 506880a b c  - 388608a b c  - 80256a b c
+--R             + 
+--R                      2 9 2        11
+--R               - 4400a b c  - 44a b  c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        7 6           6 2 5           5 4 4           4 6 3
+--R               - 126976a c  - 1901568a b c  - 3210240a b c  - 1339008a b c
+--R             + 
+--R                        3 8 2        2 10         12
+--R               - 159984a b c  - 4884a b  c - 22a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                         7   5            6 3 4           5 5 3           4 7 2
+--R               - 2789376a b c  - 11729920a b c  - 9636352a b c  - 2192256a b c
+--R             + 
+--R                        3 9         2 11
+--R               - 139216a b c - 1804a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                         8 5            7 2 4            6 4 3            5 6 2
+--R               - 1394688a c  - 21081600a b c  - 35820800a b c  - 14900160a b c
+--R             + 
+--R                         4 8          3 10
+--R               - 1722600a b c - 44726a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                          8   4            7 3 3            6 5 2
+--R               - 18259968a b c  - 74178560a b c  - 57252864a b c
+--R             + 
+--R                          5 7           4 9
+--R               - 11472384a b c - 523424a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         9 4            8 2 3             7 4 2            6 6
+--R               - 6086656a c  - 86351872a b c  - 132510720a b c  - 45853184a b c
+--R             + 
+--R                         5 8
+--R               - 3482336a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                            9   3             8 3 2             7 5
+--R                 - 52822016a b c  - 188448768a b c  - 116465664a b c
+--R               + 
+--R                            6 7
+--R                 - 14510080a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                       10 3             9 2 2             8 4             7 6  7
+--R           (- 13205504a  c  - 161144832a b c  - 192694272a b c - 39950848a b )x
+--R         + 
+--R                       10   2             9 3             8 5  6
+--R           (- 76021760a  b c  - 207093760a b c - 74678272a b )x
+--R         + 
+--R                       11 2             10 2             9 4  5
+--R           (- 15204352a  c  - 139460608a  b c - 95387648a b )x
+--R         + 
+--R                       11               10 3  4
+--R           (- 53477376a  b c - 82051072a  b )x
+--R         + 
+--R                      12             11 2  3            12   2           13
+--R           (- 8912896a  c - 45481984a  b )x  - 14680064a  b x  - 2097152a  x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                     5   7         4 3 6         3 5 5        2 7 4         9 3
+--R               11264a b c  + 42240a b c  + 29568a b c  + 5280a b c  + 220a b c
+--R             + 
+--R                11 2
+--R               b  c
+--R          *
+--R              16
+--R             x
+--R         + 
+--R                     6 7          5 2 6          4 4 5          3 6 4
+--R               22528a c  + 332288a b c  + 549120a b c  + 221760a b c
+--R             + 
+--R                     2 8 3         10 2     12
+--R               25080a b c  + 682a b  c  + 2b  c
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                      6   6           5 3 5           4 5 4          3 7 3
+--R               743424a b c  + 3193344a b c  + 2703360a b c  + 644160a b c
+--R             + 
+--R                     2 9 2         11     13
+--R               44440a b c  + 706a b  c + b
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                      7 6           6 2 5            5 4 4           4 6 3
+--R               495616a c  + 7873536a b c  + 14333440a b c  + 6610560a b c
+--R             + 
+--R                      3 8 2         2 10          12
+--R               910800a b c  + 34804a b  c + 244a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                       7   5            6 3 4            5 5 3           4 7 2
+--R               8616960a b c  + 38508800a b c  + 34165120a b c  + 8601120a b c
+--R             + 
+--R                      3 9          2 11
+--R               629420a b c + 10165a b
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                       8 5            7 2 4            6 4 3            5 6 2
+--R               3446784a c  + 54827520a b c  + 99137280a b c  + 44582208a b c
+--R             + 
+--R                       4 8           3 10
+--R               5706360a b c + 170610a b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        8   4             7 3 3             6 5 2
+--R               39424000a b c  + 168734720a b c  + 138733056a b c
+--R             + 
+--R                        5 7            4 9
+--R               30077696a b c + 1519760a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                        9 4             8 2 3             7 4 2            6 6
+--R               11264000a c  + 167157760a b c  + 270504960a b c  + 99793408a b c
+--R             + 
+--R                       5 8
+--R               8204768a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                     9   3             8 3 2             7 5             6 7  8
+--R           (89210880a b c  + 333189120a b c  + 217316352a b c + 28883712a b )x
+--R         + 
+--R                     10 3             9 2 2             8 4             7 6  7
+--R           (19824640a  c  + 251863040a b c  + 315504640a b c + 69076480a b )x
+--R         + 
+--R                      10   2             9 3              8 5  6
+--R           (106692608a  b c  + 302776320a b c + 114442240a b )x
+--R         + 
+--R                     11 2             10 2              9 4  5
+--R           (19398656a  c  + 184549376a  b c + 131563520a b )x
+--R         + 
+--R                     11                10 3  4            12             11 2  3
+--R           (64749568a  b c + 103088128a  b )x  + (9961472a  c + 52559872a  b )x
+--R         + 
+--R                    12   2           13
+--R           15728640a  b x  + 2097152a  x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                      6 5         5 2 4         4 4 3         3 6 2        2 8
+--R                 2048a c  + 28160a b c  + 42240a b c  + 14784a b c  + 1320a b c
+--R               + 
+--R                      10
+--R                 22a b
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                        6   4          5 3 3          4 5 2         3 7
+--R                 122880a b c  + 450560a b c  + 304128a b c  + 50688a b c
+--R               + 
+--R                      2 9
+--R                 1760a b
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                        7 4           6 2 3           5 4 2          4 6
+--R                 122880a c  + 1597440a b c  + 2196480a b c  + 658944a b c
+--R               + 
+--R                       3 8
+--R                 41184a b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                      7   3           6 3 2           5 5           4 7  13
+--R             (2293760a b c  + 7454720a b c  + 4100096a b c + 439296a b )x
+--R           + 
+--R                      8 3            7 2 2            6 4            5 6  12
+--R             (1146880a c  + 12902400a b c  + 13977600a b c + 2562560a b )x
+--R           + 
+--R                       8   2            7 3            6 5  11
+--R             (11010048a b c  + 27525120a b c + 8945664a b )x
+--R           + 
+--R                      9 2            8 2             7 4  10
+--R             (3670016a c  + 31195136a b c + 19496960a b )x
+--R           + 
+--R                       9               8 3  9            10             9 2  8
+--R             (18874368a b c + 26738688a b )x  + (4718592a  c + 22413312a b )x
+--R           + 
+--R                      10   7           11 6
+--R             10485760a  b x  + 2097152a  x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                 - 11264a b c  - 42240a b c  - 29568a b c  - 5280a b c
+--R               + 
+--R                         9     11
+--R                 - 220a b c - b
+--R            *
+--R                17
+--R               x
+--R           + 
+--R                         6 5          5 2 4          4 4 3          3 6 2
+--R                 - 22528a c  - 309760a b c  - 464640a b c  - 162624a b c
+--R               + 
+--R                         2 8          10
+--R                 - 14520a b c - 242a b
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                          6   4           5 3 3           4 5 2          3 7
+--R                 - 675840a b c  - 2478080a b c  - 1672704a b c  - 278784a b c
+--R               + 
+--R                        2 9
+--R                 - 9680a b
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                          7 4           6 2 3           5 4 2           4 6
+--R                 - 450560a c  - 5857280a b c  - 8053760a b c  - 2416128a b c
+--R               + 
+--R                          3 8
+--R                 - 151008a b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                        7   3            6 3 2            5 5            4 7  13
+--R             (- 6307840a b c  - 20500480a b c  - 11275264a b c - 1208064a b )x
+--R           + 
+--R                        8 3            7 2 2            6 4            5 6  12
+--R             (- 2523136a c  - 28385280a b c  - 30750720a b c - 5637632a b )x
+--R           + 
+--R                         8   2            7 3             6 5  11
+--R             (- 20185088a b c  - 50462720a b c - 16400384a b )x
+--R           + 
+--R                        9 2            8 2             7 4  10
+--R             (- 5767168a c  - 49020928a b c - 30638080a b )x
+--R           + 
+--R                         9               8 3  9
+--R             (- 25952256a b c - 36765696a b )x
+--R           + 
+--R                        10             9 2  8            10   7           11 6
+--R             (- 5767168a  c - 27394048a b )x  - 11534336a  b x  - 2097152a  x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 304
+
+)clear all
+
+--S 305 of 704
+t0:=x^3/sqrt(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R                   3
+--R                  x
+--R   (1)  ---------------------
+--R         +------------------+
+--R         |   4      3      2
+--R        \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 704
+r0:=1/8*(3*b^2-4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(c^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))+1/2*sqrt(a*x^2+_
+   b*x^3+c*x^4)/c-3/4*b*sqrt(a*x^2+b*x^3+c*x^4)/(c^2*x)
+--R 
+--R
+--R   (2)
+--R                       +--------------+
+--R                   2   |   2                        2c x + b
+--R       (- 4a c + 3b )x\|c x  + b x + a atanh(----------------------)
+--R                                                   +--------------+
+--R                                               +-+ |   2
+--R                                             2\|c \|c x  + b x + a
+--R     + 
+--R          2 4         3             2  2           +-+
+--R       (4c x  - 2b c x  + (4a c - 6b )x  - 6a b x)\|c
+--R  /
+--R             +------------------+
+--R       2 +-+ |   4      3      2
+--R     8c \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                      +--------------+
+--R                            3        2         2  +-+ |   2
+--R             ((16a b c - 12b )x + 32a c - 24a b )\|a \|c x  + b x + a
+--R           + 
+--R                 2 2       2      4  2         2           3        3       2 2
+--R           (- 16a c  + 8a b c + 3b )x  + (- 32a b c + 24a b )x - 32a c + 24a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                    2     2   3                 3  2         2         2    +-+
+--R           ((- 16a c  - 4b c)x  + (- 8a b c + 6b )x  + (- 32a c + 24a b )x)\|c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2 4         2     2   3                 3  2
+--R               16b c x  + (32a c  - 8b c)x  + (24a b c - 18b )x
+--R             + 
+--R                   2         2
+--R               (32a c - 24a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                                    +--------------+
+--R               2         2  +-+ +-+ |   2
+--R         (32b c x + 64a c )\|a \|c \|c x  + b x + a
+--R       + 
+--R                  3     2 2  2          2       2 2  +-+
+--R         ((- 32a c  - 8b c )x  - 64a b c x - 64a c )\|c
+--R     ,
+--R
+--R                                                        +--------------+
+--R                              3        2         2  +-+ |   2
+--R             ((- 16a b c + 12b )x - 32a c + 24a b )\|a \|c x  + b x + a
+--R           + 
+--R                 2 2       2      4  2       2           3        3       2 2
+--R             (16a c  - 8a b c - 3b )x  + (32a b c - 24a b )x + 32a c - 24a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                   2     2   3                 3  2         2         2    +---+
+--R           ((- 8a c  - 2b c)x  + (- 4a b c + 3b )x  + (- 16a c + 12a b )x)\|- c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                2 4         2     2   3                3  2       2         2
+--R           (8b c x  + (16a c  - 4b c)x  + (12a b c - 9b )x  + (16a c - 12a b )x)
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                      +--------------+
+--R               2         2  +---+ +-+ |   2
+--R         (16b c x + 32a c )\|- c \|a \|c x  + b x + a
+--R       + 
+--R                  3     2 2  2          2       2 2  +---+
+--R         ((- 16a c  - 4b c )x  - 32a b c x - 32a c )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 307
+
+--S 308 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                    +--------------+
+--R                          3        2         2  +-+ |   2
+--R           ((16a b c - 12b )x + 32a c - 24a b )\|a \|c x  + b x + a
+--R         + 
+--R                 2 2       2      4  2         2           3        3       2 2
+--R           (- 16a c  + 8a b c + 3b )x  + (- 32a b c + 24a b )x - 32a c + 24a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                     2 2       2      4  3         2           3  2
+--R               (- 16a c  + 8a b c + 3b )x  + (- 32a b c + 24a b )x
+--R             + 
+--R                     3       2 2
+--R               (- 32a c + 24a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       2      3   4       2 2       2       4  3
+--R               (16a b c  - 12b c)x  + (32a c  - 8a b c - 12b )x
+--R             + 
+--R                   2           3  2       3       2 2
+--R               (48a b c - 36a b )x  + (32a c - 24a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                      2     2   3                 3  2         2         2
+--R             ((- 16a c  - 4b c)x  + (- 8a b c + 6b )x  + (- 32a c + 24a b )x)
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                    2 4         2     2   3                 3  2
+--R               16b c x  + (32a c  - 8b c)x  + (24a b c - 18b )x
+--R             + 
+--R                   2         2
+--R               (32a c - 24a b )x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  2 5           2     2   4      3 3         2         2  2
+--R           - 16b c x  + (- 32a c  + 8b c)x  + 24b x  + (- 32a c + 72a b )x
+--R         + 
+--R              2
+--R           48a b x
+--R      *
+--R                  +--------------+
+--R          +-+ +-+ |   2
+--R         \|a \|c \|c x  + b x + a
+--R     + 
+--R                 3     2 2  6           2     3   5       2 2        2      4  4
+--R           (16a c  + 4b c )x  + (24a b c  - 2b c)x  + (48a c  - 36a b c - 6b )x
+--R         + 
+--R                2           3  3       3       2 2  2      3
+--R           (- 8a b c - 54a b )x  + (32a c - 96a b )x  - 48a b x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                    +--------------+
+--R               2         2  +-+ +-+ |   2
+--R         (32b c x + 64a c )\|a \|c \|c x  + b x + a
+--R       + 
+--R                  3     2 2  2          2       2 2  +-+
+--R         ((- 32a c  - 8b c )x  - 64a b c x - 64a c )\|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          3 4       2 2 3         4 2     6   10
+--R                   (- 128a c  - 480a b c  - 120a b c  - 2b c)x
+--R                 + 
+--R                           3   3        2 3 2         5     7  9
+--R                   (- 2752a b c  - 2480a b c  - 228a b c - b )x
+--R                 + 
+--R                           4 3         3 2 2        2 4         6  8
+--R                   (- 3200a c  - 12768a b c  - 3640a b c - 98a b )x
+--R                 + 
+--R                            4   2         3 3         2 5  7
+--R                   (- 23040a b c  - 19712a b c - 1568a b )x
+--R                 + 
+--R                            5 2         4 2         3 4  6
+--R                   (- 13312a c  - 46080a b c - 9408a b )x
+--R                 + 
+--R                            5            4 3  5            6          5 2  4
+--R                   (- 48128a b c - 26880a b )x  + (- 18432a c - 39424a b )x
+--R                 + 
+--R                           6   3        7 2
+--R                   - 28672a b x  - 8192a x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                          2   4         3 3      5 2  10
+--R                   (- 384a b c  - 320a b c  - 24b c )x
+--R                 + 
+--R                          3 4        2 2 3          4 2      6   9
+--R                   (- 896a c  - 3552a b c  - 1000a b c  - 26b c)x
+--R                 + 
+--R                           3   3        2 3 2         5   8
+--R                   (- 9600a b c  - 8512a b c  - 728a b c)x
+--R                 + 
+--R                           4 3         3 2 2        2 4   7
+--R                   (- 7168a c  - 26112a b c  - 5824a b c)x
+--R                 + 
+--R                            4   2         3 3   6            5 2         4 2   5
+--R                   (- 32768a b c  - 19968a b c)x  + (- 14336a c  - 33280a b c)x
+--R                 + 
+--R                           5     4        6   3
+--R                   - 26624a b c x  - 8192a c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2   4         3 3      5 2  11
+--R               (384a b c  + 320a b c  + 24b c )x
+--R             + 
+--R                    3 4        2 2 3          4 2      6   10
+--R               (896a c  + 3744a b c  + 1160a b c  + 38b c)x
+--R             + 
+--R                      3   3         2 3 2          5       7  9
+--R               (10496a b c  + 10848a b c  + 1312a b c + 14b )x
+--R             + 
+--R                     4 3         3 2 2         2 4          6  8
+--R               (8064a c  + 35616a b c  + 12040a b c + 462a b )x
+--R             + 
+--R                      4   2         3 3         2 5  7
+--R               (47104a b c  + 45568a b c + 4480a b )x
+--R             + 
+--R                      5 2         4 2          3 4  6
+--R               (21504a c  + 81920a b c + 19392a b )x
+--R             + 
+--R                      5            4 3  5          6          5 2  4
+--R               (69632a b c + 43520a b )x  + (22528a c + 52736a b )x
+--R             + 
+--R                     6   3        7 2
+--R               32768a b x  + 8192a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                3 5       2 2 4         4 3     6 2  11
+--R           (128a c  + 480a b c  + 120a b c  + 2b c )x
+--R         + 
+--R                 3   4        2 3 3         5 2     7   10
+--R           (2816a b c  + 2720a b c  + 288a b c  + 2b c)x
+--R         + 
+--R                 4 4         3 2 3        2 4 2         6   9
+--R           (3200a c  + 13920a b c  + 4600a b c  + 170a b c)x
+--R         + 
+--R                  4   3         3 3 2        2 5   8
+--R           (24192a b c  + 23744a b c  + 2408a b c)x
+--R         + 
+--R                  5 3         4 2 2         3 4   7
+--R           (13312a c  + 52224a b c  + 12992a b c)x
+--R         + 
+--R                  5   2         4 3   6          6 2         5 2   5
+--R           (51200a b c  + 33792a b c)x  + (18432a c  + 45568a b c)x
+--R         + 
+--R                 6     4        7   3
+--R           30720a b c x  + 8192a c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      2   4         3 3      5 2  12
+--R               (- 384a b c  - 320a b c  - 24b c )x
+--R             + 
+--R                      3 4        2 2 3          4 2      6   11
+--R               (- 896a c  - 3744a b c  - 1160a b c  - 38b c)x
+--R             + 
+--R                        3   3         2 3 2          5       7  10
+--R               (- 10496a b c  - 10848a b c  - 1312a b c - 14b )x
+--R             + 
+--R                       4 3         3 2 2         2 4          6  9
+--R               (- 8064a c  - 35616a b c  - 12040a b c - 462a b )x
+--R             + 
+--R                        4   2         3 3         2 5  8
+--R               (- 47104a b c  - 45568a b c - 4480a b )x
+--R             + 
+--R                        5 2         4 2          3 4  7
+--R               (- 21504a c  - 81920a b c - 19392a b )x
+--R             + 
+--R                        5            4 3  6            6          5 2  5
+--R               (- 69632a b c - 43520a b )x  + (- 22528a c - 52736a b )x
+--R             + 
+--R                       6   4        7 3
+--R               - 32768a b x  - 8192a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                  3 5       2 2 4         4 3     6 2  12
+--R           (- 128a c  - 480a b c  - 120a b c  - 2b c )x
+--R         + 
+--R                   3   4        2 3 3         5 2     7   11
+--R           (- 2816a b c  - 2720a b c  - 288a b c  - 2b c)x
+--R         + 
+--R                   4 4         3 2 3        2 4 2         6   10
+--R           (- 3200a c  - 13920a b c  - 4600a b c  - 170a b c)x
+--R         + 
+--R                    4   3         3 3 2        2 5   9
+--R           (- 24192a b c  - 23744a b c  - 2408a b c)x
+--R         + 
+--R                    5 3         4 2 2         3 4   8
+--R           (- 13312a c  - 52224a b c  - 12992a b c)x
+--R         + 
+--R                    5   2         4 3   7            6 2         5 2   6
+--R           (- 51200a b c  - 33792a b c)x  + (- 18432a c  - 45568a b c)x
+--R         + 
+--R                   6     5        7   4
+--R           - 30720a b c x  - 8192a c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                3 5       2 2 4         4 3     6 2  13
+--R           (128a c  + 480a b c  + 120a b c  + 2b c )x
+--R         + 
+--R                 3   4        2 3 3         5 2     7   12
+--R           (2880a b c  + 2960a b c  + 348a b c  + 3b c)x
+--R         + 
+--R                 4 4         3 2 3        2 4 2         6     8  11
+--R           (3328a c  + 16000a b c  + 6240a b c  + 328a b c + b )x
+--R         + 
+--R                  4   3         3 3 2        2 5         7  10
+--R           (28992a b c  + 34960a b c  + 5436a b c + 99a b )x
+--R         + 
+--R                  5 3         4 2 2         3 4         2 6  9
+--R           (16512a c  + 81888a b c  + 32760a b c + 1666a b )x
+--R         + 
+--R                  5   2         4 3          3 5  8
+--R           (84480a b c  + 92672a b c + 10976a b )x
+--R         + 
+--R                  6 2          5 2          4 4  7          6            5 3  6
+--R           (31744a c  + 133632a b c + 36288a b )x  + (95232a b c + 66304a b )x
+--R         + 
+--R                  7          6 2  5         7   4        8 3
+--R           (26624a c + 68096a b )x  + 36864a b x  + 8192a x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                2   5         3 4      5 3  13
+--R           (384a b c  + 320a b c  + 24b c )x
+--R         + 
+--R                3 5        2 2 4          4 3      6 2  12
+--R           (896a c  + 3936a b c  + 1320a b c  + 50b c )x
+--R         + 
+--R                  3   4         2 3 3          5 2      7   11
+--R           (10880a b c  + 12384a b c  + 1752a b c  + 26b c)x
+--R         + 
+--R                 4 4         3 2 3         2 4 2         6   10
+--R           (8064a c  + 39264a b c  + 15336a b c  + 754a b c)x
+--R         + 
+--R                  4   3         3 3 2        2 5   9
+--R           (49536a b c  + 54592a b c  + 6552a b c)x
+--R         + 
+--R                  5 3         4 2 2         3 4   8
+--R           (21504a c  + 92160a b c  + 25792a b c)x
+--R         + 
+--R                  5   2         4 3   7          6 2         5 2   6
+--R           (73728a b c  + 53248a b c)x  + (22528a c  + 59904a b c)x
+--R         + 
+--R                 6     5        7   4
+--R           34816a b c x  + 8192a c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                      2   4         3 3      5 2  9
+--R                 (384a b c  + 320a b c  + 24b c )x
+--R               + 
+--R                      3 4        2 2 3          4 2      6   8
+--R                 (896a c  + 3744a b c  + 1160a b c  + 38b c)x
+--R               + 
+--R                        3   3         2 3 2          5       7  7
+--R                 (10496a b c  + 10848a b c  + 1312a b c + 14b )x
+--R               + 
+--R                       4 3         3 2 2         2 4          6  6
+--R                 (8064a c  + 35616a b c  + 12040a b c + 462a b )x
+--R               + 
+--R                        4   2         3 3         2 5  5
+--R                 (47104a b c  + 45568a b c + 4480a b )x
+--R               + 
+--R                        5 2         4 2          3 4  4
+--R                 (21504a c  + 81920a b c + 19392a b )x
+--R               + 
+--R                        5            4 3  3          6          5 2  2
+--R                 (69632a b c + 43520a b )x  + (22528a c + 52736a b )x
+--R               + 
+--R                       6           7
+--R                 32768a b x + 8192a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                  3 5       2 2 4         4 3     6 2  9
+--R             (128a c  + 480a b c  + 120a b c  + 2b c )x
+--R           + 
+--R                   3   4        2 3 3         5 2     7   8
+--R             (2816a b c  + 2720a b c  + 288a b c  + 2b c)x
+--R           + 
+--R                   4 4         3 2 3        2 4 2         6   7
+--R             (3200a c  + 13920a b c  + 4600a b c  + 170a b c)x
+--R           + 
+--R                    4   3         3 3 2        2 5   6
+--R             (24192a b c  + 23744a b c  + 2408a b c)x
+--R           + 
+--R                    5 3         4 2 2         3 4   5
+--R             (13312a c  + 52224a b c  + 12992a b c)x
+--R           + 
+--R                    5   2         4 3   4          6 2         5 2   3
+--R             (51200a b c  + 33792a b c)x  + (18432a c  + 45568a b c)x
+--R           + 
+--R                   6     2        7
+--R             30720a b c x  + 8192a c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    3 5       2 2 4         4 3     6 2  10
+--R             (- 128a c  - 480a b c  - 120a b c  - 2b c )x
+--R           + 
+--R                     3   4        2 3 3         5 2     7   9
+--R             (- 2880a b c  - 2960a b c  - 348a b c  - 3b c)x
+--R           + 
+--R                     4 4         3 2 3        2 4 2         6     8  8
+--R             (- 3328a c  - 16000a b c  - 6240a b c  - 328a b c - b )x
+--R           + 
+--R                      4   3         3 3 2        2 5         7  7
+--R             (- 28992a b c  - 34960a b c  - 5436a b c - 99a b )x
+--R           + 
+--R                      5 3         4 2 2         3 4         2 6  6
+--R             (- 16512a c  - 81888a b c  - 32760a b c - 1666a b )x
+--R           + 
+--R                      5   2         4 3          3 5  5
+--R             (- 84480a b c  - 92672a b c - 10976a b )x
+--R           + 
+--R                      6 2          5 2          4 4  4
+--R             (- 31744a c  - 133632a b c - 36288a b )x
+--R           + 
+--R                      6            5 3  3            7          6 2  2
+--R             (- 95232a b c - 66304a b )x  + (- 26624a c - 68096a b )x
+--R           + 
+--R                     7           8
+--R             - 36864a b x - 8192a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                    2   5         3 4      5 3  10
+--R             (- 384a b c  - 320a b c  - 24b c )x
+--R           + 
+--R                    3 5        2 2 4          4 3      6 2  9
+--R             (- 896a c  - 3936a b c  - 1320a b c  - 50b c )x
+--R           + 
+--R                      3   4         2 3 3          5 2      7   8
+--R             (- 10880a b c  - 12384a b c  - 1752a b c  - 26b c)x
+--R           + 
+--R                     4 4         3 2 3         2 4 2         6   7
+--R             (- 8064a c  - 39264a b c  - 15336a b c  - 754a b c)x
+--R           + 
+--R                      4   3         3 3 2        2 5   6
+--R             (- 49536a b c  - 54592a b c  - 6552a b c)x
+--R           + 
+--R                      5 3         4 2 2         3 4   5
+--R             (- 21504a c  - 92160a b c  - 25792a b c)x
+--R           + 
+--R                      5   2         4 3   4            6 2         5 2   3
+--R             (- 73728a b c  - 53248a b c)x  + (- 22528a c  - 59904a b c)x
+--R           + 
+--R                     6     2        7
+--R             - 34816a b c x  - 8192a c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     2 2       2      4  3         2           3  2
+--R               (- 16a c  + 8a b c + 3b )x  + (- 32a b c + 24a b )x
+--R             + 
+--R                     3       2 2
+--R               (- 32a c + 24a b )x
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- c \|c x  + b x + a
+--R         + 
+--R                       2      3   4       2 2       2       4  3
+--R               (16a b c  - 12b c)x  + (32a c  - 8a b c - 12b )x
+--R             + 
+--R                   2           3  2       3       2 2
+--R               (48a b c - 36a b )x  + (32a c - 24a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                                                          +--------------+
+--R                            3        2         2  +-+ +-+ |   2
+--R           ((- 32a b c + 24b )x - 64a c + 48a b )\|a \|c \|c x  + b x + a
+--R         + 
+--R              2 2        2      4  2       2           3        3       2 2  +-+
+--R         ((32a c  - 16a b c - 6b )x  + (64a b c - 48a b )x + 64a c - 48a b )\|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                      2     2   3                 3  2         2         2
+--R             ((- 16a c  - 4b c)x  + (- 8a b c + 6b )x  + (- 32a c + 24a b )x)
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|c \|c x  + b x + a
+--R         + 
+--R                    2 4         2     2   3                 3  2
+--R               16b c x  + (32a c  - 8b c)x  + (24a b c - 18b )x
+--R             + 
+--R                   2         2
+--R               (32a c - 24a b )x
+--R          *
+--R              +---+ +-+ +-+
+--R             \|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  2 5           2     2   4      3 3         2         2  2
+--R           - 16b c x  + (- 32a c  + 8b c)x  + 24b x  + (- 32a c + 72a b )x
+--R         + 
+--R              2
+--R           48a b x
+--R      *
+--R                        +--------------+
+--R          +---+ +-+ +-+ |   2
+--R         \|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R                 3     2 2  6           2     3   5       2 2        2      4  4
+--R           (16a c  + 4b c )x  + (24a b c  - 2b c)x  + (48a c  - 36a b c - 6b )x
+--R         + 
+--R                2           3  3       3       2 2  2      3
+--R           (- 8a b c - 54a b )x  + (32a c - 96a b )x  - 48a b x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                                          +--------------+
+--R               2         2  +---+ +-+ +-+ |   2
+--R         (32b c x + 64a c )\|- c \|a \|c \|c x  + b x + a
+--R       + 
+--R                  3     2 2  2          2       2 2  +---+ +-+
+--R         ((- 32a c  - 8b c )x  - 64a b c x - 64a c )\|- c \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                             3  5         2         2  4       2   3       3 2
+--R             ((- 32a b c - 8b )x  + (- 64a c - 80a b )x  - 192a b x  - 128a x )
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               2 2        2     4  6        2           3  5
+--R           (16a c  + 24a b c + b )x  + (128a b c + 32a b )x
+--R         + 
+--R                3        2 2  4       3   3       4 2
+--R           (128a c + 160a b )x  + 256a b x  + 128a x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 2 2        2     4  7          2           3  6
+--R           (- 16a c  - 24a b c - b )x  + (- 128a b c - 32a b )x
+--R         + 
+--R                  3        2 2  5       3   4       4 3
+--R           (- 128a c - 160a b )x  - 256a b x  - 128a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   2     3   8       2 2         2      4  7
+--R           (32a b c  + 8b c)x  + (64a c  + 112a b c + 8b )x
+--R         + 
+--R                2           3  6        3        2 2  5       3   4       4 3
+--R           (288a b c + 88a b )x  + (192a c + 272a b )x  + 320a b x  + 128a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 2 2        2     4  4        2           3  3
+--R             (16a c  + 24a b c + b )x  + (128a b c + 32a b )x
+--R           + 
+--R                  3        2 2  2       3          4
+--R             (128a c + 160a b )x  + 256a b x + 128a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                       2     3   5         2 2         2      4  4
+--R             (- 32a b c  - 8b c)x  + (- 64a c  - 112a b c - 8b )x
+--R           + 
+--R                  2           3  3          3        2 2  2       3          4
+--R           (- 288a b c - 88a b )x  + (- 192a c - 272a b )x  - 320a b x - 128a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 311
+
+)clear all
+
+--S 312 of 704
+t0:=x^2/sqrt(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R                   2
+--R                  x
+--R   (1)  ---------------------
+--R         +------------------+
+--R         |   4      3      2
+--R        \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 704
+r0:=-1/2*b*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(c^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   sqrt(a*x^2+b*x^3+c*x^4)/(c*x)
+--R 
+--R
+--R   (2)
+--R             +--------------+
+--R             |   2                        2c x + b
+--R       - b x\|c x  + b x + a atanh(----------------------)
+--R                                         +--------------+
+--R                                     +-+ |   2
+--R                                   2\|c \|c x  + b x + a
+--R     + 
+--R            3       2         +-+
+--R       (2c x  + 2b x  + 2a x)\|c
+--R  /
+--R            +------------------+
+--R        +-+ |   4      3      2
+--R     2c\|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   +--------------+
+--R               +-+ |   2               2
+--R           (2b\|a \|c x  + b x + a  - b x - 2a b)
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                    +--------------+
+--R                +-+ |   2                   2         +-+ +-+
+--R         - 2b x\|c \|c x  + b x + a  + (4c x  + 2b x)\|a \|c
+--R    /
+--R                  +--------------+
+--R          +-+ +-+ |   2                                +-+
+--R       4c\|a \|c \|c x  + b x + a  + (- 2b c x - 4a c)\|c
+--R     ,
+--R
+--R                     +--------------+
+--R                 +-+ |   2               2
+--R           (- 2b\|a \|c x  + b x + a  + b x + 2a b)
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                     +--------------+
+--R               +---+ |   2                   2        +---+ +-+
+--R         - b x\|- c \|c x  + b x + a  + (2c x  + b x)\|- c \|a
+--R    /
+--R                    +--------------+
+--R          +---+ +-+ |   2                               +---+
+--R       2c\|- c \|a \|c x  + b x + a  + (- b c x - 2a c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 314
+
+--S 315 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 +--------------+               +------------------+
+--R             +-+ |   2               2          |   4      3      2
+--R         (2b\|a \|c x  + b x + a  - b x - 2a b)\|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                            +--------------+
+--R              2 2           |   2                     3     2 2           +-+
+--R         ((- b x  - 2a b x)\|c x  + b x + a  + (2b c x  + 2b x  + 2a b x)\|a )
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                     +--------------+
+--R                 +-+ |   2                   2         +-+ +-+
+--R         (- 2b x\|c \|c x  + b x + a  + (4c x  + 2b x)\|a \|c )
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                        +--------------+
+--R              3       2         +-+ +-+ |   2
+--R       (- 4c x  - 4b x  - 4a x)\|a \|c \|c x  + b x + a
+--R     + 
+--R              4             2  3         2     2   +-+
+--R       (2b c x  + (4a c + 2b )x  + 6a b x  + 4a x)\|c
+--R  /
+--R                 +--------------+                          +------------------+
+--R         +-+ +-+ |   2                                +-+  |   4      3      2
+--R     (4c\|a \|c \|c x  + b x + a  + (- 2b c x - 4a c)\|c )\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 315
+
+--S 316 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         2 3        2 2     4   7
+--R                   (- 32a c  - 48a b c  - 2b c)x
+--R                 + 
+--R                          2   2         3     5  6
+--R                   (- 336a b c  - 104a b c - b )x
+--R                 + 
+--R                          3 2       2 2         4  5           3          2 3  4
+--R                   (- 416a c  - 720a b c - 50a b )x  + (- 1472a b c - 400a b )x
+--R                 + 
+--R                          4         3 2  3        4   2       5
+--R                   (- 896a c - 1120a b )x  - 1280a b x  - 512a x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                             3      3 2  7          2 3         2 2      4   6
+--R                   (- 64a b c  - 16b c )x  + (- 160a c  - 272a b c  - 18b c)x
+--R                 + 
+--R                          2   2         3   5          3 2       2 2   4
+--R                   (- 832a b c  - 240a b c)x  + (- 640a c  - 864a b c)x
+--R                 + 
+--R                          3     3       4   2
+--R                   - 1152a b c x  - 512a c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       3      3 2  8        2 3         2 2      4   7
+--R               (64a b c  + 16b c )x  + (160a c  + 304a b c  + 26b c)x
+--R             + 
+--R                    2   2         3       5  6
+--R               (992a b c  + 416a b c + 10b )x
+--R             + 
+--R                    3 2        2 2          4  5         3          2 3  4
+--R               (800a c  + 1680a b c + 170a b )x  + (2432a b c + 832a b )x
+--R             + 
+--R                     4         3 2  3        4   2       5
+--R               (1152a c + 1696a b )x  + 1536a b x  + 512a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R               2 4        2 3     4 2  8        2   3         3 2     5   7
+--R           (32a c  + 48a b c  + 2b c )x  + (352a b c  + 128a b c  + 2b c)x
+--R         + 
+--R                3 3       2 2 2        4   6         3   2       2 3   5
+--R           (416a c  + 848a b c  + 82a b c)x  + (1600a b c  + 560a b c)x
+--R         + 
+--R                4 2        3 2   4        4     3       5   2
+--R           (896a c  + 1376a b c)x  + 1408a b c x  + 512a c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                         3      3 2  9          2 3         2 2      4   8
+--R               (- 64a b c  - 16b c )x  + (- 160a c  - 304a b c  - 26b c)x
+--R             + 
+--R                      2   2         3       5  7
+--R               (- 992a b c  - 416a b c - 10b )x
+--R             + 
+--R                      3 2        2 2          4  6           3          2 3  5
+--R               (- 800a c  - 1680a b c - 170a b )x  + (- 2432a b c - 832a b )x
+--R             + 
+--R                       4         3 2  4        4   3       5 2
+--R               (- 1152a c - 1696a b )x  - 1536a b x  - 512a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                 2 4        2 3     4 2  9          2   3         3 2     5   8
+--R           (- 32a c  - 48a b c  - 2b c )x  + (- 352a b c  - 128a b c  - 2b c)x
+--R         + 
+--R                  3 3       2 2 2        4   7           3   2       2 3   6
+--R           (- 416a c  - 848a b c  - 82a b c)x  + (- 1600a b c  - 560a b c)x
+--R         + 
+--R                  4 2        3 2   5        4     4       5   3
+--R           (- 896a c  - 1376a b c)x  - 1408a b c x  - 512a c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R               2 4        2 3     4 2  10        2   3         3 2     5   9
+--R           (32a c  + 48a b c  + 2b c )x   + (368a b c  + 152a b c  + 3b c)x
+--R         + 
+--R                3 3        2 2 2         4     6  8
+--R           (448a c  + 1104a b c  + 156a b c + b )x
+--R         + 
+--R                 3   2        2 3         5  7
+--R           (2224a b c  + 1224a b c + 51a b )x
+--R         + 
+--R                 4 2        3 2        2 4  6         4           3 3  5
+--R           (1312a c  + 3312a b c + 450a b )x  + (3648a b c + 1520a b )x
+--R         + 
+--R                 5         4 2  4        5   3       6 2
+--R           (1408a c + 2400a b )x  + 1792a b x  + 512a x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                   4      3 3  10        2 4         2 3      4 2  9
+--R           (64a b c  + 16b c )x   + (160a c  + 336a b c  + 34b c )x
+--R         + 
+--R                 2   3         3 2      5   8
+--R           (1056a b c  + 528a b c  + 18b c)x
+--R         + 
+--R                3 3        2 2 2         4   7         3   2        2 3   6
+--R           (800a c  + 1968a b c  + 258a b c)x  + (2624a b c  + 1104a b c)x
+--R         + 
+--R                 4 2        3 2   5        4     4       5   3
+--R           (1152a c  + 2016a b c)x  + 1664a b c x  + 512a c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                         3      3 2  7        2 3         2 2      4   6
+--R                 (64a b c  + 16b c )x  + (160a c  + 304a b c  + 26b c)x
+--R               + 
+--R                      2   2         3       5  5
+--R                 (992a b c  + 416a b c + 10b )x
+--R               + 
+--R                      3 2        2 2          4  4         3          2 3  3
+--R                 (800a c  + 1680a b c + 170a b )x  + (2432a b c + 832a b )x
+--R               + 
+--R                       4         3 2  2        4          5
+--R                 (1152a c + 1696a b )x  + 1536a b x + 512a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                 2 4        2 3     4 2  7        2   3         3 2     5   6
+--R             (32a c  + 48a b c  + 2b c )x  + (352a b c  + 128a b c  + 2b c)x
+--R           + 
+--R                  3 3       2 2 2        4   5         3   2       2 3   4
+--R             (416a c  + 848a b c  + 82a b c)x  + (1600a b c  + 560a b c)x
+--R           + 
+--R                  4 2        3 2   3        4     2       5
+--R             (896a c  + 1376a b c)x  + 1408a b c x  + 512a c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   2 4        2 3     4 2  8
+--R             (- 32a c  - 48a b c  - 2b c )x
+--R           + 
+--R                    2   3         3 2     5   7
+--R             (- 368a b c  - 152a b c  - 3b c)x
+--R           + 
+--R                    3 3        2 2 2         4     6  6
+--R             (- 448a c  - 1104a b c  - 156a b c - b )x
+--R           + 
+--R                     3   2        2 3         5  5
+--R             (- 2224a b c  - 1224a b c - 51a b )x
+--R           + 
+--R                     4 2        3 2        2 4  4           4           3 3  3
+--R             (- 1312a c  - 3312a b c - 450a b )x  + (- 3648a b c - 1520a b )x
+--R           + 
+--R                     5         4 2  2        5          6
+--R             (- 1408a c - 2400a b )x  - 1792a b x - 512a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                       4      3 3  8          2 4         2 3      4 2  7
+--R             (- 64a b c  - 16b c )x  + (- 160a c  - 336a b c  - 34b c )x
+--R           + 
+--R                     2   3         3 2      5   6
+--R             (- 1056a b c  - 528a b c  - 18b c)x
+--R           + 
+--R                    3 3        2 2 2         4   5
+--R             (- 800a c  - 1968a b c  - 258a b c)x
+--R           + 
+--R                     3   2        2 3   4           4 2        3 2   3
+--R             (- 2624a b c  - 1104a b c)x  + (- 1152a c  - 2016a b c)x
+--R           + 
+--R                    4     2       5
+--R             - 1664a b c x  - 512a c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                   +--------------+
+--R               2 2           +---+ |   2
+--R           (- b x  - 2a b x)\|- c \|c x  + b x + a
+--R         + 
+--R                  3     2 2           +---+ +-+
+--R           (2b c x  + 2b x  + 2a b x)\|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                       +--------------+
+--R               +-+ +-+ |   2                 2          +-+
+--R         (- 4b\|a \|c \|c x  + b x + a  + (2b x + 4a b)\|c )
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                           +--------------+
+--R                 +---+ +-+ |   2                   2         +---+ +-+ +-+
+--R         (- 2b x\|- c \|c \|c x  + b x + a  + (4c x  + 2b x)\|- c \|a \|c )
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                              +--------------+
+--R              3       2         +---+ +-+ +-+ |   2
+--R       (- 4c x  - 4b x  - 4a x)\|- c \|a \|c \|c x  + b x + a
+--R     + 
+--R              4             2  3         2     2   +---+ +-+
+--R       (2b c x  + (4a c + 2b )x  + 6a b x  + 4a x)\|- c \|c
+--R  /
+--R                         +--------------+
+--R           +---+ +-+ +-+ |   2                                +---+ +-+
+--R       (4c\|- c \|a \|c \|c x  + b x + a  + (- 2b c x - 4a c)\|- c \|c )
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                  +--------------+
+--R                    2         +-+ |   2                       2  3         2
+--R             (- 4b x  - 8a x)\|a \|c x  + b x + a  + (4a c + b )x  + 8a b x
+--R           + 
+--R               2
+--R             8a x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                           +--------------+
+--R                   2  4         3     2 2  |   2
+--R       ((- 4a c - b )x  - 8a b x  - 8a x )\|c x  + b x + a
+--R     + 
+--R              5             2  4          3     2 2  +-+
+--R       (4b c x  + (8a c + 4b )x  + 12a b x  + 8a x )\|a
+--R  /
+--R                                        +--------------+
+--R                   2  2              2  |   2
+--R         ((4a c + b )x  + 8a b x + 8a )\|c x  + b x + a
+--R       + 
+--R                  3               2  2               2  +-+
+--R         (- 4b c x  + (- 8a c - 4b )x  - 12a b x - 8a )\|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 704
+t0:=x/sqrt(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R                  x
+--R   (1)  ---------------------
+--R         +------------------+
+--R         |   4      3      2
+--R        \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 704
+r0:=x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (sqrt(c)*sqrt(a*x^2+b*x^3+c*x^4))
+--R 
+--R
+--R          +--------------+
+--R          |   2                        2c x + b
+--R        x\|c x  + b x + a atanh(----------------------)
+--R                                      +--------------+
+--R                                  +-+ |   2
+--R                                2\|c \|c x  + b x + a
+--R   (2)  -----------------------------------------------
+--R                        +------------------+
+--R                    +-+ |   4      3      2
+--R                   \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                 +--------------+
+--R                 +-+ +-+         |   2                     2             +-+
+--R              (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R            + 
+--R                   +-+
+--R              2c x\|a
+--R         /
+--R                  +--------------+
+--R              +-+ |   2
+--R            2\|a \|c x  + b x + a  - b x - 2a
+--R    /
+--R        +-+
+--R       \|c
+--R     ,
+--R                 +--------------+
+--R           +---+ |   2               +---+ +-+
+--R          \|- c \|c x  + b x + a  - \|- c \|a
+--R    2atan(------------------------------------)
+--R                           c x
+--R    -------------------------------------------]
+--R                        +---+
+--R                       \|- c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 321
+
+--S 322 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R           +--------------+
+--R           |   2                        2c x + b
+--R       - x\|c x  + b x + a atanh(----------------------)
+--R                                       +--------------+
+--R                                   +-+ |   2
+--R                                 2\|c \|c x  + b x + a
+--R  /
+--R          +------------------+
+--R      +-+ |   4      3      2
+--R     \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          2     2   4                 3  3
+--R                   (- 8a c  - 2b c)x  + (- 28a b c - b )x
+--R                 + 
+--R                         2         2  2      2         3
+--R                   (- 40a c - 18a b )x  - 48a b x - 32a
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                    2 4         2      2   3            2      2     +-+
+--R               (8b c x  + (24a c  + 10b c)x  + 40a b c x  + 32a c x)\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   2 5         2      2   4                3  3
+--R               8b c x  + (24a c  + 14b c)x  + (64a b c + 6b )x
+--R             + 
+--R                   2         2  2      2         3
+--R               (56a c + 38a b )x  + 64a b x + 32a
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                  3     2 2  5             2     3   4         2 2        2   3
+--R           (- 8a c  - 2b c )x  + (- 32a b c  - 2b c)x  + (- 40a c  - 26a b c)x
+--R         + 
+--R                2     2      3
+--R           - 56a b c x  - 32a c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                     2 6           2      2   5                  3  4
+--R               - 8b c x  + (- 24a c  - 14b c)x  + (- 64a b c - 6b )x
+--R             + 
+--R                     2         2  3      2   2      3
+--R               (- 56a c - 38a b )x  - 64a b x  - 32a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                3     2 2  6           2     3   5       2 2        2   4
+--R           (8a c  + 2b c )x  + (32a b c  + 2b c)x  + (40a c  + 26a b c)x
+--R         + 
+--R              2     3      3   2
+--R           56a b c x  + 32a c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                3     2 2  7           2     3   6       2 2        2     4  5
+--R           (8a c  + 2b c )x  + (36a b c  + 3b c)x  + (48a c  + 48a b c + b )x
+--R         + 
+--R                2           3  4       3       2 2  3      3   2      4
+--R           (116a b c + 19a b )x  + (72a c + 66a b )x  + 80a b x  + 32a x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                 3 7           3      2 2  6             2      3   5
+--R           - 8b c x  + (- 24a c  - 18b c )x  + (- 72a b c  - 10b c)x
+--R         + 
+--R                 2 2        2   4      2     3      3   2
+--R           (- 56a c  - 50a b c)x  - 72a b c x  - 32a c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                     2 5         2      2   4                3  3
+--R                 8b c x  + (24a c  + 14b c)x  + (64a b c + 6b )x
+--R               + 
+--R                     2         2  2      2         3
+--R                 (56a c + 38a b )x  + 64a b x + 32a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                    3     2 2  5             2     3   4
+--R             (- 8a c  - 2b c )x  + (- 32a b c  - 2b c)x
+--R           + 
+--R                   2 2        2   3      2     2      3
+--R             (- 40a c  - 26a b c)x  - 56a b c x  - 32a c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    3     2 2  6             2     3   5
+--R             (- 8a c  - 2b c )x  + (- 36a b c  - 3b c)x
+--R           + 
+--R                   2 2        2     4  4          2           3  3
+--R             (- 48a c  - 48a b c - b )x  + (- 116a b c - 19a b )x
+--R           + 
+--R                   3       2 2  2      3         4
+--R             (- 72a c - 66a b )x  - 80a b x - 32a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                 3 6         3      2 2  5           2      3   4
+--R             8b c x  + (24a c  + 18b c )x  + (72a b c  + 10b c)x
+--R           + 
+--R                 2 2        2   3      2     2      3
+--R             (56a c  + 50a b c)x  + 72a b c x  + 32a c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 +--------------+
+--R           +---+ |   2                        2c x + b
+--R       - x\|- c \|c x  + b x + a atanh(----------------------)
+--R                                             +--------------+
+--R                                         +-+ |   2
+--R                                       2\|c \|c x  + b x + a
+--R     + 
+--R                                             +--------------+
+--R             +------------------+      +---+ |   2               +---+ +-+
+--R         +-+ |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R       2\|c \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                       c x
+--R  /
+--R                +------------------+
+--R      +---+ +-+ |   4      3      2
+--R     \|- c \|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R         +------------------+     +--------------+
+--R         |   4      3      2      |   2
+--R        \|c x  + b x  + a x   - x\|c x  + b x + a
+--R   (7)  ------------------------------------------
+--R           +--------------+ +------------------+
+--R           |   2            |   4      3      2
+--R          \|c x  + b x + a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 325
+
+)clear all
+
+--S 326 of 704
+t0:=1/sqrt(a*x^2+b*x^3+c*x^4)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         +------------------+
+--R         |   4      3      2
+--R        \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 704
+r0:=-x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (sqrt(a)*sqrt(a*x^2+b*x^3+c*x^4))
+--R 
+--R
+--R            +--------------+
+--R            |   2                        b x + 2a
+--R          x\|c x  + b x + a atanh(----------------------)
+--R                                        +--------------+
+--R                                    +-+ |   2
+--R                                  2\|a \|c x  + b x + a
+--R   (2)  - -----------------------------------------------
+--R                          +------------------+
+--R                      +-+ |   4      3      2
+--R                     \|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +--------------+
+--R              +-+ |   2
+--R            2\|a \|c x  + b x + a  - b x - 2a
+--R        log(---------------------------------)
+--R                            x
+--R   (3)  --------------------------------------
+--R                          +-+
+--R                         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 328
+
+--S 329 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +--------------+
+--R        +------------------+      +-+ |   2
+--R        |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R       \|c x  + b x  + a x  log(---------------------------------)
+--R                                                x
+--R     + 
+--R         +--------------+
+--R         |   2                        b x + 2a
+--R       x\|c x  + b x + a atanh(----------------------)
+--R                                     +--------------+
+--R                                 +-+ |   2
+--R                               2\|a \|c x  + b x + a
+--R  /
+--R          +------------------+
+--R      +-+ |   4      3      2
+--R     \|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       +--------------+
+--R                       |   2                   2              +-+
+--R         ((- b x - 2a)\|c x  + b x + a  + (2c x  + 2b x + 2a)\|a )
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                    +--------------+
+--R              3       2         +-+ |   2                   4            2  3
+--R       (- 2c x  - 2b x  - 2a x)\|a \|c x  + b x + a  + b c x  + (2a c + b )x
+--R     + 
+--R             2     2
+--R       3a b x  + 2a x
+--R  /
+--R                                    +--------------+
+--R              3       2         +-+ |   2                   4              2  3
+--R         (2c x  + 2b x  + 2a x)\|a \|c x  + b x + a  - b c x  + (- 2a c - b )x
+--R       + 
+--R                 2     2
+--R         - 3a b x  - 2a x
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 704
+t0:=1/(x*sqrt(a*x^2+b*x^3+c*x^4))
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R          +------------------+
+--R          |   4      3      2
+--R        x\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 704
+r0:=1/2*b*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))-_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a*x^2)
+--R 
+--R
+--R   (2)
+--R       +--------------+
+--R       |   2                        b x + 2a                  2              +-+
+--R   b x\|c x  + b x + a atanh(----------------------) + (- 2c x  - 2b x - 2a)\|a
+--R                                   +--------------+
+--R                               +-+ |   2
+--R                             2\|a \|c x  + b x + a
+--R   -----------------------------------------------------------------------------
+--R                                   +------------------+
+--R                               +-+ |   4      3      2
+--R                            2a\|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +--------------+
+--R                 +-+ |   2                2 2
+--R         (- 4b x\|a \|c x  + b x + a  + 2b x  + 4a b x)
+--R      *
+--R                +--------------+
+--R                |   2                           +-+
+--R             2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         log(--------------------------------------)
+--R                              2a x
+--R     + 
+--R                       +--------------+
+--R                   +-+ |   2                         2  2              2
+--R       (2b x + 8a)\|a \|c x  + b x + a  + (- 8a c + b )x  - 6a b x - 8a
+--R  /
+--R          +--------------+
+--R       2  |   2                       2     2   +-+
+--R     8a x\|c x  + b x + a  + (- 4a b x  - 8a x)\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 333
+
+--S 334 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +--------------+                         +------------------+
+--R                   |   2                 2 2           +-+  |   4      3      2
+--R         (- 4a b x\|c x  + b x + a  + (2b x  + 4a b x)\|a )\|c x  + b x  + a x
+--R      *
+--R                +--------------+
+--R                |   2                           +-+
+--R             2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         log(--------------------------------------)
+--R                              2a x
+--R     + 
+--R                                   +--------------+
+--R                2 3         2  +-+ |   2                      4       2 3
+--R             (2b x  + 4a b x )\|a \|c x  + b x + a  - 4a b c x  - 4a b x
+--R           + 
+--R                 2   2
+--R             - 4a b x
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                            +--------------+
+--R                         2  |   2
+--R             (2a b x + 8a )\|c x  + b x + a
+--R           + 
+--R                         2  2              2  +-+
+--R             ((- 8a c + b )x  - 6a b x - 8a )\|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                      +--------------+
+--R              3         2     2   +-+ |   2                      4
+--R       (8a c x  + 8a b x  + 8a x)\|a \|c x  + b x + a  - 4a b c x
+--R     + 
+--R            2        2  3      2   2     3
+--R       (- 8a c - 4a b )x  - 12a b x  - 8a x
+--R  /
+--R               +--------------+                   +------------------+
+--R        2  +-+ |   2                2   2     3   |   4      3      2
+--R     (8a x\|a \|c x  + b x + a  - 4a b x  - 8a x)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                            3  3         2         2  2      2         3  +-+
+--R             ((- 12a b c - b )x  + (- 24a c - 18a b )x  - 48a b x - 32a )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R              2 2       2   4       2          3  3       3       2 2  2
+--R           (8a c  + 6a b c)x  + (40a b c + 6a b )x  + (40a c + 38a b )x
+--R         + 
+--R              3         4
+--R           64a b x + 32a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                2 2       2   5         2          3  4         3       2 2  3
+--R           (- 8a c  - 6a b c)x  + (- 40a b c - 6a b )x  + (- 40a c - 38a b )x
+--R         + 
+--R                3   2      4
+--R           - 64a b x  - 32a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   2    3   6       2 2        2     4  5       2           3  4
+--R           (12a b c  + b c)x  + (24a c  + 30a b c + b )x  + (84a b c + 19a b )x
+--R         + 
+--R               3       2 2  3      3   2      4
+--R           (56a c + 66a b )x  + 80a b x  + 32a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                2 2       2   6       2          3  5       3       2 2  4
+--R             (8a c  + 6a b c)x  + (40a b c + 6a b )x  + (40a c + 38a b )x
+--R           + 
+--R                3   3      4 2
+--R             64a b x  + 32a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                       2    3   7         2 2        2     4  6
+--R             (- 12a b c  - b c)x  + (- 24a c  - 30a b c - b )x
+--R           + 
+--R                   2           3  5         3       2 2  4      3   3      4 2
+--R             (- 84a b c - 19a b )x  + (- 56a c - 66a b )x  - 80a b x  - 32a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 335
+
+)clear all
+
+--S 336 of 704
+t0:=1/(x^2*sqrt(a*x^2+b*x^3+c*x^4))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R           +------------------+
+--R         2 |   4      3      2
+--R        x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 704
+r0:=-1/8*(3*b^2-4*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))-_
+   1/2*sqrt(a*x^2+b*x^3+c*x^4)/(a*x^3)+3/4*b*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*x^2)
+--R 
+--R
+--R   (2)
+--R                      +--------------+
+--R                 2  2 |   2                        b x + 2a
+--R       (4a c - 3b )x \|c x  + b x + a atanh(----------------------)
+--R                                                  +--------------+
+--R                                              +-+ |   2
+--R                                            2\|a \|c x  + b x + a
+--R     + 
+--R              3               2  2              2  +-+
+--R       (6b c x  + (- 4a c + 6b )x  + 2a b x - 4a )\|a
+--R  /
+--R              +------------------+
+--R       2  +-+ |   4      3      2
+--R     8a x\|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                            +--------------+
+--R                  2           3  3          3       2 2  2  |   2
+--R           ((- 64a b c + 48a b )x  + (- 128a c + 96a b )x )\|c x  + b x + a
+--R         + 
+--R                   2 2        2       4  4        2           3  3
+--R               (64a c  - 32a b c - 12b )x  + (128a b c - 96a b )x
+--R             + 
+--R                    3       2 2  2
+--R               (128a c - 96a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +--------------+
+--R               +-+ |   2
+--R             2\|a \|c x  + b x + a  - b x - 2a
+--R         log(---------------------------------)
+--R                              +-+
+--R                           2x\|a
+--R     + 
+--R                2          3  3       3        2 2  2      3          4
+--R         ((- 96a b c + 4a b )x  + (64a c - 120a b )x  - 64a b x + 128a )
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 2      4  4        2           3  3          3        2 2  2
+--R           (68a b c - 7b )x  + (128a b c + 40a b )x  + (- 128a c + 168a b )x
+--R         + 
+--R                 4
+--R           - 128a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                 +--------------+
+--R            3   3       4 2  +-+ |   2                     4       3 2  4
+--R       (128a b x  + 256a x )\|a \|c x  + b x + a  + (- 128a c - 32a b )x
+--R     + 
+--R             4   3       5 2
+--R       - 256a b x  - 256a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 338
+
+--S 339 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                              +--------------+
+--R                            3  3          2         2  2  +-+ |   2
+--R           ((- 64a b c + 48b )x  + (- 128a c + 96a b )x )\|a \|c x  + b x + a
+--R         + 
+--R               2 2        2       4  4        2           3  3
+--R           (64a c  - 32a b c - 12b )x  + (128a b c - 96a b )x
+--R         + 
+--R                3       2 2  2
+--R           (128a c - 96a b )x
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                   2 2        2       4  5        2           3  4
+--R               (64a c  - 32a b c - 12b )x  + (128a b c - 96a b )x
+--R             + 
+--R                    3       2 2  3
+--R               (128a c - 96a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                         2      3   6          2 2        2       4  5
+--R               (- 64a b c  + 48b c)x  + (- 128a c  + 32a b c + 48b )x
+--R             + 
+--R                      2            3  4          3       2 2  3
+--R               (- 192a b c + 144a b )x  + (- 128a c + 96a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                             3  3       2          2  2      2          3  +-+
+--R             ((- 96a b c + 4b )x  + (64a c - 120a b )x  - 64a b x + 128a )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                 2      4  4        2           3  3          3        2 2  2
+--R           (68a b c - 7b )x  + (128a b c + 40a b )x  + (- 128a c + 168a b )x
+--R         + 
+--R                 4
+--R           - 128a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                    2   5          2           3  4        3        2 2  3
+--R             - 96a b c x  + (- 128a b c - 96a b )x  + (128a c - 224a b )x
+--R           + 
+--R                 4
+--R             128a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   2      3   6         2 2         2       4  5
+--R           (96a b c  + 24b c)x  + (- 64a c  + 272a b c + 24b )x
+--R         + 
+--R               2            3  4          3        2 2  3      3   2       4
+--R           (96a b c + 200a b )x  + (- 192a c + 240a b )x  - 64a b x  - 128a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                               +--------------+
+--R              3   3       4 2  |   2
+--R         (128a b x  + 256a x )\|c x  + b x + a
+--R       + 
+--R                 3       2 2  4       3   3       4 2  +-+
+--R         ((- 128a c - 32a b )x  - 256a b x  - 256a x )\|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                             3  3         2         2  2       2          3  +-+
+--R             ((- 32a b c - 8b )x  + (- 64a c - 80a b )x  - 192a b x - 128a )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R               2 2        2     4  4        2           3  3
+--R           (16a c  + 24a b c + b )x  + (128a b c + 32a b )x
+--R         + 
+--R                3        2 2  2       3          4
+--R           (128a c + 160a b )x  + 256a b x + 128a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 2 2        2     4  5          2           3  4
+--R           (- 16a c  - 24a b c - b )x  + (- 128a b c - 32a b )x
+--R         + 
+--R                  3        2 2  3       3   2       4
+--R           (- 128a c - 160a b )x  - 256a b x  - 128a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   2     3   6       2 2         2      4  5
+--R           (32a b c  + 8b c)x  + (64a c  + 112a b c + 8b )x
+--R         + 
+--R                2           3  4        3        2 2  3       3   2       4
+--R           (288a b c + 88a b )x  + (192a c + 272a b )x  + 320a b x  + 128a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 2 2        2     4  7        2           3  6
+--R             (16a c  + 24a b c + b )x  + (128a b c + 32a b )x
+--R           + 
+--R                  3        2 2  5       3   4       4 3
+--R             (128a c + 160a b )x  + 256a b x  + 128a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                       2     3   8         2 2         2      4  7
+--R             (- 32a b c  - 8b c)x  + (- 64a c  - 112a b c - 8b )x
+--R           + 
+--R                    2           3  6          3        2 2  5       3   4
+--R             (- 288a b c - 88a b )x  + (- 192a c - 272a b )x  - 320a b x
+--R           + 
+--R                   4 3
+--R             - 128a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 340
+
+)clear all
+
+--S 341 of 704
+t0:=x^7/(a*x^2+b*x^3+c*x^4)^(3/2)
+--R 
+--R
+--R                           5
+--R                          x
+--R   (1)  -------------------------------------
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 704
+r0:=2*x^4*(2*a+b*x)/((b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))+3/8*(5*b^2-4*a*c)*_
+   x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (c^(7/2)*sqrt(a*x^2+b*x^3+c*x^4))+1/2*(5*b^2-12*a*c)*sqrt(a*x^2+_
+   b*x^3+c*x^4)/(c^2*(b^2-4*a*c))-1/4*b*(15*b^2-52*a*c)*sqrt(a*x^2+_
+   b*x^3+c*x^4)/(c^3*(b^2-4*a*c)*x)-2*b*x*sqrt(a*x^2+b*x^3+c*x^4)/_
+   (c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                      +--------------+
+--R               2 2        2       4   |   2
+--R         (- 48a c  + 72a b c - 15b )x\|c x  + b x + a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                 3     2 2  4             2      3   3
+--R           (16a c  - 4b c )x  + (- 40a b c  + 10b c)x
+--R         + 
+--R               2 2         2       4  2          2           3
+--R           (48a c  - 124a b c + 30b )x  + (- 104a b c + 30a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                          +------------------+
+--R           4     2 3  +-+ |   4      3      2
+--R     (32a c  - 8b c )\|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      2   2         3       5  3
+--R                 (144a b c  - 168a b c - 15b )x
+--R               + 
+--R                      3 2       2 2          4  2        3          2 3
+--R                 (288a c  - 144a b c - 270a b )x  + (576a b c - 720a b )x
+--R               + 
+--R                     4        3 2
+--R                 384a c - 480a b
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                       2 3        2 2      4   4
+--R                 (- 96a c  + 48a b c  + 90b c)x
+--R               + 
+--R                        2   2         3       5  3
+--R                 (- 480a b c  + 528a b c + 90b )x
+--R               + 
+--R                        3 2       2 2          4  2          3          2 3
+--R                 (- 480a c  + 144a b c + 570a b )x  + (- 768a b c + 960a b )x
+--R               + 
+--R                       4        3 2
+--R                 - 384a c + 480a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                     3      2 2  5             2      3   4
+--R             (- 32a c  - 24b c )x  + (- 48a b c  + 60b c)x
+--R           + 
+--R                    2 2         2        4  3          2            3  2
+--R             (- 224a c  + 160a b c + 150b )x  + (- 480a b c + 600a b )x
+--R           + 
+--R                    3        2 2
+--R             (- 384a c + 480a b )x
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|c \|c x  + b x + a
+--R       + 
+--R                     3     3 2  6       2 3        2 2      4   5
+--R             (48a b c  + 4b c )x  + (96a c  - 48a b c  - 10b c)x
+--R           + 
+--R                  2   2         3       5  4        3 2       2 2          4  3
+--R             (304a b c  - 356a b c - 30b )x  + (416a c  - 208a b c - 390a b )x
+--R           + 
+--R                  3          2 3  2        4        3 2
+--R             (672a b c - 840a b )x  + (384a c - 480a b )x
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R                       4     3 3  3        2 4         2 3  2       2   3
+--R               (96a b c  + 8b c )x  + (192a c  + 144a b c )x  + 384a b c x
+--R             + 
+--R                   3 3
+--R               256a c
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                     5      2 4  4              4      3 3  3
+--R             (- 64a c  - 48b c )x  + (- 320a b c  - 48b c )x
+--R           + 
+--R                    2 4         2 3  2       2   3        3 3
+--R             (- 320a c  - 304a b c )x  - 512a b c x - 256a c
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R     ,
+--R
+--R                        2   2         3       5  3
+--R                 (- 144a b c  + 168a b c + 15b )x
+--R               + 
+--R                        3 2       2 2          4  2          3          2 3
+--R                 (- 288a c  + 144a b c + 270a b )x  + (- 576a b c + 720a b )x
+--R               + 
+--R                       4        3 2
+--R                 - 384a c + 480a b
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                     2 3        2 2      4   4        2   2         3       5  3
+--R                 (96a c  - 48a b c  - 90b c)x  + (480a b c  - 528a b c - 90b )x
+--R               + 
+--R                      3 2       2 2          4  2        3          2 3
+--R                 (480a c  - 144a b c - 570a b )x  + (768a b c - 960a b )x
+--R               + 
+--R                     4        3 2
+--R                 384a c - 480a b
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                     3      2 2  5             2      3   4
+--R             (- 16a c  - 12b c )x  + (- 24a b c  + 30b c)x
+--R           + 
+--R                    2 2        2       4  3          2            3  2
+--R             (- 112a c  + 80a b c + 75b )x  + (- 240a b c + 300a b )x
+--R           + 
+--R                    3        2 2
+--R             (- 192a c + 240a b )x
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|a \|c x  + b x + a
+--R       + 
+--R                     3     3 2  6       2 3        2 2     4   5
+--R             (24a b c  + 2b c )x  + (48a c  - 24a b c  - 5b c)x
+--R           + 
+--R                  2   2         3       5  4        3 2       2 2          4  3
+--R             (152a b c  - 178a b c - 15b )x  + (208a c  - 104a b c - 195a b )x
+--R           + 
+--R                  3          2 3  2        4        3 2
+--R             (336a b c - 420a b )x  + (192a c - 240a b )x
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R                    4     3 3  3       2 4        2 3  2       2   3        3 3
+--R           ((48a b c  + 4b c )x  + (96a c  + 72a b c )x  + 192a b c x + 128a c )
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- c \|c x  + b x + a
+--R       + 
+--R                     5      2 4  4              4      3 3  3
+--R             (- 32a c  - 24b c )x  + (- 160a b c  - 24b c )x
+--R           + 
+--R                    2 4         2 3  2       2   3        3 3
+--R             (- 160a c  - 152a b c )x  - 256a b c x - 128a c
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 343
+
+--S 344 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3   3       2 3 2         5       7  3
+--R               (576a b c  - 816a b c  + 108a b c + 15b )x
+--R             + 
+--R                     4 3       3 2 2       2 4          6  2
+--R               (1152a c  - 864a b c  - 936a b c + 270a b )x
+--R             + 
+--R                     4   2        3 3        2 5          5 2        4 2
+--R               (2304a b c  - 3456a b c + 720a b )x + 1536a c  - 2304a b c
+--R             + 
+--R                   3 4
+--R               480a b
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      3 4       2 2 3         4 2      6   4
+--R               (- 384a c  + 288a b c  + 312a b c  - 90b c)x
+--R             + 
+--R                       3   3        2 3 2         5       7  3
+--R               (- 1920a b c  + 2592a b c  - 168a b c - 90b )x
+--R             + 
+--R                       4 3        3 2 2        2 4          6  2
+--R               (- 1920a c  + 1056a b c  + 2136a b c - 570a b )x
+--R             + 
+--R                       4   2        3 3        2 5          5 2        4 2
+--R               (- 3072a b c  + 4608a b c - 960a b )x - 1536a c  + 2304a b c
+--R             + 
+--R                     3 4
+--R               - 480a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                      3 4       2 2 3         4 2      6   5
+--R               (- 384a c  + 288a b c  + 312a b c  - 90b c)x
+--R             + 
+--R                       3   3        2 3 2         5       7  4
+--R               (- 1920a b c  + 2592a b c  - 168a b c - 90b )x
+--R             + 
+--R                       4 3        3 2 2        2 4          6  3
+--R               (- 1920a c  + 1056a b c  + 2136a b c - 570a b )x
+--R             + 
+--R                       4   2        3 3        2 5  2
+--R               (- 3072a b c  + 4608a b c - 960a b )x
+--R             + 
+--R                       5 2        4 2        3 4
+--R               (- 1536a c  + 2304a b c - 480a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                3   4       2 3 3         5 2      7   6
+--R           (576a b c  - 816a b c  + 108a b c  + 15b c)x
+--R         + 
+--R                 4 4       3 2 3        2 4 2         6       8  5
+--R           (1152a c  - 288a b c  - 1752a b c  + 378a b c + 15b )x
+--R         + 
+--R                 4   3        3 3 2       2 5          7  4
+--R           (4032a b c  - 5136a b c  - 108a b c + 285a b )x
+--R         + 
+--R                 5 3       4 2 2        3 4        2 6  3
+--R           (2688a c  - 864a b c  - 3912a b c + 990a b )x
+--R         + 
+--R                 5   2        4 3         3 5  2
+--R           (3840a b c  - 5760a b c + 1200a b )x
+--R         + 
+--R                 6 2        5 2        4 4
+--R           (1536a c  - 2304a b c + 480a b )x
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                      2 4        2 3      4 2  5
+--R               (- 128a c  - 64a b c  + 24b c )x
+--R             + 
+--R                      2   3         3 2      5   4
+--R               (- 192a b c  + 288a b c  - 60b c)x
+--R             + 
+--R                      3 3       2 2 2         4        6  3
+--R               (- 896a c  + 864a b c  + 440a b c - 150b )x
+--R             + 
+--R                       3   2        2 3          5  2
+--R               (- 1920a b c  + 2880a b c - 600a b )x
+--R             + 
+--R                       4 2        3 2        2 4
+--R               (- 1536a c  + 2304a b c - 480a b )x
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                    2   4        3 3     5 2  6
+--R               (192a b c  - 32a b c  - 4b c )x
+--R             + 
+--R                    3 4       2 2 3       4 2      6   5
+--R               (384a c  - 288a b c  + 8a b c  + 10b c)x
+--R             + 
+--R                     3   3        2 3 2         5       7  4
+--R               (1216a b c  - 1728a b c  + 236a b c + 30b )x
+--R             + 
+--R                     4 3        3 2 2        2 4          6  3
+--R               (1664a c  - 1248a b c  - 1352a b c + 390a b )x
+--R             + 
+--R                     4   2        3 3        2 5  2
+--R               (2688a b c  - 4032a b c + 840a b )x
+--R             + 
+--R                     5 2        4 2        3 4
+--R               (1536a c  - 2304a b c + 480a b )x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  2   4        3 3     5 2  7
+--R           (- 192a b c  + 32a b c  + 4b c )x
+--R         + 
+--R                  3 4       2 2 3       4 2      6   6
+--R           (- 384a c  + 288a b c  - 8a b c  - 10b c)x
+--R         + 
+--R                  3   3        2 3 2         5       7  5
+--R           (- 384a b c  + 2112a b c  - 416a b c - 30b )x
+--R         + 
+--R                   4 3        3 2 2       2 4          6  4
+--R           (- 1664a c  + 5408a b c  + 776a b c - 570a b )x
+--R         + 
+--R                 4   2        3 3         2 5  3
+--R           (1472a b c  + 6784a b c - 1980a b )x
+--R         + 
+--R                   5 2        4 2         3 4  2         5          4 3
+--R           (- 1536a c  + 8960a b c - 2400a b )x  + (3328a b c - 960a b )x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R     + 
+--R                2 5        2 4      4 3  8        2   4         3 3      5 2  7
+--R           (128a c  + 64a b c  - 24b c )x  + (320a b c  - 224a b c  + 36b c )x
+--R         + 
+--R                 3 4        2 2 3         4 2       6   6
+--R           (1024a c  - 1856a b c  - 496a b c  + 240b c)x
+--R         + 
+--R                3   3        2 3 2          5        7  5
+--R           (512a b c  - 6432a b c  + 1016a b c + 180b )x
+--R         + 
+--R                 4 3        3 2 2        2 4           6  4
+--R           (2432a c  - 9984a b c  - 2296a b c + 1320a b )x
+--R         + 
+--R                   4   2         3 3         2 5  3
+--R           (- 2368a b c  - 10368a b c + 3060a b )x
+--R         + 
+--R                 5 2         4 2         3 4  2           5          4 3
+--R           (1536a c  - 10624a b c + 2880a b )x  + (- 3328a b c + 960a b )x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                  2   5        3 4     5 3  3
+--R             (384a b c  - 64a b c  - 8b c )x
+--R           + 
+--R                  3 5       2 2 4         4 3  2         3   4       2 3 3
+--R             (768a c  + 384a b c  - 144a b c )x  + (1536a b c  - 384a b c )x
+--R           + 
+--R                  4 4       3 2 3
+--R             1024a c  - 256a b c
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|c \|c x  + b x + a
+--R       + 
+--R                    2 6         2 5      4 4  4
+--R             (- 256a c  - 128a b c  + 48b c )x
+--R           + 
+--R                     2   5         3 4      5 3  3
+--R             (- 1280a b c  + 128a b c  + 48b c )x
+--R           + 
+--R                     3 5       2 2 4         4 3  2
+--R             (- 1280a c  - 896a b c  + 304a b c )x
+--R           + 
+--R                     3   4       2 3 3          4 4       3 2 3
+--R             (- 2048a b c  + 512a b c )x - 1024a c  + 256a b c
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          4 5        3 2 4        2 4 3         6 2     8   14
+--R                   (- 512a c  - 3584a b c  - 2240a b c  - 224a b c  - 2b c)x
+--R                 + 
+--R                            4   4         3 3 3        2 5 2         7     9  13
+--R                   (- 18688a b c  - 34048a b c  - 9184a b c  - 400a b c - b )x
+--R                 + 
+--R                               5 4          4 2 3          3 4 2         2 6
+--R                       - 20992a c  - 152064a b c  - 100800a b c  - 11424a b c
+--R                     + 
+--R                               8
+--R                       - 162a b
+--R                  *
+--R                      12
+--R                     x
+--R                 + 
+--R                             5   3          4 3 2          3 5         2 7  11
+--R                   (- 256000a b c  - 453120a b c  - 115584a b c - 4320a b )x
+--R                 + 
+--R                             6 3          5 2 2          4 4          3 6  10
+--R                   (- 143360a c  - 957440a b c  - 549120a b c - 44352a b )x
+--R                 + 
+--R                             6   2           5 3           4 5  9
+--R                   (- 946176a b c  - 1374208a b c - 228096a b )x
+--R                 + 
+--R                             7 2           6 2           5 4  8
+--R                   (- 352256a c  - 1863680a b c - 658944a b )x
+--R                 + 
+--R                              7              6 3  7
+--R                   (- 1294336a b c - 1118208a b )x
+--R                 + 
+--R                             8            7 2  6          8   5          9 4
+--R                   (- 360448a c - 1105920a b )x  - 589824a b x  - 131072a x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                           3   5        2 3 4         5 3      7 2  14
+--R                   (- 2048a b c  - 3584a b c  - 896a b c  - 32b c )x
+--R                 + 
+--R                                4 5         3 2 4         2 4 3          6 2
+--R                         - 4608a c  - 33280a b c  - 21952a b c  - 2464a b c
+--R                       + 
+--R                              8
+--R                         - 34b c
+--R                  *
+--R                      13
+--R                     x
+--R                 + 
+--R                            4   4          3 3 3         2 5 2          7   12
+--R                   (- 83968a b c  - 152064a b c  - 40320a b c  - 1632a b c)x
+--R                 + 
+--R                            5 4          4 2 3          3 4 2         2 6   11
+--R                   (- 61440a c  - 424960a b c  - 257280a b c  - 22848a b c)x
+--R                 + 
+--R                             5   3          4 3 2          3 5   10
+--R                   (- 512000a b c  - 788480a b c  - 143616a b c)x
+--R                 + 
+--R                             6 3           5 2 2          4 4   9
+--R                   (- 221184a c  - 1241088a b c  - 478720a b c)x
+--R                 + 
+--R                             6   2          5 3   8
+--R                   (- 966656a b c  - 905216a b c)x
+--R                 + 
+--R                           7 2          6 2   7          7     6          8   5
+--R                 (- 294912a c  - 974848a b c)x  - 557056a b c x  - 131072a c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                     3   5        2 3 4         5 3      7 2  15
+--R               (2048a b c  + 3584a b c  + 896a b c  + 32b c )x
+--R             + 
+--R                     4 5         3 2 4         2 4 3          6 2      8   14
+--R               (4608a c  + 34304a b c  + 23744a b c  + 2912a b c  + 50b c)x
+--R             + 
+--R                      4   4          3 3 3         2 5 2          7       9  13
+--R               (88576a b c  + 174080a b c  + 53312a b c  + 3008a b c + 18b )x
+--R             + 
+--R                           5 4          4 2 3          3 4 2         2 6
+--R                     66048a c  + 508416a b c  + 369600a b c  + 49056a b c
+--R                   + 
+--R                           8
+--R                     978a b
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                       5   3           4 3 2          3 5          2 7  11
+--R               (634880a b c  + 1208320a b c  + 344832a b c + 15744a b )x
+--R             + 
+--R                       6 3           5 2 2           4 4           3 6  10
+--R               (282624a c  + 2003968a b c  + 1253120a b c + 116160a b )x
+--R             + 
+--R                        6   2           5 3           4 5  9
+--R               (1630208a b c  + 2539520a b c + 467456a b )x
+--R             + 
+--R                       7 2           6 2            5 4  8
+--R               (516096a c  + 2895872a b c + 1111552a b )x
+--R             + 
+--R                        7              6 3  7           8            7 2  6
+--R               (1736704a b c + 1605632a b )x  + (425984a c + 1384448a b )x
+--R             + 
+--R                      8   5          9 4
+--R               655360a b x  + 131072a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                4 6        3 2 5        2 4 4         6 3     8 2  15
+--R           (512a c  + 3584a b c  + 2240a b c  + 224a b c  + 2b c )x
+--R         + 
+--R                  4   5         3 3 4         2 5 3         7 2     9   14
+--R           (18944a b c  + 35840a b c  + 10304a b c  + 512a b c  + 2b c)x
+--R         + 
+--R                  5 5          4 2 4          3 4 3         2 6 2         8   13
+--R           (20992a c  + 160256a b c  + 115136a b c  + 15008a b c  + 290a b c)x
+--R         + 
+--R                   5   4          4 3 3          3 5 2        2 7   12
+--R           (264192a b c  + 508416a b c  + 147840a b c  + 7008a b c)x
+--R         + 
+--R                   6 4           5 2 3          4 4 2         3 6   11
+--R           (143360a c  + 1039360a b c  + 672000a b c  + 65856a b c)x
+--R         + 
+--R                   6   3           5 3 2          4 5   10
+--R           (987136a b c  + 1599488a b c  + 312576a b c)x
+--R         + 
+--R                   7 3           6 2 2          5 4   9
+--R           (352256a c  + 2060288a b c  + 839168a b c)x
+--R         + 
+--R                    7   2           6 3   8           8 2           7 2   7
+--R           (1359872a b c  + 1331200a b c)x  + (360448a c  + 1236992a b c)x
+--R         + 
+--R                  8     6          9   5
+--R           622592a b c x  + 131072a c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                       3   5        2 3 4         5 3      7 2  16
+--R               (- 2048a b c  - 3584a b c  - 896a b c  - 32b c )x
+--R             + 
+--R                       4 5         3 2 4         2 4 3          6 2      8   15
+--R               (- 4608a c  - 34304a b c  - 23744a b c  - 2912a b c  - 50b c)x
+--R             + 
+--R                          4   4          3 3 3         2 5 2          7       9
+--R                 (- 88576a b c  - 174080a b c  - 53312a b c  - 3008a b c - 18b )
+--R              *
+--R                  14
+--R                 x
+--R             + 
+--R                           5 4          4 2 3          3 4 2         2 6
+--R                   - 66048a c  - 508416a b c  - 369600a b c  - 49056a b c
+--R                 + 
+--R                           8
+--R                   - 978a b
+--R              *
+--R                  13
+--R                 x
+--R             + 
+--R                         5   3           4 3 2          3 5          2 7  12
+--R               (- 634880a b c  - 1208320a b c  - 344832a b c - 15744a b )x
+--R             + 
+--R                         6 3           5 2 2           4 4           3 6  11
+--R               (- 282624a c  - 2003968a b c  - 1253120a b c - 116160a b )x
+--R             + 
+--R                          6   2           5 3           4 5  10
+--R               (- 1630208a b c  - 2539520a b c - 467456a b )x
+--R             + 
+--R                         7 2           6 2            5 4  9
+--R               (- 516096a c  - 2895872a b c - 1111552a b )x
+--R             + 
+--R                          7              6 3  8             8            7 2  7
+--R               (- 1736704a b c - 1605632a b )x  + (- 425984a c - 1384448a b )x
+--R             + 
+--R                        8   6          9 5
+--R               - 655360a b x  - 131072a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                  4 6        3 2 5        2 4 4         6 3     8 2  16
+--R           (- 512a c  - 3584a b c  - 2240a b c  - 224a b c  - 2b c )x
+--R         + 
+--R                    4   5         3 3 4         2 5 3         7 2     9   15
+--R           (- 18944a b c  - 35840a b c  - 10304a b c  - 512a b c  - 2b c)x
+--R         + 
+--R                         5 5          4 2 4          3 4 3         2 6 2
+--R                 - 20992a c  - 160256a b c  - 115136a b c  - 15008a b c
+--R               + 
+--R                         8
+--R                 - 290a b c
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                     5   4          4 3 3          3 5 2        2 7   13
+--R           (- 264192a b c  - 508416a b c  - 147840a b c  - 7008a b c)x
+--R         + 
+--R                     6 4           5 2 3          4 4 2         3 6   12
+--R           (- 143360a c  - 1039360a b c  - 672000a b c  - 65856a b c)x
+--R         + 
+--R                     6   3           5 3 2          4 5   11
+--R           (- 987136a b c  - 1599488a b c  - 312576a b c)x
+--R         + 
+--R                     7 3           6 2 2          5 4   10
+--R           (- 352256a c  - 2060288a b c  - 839168a b c)x
+--R         + 
+--R                      7   2           6 3   9             8 2           7 2   8
+--R           (- 1359872a b c  - 1331200a b c)x  + (- 360448a c  - 1236992a b c)x
+--R         + 
+--R                    8     7          9   6
+--R           - 622592a b c x  - 131072a c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                4 6        3 2 5        2 4 4         6 3     8 2  17
+--R           (512a c  + 3584a b c  + 2240a b c  + 224a b c  + 2b c )x
+--R         + 
+--R                  4   5         3 3 4         2 5 3         7 2     9   16
+--R           (19200a b c  + 37632a b c  + 11424a b c  + 624a b c  + 3b c)x
+--R         + 
+--R                     5 5          4 2 4          3 4 3         2 6 2         8
+--R               21504a c  + 174336a b c  + 137088a b c  + 20832a b c  + 564a b c
+--R             + 
+--R                10
+--R               b
+--R          *
+--R              15
+--R             x
+--R         + 
+--R                     5   4          4 3 3          3 5 2         2 7          9
+--R             (295680a b c  + 639232a b c  + 225568a b c  + 16144a b c + 163a b )
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                        6 4           5 2 3           4 4 2          3 6
+--R                 164352a c  + 1365504a b c  + 1103040a b c  + 171360a b c
+--R               + 
+--R                      2 8
+--R                 4482a b
+--R          *
+--R              13
+--R             x
+--R         + 
+--R                    6   3           5 3 2          4 5          3 7  12
+--R           (1345536a b c  + 2784768a b c  + 892800a b c + 48672a b )x
+--R         + 
+--R                   7 3           6 2 2           5 4           4 6  11
+--R           (495616a c  + 3767296a b c  + 2582272a b c + 272448a b )x
+--R         + 
+--R                    7   2           6 3           5 5  10
+--R           (2592768a b c  + 4356096a b c + 887040a b )x
+--R         + 
+--R                   8 2           7 2            6 4  9
+--R           (712704a c  + 4263936a b c + 1777152a b )x
+--R         + 
+--R                    8              7 3  8           9            8 2  7
+--R           (2244608a b c + 2224128a b )x  + (491520a c + 1695744a b )x
+--R         + 
+--R                  9   6          10 5
+--R           720896a b x  + 131072a  x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                 3   6        2 3 5         5 4      7 3  17
+--R           (2048a b c  + 3584a b c  + 896a b c  + 32b c )x
+--R         + 
+--R                 4 6         3 2 5         2 4 4          6 3      8 2  16
+--R           (4608a c  + 35328a b c  + 25536a b c  + 3360a b c  + 66b c )x
+--R         + 
+--R                  4   5          3 3 4         2 5 3          7 2      9   15
+--R           (90624a b c  + 188928a b c  + 63168a b c  + 4128a b c  + 34b c)x
+--R         + 
+--R                    5 5          4 2 4          3 4 3         2 6 2          8
+--R             (66048a c  + 542208a b c  + 431296a b c  + 65632a b c  + 1666a b c)
+--R          *
+--R              14
+--R             x
+--R         + 
+--R                   5   4           4 3 3          3 5 2         2 7   13
+--R           (657408a b c  + 1365504a b c  + 441216a b c  + 24480a b c)x
+--R         + 
+--R                   6 4           5 2 3           4 4 2          3 6   12
+--R           (282624a c  + 2178048a b c  + 1524480a b c  + 166464a b c)x
+--R         + 
+--R                    6   3           5 3 2          4 5   11
+--R           (1699840a b c  + 2934784a b c  + 622336a b c)x
+--R         + 
+--R                   7 3           6 2 2           5 4   10
+--R           (516096a c  + 3182592a b c  + 1383936a b c)x
+--R         + 
+--R                    7   2           6 3   9           8 2           7 2   8
+--R           (1818624a b c  + 1880064a b c)x  + (425984a c  + 1531904a b c)x
+--R         + 
+--R                  8     7          9   6
+--R           688128a b c x  + 131072a c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                       3   6        2 3 5         5 4      7 3  13
+--R                 (2048a b c  + 3584a b c  + 896a b c  + 32b c )x
+--R               + 
+--R                       4 6         3 2 5         2 4 4          6 3      8 2  12
+--R                 (4608a c  + 36352a b c  + 27328a b c  + 3808a b c  + 82b c )x
+--R               + 
+--R                             4   5          3 3 4         2 5 3          7 2
+--R                       95232a b c  + 211968a b c  + 77952a b c  + 5952a b c
+--R                     + 
+--R                          9
+--R                       68b c
+--R                *
+--R                    11
+--R                   x
+--R               + 
+--R                           5 5          4 2 4          3 4 3          2 6 2
+--R                     70656a c  + 631296a b c  + 567424a b c  + 105280a b c
+--R                   + 
+--R                            8       10
+--R                     4036a b c + 18b
+--R                *
+--R                    10
+--R                   x
+--R               + 
+--R                            5   4           4 3 3          3 5 2         2 7
+--R                     789504a b c  + 1890816a b c  + 767744a b c  + 67808a b c
+--R                   + 
+--R                           9
+--R                     996a b
+--R                *
+--R                    9
+--R                   x
+--R               + 
+--R                            6 4           5 2 3           4 4 2          3 6
+--R                     348672a c  + 3147264a b c  + 2831040a b c  + 510048a b c
+--R                   + 
+--R                           2 8
+--R                     16722a b
+--R                *
+--R                    8
+--R                   x
+--R               + 
+--R                          6   3           5 3 2           4 5           3 7  7
+--R                 (2547712a b c  + 5751808a b c  + 2065408a b c + 131904a b )x
+--R               + 
+--R                         7 3           6 2 2           5 4           4 6  6
+--R                 (798720a c  + 6530048a b c  + 4904192a b c + 583616a b )x
+--R               + 
+--R                          7   2           6 3            5 5  5
+--R                 (3883008a b c  + 7041024a b c + 1579008a b )x
+--R               + 
+--R                         8 2           7 2            6 4  4
+--R                 (942080a c  + 6017024a b c + 2717184a b )x
+--R               + 
+--R                          8              7 3  3           9            8 2  2
+--R                 (2818048a b c + 2990080a b )x  + (557056a c + 2039808a b )x
+--R               + 
+--R                        9             10
+--R                 786432a b x + 131072a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                  4 7        3 2 6        2 4 5         6 4     8 3  13
+--R             (512a c  + 3584a b c  + 2240a b c  + 224a b c  + 2b c )x
+--R           + 
+--R                    4   6         3 3 5         2 5 4         7 3     9 2  12
+--R             (19456a b c  + 39424a b c  + 12544a b c  + 736a b c  + 4b c )x
+--R           + 
+--R                       5 6          4 2 5          3 4 4         2 6 3
+--R                 21504a c  + 182784a b c  + 153216a b c  + 25536a b c
+--R               + 
+--R                       8 2     10
+--R                 804a b c  + 2b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                        5   5          4 3 4          3 5 3         2 7 2
+--R                 304128a b c  + 704512a b c  + 273280a b c  + 22528a b c
+--R               + 
+--R                       9
+--R                 292a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                        6 5           5 2 4           4 4 3          3 6 2
+--R                 164352a c  + 1463808a b c  + 1295552a b c  + 228704a b c
+--R               + 
+--R                      2 8
+--R                 7298a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                      6   4           5 3 3           4 5 2         3 7   8
+--R             (1394688a b c  + 3147264a b c  + 1132416a b c  + 72864a b c)x
+--R           + 
+--R                     7 4           6 2 3           5 4 2          4 6   7
+--R             (495616a c  + 4086784a b c  + 3110656a b c  + 378432a b c)x
+--R           + 
+--R                      7   3           6 3 2           5 5   6
+--R             (2699264a b c  + 4990976a b c  + 1151744a b c)x
+--R           + 
+--R                     8 3           7 2 2           6 4   5
+--R             (712704a c  + 4657152a b c  + 2170368a b c)x
+--R           + 
+--R                      8   2           7 3   4           9 2           8 2   3
+--R             (2342912a b c  + 2568192a b c)x  + (491520a c  + 1859584a b c)x
+--R           + 
+--R                    9     2          10
+--R             753664a b c x  + 131072a  c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    4 7        3 2 6        2 4 5         6 4     8 3  14
+--R             (- 512a c  - 3584a b c  - 2240a b c  - 224a b c  - 2b c )x
+--R           + 
+--R                      4   6         3 3 5         2 5 4         7 3     9 2  13
+--R             (- 19712a b c  - 41216a b c  - 13664a b c  - 848a b c  - 5b c )x
+--R           + 
+--R                         5 6          4 2 5          3 4 4         2 6 3
+--R                 - 22016a c  - 197120a b c  - 176960a b c  - 32480a b c
+--R               + 
+--R                          8 2     10
+--R                 - 1190a b c  - 4b  c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                          5   5          4 3 4          3 5 3         2 7 2
+--R                 - 336384a b c  - 851200a b c  - 374080a b c  - 37600a b c
+--R               + 
+--R                         9     11
+--R                 - 730a b c - b
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                          6 5           5 2 4           4 4 3          3 6 2
+--R                 - 185856a c  - 1835520a b c  - 1879360a b c  - 417760a b c
+--R               + 
+--R                         2 8          10
+--R                 - 21190a b c - 164a b
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                           6   4           5 3 3           4 5 2          3 7
+--R                 - 1805568a b c  - 4789504a b c  - 2221408a b c  - 236176a b c
+--R               + 
+--R                        2 9
+--R                 - 4645a b
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                          7 4           6 2 3           5 4 2           4 6
+--R                 - 659968a c  - 6478336a b c  - 6470080a b c  - 1336608a b c
+--R               + 
+--R                         3 8
+--R                 - 53154a b
+--R            *
+--R                8
+--R               x
+--R           + 
+--R                        7   3            6 3 2           5 5           4 7  7
+--R             (- 4433920a b c  - 10908160a b c  - 4362112a b c - 321120a b )x
+--R           + 
+--R                        8 3            7 2 2           6 4            5 6  6
+--R             (- 1208320a c  - 10624000a b c  - 8715520a b c - 1159488a b )x
+--R           + 
+--R                        8   2            7 3            6 5  5
+--R             (- 5550080a b c  - 10844160a b c - 2664192a b )x
+--R           + 
+--R                        9 2           8 2            7 4  4
+--R             (- 1204224a c  - 8204288a b c - 4001280a b )x
+--R           + 
+--R                        9              8 3  3             10            9 2  2
+--R             (- 3457024a b c - 3919872a b )x  + (- 622592a  c - 2416640a b )x
+--R           + 
+--R                      10             11
+--R             - 851968a  b x - 131072a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                     3   7        2 3 6         5 5      7 4  14
+--R             (- 2048a b c  - 3584a b c  - 896a b c  - 32b c )x
+--R           + 
+--R                     4 7         3 2 6         2 4 5          6 4      8 3  13
+--R             (- 4608a c  - 37376a b c  - 29120a b c  - 4256a b c  - 98b c )x
+--R           + 
+--R                           4   6          3 3 5         2 5 4          7 3
+--R                   - 97280a b c  - 227840a b c  - 89600a b c  - 7520a b c
+--R                 + 
+--R                         9 2
+--R                   - 100b c
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                         5 6          4 2 5          3 4 4          2 6 3
+--R                 - 70656a c  - 668160a b c  - 645760a b c  - 132160a b c
+--R               + 
+--R                          8 2      10
+--R                 - 5860a b c  - 34b  c
+--R            *
+--R                11
+--R               x
+--R           + 
+--R                          5   5           4 3 4          3 5 3         2 7 2
+--R                 - 814080a b c  - 2096640a b c  - 935680a b c  - 94240a b c
+--R               + 
+--R                          9
+--R                 - 1700a b c
+--R            *
+--R                10
+--R               x
+--R           + 
+--R                          6 5           5 2 4           4 4 3          3 6 2
+--R                 - 348672a c  - 3377664a b c  - 3321280a b c  - 673312a b c
+--R               + 
+--R                         2 8
+--R                 - 26146a b c
+--R            *
+--R                9
+--R               x
+--R           + 
+--R                        6   4           5 3 3           4 5 2          3 7   8
+--R             (- 2639872a b c  - 6478336a b c  - 2588032a b c  - 190944a b c)x
+--R           + 
+--R                       7 4           6 2 3           5 4 2          4 6   7
+--R             (- 798720a c  - 7060480a b c  - 5843200a b c  - 788800a b c)x
+--R           + 
+--R                        7   3           6 3 2           5 5   6
+--R             (- 4034560a b c  - 7997440a b c  - 2006272a b c)x
+--R           + 
+--R                       8 3           7 2 2           6 4   5
+--R             (- 942080a c  - 6533120a b c  - 3264000a b c)x
+--R           + 
+--R                        8   2           7 3   4
+--R             (- 2932736a b c  - 3411968a b c)x
+--R           + 
+--R                       9 2           8 2   3          9     2          10
+--R             (- 557056a c  - 2220032a b c)x  - 819200a b c x  - 131072a  c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 345
+
+--S 346 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      3 4       2 2 3         4 2      6   5
+--R               (- 384a c  + 288a b c  + 312a b c  - 90b c)x
+--R             + 
+--R                       3   3        2 3 2         5       7  4
+--R               (- 1920a b c  + 2592a b c  - 168a b c - 90b )x
+--R             + 
+--R                       4 3        3 2 2        2 4          6  3
+--R               (- 1920a c  + 1056a b c  + 2136a b c - 570a b )x
+--R             + 
+--R                       4   2        3 3        2 5  2
+--R               (- 3072a b c  + 4608a b c - 960a b )x
+--R             + 
+--R                       5 2        4 2        3 4
+--R               (- 1536a c  + 2304a b c - 480a b )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + b x + a
+--R         + 
+--R                    3   4       2 3 3         5 2      7   6
+--R               (576a b c  - 816a b c  + 108a b c  + 15b c)x
+--R             + 
+--R                     4 4       3 2 3        2 4 2         6       8  5
+--R               (1152a c  - 288a b c  - 1752a b c  + 378a b c + 15b )x
+--R             + 
+--R                     4   3        3 3 2       2 5          7  4
+--R               (4032a b c  - 5136a b c  - 108a b c + 285a b )x
+--R             + 
+--R                     5 3       4 2 2        3 4        2 6  3
+--R               (2688a c  - 864a b c  - 3912a b c + 990a b )x
+--R             + 
+--R                     5   2        4 3         3 5  2
+--R               (3840a b c  - 5760a b c + 1200a b )x
+--R             + 
+--R                     6 2        5 2        4 4
+--R               (1536a c  - 2304a b c + 480a b )x
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                       3   3        2 3 2         5       7  3
+--R               (- 1152a b c  + 1632a b c  - 216a b c - 30b )x
+--R             + 
+--R                       4 3        3 2 2        2 4          6  2
+--R               (- 2304a c  + 1728a b c  + 1872a b c - 540a b )x
+--R             + 
+--R                       4   2        3 3         2 5          5 2        4 2
+--R               (- 4608a b c  + 6912a b c - 1440a b )x - 3072a c  + 4608a b c
+--R             + 
+--R                     3 4
+--R               - 960a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                    3 4       2 2 3         4 2       6   4
+--R               (768a c  - 576a b c  - 624a b c  + 180b c)x
+--R             + 
+--R                     3   3        2 3 2         5        7  3
+--R               (3840a b c  - 5184a b c  + 336a b c + 180b )x
+--R             + 
+--R                     4 3        3 2 2        2 4           6  2
+--R               (3840a c  - 2112a b c  - 4272a b c + 1140a b )x
+--R             + 
+--R                     4   2        3 3         2 5          5 2        4 2
+--R               (6144a b c  - 9216a b c + 1920a b )x + 3072a c  - 4608a b c
+--R             + 
+--R                   3 4
+--R               960a b
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                      2 4        2 3      4 2  5
+--R               (- 128a c  - 64a b c  + 24b c )x
+--R             + 
+--R                      2   3         3 2      5   4
+--R               (- 192a b c  + 288a b c  - 60b c)x
+--R             + 
+--R                      3 3       2 2 2         4        6  3
+--R               (- 896a c  + 864a b c  + 440a b c - 150b )x
+--R             + 
+--R                       3   2        2 3          5  2
+--R               (- 1920a b c  + 2880a b c - 600a b )x
+--R             + 
+--R                       4 2        3 2        2 4
+--R               (- 1536a c  + 2304a b c - 480a b )x
+--R          *
+--R                            +--------------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|a \|c \|c x  + b x + a
+--R         + 
+--R                    2   4        3 3     5 2  6
+--R               (192a b c  - 32a b c  - 4b c )x
+--R             + 
+--R                    3 4       2 2 3       4 2      6   5
+--R               (384a c  - 288a b c  + 8a b c  + 10b c)x
+--R             + 
+--R                     3   3        2 3 2         5       7  4
+--R               (1216a b c  - 1728a b c  + 236a b c + 30b )x
+--R             + 
+--R                     4 3        3 2 2        2 4          6  3
+--R               (1664a c  - 1248a b c  - 1352a b c + 390a b )x
+--R             + 
+--R                     4   2        3 3        2 5  2
+--R               (2688a b c  - 4032a b c + 840a b )x
+--R             + 
+--R                     5 2        4 2        3 4
+--R               (1536a c  - 2304a b c + 480a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  2   4        3 3     5 2  7
+--R           (- 192a b c  + 32a b c  + 4b c )x
+--R         + 
+--R                  3 4       2 2 3       4 2      6   6
+--R           (- 384a c  + 288a b c  - 8a b c  - 10b c)x
+--R         + 
+--R                  3   3        2 3 2         5       7  5
+--R           (- 384a b c  + 2112a b c  - 416a b c - 30b )x
+--R         + 
+--R                   4 3        3 2 2       2 4          6  4
+--R           (- 1664a c  + 5408a b c  + 776a b c - 570a b )x
+--R         + 
+--R                 4   2        3 3         2 5  3
+--R           (1472a b c  + 6784a b c - 1980a b )x
+--R         + 
+--R                   5 2        4 2         3 4  2         5          4 3
+--R           (- 1536a c  + 8960a b c - 2400a b )x  + (3328a b c - 960a b )x
+--R      *
+--R                    +--------------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b x + a
+--R     + 
+--R                2 5        2 4      4 3  8        2   4         3 3      5 2  7
+--R           (128a c  + 64a b c  - 24b c )x  + (320a b c  - 224a b c  + 36b c )x
+--R         + 
+--R                 3 4        2 2 3         4 2       6   6
+--R           (1024a c  - 1856a b c  - 496a b c  + 240b c)x
+--R         + 
+--R                3   3        2 3 2          5        7  5
+--R           (512a b c  - 6432a b c  + 1016a b c + 180b )x
+--R         + 
+--R                 4 3        3 2 2        2 4           6  4
+--R           (2432a c  - 9984a b c  - 2296a b c + 1320a b )x
+--R         + 
+--R                   4   2         3 3         2 5  3
+--R           (- 2368a b c  - 10368a b c + 3060a b )x
+--R         + 
+--R                 5 2         4 2         3 4  2           5          4 3
+--R           (1536a c  - 10624a b c + 2880a b )x  + (- 3328a b c + 960a b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                  2   5        3 4     5 3  3
+--R             (384a b c  - 64a b c  - 8b c )x
+--R           + 
+--R                  3 5       2 2 4         4 3  2         3   4       2 3 3
+--R             (768a c  + 384a b c  - 144a b c )x  + (1536a b c  - 384a b c )x
+--R           + 
+--R                  4 4       3 2 3
+--R             1024a c  - 256a b c
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|c \|c x  + b x + a
+--R       + 
+--R                    2 6         2 5      4 4  4
+--R             (- 256a c  - 128a b c  + 48b c )x
+--R           + 
+--R                     2   5         3 4      5 3  3
+--R             (- 1280a b c  + 128a b c  + 48b c )x
+--R           + 
+--R                     3 5       2 2 4         4 3  2
+--R             (- 1280a c  - 896a b c  + 304a b c )x
+--R           + 
+--R                     3   4       2 3 3          4 4       3 2 3
+--R             (- 2048a b c  + 512a b c )x - 1024a c  + 256a b c
+--R        *
+--R            +---+ +-+ +-+
+--R           \|- c \|a \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                      2   2         3       5  9
+--R               (- 192a b c  - 160a b c - 12b )x
+--R             + 
+--R                      3 2        2 2          4  8           3           2 3  7
+--R               (- 384a c  - 1344a b c - 280a b )x  + (- 3072a b c - 1792a b )x
+--R             + 
+--R                       4         3 2  6        4   5        5 4
+--R               (- 2048a c - 4608a b )x  - 5120a b x  - 2048a x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               3 3       2 2 2        4     6  10
+--R           (64a c  + 240a b c  + 60a b c + b )x
+--R         + 
+--R                 3   2       2 3         5  9
+--R           (1152a b c  + 960a b c + 72a b )x
+--R         + 
+--R                 4 2        3 2        2 4  8         4           3 3  7
+--R           (1152a c  + 4032a b c + 840a b )x  + (6144a b c + 3584a b )x
+--R         + 
+--R                 5         4 2  6        5   5        6 4
+--R           (3072a c + 6912a b )x  + 6144a b x  + 2048a x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 3 3       2 2 2        4     6  11
+--R           (- 64a c  - 240a b c  - 60a b c - b )x
+--R         + 
+--R                   3   2       2 3         5  10
+--R           (- 1152a b c  - 960a b c - 72a b )x
+--R         + 
+--R                   4 2        3 2        2 4  9           4           3 3  8
+--R           (- 1152a c  - 4032a b c - 840a b )x  + (- 6144a b c - 3584a b )x
+--R         + 
+--R                   5         4 2  7        5   6        6 5
+--R           (- 3072a c - 6912a b )x  - 6144a b x  - 2048a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                2   3         3 2      5   12
+--R           (192a b c  + 160a b c  + 12b c)x
+--R         + 
+--R                3 3        2 2 2         4       6  11
+--R           (384a c  + 1536a b c  + 440a b c + 12b )x
+--R         + 
+--R                 3   2        2 3          5  10
+--R           (3648a b c  + 3296a b c + 292a b )x
+--R         + 
+--R                 4 2        3 2         2 4  9          4           3 3  8
+--R           (2432a c  + 9024a b c + 2072a b )x  + (10240a b c + 6400a b )x
+--R         + 
+--R                 5         4 2  7        5   6        6 5
+--R           (4096a c + 9728a b )x  + 7168a b x  + 2048a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 3 4       2 2 3        4 2    6   8
+--R             (64a c  + 240a b c  + 60a b c  + b c)x
+--R           + 
+--R                   3   3        2 3 2         5     7  7
+--R             (1216a b c  + 1200a b c  + 132a b c + b )x
+--R           + 
+--R                   4 3        3 2 2        2 4         6  6
+--R             (1216a c  + 5424a b c  + 1860a b c + 73a b )x
+--R           + 
+--R                   4   2        3 3        2 5  5
+--R             (8448a b c  + 8576a b c + 912a b )x
+--R           + 
+--R                   5 2         4 2         3 4  4          5            4 3  3
+--R             (4224a c  + 17088a b c + 4424a b )x  + (15360a b c + 10496a b )x
+--R           + 
+--R                   6          5 2  2        6           7
+--R             (5120a c + 13056a b )x  + 8192a b x + 2048a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2   4         3 3      5 2  9
+--R             (- 192a b c  - 160a b c  - 12b c )x
+--R           + 
+--R                    3 4        2 2 3         4 2      6   8
+--R             (- 384a c  - 1728a b c  - 600a b c  - 24b c)x
+--R           + 
+--R                     3   3        2 3 2         5       7  7
+--R             (- 4224a b c  - 4992a b c  - 744a b c - 12b )x
+--R           + 
+--R                     4 3         3 2 2        2 4          6  6
+--R             (- 2816a c  - 14208a b c  - 5808a b c - 304a b )x
+--R           + 
+--R                      4   2         3 3         2 5  5
+--R             (- 16320a b c  - 18720a b c - 2364a b )x
+--R           + 
+--R                     5 2         4 2         3 4  4
+--R             (- 6528a c  - 28992a b c - 8472a b )x
+--R           + 
+--R                      5            4 3  3           6          5 2  2
+--R             (- 21504a b c - 16128a b )x  + (- 6144a c - 16896a b )x
+--R           + 
+--R                    6           7
+--R             - 9216a b x - 2048a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 347
+
+)clear all
+
+--S 348 of 704
+t0:=x^6/(a*x^2+b*x^3+c*x^4)^(3/2)
+--R 
+--R
+--R                           4
+--R                          x
+--R   (1)  -------------------------------------
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 348
+
+--S 349 of 704
+r0:=2*x^3*(2*a+b*x)/((b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))-3/2*b*x*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (c^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))-2*b*sqrt(a*x^2+b*x^3+c*x^4)/_
+   (c*(b^2-4*a*c))+(3*b^2-8*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(c^2*(b^2-4*a*c)*x)
+--R 
+--R
+--R   (2)
+--R                          +--------------+
+--R                      3   |   2                        2c x + b
+--R       (- 12a b c + 3b )x\|c x  + b x + a atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|c \|c x  + b x + a
+--R     + 
+--R             2     2   3                3  2       2        2    +-+
+--R       ((8a c  - 2b c)x  + (20a b c - 6b )x  + (16a c - 6a b )x)\|c
+--R  /
+--R                         +------------------+
+--R          3     2 2  +-+ |   4      3      2
+--R     (8a c  - 2b c )\|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                   +--------------+
+--R                           3  2        2       2   |   2
+--R             ((12a b c + 3b )x  + 24a b x + 24a b)\|c x  + b x + a
+--R           + 
+--R                   2   3                   3  2        2       2   +-+
+--R             (- 12b c x  + (- 24a b c - 12b )x  - 36a b x - 24a b)\|a
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                                                +--------------+
+--R                  3      2 2            +-+ +-+ |   2
+--R         (- 8b c x  - 18b x  - 24a b x)\|a \|c \|c x  + b x + a
+--R       + 
+--R               2     2   4                3  3        2 2      2     +-+
+--R         ((8a c  + 2b c)x  + (20a b c + 6b )x  + 30a b x  + 24a b x)\|c
+--R    /
+--R                                                      +--------------+
+--R               3     2 2  2          2       2 2  +-+ |   2
+--R         ((8a c  + 2b c )x  + 16a b c x + 16a c )\|c \|c x  + b x + a
+--R       + 
+--R                3 3           3     2 2  2          2       2 2  +-+ +-+
+--R         (- 8b c x  + (- 16a c  - 8b c )x  - 24a b c x - 16a c )\|a \|c
+--R     ,
+--R
+--R                                                     +--------------+
+--R                             3  2        2       2   |   2
+--R             ((- 12a b c - 3b )x  - 24a b x - 24a b)\|c x  + b x + a
+--R           + 
+--R                 2   3                 3  2        2       2   +-+
+--R             (12b c x  + (24a b c + 12b )x  + 36a b x + 24a b)\|a
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                                                 +--------------+
+--R                  3     2 2            +---+ +-+ |   2
+--R         (- 4b c x  - 9b x  - 12a b x)\|- c \|a \|c x  + b x + a
+--R       + 
+--R               2    2   4                3  3        2 2      2     +---+
+--R         ((4a c  + b c)x  + (10a b c + 3b )x  + 15a b x  + 12a b x)\|- c
+--R    /
+--R                                                     +--------------+
+--R               3    2 2  2         2      2 2  +---+ |   2
+--R         ((4a c  + b c )x  + 8a b c x + 8a c )\|- c \|c x  + b x + a
+--R       + 
+--R                3 3          3     2 2  2          2      2 2  +---+ +-+
+--R         (- 4b c x  + (- 8a c  - 4b c )x  - 12a b c x - 8a c )\|- c \|a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 350
+
+--S 351 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2   2     5  2       2 2         4        3         2 3
+--R             ((48a b c  - 3b )x  + (96a b c - 24a b )x + 96a b c - 24a b )
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       2 2      4   3         2   2        3       5  2
+--R               (- 48a b c  + 12b c)x  + (- 96a b c  - 24a b c + 12b )x
+--R             + 
+--R                      2 2         4        3         2 3
+--R               (- 144a b c + 36a b )x - 96a b c + 24a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                       2 2      4   4         2   2        3       5  3
+--R               (- 48a b c  + 12b c)x  + (- 96a b c  - 24a b c + 12b )x
+--R             + 
+--R                      2 2         4  2         3         2 3
+--R               (- 144a b c + 36a b )x  + (- 96a b c + 24a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               2   3     5   5        2 2 2        4      6  4
+--R           (48a b c  - 3b c)x  + (144a b c  - 24a b c - 3b )x
+--R         + 
+--R                3   2      2 3         5  3        3 2       2 4  2
+--R           (144a b c  + 72a b c - 27a b )x  + (192a b c - 48a b )x
+--R         + 
+--R               4         3 3
+--R           (96a b c - 24a b )x
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                         2     3   3           2       4  2
+--R               (- 32a b c  + 8b c)x  + (- 72a b c + 18b )x
+--R             + 
+--R                     2           3
+--R               (- 96a b c + 24a b )x
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|c \|c x  + b x + a
+--R         + 
+--R                   2 3     4   4       2   2       3      5  3
+--R               (32a c  - 2b c)x  + (80a b c  + 4a b c - 6b )x
+--R             + 
+--R                    2 2         4  2       3         2 3
+--R               (120a b c - 30a b )x  + (96a b c - 24a b )x
+--R          *
+--R              +-+
+--R             \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 2 3     4   5          2   2        3      5  4
+--R           (- 32a c  + 2b c)x  + (- 144a b c  + 20a b c + 6b )x
+--R         + 
+--R                  3 2       2 2         4  3          3         2 3  2
+--R           (- 128a c  - 136a b c + 54a b )x  + (- 288a b c + 96a b )x
+--R         + 
+--R                  4       3 2
+--R           (- 128a c + 48a b )x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R     + 
+--R                   3     3 2  6       2 3        2 2      4   5
+--R           (32a b c  - 8b c )x  + (64a c  + 96a b c  - 32b c)x
+--R         + 
+--R                2   2        3       5  4        3 2       2 2         4  3
+--R           (320a b c  - 16a b c - 24b )x  + (192a c  + 240a b c - 96a b )x
+--R         + 
+--R                3          2 3  2        4       3 2
+--R           (352a b c - 120a b )x  + (128a c - 48a b )x
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R                2 4     4 2  2       2   3        3 2        3 3      2 2 2  +-+
+--R           ((32a c  - 2b c )x  + (64a b c  - 16a b c )x + 64a c  - 16a b c )\|c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                       4     3 3  3         2 4        2 3     4 2  2
+--R             (- 32a b c  + 8b c )x  + (- 64a c  - 16a b c  + 8b c )x
+--R           + 
+--R                   2   3        3 2        3 3      2 2 2
+--R             (- 96a b c  + 24a b c )x - 64a c  + 16a b c
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                          3 4       2 2 3         4 2     6   11
+--R                   (- 128a c  - 480a b c  - 120a b c  - 2b c)x
+--R                 + 
+--R                           3   3        2 3 2         5     7  10
+--R                   (- 2752a b c  - 2480a b c  - 228a b c - b )x
+--R                 + 
+--R                           4 3         3 2 2        2 4         6  9
+--R                   (- 3200a c  - 12768a b c  - 3640a b c - 98a b )x
+--R                 + 
+--R                            4   2         3 3         2 5  8
+--R                   (- 23040a b c  - 19712a b c - 1568a b )x
+--R                 + 
+--R                            5 2         4 2         3 4  7
+--R                   (- 13312a c  - 46080a b c - 9408a b )x
+--R                 + 
+--R                            5            4 3  6            6          5 2  5
+--R                   (- 48128a b c - 26880a b )x  + (- 18432a c - 39424a b )x
+--R                 + 
+--R                           6   4        7 3
+--R                   - 28672a b x  - 8192a x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                          2   4         3 3      5 2  11
+--R                   (- 384a b c  - 320a b c  - 24b c )x
+--R                 + 
+--R                          3 4        2 2 3          4 2      6   10
+--R                   (- 896a c  - 3552a b c  - 1000a b c  - 26b c)x
+--R                 + 
+--R                           3   3        2 3 2         5   9
+--R                   (- 9600a b c  - 8512a b c  - 728a b c)x
+--R                 + 
+--R                           4 3         3 2 2        2 4   8
+--R                   (- 7168a c  - 26112a b c  - 5824a b c)x
+--R                 + 
+--R                            4   2         3 3   7            5 2         4 2   6
+--R                   (- 32768a b c  - 19968a b c)x  + (- 14336a c  - 33280a b c)x
+--R                 + 
+--R                           5     5        6   4
+--R                   - 26624a b c x  - 8192a c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2   4         3 3      5 2  12
+--R               (384a b c  + 320a b c  + 24b c )x
+--R             + 
+--R                    3 4        2 2 3          4 2      6   11
+--R               (896a c  + 3744a b c  + 1160a b c  + 38b c)x
+--R             + 
+--R                      3   3         2 3 2          5       7  10
+--R               (10496a b c  + 10848a b c  + 1312a b c + 14b )x
+--R             + 
+--R                     4 3         3 2 2         2 4          6  9
+--R               (8064a c  + 35616a b c  + 12040a b c + 462a b )x
+--R             + 
+--R                      4   2         3 3         2 5  8
+--R               (47104a b c  + 45568a b c + 4480a b )x
+--R             + 
+--R                      5 2         4 2          3 4  7
+--R               (21504a c  + 81920a b c + 19392a b )x
+--R             + 
+--R                      5            4 3  6          6          5 2  5
+--R               (69632a b c + 43520a b )x  + (22528a c + 52736a b )x
+--R             + 
+--R                     6   4        7 3
+--R               32768a b x  + 8192a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                3 5       2 2 4         4 3     6 2  12
+--R           (128a c  + 480a b c  + 120a b c  + 2b c )x
+--R         + 
+--R                 3   4        2 3 3         5 2     7   11
+--R           (2816a b c  + 2720a b c  + 288a b c  + 2b c)x
+--R         + 
+--R                 4 4         3 2 3        2 4 2         6   10
+--R           (3200a c  + 13920a b c  + 4600a b c  + 170a b c)x
+--R         + 
+--R                  4   3         3 3 2        2 5   9
+--R           (24192a b c  + 23744a b c  + 2408a b c)x
+--R         + 
+--R                  5 3         4 2 2         3 4   8
+--R           (13312a c  + 52224a b c  + 12992a b c)x
+--R         + 
+--R                  5   2         4 3   7          6 2         5 2   6
+--R           (51200a b c  + 33792a b c)x  + (18432a c  + 45568a b c)x
+--R         + 
+--R                 6     5        7   4
+--R           30720a b c x  + 8192a c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      2   4         3 3      5 2  13
+--R               (- 384a b c  - 320a b c  - 24b c )x
+--R             + 
+--R                      3 4        2 2 3          4 2      6   12
+--R               (- 896a c  - 3744a b c  - 1160a b c  - 38b c)x
+--R             + 
+--R                        3   3         2 3 2          5       7  11
+--R               (- 10496a b c  - 10848a b c  - 1312a b c - 14b )x
+--R             + 
+--R                       4 3         3 2 2         2 4          6  10
+--R               (- 8064a c  - 35616a b c  - 12040a b c - 462a b )x
+--R             + 
+--R                        4   2         3 3         2 5  9
+--R               (- 47104a b c  - 45568a b c - 4480a b )x
+--R             + 
+--R                        5 2         4 2          3 4  8
+--R               (- 21504a c  - 81920a b c - 19392a b )x
+--R             + 
+--R                        5            4 3  7            6          5 2  6
+--R               (- 69632a b c - 43520a b )x  + (- 22528a c - 52736a b )x
+--R             + 
+--R                       6   5        7 4
+--R               - 32768a b x  - 8192a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                  3 5       2 2 4         4 3     6 2  13
+--R           (- 128a c  - 480a b c  - 120a b c  - 2b c )x
+--R         + 
+--R                   3   4        2 3 3         5 2     7   12
+--R           (- 2816a b c  - 2720a b c  - 288a b c  - 2b c)x
+--R         + 
+--R                   4 4         3 2 3        2 4 2         6   11
+--R           (- 3200a c  - 13920a b c  - 4600a b c  - 170a b c)x
+--R         + 
+--R                    4   3         3 3 2        2 5   10
+--R           (- 24192a b c  - 23744a b c  - 2408a b c)x
+--R         + 
+--R                    5 3         4 2 2         3 4   9
+--R           (- 13312a c  - 52224a b c  - 12992a b c)x
+--R         + 
+--R                    5   2         4 3   8            6 2         5 2   7
+--R           (- 51200a b c  - 33792a b c)x  + (- 18432a c  - 45568a b c)x
+--R         + 
+--R                   6     6        7   5
+--R           - 30720a b c x  - 8192a c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                3 5       2 2 4         4 3     6 2  14
+--R           (128a c  + 480a b c  + 120a b c  + 2b c )x
+--R         + 
+--R                 3   4        2 3 3         5 2     7   13
+--R           (2880a b c  + 2960a b c  + 348a b c  + 3b c)x
+--R         + 
+--R                 4 4         3 2 3        2 4 2         6     8  12
+--R           (3328a c  + 16000a b c  + 6240a b c  + 328a b c + b )x
+--R         + 
+--R                  4   3         3 3 2        2 5         7  11
+--R           (28992a b c  + 34960a b c  + 5436a b c + 99a b )x
+--R         + 
+--R                  5 3         4 2 2         3 4         2 6  10
+--R           (16512a c  + 81888a b c  + 32760a b c + 1666a b )x
+--R         + 
+--R                  5   2         4 3          3 5  9
+--R           (84480a b c  + 92672a b c + 10976a b )x
+--R         + 
+--R                  6 2          5 2          4 4  8          6            5 3  7
+--R           (31744a c  + 133632a b c + 36288a b )x  + (95232a b c + 66304a b )x
+--R         + 
+--R                  7          6 2  6         7   5        8 4
+--R           (26624a c + 68096a b )x  + 36864a b x  + 8192a x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                2   5         3 4      5 3  14
+--R           (384a b c  + 320a b c  + 24b c )x
+--R         + 
+--R                3 5        2 2 4          4 3      6 2  13
+--R           (896a c  + 3936a b c  + 1320a b c  + 50b c )x
+--R         + 
+--R                  3   4         2 3 3          5 2      7   12
+--R           (10880a b c  + 12384a b c  + 1752a b c  + 26b c)x
+--R         + 
+--R                 4 4         3 2 3         2 4 2         6   11
+--R           (8064a c  + 39264a b c  + 15336a b c  + 754a b c)x
+--R         + 
+--R                  4   3         3 3 2        2 5   10
+--R           (49536a b c  + 54592a b c  + 6552a b c)x
+--R         + 
+--R                  5 3         4 2 2         3 4   9
+--R           (21504a c  + 92160a b c  + 25792a b c)x
+--R         + 
+--R                  5   2         4 3   8          6 2         5 2   7
+--R           (73728a b c  + 53248a b c)x  + (22528a c  + 59904a b c)x
+--R         + 
+--R                 6     6        7   5
+--R           34816a b c x  + 8192a c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                      2   5         3 4      5 3  11
+--R                 (384a b c  + 320a b c  + 24b c )x
+--R               + 
+--R                      3 5        2 2 4          4 3      6 2  10
+--R                 (896a c  + 4128a b c  + 1480a b c  + 62b c )x
+--R               + 
+--R                        3   4         2 3 3          5 2      7   9
+--R                 (11776a b c  + 14912a b c  + 2496a b c  + 52b c)x
+--R               + 
+--R                       4 4         3 2 3         2 4 2          6       8  8
+--R                 (8960a c  + 49856a b c  + 24048a b c  + 1812a b c + 14b )x
+--R               + 
+--R                        4   3         3 3 2         2 5          7  7
+--R                 (65664a b c  + 92032a b c  + 17832a b c + 476a b )x
+--R               + 
+--R                        5 3          4 2 2         3 4         2 6  6
+--R                 (29568a c  + 164640a b c  + 77000a b c + 4942a b )x
+--R               + 
+--R                         5   2          4 3          3 5  5
+--R                 (138240a b c  + 171008a b c + 23872a b )x
+--R               + 
+--R                        6 2          5 2          4 4  4
+--R                 (44032a c  + 204288a b c + 62912a b )x
+--R               + 
+--R                         6            5 3  3          7          6 2  2
+--R                 (124928a b c + 96256a b )x  + (30720a c + 85504a b )x
+--R               + 
+--R                       7           8
+--R                 40960a b x + 8192a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                  3 6       2 2 5         4 4     6 3  11
+--R             (128a c  + 480a b c  + 120a b c  + 2b c )x
+--R           + 
+--R                   3   5        2 3 4         5 3     7 2  10
+--R             (2944a b c  + 3200a b c  + 408a b c  + 4b c )x
+--R           + 
+--R                   4 5         3 2 4        2 4 3         6 2     8   9
+--R             (3328a c  + 17216a b c  + 7440a b c  + 460a b c  + 2b c)x
+--R           + 
+--R                    4   4         3 3 3        2 5 2         7   8
+--R             (30208a b c  + 40384a b c  + 7296a b c  + 172a b c)x
+--R           + 
+--R                    5 4         4 2 3         3 4 2        2 6   7
+--R             (16512a c  + 90336a b c  + 41336a b c  + 2578a b c)x
+--R           + 
+--R                    5   3          4 3 2         3 5   6
+--R             (88704a b c  + 109760a b c  + 15400a b c)x
+--R           + 
+--R                    6 3          5 2 2         4 4   5
+--R             (31744a c  + 148992a b c  + 46784a b c)x
+--R           + 
+--R                     6   2         5 3   4          7 2         6 2   3
+--R             (100352a b c  + 79360a b c)x  + (26624a c  + 76288a b c)x
+--R           + 
+--R                   7     2        8
+--R             38912a b c x  + 8192a c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    3 6       2 2 5         4 4     6 3  12
+--R             (- 128a c  - 480a b c  - 120a b c  - 2b c )x
+--R           + 
+--R                     3   5        2 3 4         5 3     7 2  11
+--R             (- 3008a b c  - 3440a b c  - 468a b c  - 5b c )x
+--R           + 
+--R                     4 5         3 2 4        2 4 3         6 2     8   10
+--R             (- 3456a c  - 19360a b c  - 9320a b c  - 678a b c  - 4b c)x
+--R           + 
+--R                      4   4         3 3 3         2 5 2         7     9  9
+--R             (- 35200a b c  - 53920a b c  - 12024a b c  - 430a b c - b )x
+--R           + 
+--R                      5 4          4 2 3         3 4 2        2 6          8  8
+--R             (- 19840a c  - 126880a b c  - 73960a b c  - 7430a b c - 100a b )x
+--R           + 
+--R                       5   3          4 3 2         3 5         2 7  7
+--R             (- 129984a b c  - 209520a b c  - 49172a b c - 1765a b )x
+--R           + 
+--R                      6 3          5 2 2          4 4          3 6  6
+--R             (- 48256a c  - 300000a b c  - 161720a b c - 12642a b )x
+--R           + 
+--R                       6   2          5 3          4 5  5
+--R             (- 211456a b c  - 292608a b c - 47264a b )x
+--R           + 
+--R                      7 2          6 2           5 4  4
+--R             (- 58368a c  - 296960a b c - 102592a b )x
+--R           + 
+--R                       7             6 3  3            8           7 2  2
+--R             (- 158720a b c - 134400a b )x  + (- 34816a c - 104960a b )x
+--R           + 
+--R                     8           9
+--R             - 45056a b x - 8192a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                    2   6         3 5      5 4  12
+--R             (- 384a b c  - 320a b c  - 24b c )x
+--R           + 
+--R                    3 6        2 2 5          4 4      6 3  11
+--R             (- 896a c  - 4320a b c  - 1640a b c  - 74b c )x
+--R           + 
+--R                      3   5         2 3 4          5 3      7 2  10
+--R             (- 12160a b c  - 16640a b c  - 3096a b c  - 76b c )x
+--R           + 
+--R                     4 5         3 2 4         2 4 3          6 2      8   9
+--R             (- 8960a c  - 54080a b c  - 29040a b c  - 2556a b c  - 26b c)x
+--R           + 
+--R                      4   4          3 3 3         2 5 2         7   8
+--R             (- 68480a b c  - 106240a b c  - 23640a b c  - 780a b c)x
+--R           + 
+--R                      5 4          4 2 3         3 4 2        2 6   7
+--R             (- 29568a c  - 180960a b c  - 95720a b c  - 7306a b c)x
+--R           + 
+--R                       5   3          4 3 2         3 5   6
+--R             (- 144768a b c  - 200000a b c  - 32344a b c)x
+--R           + 
+--R                      6 3          5 2 2         4 4   5
+--R             (- 44032a c  - 225792a b c  - 79040a b c)x
+--R           + 
+--R                       6   2          5 3   4            7 2         6 2   3
+--R             (- 131072a b c  - 113152a b c)x  + (- 30720a c  - 94720a b c)x
+--R           + 
+--R                     7     2        8
+--R             - 43008a b c x  - 8192a c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       2 2      4   4         2   2        3       5  3
+--R               (- 48a b c  + 12b c)x  + (- 96a b c  - 24a b c + 12b )x
+--R             + 
+--R                      2 2         4  2         3         2 3
+--R               (- 144a b c + 36a b )x  + (- 96a b c + 24a b )x
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- c \|a \|c x  + b x + a
+--R         + 
+--R                   2   3     5   5        2 2 2        4      6  4
+--R               (48a b c  - 3b c)x  + (144a b c  - 24a b c - 3b )x
+--R             + 
+--R                    3   2      2 3         5  3        3 2       2 4  2
+--R               (144a b c  + 72a b c - 27a b )x  + (192a b c - 48a b )x
+--R             + 
+--R                   4         3 3
+--R               (96a b c - 24a b )x
+--R          *
+--R              +---+
+--R             \|- c
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                    2   2     5  2          2 2         4         3         2 3
+--R             ((- 96a b c  + 6b )x  + (- 192a b c + 48a b )x - 192a b c + 48a b )
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                     2 2      4   3        2   2        3       5  2
+--R               (96a b c  - 24b c)x  + (192a b c  + 48a b c - 24b )x
+--R             + 
+--R                    2 2         4         3         2 3
+--R               (288a b c - 72a b )x + 192a b c - 48a b
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                         2     3   3           2       4  2
+--R               (- 32a b c  + 8b c)x  + (- 72a b c + 18b )x
+--R             + 
+--R                     2           3
+--R               (- 96a b c + 24a b )x
+--R          *
+--R                            +--------------+
+--R              +---+ +-+ +-+ |   2
+--R             \|- c \|a \|c \|c x  + b x + a
+--R         + 
+--R                   2 3     4   4       2   2       3      5  3
+--R               (32a c  - 2b c)x  + (80a b c  + 4a b c - 6b )x
+--R             + 
+--R                    2 2         4  2       3         2 3
+--R               (120a b c - 30a b )x  + (96a b c - 24a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 2 3     4   5          2   2        3      5  4
+--R           (- 32a c  + 2b c)x  + (- 144a b c  + 20a b c + 6b )x
+--R         + 
+--R                  3 2       2 2         4  3          3         2 3  2
+--R           (- 128a c  - 136a b c + 54a b )x  + (- 288a b c + 96a b )x
+--R         + 
+--R                  4       3 2
+--R           (- 128a c + 48a b )x
+--R      *
+--R                    +--------------+
+--R          +---+ +-+ |   2
+--R         \|- c \|c \|c x  + b x + a
+--R     + 
+--R                   3     3 2  6       2 3        2 2      4   5
+--R           (32a b c  - 8b c )x  + (64a c  + 96a b c  - 32b c)x
+--R         + 
+--R                2   2        3       5  4        3 2       2 2         4  3
+--R           (320a b c  - 16a b c - 24b )x  + (192a c  + 240a b c - 96a b )x
+--R         + 
+--R                3          2 3  2        4       3 2
+--R           (352a b c - 120a b )x  + (128a c - 48a b )x
+--R      *
+--R          +---+ +-+ +-+
+--R         \|- c \|a \|c
+--R  /
+--R                2 4     4 2  2       2   3        3 2        3 3      2 2 2
+--R           ((32a c  - 2b c )x  + (64a b c  - 16a b c )x + 64a c  - 16a b c )
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- c \|c \|c x  + b x + a
+--R       + 
+--R                       4     3 3  3         2 4        2 3     4 2  2
+--R             (- 32a b c  + 8b c )x  + (- 64a c  - 16a b c  + 8b c )x
+--R           + 
+--R                   2   3        3 2        3 3      2 2 2
+--R             (- 96a b c  + 24a b c )x - 64a c  + 16a b c
+--R        *
+--R            +---+ +-+ +-+
+--R           \|- c \|a \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                             3  6         2         2  5       2   4       3 3
+--R             ((- 32a b c - 8b )x  + (- 64a c - 80a b )x  - 192a b x  - 128a x )
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               2 2        2     4  7        2           3  6
+--R           (16a c  + 24a b c + b )x  + (128a b c + 32a b )x
+--R         + 
+--R                3        2 2  5       3   4       4 3
+--R           (128a c + 160a b )x  + 256a b x  + 128a x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 2 2        2     4  8          2           3  7
+--R           (- 16a c  - 24a b c - b )x  + (- 128a b c - 32a b )x
+--R         + 
+--R                  3        2 2  6       3   5       4 4
+--R           (- 128a c - 160a b )x  - 256a b x  - 128a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   2     3   9       2 2         2      4  8
+--R           (32a b c  + 8b c)x  + (64a c  + 112a b c + 8b )x
+--R         + 
+--R                2           3  7        3        2 2  6       3   5       4 4
+--R           (288a b c + 88a b )x  + (192a c + 272a b )x  + 320a b x  + 128a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 2 3        2 2    4   6        2   2        3     5  5
+--R             (16a c  + 24a b c  + b c)x  + (144a b c  + 56a b c + b )x
+--R           + 
+--R                  3 2       2 2         4  4        3          2 3  3
+--R             (144a c  + 312a b c + 33a b )x  + (512a b c + 192a b )x
+--R           + 
+--R                  4        3 2  2       4          5
+--R             (256a c + 416a b )x  + 384a b x + 128a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                       3     3 2  7         2 3         2 2      4   6
+--R             (- 32a b c  - 8b c )x  + (- 64a c  - 144a b c  - 16b c)x
+--R           + 
+--R                    2   2         3      5  5
+--R             (- 384a b c  - 208a b c - 8b )x
+--R           + 
+--R                    3 2       2 2         4  4          3          2 3  3
+--R             (- 256a c  - 672a b c - 96a b )x  + (- 800a b c - 360a b )x
+--R           + 
+--R                    4        3 2  2       4          5
+--R             (- 320a c - 592a b )x  - 448a b x - 128a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 704
+t0:=x^5/(a*x^2+b*x^3+c*x^4)^(3/2)
+--R 
+--R
+--R                           3
+--R                          x
+--R   (1)  -------------------------------------
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 704
+r0:=2*x^2*(2*a+b*x)/((b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (c^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))-2*b*sqrt(a*x^2+b*x^3+c*x^4)/_
+   (c*(b^2-4*a*c)*x)
+--R 
+--R
+--R   (2)
+--R                    +--------------+
+--R                2   |   2                        2c x + b
+--R       (4a c - b )x\|c x  + b x + a atanh(----------------------)
+--R                                                +--------------+
+--R                                            +-+ |   2
+--R                                          2\|c \|c x  + b x + a
+--R     + 
+--R                    2  2           +-+
+--R       ((- 4a c + 2b )x  + 2a b x)\|c
+--R  /
+--R                       +------------------+
+--R          2    2   +-+ |   4      3      2
+--R     (4a c  - b c)\|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                           +--------------+
+--R                       +-+ |   2                    2              2
+--R           ((b x + 2a)\|a \|c x  + b x + a  - 2a c x  - 2a b x - 2a )
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                       +-+
+--R                  2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                  +--------------+
+--R              +-+ |   2                     2         +-+ +-+
+--R         2a x\|c \|c x  + b x + a  + (- 2b x  - 2a x)\|a \|c
+--R    /
+--R                                +--------------+
+--R                        +-+ +-+ |   2
+--R         (b c x + 2a c)\|a \|c \|c x  + b x + a
+--R       + 
+--R                2 2                2   +-+
+--R         (- 2a c x  - 2a b c x - 2a c)\|c
+--R     ,
+--R
+--R                            +--------------+
+--R                        +-+ |   2                    2              2
+--R           ((2b x + 4a)\|a \|c x  + b x + a  - 4a c x  - 4a b x - 4a )
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                    +--------------+
+--R              +---+ |   2                     2         +---+ +-+
+--R         2a x\|- c \|c x  + b x + a  + (- 2b x  - 2a x)\|- c \|a
+--R    /
+--R                                  +--------------+
+--R                        +---+ +-+ |   2
+--R         (b c x + 2a c)\|- c \|a \|c x  + b x + a
+--R       + 
+--R                2 2                2   +---+
+--R         (- 2a c x  - 2a b c x - 2a c)\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 357
+
+--S 358 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                               +--------------+
+--R                       3       2        2  +-+ |   2
+--R           ((4a b c - b )x + 8a c - 2a b )\|a \|c x  + b x + a
+--R         + 
+--R                2 2       2   2        2          3       3      2 2
+--R           (- 8a c  + 2a b c)x  + (- 8a b c + 2a b )x - 8a c + 2a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  - 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                     +-+
+--R                2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                 2 2       2   3      2          3  2      3      2 2
+--R             ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x)
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        2    3   4        2 2       2     4  3
+--R               (- 4a b c  + b c)x  + (- 8a c  - 2a b c + b )x
+--R             + 
+--R                     2          3  2        3      2 2
+--R               (- 12a b c + 3a b )x  + (- 8a c + 2a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                               +--------------+
+--R              2        2   +-+ |   2
+--R           (8a c - 2a b )x\|c \|c x  + b x + a
+--R         + 
+--R                          3  2        2        2    +-+ +-+
+--R           ((- 8a b c + 2b )x  + (- 8a c + 2a b )x)\|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                                              +--------------+
+--R                    3  3      2        2  2     2     +-+ +-+ |   2
+--R       ((4a b c - 2b )x  + (8a c - 6a b )x  - 4a b x)\|a \|c \|c x  + b x + a
+--R     + 
+--R                2 2       2   4        2          3  3        3      2 2  2
+--R           (- 8a c  + 4a b c)x  + (- 4a b c + 4a b )x  + (- 8a c + 8a b )x
+--R         + 
+--R             3
+--R           4a b x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                                     +--------------+
+--R                 2    3        2 2       2   +-+ +-+ |   2
+--R         ((4a b c  - b c)x + 8a c  - 2a b c)\|a \|c \|c x  + b x + a
+--R       + 
+--R               2 3       2 2  2        2   2       3        3 2     2 2   +-+
+--R         ((- 8a c  + 2a b c )x  + (- 8a b c  + 2a b c)x - 8a c  + 2a b c)\|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                         2 3        2 2     4   8
+--R                   (- 32a c  - 48a b c  - 2b c)x
+--R                 + 
+--R                          2   2         3     5  7
+--R                   (- 336a b c  - 104a b c - b )x
+--R                 + 
+--R                          3 2       2 2         4  6           3          2 3  5
+--R                   (- 416a c  - 720a b c - 50a b )x  + (- 1472a b c - 400a b )x
+--R                 + 
+--R                          4         3 2  4        4   3       5 2
+--R                   (- 896a c - 1120a b )x  - 1280a b x  - 512a x
+--R              *
+--R                  +-+
+--R                 \|c
+--R             + 
+--R                           3      3 2  8        2 3         2 2      4   7
+--R                   (64a b c  + 16b c )x  + (160a c  + 272a b c  + 18b c)x
+--R                 + 
+--R                        2   2         3   6        3 2       2 2   5
+--R                   (832a b c  + 240a b c)x  + (640a c  + 864a b c)x
+--R                 + 
+--R                        3     4       4   3
+--R                   1152a b c x  + 512a c x
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       3      3 2  9        2 3         2 2      4   8
+--R               (64a b c  + 16b c )x  + (160a c  + 304a b c  + 26b c)x
+--R             + 
+--R                    2   2         3       5  7
+--R               (992a b c  + 416a b c + 10b )x
+--R             + 
+--R                    3 2        2 2          4  6         3          2 3  5
+--R               (800a c  + 1680a b c + 170a b )x  + (2432a b c + 832a b )x
+--R             + 
+--R                     4         3 2  4        4   3       5 2
+--R               (1152a c + 1696a b )x  + 1536a b x  + 512a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R                 2 4        2 3     4 2  9          2   3         3 2     5   8
+--R           (- 32a c  - 48a b c  - 2b c )x  + (- 352a b c  - 128a b c  - 2b c)x
+--R         + 
+--R                  3 3       2 2 2        4   7           3   2       2 3   6
+--R           (- 416a c  - 848a b c  - 82a b c)x  + (- 1600a b c  - 560a b c)x
+--R         + 
+--R                  4 2        3 2   5        4     4       5   3
+--R           (- 896a c  - 1376a b c)x  - 1408a b c x  - 512a c x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                         3      3 2  10          2 3         2 2      4   9
+--R               (- 64a b c  - 16b c )x   + (- 160a c  - 304a b c  - 26b c)x
+--R             + 
+--R                      2   2         3       5  8
+--R               (- 992a b c  - 416a b c - 10b )x
+--R             + 
+--R                      3 2        2 2          4  7           3          2 3  6
+--R               (- 800a c  - 1680a b c - 170a b )x  + (- 2432a b c - 832a b )x
+--R             + 
+--R                       4         3 2  5        4   4       5 3
+--R               (- 1152a c - 1696a b )x  - 1536a b x  - 512a x
+--R          *
+--R              +-+ +-+
+--R             \|a \|c
+--R         + 
+--R               2 4        2 3     4 2  10        2   3         3 2     5   9
+--R           (32a c  + 48a b c  + 2b c )x   + (352a b c  + 128a b c  + 2b c)x
+--R         + 
+--R                3 3       2 2 2        4   8         3   2       2 3   7
+--R           (416a c  + 848a b c  + 82a b c)x  + (1600a b c  + 560a b c)x
+--R         + 
+--R                4 2        3 2   6        4     5       5   4
+--R           (896a c  + 1376a b c)x  + 1408a b c x  + 512a c x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R               2 4        2 3     4 2  11        2   3         3 2     5   10
+--R           (32a c  + 48a b c  + 2b c )x   + (368a b c  + 152a b c  + 3b c)x
+--R         + 
+--R                3 3        2 2 2         4     6  9
+--R           (448a c  + 1104a b c  + 156a b c + b )x
+--R         + 
+--R                 3   2        2 3         5  8
+--R           (2224a b c  + 1224a b c + 51a b )x
+--R         + 
+--R                 4 2        3 2        2 4  7         4           3 3  6
+--R           (1312a c  + 3312a b c + 450a b )x  + (3648a b c + 1520a b )x
+--R         + 
+--R                 5         4 2  5        5   4       6 3
+--R           (1408a c + 2400a b )x  + 1792a b x  + 512a x
+--R      *
+--R          +-+
+--R         \|c
+--R     + 
+--R                     4      3 3  11          2 4         2 3      4 2  10
+--R           (- 64a b c  - 16b c )x   + (- 160a c  - 336a b c  - 34b c )x
+--R         + 
+--R                   2   3         3 2      5   9
+--R           (- 1056a b c  - 528a b c  - 18b c)x
+--R         + 
+--R                  3 3        2 2 2         4   8           3   2        2 3   7
+--R           (- 800a c  - 1968a b c  - 258a b c)x  + (- 2624a b c  - 1104a b c)x
+--R         + 
+--R                   4 2        3 2   6        4     5       5   4
+--R           (- 1152a c  - 2016a b c)x  - 1664a b c x  - 512a c x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                         4      3 3  9        2 4         2 3      4 2  8
+--R                 (64a b c  + 16b c )x  + (160a c  + 368a b c  + 42b c )x
+--R               + 
+--R                       2   3         3 2      5   7
+--R                 (1216a b c  + 736a b c  + 36b c)x
+--R               + 
+--R                      3 3        2 2 2         4       6  6
+--R                 (960a c  + 2976a b c  + 612a b c + 10b )x
+--R               + 
+--R                       3   2        2 3          5  5
+--R                 (4224a b c  + 2928a b c + 180a b )x
+--R               + 
+--R                       4 2        3 2         2 4  4         4           3 3  3
+--R                 (1952a c  + 5808a b c + 1002a b )x  + (5120a b c + 2528a b )x
+--R               + 
+--R                       5         4 2  2        5          6
+--R                 (1664a c + 3232a b )x  + 2048a b x + 512a
+--R            *
+--R                +-+ +-+
+--R               \|a \|c
+--R           + 
+--R                   2 5        2 4     4 3  9
+--R             (- 32a c  - 48a b c  - 2b c )x
+--R           + 
+--R                    2   4         3 3     5 2  8
+--R             (- 384a b c  - 176a b c  - 4b c )x
+--R           + 
+--R                    3 4        2 2 3         4 2     6   7
+--R             (- 448a c  - 1248a b c  - 212a b c  - 2b c)x
+--R           + 
+--R                     3   3        2 3 2        5   6
+--R             (- 2368a b c  - 1536a b c  - 84a b c)x
+--R           + 
+--R                     4 3        3 2 2       2 4   5
+--R             (- 1312a c  - 3824a b c  - 642a b c)x
+--R           + 
+--R                     4   2        3 3   4           5 2        4 2   3
+--R             (- 3904a b c  - 1936a b c)x  + (- 1408a c  - 2784a b c)x
+--R           + 
+--R                    5     2       6
+--R             - 1920a b c x  - 512a c x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   2 5        2 4     4 3  10
+--R             (- 32a c  - 48a b c  - 2b c )x
+--R           + 
+--R                    2   4         3 3     5 2  9
+--R             (- 400a b c  - 200a b c  - 5b c )x
+--R           + 
+--R                    3 4        2 2 3         4 2     6   8
+--R             (- 480a c  - 1520a b c  - 310a b c  - 4b c)x
+--R           + 
+--R                     3   3        2 3 2         5     7  7
+--R             (- 3040a b c  - 2480a b c  - 210a b c - b )x
+--R           + 
+--R                     4 3        3 2 2        2 4         6  6
+--R             (- 1760a c  - 6640a b c  - 1830a b c - 52a b )x
+--R           + 
+--R                     4   2        3 3        2 5  5
+--R             (- 7184a b c  - 6056a b c - 501a b )x
+--R           + 
+--R                     5 2        4 2         3 4  4           5           4 3  3
+--R             (- 2720a c  - 9360a b c - 1970a b )x  + (- 6848a b c - 3920a b )x
+--R           + 
+--R                     6         5 2  2        6          7
+--R             (- 1920a c - 4192a b )x  - 2304a b x - 512a
+--R        *
+--R            +-+
+--R           \|c
+--R       + 
+--R                     5      3 4  10        2 5         2 4      4 3  9
+--R             (64a b c  + 16b c )x   + (160a c  + 400a b c  + 50b c )x
+--R           + 
+--R                   2   4         3 3      5 2  8
+--R             (1280a b c  + 880a b c  + 52b c )x
+--R           + 
+--R                  3 4        2 2 3         4 2      6   7
+--R             (960a c  + 3360a b c  + 820a b c  + 18b c)x
+--R           + 
+--R                   3   3        2 3 2         5   6
+--R             (4480a b c  + 3600a b c  + 276a b c)x
+--R           + 
+--R                   4 3        3 2 2        2 4   5         4   2        3 3   4
+--R             (1952a c  + 6608a b c  + 1362a b c)x  + (5440a b c  + 3120a b c)x
+--R           + 
+--R                   5 2        4 2   3        5     2       6
+--R             (1664a c  + 3680a b c)x  + 2176a b c x  + 512a c x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                 2 2       2   3      2          3  2      3      2 2    +---+
+--R             ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x)\|- c
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        2    3   4        2 2       2     4  3
+--R               (- 4a b c  + b c)x  + (- 8a c  - 2a b c + b )x
+--R             + 
+--R                     2          3  2        3      2 2
+--R               (- 12a b c + 3a b )x  + (- 8a c + 2a b )x
+--R          *
+--R              +---+ +-+
+--R             \|- c \|a
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                                                     +--------------+
+--R                        3        2        2  +-+ +-+ |   2
+--R           ((8a b c - 2b )x + 16a c - 4a b )\|a \|c \|c x  + b x + a
+--R         + 
+--R                  2 2       2   2         2          3        3      2 2  +-+
+--R           ((- 16a c  + 4a b c)x  + (- 16a b c + 4a b )x - 16a c + 4a b )\|c
+--R      *
+--R                                          +--------------+
+--R          +------------------+      +---+ |   2               +---+ +-+
+--R          |   4      3      2      \|- c \|c x  + b x + a  - \|- c \|a
+--R         \|c x  + b x  + a x  atan(------------------------------------)
+--R                                                    c x
+--R     + 
+--R                                     +--------------+
+--R              2        2   +---+ +-+ |   2
+--R           (8a c - 2a b )x\|- c \|c \|c x  + b x + a
+--R         + 
+--R                          3  2        2        2    +---+ +-+ +-+
+--R           ((- 8a b c + 2b )x  + (- 8a c + 2a b )x)\|- c \|a \|c
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      3  3      2        2  2     2     +---+ +-+ +-+
+--R         ((4a b c - 2b )x  + (8a c - 6a b )x  - 4a b x)\|- c \|a \|c
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                2 2       2   4        2          3  3        3      2 2  2
+--R           (- 8a c  + 4a b c)x  + (- 4a b c + 4a b )x  + (- 8a c + 8a b )x
+--R         + 
+--R             3
+--R           4a b x
+--R      *
+--R          +---+ +-+
+--R         \|- c \|c
+--R  /
+--R                                                           +--------------+
+--R                 2    3        2 2       2   +---+ +-+ +-+ |   2
+--R         ((4a b c  - b c)x + 8a c  - 2a b c)\|- c \|a \|c \|c x  + b x + a
+--R       + 
+--R                 2 3       2 2  2        2   2       3        3 2     2 2
+--R           ((- 8a c  + 2a b c )x  + (- 8a b c  + 2a b c)x - 8a c  + 2a b c)
+--R        *
+--R            +---+ +-+
+--R           \|- c \|c
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 360
+
+--S 361 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                 +--------------+
+--R                  3       2  +-+ |   2                       2  4         3
+--R           (- 4b x  - 8a x )\|a \|c x  + b x + a  + (4a c + b )x  + 8a b x
+--R         + 
+--R             2 2
+--R           8a x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                           +--------------+
+--R                   2  5         4     2 3  |   2
+--R       ((- 4a c - b )x  - 8a b x  - 8a x )\|c x  + b x + a
+--R     + 
+--R              6             2  5          4     2 3  +-+
+--R       (4b c x  + (8a c + 4b )x  + 12a b x  + 8a x )\|a
+--R  /
+--R                  2    2   4               3  3       2        2  2      2
+--R             (4a c  + b c)x  + (12a b c + b )x  + (12a c + 9a b )x  + 16a b x
+--R           + 
+--R               3
+--R             8a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   2 5          2     2   4                  3  3
+--R             - 4b c x  + (- 8a c  - 8b c)x  + (- 24a b c - 4b )x
+--R           + 
+--R                   2         2  2      2        3
+--R             (- 16a c - 16a b )x  - 20a b x - 8a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 361
+
+)clear all
+
+--S 362 of 704
+t0:=x^4/(a*x^2+b*x^3+c*x^4)^(3/2)
+--R 
+--R
+--R                           2
+--R                          x
+--R   (1)  -------------------------------------
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 704
+r0:=2*x*(2*a+b*x)/((b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))
+--R 
+--R
+--R                       2
+--R                 - 2b x  - 4a x
+--R   (2)  --------------------------------
+--R                    +------------------+
+--R                 2  |   4      3      2
+--R        (4a c - b )\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 363
+
+--S 364 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   2 +-+
+--R                                 2x \|a
+--R   (3)  --------------------------------------------------------
+--R                       +--------------+
+--R                   +-+ |   2                    2              2
+--R        (b x + 2a)\|a \|c x  + b x + a  - 2a c x  - 2a b x - 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 364
+
+--S 365 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +------------------+
+--R                 2  2 +-+ |   4      3      2
+--R       (8a c - 2b )x \|a \|c x  + b x  + a x
+--R     + 
+--R                                    +--------------+
+--R          2 3         2     2   +-+ |   2                      4
+--R       (2b x  + 8a b x  + 8a x)\|a \|c x  + b x + a  - 4a b c x
+--R     + 
+--R            2        2  3      2   2     3
+--R       (- 8a c - 4a b )x  - 12a b x  - 8a x
+--R  /
+--R                                             +--------------+
+--R                     3       2        2  +-+ |   2
+--R         ((4a b c - b )x + 8a c - 2a b )\|a \|c x  + b x + a
+--R       + 
+--R              2 2       2   2        2          3       3      2 2
+--R         (- 8a c  + 2a b c)x  + (- 8a b c + 2a b )x - 8a c + 2a b
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                  +--------------+
+--R                    2         +-+ |   2                       2  3         2
+--R             (- 4b x  - 8a x)\|a \|c x  + b x + a  + (4a c + b )x  + 8a b x
+--R           + 
+--R               2
+--R             8a x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                           +--------------+
+--R                   2  4         3     2 2  |   2
+--R       ((- 4a c - b )x  - 8a b x  - 8a x )\|c x  + b x + a
+--R     + 
+--R              5             2  4          3     2 2  +-+
+--R       (4b c x  + (8a c + 4b )x  + 12a b x  + 8a x )\|a
+--R  /
+--R                  2    2   4               3  3       2        2  2      2
+--R             (4a c  + b c)x  + (12a b c + b )x  + (12a c + 9a b )x  + 16a b x
+--R           + 
+--R               3
+--R             8a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   2 5          2     2   4                  3  3
+--R             - 4b c x  + (- 8a c  - 8b c)x  + (- 24a b c - 4b )x
+--R           + 
+--R                   2         2  2      2        3
+--R             (- 16a c - 16a b )x  - 20a b x - 8a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 704
+t0:=x^3/(a*x^2+b*x^3+c*x^4)^(3/2)
+--R 
+--R
+--R                          x
+--R   (1)  -------------------------------------
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 704
+r0:=-2*x*(b+2*c*x)/((b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))
+--R 
+--R
+--R                      2
+--R                  4c x  + 2b x
+--R   (2)  --------------------------------
+--R                    +------------------+
+--R                 2  |   4      3      2
+--R        (4a c - b )\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          +--------------+
+--R                          |   2                 +-+
+--R                     - 2x\|c x  + b x + a  + 2x\|a
+--R   (3)  --------------------------------------------------------
+--R                       +--------------+
+--R                   +-+ |   2                    2              2
+--R        (b x + 2a)\|a \|c x  + b x + a  - 2a c x  - 2a b x - 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 369
+
+--S 370 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +--------------+
+--R                      2   |   2                        2   +-+
+--R         ((- 8a c + 2b )x\|c x  + b x + a  + (8a c - 2b )x\|a )
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                                   +--------------+
+--R                3               2  2           +-+ |   2                  2 4
+--R       (- 4b c x  + (- 8a c - 2b )x  - 4a b x)\|a \|c x  + b x + a  + 8a c x
+--R     + 
+--R                3      2        2  2     2
+--R       12a b c x  + (8a c + 4a b )x  + 4a b x
+--R  /
+--R                                             +--------------+
+--R                     3       2        2  +-+ |   2
+--R         ((4a b c - b )x + 8a c - 2a b )\|a \|c x  + b x + a
+--R       + 
+--R              2 2       2   2        2          3       3      2 2
+--R         (- 8a c  + 2a b c)x  + (- 8a b c + 2a b )x - 8a c + 2a b
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                            +--------------+
+--R                        +-+ |   2                       2  2              2
+--R         ((- 4b x - 8a)\|a \|c x  + b x + a  + (4a c + b )x  + 8a b x + 8a )
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                          +--------------+
+--R                   2  3         2     2   |   2
+--R       ((- 4a c - b )x  - 8a b x  - 8a x)\|c x  + b x + a
+--R     + 
+--R              4             2  3          2     2   +-+
+--R       (4b c x  + (8a c + 4b )x  + 12a b x  + 8a x)\|a
+--R  /
+--R                  2    2   4               3  3       2        2  2      2
+--R             (4a c  + b c)x  + (12a b c + b )x  + (12a c + 9a b )x  + 16a b x
+--R           + 
+--R               3
+--R             8a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   2 5          2     2   4                  3  3
+--R             - 4b c x  + (- 8a c  - 8b c)x  + (- 24a b c - 4b )x
+--R           + 
+--R                   2         2  2      2        3
+--R             (- 16a c - 16a b )x  - 20a b x - 8a
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+)clear all
+
+--S 372 of 704
+t0:=x^2/(a*x^2+b*x^3+c*x^4)^(3/2)
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R                         +------------------+
+--R            2            |   4      3      2
+--R        (c x  + b x + a)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 372
+
+--S 373 of 704
+r0:=2*x*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))-_
+   x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (a^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))
+--R 
+--R
+--R   (2)
+--R                      +--------------+
+--R                  2   |   2                        b x + 2a
+--R       (- 4a c + b )x\|c x  + b x + a atanh(----------------------)
+--R                                                  +--------------+
+--R                                              +-+ |   2
+--R                                            2\|a \|c x  + b x + a
+--R     + 
+--R                2             2    +-+
+--R       (- 2b c x  + (4a c - 2b )x)\|a
+--R  /
+--R                       +------------------+
+--R        2       2  +-+ |   4      3      2
+--R     (4a c - a b )\|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +--------------+
+--R                     |   2                     2              +-+
+--R         ((b x + 2a)\|c x  + b x + a  + (- 2c x  - 2b x - 2a)\|a )
+--R      *
+--R                   +--------------+
+--R               +-+ |   2
+--R             2\|a \|c x  + b x + a  - b x - 2a
+--R         log(---------------------------------)
+--R                              +-+
+--R                           2x\|a
+--R     + 
+--R            +--------------+
+--R            |   2                     2         +-+
+--R       2b x\|c x  + b x + a  + (- 2c x  - 2b x)\|a
+--R  /
+--R                       +--------------+
+--R                2  +-+ |   2                2   2     2        3
+--R     (a b x + 2a )\|a \|c x  + b x + a  - 2a c x  - 2a b x - 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 374
+
+--S 375 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +--------------+
+--R                       3       2        2  +-+ |   2
+--R           ((4a b c - b )x + 8a c - 2a b )\|a \|c x  + b x + a
+--R         + 
+--R                2 2       2   2        2          3       3      2 2
+--R           (- 8a c  + 2a b c)x  + (- 8a b c + 2a b )x - 8a c + 2a b
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                   2 2       2   3        2          3  2        3      2 2
+--R             ((- 8a c  + 2a b c)x  + (- 8a b c + 2a b )x  + (- 8a c + 2a b )x)
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      2    3   4      2 2       2     4  3       2          3  2
+--R               (4a b c  - b c)x  + (8a c  + 2a b c - b )x  + (12a b c - 3a b )x
+--R             + 
+--R                  3      2 2
+--R               (8a c - 2a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                               +--------------+
+--R                       3   +-+ |   2                   2 2       2   2
+--R           (8a b c - 2b )x\|a \|c x  + b x + a  + (- 8a c  + 2a b c)x
+--R         + 
+--R                2          3
+--R           (- 8a b c + 2a b )x
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                                 +--------------+
+--R            2   3       3 2        3      2 2    |   2
+--R       (2a b c x  + 2a b x  + (- 8a c + 4a b )x)\|c x  + b x + a
+--R     + 
+--R                     2 4      2 2       2   3      2          3  2
+--R             - 4a b c x  + (8a c  - 8a b c)x  + (4a b c - 4a b )x
+--R           + 
+--R                3      2 2
+--R             (8a c - 4a b )x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                           +--------------+
+--R             3       2 3       4      3 2  |   2
+--R         ((4a b c - a b )x + 8a c - 2a b )\|c x  + b x + a
+--R       + 
+--R               3 2     2 2   2        3        2 3       4      3 2  +-+
+--R         ((- 8a c  + 2a b c)x  + (- 8a b c + 2a b )x - 8a c + 2a b )\|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 375
+
+--S 376 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                            +--------------+
+--R                        +-+ |   2                       2  2              2
+--R         ((- 4b x - 8a)\|a \|c x  + b x + a  + (4a c + b )x  + 8a b x + 8a )
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                                          +--------------+
+--R                   2  3         2     2   |   2
+--R       ((- 4a c - b )x  - 8a b x  - 8a x)\|c x  + b x + a
+--R     + 
+--R              4             2  3          2     2   +-+
+--R       (4b c x  + (8a c + 4b )x  + 12a b x  + 8a x)\|a
+--R  /
+--R                  2    2   5               3  4       2        2  3      2   2
+--R             (4a c  + b c)x  + (12a b c + b )x  + (12a c + 9a b )x  + 16a b x
+--R           + 
+--R               3
+--R             8a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   2 6          2     2   5                  3  4
+--R             - 4b c x  + (- 8a c  - 8b c)x  + (- 24a b c - 4b )x
+--R           + 
+--R                   2         2  3      2   2     3
+--R             (- 16a c - 16a b )x  - 20a b x  - 8a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+)clear all
+
+--S 377 of 704
+t0:=x/(a*x^2+b*x^3+c*x^4)^(3/2)
+--R 
+--R
+--R                            1
+--R   (1)  ----------------------------------------
+--R                            +------------------+
+--R            3      2        |   4      3      2
+--R        (c x  + b x  + a x)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 704
+r0:=2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   3/2*b*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+_
+   c*x^2)/(a^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))-(3*b^2-8*a*c)*sqrt(a*x^2+_
+   b*x^3+c*x^4)/(a^2*(b^2-4*a*c)*x^2)
+--R 
+--R
+--R   (2)
+--R                        +--------------+
+--R                    3   |   2                        b x + 2a
+--R       (12a b c - 3b )x\|c x  + b x + a atanh(----------------------)
+--R                                                    +--------------+
+--R                                                +-+ |   2
+--R                                              2\|a \|c x  + b x + a
+--R     + 
+--R                2     2   2                  3       2        2  +-+
+--R       ((- 16a c  + 6b c)x  + (- 20a b c + 6b )x - 8a c + 2a b )\|a
+--R  /
+--R                        +------------------+
+--R        3      2 2  +-+ |   4      3      2
+--R     (8a c - 2a b )\|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 378
+
+--S 379 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                          +--------------+
+--R                           3  3        2 2      2     +-+ |   2
+--R           ((- 24a b c - 6b )x  - 48a b x  - 48a b x)\|a \|c x  + b x + a
+--R         + 
+--R                2   4       2           3  3      2 2 2      3
+--R           24a b c x  + (48a b c + 24a b )x  + 72a b x  + 48a b x
+--R      *
+--R                   +--------------+
+--R               +-+ |   2
+--R             2\|a \|c x  + b x + a  - b x - 2a
+--R         log(---------------------------------)
+--R                              +-+
+--R                           2x\|a
+--R     + 
+--R                      3  3       2         2  2      2         3  +-+
+--R         ((4a b c - 9b )x  + (64a c - 24a b )x  + 40a b x + 32a )\|a
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R             2 2        2   4         2           3  3         3      2 2  2
+--R       (- 32a c  + 24a b c)x  + (- 48a b c + 24a b )x  + (- 80a c + 8a b )x
+--R     + 
+--R            3         4
+--R       - 56a b x - 32a
+--R  /
+--R                                              +--------------+
+--R            4      3 2  3      4   2      5   |   2
+--R       ((16a c + 4a b )x  + 32a b x  + 32a x)\|c x  + b x + a
+--R     + 
+--R             3     4         4       3 2  3      4   2      5   +-+
+--R       (- 16a b c x  + (- 32a c - 16a b )x  - 48a b x  - 32a x)\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 379
+
+--S 380 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     2   2     5  3          2 2         4  2
+--R               (- 96a b c  + 6b )x  + (- 192a b c + 48a b )x
+--R             + 
+--R                      3         2 3
+--R               (- 192a b c + 48a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                     2 2      4   4        2   2        3       5  3
+--R               (96a b c  - 24b c)x  + (192a b c  + 48a b c - 24b )x
+--R             + 
+--R                    2 2         4  2        3         2 3
+--R               (288a b c - 72a b )x  + (192a b c - 48a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                     2 2      4   5        2   2        3       5  4
+--R               (96a b c  - 24b c)x  + (192a b c  + 48a b c - 24b )x
+--R             + 
+--R                    2 2         4  3        3         2 3  2
+--R               (288a b c - 72a b )x  + (192a b c - 48a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                 2   3     5   6          2 2 2        4      6  5
+--R           (- 96a b c  + 6b c)x  + (- 288a b c  + 48a b c + 6b )x
+--R         + 
+--R                  3   2       2 3         5  4          3 2       2 4  3
+--R           (- 288a b c  - 144a b c + 54a b )x  + (- 384a b c + 96a b )x
+--R         + 
+--R                  4         3 3  2
+--R           (- 192a b c + 48a b )x
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                   2   2        3      5  3        3 2       2 2         4  2
+--R               (16a b c  - 40a b c + 9b )x  + (256a c  - 160a b c + 24a b )x
+--R             + 
+--R                    3         2 3         4       3 2
+--R               (160a b c - 40a b )x + 128a c - 32a b
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      2 3         2 2      4   4
+--R               (- 128a c  + 128a b c  - 24b c)x
+--R             + 
+--R                      2   2         3       5  3
+--R               (- 192a b c  + 144a b c - 24b )x
+--R             + 
+--R                      3 2       2 2        4  2          3         2 3
+--R               (- 320a c  + 112a b c - 8a b )x  + (- 224a b c + 56a b )x
+--R             + 
+--R                     4       3 2
+--R               - 128a c + 32a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                2 3        2 2      4   5        2   2         3       5  4
+--R           (128a c  - 16a b c  - 12b c)x  + (416a b c  - 104a b c - 12b )x
+--R         + 
+--R                3 2       2 2          4  3        3          2 3  2
+--R           (320a c  + 224a b c - 100a b )x  + (448a b c - 128a b )x
+--R         + 
+--R                4       3 2
+--R           (128a c - 32a b )x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R              2   3        3 2  6          3 3       2 2 2        4   5
+--R       (- 128a b c  + 48a b c )x  + (- 256a c  - 192a b c  + 96a b c)x
+--R     + 
+--R              3   2      2 3         5  4          4 2       3 2        2 4  3
+--R       (- 768a b c  + 96a b c + 48a b )x  + (- 384a c  - 416a b c + 160a b )x
+--R     + 
+--R              4          3 3  2          5       4 2
+--R       (- 512a b c + 144a b )x  + (- 128a c + 32a b )x
+--R  /
+--R                4 2     2 4  3        4         3 3  2        5       4 2    +-+
+--R           ((64a c  - 4a b )x  + (128a b c - 32a b )x  + (128a c - 32a b )x)\|a
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R               4   2      3 3   4          5 2      4 2       3 4  3
+--R         (- 64a b c  + 16a b c)x  + (- 128a c  - 32a b c + 16a b )x
+--R       + 
+--R                5         4 3  2          6       5 2
+--R         (- 192a b c + 48a b )x  + (- 128a c + 32a b )x
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                             3  3         2         2  2       2          3  +-+
+--R             ((- 32a b c - 8b )x  + (- 64a c - 80a b )x  - 192a b x - 128a )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R               2 2        2     4  4        2           3  3
+--R           (16a c  + 24a b c + b )x  + (128a b c + 32a b )x
+--R         + 
+--R                3        2 2  2       3          4
+--R           (128a c + 160a b )x  + 256a b x + 128a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 2 2        2     4  5          2           3  4
+--R           (- 16a c  - 24a b c - b )x  + (- 128a b c - 32a b )x
+--R         + 
+--R                  3        2 2  3       3   2       4
+--R           (- 128a c - 160a b )x  - 256a b x  - 128a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   2     3   6       2 2         2      4  5
+--R           (32a b c  + 8b c)x  + (64a c  + 112a b c + 8b )x
+--R         + 
+--R                2           3  4        3        2 2  3       3   2       4
+--R           (288a b c + 88a b )x  + (192a c + 272a b )x  + 320a b x  + 128a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 2 3        2 2    4   8        2   2        3     5  7
+--R             (16a c  + 24a b c  + b c)x  + (144a b c  + 56a b c + b )x
+--R           + 
+--R                  3 2       2 2         4  6        3          2 3  5
+--R             (144a c  + 312a b c + 33a b )x  + (512a b c + 192a b )x
+--R           + 
+--R                  4        3 2  4       4   3       5 2
+--R             (256a c + 416a b )x  + 384a b x  + 128a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                       3     3 2  9         2 3         2 2      4   8
+--R             (- 32a b c  - 8b c )x  + (- 64a c  - 144a b c  - 16b c)x
+--R           + 
+--R                    2   2         3      5  7
+--R             (- 384a b c  - 208a b c - 8b )x
+--R           + 
+--R                    3 2       2 2         4  6          3          2 3  5
+--R             (- 256a c  - 672a b c - 96a b )x  + (- 800a b c - 360a b )x
+--R           + 
+--R                    4        3 2  4       4   3       5 2
+--R             (- 320a c - 592a b )x  - 448a b x  - 128a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 704
+t0:=1/(a*x^2+b*x^3+c*x^4)^(3/2)
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R                             +------------------+
+--R            4      3      2  |   4      3      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 704
+r0:=2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x*sqrt(a*x^2+b*x^3+c*x^4))-_
+   3/8*(5*b^2-4*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(7/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/2*(5*b^2-12*a*c)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a^2*(b^2-4*a*c)*x^3)+1/4*b*(15*b^2-52*a*c)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a^3*(b^2-4*a*c)*x^2)
+--R 
+--R
+--R   (2)
+--R                                   +--------------+
+--R           2 2        2       4  2 |   2                        b x + 2a
+--R       (48a c  - 72a b c + 15b )x \|c x  + b x + a atanh(----------------------)
+--R                                                               +--------------+
+--R                                                           +-+ |   2
+--R                                                         2\|a \|c x  + b x + a
+--R     + 
+--R                    2      3   3         2 2         2       4  2
+--R           (104a b c  - 30b c)x  + (- 48a c  + 124a b c - 30b )x
+--R         + 
+--R               2           3        3      2 2
+--R           (40a b c - 10a b )x - 16a c + 4a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                          +------------------+
+--R         4      3 2   +-+ |   4      3      2
+--R     (32a c - 8a b )x\|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      2   2         3       5  5
+--R               (- 576a b c  + 672a b c + 60b )x
+--R             + 
+--R                       3 2       2 2           4  4           3           2 3  3
+--R               (- 1152a c  + 576a b c + 1080a b )x  + (- 2304a b c + 2880a b )x
+--R             + 
+--R                       4         3 2  2
+--R               (- 1536a c + 1920a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2 3         2 2       4   6
+--R               (384a c  - 192a b c  - 360b c)x
+--R             + 
+--R                     2   2          3        5  5
+--R               (1920a b c  - 2112a b c - 360b )x
+--R             + 
+--R                     3 2       2 2           4  4         3           2 3  3
+--R               (1920a c  - 576a b c - 2280a b )x  + (3072a b c - 3840a b )x
+--R             + 
+--R                     4         3 2  2
+--R               (1536a c - 1920a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +--------------+
+--R               +-+ |   2
+--R             2\|a \|c x  + b x + a  - b x - 2a
+--R         log(---------------------------------)
+--R                              +-+
+--R                           2x\|a
+--R     + 
+--R                   2   2         3       5  5
+--R           (- 1216a b c  + 228a b c + 79b )x
+--R         + 
+--R                  3 2        2 2          4  4           3          2 3  3
+--R           (- 384a c  - 2808a b c + 702a b )x  + (- 3648a b c - 288a b )x
+--R         + 
+--R                4         3 2  2       4          5
+--R           (640a c - 2496a b )x  - 768a b x + 512a
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                2 3         2 2       4   6         2   2         3        5  5
+--R           (256a c  + 872a b c  - 354b c)x  + (3200a b c  + 424a b c - 354b )x
+--R         + 
+--R                3 2        2 2          4  4         3           2 3  3
+--R           (128a c  + 5672a b c - 802a b )x  + (3840a b c + 1408a b )x
+--R         + 
+--R                  4         3 2  2       4          5
+--R           (- 896a c + 2944a b )x  + 512a b x - 512a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R               4         3 3  5        5        4 2  4        5   3        6 2
+--R         ((384a b c + 32a b )x  + (768a c + 576a b )x  + 1536a b x  + 1024a x )
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R              5 2       4 2   6           5          4 3  5
+--R       (- 256a c  - 192a b c)x  + (- 1280a b c - 192a b )x
+--R     + 
+--R               6         5 2  4        6   3        7 2
+--R       (- 1280a c - 1216a b )x  - 2048a b x  - 1024a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 384
+
+--S 385 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       3   3        2 3 2         5       7  5
+--R               (- 2304a b c  + 3264a b c  - 432a b c - 60b )x
+--R             + 
+--R                       4 3        3 2 2        2 4           6  4
+--R               (- 4608a c  + 3456a b c  + 3744a b c - 1080a b )x
+--R             + 
+--R                       4   2         3 3         2 5  3
+--R               (- 9216a b c  + 13824a b c - 2880a b )x
+--R             + 
+--R                       5 2        4 2         3 4  2
+--R               (- 6144a c  + 9216a b c - 1920a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                 4 4        3 2 3        2 4 2         6   6
+--R           (1536a c  - 1152a b c  - 1248a b c  + 360a b c)x
+--R         + 
+--R                 4   3         3 3 2       2 5          7  5
+--R           (7680a b c  - 10368a b c  + 672a b c + 360a b )x
+--R         + 
+--R                 5 3        4 2 2        3 4         2 6  4
+--R           (7680a c  - 4224a b c  - 8544a b c + 2280a b )x
+--R         + 
+--R                  5   2         4 3         3 5  3
+--R           (12288a b c  - 18432a b c + 3840a b )x
+--R         + 
+--R                 6 2        5 2         4 4  2
+--R           (6144a c  - 9216a b c + 1920a b )x
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                     4 4        3 2 3        2 4 2         6   7
+--R               (1536a c  - 1152a b c  - 1248a b c  + 360a b c)x
+--R             + 
+--R                     4   3         3 3 2       2 5          7  6
+--R               (7680a b c  - 10368a b c  + 672a b c + 360a b )x
+--R             + 
+--R                     5 3        4 2 2        3 4         2 6  5
+--R               (7680a c  - 4224a b c  - 8544a b c + 2280a b )x
+--R             + 
+--R                      5   2         4 3         3 5  4
+--R               (12288a b c  - 18432a b c + 3840a b )x
+--R             + 
+--R                     6 2        5 2         4 4  3
+--R               (6144a c  - 9216a b c + 1920a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                       3   4        2 3 3         5 2      7   8
+--R               (- 2304a b c  + 3264a b c  - 432a b c  - 60b c)x
+--R             + 
+--R                       4 4        3 2 3        2 4 2          6       8  7
+--R               (- 4608a c  + 1152a b c  + 7008a b c  - 1512a b c - 60b )x
+--R             + 
+--R                        4   3         3 3 2       2 5           7  6
+--R               (- 16128a b c  + 20544a b c  + 432a b c - 1140a b )x
+--R             + 
+--R                        5 3        4 2 2         3 4         2 6  5
+--R               (- 10752a c  + 3456a b c  + 15648a b c - 3960a b )x
+--R             + 
+--R                        5   2         4 3         3 5  4
+--R               (- 15360a b c  + 23040a b c - 4800a b )x
+--R             + 
+--R                       6 2        5 2         4 4  3
+--R               (- 6144a c  + 9216a b c - 1920a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                       3   3        2 3 2        5       7  5
+--R               (- 4864a b c  + 2128a b c  + 88a b c - 79b )x
+--R             + 
+--R                       4 3         3 2 2        2 4          6  4
+--R               (- 1536a c  - 10848a b c  + 5616a b c - 702a b )x
+--R             + 
+--R                        4   2        3 3        2 5  3
+--R               (- 14592a b c  + 2496a b c + 288a b )x
+--R             + 
+--R                     5 2         4 2         3 4  2           5          4 3
+--R               (2560a c  - 10624a b c + 2496a b )x  + (- 3072a b c + 768a b )x
+--R             + 
+--R                    6        5 2
+--R               2048a c - 512a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                 4 4        3 2 3        2 4 2         6   6
+--R           (1024a c  + 3232a b c  - 2288a b c  + 354a b c)x
+--R         + 
+--R                  4   3        3 3 2        2 5          7  5
+--R           (12800a b c  - 1504a b c  - 1840a b c + 354a b )x
+--R         + 
+--R                5 3         4 2 2        3 4        2 6  4
+--R           (512a c  + 22560a b c  - 8880a b c + 802a b )x
+--R         + 
+--R                  5   2        4 3         3 5  3
+--R           (15360a b c  + 1792a b c - 1408a b )x
+--R         + 
+--R                   6 2         5 2         4 4  2         6          5 3
+--R           (- 3584a c  + 12672a b c - 2944a b )x  + (2048a b c - 512a b )x
+--R         + 
+--R                  7        6 2
+--R           - 2048a c + 512a b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                   3 2 3        2 4 2         6   7
+--R           (- 4992a b c  + 1024a b c  + 120a b c)x
+--R         + 
+--R                   4   3         3 3 2        2 5          7  6
+--R           (- 7680a b c  - 10368a b c  + 3104a b c + 120a b )x
+--R         + 
+--R                 5 3         4 2 2      3 4         2 6  5
+--R           (4608a c  - 30336a b c  + 32a b c + 2200a b )x
+--R         + 
+--R                   5   2         4 3         3 5  4
+--R           (- 7168a b c  - 22016a b c + 6464a b )x
+--R         + 
+--R                 6 2         5 2         4 4  3           6          5 3  2
+--R           (7680a c  - 22784a b c + 5472a b )x  + (- 2048a b c + 512a b )x
+--R         + 
+--R                 7        6 2
+--R           (2048a c - 512a b )x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 3   4        2 3 3         5 2  8
+--R           (3328a b c  + 1536a b c  - 720a b c )x
+--R         + 
+--R                   4 4         3 2 3       2 4 2          6   7
+--R           (- 1536a c  + 19456a b c  - 288a b c  - 1440a b c)x
+--R         + 
+--R                  4   3         3 3 2        2 5          7  6
+--R           (10240a b c  + 30336a b c  - 6624a b c - 720a b )x
+--R         + 
+--R                   5 3         4 2 2        3 4         2 6  5
+--R           (- 8192a c  + 45312a b c  + 5824a b c - 4800a b )x
+--R         + 
+--R                 5   2         4 3         3 5  4
+--R           (4864a b c  + 32640a b c - 9104a b )x
+--R         + 
+--R                   6 2         5 2         4 4  3         6          5 3  2
+--R           (- 8704a c  + 24320a b c - 5792a b )x  + (1024a b c - 256a b )x
+--R         + 
+--R                   7        6 2
+--R           (- 2048a c + 512a b )x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                   6   2       5 3       4 5  5
+--R             (1536a b c  - 256a b c - 32a b )x
+--R           + 
+--R                   7 2        6 2        5 4  4         7           6 3  3
+--R             (3072a c  + 1536a b c - 576a b )x  + (6144a b c - 1536a b )x
+--R           + 
+--R                   8         7 2  2
+--R             (4096a c - 1024a b )x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                     6 3       5 2 2       4 4   6
+--R             (- 1024a c  - 512a b c  + 192a b c)x
+--R           + 
+--R                     6   2       5 3        4 5  5
+--R             (- 5120a b c  + 512a b c + 192a b )x
+--R           + 
+--R                     7 2        6 2         5 4  4           7           6 3  3
+--R             (- 5120a c  - 3584a b c + 1216a b )x  + (- 8192a b c + 2048a b )x
+--R           + 
+--R                     8         7 2  2
+--R             (- 4096a c + 1024a b )x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      2   2         3       5  5
+--R               (- 192a b c  - 160a b c - 12b )x
+--R             + 
+--R                      3 2        2 2          4  4           3           2 3  3
+--R               (- 384a c  - 1344a b c - 280a b )x  + (- 3072a b c - 1792a b )x
+--R             + 
+--R                       4         3 2  2        4           5
+--R               (- 2048a c - 4608a b )x  - 5120a b x - 2048a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R               3 3       2 2 2        4     6  6
+--R           (64a c  + 240a b c  + 60a b c + b )x
+--R         + 
+--R                 3   2       2 3         5  5
+--R           (1152a b c  + 960a b c + 72a b )x
+--R         + 
+--R                 4 2        3 2        2 4  4         4           3 3  3
+--R           (1152a c  + 4032a b c + 840a b )x  + (6144a b c + 3584a b )x
+--R         + 
+--R                 5         4 2  2        5           6
+--R           (3072a c + 6912a b )x  + 6144a b x + 2048a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                 3 3       2 2 2        4     6  7
+--R           (- 64a c  - 240a b c  - 60a b c - b )x
+--R         + 
+--R                   3   2       2 3         5  6
+--R           (- 1152a b c  - 960a b c - 72a b )x
+--R         + 
+--R                   4 2        3 2        2 4  5           4           3 3  4
+--R           (- 1152a c  - 4032a b c - 840a b )x  + (- 6144a b c - 3584a b )x
+--R         + 
+--R                   5         4 2  3        5   2        6
+--R           (- 3072a c - 6912a b )x  - 6144a b x  - 2048a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                2   3         3 2      5   8
+--R           (192a b c  + 160a b c  + 12b c)x
+--R         + 
+--R                3 3        2 2 2         4       6  7
+--R           (384a c  + 1536a b c  + 440a b c + 12b )x
+--R         + 
+--R                 3   2        2 3          5  6
+--R           (3648a b c  + 3296a b c + 292a b )x
+--R         + 
+--R                 4 2        3 2         2 4  5          4           3 3  4
+--R           (2432a c  + 9024a b c + 2072a b )x  + (10240a b c + 6400a b )x
+--R         + 
+--R                 5         4 2  3        5   2        6
+--R           (4096a c + 9728a b )x  + 7168a b x  + 2048a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                 3 4       2 2 3        4 2    6   11
+--R             (64a c  + 240a b c  + 60a b c  + b c)x
+--R           + 
+--R                   3   3        2 3 2         5     7  10
+--R             (1216a b c  + 1200a b c  + 132a b c + b )x
+--R           + 
+--R                   4 3        3 2 2        2 4         6  9
+--R             (1216a c  + 5424a b c  + 1860a b c + 73a b )x
+--R           + 
+--R                   4   2        3 3        2 5  8
+--R             (8448a b c  + 8576a b c + 912a b )x
+--R           + 
+--R                   5 2         4 2         3 4  7          5            4 3  6
+--R             (4224a c  + 17088a b c + 4424a b )x  + (15360a b c + 10496a b )x
+--R           + 
+--R                   6          5 2  5        6   4        7 3
+--R             (5120a c + 13056a b )x  + 8192a b x  + 2048a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2   4         3 3      5 2  12
+--R             (- 192a b c  - 160a b c  - 12b c )x
+--R           + 
+--R                    3 4        2 2 3         4 2      6   11
+--R             (- 384a c  - 1728a b c  - 600a b c  - 24b c)x
+--R           + 
+--R                     3   3        2 3 2         5       7  10
+--R             (- 4224a b c  - 4992a b c  - 744a b c - 12b )x
+--R           + 
+--R                     4 3         3 2 2        2 4          6  9
+--R             (- 2816a c  - 14208a b c  - 5808a b c - 304a b )x
+--R           + 
+--R                      4   2         3 3         2 5  8
+--R             (- 16320a b c  - 18720a b c - 2364a b )x
+--R           + 
+--R                     5 2         4 2         3 4  7
+--R             (- 6528a c  - 28992a b c - 8472a b )x
+--R           + 
+--R                      5            4 3  6           6          5 2  5
+--R             (- 21504a b c - 16128a b )x  + (- 6144a c - 16896a b )x
+--R           + 
+--R                    6   4        7 3
+--R             - 9216a b x  - 2048a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 386
+
+)clear all
+
+--S 387 of 704
+t0:=1/(x*(a*x^2+b*x^3+c*x^4)^(3/2))
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R                             +------------------+
+--R            5      4      3  |   4      3      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 704
+r0:=2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^2*sqrt(a*x^2+b*x^3+c*x^4))+_
+   5/16*b*(7*b^2-12*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(9/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/3*(7*b^2-16*a*c)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a^2*(b^2-4*a*c)*x^4)+1/12*b*(35*b^2-116*a*c)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a^3*(b^2-4*a*c)*x^3)-1/24*(105*b^4-_
+   460*a*b^2*c+256*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/(a^4*(b^2-4*a*c)*x^2)
+--R 
+--R
+--R   (2)
+--R                                            +--------------+
+--R                2   2         3        5  3 |   2
+--R         (- 720a b c  + 600a b c - 105b )x \|c x  + b x + a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                2 3         2 2       4   4        2   2          3        5  3
+--R           (512a c  - 920a b c  + 210b c)x  + (976a b c  - 1060a b c + 210b )x
+--R         + 
+--R              3 2       2 2         4  2        3         2 3        4       3 2
+--R         (256a c  - 344a b c + 70a b )x  + (112a b c - 28a b )x - 64a c + 16a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                             +------------------+
+--R          5       4 2  2 +-+ |   4      3      2
+--R     (192a c - 48a b )x \|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      3   3         2 3 2          5        7  7
+--R               (11520a b c  + 10560a b c  - 9360a b c - 420b )x
+--R             + 
+--R                      3 2 2         2 4            6  6
+--R               (92160a b c  - 30720a b c - 13440a b )x
+--R             + 
+--R                      4   2         3 3          2 5  5
+--R               (92160a b c  + 61440a b c - 67200a b )x
+--R             + 
+--R                       4 2           3 4  4          5            4 3  3
+--R               (184320a b c - 107520a b )x  + (92160a b c - 53760a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                    3 2 3        2 4 2          6   8
+--R           (- 23040a b c  + 7680a b c  + 3360a b c)x
+--R         + 
+--R                    4   3         3 3 2         2 5           7  7
+--R           (- 46080a b c  - 53760a b c  + 41280a b c + 3360a b )x
+--R         + 
+--R                     4 2 2         3 4          2 6  6
+--R           (- 207360a b c  + 57600a b c + 36960a b )x
+--R         + 
+--R                     5   2          4 3           3 5  5
+--R           (- 138240a b c  - 115200a b c + 114240a b )x
+--R         + 
+--R                     5 2           4 4  4            6            5 3  3
+--R           (- 230400a b c + 134400a b )x  + (- 92160a b c + 53760a b )x
+--R      *
+--R                   +--------------+
+--R               +-+ |   2
+--R             2\|a \|c x  + b x + a  - b x - 2a
+--R         log(---------------------------------)
+--R                              +-+
+--R                           2x\|a
+--R     + 
+--R                   3   3         2 3 2          5        7  7
+--R           (- 7360a b c  + 26992a b c  - 5076a b c - 511b )x
+--R         + 
+--R                    4 3         3 2 2         2 4           6  6
+--R           (- 32768a c  + 50688a b c  + 36608a b c - 9632a b )x
+--R         + 
+--R                    4   2          3 3          2 5  5
+--R           (- 96768a b c  + 161024a b c - 12320a b )x
+--R         + 
+--R                    5 2         4 2          3 4  4
+--R           (- 81920a c  + 52224a b c + 51968a b )x
+--R         + 
+--R                     5            4 3  3            6          5 2  2
+--R           (- 107008a b c + 87424a b )x  + (- 28672a c + 19456a b )x
+--R         + 
+--R                  6           7
+--R           - 2048a b x + 8192a
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R             4 4         3 2 3        2 4 2          6   8
+--R       (8192a c  - 18432a b c  - 7232a b c  + 3248a b c)x
+--R     + 
+--R              4   3          3 3 2        2 5           7  7
+--R       (45056a b c  - 106624a b c  + 7328a b c + 3248a b )x
+--R     + 
+--R              5 3         4 2 2          3 4          2 6  6
+--R       (69632a c  - 55296a b c  - 114240a b c + 17808a b )x
+--R     + 
+--R               5   2          4 3         3 5  5
+--R       (182272a b c  - 235904a b c - 4256a b )x
+--R     + 
+--R              6 2         5 2          4 4  4           6            5 3  3
+--R       (97280a c  - 14080a b c - 92800a b )x  + (124416a b c - 97920a b )x
+--R     + 
+--R              7          6 2  2        7           8
+--R       (24576a c - 17408a b )x  - 2048a b x - 8192a
+--R  /
+--R                 7 2        6 2        5 4  7          7           6 3  6
+--R           (3072a c  + 4608a b c + 192a b )x  + (24576a b c + 6144a b )x
+--R         + 
+--R                  8          7 2  5         8   4         9 3
+--R           (24576a c + 30720a b )x  + 49152a b x  + 24576a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                   6   2        5 3   8
+--R           (- 6144a b c  - 1536a b c)x
+--R         + 
+--R                    7 2         6 2         5 4  7
+--R           (- 12288a c  - 21504a b c - 1536a b )x
+--R         + 
+--R                    7            6 3  6            8          7 2  5
+--R           (- 55296a b c - 16896a b )x  + (- 36864a c - 52224a b )x
+--R         + 
+--R                   8   4         9 3
+--R           - 61440a b x  - 24576a x
+--R      *
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 389
+
+--S 390 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      4   4         3 3 3         2 5 2          7        9  7
+--R               (46080a b c  + 30720a b c  - 48000a b c  + 7680a b c + 420b )x
+--R             + 
+--R                       4 2 3          3 4 2         2 6            8  6
+--R               (368640a b c  - 215040a b c  - 23040a b c + 13440a b )x
+--R             + 
+--R                       5   3          4 3 2          3 5          2 7  5
+--R               (368640a b c  + 153600a b c  - 330240a b c + 67200a b )x
+--R             + 
+--R                       5 2 2          4 4           3 6  4
+--R               (737280a b c  - 614400a b c + 107520a b )x
+--R             + 
+--R                       6   2          5 3          4 5  3
+--R               (368640a b c  - 307200a b c + 53760a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        3 2 4         2 4 3          6 2        8   8
+--R               (- 92160a b c  + 53760a b c  + 5760a b c  - 3360b c)x
+--R             + 
+--R                            4   4          3 3 3          2 5 2           7
+--R                   - 184320a b c  - 168960a b c  + 218880a b c  - 27840a b c
+--R                 + 
+--R                          9
+--R                   - 3360b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                         4 2 3          3 4 2         2 6            8  6
+--R               (- 829440a b c  + 437760a b c  + 90240a b c - 36960a b )x
+--R             + 
+--R                         5   3          4 3 2          3 5           2 7  5
+--R               (- 552960a b c  - 322560a b c  + 572160a b c - 114240a b )x
+--R             + 
+--R                         5 2 2          4 4           3 6  4
+--R               (- 921600a b c  + 768000a b c - 134400a b )x
+--R             + 
+--R                         6   2          5 3          4 5  3
+--R               (- 368640a b c  + 307200a b c - 53760a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                        3 2 4         2 4 3          6 2        8   9
+--R               (- 92160a b c  + 53760a b c  + 5760a b c  - 3360b c)x
+--R             + 
+--R                            4   4          3 3 3          2 5 2           7
+--R                   - 184320a b c  - 168960a b c  + 218880a b c  - 27840a b c
+--R                 + 
+--R                          9
+--R                   - 3360b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                         4 2 3          3 4 2         2 6            8  7
+--R               (- 829440a b c  + 437760a b c  + 90240a b c - 36960a b )x
+--R             + 
+--R                         5   3          4 3 2          3 5           2 7  6
+--R               (- 552960a b c  - 322560a b c  + 572160a b c - 114240a b )x
+--R             + 
+--R                         5 2 2          4 4           3 6  5
+--R               (- 921600a b c  + 768000a b c - 134400a b )x
+--R             + 
+--R                         6   2          5 3          4 5  4
+--R               (- 368640a b c  + 307200a b c - 53760a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                  4   5         3 3 4         2 5 3          7 2       9   10
+--R           (46080a b c  + 30720a b c  - 48000a b c  + 7680a b c  + 420b c)x
+--R         + 
+--R                   4 2 4          3 4 3         2 6 2           8        10  9
+--R           (414720a b c  - 184320a b c  - 71040a b c  + 21120a b c + 420b  )x
+--R         + 
+--R                        5   4          4 3 3          3 5 2         2 7
+--R                 414720a b c  + 552960a b c  - 593280a b c  + 51840a b c
+--R               + 
+--R                         9
+--R                 13860a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    5 2 3          4 4 2          3 6          2 8  7
+--R           (1474560a b c  - 675840a b c  - 245760a b c + 80640a b )x
+--R         + 
+--R                   6   3          5 3 2          4 5           3 7  6
+--R           (737280a b c  + 583680a b c  - 890880a b c + 174720a b )x
+--R         + 
+--R                    6 2 2          5 4           4 6  5
+--R           (1105920a b c  - 921600a b c + 161280a b )x
+--R         + 
+--R                   7   2          6 3          5 5  4
+--R           (368640a b c  - 307200a b c + 53760a b )x
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                             4   4          3 3 3         2 5 2          7
+--R                     - 29440a b c  + 115328a b c  - 47296a b c  + 3032a b c
+--R                   + 
+--R                         9
+--R                     511b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            5 4          4 2 3         3 4 2         2 6
+--R                   - 131072a c  + 235520a b c  + 95744a b c  - 75136a b c
+--R                 + 
+--R                          8
+--R                   9632a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         5   3          4 3 2          3 5          2 7  5
+--R               (- 387072a b c  + 740864a b c  - 210304a b c + 12320a b )x
+--R             + 
+--R                         6 3          5 2 2          4 4          3 6  4
+--R               (- 327680a c  + 290816a b c  + 155648a b c - 51968a b )x
+--R             + 
+--R                         6   2          5 3          4 5  3
+--R               (- 428032a b c  + 456704a b c - 87424a b )x
+--R             + 
+--R                         7 2          6 2          5 4  2
+--R               (- 114688a c  + 106496a b c - 19456a b )x
+--R             + 
+--R                       7           6 3           8         7 2
+--R               (- 8192a b c + 2048a b )x + 32768a c - 8192a b
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      4 5         3 2 4         2 4 3           6 2        8   8
+--R               (32768a c  - 81920a b c  - 10496a b c  + 20224a b c  - 3248b c)x
+--R             + 
+--R                            4   4          3 3 3          2 5 2          7
+--R                     180224a b c  - 471552a b c  + 135936a b c  + 5664a b c
+--R                   + 
+--R                            9
+--R                     - 3248b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                          5 4          4 2 3          3 4 2          2 6
+--R                   278528a c  - 290816a b c  - 401664a b c  + 185472a b c
+--R                 + 
+--R                             8
+--R                   - 17808a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                       5   3           4 3 2          3 5         2 7  5
+--R               (729088a b c  - 1125888a b c  + 218880a b c + 4256a b )x
+--R             + 
+--R                       6 3          5 2 2          4 4          3 6  4
+--R               (389120a c  - 153600a b c  - 357120a b c + 92800a b )x
+--R             + 
+--R                       6   2          5 3          4 5  3
+--R               (497664a b c  - 516096a b c + 97920a b )x
+--R             + 
+--R                      7 2         6 2          5 4  2
+--R               (98304a c  - 94208a b c + 17408a b )x
+--R             + 
+--R                       7           6 3           8         7 2
+--R               (- 8192a b c + 2048a b )x - 32768a c + 8192a b
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                    4 5        3 2 4         2 4 3           6 2       8   9
+--R           (- 32768a c  + 9728a b c  + 72832a b c  - 16480a b c  - 840b c)x
+--R         + 
+--R                     4   4          3 3 3         2 5 2           7        9  8
+--R           (- 324608a b c  + 379648a b c  + 94656a b c  - 42800a b c - 840b )x
+--R         + 
+--R                        5 4          4 2 3          3 4 2          2 6
+--R               - 278528a c  - 358912a b c  + 926592a b c  - 111584a b c
+--R             + 
+--R                         8
+--R               - 27160a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                      5   3          4 3 2          3 5           2 7  6
+--R           (- 1162240a b c  + 994560a b c  + 366272a b c - 143248a b )x
+--R         + 
+--R                     6 3          5 2 2           4 4           3 6  5
+--R           (- 389120a c  - 568320a b c  + 1160960a b c - 256320a b )x
+--R         + 
+--R                     6   2          5 3           4 5  4
+--R           (- 786432a b c  + 837632a b c - 163328a b )x
+--R         + 
+--R                    7 2         6 2          5 4  3         7           6 3  2
+--R           (- 98304a c  + 94208a b c - 17408a b )x  + (8192a b c - 2048a b )x
+--R         + 
+--R                  8         7 2
+--R           (32768a c - 8192a b )x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R              4   5          3 3 4        2 5 3          7 2  10
+--R       (65536a b c  - 101376a b c  - 2560a b c  + 6720a b c )x
+--R     + 
+--R               5 5          4 2 4          3 4 3         2 6 2           8   9
+--R       (131072a c  + 118784a b c  - 446464a b c  + 57600a b c  + 13440a b c)x
+--R     + 
+--R               5   4          4 3 3          3 5 2          2 7           9  8
+--R       (872448a b c  - 749568a b c  - 473856a b c  + 136320a b c + 6720a b )x
+--R     + 
+--R               6 4           5 2 3           4 4 2          3 6          2 8  7
+--R       (458752a c  + 1015808a b c  - 1845248a b c  + 116736a b c + 76160a b )x
+--R     + 
+--R                6   3           5 3 2          4 5           3 7  6
+--R       (1720320a b c  - 1192960a b c  - 772096a b c + 252224a b )x
+--R     + 
+--R               7 3          6 2 2           5 4           4 6  5
+--R       (442368a c  + 897024a b c  - 1557504a b c + 335616a b )x
+--R     + 
+--R               7   2          6 3           5 5  4
+--R       (839680a b c  - 886784a b c + 172288a b )x
+--R     + 
+--R              8 2         7 2          6 4  3            8           7 3  2
+--R       (81920a c  - 90112a b c + 17408a b )x  + (- 24576a b c + 6144a b )x
+--R     + 
+--R                9         8 2
+--R       (- 32768a c + 8192a b )x
+--R  /
+--R                    7 3         6 2 2        5 4        4 6  7
+--R             (12288a c  + 15360a b c  - 3840a b c - 192a b )x
+--R           + 
+--R                    7   2        5 5  6          8 2         7 2          6 4  5
+--R             (98304a b c  - 6144a b )x  + (98304a c  + 98304a b c - 30720a b )x
+--R           + 
+--R                     8            7 3  4          9          8 2  3
+--R             (196608a b c - 49152a b )x  + (98304a c - 24576a b )x
+--R        *
+--R                +--------------+
+--R            +-+ |   2
+--R           \|a \|c x  + b x + a
+--R       + 
+--R                  7   3        5 5   8
+--R         (- 24576a b c  + 1536a b c)x
+--R       + 
+--R                  8 3         7 2 2         6 4         5 6  7
+--R         (- 49152a c  - 73728a b c  + 15360a b c + 1536a b )x
+--R       + 
+--R                   8   2         7 3          6 5  6
+--R         (- 221184a b c  - 12288a b c + 16896a b )x
+--R       + 
+--R                   9 2          8 2          7 4  5
+--R         (- 147456a c  - 172032a b c + 52224a b )x
+--R       + 
+--R                   9            8 3  4            10          9 2  3
+--R         (- 245760a b c + 61440a b )x  + (- 98304a  c + 24576a b )x
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 390
+
+--S 391 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       3   3        2 3 2         5       7  7
+--R               (- 1024a b c  - 1792a b c  - 448a b c - 16b )x
+--R             + 
+--R                       4 3         3 2 2        2 4          6  6
+--R               (- 2048a c  - 13824a b c  - 8064a b c - 672a b )x
+--R             + 
+--R                        4   2         3 3         2 5  5
+--R               (- 30720a b c  - 46080a b c - 8064a b )x
+--R             + 
+--R                        5 2          4 2          3 4  4
+--R               (- 20480a c  - 112640a b c - 42240a b )x
+--R             + 
+--R                         5             4 3  3            6           5 2  2
+--R               (- 122880a b c - 112640a b )x  + (- 49152a c - 159744a b )x
+--R             + 
+--R                        6            7
+--R               - 114688a b x - 32768a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                4 4        3 2 3        2 4 2         6     8  8
+--R           (256a c  + 1792a b c  + 1120a b c  + 112a b c + b )x
+--R         + 
+--R                 4   3         3 3 2        2 5          7  7
+--R           (8192a b c  + 14336a b c  + 3584a b c + 128a b )x
+--R         + 
+--R                 5 3         4 2 2         3 4         2 6  6
+--R           (8192a c  + 55296a b c  + 32256a b c + 2688a b )x
+--R         + 
+--R                  5   2          4 3          3 5  5
+--R           (81920a b c  + 122880a b c + 21504a b )x
+--R         + 
+--R                  6 2          5 2          4 4  4
+--R           (40960a c  + 225280a b c + 84480a b )x
+--R         + 
+--R                   6             5 3  3          7           6 2  2
+--R           (196608a b c + 180224a b )x  + (65536a c + 212992a b )x
+--R         + 
+--R                  7            8
+--R           131072a b x + 32768a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                  4 4        3 2 3        2 4 2         6     8  9
+--R           (- 256a c  - 1792a b c  - 1120a b c  - 112a b c - b )x
+--R         + 
+--R                   4   3         3 3 2        2 5          7  8
+--R           (- 8192a b c  - 14336a b c  - 3584a b c - 128a b )x
+--R         + 
+--R                   5 3         4 2 2         3 4         2 6  7
+--R           (- 8192a c  - 55296a b c  - 32256a b c - 2688a b )x
+--R         + 
+--R                    5   2          4 3          3 5  6
+--R           (- 81920a b c  - 122880a b c - 21504a b )x
+--R         + 
+--R                    6 2          5 2          4 4  5
+--R           (- 40960a c  - 225280a b c - 84480a b )x
+--R         + 
+--R                     6             5 3  4            7           6 2  3
+--R           (- 196608a b c - 180224a b )x  + (- 65536a c - 212992a b )x
+--R         + 
+--R                    7   2         8
+--R           - 131072a b x  - 32768a x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 3   4        2 3 3         5 2      7   10
+--R           (1024a b c  + 1792a b c  + 448a b c  + 16b c)x
+--R         + 
+--R                 4 4         3 2 3        2 4 2          6       8  9
+--R           (2048a c  + 14848a b c  + 9856a b c  + 1120a b c + 16b )x
+--R         + 
+--R                  4   3         3 3 2         2 5          7  8
+--R           (33792a b c  + 61696a b c  + 16576a b c + 688a b )x
+--R         + 
+--R                  5 3          4 2 2         3 4         2 6  7
+--R           (22528a c  + 157184a b c  + 96384a b c + 8736a b )x
+--R         + 
+--R                   5   2          4 3          3 5  6
+--R           (174080a b c  + 271360a b c + 50304a b )x
+--R         + 
+--R                  6 2          5 2           4 4  5
+--R           (69632a c  + 395264a b c + 154880a b )x
+--R         + 
+--R                   6             5 3  4          7           6 2  3
+--R           (286720a b c + 272384a b )x  + (81920a c + 274432a b )x
+--R         + 
+--R                  7   2         8
+--R           147456a b x  + 32768a x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  4 5        3 2 4        2 4 3         6 2    8   14
+--R             (256a c  + 1792a b c  + 1120a b c  + 112a b c  + b c)x
+--R           + 
+--R                   4   4         3 3 3        2 5 2         7     9  13
+--R             (8448a b c  + 16128a b c  + 4704a b c  + 240a b c + b )x
+--R           + 
+--R                   5 4         4 2 3         3 4 2        2 6          8  12
+--R             (8448a c  + 65280a b c  + 47712a b c  + 6384a b c + 129a b )x
+--R           + 
+--R                    5   3          4 3 2         3 5         2 7  11
+--R             (98304a b c  + 192512a b c  + 57344a b c + 2816a b )x
+--R           + 
+--R                    6 3          5 2 2          4 4          3 6  10
+--R             (49152a c  + 362496a b c  + 239616a b c + 24192a b )x
+--R           + 
+--R                     6   2          5 3           4 5  9
+--R             (319488a b c  + 528384a b c + 105984a b )x
+--R           + 
+--R                     7 2          6 2           5 4  8
+--R             (106496a c  + 634880a b c + 264704a b )x
+--R           + 
+--R                     7             6 3  7          8           7 2  6
+--R             (393216a b c + 393216a b )x  + (98304a c + 344064a b )x
+--R           + 
+--R                    8   5         9 4
+--R             163840a b x  + 32768a x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                     3   5        2 3 4         5 3      7 2  15
+--R             (- 1024a b c  - 1792a b c  - 448a b c  - 16b c )x
+--R           + 
+--R                     4 5         3 2 4         2 4 3          6 2      8   14
+--R             (- 2048a c  - 15872a b c  - 11648a b c  - 1568a b c  - 32b c)x
+--R           + 
+--R                      4   4         3 3 3         2 5 2          7       9  13
+--R             (- 36864a b c  - 78336a b c  - 26880a b c  - 1824a b c - 16b )x
+--R           + 
+--R                           5 4          4 2 3          3 4 2         2 6
+--R                   - 24576a c  - 205824a b c  - 167936a b c  - 26432a b c
+--R                 + 
+--R                           8
+--R                   - 704a b
+--R            *
+--R                12
+--R               x
+--R           + 
+--R                       5   3          4 3 2          3 5         2 7  11
+--R             (- 230400a b c  - 490240a b c  - 163264a b c - 9424a b )x
+--R           + 
+--R                      6 3          5 2 2          4 4          3 6  10
+--R             (- 92160a c  - 726528a b c  - 522624a b c - 59040a b )x
+--R           + 
+--R                       6   2          5 3           4 5  9
+--R             (- 530432a b c  - 939008a b c - 205184a b )x
+--R           + 
+--R                       7 2          6 2           5 4  8
+--R             (- 151552a c  - 956416a b c - 427264a b )x
+--R           + 
+--R                       7             6 3  7             8           7 2  6
+--R             (- 516096a b c - 546816a b )x  + (- 114688a c - 421888a b )x
+--R           + 
+--R                      8   5         9 4
+--R             - 180224a b x  - 32768a x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 391
+
+)clear all
+
+--S 392 of 704
+t0:=1/(x^2*(a*x^2+b*x^3+c*x^4)^(3/2))
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R                             +------------------+
+--R            6      5      4  |   4      3      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 704
+r0:=2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^3*sqrt(a*x^2+b*x^3+c*x^4))-_
+   15/128*(21*b^4-56*a*b^2*c+16*a^2*c^2)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(a^(11/2)*sqrt(a*x^2+b*x^3+c*x^4))-_
+   1/4*(9*b^2-20*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*(b^2-4*a*c)*x^5)+_
+   1/8*b*(21*b^2-68*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^3*(b^2-4*a*c)*x^4)-_
+   1/32*(105*b^4-448*a*b^2*c+240*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/(a^4*_
+   (b^2-4*a*c)*x^3)+1/64*b*(315*b^4-1680*a*b^2*c+1808*a^2*c^2)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a^5*(b^2-4*a*c)*x^2)
+--R 
+--R
+--R   (2)
+--R                                                        +--------------+
+--R                3 3        2 2 2          4        6  4 |   2
+--R         (- 960a c  + 3600a b c  - 2100a b c + 315b )x \|c x  + b x + a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                   2   3          3 2       5   5
+--R           (- 3616a b c  + 3360a b c  - 630b c)x
+--R         + 
+--R                3 3        2 2 2          4        6  4
+--R           (960a c  - 5408a b c  + 3780a b c - 630b )x
+--R         + 
+--R                   3   2        2 3          5  3
+--R           (- 1568a b c  + 1232a b c - 210a b )x
+--R         + 
+--R                4 2       3 2       2 4  2        4         3 3         5
+--R           (320a c  - 416a b c + 84a b )x  + (192a b c - 48a b )x - 128a c
+--R         + 
+--R              4 2
+--R           32a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                              +------------------+
+--R          6        5 2  3 +-+ |   4      3      2
+--R     (512a c - 128a b )x \|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 393
+
+--S 394 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                            4   4          3 3 3         2 5 2           7
+--R                     153600a b c  - 460800a b c  - 65280a b c  + 94080a b c
+--R                   + 
+--R                          9
+--R                     2520b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                          5 4          4 2 3           3 4 2          2 6
+--R                   307200a c  - 307200a b c  - 2188800a b c  + 672000a b c
+--R                 + 
+--R                            8
+--R                   126000a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                        5   3           4 3 2          3 5            2 7  7
+--R               (1843200a b c  - 5683200a b c  - 268800a b c + 1008000a b )x
+--R             + 
+--R                        6 3           5 2 2           4 4            3 6  6
+--R               (1228800a c  - 2150400a b c  - 5913600a b c + 2822400a b )x
+--R             + 
+--R                        6   2           5 3            4 5  5
+--R               (2457600a b c  - 8601600a b c + 3225600a b )x
+--R             + 
+--R                       7 2           6 2            5 4  4
+--R               (983040a c  - 3440640a b c + 1290240a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                           4 5         3 2 4          2 4 3            6 2
+--R                   - 61440a c  + 61440a b c  + 437760a b c  - 134400a b c
+--R                 + 
+--R                           8
+--R                   - 25200b c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            4   4           3 3 3          2 5 2            7
+--R                   - 798720a b c  + 2334720a b c  + 545280a b c  - 537600a b c
+--R                 + 
+--R                           9
+--R                   - 25200b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            5 4          4 2 3           3 4 2           2 6
+--R                   - 798720a c  + 614400a b c  + 6259200a b c  - 1720320a b c
+--R                 + 
+--R                              8
+--R                   - 428400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                          5   3            4 3 2           3 5            2 7  7
+--R               (- 3440640a b c  + 10444800a b c  + 1075200a b c - 2096640a b )x
+--R             + 
+--R                          6 3           5 2 2           4 4            3 6  6
+--R               (- 1720320a c  + 2764800a b c  + 9139200a b c - 4273920a b )x
+--R             + 
+--R                          6   2            5 3            4 5  5
+--R               (- 2949120a b c  + 10321920a b c - 3870720a b )x
+--R             + 
+--R                         7 2           6 2            5 4  4
+--R               (- 983040a c  + 3440640a b c - 1290240a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                   +--------------+
+--R               +-+ |   2
+--R             2\|a \|c x  + b x + a  - b x - 2a
+--R         log(---------------------------------)
+--R                              +-+
+--R                           2x\|a
+--R     + 
+--R                   4   4         3 3 3          2 5 2           7         9  9
+--R           (313344a b c  + 11776a b c  - 316752a b c  + 60344a b c + 2903b )x
+--R         + 
+--R                      5 4           4 2 3           3 4 2          2 6
+--R               102400a c  + 2462720a b c  - 1828000a b c  - 216400a b c
+--R             + 
+--R                       8
+--R               94750a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    5   3           4 3 2           3 5           2 7  7
+--R           (3123200a b c  + 1835520a b c  - 3176000a b c + 338000a b )x
+--R         + 
+--R                     6 3           5 2 2           4 4           3 6  6
+--R           (- 102400a c  + 8801280a b c  - 4581760a b c - 397600a b )x
+--R         + 
+--R                    6   2           5 3            4 5  5
+--R           (3993600a b c  + 2447360a b c - 2470400a b )x
+--R         + 
+--R                     7 2           6 2            5 4  4
+--R           (- 696320a c  + 5320704a b c - 2421760a b )x
+--R         + 
+--R                   7             6 3  3             8           7 2  2
+--R           (901120a b c - 389120a b )x  + (- 229376a c + 122880a b )x
+--R         + 
+--R                 8             9
+--R           65536a b x + 131072a
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                         4 5          3 2 4          2 4 3           6 2
+--R                 - 32768a c  - 480256a b c  + 453152a b c  + 16400a b c
+--R               + 
+--R                         8
+--R                 - 23990b c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         4   4          3 3 3           2 5 2            7
+--R               - 1429504a b c  - 759808a b c  + 1745056a b c  - 199440a b c
+--R             + 
+--R                       9
+--R               - 23990b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                        5 4           4 2 3           3 4 2           2 6
+--R               - 118784a c  - 6899712a b c  + 3632288a b c  + 1208176a b c
+--R             + 
+--R                          8
+--R               - 239830a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      5   3           4 3 2           3 5           2 7  7
+--R           (- 5070848a b c  - 5883904a b c  + 6210816a b c - 315968a b )x
+--R         + 
+--R                   6 3            5 2 2           4 4            3 6  6
+--R           (413696a c  - 13243392a b c  + 5040768a b c + 1360096a b )x
+--R         + 
+--R                      6   2           5 3            4 5  5
+--R           (- 4169728a b c  - 4747264a b c + 3623936a b )x
+--R         + 
+--R                   7 2           6 2            5 4  4
+--R           (827392a c  - 5869568a b c + 2632704a b )x
+--R         + 
+--R                     7             6 3  3           8           7 2  2
+--R           (- 786432a b c + 327680a b )x  + (163840a c - 139264a b )x
+--R         + 
+--R                    8             9
+--R           - 131072a b x - 131072a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                  7   2         6 3         5 5  9
+--R           (81920a b c  + 40960a b c + 1024a b )x
+--R         + 
+--R                   8 2          7 2          6 4  8
+--R           (163840a c  + 409600a b c + 51200a b )x
+--R         + 
+--R                   8             7 3  7           9            8 2  6
+--R           (983040a b c + 409600a b )x  + (655360a c + 1146880a b )x
+--R         + 
+--R                   9   5          10 4
+--R           1310720a b x  + 524288a  x
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R                8 3         7 2 2         6 4   10
+--R       (- 32768a c  - 81920a b c  - 10240a b c)x
+--R     + 
+--R                 8   2          7 3          6 5  9
+--R       (- 425984a b c  - 245760a b c - 10240a b )x
+--R     + 
+--R                 9 2           8 2           7 4  8
+--R       (- 425984a c  - 1163264a b c - 174080a b )x
+--R     + 
+--R                  9             8 3  7             10            9 2  6
+--R       (- 1835008a b c - 851968a b )x  + (- 917504a  c - 1736704a b )x
+--R     + 
+--R                 10   5          11 4
+--R       - 1572864a  b x  - 524288a  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 394
+
+--S 395 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          5   5           4 3 4          3 5 3          2 7 2
+--R                   614400a b c  - 1996800a b c  + 199680a b c  + 441600a b c
+--R                 + 
+--R                             9         11
+--R                   - 84000a b c - 2520b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                           6 5           5 2 4           4 4 3           3 6 2
+--R                   1228800a c  - 1536000a b c  - 8448000a b c  + 4876800a b c
+--R                 + 
+--R                            2 8             10
+--R                   - 168000a b c - 126000a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           6   4            5 3 3           4 5 2           3 7
+--R                   7372800a b c  - 24576000a b c  + 4608000a b c  + 4300800a b c
+--R                 + 
+--R                             2 9
+--R                   - 1008000a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                           7 4           6 2 3            5 4 2            4 6
+--R                   4915200a c  - 9830400a b c  - 21504000a b c  + 17203200a b c
+--R                 + 
+--R                             3 8
+--R                   - 2822400a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                        7   3            6 3 2            5 5            4 7  5
+--R               (9830400a b c  - 36864000a b c  + 21504000a b c - 3225600a b )x
+--R             + 
+--R                        8 3            7 2 2           6 4            5 6  4
+--R               (3932160a c  - 14745600a b c  + 8601600a b c - 1290240a b )x
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                        6 6          5 2 5           4 4 4          3 6 3
+--R               - 245760a c  + 307200a b c  + 1689600a b c  - 975360a b c
+--R             + 
+--R                     2 8 2           10
+--R               33600a b c  + 25200a b  c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         6   5            5 3 4          4 5 3           3 7 2
+--R               - 3194880a b c  + 10137600a b c  - 153600a b c  - 2695680a b c
+--R             + 
+--R                      2 9            11
+--R               436800a b c + 25200a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                         7 5           6 2 4            5 4 3            4 6 2
+--R               - 3194880a c  + 3256320a b c  + 24422400a b c  - 13140480a b c
+--R             + 
+--R                    3 8           2 10
+--R               6720a b c + 428400a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                          7   4            6 3 3           5 5 2           4 7
+--R               - 13762560a b c  + 45219840a b c  - 6144000a b c  - 9461760a b c
+--R             + 
+--R                       3 9
+--R               2096640a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                         8 4            7 2 3            6 4 2            5 6
+--R               - 6881280a c  + 12779520a b c  + 33792000a b c  - 26234880a b c
+--R             + 
+--R                       4 8
+--R               4273920a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                       8   3            7 3 2            6 5            5 7  5
+--R           (- 11796480a b c  + 44236800a b c  - 25804800a b c + 3870720a b )x
+--R         + 
+--R                      9 3            8 2 2           7 4            6 6  4
+--R           (- 3932160a c  + 14745600a b c  - 8601600a b c + 1290240a b )x
+--R      *
+--R                                        +--------------+
+--R          +------------------+      +-+ |   2
+--R          |   4      3      2     2\|a \|c x  + b x + a  - b x - 2a
+--R         \|c x  + b x  + a x  log(---------------------------------)
+--R                                                   +-+
+--R                                                2x\|a
+--R     + 
+--R                            6 6          5 2 5           4 4 4          3 6 3
+--R                   - 245760a c  + 307200a b c  + 1689600a b c  - 975360a b c
+--R                 + 
+--R                         2 8 2           10
+--R                   33600a b c  + 25200a b  c
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                             6   5            5 3 4          4 5 3
+--R                   - 3194880a b c  + 10137600a b c  - 153600a b c
+--R                 + 
+--R                             3 7 2          2 9            11
+--R                   - 2695680a b c  + 436800a b c + 25200a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                             7 5           6 2 4            5 4 3
+--R                   - 3194880a c  + 3256320a b c  + 24422400a b c
+--R                 + 
+--R                              4 6 2        3 8           2 10
+--R                   - 13140480a b c  + 6720a b c + 428400a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                              7   4            6 3 3           5 5 2
+--R                   - 13762560a b c  + 45219840a b c  - 6144000a b c
+--R                 + 
+--R                             4 7            3 9
+--R                   - 9461760a b c + 2096640a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                             8 4            7 2 3            6 4 2
+--R                   - 6881280a c  + 12779520a b c  + 33792000a b c
+--R                 + 
+--R                              5 6            4 8
+--R                   - 26234880a b c + 4273920a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                                8   3            7 3 2            6 5
+--R                     - 11796480a b c  + 44236800a b c  - 25804800a b c
+--R                   + 
+--R                             5 7
+--R                     3870720a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          9 3            8 2 2           7 4            6 6  5
+--R               (- 3932160a c  + 14745600a b c  - 8601600a b c + 1290240a b )x
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                          5   6           4 3 5          3 5 4          2 7 3
+--R                   614400a b c  - 1996800a b c  + 199680a b c  + 441600a b c
+--R                 + 
+--R                             9 2        11
+--R                   - 84000a b c  - 2520b  c
+--R              *
+--R                  12
+--R                 x
+--R             + 
+--R                           6 6          5 2 5            4 4 4           3 6 3
+--R                   1228800a c  - 921600a b c  - 10444800a b c  + 5076480a b c
+--R                 + 
+--R                          2 8 2            10         12
+--R                   273600a b c  - 210000a b  c - 2520b
+--R              *
+--R                  11
+--R                 x
+--R             + 
+--R                           6   5            5 3 4           4 5 3
+--R                   9216000a b c  - 28108800a b c  - 3640320a b c
+--R                 + 
+--R                           3 7 2           2 9             11
+--R                   9619200a b c  - 1260000a b c - 128520a b
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                           7 5           6 2 4            5 4 3            4 6 2
+--R                   6144000a c  - 3993600a b c  - 54528000a b c  + 26688000a b c
+--R                 + 
+--R                           3 8            2 10
+--R                   1310400a b c - 1134000a b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                            7   4            6 3 3           5 5 2
+--R                   22118400a b c  - 71270400a b c  + 4608000a b c
+--R                 + 
+--R                            4 7            3 9
+--R                   18278400a b c - 3830400a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           8 4            7 2 3            6 4 2            5 6
+--R                   8847360a c  - 14745600a b c  - 49766400a b c  + 37416960a b c
+--R                 + 
+--R                             4 8
+--R                   - 6048000a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                         8   3            7 3 2            6 5            5 7  6
+--R               (13762560a b c  - 51609600a b c  + 30105600a b c - 4515840a b )x
+--R             + 
+--R                        9 3            8 2 2           7 4            6 6  5
+--R               (3932160a c  - 14745600a b c  + 8601600a b c - 1290240a b )x
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                           5   5          4 3 4           3 5 3          2 7 2
+--R                   1253376a b c  - 266240a b c  - 1278784a b c  + 558128a b c
+--R                 + 
+--R                             9         11
+--R                   - 48732a b c - 2903b
+--R              *
+--R                  9
+--R                 x
+--R             + 
+--R                          6 5           5 2 4           4 4 3          3 6 2
+--R                   409600a c  + 9748480a b c  - 9774720a b c  + 962400a b c
+--R                 + 
+--R                          2 8            10
+--R                   595400a b c - 94750a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            6   4           5 3 3            4 5 2
+--R                   12492800a b c  + 4218880a b c  - 14539520a b c
+--R                 + 
+--R                           3 7           2 9
+--R                   4528000a b c - 338000a b
+--R              *
+--R                  7
+--R                 x
+--R             + 
+--R                            7 4            6 2 3            5 4 2           4 6
+--R                   - 409600a c  + 35307520a b c  - 27128320a b c  + 2991360a b c
+--R                 + 
+--R                          3 8
+--R                   397600a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         7   3           6 3 2            5 5            4 7  5
+--R               (15974400a b c  + 5795840a b c  - 12328960a b c + 2470400a b )x
+--R             + 
+--R                          8 3            7 2 2            6 4            5 6  4
+--R               (- 2785280a c  + 21979136a b c  - 15007744a b c + 2421760a b )x
+--R             + 
+--R                        8   2           7 3           6 5  3
+--R               (3604480a b c  - 2457600a b c + 389120a b )x
+--R             + 
+--R                         9 2          8 2           7 4  2
+--R               (- 917504a c  + 720896a b c - 122880a b )x
+--R             + 
+--R                       9            8 3            10           9 2
+--R               (262144a b c - 65536a b )x + 524288a  c - 131072a b
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                        6 6           5 2 5           4 4 4          3 6 3
+--R               - 131072a c  - 1888256a b c  + 2292864a b c  - 387552a b c
+--R             + 
+--R                        2 8 2           10
+--R               - 112360a b c  + 23990a b  c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         6   5           5 3 4           4 5 3           3 7 2
+--R               - 5718016a b c  - 1609728a b c  + 7740032a b c  - 2542816a b c
+--R             + 
+--R                      2 9            11
+--R               103480a b c + 23990a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                        7 5            6 2 4            5 4 3           4 6 2
+--R               - 475136a c  - 27480064a b c  + 21428864a b c  + 1200416a b c
+--R             + 
+--R                         3 8           2 10
+--R               - 2167496a b c + 239830a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                          7   4            6 3 3            5 5 2           4 7
+--R               - 20283392a b c  - 18464768a b c  + 30727168a b c  - 7474688a b c
+--R             + 
+--R                      3 9
+--R               315968a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                       8 4            7 2 3            6 4 2          5 6
+--R               1654784a c  - 53387264a b c  + 33406464a b c  + 399616a b c
+--R             + 
+--R                         4 8
+--R               - 1360096a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                       8   3            7 3 2            6 5            5 7  5
+--R           (- 16678912a b c  - 14819328a b c  + 19243008a b c - 3623936a b )x
+--R         + 
+--R                    9 3            8 2 2            7 4            6 6  4
+--R           (3309568a c  - 24305664a b c  + 16400384a b c - 2632704a b )x
+--R         + 
+--R                      9   2           8 3           7 5  3
+--R           (- 3145728a b c  + 2097152a b c - 327680a b )x
+--R         + 
+--R                   10 2          9 2           8 4  2
+--R           (655360a  c  - 720896a b c + 139264a b )x
+--R         + 
+--R                     10             9 3            11           10 2
+--R           (- 524288a  b c + 131072a b )x - 524288a  c + 131072a  b
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                       5 2 5          4 4 4          3 6 3          2 8 2
+--R               2314240a b c  - 993280a b c  - 643072a b c  + 174720a b c
+--R             + 
+--R                      10
+--R               5040a b  c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                       6   5            5 3 4           4 5 3         3 7 2
+--R               4014080a b c  + 10424320a b c  - 9195520a b c  - 91136a b c
+--R             + 
+--R                      2 9           11
+--R               423360a b c + 5040a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                         7 5            6 2 4           5 4 3            4 6 2
+--R               - 1228800a c  + 32624640a b c  - 2437120a b c  - 15287296a b c
+--R             + 
+--R                       3 8           2 10
+--R               2577344a b c + 253680a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                        7   4            6 3 3            5 5 2           4 7
+--R               12943360a b c  + 57262080a b c  - 41574400a b c  - 1457152a b c
+--R             + 
+--R                       3 9
+--R               2099328a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                         8 4            7 2 3           6 4 2            5 6
+--R               - 5324800a c  + 67543040a b c  - 8683520a b c  - 26610176a b c
+--R             + 
+--R                       4 8
+--R               6283584a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                     8   3            7 3 2            6 5            5 7  6
+--R           (10387456a b c  + 50995200a b c  - 45336576a b c + 8082944a b )x
+--R         + 
+--R                      9 3            8 2 2            7 4            6 6  5
+--R           (- 5406720a c  + 36364288a b c  - 25098240a b c + 4119040a b )x
+--R         + 
+--R                    9   2           8 3           7 5  4
+--R           (3145728a b c  - 2097152a b c + 327680a b )x
+--R         + 
+--R                     10 2          9 2           8 4  3
+--R           (- 655360a  c  + 720896a b c - 139264a b )x
+--R         + 
+--R                   10             9 3  2           11           10 2
+--R           (524288a  b c - 131072a b )x  + (524288a  c - 131072a  b )x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                        5   6           4 3 5           3 5 4          2 7 3
+--R               - 925696a b c  - 1454080a b c  + 1699840a b c  - 134400a b c
+--R             + 
+--R                         9 2
+--R               - 50400a b c
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                      6 6            5 2 5           4 4 4           3 6 3
+--R               245760a c  - 12804096a b c  + 1822720a b c  + 5890560a b c
+--R             + 
+--R                         2 8 2            10
+--R               - 1041600a b c  - 100800a b  c
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                         6   5            5 3 4            4 5 3           3 7 2
+--R               - 9240576a b c  - 38522880a b c  + 26403840a b c  + 3536640a b c
+--R             + 
+--R                         2 9            11
+--R               - 1780800a b c - 50400a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                       7 5            6 2 4            5 4 3            4 6 2
+--R               3276800a c  - 66232320a b c  - 10291200a b c  + 39795200a b c
+--R             + 
+--R                         3 8           2 10
+--R               - 5075840a b c - 873600a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                          7   4             6 3 3            5 5 2
+--R               - 16261120a b c  - 106926080a b c  + 67123200a b c
+--R             + 
+--R                       4 7            3 9
+--R               7471360a b c - 4472160a b
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                       8 4            7 2 3          6 4 2            5 6
+--R               7913472a c  - 90562560a b c  - 614400a b c  + 44342784a b c
+--R             + 
+--R                         4 8
+--R               - 9835200a b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                      8   3            7 3 2            6 5             5 7  6
+--R           (- 9453568a b c  - 67522560a b c  + 57390080a b c - 10094336a b )x
+--R         + 
+--R                    9 3            8 2 2            7 4            6 6  5
+--R           (5799936a c  - 38363136a b c  + 26286080a b c - 4297216a b )x
+--R         + 
+--R                      9   2           8 3           7 5  4
+--R           (- 2949120a b c  + 1802240a b c - 266240a b )x
+--R         + 
+--R                   10 2          9 2           8 4  3
+--R           (393216a  c  - 851968a b c + 188416a b )x
+--R         + 
+--R                     10             9 3  2             11           10 2
+--R           (- 786432a  b c + 196608a b )x  + (- 524288a  c + 131072a  b )x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                     9   3         8 3 2         7 5         6 7  9
+--R             (327680a b c  + 81920a b c  - 36864a b c - 1024a b )x
+--R           + 
+--R                     10 3           9 2 2          8 4          7 6  8
+--R             (655360a  c  + 1474560a b c  - 204800a b c - 51200a b )x
+--R           + 
+--R                      10   2          9 3           8 5  7
+--R             (3932160a  b c  + 655360a b c - 409600a b )x
+--R           + 
+--R                      11 2           10 2            9 4  6
+--R             (2621440a  c  + 3932160a  b c - 1146880a b )x
+--R           + 
+--R                      11              10 3  5            12           11 2  4
+--R             (5242880a  b c - 1310720a  b )x  + (2097152a  c - 524288a  b )x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                       9 4          8 2 3         7 4 2         6 6   10
+--R             (- 131072a c  - 294912a b c  + 40960a b c  + 10240a b c)x
+--R           + 
+--R                        9   3          8 3 2          7 5          6 7  9
+--R             (- 1703936a b c  - 557056a b c  + 204800a b c + 10240a b )x
+--R           + 
+--R                        10 3           9 2 2          8 4           7 6  8
+--R             (- 1703936a  c  - 4227072a b c  + 466944a b c + 174080a b )x
+--R           + 
+--R                        10   2           9 3           8 5  7
+--R             (- 7340032a  b c  - 1572864a b c + 851968a b )x
+--R           + 
+--R                        11 2           10 2            9 4  6
+--R             (- 3670016a  c  - 6029312a  b c + 1736704a b )x
+--R           + 
+--R                      11              10 3  5              12           11 2  4
+--R           (- 6291456a  b c + 1572864a  b )x  + (- 2097152a  c + 524288a  b )x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       4   4         3 3 3        2 5 2         7       9  9
+--R               (- 5120a b c  - 15360a b c  - 8064a b c  - 960a b c - 20b )x
+--R             + 
+--R                           5 4          4 2 3          3 4 2         2 6
+--R                   - 10240a c  - 112640a b c  - 126720a b c  - 29568a b c
+--R                 + 
+--R                            8
+--R                   - 1320a b
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                         5   3          4 3 2          3 5          2 7  7
+--R               (- 245760a b c  - 675840a b c  - 304128a b c - 25344a b )x
+--R             + 
+--R                         6 3           5 2 2           4 4           3 6  6
+--R               (- 163840a c  - 1597440a b c  - 1464320a b c - 219648a b )x
+--R             + 
+--R                          6   2           5 3            4 5  5
+--R               (- 1720320a b c  - 3727360a b c - 1025024a b )x
+--R             + 
+--R                         7 2           6 2            5 4  4
+--R               (- 688128a c  - 5160960a b c - 2795520a b )x
+--R             + 
+--R                          7              6 3  3              8            7 2  2
+--R               (- 3670016a b c - 4587520a b )x  + (- 1048576a c - 4456448a b )x
+--R             + 
+--R                         8             9
+--R               - 2359296a b x - 524288a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                      5 5         4 2 4         3 4 3        2 6 2         8
+--R                 1024a c  + 11520a b c  + 13440a b c  + 3360a b c  + 180a b c
+--R               + 
+--R                  10
+--R                 b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                  5   4          4 3 3         3 5 2        2 7          9  9
+--R           (51200a b c  + 153600a b c  + 80640a b c  + 9600a b c + 200a b )x
+--R         + 
+--R                  6 4          5 2 3          4 4 2          3 6         2 8  8
+--R           (51200a c  + 563200a b c  + 633600a b c  + 147840a b c + 6600a b )x
+--R         + 
+--R                   6   3           5 3 2           4 5          3 7  7
+--R           (819200a b c  + 2252800a b c  + 1013760a b c + 84480a b )x
+--R         + 
+--R                   7 3           6 2 2           5 4           4 6  6
+--R           (409600a c  + 3993600a b c  + 3660800a b c + 549120a b )x
+--R         + 
+--R                    7   2           6 3            5 5  5
+--R           (3440640a b c  + 7454720a b c + 2050048a b )x
+--R         + 
+--R                    8 2           7 2            6 4  4
+--R           (1146880a c  + 8601600a b c + 4659200a b )x
+--R         + 
+--R                    8              7 3  3            9            8 2  2
+--R           (5242880a b c + 6553600a b )x  + (1310720a c + 5570560a b )x
+--R         + 
+--R                   9             10
+--R           2621440a b x + 524288a
+--R      *
+--R          +------------------+
+--R          |   4      3      2
+--R         \|c x  + b x  + a x
+--R     + 
+--R                      5 5         4 2 4         3 4 3        2 6 2         8
+--R               - 1024a c  - 11520a b c  - 13440a b c  - 3360a b c  - 180a b c
+--R             + 
+--R                  10
+--R               - b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                    5   4          4 3 3         3 5 2        2 7          9  10
+--R           (- 51200a b c  - 153600a b c  - 80640a b c  - 9600a b c - 200a b )x
+--R         + 
+--R                         6 4          5 2 3          4 4 2          3 6
+--R                 - 51200a c  - 563200a b c  - 633600a b c  - 147840a b c
+--R               + 
+--R                        2 8
+--R                 - 6600a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                     6   3           5 3 2           4 5          3 7  8
+--R           (- 819200a b c  - 2252800a b c  - 1013760a b c - 84480a b )x
+--R         + 
+--R                     7 3           6 2 2           5 4           4 6  7
+--R           (- 409600a c  - 3993600a b c  - 3660800a b c - 549120a b )x
+--R         + 
+--R                      7   2           6 3            5 5  6
+--R           (- 3440640a b c  - 7454720a b c - 2050048a b )x
+--R         + 
+--R                      8 2           7 2            6 4  5
+--R           (- 1146880a c  - 8601600a b c - 4659200a b )x
+--R         + 
+--R                      8              7 3  4              9            8 2  3
+--R           (- 5242880a b c - 6553600a b )x  + (- 1310720a c - 5570560a b )x
+--R         + 
+--R                     9   2          10
+--R           - 2621440a b x  - 524288a  x
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                 4   5         3 3 4        2 5 3         7 2      9   12
+--R           (5120a b c  + 15360a b c  + 8064a b c  + 960a b c  + 20b c)x
+--R         + 
+--R                     5 5          4 2 4          3 4 3         2 6 2          8
+--R               10240a c  + 117760a b c  + 142080a b c  + 37632a b c  + 2280a b c
+--R             + 
+--R                  10
+--R               20b
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                        5   4          4 3 3          3 5 2         2 7
+--R                 261120a b c  + 803840a b c  + 438912a b c  + 55872a b c
+--R               + 
+--R                        9
+--R                 1340a b
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                      6 4           5 2 3           4 4 2          3 6
+--R               174080a c  + 1955840a b c  + 2266880a b c  + 553344a b c
+--R             + 
+--R                     2 8
+--R               26664a b
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                    6   3           5 3 2           4 5           3 7  8
+--R           (2129920a b c  + 6000640a b c  + 2793472a b c + 244992a b )x
+--R         + 
+--R                   7 3           6 2 2           5 4            4 6  7
+--R           (851968a c  + 8478720a b c  + 7987200a b c + 1244672a b )x
+--R         + 
+--R                    7   2            6 3            5 5  6
+--R           (6078464a b c  + 13475840a b c + 3820544a b )x
+--R         + 
+--R                    8 2            7 2            6 4  5
+--R           (1736704a c  + 13287424a b c + 7383040a b )x
+--R         + 
+--R                    8              7 3  4            9            8 2  3
+--R           (7077888a b c + 9043968a b )x  + (1572864a c + 6815744a b )x
+--R         + 
+--R                   9   2          10
+--R           2883584a b x  + 524288a  x
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                      5 6         4 2 5         3 4 4        2 6 3         8 2
+--R                 1024a c  + 11520a b c  + 13440a b c  + 3360a b c  + 180a b c
+--R               + 
+--R                  10
+--R                 b  c
+--R            *
+--R                17
+--R               x
+--R           + 
+--R                       5   5          4 3 4         3 5 3         2 7 2
+--R                 52224a b c  + 165120a b c  + 94080a b c  + 12960a b c
+--R               + 
+--R                       9     11
+--R                 380a b c + b
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                       6 5          5 2 4          4 4 3          3 6 2
+--R                 52224a c  + 625920a b c  + 800640a b c  + 231840a b c
+--R               + 
+--R                       2 8          10
+--R                 16380a b c + 201a b
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                        6   4           5 3 3           4 5 2          3 7
+--R                 921600a b c  + 2969600a b c  + 1728000a b c  + 241920a b c
+--R               + 
+--R                      2 9
+--R                 6800a b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                        7 4           6 2 3           5 4 2           4 6
+--R                 460800a c  + 5376000a b c  + 6547200a b c  + 1710720a b c
+--R               + 
+--R                       3 8
+--R                 91080a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                      7   3            6 3 2           5 5           4 7  12
+--R             (4669440a b c  + 13701120a b c  + 6724608a b c + 633600a b )x
+--R           + 
+--R                      8 3            7 2 2            6 4            5 6  11
+--R             (1556480a c  + 16035840a b c  + 15774720a b c + 2599168a b )x
+--R           + 
+--R                      8   2            7 3            6 5  10
+--R             (9830400a b c  + 22609920a b c + 6709248a b )x
+--R           + 
+--R                      9 2            8 2             7 4  9
+--R             (2457600a c  + 19415040a b c + 11212800a b )x
+--R           + 
+--R                      9               8 3  8            10            9 2  7
+--R             (9175040a b c + 12124160a b )x  + (1835008a  c + 8192000a b )x
+--R           + 
+--R                     10   6          11 5
+--R             3145728a  b x  + 524288a  x
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                     4   6         3 3 5        2 5 4         7 3      9 2  18
+--R             (- 5120a b c  - 15360a b c  - 8064a b c  - 960a b c  - 20b c )x
+--R           + 
+--R                         5 6          4 2 5          3 4 4         2 6 3
+--R                 - 10240a c  - 122880a b c  - 157440a b c  - 45696a b c
+--R               + 
+--R                          8 2      10
+--R                 - 3240a b c  - 40b  c
+--R            *
+--R                17
+--R               x
+--R           + 
+--R                          5   5          4 3 4          3 5 3         2 7 2
+--R                 - 276480a b c  - 936960a b c  - 589056a b c  - 94464a b c
+--R               + 
+--R                          9       11
+--R                 - 3640a b c - 20b
+--R            *
+--R                16
+--R               x
+--R           + 
+--R                          6 5           5 2 4           4 4 3           3 6 2
+--R                 - 184320a c  - 2334720a b c  - 3212800a b c  - 1029888a b c
+--R               + 
+--R                         2 8           10
+--R                 - 84816a b c - 1360a b
+--R            *
+--R                15
+--R               x
+--R           + 
+--R                           6   4           5 3 3           4 5 2          3 7
+--R                 - 2565120a b c  - 8760320a b c  - 5499264a b c  - 854208a b c
+--R               + 
+--R                         2 9
+--R                 - 28004a b
+--R            *
+--R                14
+--R               x
+--R           + 
+--R                           7 4            6 2 3            5 4 2           4 6
+--R                 - 1026048a c  - 12564480a b c  - 16254720a b c  - 4591488a b c
+--R               + 
+--R                          3 8
+--R                 - 271656a b
+--R            *
+--R                13
+--R               x
+--R           + 
+--R                        7   3            6 3 2            5 5            4 7  12
+--R             (- 9060352a b c  - 27955200a b c  - 14601216a b c - 1489664a b )x
+--R           + 
+--R                        8 3            7 2 2            6 4            5 6  11
+--R             (- 2588672a c  - 27844608a b c  - 28846080a b c - 5065216a b )x
+--R           + 
+--R                         8   2            7 3             6 5  10
+--R             (- 14893056a b c  - 35807232a b c - 11203584a b )x
+--R           + 
+--R                        9 2            8 2             7 4  9
+--R             (- 3309568a c  - 27181056a b c - 16427008a b )x
+--R           + 
+--R                         9               8 3  8
+--R             (- 11534336a b c - 15859712a b )x
+--R           + 
+--R                        10            9 2  7           10   6          11 5
+--R             (- 2097152a  c - 9699328a b )x  - 3407872a  b x  - 524288a  x
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +------------------+
+--R        |   4      3      2
+--R       \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 704
+t0:=x^m*(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R            5      3        m
+--R   (1)  (c x  + b x  + a x)x
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 704
+r0:=a*x^(2+m)/(2+m)+b*x^(4+m)/(4+m)+c*x^(6+m)/(6+m)
+--R 
+--R
+--R   (2)
+--R           2              m + 6       2               m + 4
+--R       (c m  + 6c m + 8c)x      + (b m  + 8b m + 12b)x
+--R     + 
+--R           2                m + 2
+--R       (a m  + 10a m + 24a)x
+--R  /
+--R      3      2
+--R     m  + 12m  + 44m + 48
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2              6       2               4       2                2
+--R       ((c m  + 6c m + 8c)x  + (b m  + 8b m + 12b)x  + (a m  + 10a m + 24a)x )
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      3      2
+--R     m  + 12m  + 44m + 48
+--R                                         Type: Union(Expression(Integer),...)
+--E 399
+
+--S 400 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2              6       2               4       2                2
+--R         ((c m  + 6c m + 8c)x  + (b m  + 8b m + 12b)x  + (a m  + 10a m + 24a)x )
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R             2              m + 6         2               m + 4
+--R       (- c m  - 6c m - 8c)x      + (- b m  - 8b m - 12b)x
+--R     + 
+--R             2                m + 2
+--R       (- a m  - 10a m - 24a)x
+--R  /
+--R      3      2
+--R     m  + 12m  + 44m + 48
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R            5      3         m log(x)      m + 5      m + 3      m + 1
+--R   (5)  (c x  + b x  + a x)%e         - c x      - b x      - a x
+--R                                                    Type: Expression(Integer)
+--E 401
+
+)clear all
+
+--S 402 of 704
+t0:=x^2*(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R           7      5      3
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 402
+
+--S 403 of 704
+r0:=1/4*a*x^4+1/6*b*x^6+1/8*c*x^8
+--R 
+--R
+--R        1    8   1    6   1    4
+--R   (2)  - c x  + - b x  + - a x
+--R        8        6        4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 403
+
+--S 404 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    8   1    6   1    4
+--R   (3)  - c x  + - b x  + - a x
+--R        8        6        4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 404
+
+--S 405 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 405
+
+--S 406 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 406
+
+)clear all
+
+--S 407 of 704
+t0:=x*(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R           6      4      2
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 407
+
+--S 408 of 704
+r0:=1/3*a*x^3+1/5*b*x^5+1/7*c*x^7
+--R 
+--R
+--R        1    7   1    5   1    3
+--R   (2)  - c x  + - b x  + - a x
+--R        7        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 408
+
+--S 409 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    7   1    5   1    3
+--R   (3)  - c x  + - b x  + - a x
+--R        7        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 409
+
+--S 410 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 410
+
+--S 411 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 411
+
+)clear all
+
+--S 412 of 704
+t0:=a*x+b*x^3+c*x^5
+--R 
+--R
+--R           5      3
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 412
+
+--S 413 of 704
+r0:=1/2*a*x^2+1/4*b*x^4+1/6*c*x^6
+--R 
+--R
+--R        1    6   1    4   1    2
+--R   (2)  - c x  + - b x  + - a x
+--R        6        4        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 413
+
+--S 414 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    6   1    4   1    2
+--R   (3)  - c x  + - b x  + - a x
+--R        6        4        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 414
+
+--S 415 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 415
+
+--S 416 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 416
+
+)clear all
+
+--S 417 of 704
+t0:=(a*x+b*x^3+c*x^5)/x
+--R 
+--R
+--R           4      2
+--R   (1)  c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 417
+
+--S 418 of 704
+r0:=a*x+1/3*b*x^3+1/5*c*x^5
+--R 
+--R
+--R        1    5   1    3
+--R   (2)  - c x  + - b x  + a x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 418
+
+--S 419 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5       3
+--R        3c x  + 5b x  + 15a x
+--R   (3)  ---------------------
+--R                  15
+--R                                         Type: Union(Expression(Integer),...)
+--E 419
+
+--S 420 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+--S 421 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 421
+
+)clear all
+
+--S 422 of 704
+t0:=(a*x+b*x^3+c*x^5)/x^2
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R               x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 422
+
+--S 423 of 704
+r0:=1/2*b*x^2+1/4*c*x^4+a*log(x)
+--R 
+--R
+--R                       4       2
+--R        4a log(x) + c x  + 2b x
+--R   (2)  ------------------------
+--R                    4
+--R                                                    Type: Expression(Integer)
+--E 423
+
+--S 424 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       4       2
+--R        4a log(x) + c x  + 2b x
+--R   (3)  ------------------------
+--R                    4
+--R                                         Type: Union(Expression(Integer),...)
+--E 424
+
+--S 425 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 704
+t0:=(a*x+b*x^3+c*x^5)/x^3
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R                2
+--R               x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 427
+
+--S 428 of 704
+r0:=-a/x+b*x+1/3*c*x^3
+--R 
+--R
+--R           4       2
+--R        c x  + 3b x  - 3a
+--R   (2)  -----------------
+--R                3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 428
+
+--S 429 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4       2
+--R        c x  + 3b x  - 3a
+--R   (3)  -----------------
+--R                3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 429
+
+--S 430 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 431
+
+)clear all
+
+--S 432 of 704
+t0:=x^m*(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R          2 10         8            2  6         4    2 2  m
+--R   (1)  (c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x )x
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 704
+r0:=a^2*x^(3+m)/(3+m)+2*a*b*x^(5+m)/(5+m)+(b^2+2*a*c)*x^(7+m)/(7+m)+_
+   2*b*c*x^(9+m)/(9+m)+c^2*x^(11+m)/(11+m)
+--R 
+--R
+--R   (2)
+--R         2 4      2 3       2 2       2        2  m + 11
+--R       (c m  + 24c m  + 206c m  + 744c m + 945c )x
+--R     + 
+--R              4          3           2                        m + 9
+--R       (2b c m  + 52b c m  + 472b c m  + 1772b c m + 2310b c)x
+--R     + 
+--R                    2  4               2  3                 2  2
+--R           (2a c + b )m  + (56a c + 28b )m  + (548a c + 274b )m
+--R         + 
+--R                           2                    2
+--R           (2184a c + 1092b )m + 2970a c + 1485b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R              4          3           2                        m + 5
+--R       (2a b m  + 60a b m  + 640a b m  + 2820a b m + 4158a b)x
+--R     + 
+--R         2 4      2 3       2 2        2         2  m + 3
+--R       (a m  + 32a m  + 374a m  + 1888a m + 3465a )x
+--R  /
+--R      5      4       3        2
+--R     m  + 35m  + 470m  + 3010m  + 9129m + 10395
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 4      2 3       2 2       2        2  11
+--R         (c m  + 24c m  + 206c m  + 744c m + 945c )x
+--R       + 
+--R                4          3           2                        9
+--R         (2b c m  + 52b c m  + 472b c m  + 1772b c m + 2310b c)x
+--R       + 
+--R                      2  4               2  3                 2  2
+--R             (2a c + b )m  + (56a c + 28b )m  + (548a c + 274b )m
+--R           + 
+--R                             2                    2
+--R             (2184a c + 1092b )m + 2970a c + 1485b
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                4          3           2                        5
+--R         (2a b m  + 60a b m  + 640a b m  + 2820a b m + 4158a b)x
+--R       + 
+--R           2 4      2 3       2 2        2         2  3
+--R         (a m  + 32a m  + 374a m  + 1888a m + 3465a )x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      5      4       3        2
+--R     m  + 35m  + 470m  + 3010m  + 9129m + 10395
+--R                                         Type: Union(Expression(Integer),...)
+--E 434
+
+--S 435 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2 4      2 3       2 2       2        2  11
+--R           (c m  + 24c m  + 206c m  + 744c m + 945c )x
+--R         + 
+--R                  4          3           2                        9
+--R           (2b c m  + 52b c m  + 472b c m  + 1772b c m + 2310b c)x
+--R         + 
+--R                        2  4               2  3                 2  2
+--R               (2a c + b )m  + (56a c + 28b )m  + (548a c + 274b )m
+--R             + 
+--R                               2                    2
+--R               (2184a c + 1092b )m + 2970a c + 1485b
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                  4          3           2                        5
+--R           (2a b m  + 60a b m  + 640a b m  + 2820a b m + 4158a b)x
+--R         + 
+--R             2 4      2 3       2 2        2         2  3
+--R           (a m  + 32a m  + 374a m  + 1888a m + 3465a )x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           2 4      2 3       2 2       2        2  m + 11
+--R       (- c m  - 24c m  - 206c m  - 744c m - 945c )x
+--R     + 
+--R                4          3           2                        m + 9
+--R       (- 2b c m  - 52b c m  - 472b c m  - 1772b c m - 2310b c)x
+--R     + 
+--R                      2  4                 2  3                   2  2
+--R           (- 2a c - b )m  + (- 56a c - 28b )m  + (- 548a c - 274b )m
+--R         + 
+--R                             2                    2
+--R           (- 2184a c - 1092b )m - 2970a c - 1485b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R                4          3           2                        m + 5
+--R       (- 2a b m  - 60a b m  - 640a b m  - 2820a b m - 4158a b)x
+--R     + 
+--R           2 4      2 3       2 2        2         2  m + 3
+--R       (- a m  - 32a m  - 374a m  - 1888a m - 3465a )x
+--R  /
+--R      5      4       3        2
+--R     m  + 35m  + 470m  + 3010m  + 9129m + 10395
+--R                                                    Type: Expression(Integer)
+--E 435
+
+--S 436 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R       2 10         8            2  6         4    2 2   m log(x)    2 m + 10
+--R     (c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x )%e         - c x
+--R   + 
+--R             m + 8              2  m + 6         m + 4    2 m + 2
+--R     - 2b c x      + (- 2a c - b )x      - 2a b x      - a x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+)clear all
+
+--S 437 of 704
+t0:=x^2*(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R         2 12         10            2  8         6    2 4
+--R   (1)  c x   + 2b c x   + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 437
+
+--S 438 of 704
+r0:=1/5*a^2*x^5+2/7*a*b*x^7+1/9*(b^2+2*a*c)*x^9+2/11*b*c*x^11+1/13*c^2*x^13
+--R 
+--R
+--R         1  2 13    2      11    2       1  2  9   2      7   1  2 5
+--R   (2)  -- c x   + -- b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        13         11            9       9         7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 438
+
+--S 439 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  2 13    2      11    2       1  2  9   2      7   1  2 5
+--R   (3)  -- c x   + -- b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        13         11            9       9         7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 439
+
+--S 440 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 440
+
+--S 441 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 441
+
+)clear all
+
+--S 442 of 704
+t0:=x*(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R         2 11         9            2  7         5    2 3
+--R   (1)  c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 442
+
+--S 443 of 704
+r0:=1/4*a^2*x^4+1/3*a*b*x^6+1/8*(b^2+2*a*c)*x^8+1/5*b*c*x^10+1/12*c^2*x^12
+--R 
+--R
+--R         1  2 12   1      10    1       1  2  8   1      6   1  2 4
+--R   (2)  -- c x   + - b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        12         5            4       8         3          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 443
+
+--S 444 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  2 12   1      10    1       1  2  8   1      6   1  2 4
+--R   (3)  -- c x   + - b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        12         5            4       8         3          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 444
+
+--S 445 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 445
+
+--S 446 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 446
+
+)clear all
+
+--S 447 of 704
+t0:=(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R         2 10         8            2  6         4    2 2
+--R   (1)  c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 447
+
+--S 448 of 704
+r0:=1/3*a^2*x^3+2/5*a*b*x^5+1/7*(b^2+2*a*c)*x^7+2/9*b*c*x^9+1/11*c^2*x^11
+--R 
+--R
+--R         1  2 11   2      9    2       1  2  7   2      5   1  2 3
+--R   (2)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        11         9           7       7         5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 448
+
+--S 449 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1  2 11   2      9    2       1  2  7   2      5   1  2 3
+--R   (3)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        11         9           7       7         5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 449
+
+--S 450 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 450
+
+--S 451 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 451
+
+)clear all
+
+--S 452 of 704
+t0:=(a*x+b*x^3+c*x^5)^2/x
+--R 
+--R
+--R         2 9         7            2  5         3    2
+--R   (1)  c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 452
+
+--S 453 of 704
+r0:=1/2*a^2*x^2+1/2*a*b*x^4+1/6*(b^2+2*a*c)*x^6+1/4*b*c*x^8+1/10*c^2*x^10
+--R 
+--R
+--R         1  2 10   1      8    1       1  2  6   1      4   1  2 2
+--R   (2)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        10         4           3       6         2          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 453
+
+--S 454 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 10          8               2  6          4      2 2
+--R        6c x   + 15b c x  + (20a c + 10b )x  + 30a b x  + 30a x
+--R   (3)  --------------------------------------------------------
+--R                                   60
+--R                                         Type: Union(Expression(Integer),...)
+--E 454
+
+--S 455 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 704
+t0:=(a*x+b*x^3+c*x^5)^2/x^2
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R   (1)  c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 457
+
+--S 458 of 704
+r0:=a^2*x+2/3*a*b*x^3+1/5*(b^2+2*a*c)*x^5+2/7*b*c*x^7+1/9*c^2*x^9
+--R 
+--R
+--R        1  2 9   2      7    2       1  2  5   2      3    2
+--R   (2)  - c x  + - b c x  + (- a c + - b )x  + - a b x  + a x
+--R        9        7           5       5         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 458
+
+--S 459 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 9          7                2  5           3       2
+--R        35c x  + 90b c x  + (126a c + 63b )x  + 210a b x  + 315a x
+--R   (3)  ----------------------------------------------------------
+--R                                    315
+--R                                         Type: Union(Expression(Integer),...)
+--E 459
+
+--S 460 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 461
+
+)clear all
+
+--S 462 of 704
+t0:=x^8/(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R                7
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 462
+
+--S 463 of 704
+r0:=-1/2*b*x^2/c^2+1/4*x^4/c+1/4*(b^2-a*c)*log(a+b*x^2+c*x^4)/c^3+_
+   1/2*b*(b^2-3*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                    2
+--R                     3          2c x  + b
+--R       (- 6a b c + 2b )atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                                           +-----------+
+--R                  2        4      2         2 4         2  |          2
+--R       ((- a c + b )log(c x  + b x  + a) + c x  - 2b c x )\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      3
+--R           (3a b c - b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                                             +-----------+
+--R                    2        4      2         2 4         2  |          2
+--R         ((- a c + b )log(c x  + b x  + a) + c x  - 2b c x )\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         3 |          2
+--R       4c \|- 4a c + b
+--R     ,
+--R
+--R                                        +---------+
+--R                                 2      |        2
+--R                     3      (2c x  + b)\|4a c - b
+--R         (6a b c - 2b )atan(-----------------------)
+--R                                           2
+--R                                   4a c - b
+--R       + 
+--R                                                             +---------+
+--R                    2        4      2         2 4         2  |        2
+--R         ((- a c + b )log(c x  + b x  + a) + c x  - 2b c x )\|4a c - b
+--R    /
+--R           +---------+
+--R         3 |        2
+--R       4c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 464
+
+--S 465 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (3a b c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                  2
+--R                   3          2c x  + b
+--R       (6a b c - 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+             2
+--R                  3  |        2          2c x  + b
+--R       (3a b c - b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                     +-----------+          2      |        2
+--R                  3  |          2      (2c x  + b)\|4a c - b
+--R       (3a b c - b )\|- 4a c + b  atan(-----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       3 |          2  |        2
+--R     2c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 704
+t0:=x^7/(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R                6
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 469
+
+--S 470 of 704
+r0:=-b*x/c^2+1/3*x^3/c+atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b^2-a*c-b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (b^2-a*c+b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                       +------------------+
+--R                         +-----------+                 | +-----------+
+--R                      2  |          2               3  | |          2
+--R         ((- 3a c + 3b )\|- 4a c + b   + 9a b c - 3b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                       +--------------------+
+--R                         +-----------+                 |   +-----------+
+--R                      2  |          2               3  |   |          2
+--R         ((- 3a c + 3b )\|- 4a c + b   - 9a b c + 3b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                             +--------------------+
+--R                           +-----------+     |   +-----------+
+--R             3         +-+ |          2  +-+ |   |          2
+--R         (c x  - 3b x)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     3c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R              2
+--R            3c
+--R         *
+--R            ROOT
+--R                                    +-----------------------------------------+
+--R                                    |   4 4     3 2 3      2 4 2       6     8
+--R                         6     2 5  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   (16a c  - 4b c ) |-----------------------------------------
+--R                                    |                 11      2 10
+--R                                   \|            64a c   - 16b c
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                     6     2 5
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                           2 7        2 6     4 5
+--R                       (32a c  - 24a b c  + 4b c )
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |                 11      2 10
+--R                       \|            64a c   - 16b c
+--R                   + 
+--R                         3   3      2 3 2       5     7
+--R                     - 4a b c  + 13a b c  - 7a b c + b
+--R                *
+--R                   ROOT
+--R                                  6     2 5
+--R                            (16a c  - 4b c )
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |                 11      2 10
+--R                            \|            64a c   - 16b c
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                            6     2 5
+--R                        8a c  - 2b c
+--R               + 
+--R                    4 2     3 2      2 4
+--R                 (2a c  - 6a b c + 2a b )x
+--R     + 
+--R           2
+--R         3c
+--R      *
+--R         ROOT
+--R                                   +-----------------------------------------+
+--R                                   |   4 4     3 2 3      2 4 2       6     8
+--R                        6     2 5  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (- 16a c  + 4b c ) |-----------------------------------------
+--R                                   |                 11      2 10
+--R                                  \|            64a c   - 16b c
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                        2 7        2 6     4 5
+--R                    (32a c  - 24a b c  + 4b c )
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |                 11      2 10
+--R                    \|            64a c   - 16b c
+--R                + 
+--R                    3   3      2 3 2       5     7
+--R                  4a b c  - 13a b c  + 7a b c - b
+--R             *
+--R                ROOT
+--R                                 6     2 5
+--R                         (- 16a c  + 4b c )
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |                 11      2 10
+--R                         \|            64a c   - 16b c
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                         6     2 5
+--R                     8a c  - 2b c
+--R            + 
+--R                 4 2     3 2      2 4
+--R              (2a c  - 6a b c + 2a b )x
+--R     + 
+--R       -
+--R              2
+--R            3c
+--R         *
+--R            ROOT
+--R                             6     2 5
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                      +-----------------------------------------+
+--R                      |   4 4     3 2 3      2 4 2       6     8
+--R                      |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                      |-----------------------------------------
+--R                      |                 11      2 10
+--R                     \|            64a c   - 16b c
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                     6     2 5
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                             2 7        2 6     4 5
+--R                       (- 32a c  + 24a b c  - 4b c )
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |                 11      2 10
+--R                       \|            64a c   - 16b c
+--R                   + 
+--R                         3   3      2 3 2       5     7
+--R                     - 4a b c  + 13a b c  - 7a b c + b
+--R                *
+--R                   ROOT
+--R                                    6     2 5
+--R                            (- 16a c  + 4b c )
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |                 11      2 10
+--R                            \|            64a c   - 16b c
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                            6     2 5
+--R                        8a c  - 2b c
+--R               + 
+--R                    4 2     3 2      2 4
+--R                 (2a c  - 6a b c + 2a b )x
+--R     + 
+--R           2
+--R         3c
+--R      *
+--R         ROOT
+--R                                 +-----------------------------------------+
+--R                                 |   4 4     3 2 3      2 4 2       6     8
+--R                      6     2 5  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (16a c  - 4b c ) |-----------------------------------------
+--R                                 |                 11      2 10
+--R                                \|            64a c   - 16b c
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                          2 7        2 6     4 5
+--R                    (- 32a c  + 24a b c  - 4b c )
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |                 11      2 10
+--R                    \|            64a c   - 16b c
+--R                + 
+--R                    3   3      2 3 2       5     7
+--R                  4a b c  - 13a b c  + 7a b c - b
+--R             *
+--R                ROOT
+--R                               6     2 5
+--R                         (16a c  - 4b c )
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |                 11      2 10
+--R                         \|            64a c   - 16b c
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                         6     2 5
+--R                     8a c  - 2b c
+--R            + 
+--R                 4 2     3 2      2 4
+--R              (2a c  - 6a b c + 2a b )x
+--R     + 
+--R           3
+--R       2c x  - 6b x
+--R  /
+--R       2
+--R     6c
+--R                                         Type: Union(Expression(Integer),...)
+--E 471
+
+--S 472 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                     +--------------------+ +------------------+
+--R                   +-----------+     |   +-----------+      | +-----------+
+--R             2 +-+ |          2  +-+ |   |          2       | |          2
+--R            c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            ROOT
+--R                                    +-----------------------------------------+
+--R                                    |   4 4     3 2 3      2 4 2       6     8
+--R                         6     2 5  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                   (16a c  - 4b c ) |-----------------------------------------
+--R                                    |                 11      2 10
+--R                                   \|            64a c   - 16b c
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                     6     2 5
+--R                 8a c  - 2b c
+--R         *
+--R            log
+--R                           2 7        2 6     4 5
+--R                       (32a c  - 24a b c  + 4b c )
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |                 11      2 10
+--R                       \|            64a c   - 16b c
+--R                   + 
+--R                         3   3      2 3 2       5     7
+--R                     - 4a b c  + 13a b c  - 7a b c + b
+--R                *
+--R                   ROOT
+--R                                  6     2 5
+--R                            (16a c  - 4b c )
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |                 11      2 10
+--R                            \|            64a c   - 16b c
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                            6     2 5
+--R                        8a c  - 2b c
+--R               + 
+--R                    4 2     3 2      2 4
+--R                 (2a c  - 6a b c + 2a b )x
+--R     + 
+--R                +-----------+
+--R          2 +-+ |          2  +-+
+--R         c \|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                                   +-----------------------------------------+
+--R                                   |   4 4     3 2 3      2 4 2       6     8
+--R                        6     2 5  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (- 16a c  + 4b c ) |-----------------------------------------
+--R                                   |                 11      2 10
+--R                                  \|            64a c   - 16b c
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                        2 7        2 6     4 5
+--R                    (32a c  - 24a b c  + 4b c )
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |                 11      2 10
+--R                    \|            64a c   - 16b c
+--R                + 
+--R                    3   3      2 3 2       5     7
+--R                  4a b c  - 13a b c  + 7a b c - b
+--R             *
+--R                ROOT
+--R                                 6     2 5
+--R                         (- 16a c  + 4b c )
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |                 11      2 10
+--R                         \|            64a c   - 16b c
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                         6     2 5
+--R                     8a c  - 2b c
+--R            + 
+--R                 4 2     3 2      2 4
+--R              (2a c  - 6a b c + 2a b )x
+--R     + 
+--R       -
+--R                   +-----------+
+--R             2 +-+ |          2  +-+
+--R            c \|2 \|- 4a c + b  \|c
+--R         *
+--R            ROOT
+--R                             6     2 5
+--R                     (- 16a c  + 4b c )
+--R                  *
+--R                      +-----------------------------------------+
+--R                      |   4 4     3 2 3      2 4 2       6     8
+--R                      |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                      |-----------------------------------------
+--R                      |                 11      2 10
+--R                     \|            64a c   - 16b c
+--R                 + 
+--R                     2   2       3     5
+--R                   5a b c  - 5a b c + b
+--R              /
+--R                     6     2 5
+--R                 8a c  - 2b c
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                             2 7        2 6     4 5
+--R                       (- 32a c  + 24a b c  - 4b c )
+--R                    *
+--R                        +-----------------------------------------+
+--R                        |   4 4     3 2 3      2 4 2       6     8
+--R                        |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                        |-----------------------------------------
+--R                        |                 11      2 10
+--R                       \|            64a c   - 16b c
+--R                   + 
+--R                         3   3      2 3 2       5     7
+--R                     - 4a b c  + 13a b c  - 7a b c + b
+--R                *
+--R                   ROOT
+--R                                    6     2 5
+--R                            (- 16a c  + 4b c )
+--R                         *
+--R                             +-----------------------------------------+
+--R                             |   4 4     3 2 3      2 4 2       6     8
+--R                             |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                             |-----------------------------------------
+--R                             |                 11      2 10
+--R                            \|            64a c   - 16b c
+--R                        + 
+--R                            2   2       3     5
+--R                          5a b c  - 5a b c + b
+--R                     /
+--R                            6     2 5
+--R                        8a c  - 2b c
+--R               + 
+--R                    4 2     3 2      2 4
+--R                 (2a c  - 6a b c + 2a b )x
+--R     + 
+--R                                  +--------------------+ +------------------+
+--R                +-----------+     |   +-----------+      | +-----------+
+--R          2 +-+ |          2  +-+ |   |          2       | |          2
+--R         c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                                 +-----------------------------------------+
+--R                                 |   4 4     3 2 3      2 4 2       6     8
+--R                      6     2 5  |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                (16a c  - 4b c ) |-----------------------------------------
+--R                                 |                 11      2 10
+--R                                \|            64a c   - 16b c
+--R              + 
+--R                  2   2       3     5
+--R                5a b c  - 5a b c + b
+--R           /
+--R                  6     2 5
+--R              8a c  - 2b c
+--R      *
+--R         log
+--R                          2 7        2 6     4 5
+--R                    (- 32a c  + 24a b c  - 4b c )
+--R                 *
+--R                     +-----------------------------------------+
+--R                     |   4 4     3 2 3      2 4 2       6     8
+--R                     |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                     |-----------------------------------------
+--R                     |                 11      2 10
+--R                    \|            64a c   - 16b c
+--R                + 
+--R                    3   3      2 3 2       5     7
+--R                  4a b c  - 13a b c  + 7a b c - b
+--R             *
+--R                ROOT
+--R                               6     2 5
+--R                         (16a c  - 4b c )
+--R                      *
+--R                          +-----------------------------------------+
+--R                          |   4 4     3 2 3      2 4 2       6     8
+--R                          |- a c  + 6a b c  - 11a b c  + 6a b c - b
+--R                          |-----------------------------------------
+--R                          |                 11      2 10
+--R                         \|            64a c   - 16b c
+--R                     + 
+--R                         2   2       3     5
+--R                       5a b c  - 5a b c + b
+--R                  /
+--R                         6     2 5
+--R                     8a c  - 2b c
+--R            + 
+--R                 4 2     3 2      2 4
+--R              (2a c  - 6a b c + 2a b )x
+--R     + 
+--R                                                     +------------------+
+--R                       +-----------+                 | +-----------+
+--R                    2  |          2               3  | |          2
+--R         ((2a c - 2b )\|- 4a c + b   - 6a b c + 2b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                       +-----------+                 |   +-----------+
+--R                    2  |          2               3  |   |          2
+--R         ((2a c - 2b )\|- 4a c + b   + 6a b c - 2b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 473
+
+)clear all
+
+--S 474 of 704
+t0:=x^6/(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R                5
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 474
+
+--S 475 of 704
+r0:=1/2*x^2/c-1/4*b*log(a+b*x^2+c*x^4)/c^2-1/2*(b^2-2*a*c)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                2
+--R                 2          2c x  + b
+--R       (4a c - 2b )atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                          +-----------+
+--R                   4      2            2  |          2
+--R       (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2
+--R           (2a c - b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                            +-----------+
+--R                     4      2            2  |          2
+--R         (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R    /
+--R           +-----------+
+--R         2 |          2
+--R       4c \|- 4a c + b
+--R     ,
+--R
+--R                                        +---------+
+--R                                 2      |        2
+--R                     2      (2c x  + b)\|4a c - b
+--R         (- 4a c + 2b )atan(-----------------------)
+--R                                           2
+--R                                   4a c - b
+--R       + 
+--R                                            +---------+
+--R                     4      2            2  |        2
+--R         (- b log(c x  + b x  + a) + 2c x )\|4a c - b
+--R    /
+--R           +---------+
+--R         2 |        2
+--R       4c \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 476
+
+--S 477 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                  2
+--R                   2          2c x  + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+             2
+--R                  2  |        2          2c x  + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                     +-----------+          2      |        2
+--R                  2  |          2      (2c x  + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     2c \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 704
+t0:=x^5/(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 481
+
+--S 482 of 704
+r0:=x/c-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+_
+   (-b^2+2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R              +-----------+              | +-----------+
+--R              |          2            2  | |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R              +-----------+              |   +-----------+
+--R              |          2            2  |   |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R         +-+ |          2  +-+ |   |          2       | |          2
+--R       x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-----------------------------------------------------+
+--R           |                 +--------------------+
+--R           |                 |   2 2       2     4
+--R           |      4     2 3  |- a c  + 2a b c - b               3
+--R           |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R           |                 |        7      2 6
+--R           |                \|   64a c  - 16b c
+--R         c |-----------------------------------------------------
+--R           |                        4     2 3
+--R          \|                    8a c  - 2b c
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                    (16a b c  - 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                  + 
+--R                       4
+--R                    - b
+--R             *
+--R                 +-----------------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |                 |   2 2       2     4
+--R                 |      4     2 3  |- a c  + 2a b c - b               3
+--R                 |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R                 |                 |        7      2 6
+--R                 |                \|   64a c  - 16b c
+--R                 |-----------------------------------------------------
+--R                 |                        4     2 3
+--R                \|                    8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       -
+--R              +-------------------------------------------------------+
+--R              |                   +--------------------+
+--R              |                   |   2 2       2     4
+--R              |        4     2 3  |- a c  + 2a b c - b               3
+--R              |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R              |                   |        7      2 6
+--R              |                  \|   64a c  - 16b c
+--R            c |-------------------------------------------------------
+--R              |                         4     2 3
+--R             \|                     8a c  - 2b c
+--R         *
+--R            log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                             4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                     (16a b c  - 4b c ) |--------------------  + 4a c  - 5a b c
+--R                                        |        7      2 6
+--R                                       \|   64a c  - 16b c
+--R                   + 
+--R                      4
+--R                     b
+--R                *
+--R                    +-------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |        4     2 3  |- a c  + 2a b c - b               3
+--R                    |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R                    |                   |        7      2 6
+--R                    |                  \|   64a c  - 16b c
+--R                    |-------------------------------------------------------
+--R                    |                         4     2 3
+--R                   \|                     8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R           +-------------------------------------------------------+
+--R           |                   +--------------------+
+--R           |                   |   2 2       2     4
+--R           |        4     2 3  |- a c  + 2a b c - b               3
+--R           |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R           |                   |        7      2 6
+--R           |                  \|   64a c  - 16b c
+--R         c |-------------------------------------------------------
+--R           |                         4     2 3
+--R          \|                     8a c  - 2b c
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                  (- 16a b c  + 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                + 
+--R                     4
+--R                  - b
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |        4     2 3  |- a c  + 2a b c - b               3
+--R                 |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R                 |                   |        7      2 6
+--R                 |                  \|   64a c  - 16b c
+--R                 |-------------------------------------------------------
+--R                 |                         4     2 3
+--R                \|                     8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       -
+--R              +-----------------------------------------------------+
+--R              |                 +--------------------+
+--R              |                 |   2 2       2     4
+--R              |      4     2 3  |- a c  + 2a b c - b               3
+--R              |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R              |                 |        7      2 6
+--R              |                \|   64a c  - 16b c
+--R            c |-----------------------------------------------------
+--R              |                        4     2 3
+--R             \|                    8a c  - 2b c
+--R         *
+--R            log
+--R                                          +--------------------+
+--R                                          |   2 2       2     4
+--R                               4     3 3  |- a c  + 2a b c - b       2 2
+--R                     (- 16a b c  + 4b c ) |--------------------  + 4a c
+--R                                          |        7      2 6
+--R                                         \|   64a c  - 16b c
+--R                   + 
+--R                           2     4
+--R                     - 5a b c + b
+--R                *
+--R                    +-----------------------------------------------------+
+--R                    |                 +--------------------+
+--R                    |                 |   2 2       2     4
+--R                    |      4     2 3  |- a c  + 2a b c - b               3
+--R                    |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R                    |                 |        7      2 6
+--R                    |                \|   64a c  - 16b c
+--R                    |-----------------------------------------------------
+--R                    |                        4     2 3
+--R                   \|                    8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R       2x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 483
+
+--S 484 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R         c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------------------------------------+
+--R          |                 +--------------------+
+--R          |                 |   2 2       2     4
+--R          |      4     2 3  |- a c  + 2a b c - b               3
+--R          |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R          |                 |        7      2 6
+--R          |                \|   64a c  - 16b c
+--R          |-----------------------------------------------------
+--R          |                        4     2 3
+--R         \|                    8a c  - 2b c
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                    (16a b c  - 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                  + 
+--R                       4
+--R                    - b
+--R             *
+--R                 +-----------------------------------------------------+
+--R                 |                 +--------------------+
+--R                 |                 |   2 2       2     4
+--R                 |      4     2 3  |- a c  + 2a b c - b               3
+--R                 |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R                 |                 |        7      2 6
+--R                 |                \|   64a c  - 16b c
+--R                 |-----------------------------------------------------
+--R                 |                        4     2 3
+--R                \|                    8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            c\|2 \|- 4a c + b  \|c
+--R         *
+--R             +-------------------------------------------------------+
+--R             |                   +--------------------+
+--R             |                   |   2 2       2     4
+--R             |        4     2 3  |- a c  + 2a b c - b               3
+--R             |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R             |                   |        7      2 6
+--R             |                  \|   64a c  - 16b c
+--R             |-------------------------------------------------------
+--R             |                         4     2 3
+--R            \|                     8a c  - 2b c
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                        +--------------------+
+--R                                        |   2 2       2     4
+--R                             4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                     (16a b c  - 4b c ) |--------------------  + 4a c  - 5a b c
+--R                                        |        7      2 6
+--R                                       \|   64a c  - 16b c
+--R                   + 
+--R                      4
+--R                     b
+--R                *
+--R                    +-------------------------------------------------------+
+--R                    |                   +--------------------+
+--R                    |                   |   2 2       2     4
+--R                    |        4     2 3  |- a c  + 2a b c - b               3
+--R                    |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R                    |                   |        7      2 6
+--R                    |                  \|   64a c  - 16b c
+--R                    |-------------------------------------------------------
+--R                    |                         4     2 3
+--R                   \|                     8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2  +-+
+--R         c\|2 \|- 4a c + b  \|c
+--R      *
+--R          +-------------------------------------------------------+
+--R          |                   +--------------------+
+--R          |                   |   2 2       2     4
+--R          |        4     2 3  |- a c  + 2a b c - b               3
+--R          |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R          |                   |        7      2 6
+--R          |                  \|   64a c  - 16b c
+--R          |-------------------------------------------------------
+--R          |                         4     2 3
+--R         \|                     8a c  - 2b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                       +--------------------+
+--R                                       |   2 2       2     4
+--R                            4     3 3  |- a c  + 2a b c - b       2 2       2
+--R                  (- 16a b c  + 4b c ) |--------------------  - 4a c  + 5a b c
+--R                                       |        7      2 6
+--R                                      \|   64a c  - 16b c
+--R                + 
+--R                     4
+--R                  - b
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |                   +--------------------+
+--R                 |                   |   2 2       2     4
+--R                 |        4     2 3  |- a c  + 2a b c - b               3
+--R                 |(- 16a c  + 4b c ) |--------------------  - 3a b c + b
+--R                 |                   |        7      2 6
+--R                 |                  \|   64a c  - 16b c
+--R                 |-------------------------------------------------------
+--R                 |                         4     2 3
+--R                \|                     8a c  - 2b c
+--R            + 
+--R                 2        2
+--R              (2a c - 2a b )x
+--R     + 
+--R       -
+--R                                    +--------------------+ +------------------+
+--R                  +-----------+     |   +-----------+      | +-----------+
+--R              +-+ |          2  +-+ |   |          2       | |          2
+--R            c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +-----------------------------------------------------+
+--R             |                 +--------------------+
+--R             |                 |   2 2       2     4
+--R             |      4     2 3  |- a c  + 2a b c - b               3
+--R             |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R             |                 |        7      2 6
+--R             |                \|   64a c  - 16b c
+--R             |-----------------------------------------------------
+--R             |                        4     2 3
+--R            \|                    8a c  - 2b c
+--R         *
+--R            log
+--R                                          +--------------------+
+--R                                          |   2 2       2     4
+--R                               4     3 3  |- a c  + 2a b c - b       2 2
+--R                     (- 16a b c  + 4b c ) |--------------------  + 4a c
+--R                                          |        7      2 6
+--R                                         \|   64a c  - 16b c
+--R                   + 
+--R                           2     4
+--R                     - 5a b c + b
+--R                *
+--R                    +-----------------------------------------------------+
+--R                    |                 +--------------------+
+--R                    |                 |   2 2       2     4
+--R                    |      4     2 3  |- a c  + 2a b c - b               3
+--R                    |(16a c  - 4b c ) |--------------------  - 3a b c + b
+--R                    |                 |        7      2 6
+--R                    |                \|   64a c  - 16b c
+--R                    |-----------------------------------------------------
+--R                    |                        4     2 3
+--R                   \|                    8a c  - 2b c
+--R               + 
+--R                    2        2
+--R                 (2a c - 2a b )x
+--R     + 
+--R                                         +------------------+
+--R             +-----------+               | +-----------+
+--R             |          2             2  | |          2
+--R         (2b\|- 4a c + b   + 4a c - 2b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R             +-----------+               |   +-----------+
+--R             |          2             2  |   |          2
+--R         (2b\|- 4a c + b   - 4a c + 2b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 485
+
+)clear all
+
+--S 486 of 704
+t0:=x^4/(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 486
+
+--S 487 of 704
+r0:=1/4*log(a+b*x^2+c*x^4)/c+1/2*b*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                        2                               +-----------+
+--R                    2c x  + b             4      2      |          2
+--R        2b atanh(--------------) + log(c x  + b x  + a)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  -------------------------------------------------------------
+--R                                  +-----------+
+--R                                  |          2
+--R                               4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                              +-----------+
+--R                4      2      |          2
+--R         log(c x  + b x  + a)\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       4c\|- 4a c + b
+--R     ,
+--R                          +---------+
+--R                   2      |        2                          +---------+
+--R              (2c x  + b)\|4a c - b             4      2      |        2
+--R    - 2b atan(-----------------------) + log(c x  + b x  + a)\|4a c - b
+--R                             2
+--R                     4a c - b
+--R    ---------------------------------------------------------------------]
+--R                                   +---------+
+--R                                   |        2
+--R                                4c\|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 488
+
+--S 489 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                         2
+--R                     2c x  + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             2
+--R           |        2          2c x  + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          2      |        2
+--R           |          2      (2c x  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     2c\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 704
+t0:=x^3/(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 493
+
+--S 494 of 704
+r0:=-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(b-_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))/(sqrt(2)*_
+   sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +--------------------+
+--R          |   +-----------+                   +-+ +-+
+--R          |   |          2                  x\|2 \|c
+--R       - \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                      |   |          2
+--R                                     \|- \|- 4a c + b   + b
+--R     + 
+--R        +------------------+
+--R        | +-----------+                  +-+ +-+
+--R        | |          2                 x\|2 \|c
+--R       \|\|- 4a c + b   + b atan(---------------------)
+--R                                  +------------------+
+--R                                  | +-----------+
+--R                                  | |          2
+--R                                 \|\|- 4a c + b   + b
+--R  /
+--R          +-----------+
+--R      +-+ |          2  +-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +---------------------------------------+
+--R          |                +-----------------+
+--R          |      2     2   |         1
+--R          |(16a c  - 4b c) |- ---------------  + b
+--R          |                |       3      2 2
+--R          |               \|  64a c  - 16b c
+--R          |---------------------------------------
+--R          |                  2     2
+--R         \|              8a c  - 2b c
+--R      *
+--R         log
+--R                                +-----------------+
+--R                      2     2   |         1
+--R                (16a c  - 4b c) |- ---------------
+--R                                |       3      2 2
+--R                               \|  64a c  - 16b c
+--R             *
+--R                 +---------------------------------------+
+--R                 |                +-----------------+
+--R                 |      2     2   |         1
+--R                 |(16a c  - 4b c) |- ---------------  + b
+--R                 |                |       3      2 2
+--R                 |               \|  64a c  - 16b c
+--R                 |---------------------------------------
+--R                 |                  2     2
+--R                \|              8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +-----------------------------------------+
+--R             |                  +-----------------+
+--R             |        2     2   |         1
+--R             |(- 16a c  + 4b c) |- ---------------  + b
+--R             |                  |       3      2 2
+--R             |                 \|  64a c  - 16b c
+--R             |-----------------------------------------
+--R             |                   2     2
+--R            \|               8a c  - 2b c
+--R         *
+--R            log
+--R                                   +-----------------+
+--R                         2     2   |         1
+--R                   (16a c  - 4b c) |- ---------------
+--R                                   |       3      2 2
+--R                                  \|  64a c  - 16b c
+--R                *
+--R                    +-----------------------------------------+
+--R                    |                  +-----------------+
+--R                    |        2     2   |         1
+--R                    |(- 16a c  + 4b c) |- ---------------  + b
+--R                    |                  |       3      2 2
+--R                    |                 \|  64a c  - 16b c
+--R                    |-----------------------------------------
+--R                    |                   2     2
+--R                   \|               8a c  - 2b c
+--R               + 
+--R                 x
+--R     + 
+--R          +-----------------------------------------+
+--R          |                  +-----------------+
+--R          |        2     2   |         1
+--R          |(- 16a c  + 4b c) |- ---------------  + b
+--R          |                  |       3      2 2
+--R          |                 \|  64a c  - 16b c
+--R          |-----------------------------------------
+--R          |                   2     2
+--R         \|               8a c  - 2b c
+--R      *
+--R         log
+--R                                  +-----------------+
+--R                        2     2   |         1
+--R                (- 16a c  + 4b c) |- ---------------
+--R                                  |       3      2 2
+--R                                 \|  64a c  - 16b c
+--R             *
+--R                 +-----------------------------------------+
+--R                 |                  +-----------------+
+--R                 |        2     2   |         1
+--R                 |(- 16a c  + 4b c) |- ---------------  + b
+--R                 |                  |       3      2 2
+--R                 |                 \|  64a c  - 16b c
+--R                 |-----------------------------------------
+--R                 |                   2     2
+--R                \|               8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +---------------------------------------+
+--R             |                +-----------------+
+--R             |      2     2   |         1
+--R             |(16a c  - 4b c) |- ---------------  + b
+--R             |                |       3      2 2
+--R             |               \|  64a c  - 16b c
+--R             |---------------------------------------
+--R             |                  2     2
+--R            \|              8a c  - 2b c
+--R         *
+--R            log
+--R                                     +-----------------+
+--R                           2     2   |         1
+--R                   (- 16a c  + 4b c) |- ---------------
+--R                                     |       3      2 2
+--R                                    \|  64a c  - 16b c
+--R                *
+--R                    +---------------------------------------+
+--R                    |                +-----------------+
+--R                    |      2     2   |         1
+--R                    |(16a c  - 4b c) |- ---------------  + b
+--R                    |                |       3      2 2
+--R                    |               \|  64a c  - 16b c
+--R                    |---------------------------------------
+--R                    |                  2     2
+--R                   \|              8a c  - 2b c
+--R               + 
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 495
+
+--S 496 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +---------------------------------------+
+--R                                |                +-----------------+
+--R                                |      2     2   |         1
+--R                                |(16a c  - 4b c) |- ---------------  + b
+--R              +-----------+     |                |       3      2 2
+--R          +-+ |          2  +-+ |               \|  64a c  - 16b c
+--R         \|2 \|- 4a c + b  \|c  |---------------------------------------
+--R                                |                  2     2
+--R                               \|              8a c  - 2b c
+--R      *
+--R         log
+--R                                +-----------------+
+--R                      2     2   |         1
+--R                (16a c  - 4b c) |- ---------------
+--R                                |       3      2 2
+--R                               \|  64a c  - 16b c
+--R             *
+--R                 +---------------------------------------+
+--R                 |                +-----------------+
+--R                 |      2     2   |         1
+--R                 |(16a c  - 4b c) |- ---------------  + b
+--R                 |                |       3      2 2
+--R                 |               \|  64a c  - 16b c
+--R                 |---------------------------------------
+--R                 |                  2     2
+--R                \|              8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                                   +-----------------------------------------+
+--R                                   |                  +-----------------+
+--R                                   |        2     2   |         1
+--R                                   |(- 16a c  + 4b c) |- ---------------  + b
+--R                 +-----------+     |                  |       3      2 2
+--R             +-+ |          2  +-+ |                 \|  64a c  - 16b c
+--R            \|2 \|- 4a c + b  \|c  |-----------------------------------------
+--R                                   |                   2     2
+--R                                  \|               8a c  - 2b c
+--R         *
+--R            log
+--R                                   +-----------------+
+--R                         2     2   |         1
+--R                   (16a c  - 4b c) |- ---------------
+--R                                   |       3      2 2
+--R                                  \|  64a c  - 16b c
+--R                *
+--R                    +-----------------------------------------+
+--R                    |                  +-----------------+
+--R                    |        2     2   |         1
+--R                    |(- 16a c  + 4b c) |- ---------------  + b
+--R                    |                  |       3      2 2
+--R                    |                 \|  64a c  - 16b c
+--R                    |-----------------------------------------
+--R                    |                   2     2
+--R                   \|               8a c  - 2b c
+--R               + 
+--R                 x
+--R     + 
+--R                                +-----------------------------------------+
+--R                                |                  +-----------------+
+--R                                |        2     2   |         1
+--R                                |(- 16a c  + 4b c) |- ---------------  + b
+--R              +-----------+     |                  |       3      2 2
+--R          +-+ |          2  +-+ |                 \|  64a c  - 16b c
+--R         \|2 \|- 4a c + b  \|c  |-----------------------------------------
+--R                                |                   2     2
+--R                               \|               8a c  - 2b c
+--R      *
+--R         log
+--R                                  +-----------------+
+--R                        2     2   |         1
+--R                (- 16a c  + 4b c) |- ---------------
+--R                                  |       3      2 2
+--R                                 \|  64a c  - 16b c
+--R             *
+--R                 +-----------------------------------------+
+--R                 |                  +-----------------+
+--R                 |        2     2   |         1
+--R                 |(- 16a c  + 4b c) |- ---------------  + b
+--R                 |                  |       3      2 2
+--R                 |                 \|  64a c  - 16b c
+--R                 |-----------------------------------------
+--R                 |                   2     2
+--R                \|               8a c  - 2b c
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                                   +---------------------------------------+
+--R                                   |                +-----------------+
+--R                                   |      2     2   |         1
+--R                                   |(16a c  - 4b c) |- ---------------  + b
+--R                 +-----------+     |                |       3      2 2
+--R             +-+ |          2  +-+ |               \|  64a c  - 16b c
+--R            \|2 \|- 4a c + b  \|c  |---------------------------------------
+--R                                   |                  2     2
+--R                                  \|              8a c  - 2b c
+--R         *
+--R            log
+--R                                     +-----------------+
+--R                           2     2   |         1
+--R                   (- 16a c  + 4b c) |- ---------------
+--R                                     |       3      2 2
+--R                                    \|  64a c  - 16b c
+--R                *
+--R                    +---------------------------------------+
+--R                    |                +-----------------+
+--R                    |      2     2   |         1
+--R                    |(16a c  - 4b c) |- ---------------  + b
+--R                    |                |       3      2 2
+--R                    |               \|  64a c  - 16b c
+--R                    |---------------------------------------
+--R                    |                  2     2
+--R                   \|              8a c  - 2b c
+--R               + 
+--R                 x
+--R     + 
+--R         +--------------------+
+--R         |   +-----------+                   +-+ +-+
+--R         |   |          2                  x\|2 \|c
+--R       2\|- \|- 4a c + b   + b atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                     |   |          2
+--R                                    \|- \|- 4a c + b   + b
+--R     + 
+--R           +------------------+
+--R           | +-----------+                  +-+ +-+
+--R           | |          2                 x\|2 \|c
+--R       - 2\|\|- 4a c + b   + b atan(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                     | |          2
+--R                                    \|\|- 4a c + b   + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 497
+
+)clear all
+
+--S 498 of 704
+t0:=x^2/(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 498
+
+--S 499 of 704
+r0:=-atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                       2
+--R                   2c x  + b
+--R          atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R   (2)  - ---------------------
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                            +-----------+
+--R                 2 4         2           2  |          2         2     2   2
+--R              (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               4      2
+--R            c x  + b x  + a
+--R    /
+--R         +-----------+
+--R         |          2
+--R       2\|- 4a c + b
+--R     ,
+--R                     +---------+
+--R              2      |        2
+--R         (2c x  + b)\|4a c - b
+--R    atan(-----------------------)
+--R                        2
+--R                4a c - b
+--R    -----------------------------]
+--R              +---------+
+--R              |        2
+--R             \|4a c - b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 500
+
+--S 501 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                            +-----------+
+--R                 2 4         2           2  |          2         2     2   2
+--R              (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R            + 
+--R                        3
+--R              4a b c - b
+--R         /
+--R               4      2
+--R            c x  + b x  + a
+--R     + 
+--R                     2
+--R                 2c x  + b
+--R       2atanh(--------------)
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R  /
+--R       +-----------+
+--R       |          2
+--R     2\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        +---------+             2
+--R        |        2          2c x  + b
+--R       \|4a c - b  atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                      +---------+
+--R        +-----------+          2      |        2
+--R        |          2      (2c x  + b)\|4a c - b
+--R       \|- 4a c + b  atan(-----------------------)
+--R                                         2
+--R                                 4a c - b
+--R  /
+--R      +-----------+ +---------+
+--R      |          2  |        2
+--R     \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 704
+t0:=x/(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 505
+
+--S 506 of 704
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/_
+   (sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                +------------------+
+--R                | +-----------+                   +-+ +-+
+--R        +-+ +-+ | |          2                  x\|2 \|c
+--R       \|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                          +--------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + b
+--R     + 
+--R                  +--------------------+
+--R                  |   +-----------+                  +-+ +-+
+--R          +-+ +-+ |   |          2                 x\|2 \|c
+--R       - \|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                              | |          2
+--R                                             \|\|- 4a c + b   + b
+--R  /
+--R                    +--------------------+ +------------------+
+--R      +-----------+ |   +-----------+      | +-----------+
+--R      |          2  |   |          2       | |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +--------------------------------------+
+--R          |                +----------------+
+--R          |    2        2  |         1
+--R          |(16a c - 4a b ) |- --------------  + b
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |--------------------------------------
+--R          |               2        2
+--R         \|             8a c - 2a b
+--R      *
+--R         log
+--R                                   +----------------+
+--R                     2          3  |         1                  2
+--R                ((16a b c - 4a b ) |- --------------  + 4a c - b )
+--R                                   |     3       2 2
+--R                                  \|  64a c - 16a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |                +----------------+
+--R                 |    2        2  |         1
+--R                 |(16a c - 4a b ) |- --------------  + b
+--R                 |                |     3       2 2
+--R                 |               \|  64a c - 16a b
+--R                 |--------------------------------------
+--R                 |               2        2
+--R                \|             8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R             +----------------------------------------+
+--R             |                  +----------------+
+--R             |      2        2  |         1
+--R             |(- 16a c + 4a b ) |- --------------  + b
+--R             |                  |     3       2 2
+--R             |                 \|  64a c - 16a b
+--R             |----------------------------------------
+--R             |                2        2
+--R            \|              8a c - 2a b
+--R         *
+--R            log
+--R                                      +----------------+
+--R                        2          3  |         1                  2
+--R                   ((16a b c - 4a b ) |- --------------  - 4a c + b )
+--R                                      |     3       2 2
+--R                                     \|  64a c - 16a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |                  +----------------+
+--R                    |      2        2  |         1
+--R                    |(- 16a c + 4a b ) |- --------------  + b
+--R                    |                  |     3       2 2
+--R                    |                 \|  64a c - 16a b
+--R                    |----------------------------------------
+--R                    |                2        2
+--R                   \|              8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R          +----------------------------------------+
+--R          |                  +----------------+
+--R          |      2        2  |         1
+--R          |(- 16a c + 4a b ) |- --------------  + b
+--R          |                  |     3       2 2
+--R          |                 \|  64a c - 16a b
+--R          |----------------------------------------
+--R          |                2        2
+--R         \|              8a c - 2a b
+--R      *
+--R         log
+--R                                     +----------------+
+--R                       2          3  |         1                  2
+--R                ((- 16a b c + 4a b ) |- --------------  + 4a c - b )
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |                  +----------------+
+--R                 |      2        2  |         1
+--R                 |(- 16a c + 4a b ) |- --------------  + b
+--R                 |                  |     3       2 2
+--R                 |                 \|  64a c - 16a b
+--R                 |----------------------------------------
+--R                 |                2        2
+--R                \|              8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R             +--------------------------------------+
+--R             |                +----------------+
+--R             |    2        2  |         1
+--R             |(16a c - 4a b ) |- --------------  + b
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |--------------------------------------
+--R             |               2        2
+--R            \|             8a c - 2a b
+--R         *
+--R            log
+--R                                        +----------------+
+--R                          2          3  |         1                  2
+--R                   ((- 16a b c + 4a b ) |- --------------  - 4a c + b )
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |                +----------------+
+--R                    |    2        2  |         1
+--R                    |(16a c - 4a b ) |- --------------  + b
+--R                    |                |     3       2 2
+--R                    |               \|  64a c - 16a b
+--R                    |--------------------------------------
+--R                    |               2        2
+--R                   \|             8a c - 2a b
+--R               + 
+--R                 2c x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 507
+
+--S 508 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2  |   |          2       | |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +--------------------------------------+
+--R          |                +----------------+
+--R          |    2        2  |         1
+--R          |(16a c - 4a b ) |- --------------  + b
+--R          |                |     3       2 2
+--R          |               \|  64a c - 16a b
+--R          |--------------------------------------
+--R          |               2        2
+--R         \|             8a c - 2a b
+--R      *
+--R         log
+--R                                   +----------------+
+--R                     2          3  |         1                  2
+--R                ((16a b c - 4a b ) |- --------------  + 4a c - b )
+--R                                   |     3       2 2
+--R                                  \|  64a c - 16a b
+--R             *
+--R                 +--------------------------------------+
+--R                 |                +----------------+
+--R                 |    2        2  |         1
+--R                 |(16a c - 4a b ) |- --------------  + b
+--R                 |                |     3       2 2
+--R                 |               \|  64a c - 16a b
+--R                 |--------------------------------------
+--R                 |               2        2
+--R                \|             8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R                           +----------------------------------------+
+--R                           |                  +----------------+
+--R                           |      2        2  |         1
+--R                           |(- 16a c + 4a b ) |- --------------  + b
+--R             +-----------+ |                  |     3       2 2
+--R             |          2  |                 \|  64a c - 16a b
+--R            \|- 4a c + b   |----------------------------------------
+--R                           |                2        2
+--R                          \|              8a c - 2a b
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                      +----------------+
+--R                        2          3  |         1                  2
+--R                   ((16a b c - 4a b ) |- --------------  - 4a c + b )
+--R                                      |     3       2 2
+--R                                     \|  64a c - 16a b
+--R                *
+--R                    +----------------------------------------+
+--R                    |                  +----------------+
+--R                    |      2        2  |         1
+--R                    |(- 16a c + 4a b ) |- --------------  + b
+--R                    |                  |     3       2 2
+--R                    |                 \|  64a c - 16a b
+--R                    |----------------------------------------
+--R                    |                2        2
+--R                   \|              8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R                        +----------------------------------------+
+--R                        |                  +----------------+
+--R                        |      2        2  |         1
+--R                        |(- 16a c + 4a b ) |- --------------  + b
+--R          +-----------+ |                  |     3       2 2
+--R          |          2  |                 \|  64a c - 16a b
+--R         \|- 4a c + b   |----------------------------------------
+--R                        |                2        2
+--R                       \|              8a c - 2a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                     +----------------+
+--R                       2          3  |         1                  2
+--R                ((- 16a b c + 4a b ) |- --------------  + 4a c - b )
+--R                                     |     3       2 2
+--R                                    \|  64a c - 16a b
+--R             *
+--R                 +----------------------------------------+
+--R                 |                  +----------------+
+--R                 |      2        2  |         1
+--R                 |(- 16a c + 4a b ) |- --------------  + b
+--R                 |                  |     3       2 2
+--R                 |                 \|  64a c - 16a b
+--R                 |----------------------------------------
+--R                 |                2        2
+--R                \|              8a c - 2a b
+--R            + 
+--R              2c x
+--R     + 
+--R       -
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R             |          2  |   |          2       | |          2
+--R            \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +--------------------------------------+
+--R             |                +----------------+
+--R             |    2        2  |         1
+--R             |(16a c - 4a b ) |- --------------  + b
+--R             |                |     3       2 2
+--R             |               \|  64a c - 16a b
+--R             |--------------------------------------
+--R             |               2        2
+--R            \|             8a c - 2a b
+--R         *
+--R            log
+--R                                        +----------------+
+--R                          2          3  |         1                  2
+--R                   ((- 16a b c + 4a b ) |- --------------  - 4a c + b )
+--R                                        |     3       2 2
+--R                                       \|  64a c - 16a b
+--R                *
+--R                    +--------------------------------------+
+--R                    |                +----------------+
+--R                    |    2        2  |         1
+--R                    |(16a c - 4a b ) |- --------------  + b
+--R                    |                |     3       2 2
+--R                    |               \|  64a c - 16a b
+--R                    |--------------------------------------
+--R                    |               2        2
+--R                   \|             8a c - 2a b
+--R               + 
+--R                 2c x
+--R     + 
+--R                   +------------------+
+--R                   | +-----------+                   +-+ +-+
+--R           +-+ +-+ | |          2                  x\|2 \|c
+--R       - 2\|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                             +--------------------+
+--R                                             |   +-----------+
+--R                                             |   |          2
+--R                                            \|- \|- 4a c + b   + b
+--R     + 
+--R                 +--------------------+
+--R                 |   +-----------+                  +-+ +-+
+--R         +-+ +-+ |   |          2                 x\|2 \|c
+--R       2\|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                             | |          2
+--R                                            \|\|- 4a c + b   + b
+--R  /
+--R                     +--------------------+ +------------------+
+--R       +-----------+ |   +-----------+      | +-----------+
+--R       |          2  |   |          2       | |          2
+--R     2\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 509
+
+)clear all
+
+--S 510 of 704
+t0:=1/(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 510
+
+--S 511 of 704
+r0:=log(x)/a-1/4*log(a+b*x^2+c*x^4)/a+1/2*b*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                   2                                             +-----------+
+--R               2c x  + b                4      2                 |          2
+--R   2b atanh(--------------) + (- log(c x  + b x  + a) + 4log(x))\|- 4a c + b
+--R             +-----------+
+--R             |          2
+--R            \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                    +-----------+
+--R                                    |          2
+--R                                 4a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                            +-----------+
+--R                   4      2                 |          2
+--R         (- log(c x  + b x  + a) + 4log(x))\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       4a\|- 4a c + b
+--R     ,
+--R
+--R                               +---------+
+--R                        2      |        2
+--R                   (2c x  + b)\|4a c - b
+--R         - 2b atan(-----------------------)
+--R                                  2
+--R                          4a c - b
+--R       + 
+--R                                            +---------+
+--R                   4      2                 |        2
+--R         (- log(c x  + b x  + a) + 4log(x))\|4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       4a\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 512
+
+--S 513 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                         2
+--R                     2c x  + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     4a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 513
+
+--S 514 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             2
+--R           |        2          2c x  + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          2      |        2
+--R           |          2      (2c x  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     2a\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 704
+t0:=1/(x*(a*x+b*x^3+c*x^5))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 517
+
+--S 518 of 704
+r0:=(-1)/(a*x)-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (1+b/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(1-b/sqrt(b^2-4*a*c))/_
+   (a*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                       +------------------+
+--R              +-----------+            | +-----------+
+--R              |          2         +-+ | |          2
+--R         (- x\|- 4a c + b   - b x)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                       +--------------------+
+--R              +-----------+            |   +-----------+
+--R              |          2         +-+ |   |          2
+--R         (- x\|- 4a c + b   + b x)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R       - \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R         +-+ |          2  |   |          2       | |          2
+--R     a x\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                +----------------------------------------------------+
+--R                |                +--------------------+
+--R                |                |   2 2       2     4
+--R                |    4      3 2  |- a c  + 2a b c - b               3
+--R                |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R                |                |      7       6 2
+--R                |               \|   64a c - 16a b
+--R            a x |----------------------------------------------------
+--R                |                      4      3 2
+--R               \|                    8a c - 2a b
+--R         *
+--R            log
+--R                                                +--------------------+
+--R                                                |   2 2       2     4
+--R                         5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                     (32a c  - 24a b c + 4a b ) |--------------------  + 4a b c
+--R                                                |      7       6 2
+--R                                               \|   64a c - 16a b
+--R                   + 
+--R                           3     5
+--R                     - 5a b c + b
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |                +--------------------+
+--R                    |                |   2 2       2     4
+--R                    |    4      3 2  |- a c  + 2a b c - b               3
+--R                    |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R                    |                |      7       6 2
+--R                    |               \|   64a c - 16a b
+--R                    |----------------------------------------------------
+--R                    |                      4      3 2
+--R                   \|                    8a c - 2a b
+--R               + 
+--R                      3     2 2
+--R                 (2a c  - 2b c )x
+--R     + 
+--R             +------------------------------------------------------+
+--R             |                  +--------------------+
+--R             |                  |   2 2       2     4
+--R             |      4      3 2  |- a c  + 2a b c - b               3
+--R             |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R             |                  |      7       6 2
+--R             |                 \|   64a c - 16a b
+--R         a x |------------------------------------------------------
+--R             |                       4      3 2
+--R            \|                     8a c - 2a b
+--R      *
+--R         log
+--R                                             +--------------------+
+--R                                             |   2 2       2     4
+--R                      5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                  (32a c  - 24a b c + 4a b ) |--------------------  - 4a b c
+--R                                             |      7       6 2
+--R                                            \|   64a c - 16a b
+--R                + 
+--R                      3     5
+--R                  5a b c - b
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                  +--------------------+
+--R                 |                  |   2 2       2     4
+--R                 |      4      3 2  |- a c  + 2a b c - b               3
+--R                 |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R                 |                  |      7       6 2
+--R                 |                 \|   64a c - 16a b
+--R                 |------------------------------------------------------
+--R                 |                       4      3 2
+--R                \|                     8a c - 2a b
+--R            + 
+--R                   3     2 2
+--R              (2a c  - 2b c )x
+--R     + 
+--R       -
+--R                +------------------------------------------------------+
+--R                |                  +--------------------+
+--R                |                  |   2 2       2     4
+--R                |      4      3 2  |- a c  + 2a b c - b               3
+--R                |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R                |                  |      7       6 2
+--R                |                 \|   64a c - 16a b
+--R            a x |------------------------------------------------------
+--R                |                       4      3 2
+--R               \|                     8a c - 2a b
+--R         *
+--R            log
+--R                                                  +--------------------+
+--R                                                  |   2 2       2     4
+--R                           5 2      4 2      3 4  |- a c  + 2a b c - b
+--R                     (- 32a c  + 24a b c - 4a b ) |--------------------
+--R                                                  |      7       6 2
+--R                                                 \|   64a c - 16a b
+--R                   + 
+--R                       2   2       3     5
+--R                     4a b c  - 5a b c + b
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                  +--------------------+
+--R                    |                  |   2 2       2     4
+--R                    |      4      3 2  |- a c  + 2a b c - b               3
+--R                    |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R                    |                  |      7       6 2
+--R                    |                 \|   64a c - 16a b
+--R                    |------------------------------------------------------
+--R                    |                       4      3 2
+--R                   \|                     8a c - 2a b
+--R               + 
+--R                      3     2 2
+--R                 (2a c  - 2b c )x
+--R     + 
+--R             +----------------------------------------------------+
+--R             |                +--------------------+
+--R             |                |   2 2       2     4
+--R             |    4      3 2  |- a c  + 2a b c - b               3
+--R             |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R             |                |      7       6 2
+--R             |               \|   64a c - 16a b
+--R         a x |----------------------------------------------------
+--R             |                      4      3 2
+--R            \|                    8a c - 2a b
+--R      *
+--R         log
+--R                                               +--------------------+
+--R                                               |   2 2       2     4
+--R                        5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                  (- 32a c  + 24a b c - 4a b ) |--------------------  - 4a b c
+--R                                               |      7       6 2
+--R                                              \|   64a c - 16a b
+--R                + 
+--R                      3     5
+--R                  5a b c - b
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |                +--------------------+
+--R                 |                |   2 2       2     4
+--R                 |    4      3 2  |- a c  + 2a b c - b               3
+--R                 |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R                 |                |      7       6 2
+--R                 |               \|   64a c - 16a b
+--R                 |----------------------------------------------------
+--R                 |                      4      3 2
+--R                \|                    8a c - 2a b
+--R            + 
+--R                   3     2 2
+--R              (2a c  - 2b c )x
+--R     + 
+--R       - 2
+--R  /
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 519
+
+--S 520 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                                +--------------------+ +------------------+
+--R                  +-----------+ |   +-----------+      | +-----------+
+--R              +-+ |          2  |   |          2       | |          2
+--R            a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------------------------------+
+--R             |                +--------------------+
+--R             |                |   2 2       2     4
+--R             |    4      3 2  |- a c  + 2a b c - b               3
+--R             |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R             |                |      7       6 2
+--R             |               \|   64a c - 16a b
+--R             |----------------------------------------------------
+--R             |                      4      3 2
+--R            \|                    8a c - 2a b
+--R         *
+--R            log
+--R                                                +--------------------+
+--R                                                |   2 2       2     4
+--R                         5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                     (32a c  - 24a b c + 4a b ) |--------------------  + 4a b c
+--R                                                |      7       6 2
+--R                                               \|   64a c - 16a b
+--R                   + 
+--R                           3     5
+--R                     - 5a b c + b
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |                +--------------------+
+--R                    |                |   2 2       2     4
+--R                    |    4      3 2  |- a c  + 2a b c - b               3
+--R                    |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R                    |                |      7       6 2
+--R                    |               \|   64a c - 16a b
+--R                    |----------------------------------------------------
+--R                    |                      4      3 2
+--R                   \|                    8a c - 2a b
+--R               + 
+--R                      3     2 2
+--R                 (2a c  - 2b c )x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2
+--R         a\|2 \|- 4a c + b
+--R      *
+--R          +------------------------------------------------------+
+--R          |                  +--------------------+
+--R          |                  |   2 2       2     4
+--R          |      4      3 2  |- a c  + 2a b c - b               3
+--R          |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R          |                  |      7       6 2
+--R          |                 \|   64a c - 16a b
+--R          |------------------------------------------------------
+--R          |                       4      3 2
+--R         \|                     8a c - 2a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                             +--------------------+
+--R                                             |   2 2       2     4
+--R                      5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                  (32a c  - 24a b c + 4a b ) |--------------------  - 4a b c
+--R                                             |      7       6 2
+--R                                            \|   64a c - 16a b
+--R                + 
+--R                      3     5
+--R                  5a b c - b
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                  +--------------------+
+--R                 |                  |   2 2       2     4
+--R                 |      4      3 2  |- a c  + 2a b c - b               3
+--R                 |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R                 |                  |      7       6 2
+--R                 |                 \|   64a c - 16a b
+--R                 |------------------------------------------------------
+--R                 |                       4      3 2
+--R                \|                     8a c - 2a b
+--R            + 
+--R                   3     2 2
+--R              (2a c  - 2b c )x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2
+--R            a\|2 \|- 4a c + b
+--R         *
+--R             +------------------------------------------------------+
+--R             |                  +--------------------+
+--R             |                  |   2 2       2     4
+--R             |      4      3 2  |- a c  + 2a b c - b               3
+--R             |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R             |                  |      7       6 2
+--R             |                 \|   64a c - 16a b
+--R             |------------------------------------------------------
+--R             |                       4      3 2
+--R            \|                     8a c - 2a b
+--R         *
+--R             +--------------------+ +------------------+
+--R             |   +-----------+      | +-----------+
+--R             |   |          2       | |          2
+--R            \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                                                  +--------------------+
+--R                                                  |   2 2       2     4
+--R                           5 2      4 2      3 4  |- a c  + 2a b c - b
+--R                     (- 32a c  + 24a b c - 4a b ) |--------------------
+--R                                                  |      7       6 2
+--R                                                 \|   64a c - 16a b
+--R                   + 
+--R                       2   2       3     5
+--R                     4a b c  - 5a b c + b
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                  +--------------------+
+--R                    |                  |   2 2       2     4
+--R                    |      4      3 2  |- a c  + 2a b c - b               3
+--R                    |(- 16a c + 4a b ) |--------------------  - 3a b c + b
+--R                    |                  |      7       6 2
+--R                    |                 \|   64a c - 16a b
+--R                    |------------------------------------------------------
+--R                    |                       4      3 2
+--R                   \|                     8a c - 2a b
+--R               + 
+--R                      3     2 2
+--R                 (2a c  - 2b c )x
+--R     + 
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R           +-+ |          2  |   |          2       | |          2
+--R         a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R          +----------------------------------------------------+
+--R          |                +--------------------+
+--R          |                |   2 2       2     4
+--R          |    4      3 2  |- a c  + 2a b c - b               3
+--R          |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R          |                |      7       6 2
+--R          |               \|   64a c - 16a b
+--R          |----------------------------------------------------
+--R          |                      4      3 2
+--R         \|                    8a c - 2a b
+--R      *
+--R         log
+--R                                               +--------------------+
+--R                                               |   2 2       2     4
+--R                        5 2      4 2      3 4  |- a c  + 2a b c - b       2   2
+--R                  (- 32a c  + 24a b c - 4a b ) |--------------------  - 4a b c
+--R                                               |      7       6 2
+--R                                              \|   64a c - 16a b
+--R                + 
+--R                      3     5
+--R                  5a b c - b
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |                +--------------------+
+--R                 |                |   2 2       2     4
+--R                 |    4      3 2  |- a c  + 2a b c - b               3
+--R                 |(16a c - 4a b ) |--------------------  - 3a b c + b
+--R                 |                |      7       6 2
+--R                 |               \|   64a c - 16a b
+--R                 |----------------------------------------------------
+--R                 |                      4      3 2
+--R                \|                    8a c - 2a b
+--R            + 
+--R                   3     2 2
+--R              (2a c  - 2b c )x
+--R     + 
+--R                                    +------------------+
+--R            +-----------+           | +-----------+
+--R            |          2        +-+ | |          2
+--R         (2\|- 4a c + b   + 2b)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                    +--------------------+
+--R            +-----------+           |   +-----------+
+--R            |          2        +-+ |   |          2
+--R         (2\|- 4a c + b   - 2b)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R     2a\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 521
+
+)clear all
+
+--S 522 of 704
+t0:=1/(x^2*(a*x+b*x^3+c*x^5))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 522
+
+--S 523 of 704
+r0:=(-1/2)/(a*x^2)-b*log(x)/a^2+1/4*b*log(a+b*x^2+c*x^4)/a^2-_
+   1/2*(b^2-2*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                  2
+--R                 2  2         2c x  + b
+--R       (4a c - 2b )x atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R           2       4      2            2             |          2
+--R       (b x log(c x  + b x  + a) - 4b x log(x) - 2a)\|- 4a c + b
+--R  /
+--R           +-----------+
+--R       2 2 |          2
+--R     4a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2  2
+--R           (2a c - b )x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                                       +-----------+
+--R             2       4      2            2             |          2
+--R         (b x log(c x  + b x  + a) - 4b x log(x) - 2a)\|- 4a c + b
+--R    /
+--R             +-----------+
+--R         2 2 |          2
+--R       4a x \|- 4a c + b
+--R     ,
+--R
+--R                                          +---------+
+--R                                   2      |        2
+--R                     2  2     (2c x  + b)\|4a c - b
+--R         (- 4a c + 2b )x atan(-----------------------)
+--R                                             2
+--R                                     4a c - b
+--R       + 
+--R                                                       +---------+
+--R             2       4      2            2             |        2
+--R         (b x log(c x  + b x  + a) - 4b x log(x) - 2a)\|4a c - b
+--R    /
+--R             +---------+
+--R         2 2 |        2
+--R       4a x \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 524
+
+--S 525 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R         (2a c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                  2
+--R                   2          2c x  + b
+--R       (- 4a c + 2b )atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4a \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------+             2
+--R                  2  |        2          2c x  + b
+--R       (- 2a c + b )\|4a c - b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                                   +---------+
+--R                     +-----------+          2      |        2
+--R                  2  |          2      (2c x  + b)\|4a c - b
+--R       (- 2a c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                      2
+--R                                              4a c - b
+--R  /
+--R         +-----------+ +---------+
+--R       2 |          2  |        2
+--R     2a \|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 704
+t0:=x^11/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                               9
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 529
+
+--S 530 of 704
+r0:=(b^2-3*a*c)*x^2/(c^2*(b^2-4*a*c))-1/2*b*x^4/(c*(b^2-4*a*c))+_
+   1/2*x^6*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-(b^4-6*a*b^2*c+_
+   6*a^2*c^2)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^3*(b^2-4*a*c)^(3/2))-_
+   1/2*b*log(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   4       2   2        3      5  2      3 2
+--R           (12a c  - 12a b c  + 2b c)x  + (12a b c  - 12a b c + 2b )x  + 12a c
+--R         + 
+--R                2 2        4
+--R           - 12a b c + 2a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                       2    3   4          2     4  2     2         3
+--R             ((- 4a b c  + b c)x  + (- 4a b c + b )x  - 4a b c + a b )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                3    2 2  6          2     3   4      2 2       2   2
+--R           (4a c  - b c )x  + (7a b c  - 2b c)x  + (6a c  - 2a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                 +-----------+
+--R           5     2 4  4          4     3 3  2     2 4       2 3  |          2
+--R     ((8a c  - 2b c )x  + (8a b c  - 2b c )x  + 8a c  - 2a b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3       2 2    4   4      2   2       3     5  2     3 2
+--R             (6a c  - 6a b c  + b c)x  + (6a b c  - 6a b c + b )x  + 6a c
+--R           + 
+--R                 2 2       4
+--R             - 6a b c + a b
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                         2    3   4          2     4  2     2         3
+--R               ((- 4a b c  + b c)x  + (- 4a b c + b )x  - 4a b c + a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                  3    2 2  6          2    3   4      2 2       2     4  2
+--R             (4a c  - b c )x  + (4a b c  - b c)x  + (6a c  - 5a b c + b )x
+--R           + 
+--R                 2         3
+--R             - 3a b c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                                   +-----------+
+--R             5     2 4  4          4     3 3  2     2 4       2 3  |          2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x  + 8a c  - 2a b c )\|- 4a c + b
+--R     ,
+--R
+--R                   2 3        2 2     4   4         2   2        3      5  2
+--R             (- 12a c  + 12a b c  - 2b c)x  + (- 12a b c  + 12a b c - 2b )x
+--R           + 
+--R                  3 2      2 2        4
+--R             - 12a c  + 12a b c - 2a b
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                         2    3   4          2     4  2     2         3
+--R               ((- 4a b c  + b c)x  + (- 4a b c + b )x  - 4a b c + a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                  3    2 2  6          2    3   4      2 2       2     4  2
+--R             (4a c  - b c )x  + (4a b c  - b c)x  + (6a c  - 5a b c + b )x
+--R           + 
+--R                 2         3
+--R             - 3a b c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                   +---------+
+--R             5     2 4  4          4     3 3  2     2 4       2 3  |        2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x  + 8a c  - 2a b c )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 531
+
+--S 532 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (6a c  - 6a b c + b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                              2
+--R             2 2        2      4          2c x  + b
+--R       (- 12a c  + 12a b c - 2b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                       +-----------+
+--R                    3  |          2
+--R       (- 3a b c + b )\|- 4a c + b
+--R  /
+--R                     +-----------+
+--R          4     2 3  |          2
+--R     (8a c  - 2b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------+             2
+--R             2 2        2      4  |        2          2c x  + b
+--R       (- 12a c  + 12a b c - 2b )\|4a c - b  atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R     + 
+--R                                                                +---------+
+--R                                  +-----------+          2      |        2
+--R             2 2        2      4  |          2      (2c x  + b)\|4a c - b
+--R       (- 12a c  + 12a b c - 2b )\|- 4a c + b  atan(-----------------------)
+--R                                                                   2
+--R                                                           4a c - b
+--R     + 
+--R                       +-----------+ +---------+
+--R                    3  |          2  |        2
+--R       (- 3a b c + b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                     +-----------+ +---------+
+--R          4     2 3  |          2  |        2
+--R     (8a c  - 2b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 535
+
+)clear all
+
+--S 536 of 704
+t0:=x^10/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                               8
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 536
+
+--S 537 of 704
+r0:=1/2*(3*b^2-10*a*c)*x/(c^2*(b^2-4*a*c))-1/2*b*x^3/(c*(b^2-4*a*c))+_
+   1/2*x^5*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(3*b^3-13*a*b*c+(-3*b^4+19*a*b^2*c-_
+   20*a^2*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*(b^2-4*a*c)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (3*b^3-13*a*b*c+(3*b^4-19*a*b^2*c+20*a^2*c^2)/sqrt(b^2-4*a*c))/_
+   (c^(5/2)*(b^2-4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                        2     3   4           2      4  2      2          3
+--R             ((- 13a b c  + 3b c)x  + (- 13a b c + 3b )x  - 13a b c + 3a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 3        2 2     4   4         2   2        3      5  2
+--R           (- 20a c  + 19a b c  - 3b c)x  + (- 20a b c  + 19a b c - 3b )x
+--R         + 
+--R                3 2      2 2        4
+--R           - 20a c  + 19a b c - 3a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                        2     3   4           2      4  2      2          3
+--R             ((- 13a b c  + 3b c)x  + (- 13a b c + 3b )x  - 13a b c + 3a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 3        2 2     4   4       2   2        3      5  2      3 2
+--R           (20a c  - 19a b c  + 3b c)x  + (20a b c  - 19a b c + 3b )x  + 20a c
+--R         + 
+--R                2 2        4
+--R           - 19a b c + 3a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R               2     2   5                3  3       2        2    +-+
+--R         ((8a c  - 2b c)x  + (11a b c - 3b )x  + (10a c - 3a b )x)\|2
+--R      *
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R          |          2  +-+ |   |          2       | |          2
+--R         \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R             4     2 3  4          3     3 2  2     2 3       2 2  +-+
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x  + 8a c  - 2a b c )\|2
+--R    *
+--R                          +--------------------+ +------------------+
+--R        +-----------+     |   +-----------+      | +-----------+
+--R        |          2  +-+ |   |          2       | |          2
+--R       \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4    2 3  4          3    3 2  2     2 3      2 2
+--R         ((4a c  - b c )x  + (4a b c  - b c )x  + 4a c  - a b c )
+--R      *
+--R         ROOT
+--R                        3 8       2 2 7         4 6      6 5
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        3 13         2 2 12          4 11       6 10
+--R                  \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              4   9         3 3 8        2 5 7         7 6
+--R                        16384a b c  - 15360a b c  + 5376a b c  - 832a b c
+--R                      + 
+--R                           9 5
+--R                        48b c
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        3 13         2 2 12          4 11       6 10
+--R                    \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                         5 5         4 2 4        3 4 3        2 6 2         8
+--R                  - 4000a c  + 11360a b c  - 8818a b c  + 2961a b c  - 459a b c
+--R                + 
+--R                     10
+--R                  27b
+--R             *
+--R                ROOT
+--R                               3 8       2 2 7         4 6      6 5
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        3 13         2 2 12          4 11       6 10
+--R                       \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    5 3        4 2 2        3 4        2 6
+--R              (2500a c  - 5625a b c  + 1971a b c - 189a b )x
+--R     + 
+--R                 4    2 3  4            3    3 2  2     2 3      2 2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c )x  - 4a c  + a b c )
+--R      *
+--R         ROOT
+--R                          3 8       2 2 7         4 6      6 5
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        3 13         2 2 12          4 11       6 10
+--R                  \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              4   9         3 3 8        2 5 7         7 6
+--R                        16384a b c  - 15360a b c  + 5376a b c  - 832a b c
+--R                      + 
+--R                           9 5
+--R                        48b c
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        3 13         2 2 12          4 11       6 10
+--R                    \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                       5 5         4 2 4        3 4 3        2 6 2         8
+--R                  4000a c  - 11360a b c  + 8818a b c  - 2961a b c  + 459a b c
+--R                + 
+--R                       10
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                                 3 8       2 2 7         4 6      6 5
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        3 13         2 2 12          4 11       6 10
+--R                       \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    5 3        4 2 2        3 4        2 6
+--R              (2500a c  - 5625a b c  + 1971a b c - 189a b )x
+--R     + 
+--R               4    2 3  4          3    3 2  2     2 3      2 2
+--R         ((4a c  - b c )x  + (4a b c  - b c )x  + 4a c  - a b c )
+--R      *
+--R         ROOT
+--R                          3 8       2 2 7         4 6      6 5
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        3 13         2 2 12          4 11       6 10
+--R                  \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              4   9         3 3 8        2 5 7         7 6
+--R                      - 16384a b c  + 15360a b c  - 5376a b c  + 832a b c
+--R                    + 
+--R                           9 5
+--R                      - 48b c
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        3 13         2 2 12          4 11       6 10
+--R                    \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                         5 5         4 2 4        3 4 3        2 6 2         8
+--R                  - 4000a c  + 11360a b c  - 8818a b c  + 2961a b c  - 459a b c
+--R                + 
+--R                     10
+--R                  27b
+--R             *
+--R                ROOT
+--R                                 3 8       2 2 7         4 6      6 5
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        3 13         2 2 12          4 11       6 10
+--R                       \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    5 3        4 2 2        3 4        2 6
+--R              (2500a c  - 5625a b c  + 1971a b c - 189a b )x
+--R     + 
+--R                 4    2 3  4            3    3 2  2     2 3      2 2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c )x  - 4a c  + a b c )
+--R      *
+--R         ROOT
+--R                        3 8       2 2 7         4 6      6 5
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        3 13         2 2 12          4 11       6 10
+--R                  \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              4   9         3 3 8        2 5 7         7 6
+--R                      - 16384a b c  + 15360a b c  - 5376a b c  + 832a b c
+--R                    + 
+--R                           9 5
+--R                      - 48b c
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        3 13         2 2 12          4 11       6 10
+--R                    \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                       5 5         4 2 4        3 4 3        2 6 2         8
+--R                  4000a c  - 11360a b c  + 8818a b c  - 2961a b c  + 459a b c
+--R                + 
+--R                       10
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                               3 8       2 2 7         4 6      6 5
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        3 13         2 2 12          4 11       6 10
+--R                       \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    5 3        4 2 2        3 4        2 6
+--R              (2500a c  - 5625a b c  + 1971a b c - 189a b )x
+--R     + 
+--R            2     2   5                3  3       2        2
+--R       (8a c  - 2b c)x  + (11a b c - 3b )x  + (10a c - 3a b )x
+--R  /
+--R          4     2 3  4          3     3 2  2     2 3       2 2
+--R     (8a c  - 2b c )x  + (8a b c  - 2b c )x  + 8a c  - 2a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 538
+
+--S 539 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +--------------------+
+--R                            +-----------+     |   +-----------+
+--R              3    2 2  +-+ |          2  +-+ |   |          2
+--R         (4a c  - b c )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 8       2 2 7         4 6      6 5
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        3 13         2 2 12          4 11       6 10
+--R                  \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              4   9         3 3 8        2 5 7         7 6
+--R                        16384a b c  - 15360a b c  + 5376a b c  - 832a b c
+--R                      + 
+--R                           9 5
+--R                        48b c
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        3 13         2 2 12          4 11       6 10
+--R                    \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                         5 5         4 2 4        3 4 3        2 6 2         8
+--R                  - 4000a c  + 11360a b c  - 8818a b c  + 2961a b c  - 459a b c
+--R                + 
+--R                     10
+--R                  27b
+--R             *
+--R                ROOT
+--R                               3 8       2 2 7         4 6      6 5
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        3 13         2 2 12          4 11       6 10
+--R                       \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    5 3        4 2 2        3 4        2 6
+--R              (2500a c  - 5625a b c  + 1971a b c - 189a b )x
+--R     + 
+--R                              +-----------+
+--R                3    2 2  +-+ |          2  +-+
+--R         (- 4a c  + b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 8       2 2 7         4 6      6 5
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        3 13         2 2 12          4 11       6 10
+--R                  \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              4   9         3 3 8        2 5 7         7 6
+--R                        16384a b c  - 15360a b c  + 5376a b c  - 832a b c
+--R                      + 
+--R                           9 5
+--R                        48b c
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        3 13         2 2 12          4 11       6 10
+--R                    \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                       5 5         4 2 4        3 4 3        2 6 2         8
+--R                  4000a c  - 11360a b c  + 8818a b c  - 2961a b c  + 459a b c
+--R                + 
+--R                       10
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                                 3 8       2 2 7         4 6      6 5
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        3 13         2 2 12          4 11       6 10
+--R                       \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    5 3        4 2 2        3 4        2 6
+--R              (2500a c  - 5625a b c  + 1971a b c - 189a b )x
+--R     + 
+--R                            +-----------+
+--R              3    2 2  +-+ |          2  +-+
+--R         (4a c  - b c )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 8       2 2 7         4 6      6 5
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        3 13         2 2 12          4 11       6 10
+--R                  \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              4   9         3 3 8        2 5 7         7 6
+--R                      - 16384a b c  + 15360a b c  - 5376a b c  + 832a b c
+--R                    + 
+--R                           9 5
+--R                      - 48b c
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        3 13         2 2 12          4 11       6 10
+--R                    \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                         5 5         4 2 4        3 4 3        2 6 2         8
+--R                  - 4000a c  + 11360a b c  - 8818a b c  + 2961a b c  - 459a b c
+--R                + 
+--R                     10
+--R                  27b
+--R             *
+--R                ROOT
+--R                                 3 8       2 2 7         4 6      6 5
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        3 13         2 2 12          4 11       6 10
+--R                       \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    5 3        4 2 2        3 4        2 6
+--R              (2500a c  - 5625a b c  + 1971a b c - 189a b )x
+--R     + 
+--R                                                +--------------------+
+--R                              +-----------+     |   +-----------+
+--R                3    2 2  +-+ |          2  +-+ |   |          2
+--R         (- 4a c  + b c )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 8       2 2 7         4 6      6 5
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        3 13         2 2 12          4 11       6 10
+--R                  \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  3 8       2 2 7        4 6     6 5
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                              4   9         3 3 8        2 5 7         7 6
+--R                      - 16384a b c  + 15360a b c  - 5376a b c  + 832a b c
+--R                    + 
+--R                           9 5
+--R                      - 48b c
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        3 13         2 2 12          4 11       6 10
+--R                    \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                + 
+--R                       5 5         4 2 4        3 4 3        2 6 2         8
+--R                  4000a c  - 11360a b c  + 8818a b c  - 2961a b c  + 459a b c
+--R                + 
+--R                       10
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                               3 8       2 2 7         4 6      6 5
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        3 13         2 2 12          4 11       6 10
+--R                       \|  16384a c   - 12288a b c   + 3072a b c   - 256b c
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         3 8       2 2 7        4 6     6 5
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                    5 3        4 2 2        3 4        2 6
+--R              (2500a c  - 5625a b c  + 1971a b c - 189a b )x
+--R     + 
+--R                          +-----------+
+--R                       3  |          2       2 2        2      4
+--R         ((13a b c - 3b )\|- 4a c + b   + 20a c  - 19a b c + 3b )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                       3  |          2       2 2        2      4
+--R         ((13a b c - 3b )\|- 4a c + b   - 20a c  + 19a b c - 3b )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                             +--------------------+
+--R                           +-----------+     |   +-----------+
+--R            3     2 2  +-+ |          2  +-+ |   |          2
+--R       (8a c  - 2b c )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 704
+t0:=x^9/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                               7
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 541
+
+--S 542 of 704
+r0:=-1/2*b*x^2/(c*(b^2-4*a*c))+1/2*x^4*(2*a+b*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/2*b*(b^2-6*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c^2*(b^2-4*a*c)^(3/2))+1/4*log(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                  2     3   4         2      4  2      2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x  + 12a b c - 2a b )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 2    2   4              3  2     2       2        4      2
+--R           ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )log(c x  + b x  + a)
+--R         + 
+--R                  2     2   4           2
+--R           (- 4a c  + 2b c)x  + 2a b c x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              4     2 3  4           3     3 2  2      2 3       2 2
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2    3   4        2     4  2     2         3
+--R           ((6a b c  - b c)x  + (6a b c - b )x  + 6a b c - a b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                     2    2   4              3  2     2       2
+--R               ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                         3  2     2        2
+--R             (6a b c - 2b )x  + 4a c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                4     2 3  4           3     3 2  2      2 3       2 2
+--R         ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                      2     3   4           2      4  2      2          3
+--R           ((- 12a b c  + 2b c)x  + (- 12a b c + 2b )x  - 12a b c + 2a b )
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                     2    2   4              3  2     2       2
+--R               ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                         3  2     2        2
+--R             (6a b c - 2b )x  + 4a c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                4     2 3  4           3     3 2  2      2 3       2 2
+--R         ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 543
+
+--S 544 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (6a b c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                     2                       +-----------+
+--R                      3          2c x  + b                2  |          2
+--R       (- 12a b c + 2b )atanh(--------------) + (4a c - 2b )\|- 4a c + b
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                      +-----------+
+--R           3     2 2  |          2
+--R     (16a c  - 4b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+             2
+--R                    3  |        2          2c x  + b
+--R       (- 6a b c + b )\|4a c - b  atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                                                     +---------+
+--R                       +-----------+          2      |        2
+--R                    3  |          2      (2c x  + b)\|4a c - b
+--R       (- 6a b c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                        2
+--R                                                4a c - b
+--R     + 
+--R                   +-----------+ +---------+
+--R                2  |          2  |        2
+--R       (2a c - b )\|- 4a c + b  \|4a c - b
+--R  /
+--R                     +-----------+ +---------+
+--R          3     2 2  |          2  |        2
+--R     (8a c  - 2b c )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 547
+
+)clear all
+
+--S 548 of 704
+t0:=x^8/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                               6
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 548
+
+--S 549 of 704
+r0:=-1/2*b*x/(c*(b^2-4*a*c))+1/2*x^3*(2*a+b*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b^2-6*a*c-b*(b^2-8*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*(b^2-6*a*c+b*(b^2-8*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                             +-----------+
+--R                 2    2   4              3  2     2       2  |          2
+--R           ((6a c  - b c)x  + (6a b c - b )x  + 6a c - a b )\|- 4a c + b
+--R         + 
+--R                    2    3   4          2     4  2     2         3
+--R           (- 8a b c  + b c)x  + (- 8a b c + b )x  - 8a b c + a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                                             +-----------+
+--R                 2    2   4              3  2     2       2  |          2
+--R           ((6a c  - b c)x  + (6a b c - b )x  + 6a c - a b )\|- 4a c + b
+--R         + 
+--R                  2    3   4        2     4  2     2         3
+--R           (8a b c  - b c)x  + (8a b c - b )x  + 8a b c - a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                         +--------------------+
+--R                                       +-----------+     |   +-----------+
+--R                     2  3          +-+ |          2  +-+ |   |          2
+--R         ((- 2a c + b )x  + a b x)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R             3     2 2  4          2     3   2     2 2       2   +-+
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|2
+--R    *
+--R                          +--------------------+ +------------------+
+--R        +-----------+     |   +-----------+      | +-----------+
+--R        |          2  +-+ |   |          2       | |          2
+--R       \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3    2 2  4          2    3   2     2 2      2
+--R         ((4a c  - b c )x  + (4a b c  - b c)x  + 4a c  - a b c)
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                           4 7         3 2 6        2 4 5         6 4      8 3
+--R                    (12288a c  - 10240a b c  + 3072a b c  - 384a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                        3   3      2 3 2        5     7
+--R                  - 144a b c  + 88a b c  - 17a b c + b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                 3    2 2  4            2    3   2     2 2      2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c)x  - 4a c  + a b c)
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                           4 7         3 2 6        2 4 5         6 4      8 3
+--R                    (12288a c  - 10240a b c  + 3072a b c  - 384a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                      3   3      2 3 2        5     7
+--R                  144a b c  - 88a b c  + 17a b c - b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R               3    2 2  4          2    3   2     2 2      2
+--R         ((4a c  - b c )x  + (4a b c  - b c)x  + 4a c  - a b c)
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                4 7         3 2 6        2 4 5         6 4
+--R                        - 12288a c  + 10240a b c  - 3072a b c  + 384a b c
+--R                      + 
+--R                             8 3
+--R                        - 16b c
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                        3   3      2 3 2        5     7
+--R                  - 144a b c  + 88a b c  - 17a b c + b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                 3    2 2  4            2    3   2     2 2      2
+--R         ((- 4a c  + b c )x  + (- 4a b c  + b c)x  - 4a c  + a b c)
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                4 7         3 2 6        2 4 5         6 4
+--R                        - 12288a c  + 10240a b c  - 3072a b c  + 384a b c
+--R                      + 
+--R                             8 3
+--R                        - 16b c
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                      3   3      2 3 2        5     7
+--R                  144a b c  - 88a b c  + 17a b c - b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                  2  3
+--R       (- 2a c + b )x  + a b x
+--R  /
+--R          3     2 2  4          2     3   2     2 2       2
+--R     (8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 550
+
+--S 551 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +--------------------+
+--R                           +-----------+     |   +-----------+
+--R              2    2   +-+ |          2  +-+ |   |          2
+--R         (4a c  - b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                           4 7         3 2 6        2 4 5         6 4      8 3
+--R                    (12288a c  - 10240a b c  + 3072a b c  - 384a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                        3   3      2 3 2        5     7
+--R                  - 144a b c  + 88a b c  - 17a b c + b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                             +-----------+
+--R                2    2   +-+ |          2  +-+
+--R         (- 4a c  + b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                           4 7         3 2 6        2 4 5         6 4      8 3
+--R                    (12288a c  - 10240a b c  + 3072a b c  - 384a b c  + 16b c )
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                      3   3      2 3 2        5     7
+--R                  144a b c  - 88a b c  + 17a b c - b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                           +-----------+
+--R              2    2   +-+ |          2  +-+
+--R         (4a c  - b c)\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 6       2 2 5         4 4      6 3
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                4 7         3 2 6        2 4 5         6 4
+--R                        - 12288a c  + 10240a b c  - 3072a b c  + 384a b c
+--R                      + 
+--R                             8 3
+--R                        - 16b c
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                        3   3      2 3 2        5     7
+--R                  - 144a b c  + 88a b c  - 17a b c + b
+--R             *
+--R                ROOT
+--R                                 3 6       2 2 5         4 4      6 3
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                                               +--------------------+
+--R                             +-----------+     |   +-----------+
+--R                2    2   +-+ |          2  +-+ |   |          2
+--R         (- 4a c  + b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 6       2 2 5         4 4      6 3
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R               *
+--R                   +----------------------------------------------+
+--R                   |                 2 2        2     4
+--R                   |            - 81a c  + 18a b c - b
+--R                   |----------------------------------------------
+--R                   |      3 9         2 2 8          4 7       6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  3 6       2 2 5        4 4     6 3
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                                4 7         3 2 6        2 4 5         6 4
+--R                        - 12288a c  + 10240a b c  - 3072a b c  + 384a b c
+--R                      + 
+--R                             8 3
+--R                        - 16b c
+--R                 *
+--R                     +----------------------------------------------+
+--R                     |                 2 2        2     4
+--R                     |            - 81a c  + 18a b c - b
+--R                     |----------------------------------------------
+--R                     |      3 9         2 2 8          4 7       6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                      3   3      2 3 2        5     7
+--R                  144a b c  - 88a b c  + 17a b c - b
+--R             *
+--R                ROOT
+--R                               3 6       2 2 5         4 4      6 3
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c )
+--R                      *
+--R                          +----------------------------------------------+
+--R                          |                 2 2        2     4
+--R                          |            - 81a c  + 18a b c - b
+--R                          |----------------------------------------------
+--R                          |      3 9         2 2 8          4 7       6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         3 6       2 2 5        4 4     6 3
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                   3 2      2 2        4
+--R              (324a c  - 81a b c + 5a b )x
+--R     + 
+--R                                                     +------------------+
+--R                        +-----------+                | +-----------+
+--R                     2  |          2              3  | |          2
+--R         ((- 6a c + b )\|- 4a c + b   + 8a b c - b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                        +-----------+                |   +-----------+
+--R                     2  |          2              3  |   |          2
+--R         ((- 6a c + b )\|- 4a c + b   - 8a b c + b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                            +--------------------+
+--R                          +-----------+     |   +-----------+
+--R            2     2   +-+ |          2  +-+ |   |          2
+--R       (8a c  - 2b c)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 704
+t0:=x^7/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                               5
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 553
+
+--S 554 of 704
+r0:=1/2*x^2*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   2*a*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                               2
+--R                4         2     2          2c x  + b
+--R       (- 4a c x  - 4a b x  - 4a )atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                        +-----------+
+--R             4       2  |          2
+--R       (- b x  - 2a x )\|- 4a c + b
+--R  /
+--R                                                          +-----------+
+--R           2     2   4               3  2     2        2  |          2
+--R     ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 4           2     2
+--R           (2a c x  + 2a b c x  + 2a c)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                                 +-----------+
+--R                     2  2        |          2
+--R         ((- 2a c + b )x  + a b)\|- 4a c + b
+--R    /
+--R                                                                 +-----------+
+--R             3     2 2  4          2     3   2     2 2       2   |          2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|- 4a c + b
+--R     ,
+--R
+--R                                                      +---------+
+--R                                               2      |        2
+--R              2 4           2     2       (2c x  + b)\|4a c - b
+--R         (4a c x  + 4a b c x  + 4a c)atan(-----------------------)
+--R                                                         2
+--R                                                 4a c - b
+--R       + 
+--R                                 +---------+
+--R                     2  2        |        2
+--R         ((- 2a c + b )x  + a b)\|4a c - b
+--R    /
+--R                                                                 +---------+
+--R             3     2 2  4          2     3   2     2 2       2   |        2
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 555
+
+--S 556 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         2a c
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                         2            +-----------+
+--R                     2c x  + b        |          2
+--R       4a c atanh(--------------) + b\|- 4a c + b
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R          2     2   |          2
+--R     (8a c  - 2b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            +---------+             2
+--R            |        2          2c x  + b
+--R       4a c\|4a c - b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                          +---------+
+--R            +-----------+          2      |        2
+--R            |          2      (2c x  + b)\|4a c - b
+--R       4a c\|- 4a c + b  atan(-----------------------)
+--R                                             2
+--R                                     4a c - b
+--R     + 
+--R         +-----------+ +---------+
+--R         |          2  |        2
+--R       b\|- 4a c + b  \|4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R          2     2   |          2  |        2
+--R     (8a c  - 2b c)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 559
+
+)clear all
+
+--S 560 of 704
+t0:=x^6/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                               4
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 560
+
+--S 561 of 704
+r0:=1/2*x*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+(-b^2-4*a*c)/sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^2+4*a*c+b*_
+   sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                   +-----------+
+--R                   4    2 2        |          2         2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (4a c  + b c)x
+--R         + 
+--R                      3  2     2       2
+--R           (4a b c + b )x  + 4a c + a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2           2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (- 4a c  - b c)x
+--R         + 
+--R                        3  2     2       2
+--R           (- 4a b c - b )x  - 4a c - a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                               +--------------------+
+--R                             +-----------+     |   +-----------+
+--R               3         +-+ |          2  +-+ |   |          2
+--R         (- b x  - 2a x)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                                                                +-----------+
+--R             2     2   4               3  2     2        2  +-+ |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2 \|- 4a c + b
+--R    *
+--R            +--------------------+ +------------------+
+--R            |   +-----------+      | +-----------+
+--R        +-+ |   |          2       | |          2
+--R       \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     2 2        2      4
+--R                  32a c  - 16a b c + 2b
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       2 2        2      4
+--R                  - 32a c  + 16a b c - 2b
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     2 2        2      4
+--R                  32a c  - 16a b c + 2b
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       2 2        2      4
+--R                  - 32a c  + 16a b c - 2b
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R            3
+--R       - b x  - 2a x
+--R  /
+--R          2     2   4               3  2     2        2
+--R     (8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 562
+
+--S 563 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +--------------------+
+--R                         +-----------+     |   +-----------+
+--R                  2  +-+ |          2  +-+ |   |          2
+--R         (4a c - b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     2 2        2      4
+--R                  32a c  - 16a b c + 2b
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                           +-----------+
+--R                    2  +-+ |          2  +-+
+--R         (- 4a c + b )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          3   4        2 3 3         5 2      7
+--R                    (4096a b c  - 3072a b c  + 768a b c  - 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       2 2        2      4
+--R                  - 32a c  + 16a b c - 2b
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                         +-----------+
+--R                  2  +-+ |          2  +-+
+--R         (4a c - b )\|2 \|- 4a c + b  \|c
+--R      *
+--R         ROOT
+--R                          3 4       2 2 3         4 2      6
+--R                  (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                     2 2        2      4
+--R                  32a c  - 16a b c + 2b
+--R             *
+--R                ROOT
+--R                                 3 4       2 2 3         4 2      6
+--R                         (- 1024a c  + 768a b c  - 192a b c  + 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                                             +--------------------+
+--R                           +-----------+     |   +-----------+
+--R                    2  +-+ |          2  +-+ |   |          2
+--R         (- 4a c + b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        3 4       2 2 3         4 2      6
+--R                  (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R               *
+--R                   +------------------------------------------------+
+--R                   |                         1
+--R                   |- ----------------------------------------------
+--R                   |        3 5         2 2 4          4 3       6 2
+--R                  \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  3 4       2 2 3        4 2     6
+--R              512a c  - 384a b c  + 96a b c  - 8b c
+--R      *
+--R         log
+--R                            3   4        2 3 3         5 2      7
+--R                    (- 4096a b c  + 3072a b c  - 768a b c  + 64b c)
+--R                 *
+--R                     +------------------------------------------------+
+--R                     |                         1
+--R                     |- ----------------------------------------------
+--R                     |        3 5         2 2 4          4 3       6 2
+--R                    \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                + 
+--R                       2 2        2      4
+--R                  - 32a c  + 16a b c - 2b
+--R             *
+--R                ROOT
+--R                               3 4       2 2 3         4 2      6
+--R                         (1024a c  - 768a b c  + 192a b c  - 16b c)
+--R                      *
+--R                          +------------------------------------------------+
+--R                          |                         1
+--R                          |- ----------------------------------------------
+--R                          |        3 5         2 2 4          4 3       6 2
+--R                         \|  16384a c  - 12288a b c  + 3072a b c  - 256b c
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         3 4       2 2 3        4 2     6
+--R                     512a c  - 384a b c  + 96a b c  - 8b c
+--R            + 
+--R                        2
+--R              (4a c + 3b )x
+--R     + 
+--R                                       +------------------+
+--R            +-----------+              | +-----------+
+--R            |          2            2  | |          2
+--R         (b\|- 4a c + b   - 4a c - b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                       +--------------------+
+--R            +-----------+              |   +-----------+
+--R            |          2            2  |   |          2
+--R         (b\|- 4a c + b   + 4a c + b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                          +--------------------+
+--R                        +-----------+     |   +-----------+
+--R                 2  +-+ |          2  +-+ |   |          2
+--R       (8a c - 2b )\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 704
+t0:=x^5/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                               3
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 565
+
+--S 566 of 704
+r0:=1/2*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-b*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                        2                        +-----------+
+--R          4     2 2                 2c x  + b            2       |          2
+--R   (2b c x  + 2b x  + 2a b)atanh(--------------) + (- b x  - 2a)\|- 4a c + b
+--R                                  +-----------+
+--R                                  |          2
+--R                                 \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                                             +-----------+
+--R              2     2   4               3  2     2        2  |          2
+--R        ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 4    2 2
+--R           (b c x  + b x  + a b)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                       +-----------+
+--R               2       |          2
+--R         (- b x  - 2a)\|- 4a c + b
+--R    /
+--R                                                            +-----------+
+--R             2     2   4               3  2     2        2  |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R     ,
+--R
+--R                                                    +---------+
+--R                                             2      |        2
+--R                  4     2 2             (2c x  + b)\|4a c - b
+--R         (- 2b c x  - 2b x  - 2a b)atan(-----------------------)
+--R                                                       2
+--R                                               4a c - b
+--R       + 
+--R                       +---------+
+--R               2       |        2
+--R         (- b x  - 2a)\|4a c - b
+--R    /
+--R                                                            +---------+
+--R             2     2   4               3  2     2        2  |        2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 567
+
+--S 568 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                         2
+--R                     2c x  + b
+--R       - 2b atanh(--------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4a c + b
+--R  /
+--R                  +-----------+
+--R               2  |          2
+--R     (8a c - 2b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           +---------+             2
+--R           |        2          2c x  + b
+--R       - b\|4a c - b  atanh(--------------)
+--R                             +-----------+
+--R                             |          2
+--R                            \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R           +-----------+          2      |        2
+--R           |          2      (2c x  + b)\|4a c - b
+--R       - b\|- 4a c + b  atan(-----------------------)
+--R                                            2
+--R                                    4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 571
+
+)clear all
+
+--S 572 of 704
+t0:=x^4/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                               2
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 572
+
+--S 573 of 704
+r0:=-1/2*x*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(2*b-sqrt(b^2-4*a*c))/((b^2-_
+   4*a*c)^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(2*b+sqrt(b^2-4*a*c))/((b^2-_
+   4*a*c)^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                               +-----------+
+--R               4       2       |          2          4     2 2         +-+
+--R         ((2c x  + 2b x  + 2a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                               +-----------+
+--R               4       2       |          2          4     2 2         +-+
+--R         ((2c x  + 2b x  + 2a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                     +--------------------+ +------------------+
+--R                       +-----------+ |   +-----------+      | +-----------+
+--R          3        +-+ |          2  |   |          2       | |          2
+--R     (2c x  + b x)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                                +-----------+
+--R             2     2   4               3  2     2        2  +-+ |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2 \|- 4a c + b
+--R    *
+--R        +--------------------+ +------------------+
+--R        |   +-----------+      | +-----------+
+--R        |   |          2       | |          2
+--R       \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                       2   2       3     5
+--R                  - 16a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                     2   2       3     5
+--R                  16a b c  - 8a b c + b
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R               2    2   4              3  2     2       2
+--R         ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                       2   2       3     5
+--R                  - 16a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                 2    2   4                3  2     2       2
+--R         ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                     2   2       3     5
+--R                  16a b c  - 8a b c + b
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R           3
+--R       2c x  + b x
+--R  /
+--R          2     2   4               3  2     2        2
+--R     (8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 574
+
+--S 575 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       +--------------------+
+--R                         +-----------+ |   +-----------+
+--R                  2  +-+ |          2  |   |          2
+--R         (4a c - b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                       2   2       3     5
+--R                  - 16a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                           +-----------+
+--R                    2  +-+ |          2
+--R         (- 4a c + b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          5 4        4 2 3       2 6         8
+--R                    (4096a c  - 2048a b c  + 128a b c - 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                     2   2       3     5
+--R                  16a b c  - 8a b c + b
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                         +-----------+
+--R                  2  +-+ |          2
+--R         (4a c - b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          4 3       3 2 2       2 4         6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                       2   2       3     5
+--R                  - 16a b c  + 8a b c - b
+--R             *
+--R                ROOT
+--R                                 4 3       3 2 2       2 4         6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R                    2  +-+ |          2  |   |          2
+--R         (- 4a c + b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        4 3       3 2 2       2 4         6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |        5 3         4 2 2        3 4        2 6
+--R                  \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                           3
+--R                12a b c + b
+--R           /
+--R                  4 3       3 2 2      2 4        6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            5 4        4 2 3       2 6         8
+--R                    (- 4096a c  + 2048a b c  - 128a b c + 16a b )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |        5 3         4 2 2        3 4        2 6
+--R                    \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                     2   2       3     5
+--R                  16a b c  - 8a b c + b
+--R             *
+--R                ROOT
+--R                               4 3       3 2 2       2 4         6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |        5 3         4 2 2        3 4        2 6
+--R                         \|  16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                                  3
+--R                       12a b c + b
+--R                  /
+--R                         4 3       3 2 2      2 4        6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2     2
+--R              (4a c  + 3b c)x
+--R     + 
+--R                                      +------------------+
+--R              +-----------+           | +-----------+
+--R              |          2        +-+ | |          2
+--R         (- 2\|- 4a c + b   + 4b)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                      +--------------------+
+--R              +-----------+           |   +-----------+
+--R              |          2        +-+ |   |          2
+--R         (- 2\|- 4a c + b   - 4b)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                    +--------------------+ +------------------+
+--R                      +-----------+ |   +-----------+      | +-----------+
+--R               2  +-+ |          2  |   |          2       | |          2
+--R     (8a c - 2b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 704
+t0:=x^3/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 577
+
+--S 578 of 704
+r0:=1/2*(-b-2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+2*c*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                          2                      +-----------+
+--R        2 4         2                 2c x  + b           2      |          2
+--R   (- 4c x  - 4b c x  - 4a c)atanh(--------------) + (2c x  + b)\|- 4a c + b
+--R                                    +-----------+
+--R                                    |          2
+--R                                   \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                                             +-----------+
+--R              2     2   4               3  2     2        2  |          2
+--R        ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              2 4         2
+--R           (2c x  + 2b c x  + 2a c)
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                     +-----------+
+--R              2      |          2
+--R         (2c x  + b)\|- 4a c + b
+--R    /
+--R                                                            +-----------+
+--R             2     2   4               3  2     2        2  |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R     ,
+--R
+--R                                                  +---------+
+--R                                           2      |        2
+--R            2 4         2             (2c x  + b)\|4a c - b
+--R         (4c x  + 4b c x  + 4a c)atan(-----------------------)
+--R                                                     2
+--R                                             4a c - b
+--R       + 
+--R                     +---------+
+--R              2      |        2
+--R         (2c x  + b)\|4a c - b
+--R    /
+--R                                                            +---------+
+--R             2     2   4               3  2     2        2  |        2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 579
+
+--S 580 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         c
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                       2
+--R                   2c x  + b
+--R       2c atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R              2  |          2
+--R     (4a c - b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +---------+             2
+--R          |        2          2c x  + b
+--R       2c\|4a c - b  atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                        +---------+
+--R          +-----------+          2      |        2
+--R          |          2      (2c x  + b)\|4a c - b
+--R       2c\|- 4a c + b  atan(-----------------------)
+--R                                           2
+--R                                   4a c - b
+--R  /
+--R                 +-----------+ +---------+
+--R              2  |          2  |        2
+--R     (4a c - b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 583
+
+)clear all
+
+--S 584 of 704
+t0:=x^2/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 584
+
+--S 585 of 704
+r0:=1/2*x*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b+(b^2-_
+   12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b+_
+   (-b^2+12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                   +-----------+
+--R                   4    2 2        |          2          2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (12a c  - b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c - b )x  + 12a c - a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2            2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (- 12a c  + b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c + b )x  - 12a c + a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R                 3            2    +-+ |          2  |   |          2
+--R         (- b c x  + (2a c - b )x)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R           2 2       2   4      2          3  2     3      2 2  +-+
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 585
+
+--S 586 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 2      2   4      2         3  2     3     2 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      4 4       3 2 3       2 4 2        6     8
+--R                  864a c  - 672a b c  + 190a b c  - 23a b c + b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R               2 2      2   4        2         3  2     3     2 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        4 4       3 2 3       2 4 2        6     8
+--R                  - 864a c  + 672a b c  - 190a b c  + 23a b c - b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R             2 2      2   4      2         3  2     3     2 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + 4a c - a b )
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      4 4       3 2 3       2 4 2        6     8
+--R                  864a c  - 672a b c  + 190a b c  - 23a b c + b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R               2 2      2   4        2         3  2     3     2 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  - 4a c + a b )
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        4 4       3 2 3       2 4 2        6     8
+--R                  - 864a c  + 672a b c  - 190a b c  + 23a b c - b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R              3            2
+--R       - b c x  + (2a c - b )x
+--R  /
+--R        2 2       2   4      2          3  2     3      2 2
+--R     (8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 586
+
+--S 587 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            2       2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      4 4       3 2 3       2 4 2        6     8
+--R                  864a c  - 672a b c  + 190a b c  - 23a b c + b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R                             +-----------+
+--R              2       2  +-+ |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                          7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (8192a b c  - 7168a b c  + 2304a b c  - 320a b c + 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        4 4       3 2 3       2 4 2        6     8
+--R                  - 864a c  + 672a b c  - 190a b c  + 23a b c - b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R                           +-----------+
+--R            2       2  +-+ |          2
+--R         (4a c - a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          6 3       5 2 2       4 4       3 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                      4 4       3 2 3       2 4 2        6     8
+--R                  864a c  - 672a b c  + 190a b c  - 23a b c + b
+--R             *
+--R                ROOT
+--R                                 6 3       5 2 2       4 4       3 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              2       2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        6 3       5 2 2       4 4       3 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +---------------------------------------------+
+--R                   |                2 2        2     4
+--R                   |           - 81a c  + 18a b c - b
+--R                   |---------------------------------------------
+--R                   |      9 3         8 2 2        7 4        6 6
+--R                  \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R              + 
+--R                   2   2        3     5
+--R                60a b c  - 15a b c + b
+--R           /
+--R                  6 3       5 2 2      4 4      3 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            7   4        6 3 3        5 5 2       4 7       3 9
+--R                    (- 8192a b c  + 7168a b c  - 2304a b c  + 320a b c - 16a b )
+--R                 *
+--R                     +---------------------------------------------+
+--R                     |                2 2        2     4
+--R                     |           - 81a c  + 18a b c - b
+--R                     |---------------------------------------------
+--R                     |      9 3         8 2 2        7 4        6 6
+--R                    \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                + 
+--R                        4 4       3 2 3       2 4 2        6     8
+--R                  - 864a c  + 672a b c  - 190a b c  + 23a b c - b
+--R             *
+--R                ROOT
+--R                               6 3       5 2 2       4 4       3 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                          +---------------------------------------------+
+--R                          |                2 2        2     4
+--R                          |           - 81a c  + 18a b c - b
+--R                          |---------------------------------------------
+--R                          |      9 3         8 2 2        7 4        6 6
+--R                         \|16384a c  - 12288a b c  + 3072a b c - 256a b
+--R                     + 
+--R                          2   2        3     5
+--R                       60a b c  - 15a b c + b
+--R                  /
+--R                         6 3       5 2 2      4 4      3 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                   2 4        2 3     4 2
+--R              (324a c  - 81a b c  + 5b c )x
+--R     + 
+--R                                            +------------------+
+--R            +-----------+                   | +-----------+
+--R            |          2             2  +-+ | |          2
+--R         (b\|- 4a c + b   - 12a c + b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R            +-----------+                   |   +-----------+
+--R            |          2             2  +-+ |   |          2
+--R         (b\|- 4a c + b   + 12a c - b )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R          2        2  +-+ |          2  |   |          2
+--R       (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 588
+
+)clear all
+
+--S 589 of 704
+t0:=x/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R         2 9         7            2  5         3    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 589
+
+--S 590 of 704
+r0:=1/2*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   1/2*b*(b^2-6*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^2*_
+   (b^2-4*a*c)^(3/2))+log(x)/a^2-1/4*log(a+b*x^2+c*x^4)/a^2
+--R 
+--R
+--R   (2)
+--R                  2     3   4         2      4  2      2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x  + 12a b c - 2a b )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    2   4                3  2     2       2
+--R             ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                  2     2   4                3  2      2        2
+--R           ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )log(x)
+--R         + 
+--R                     2     2        2
+--R           - 2a b c x  + 4a c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                 +-----------+
+--R          3 2     2 2   4       3        2 3  2      4      3 2  |          2
+--R     ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   2    3   4        2     4  2     2         3
+--R           ((6a b c  - b c)x  + (6a b c - b )x  + 6a b c - a b )
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                       2    2   4                3  2     2       2
+--R               ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                    2     2   4                3  2      2        2
+--R             ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )log(x)
+--R           + 
+--R                       2     2        2
+--R             - 2a b c x  + 4a c - 2a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R                                                                   +-----------+
+--R            3 2     2 2   4       3        2 3  2      4      3 2  |          2
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|- 4a c + b
+--R     ,
+--R
+--R                      2     3   4           2      4  2      2          3
+--R           ((- 12a b c  + 2b c)x  + (- 12a b c + 2b )x  - 12a b c + 2a b )
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2    2   4                3  2     2       2
+--R               ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                    2     2   4                3  2      2        2
+--R             ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )log(x)
+--R           + 
+--R                       2     2        2
+--R             - 2a b c x  + 4a c - 2a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                   +---------+
+--R            3 2     2 2   4       3        2 3  2      4      3 2  |        2
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 591
+
+--S 592 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                    3
+--R         (6a b c - b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                     2
+--R                      3          2c x  + b
+--R       (- 12a b c + 2b )atanh(--------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                     +-----------+
+--R         3      2 2  |          2
+--R     (16a c - 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +---------+             2
+--R                    3  |        2          2c x  + b
+--R       (- 6a b c + b )\|4a c - b  atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                                                     +---------+
+--R                       +-----------+          2      |        2
+--R                    3  |          2      (2c x  + b)\|4a c - b
+--R       (- 6a b c + b )\|- 4a c + b  atan(-----------------------)
+--R                                                        2
+--R                                                4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R        3      2 2  |          2  |        2
+--R     (8a c - 2a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 595
+
+)clear all
+
+--S 596 of 704
+t0:=1/(a*x+b*x^3+c*x^5)^2
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R         2 10         8            2  6         4    2 2
+--R        c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 596
+
+--S 597 of 704
+r0:=1/2*(-3*b^2+10*a*c)/(a^2*(b^2-4*a*c)*x)+1/2*(b^2-2*a*c+b*c*x^2)/_
+   (a*(b^2-4*a*c)*x*(a+b*x^2+c*x^4))-1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2-10*a*c+b*(3*b^2-16*a*c)/sqrt(b^2-_
+   4*a*c))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2-_
+   10*a*c+(-3*b^3+16*a*b*c)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2     2   5                  3  3         2        2
+--R             ((- 10a c  + 3b c)x  + (- 10a b c + 3b )x  + (- 10a c + 3a b )x)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   5           2      4  3         2          3
+--R           (- 16a b c  + 3b c)x  + (- 16a b c + 3b )x  + (- 16a b c + 3a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2     2   5                  3  3         2        2
+--R             ((- 10a c  + 3b c)x  + (- 10a b c + 3b )x  + (- 10a c + 3a b )x)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   5         2      4  3       2          3
+--R           (16a b c  - 3b c)x  + (16a b c - 3b )x  + (16a b c - 3a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2     2   4                  3  2     2        2  +-+
+--R         ((- 10a c  + 3b c)x  + (- 11a b c + 3b )x  - 8a c + 2a b )\|2
+--R      *
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2  |   |          2       | |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R           3 2     2 2   5      3        2 3  3      4      3 2    +-+
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x)\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 2    2 2   5        3       2 3  3        4     3 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  + (- 4a c + a b )x)
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5         4 3 4         3 5 3        2 7 2         9
+--R                  5200a b c  - 14408a b c  + 10549a b c  - 3330a b c  + 486a b c
+--R                + 
+--R                       11
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R             3 2    2 2   5      3       2 3  3      4     3 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                + 
+--R                          9       11
+--R                  - 486a b c + 27b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R               3 2    2 2   5        3       2 3  3        4     3 2
+--R         ((- 4a c  + a b c)x  + (- 4a b c + a b )x  + (- 4a c + a b )x)
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5         4 3 4         3 5 3        2 7 2         9
+--R                  5200a b c  - 14408a b c  + 10549a b c  - 3330a b c  + 486a b c
+--R                + 
+--R                       11
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R             3 2    2 2   5      3       2 3  3      4     3 2
+--R         ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                + 
+--R                          9       11
+--R                  - 486a b c + 27b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R               2     2   4                  3  2     2        2
+--R       (- 10a c  + 3b c)x  + (- 11a b c + 3b )x  - 8a c + 2a b
+--R  /
+--R        3 2     2 2   5      3        2 3  3      4      3 2
+--R     (8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 598
+
+--S 599 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              3     2 2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5         4 3 4         3 5 3        2 7 2         9
+--R                  5200a b c  - 14408a b c  + 10549a b c  - 3330a b c  + 486a b c
+--R                + 
+--R                       11
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R                           +-----------+
+--R            3     2 2  +-+ |          2
+--R         (4a c - a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            10 5         9 2 4         8 4 3        7 6 2
+--R                      20480a  c  - 34816a b c  + 21504a b c  - 6272a b c
+--R                    + 
+--R                          6 8       5 10
+--R                      880a b c - 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                + 
+--R                          9       11
+--R                  - 486a b c + 27b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R                             +-----------+
+--R              3     2 2  +-+ |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b
+--R      *
+--R         ROOT
+--R                          8 3       7 2 2       6 4       5 6
+--R                  (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                       5   5         4 3 4         3 5 3        2 7 2         9
+--R                  5200a b c  - 14408a b c  + 10549a b c  - 3330a b c  + 486a b c
+--R                + 
+--R                       11
+--R                  - 27b
+--R             *
+--R                ROOT
+--R                                 8 3       7 2 2       6 4       5 6
+--R                         (- 1024a c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            3     2 2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        8 3       7 2 2       6 4       5 6
+--R                  (1024a c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                   +-----------------------------------------------------+
+--R                   |      4 4        3 2 3        2 4 2         6       8
+--R                   |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                   |-----------------------------------------------------
+--R                   |        13 3         12 2 2        11 4        10 6
+--R                  \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                      3   3       2 3 2         5      7
+--R                - 420a b c  + 385a b c  - 105a b c + 9b
+--R           /
+--R                  8 3       7 2 2      6 4      5 6
+--R              512a c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              10 5         9 2 4         8 4 3        7 6 2
+--R                      - 20480a  c  + 34816a b c  - 21504a b c  + 6272a b c
+--R                    + 
+--R                            6 8       5 10
+--R                      - 880a b c + 48a b
+--R                 *
+--R                     +-----------------------------------------------------+
+--R                     |      4 4        3 2 3        2 4 2         6       8
+--R                     |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                     |-----------------------------------------------------
+--R                     |        13 3         12 2 2        11 4        10 6
+--R                    \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                         5   5         4 3 4         3 5 3        2 7 2
+--R                  - 5200a b c  + 14408a b c  - 10549a b c  + 3330a b c
+--R                + 
+--R                          9       11
+--R                  - 486a b c + 27b
+--R             *
+--R                ROOT
+--R                               8 3       7 2 2       6 4       5 6
+--R                         (1024a c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                        +-----------------------------------------------------+
+--R                        |      4 4        3 2 3        2 4 2         6       8
+--R                        |- 625a c  + 2550a b c  - 3051a b c  + 918a b c - 81b
+--R                        |-----------------------------------------------------
+--R                        |        13 3         12 2 2        11 4        10 6
+--R                       \|  16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                             3   3       2 3 2         5      7
+--R                       - 420a b c  + 385a b c  - 105a b c + 9b
+--R                  /
+--R                         8 3       7 2 2      6 4      5 6
+--R                     512a c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    3 6        2 2 5          4 4       6 3
+--R              (2500a c  - 5625a b c  + 1971a b c  - 189b c )x
+--R     + 
+--R                                                           +------------------+
+--R                        +-----------+                      | +-----------+
+--R                     2  |          2                3  +-+ | |          2
+--R         ((10a c - 3b )\|- 4a c + b   + 16a b c - 3b )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                        +-----------+
+--R                     2  |          2                3  +-+
+--R         ((10a c - 3b )\|- 4a c + b   - 16a b c + 3b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R          3      2 2  +-+ |          2  |   |          2
+--R       (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)clear all
+
+--S 601 of 704
+t0:=1/(x*(a*x+b*x^3+c*x^5)^2)
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R         2 11         9            2  7         5    2 3
+--R        c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 601
+
+--S 602 of 704
+r0:=(-b^2+3*a*c)/(a^2*(b^2-4*a*c)*x^2)+1/2*(b^2-2*a*c+b*c*x^2)/(a*_
+   (b^2-4*a*c)*x^2*(a+b*x^2+c*x^4))-(b^4-6*a*b^2*c+6*a^2*c^2)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(3/2))-_
+   2*b*log(x)/a^3+1/2*b*log(a+b*x^2+c*x^4)/a^3
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   6       2   2        3      5  4
+--R           (12a c  - 12a b c  + 2b c)x  + (12a b c  - 12a b c + 2b )x
+--R         + 
+--R               3 2      2 2        4  2
+--R           (12a c  - 12a b c + 2a b )x
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    3   6        2     4  4      2         3  2
+--R             ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)x  + (- 16a b c + 4b )x
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R                2 2       2   4        2          3  2     3     2 2
+--R           (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x  - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                  +-----------+
+--R         4 2     3 2   6      4        3 3  4      5      4 2  2  |          2
+--R     ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                2 3       2 2    4   6      2   2       3     5  4
+--R             (6a c  - 6a b c  + b c)x  + (6a b c  - 6a b c + b )x
+--R           + 
+--R                3 2     2 2       4  2
+--R             (6a c  - 6a b c + a b )x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2   2             3
+--R                  (- 8a c  + 2b c)x  - 4a b c + b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                       2    3   6        2     4  4      2         3  2
+--R               ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)x  + (- 16a b c + 4b )x
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                  2 2       2   4        2          3  2     3     2 2
+--R             (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x  - 4a c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R             4 2     3 2   6      4        3 3  4      5      4 2  2
+--R         ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                   2 3        2 2     4   6         2   2        3      5  4
+--R             (- 12a c  + 12a b c  - 2b c)x  + (- 12a b c  + 12a b c - 2b )x
+--R           + 
+--R                   3 2      2 2        4  2
+--R             (- 12a c  + 12a b c - 2a b )x
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                       2    3   6        2     4  4      2         3  2
+--R               ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x )
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)x  + (- 16a b c + 4b )x
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                  2 2       2   4        2          3  2     3     2 2
+--R             (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x  - 4a c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R                                                                    +---------+
+--R           4 2     3 2   6      4        3 3  4      5      4 2  2  |        2
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 603
+
+--S 604 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2       2     4
+--R         (6a c  - 6a b c + b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2           2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (- 8a c  + 2b c)x
+--R              + 
+--R                            3
+--R                - 4a b c + b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                              2
+--R             2 2        2      4          2c x  + b
+--R       (- 12a c  + 12a b c - 2b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R                    +-----------+
+--R        4      3 2  |          2
+--R     (8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                               +---------+             2
+--R            2 2       2     4  |        2          2c x  + b
+--R       (- 6a c  + 6a b c - b )\|4a c - b  atanh(--------------)
+--R                                                 +-----------+
+--R                                                 |          2
+--R                                                \|- 4a c + b
+--R     + 
+--R                                                             +---------+
+--R                               +-----------+          2      |        2
+--R            2 2       2     4  |          2      (2c x  + b)\|4a c - b
+--R       (- 6a c  + 6a b c - b )\|- 4a c + b  atan(-----------------------)
+--R                                                                2
+--R                                                        4a c - b
+--R  /
+--R                   +-----------+ +---------+
+--R        4     3 2  |          2  |        2
+--R     (4a c - a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 607
+
+)clear all
+
+--S 608 of 704
+t0:=1/(x^2*(a*x+b*x^3+c*x^5)^2)
+--R 
+--R
+--R                                1
+--R   (1)  -------------------------------------------------
+--R         2 12         10            2  8         6    2 4
+--R        c x   + 2b c x   + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 608
+
+--S 609 of 704
+r0:=1/6*(-5*b^2+14*a*c)/(a^2*(b^2-4*a*c)*x^3)+1/2*b*(5*b^2-19*a*c)/_
+   (a^3*(b^2-4*a*c)*x)+1/2*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^3*_
+   (a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(5*b^3-19*a*b*c+(5*b^4-29*a*b^2*c+28*a^2*c^2)/sqrt(b^2-4*a*c))/_
+   (a^3*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(5*b^3-19*a*b*c+(-5*b^4+_
+   29*a*b^2*c-28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2      3   7         2       4  5       2           3  3
+--R             ((57a b c  - 15b c)x  + (57a b c - 15b )x  + (57a b c - 15a b )x )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 3        2 2      4   7         2   2        3       5  5
+--R           (- 84a c  + 87a b c  - 15b c)x  + (- 84a b c  + 87a b c - 15b )x
+--R         + 
+--R                 3 2      2 2         4  3
+--R           (- 84a c  + 87a b c - 15a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2      3   7         2       4  5       2           3  3
+--R             ((57a b c  - 15b c)x  + (57a b c - 15b )x  + (57a b c - 15a b )x )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 3        2 2      4   7       2   2        3       5  5
+--R           (84a c  - 87a b c  + 15b c)x  + (84a b c  - 87a b c + 15b )x
+--R         + 
+--R               3 2      2 2         4  3
+--R           (84a c  - 87a b c + 15a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2      3   6         2 2        2       4  4
+--R           (57a b c  - 15b c)x  + (- 14a c  + 62a b c - 15b )x
+--R         + 
+--R               2           3  2     3      2 2
+--R           (40a b c - 10a b )x  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            4 2     3 2   7       4        3 3  5       5      4 2  3  +-+
+--R       ((24a c  - 6a b c)x  + (24a b c - 6a b )x  + (24a c - 6a b )x )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4 2     3 2   7         4        3 3  5         5      4 2  3
+--R         ((- 12a c  + 3a b c)x  + (- 12a b c + 3a b )x  + (- 12a c + 3a b )x )
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        7 7         6 2 6          5 4 5          4 6 4
+--R                  10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                + 
+--R                        3 8 3         2 10 2          12        14
+--R                  75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R              4 2     3 2   7       4        3 3  5       5      4 2  3
+--R         ((12a c  - 3a b c)x  + (12a b c - 3a b )x  + (12a c - 3a b )x )
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          7 7         6 2 6          5 4 5          4 6 4
+--R                  - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                + 
+--R                          3 8 3         2 10 2          12        14
+--R                  - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R                4 2     3 2   7         4        3 3  5         5      4 2  3
+--R         ((- 12a c  + 3a b c)x  + (- 12a b c + 3a b )x  + (- 12a c + 3a b )x )
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        7 7         6 2 6          5 4 5          4 6 4
+--R                  10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                + 
+--R                        3 8 3         2 10 2          12        14
+--R                  75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R              4 2     3 2   7       4        3 3  5       5      4 2  3
+--R         ((12a c  - 3a b c)x  + (12a b c - 3a b )x  + (12a c - 3a b )x )
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          7 7         6 2 6          5 4 5          4 6 4
+--R                  - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                + 
+--R                          3 8 3         2 10 2          12        14
+--R                  - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R               2      3   6         2 2        2       4  4
+--R       (57a b c  - 15b c)x  + (- 14a c  + 62a b c - 15b )x
+--R     + 
+--R           2           3  2     3      2 2
+--R       (40a b c - 10a b )x  - 8a c + 2a b
+--R  /
+--R         4 2     3 2   7       4        3 3  5       5      4 2  3
+--R     (24a c  - 6a b c)x  + (24a b c - 6a b )x  + (24a c - 6a b )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 610
+
+--S 611 of 704
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              4     3 2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        7 7         6 2 6          5 4 5          4 6 4
+--R                  10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                + 
+--R                        3 8 3         2 10 2          12        14
+--R                  75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            4     3 2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                            12   5         11 3 4         10 5 3         9 7 2
+--R                      53248a  b c  - 74752a  b c  + 41216a  b c  - 11200a b c
+--R                    + 
+--R                           8 9       7 11
+--R                      1504a b c - 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          7 7         6 2 6          5 4 5          4 6 4
+--R                  - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                + 
+--R                          3 8 3         2 10 2          12        14
+--R                  - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R                                           +--------------------+
+--R                             +-----------+ |   +-----------+
+--R              4     3 2  +-+ |          2  |   |          2
+--R         (- 4a c + a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                          10 3       9 2 2       8 4       7 6
+--R                  (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                        7 7         6 2 6          5 4 5          4 6 4
+--R                  10976a c  - 79408a b c  + 172990a b c  - 160932a b c
+--R                + 
+--R                        3 8 3         2 10 2          12        14
+--R                  75579a b c  - 18940a b  c  + 2425a b  c - 125b
+--R             *
+--R                ROOT
+--R                                 10 3       9 2 2       8 4       7 6
+--R                         (- 1024a  c  + 768a b c  - 192a b c + 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R            4     3 2  +-+ |          2  |   |          2
+--R         (4a c - a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R         ROOT
+--R                        10 3       9 2 2       8 4       7 6
+--R                  (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R               *
+--R                  ROOT
+--R                                6 6         5 2 5         4 4 4         3 6 3
+--R                         - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                       + 
+--R                                 2 8 2          10        12
+--R                         - 39525a b c  + 8250a b  c - 625b
+--R                    /
+--R                             17 3         16 2 2        15 4        14 6
+--R                       16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R              + 
+--R                     4   4        3 3 3        2 5 2         7       9
+--R                1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R           /
+--R                  10 3       9 2 2      8 4      7 6
+--R              512a  c  - 384a b c  + 96a b c - 8a b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              12   5         11 3 4         10 5 3         9 7 2
+--R                      - 53248a  b c  + 74752a  b c  - 41216a  b c  + 11200a b c
+--R                    + 
+--R                             8 9       7 11
+--R                      - 1504a b c + 80a b
+--R                 *
+--R                    ROOT
+--R                                  6 6         5 2 5         4 4 4         3 6 3
+--R                           - 2401a c  + 24108a b c  - 76686a b c  + 83630a b c
+--R                         + 
+--R                                   2 8 2          10        12
+--R                           - 39525a b c  + 8250a b  c - 625b
+--R                      /
+--R                               17 3         16 2 2        15 4        14 6
+--R                         16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                + 
+--R                          7 7         6 2 6          5 4 5          4 6 4
+--R                  - 10976a c  + 79408a b c  - 172990a b c  + 160932a b c
+--R                + 
+--R                          3 8 3         2 10 2          12        14
+--R                  - 75579a b c  + 18940a b  c  - 2425a b  c + 125b
+--R             *
+--R                ROOT
+--R                               10 3       9 2 2       8 4       7 6
+--R                         (1024a  c  - 768a b c  + 192a b c - 16a b )
+--R                      *
+--R                         ROOT
+--R                                       6 6         5 2 5         4 4 4
+--R                                - 2401a c  + 24108a b c  - 76686a b c
+--R                              + 
+--R                                      3 6 3         2 8 2          10        12
+--R                                83630a b c  - 39525a b c  + 8250a b  c - 625b
+--R                           /
+--R                                    17 3         16 2 2        15 4        14 6
+--R                              16384a  c  - 12288a  b c  + 3072a  b c - 256a  b
+--R                     + 
+--R                            4   4        3 3 3        2 5 2         7       9
+--R                       1260a b c  - 2415a b c  + 1386a b c  - 315a b c + 25b
+--R                  /
+--R                         10 3       9 2 2      8 4      7 6
+--R                     512a  c  - 384a b c  + 96a b c - 8a b
+--R            + 
+--R                    4 8         3 2 7         2 4 6           6 5        8 4
+--R              (9604a c  - 50421a b c  + 43410a b c  - 12325a b c  + 1125b c )x
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4  +-+
+--R         ((- 19a b c + 5b )\|- 4a c + b   + 28a c  - 29a b c + 5b )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                            +-----------+
+--R                         3  |          2       2 2        2      4  +-+
+--R         ((- 19a b c + 5b )\|- 4a c + b   - 28a c  + 29a b c - 5b )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R  /
+--R                                        +--------------------+
+--R                          +-----------+ |   +-----------+
+--R          4      3 2  +-+ |          2  |   |          2
+--R       (8a c - 2a b )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 704
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 612
+
+)clear all
+
+--S 613 of 704
+t0:=1/(x^3*(a*x+b*x^3+c*x^5)^2)
+--R 
+--R
+--R                                1
+--R   (1)  -------------------------------------------------
+--R         2 13         11            2  9         7    2 5
+--R        c x   + 2b c x   + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 613
+
+--S 614 of 704
+r0:=1/4*(-3*b^2+8*a*c)/(a^2*(b^2-4*a*c)*x^4)+1/2*b*(3*b^2-11*a*c)/_
+   (a^3*(b^2-4*a*c)*x^2)+1/2*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^4*_
+   (a+b*x^2+c*x^4))+1/2*b*(3*b^4-20*a*b^2*c+30*a^2*c^2)*atanh((b+_
+   2*c*x^2)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(3/2))+(3*b^2-2*a*c)*_
+   log(x)/a^4-1/4*(3*b^2-2*a*c)*log(a+b*x^2+c*x^4)/a^4
+--R 
+--R
+--R   (2)
+--R                 2   3        3 2     5   8         2 2 2        4      6  6
+--R           (- 60a b c  + 40a b c  - 6b c)x  + (- 60a b c  + 40a b c - 6b )x
+--R         + 
+--R                 3   2      2 3        5  4
+--R           (- 60a b c  + 40a b c - 6a b )x
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                  2 3        2 2     4   8      2   2        3      5  6
+--R               (8a c  - 14a b c  + 3b c)x  + (8a b c  - 14a b c + 3b )x
+--R             + 
+--R                  3 2      2 2        4  4
+--R               (8a c  - 14a b c + 3a b )x
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                     2 3        2 2      4   8         2   2        3       5  6
+--R               (- 32a c  + 56a b c  - 12b c)x  + (- 32a b c  + 56a b c - 12b )x
+--R             + 
+--R                     3 2      2 2         4  4
+--R               (- 32a c  + 56a b c - 12a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R               2   2       3   6        3 2      2 2        4  4
+--R           (22a b c  - 6a b c)x  + (- 8a c  + 25a b c - 6a b )x
+--R         + 
+--R               3        2 3  2     4     3 2
+--R           (12a b c - 3a b )x  - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            5 2     4 2   8       5        4 3  6       6      5 2  4
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + (16a c - 4a b )x )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 614
+
+--S 615 of 704
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2   3        3 2     5   8       2 2 2        4      6  6
+--R             (30a b c  - 20a b c  + 3b c)x  + (30a b c  - 20a b c + 3b )x
+--R           + 
+--R                 3   2      2 3        5  4
+--R             (30a b c  - 20a b c + 3a b )x
+--R        *
+--R           log
+--R                                                +-----------+
+--R                     2 4         2           2  |          2         2     2   2
+--R                  (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R                + 
+--R                            3
+--R                  4a b c - b
+--R             /
+--R                   4      2
+--R                c x  + b x  + a
+--R       + 
+--R                    2 3        2 2     4   8      2   2        3      5  6
+--R                 (8a c  - 14a b c  + 3b c)x  + (8a b c  - 14a b c + 3b )x
+--R               + 
+--R                    3 2      2 2        4  4
+--R                 (8a c  - 14a b c + 3a b )x
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                       2 3        2 2      4   8
+--R                 (- 32a c  + 56a b c  - 12b c)x
+--R               + 
+--R                     2   2        3       5  6         3 2      2 2         4  4
+--R               (- 32a b c  + 56a b c - 12b )x  + (- 32a c  + 56a b c - 12a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                 2   2       3   6        3 2      2 2        4  4
+--R             (22a b c  - 6a b c)x  + (- 8a c  + 25a b c - 6a b )x
+--R           + 
+--R                 3        2 3  2     4     3 2
+--R             (12a b c - 3a b )x  - 4a c + a b
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R    /
+--R              5 2     4 2   8       5        4 3  6       6      5 2  4
+--R         ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + (16a c - 4a b )x )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R     ,
+--R
+--R                 2   3        3 2     5   8       2 2 2        4      6  6
+--R             (60a b c  - 40a b c  + 6b c)x  + (60a b c  - 40a b c + 6b )x
+--R           + 
+--R                 3   2      2 3        5  4
+--R             (60a b c  - 40a b c + 6a b )x
+--R        *
+--R                            +---------+
+--R                     2      |        2
+--R                (2c x  + b)\|4a c - b
+--R           atan(-----------------------)
+--R                               2
+--R                       4a c - b
+--R       + 
+--R                    2 3        2 2     4   8      2   2        3      5  6
+--R                 (8a c  - 14a b c  + 3b c)x  + (8a b c  - 14a b c + 3b )x
+--R               + 
+--R                    3 2      2 2        4  4
+--R                 (8a c  - 14a b c + 3a b )x
+--R            *
+--R                      4      2
+--R               log(c x  + b x  + a)
+--R           + 
+--R                       2 3        2 2      4   8
+--R                 (- 32a c  + 56a b c  - 12b c)x
+--R               + 
+--R                     2   2        3       5  6         3 2      2 2         4  4
+--R               (- 32a b c  + 56a b c - 12b )x  + (- 32a c  + 56a b c - 12a b )x
+--R            *
+--R               log(x)
+--R           + 
+--R                 2   2       3   6        3 2      2 2        4  4
+--R             (22a b c  - 6a b c)x  + (- 8a c  + 25a b c - 6a b )x
+--R           + 
+--R                 3        2 3  2     4     3 2
+--R             (12a b c - 3a b )x  - 4a c + a b
+--R        *
+--R            +---------+
+--R            |        2
+--R           \|4a c - b
+--R    /
+--R              5 2     4 2   8       5        4 3  6       6      5 2  4
+--R         ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + (16a c - 4a b )x )
+--R      *
+--R          +---------+
+--R          |        2
+--R         \|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 615
+
+--S 616 of 704
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2   2        3      5
+--R         (30a b c  - 20a b c + 3b )
+--R      *
+--R         log
+--R                                              +-----------+
+--R                   2 4         2           2  |          2         2     2   2
+--R                (2c x  + 2b c x  - 2a c + b )\|- 4a c + b   + (8a c  - 2b c)x
+--R              + 
+--R                          3
+--R                4a b c - b
+--R           /
+--R                 4      2
+--R              c x  + b x  + a
+--R     + 
+--R                                              2
+--R           2   2        3      5          2c x  + b
+--R       (60a b c  - 40a b c + 6b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R                     +-----------+
+--R         5      4 2  |          2
+--R     (16a c - 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 704
+d0:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 704
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------+             2
+--R           2   2        3      5  |        2          2c x  + b
+--R       (30a b c  - 20a b c + 3b )\|4a c - b  atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R     + 
+--R                                                                +---------+
+--R                                  +-----------+          2      |        2
+--R           2   2        3      5  |          2      (2c x  + b)\|4a c - b
+--R       (30a b c  - 20a b c + 3b )\|- 4a c + b  atan(-----------------------)
+--R                                                                   2
+--R                                                           4a c - b
+--R  /
+--R                    +-----------+ +---------+
+--R        5      4 2  |          2  |        2
+--R     (8a c - 2a b )\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 704
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 619
+
+)clear all
+
+--S 620 of 704
+t0:=x^(3/2)*sqrt(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R              +-----------------+
+--R          +-+ |   5      3
+--R   (1)  x\|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 704
+--r0:=1/15*(b+3*c*x^2)*sqrt(x)*sqrt(a*x+b*x^3+c*x^5)/c-1/15*(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))+1/15*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))
+--E 621
+
+--S 622 of 704
+--a0:=integrate(t0,x)
+--E 622
+
+--S 623 of 704
+--m0:=a0-r0
+--E 623
+
+--S 624 of 704
+--d0:=D(m0,x)
+--E 624
+
+)clear all
+
+--S 625 of 704
+t0:=sqrt(x)*sqrt(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R             +-----------------+
+--R         +-+ |   5      3
+--R   (1)  \|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 704
+r0:=-1/16*(b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))*_
+   sqrt(x)*sqrt(a+b*x^2+c*x^4)/(c^(3/2)*sqrt(a*x+b*x^3+c*x^5))+_
+   1/8*(b+2*c*x^2)*sqrt(a*x+b*x^3+c*x^5)/(c*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                    +---------------+                 2
+--R                2   |   4      2                  2c x  + b
+--R       (4a c - b )x\|c x  + b x  + a atanh(-----------------------)
+--R                                                 +---------------+
+--R                                             +-+ |   4      2
+--R                                           2\|c \|c x  + b x  + a
+--R     + 
+--R          2 7         5             2  3           +-+
+--R       (4c x  + 6b c x  + (4a c + 2b )x  + 2a b x)\|c
+--R  /
+--R                 +-----------------+
+--R         +-+ +-+ |   5      3
+--R     16c\|c \|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 704
+--a0:=integrate(t0,x)
+--E 627
+
+--S 628 of 704
+--m0:=a0-r0
+--E 628
+
+--S 629 of 704
+--d0:=D(m0,x)
+--E 629
+
+)clear all
+
+--S 630 of 704
+t0:=sqrt(a*x+b*x^3+c*x^5)/sqrt(x)
+--R 
+--R
+--R         +-----------------+
+--R         |   5      3
+--R        \|c x  + b x  + a x
+--R   (1)  --------------------
+--R                 +-+
+--R                \|x
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 704
+--r0:=1/3*sqrt(x)*sqrt(a*x+b*x^3+c*x^5)+1/6*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))-1/6*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))
+--E 631
+
+--S 632 of 704
+--a0:=integrate(t0,x)
+--E 632
+
+--S 633 of 704
+--m0:=a0-r0
+--E 633
+
+--S 634 of 704
+--d0:=D(m0,x)
+--E 634
+
+)clear all
+
+--S 635 of 704
+t0:=sqrt(a*x+b*x^3+c*x^5)/x^(3/2)
+--R 
+--R
+--R         +-----------------+
+--R         |   5      3
+--R        \|c x  + b x  + a x
+--R   (1)  --------------------
+--R                  +-+
+--R                x\|x
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 704
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))*sqrt(a)*_
+   sqrt(x)*sqrt(a+b*x^2+c*x^4)/sqrt(a*x+b*x^3+c*x^5)+1/4*b*atanh(1/2*(b+_
+   2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*sqrt(a+b*x^2+c*x^4)/_
+   (sqrt(c)*sqrt(a*x+b*x^3+c*x^5))+1/2*sqrt(a*x+b*x^3+c*x^5)/sqrt(x)
+--R 
+--R
+--R   (2)
+--R                    +---------------+                2
+--R            +-+ +-+ |   4      2                  b x  + 2a
+--R       - 2x\|a \|c \|c x  + b x  + a atanh(-----------------------)
+--R                                                 +---------------+
+--R                                             +-+ |   4      2
+--R                                           2\|a \|c x  + b x  + a
+--R     + 
+--R           +---------------+                 2
+--R           |   4      2                  2c x  + b
+--R       b x\|c x  + b x  + a atanh(-----------------------)
+--R                                        +---------------+
+--R                                    +-+ |   4      2
+--R                                  2\|c \|c x  + b x  + a
+--R     + 
+--R            5       3         +-+
+--R       (2c x  + 2b x  + 2a x)\|c
+--R  /
+--R               +-----------------+
+--R       +-+ +-+ |   5      3
+--R     4\|c \|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 636
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 637 of 704
+--a0:=integrate(t0,x)
+--E 637
+
+--S 638 of 704
+--m0:=a0-r0
+--E 638
+
+--S 639 of 704
+--d0:=D(m0,x)
+--E 639
+
+)clear all
+
+--S 640 of 704
+t0:=x^(3/2)*(a*x+b*x^3+c*x^5)^(3/2)
+--R 
+--R
+--R                                 +-----------------+
+--R            6      4      2  +-+ |   5      3
+--R   (1)  (c x  + b x  + a x )\|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 704
+r0:=1/80*(3*b+8*c*x^2)*(a*x+b*x^3+c*x^5)^(3/2)*sqrt(x)/c-_
+   3/512*b*(b^2-4*a*c)^2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+_
+   b*x^2+c*x^4)))*sqrt(x)*sqrt(a+b*x^2+c*x^4)/(c^(7/2)*sqrt(a*x+b*x^3+_
+   c*x^5))-1/640*x^(3/2)*(b*(5*b^2-4*a*c)+4*c*(5*b^2-16*a*c)*x^2)*_
+   sqrt(a*x+b*x^3+c*x^5)/c^2+1/1280*(15*b^4-100*a*b^2*c+128*a^2*c^2)*_
+   sqrt(a*x+b*x^3+c*x^5)/(c^3*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                                          +---------------+
+--R                2   2         3       5   |   4      2
+--R         (- 240a b c  + 120a b c - 15b )x\|c x  + b x  + a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R               5 13         4 11          4       2 3  9            3     3 2  7
+--R           256c x   + 608b c x   + (768a c  + 368b c )x  + (976a b c  - 4b c )x
+--R         + 
+--R                2 3        2 2      4   5        2   2         3       5  3
+--R           (768a c  - 72a b c  + 10b c)x  + (368a b c  - 220a b c + 30b )x
+--R         + 
+--R                3 2       2 2         4
+--R           (256a c  - 200a b c + 30a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                    +-----------------+
+--R          3 +-+ +-+ |   5      3
+--R     2560c \|c \|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 704
+--a0:=integrate(t0,x)
+--E 642
+
+--S 643 of 704
+--m0:=a0-r0
+--E 643
+
+--S 644 of 704
+--d0:=D(m0,x)
+--E 644
+
+)clear all
+
+--S 645 of 704
+t0:=(a*x+b*x^3+c*x^5)^(3/2)*sqrt(x)
+--R 
+--R
+--R                                +-----------------+
+--R            5      3        +-+ |   5      3
+--R   (1)  (c x  + b x  + a x)\|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 645
+
+--S 646 of 704
+--r0:=1/63*(3*b+7*c*x^2)*(a*x+b*x^3+c*x^5)^(3/2)/(c*sqrt(x))-1/315*(b*(4*b^2-9*a*c)+6*c*(2*b^2-7*a*c)*x^2)*sqrt(x)*sqrt(a*x+b*x^3+c*x^5)/c^2+1/630*(8*b^4-57*a*b^2*c+84*a^2*c^2)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))-1/630*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*(8*b^4-57*a*b^2*c+84*a^2*c^2-8*a*b*c*(b^2-6*a*c)/(b+sqrt(b^2-4*a*c)))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))
+--E 646
+
+--S 647 of 704
+--a0:=integrate(t0,x)
+--E 647
+
+--S 648 of 704
+--m0:=a0-r0
+--E 648
+
+--S 649 of 704
+--d0:=D(m0,x)
+--E 649
+
+)clear all
+
+--S 650 of 704
+t0:=(a*x+b*x^3+c*x^5)^(3/2)/sqrt(x)
+--R 
+--R
+--R                            +-----------------+
+--R            5      3        |   5      3
+--R        (c x  + b x  + a x)\|c x  + b x  + a x
+--R   (1)  ---------------------------------------
+--R                           +-+
+--R                          \|x
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 704
+r0:=1/16*(b+2*c*x^2)*(a*x+b*x^3+c*x^5)^(3/2)/(c*x^(3/2))+3/256*(b^2-_
+   4*a*c)^2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*_
+   sqrt(a+b*x^2+c*x^4)/(c^(5/2)*sqrt(a*x+b*x^3+c*x^5))-3/128*(b^2-4*a*c)*_
+   (b+2*c*x^2)*sqrt(a*x+b*x^3+c*x^5)/(c^2*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                                 +---------------+                 2
+--R           2 2        2      4   |   4      2                  2c x  + b
+--R       (48a c  - 24a b c + 3b )x\|c x  + b x  + a atanh(-----------------------)
+--R                                                              +---------------+
+--R                                                          +-+ |   4      2
+--R                                                        2\|c \|c x  + b x  + a
+--R     + 
+--R              4 11        3 9          3      2 2  7            2     3   5
+--R           32c x   + 80b c x  + (112a c  + 52b c )x  + (168a b c  - 2b c)x
+--R         + 
+--R               2 2        2      4  3       2          3
+--R           (80a c  + 44a b c - 6b )x  + (40a b c - 6a b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                   +-----------------+
+--R         2 +-+ +-+ |   5      3
+--R     256c \|c \|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 704
+--a0:=integrate(t0,x)
+--E 652
+
+--S 653 of 704
+--m0:=a0-r0
+--E 653
+
+--S 654 of 704
+--d0:=D(m0,x)
+--E 654
+
+)clear all
+
+--S 655 of 704
+t0:=(a*x+b*x^3+c*x^5)^(3/2)/x^(3/2)
+--R 
+--R
+--R                          +-----------------+
+--R            4      2      |   5      3
+--R        (c x  + b x  + a)\|c x  + b x  + a x
+--R   (1)  -------------------------------------
+--R                          +-+
+--R                         \|x
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 704
+--r0:=1/7*(a*x+b*x^3+c*x^5)^(3/2)/sqrt(x)+1/35*(b^2+10*a*c+3*b*c*x^2)*sqrt(x)*sqrt(a*x+b*x^3+c*x^5)/c-1/35*b*(b^2-8*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))+1/35*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^4-9*a*b^2*c+20*a^2*c^2+b*(b^2-8*a*c)*sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))
+--E 656
+
+--S 657 of 704
+--a0:=integrate(t0,x)
+--E 657
+
+--S 658 of 704
+--m0:=a0-r0
+--E 658
+
+--S 659 of 704
+--d0:=D(m0,x)
+--E 659
+
+)clear all
+
+--S 660 of 704
+t0:=x^(3/2)/sqrt(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R                  +-+
+--R                x\|x
+--R   (1)  --------------------
+--R         +-----------------+
+--R         |   5      3
+--R        \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 704
+r0:=1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*_
+   sqrt(a+b*x^2+c*x^4)/(sqrt(c)*sqrt(a*x+b*x^3+c*x^5))
+--R 
+--R
+--R             +---------------+                 2
+--R         +-+ |   4      2                  2c x  + b
+--R        \|x \|c x  + b x  + a atanh(-----------------------)
+--R                                          +---------------+
+--R                                      +-+ |   4      2
+--R                                    2\|c \|c x  + b x  + a
+--R   (2)  ----------------------------------------------------
+--R                            +-----------------+
+--R                        +-+ |   5      3
+--R                      2\|c \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 704
+--a0:=integrate(t0,x)
+--E 662
+
+--S 663 of 704
+--m0:=a0-r0
+--E 663
+
+--S 664 of 704
+--d0:=D(m0,x)
+--E 664
+
+)clear all
+
+--S 665 of 704
+t0:=sqrt(x)/sqrt(a*x+b*x^3+c*x^5)
+--R 
+--R
+--R                 +-+
+--R                \|x
+--R   (1)  --------------------
+--R         +-----------------+
+--R         |   5      3
+--R        \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 704
+--r0:=elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))
+--E 666
+
+--S 667 of 704
+--a0:=integrate(t0,x)
+--E 667
+
+--S 668 of 704
+--m0:=a0-r0
+--E 668
+
+--S 669 of 704
+--d0:=D(m0,x)
+--E 669
+
+)clear all
+
+--S 670 of 704
+t0:=1/(sqrt(x)*sqrt(a*x+b*x^3+c*x^5))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R             +-----------------+
+--R         +-+ |   5      3
+--R        \|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 704
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*_
+   sqrt(a+b*x^2+c*x^4)/(sqrt(a)*sqrt(a*x+b*x^3+c*x^5))
+--R 
+--R
+--R               +---------------+                2
+--R           +-+ |   4      2                  b x  + 2a
+--R          \|x \|c x  + b x  + a atanh(-----------------------)
+--R                                            +---------------+
+--R                                        +-+ |   4      2
+--R                                      2\|a \|c x  + b x  + a
+--R   (2)  - ----------------------------------------------------
+--R                              +-----------------+
+--R                          +-+ |   5      3
+--R                        2\|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 704
+--a0:=integrate(t0,x)
+--E 672
+
+--S 673 of 704
+--m0:=a0-r0
+--E 673
+
+--S 674 of 704
+--d0:=D(m0,x)
+--E 674
+
+)clear all
+
+--S 675 of 704
+t0:=1/(x^(3/2)*sqrt(a*x+b*x^3+c*x^5))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R              +-----------------+
+--R          +-+ |   5      3
+--R        x\|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 704
+--r0:=-sqrt(a*x+b*x^3+c*x^5)/(a*x^(3/2))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(-b+sqrt(b^2-4*a*c))^(3/2)*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))+1/2*elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*(b-sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(-c)*sqrt(a*x+b*x^3+c*x^5))
+--E 676
+
+--S 677 of 704
+--a0:=integrate(t0,x)
+--E 677
+
+--S 678 of 704
+--m0:=a0-r0
+--E 678
+
+--S 679 of 704
+--d0:=D(m0,x)
+--E 679
+
+)clear all
+
+--S 680 of 704
+t0:=x^(3/2)/(a*x+b*x^3+c*x^5)^(3/2)
+--R 
+--R
+--R                          +-+
+--R                         \|x
+--R   (1)  -------------------------------------
+--R                          +-----------------+
+--R            4      2      |   5      3
+--R        (c x  + b x  + a)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 704
+--r0:=x^(3/2)*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*sqrt(a*x+b*x^3+c*x^5))-1/2*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))
+--E 681
+
+--S 682 of 704
+--a0:=integrate(t0,x)
+--E 682
+
+--S 683 of 704
+--m0:=a0-r0
+--E 683
+
+--S 684 of 704
+--d0:=D(m0,x)
+--E 684
+
+)clear all
+
+--S 685 of 704
+t0:=sqrt(x)/(a*x+b*x^3+c*x^5)^(3/2)
+--R 
+--R
+--R                           +-+
+--R                          \|x
+--R   (1)  ---------------------------------------
+--R                            +-----------------+
+--R            5      3        |   5      3
+--R        (c x  + b x  + a x)\|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 685
+
+--S 686 of 704
+r0:=(b^2-2*a*c+b*c*x^2)*sqrt(x)/(a*(b^2-4*a*c)*sqrt(a*x+b*x^3+c*x^5))-_
+   1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*_
+   sqrt(a+b*x^2+c*x^4)/(a^(3/2)*sqrt(a*x+b*x^3+c*x^5))
+--R 
+--R
+--R   (2)
+--R                         +---------------+                2
+--R                  2  +-+ |   4      2                  b x  + 2a
+--R       (- 4a c + b )\|x \|c x  + b x  + a atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|a \|c x  + b x  + a
+--R     + 
+--R                2            2  +-+ +-+
+--R       (- 2b c x  + 4a c - 2b )\|a \|x
+--R  /
+--R                        +-----------------+
+--R        2        2  +-+ |   5      3
+--R     (8a c - 2a b )\|a \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 704
+--a0:=integrate(t0,x)
+--E 687
+
+--S 688 of 704
+--m0:=a0-r0
+--E 688
+
+--S 689 of 704
+--d0:=D(m0,x)
+--E 689
+
+)clear all
+
+--S 690 of 704
+t0:=1/((a*x+b*x^3+c*x^5)^(3/2)*sqrt(x))
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R                                +-----------------+
+--R            5      3        +-+ |   5      3
+--R        (c x  + b x  + a x)\|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 690
+
+--S 691 of 704
+--r0:=(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*sqrt(x)*sqrt(a*x+b*x^3+c*x^5))-2*(b^2-3*a*c)*sqrt(a*x+b*x^3+c*x^5)/(a^2*(b^2-4*a*c)*x^(3/2))+(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))-elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))
+--E 691
+
+--S 692 of 704
+--a0:=integrate(t0,x)
+--E 692
+
+--S 693 of 704
+--m0:=a0-r0
+--E 693
+
+--S 694 of 704
+--d0:=D(m0,x)
+--E 694
+
+)clear all
+
+--S 695 of 704
+t0:=1/(x^(3/2)*(a*x+b*x^3+c*x^5)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R                                 +-----------------+
+--R            6      4      2  +-+ |   5      3
+--R        (c x  + b x  + a x )\|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 704
+r0:=(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^(3/2)*sqrt(a*x+b*x^3+c*x^5))+_
+   3/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*_
+   sqrt(a+b*x^2+c*x^4)/(a^(5/2)*sqrt(a*x+b*x^3+c*x^5))-1/2*(3*b^2-8*a*c)*_
+   sqrt(a*x+b*x^3+c*x^5)/(a^2*(b^2-4*a*c)*x^(5/2))
+--R 
+--R
+--R   (2)
+--R                         +---------------+                2
+--R                    3  2 |   4      2                  b x  + 2a
+--R       (12a b c - 3b )x \|c x  + b x  + a atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|a \|c x  + b x  + a
+--R     + 
+--R                2     2   4                  3  2     2        2  +-+
+--R       ((- 16a c  + 6b c)x  + (- 20a b c + 6b )x  - 8a c + 2a b )\|a
+--R  /
+--R                              +-----------------+
+--R         3      2 2   +-+ +-+ |   5      3
+--R     (16a c - 4a b )x\|a \|x \|c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 704
+--a0:=integrate(t0,x)
+--E 697
+
+--S 698 of 704
+--m0:=a0-r0
+--E 698
+
+--S 699 of 704
+--d0:=D(m0,x)
+--E 699
+
+)clear all
+
+--S 700 of 704
+t0:=x^(3/2*(-1+n))/(a*x^(-1+n)+b*x^n+c*x^(1+n))^(3/2)
+--R 
+--R
+--R                                  3n - 3
+--R                                  ------
+--R                                     2
+--R                                 x
+--R   (1)  ---------------------------------------------------------
+--R                                     +--------------------------+
+--R            n + 1      n      n - 1  |   n + 1      n      n - 1
+--R        (c x      + b x  + a x     )\|c x      + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 700
+
+--S 701 of 704
+r0:=-2*x^(1/2*(-1+n))*(b+2*c*x)/((b^2-4*a*c)*sqrt(a*x^(-1+n)+b*x^n+c*x^(1+n)))
+--R 
+--R
+--R                                n - 1
+--R                                -----
+--R                                  2
+--R                    (4c x + 2b)x
+--R   (2)  ----------------------------------------
+--R                    +--------------------------+
+--R                 2  |   n + 1      n      n - 1
+--R        (4a c - b )\|c x      + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 701
+
+-- integrate: implementation incomplete (constant residues)
+--S 702 of 704
+--a0:=integrate(t0,x)
+--E 702
+
+--S 703 of 704
+--m0:=a0-r0
+--E 703
+
+--S 704 of 704
+--d0:=D(m0,x)
+--E 704
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich19.input.pamphlet b/src/input/rich19.input.pamphlet
new file mode 100644
index 0000000..d2098a2
--- /dev/null
+++ b/src/input/rich19.input.pamphlet
@@ -0,0 +1,83240 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich19.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a+b x+c x^2)^p (d+e x+f x^2)^q|
+
+\verb|x^m (a+b x+c x^2)^(p/2) (d+e x+f x^2) when b=0|
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich19.output
+)spool rich19.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1580
+t0:=x^2*sqrt(a+c*x^2)/(d+e*x+f*x^2)
+--R 
+--R
+--R            +--------+
+--R          2 |   2
+--R         x \|c x  + a
+--R   (1)  --------------
+--R           2
+--R        f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1580
+r0:=1/2*a*atanh(x*sqrt(c)/sqrt(a+c*x^2))/(f*sqrt(c))+(e^2-d*f)*_
+   atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f^3-e*sqrt(a+c*x^2)/f^2+1/2*x*_
+   sqrt(a+c*x^2)/f-atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (-2*d*f*(a*f^2+c*(e^2-d*f))+e*(a*f^2+c*(e^2-2*d*f))*(e-sqrt(e^2-4*d*f)))/_
+   (f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*_
+   sqrt(e^2-4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (-2*d*f*(a*f^2+c*(e^2-d*f))+e*(a*f^2+c*(e^2-2*d*f))*(e+sqrt(e^2-4*d*f)))/_
+   (f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                        +-----------+
+--R                  2                  3  |          2          3
+--R           (2a e f  - 4c d e f + 2c e )\|- 4d f + e   + 4a d f
+--R         + 
+--R                  2       2  2         2        4
+--R           (- 2a e  - 4c d )f  + 8c d e f - 2c e
+--R      *
+--R              +-----------------------------------------+
+--R              |    +-----------+
+--R          +-+ |    |          2        2               2
+--R         \|c \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                          +-----------+
+--R                    2                  3  |          2          3
+--R           (- 2a e f  + 4c d e f - 2c e )\|- 4d f + e   + 4a d f
+--R         + 
+--R                  2       2  2         2        4
+--R           (- 2a e  - 4c d )f  + 8c d e f - 2c e
+--R      *
+--R              +-------------------------------------------+
+--R              |      +-----------+
+--R          +-+ |      |          2        2               2
+--R         \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                       +-----------+           +-+
+--R               2                2  +-+ |          2          x\|c
+--R           (a f  - 2c d f + 2c e )\|2 \|- 4d f + e  atanh(-----------)
+--R                                                           +--------+
+--R                                                           |   2
+--R                                                          \|c x  + a
+--R         + 
+--R                            +-----------+     +--------+
+--R             2          +-+ |          2  +-+ |   2
+--R           (f x - 2e f)\|2 \|- 4d f + e  \|c \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                 +-------------------------------------------+
+--R               +-----------+     |      +-----------+
+--R         3 +-+ |          2  +-+ |      |          2        2               2
+--R       2f \|2 \|- 4d f + e  \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1580
+--a0:=integrate(t0,x)
+--E 3
+
+--S 4 of 1580
+--m0:=a0-r0
+--E 4
+
+--S 5 of 1580
+--d0:=D(m0,x)
+--E 5
+
+)clear all
+
+--S 6 of 1580
+t0:=x*sqrt(a+c*x^2)/(d+e*x+f*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R         x\|c x  + a
+--R   (1)  --------------
+--R           2
+--R        f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 1580
+r0:=-e*atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f^2+sqrt(a+c*x^2)/f-_
+   atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*c*d*e*f-(a*f^2+_
+   c*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+atanh((2*a*f-_
+   c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))))*(2*c*d*e*f-(a*f^2+c*(e^2-d*f))*(e+_
+   sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                  +-----------+
+--R                2              2  |          2         2                 3
+--R         ((- a f  + c d f - c e )\|- 4d f + e   + a e f  - 3c d e f + c e )
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                +-----------+
+--R              2              2  |          2         2                 3
+--R         ((a f  - c d f + c e )\|- 4d f + e   + a e f  - 3c d e f + c e )
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                   +-----------+               +-+
+--R               +-+ |          2  +-+         x\|c
+--R           - e\|2 \|- 4d f + e  \|c atanh(-----------)
+--R                                           +--------+
+--R                                           |   2
+--R                                          \|c x  + a
+--R         + 
+--R                 +-----------+ +--------+
+--R             +-+ |          2  |   2
+--R           f\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                            +-------------------------------------------+
+--R              +-----------+ |      +-----------+
+--R        2 +-+ |          2  |      |          2        2               2
+--R       f \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 1580
+--a0:=integrate(t0,x)
+--E 8
+
+--S 9 of 1580
+--m0:=a0-r0
+--E 9
+
+--S 10 of 1580
+--d0:=D(m0,x)
+--E 10
+
+)clear all
+
+--S 11 of 1580
+t0:=sqrt(a+c*x^2)/(d+e*x+f*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R          \|c x  + a
+--R   (1)  --------------
+--R           2
+--R        f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1580
+r0:=atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f-atanh((2*a*f-c*x*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f)))))*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))/(f*sqrt(2)*_
+   sqrt(e^2-4*d*f))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))/(f*sqrt(2)*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +-------------------------------------------+
+--R             |      +-----------+
+--R             |      |          2        2               2
+--R            \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R                                   +-----------+
+--R                                   |          2
+--R                               c x\|- 4d f + e   - c e x + 2a f
+--R          atanh(-------------------------------------------------------------)
+--R                                +-------------------------------------------+
+--R                     +--------+ |      +-----------+
+--R                 +-+ |   2      |      |          2        2               2
+--R                \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R       -
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R                                    +-----------+
+--R                                    |          2
+--R                                c x\|- 4d f + e   + c e x - 2a f
+--R            atanh(-----------------------------------------------------------)
+--R                                  +-----------------------------------------+
+--R                       +--------+ |    +-----------+
+--R                   +-+ |   2      |    |          2        2               2
+--R                  \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R            +-----------+               +-+
+--R        +-+ |          2  +-+         x\|c
+--R       \|2 \|- 4d f + e  \|c atanh(-----------)
+--R                                    +--------+
+--R                                    |   2
+--R                                   \|c x  + a
+--R  /
+--R           +-----------+
+--R       +-+ |          2
+--R     f\|2 \|- 4d f + e
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 1580
+--a0:=integrate(t0,x)
+--E 13
+
+--S 14 of 1580
+--m0:=a0-r0
+--E 14
+
+--S 15 of 1580
+--d0:=D(m0,x)
+--E 15
+
+)clear all
+
+--S 16 of 1580
+t0:=sqrt(a+c*x^2)/(x*(d+e*x+f*x^2))
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R           \|c x  + a
+--R   (1)  -----------------
+--R           3      2
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1580
+r0:=-atanh(sqrt(a+c*x^2)/sqrt(a))*sqrt(a)/d+atanh((2*a*f-c*x*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f)))))*(2*a*e*f+(c*d-a*f)*(e-sqrt(e^2-4*d*f)))/(d*sqrt(2)*sqrt(e^2-_
+   4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-atanh((2*a*f-_
+   c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))))*(2*a*e*f+(c*d-a*f)*(e+sqrt(e^2-4*d*f)))/_
+   (d*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                      +-----------+
+--R                      |          2
+--R         ((a f - c d)\|- 4d f + e   + a e f + c d e)
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                        +-----------+
+--R                        |          2
+--R         ((- a f + c d)\|- 4d f + e   + a e f + c d e)
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R       -
+--R                                         +--------+
+--R                 +-----------+           |   2
+--R             +-+ |          2  +-+      \|c x  + a
+--R            \|2 \|- 4d f + e  \|a atanh(-----------)
+--R                                             +-+
+--R                                            \|a
+--R         *
+--R             +-------------------------------------------+
+--R             |      +-----------+
+--R             |      |          2        2               2
+--R            \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                           +-------------------------------------------+
+--R             +-----------+ |      +-----------+
+--R         +-+ |          2  |      |          2        2               2
+--R       d\|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +-------------------------------------------------------+
+--R               |               +-------------+
+--R               |               |       2 2
+--R               |   3      2 2  |      a e                     2       2
+--R               |(8d f - 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R               |               |    5     4 2
+--R           +-+ |              \|  4d f - d e
+--R         d\|a  |-------------------------------------------------------
+--R               |                        3     2 2
+--R              \|                      4d f - d e
+--R      *
+--R         log
+--R                                 +-------------+
+--R                                 |       2 2
+--R                     4     3 2   |      a e      +-+
+--R                  (4d f - d e )x |- ----------- \|a
+--R                                 |    5     4 2
+--R                                \|  4d f - d e
+--R               *
+--R                   +-------------------------------------------------------+
+--R                   |               +-------------+
+--R                   |               |       2 2
+--R                   |   3      2 2  |      a e                     2       2
+--R                   |(8d f - 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R                   |               |    5     4 2
+--R                   |              \|  4d f - d e
+--R                   |-------------------------------------------------------
+--R                   |                        3     2 2
+--R                  \|                      4d f - d e
+--R              + 
+--R                                                           +-------------+
+--R                           +--------+                      |       2 2
+--R                       +-+ |   2             3       2 2   |      a e
+--R                2a d e\|a \|c x  + a  + (4a d f - a d e )x |- -----------
+--R                                                           |    5     4 2
+--R                                                          \|  4d f - d e
+--R              + 
+--R                   2 2      2
+--R                - a e x - 2a d e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                  +---------------------------------------------------------+
+--R                  |                 +-------------+
+--R                  |                 |       2 2
+--R                  |     3      2 2  |      a e                     2       2
+--R                  |(- 8d f + 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R                  |                 |    5     4 2
+--R              +-+ |                \|  4d f - d e
+--R            d\|a  |---------------------------------------------------------
+--R                  |                         3     2 2
+--R                 \|                       4d f - d e
+--R         *
+--R            log
+--R                                    +-------------+
+--R                                    |       2 2
+--R                        4     3 2   |      a e      +-+
+--R                     (4d f - d e )x |- ----------- \|a
+--R                                    |    5     4 2
+--R                                   \|  4d f - d e
+--R                  *
+--R                    +---------------------------------------------------------+
+--R                    |                 +-------------+
+--R                    |                 |       2 2
+--R                    |     3      2 2  |      a e                     2       2
+--R                    |(- 8d f + 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R                    |                 |    5     4 2
+--R                    |                \|  4d f - d e
+--R                    |---------------------------------------------------------
+--R                    |                         3     2 2
+--R                   \|                       4d f - d e
+--R                 + 
+--R                                                                +-------------+
+--R                              +--------+                        |       2 2
+--R                          +-+ |   2               3       2 2   |      a e
+--R                   2a d e\|a \|c x  + a  + (- 4a d f + a d e )x |- -----------
+--R                                                                |    5     4 2
+--R                                                               \|  4d f - d e
+--R                 + 
+--R                      2 2      2
+--R                   - a e x - 2a d e
+--R              /
+--R                 x
+--R     + 
+--R               +---------------------------------------------------------+
+--R               |                 +-------------+
+--R               |                 |       2 2
+--R               |     3      2 2  |      a e                     2       2
+--R               |(- 8d f + 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R               |                 |    5     4 2
+--R           +-+ |                \|  4d f - d e
+--R         d\|a  |---------------------------------------------------------
+--R               |                         3     2 2
+--R              \|                       4d f - d e
+--R      *
+--R         log
+--R                                   +-------------+
+--R                                   |       2 2
+--R                       4     3 2   |      a e      +-+
+--R                  (- 4d f + d e )x |- ----------- \|a
+--R                                   |    5     4 2
+--R                                  \|  4d f - d e
+--R               *
+--R                   +---------------------------------------------------------+
+--R                   |                 +-------------+
+--R                   |                 |       2 2
+--R                   |     3      2 2  |      a e                     2       2
+--R                   |(- 8d f + 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R                   |                 |    5     4 2
+--R                   |                \|  4d f - d e
+--R                   |---------------------------------------------------------
+--R                   |                         3     2 2
+--R                  \|                       4d f - d e
+--R              + 
+--R                                                             +-------------+
+--R                           +--------+                        |       2 2
+--R                       +-+ |   2               3       2 2   |      a e
+--R                2a d e\|a \|c x  + a  + (- 4a d f + a d e )x |- -----------
+--R                                                             |    5     4 2
+--R                                                            \|  4d f - d e
+--R              + 
+--R                   2 2      2
+--R                - a e x - 2a d e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                  +-------------------------------------------------------+
+--R                  |               +-------------+
+--R                  |               |       2 2
+--R                  |   3      2 2  |      a e                     2       2
+--R                  |(8d f - 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R                  |               |    5     4 2
+--R              +-+ |              \|  4d f - d e
+--R            d\|a  |-------------------------------------------------------
+--R                  |                        3     2 2
+--R                 \|                      4d f - d e
+--R         *
+--R            log
+--R                                      +-------------+
+--R                                      |       2 2
+--R                          4     3 2   |      a e      +-+
+--R                     (- 4d f + d e )x |- ----------- \|a
+--R                                      |    5     4 2
+--R                                     \|  4d f - d e
+--R                  *
+--R                      +-------------------------------------------------------+
+--R                      |               +-------------+
+--R                      |               |       2 2
+--R                      |   3      2 2  |      a e                     2       2
+--R                      |(8d f - 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R                      |               |    5     4 2
+--R                      |              \|  4d f - d e
+--R                      |-------------------------------------------------------
+--R                      |                        3     2 2
+--R                     \|                      4d f - d e
+--R                 + 
+--R                                                              +-------------+
+--R                              +--------+                      |       2 2
+--R                          +-+ |   2             3       2 2   |      a e
+--R                   2a d e\|a \|c x  + a  + (4a d f - a d e )x |- -----------
+--R                                                              |    5     4 2
+--R                                                             \|  4d f - d e
+--R                 + 
+--R                      2 2      2
+--R                   - a e x - 2a d e
+--R              /
+--R                 x
+--R     + 
+--R                   +--------+
+--R               +-+ |   2
+--R              \|a \|c x  + a  - a
+--R       2a log(-------------------)
+--R                       x
+--R  /
+--R        +-+
+--R     2d\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +-------------------------------------------+
+--R               +-----------+     |      +-----------+
+--R           +-+ |          2  +-+ |      |          2        2               2
+--R         d\|2 \|- 4d f + e  \|a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-------------------------------------------------------+
+--R          |               +-------------+
+--R          |               |       2 2
+--R          |   3      2 2  |      a e                     2       2
+--R          |(8d f - 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R          |               |    5     4 2
+--R          |              \|  4d f - d e
+--R          |-------------------------------------------------------
+--R          |                        3     2 2
+--R         \|                      4d f - d e
+--R      *
+--R         log
+--R                                 +-------------+
+--R                                 |       2 2
+--R                     4     3 2   |      a e      +-+
+--R                  (4d f - d e )x |- ----------- \|a
+--R                                 |    5     4 2
+--R                                \|  4d f - d e
+--R               *
+--R                   +-------------------------------------------------------+
+--R                   |               +-------------+
+--R                   |               |       2 2
+--R                   |   3      2 2  |      a e                     2       2
+--R                   |(8d f - 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R                   |               |    5     4 2
+--R                   |              \|  4d f - d e
+--R                   |-------------------------------------------------------
+--R                   |                        3     2 2
+--R                  \|                      4d f - d e
+--R              + 
+--R                                                           +-------------+
+--R                           +--------+                      |       2 2
+--R                       +-+ |   2             3       2 2   |      a e
+--R                2a d e\|a \|c x  + a  + (4a d f - a d e )x |- -----------
+--R                                                           |    5     4 2
+--R                                                          \|  4d f - d e
+--R              + 
+--R                   2 2      2
+--R                - a e x - 2a d e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            d\|2 \|- 4d f + e  \|a
+--R         *
+--R             +---------------------------------------------------------+
+--R             |                 +-------------+
+--R             |                 |       2 2
+--R             |     3      2 2  |      a e                     2       2
+--R             |(- 8d f + 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R             |                 |    5     4 2
+--R             |                \|  4d f - d e
+--R             |---------------------------------------------------------
+--R             |                         3     2 2
+--R            \|                       4d f - d e
+--R         *
+--R             +-------------------------------------------+
+--R             |      +-----------+
+--R             |      |          2        2               2
+--R            \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R            log
+--R                                    +-------------+
+--R                                    |       2 2
+--R                        4     3 2   |      a e      +-+
+--R                     (4d f - d e )x |- ----------- \|a
+--R                                    |    5     4 2
+--R                                   \|  4d f - d e
+--R                  *
+--R                    +---------------------------------------------------------+
+--R                    |                 +-------------+
+--R                    |                 |       2 2
+--R                    |     3      2 2  |      a e                     2       2
+--R                    |(- 8d f + 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R                    |                 |    5     4 2
+--R                    |                \|  4d f - d e
+--R                    |---------------------------------------------------------
+--R                    |                         3     2 2
+--R                   \|                       4d f - d e
+--R                 + 
+--R                                                                +-------------+
+--R                              +--------+                        |       2 2
+--R                          +-+ |   2               3       2 2   |      a e
+--R                   2a d e\|a \|c x  + a  + (- 4a d f + a d e )x |- -----------
+--R                                                                |    5     4 2
+--R                                                               \|  4d f - d e
+--R                 + 
+--R                      2 2      2
+--R                   - a e x - 2a d e
+--R              /
+--R                 x
+--R     + 
+--R               +-----------+
+--R           +-+ |          2  +-+
+--R         d\|2 \|- 4d f + e  \|a
+--R      *
+--R          +---------------------------------------------------------+
+--R          |                 +-------------+
+--R          |                 |       2 2
+--R          |     3      2 2  |      a e                     2       2
+--R          |(- 8d f + 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R          |                 |    5     4 2
+--R          |                \|  4d f - d e
+--R          |---------------------------------------------------------
+--R          |                         3     2 2
+--R         \|                       4d f - d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                                   +-------------+
+--R                                   |       2 2
+--R                       4     3 2   |      a e      +-+
+--R                  (- 4d f + d e )x |- ----------- \|a
+--R                                   |    5     4 2
+--R                                  \|  4d f - d e
+--R               *
+--R                   +---------------------------------------------------------+
+--R                   |                 +-------------+
+--R                   |                 |       2 2
+--R                   |     3      2 2  |      a e                     2       2
+--R                   |(- 8d f + 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R                   |                 |    5     4 2
+--R                   |                \|  4d f - d e
+--R                   |---------------------------------------------------------
+--R                   |                         3     2 2
+--R                  \|                       4d f - d e
+--R              + 
+--R                                                             +-------------+
+--R                           +--------+                        |       2 2
+--R                       +-+ |   2               3       2 2   |      a e
+--R                2a d e\|a \|c x  + a  + (- 4a d f + a d e )x |- -----------
+--R                                                             |    5     4 2
+--R                                                            \|  4d f - d e
+--R              + 
+--R                   2 2      2
+--R                - a e x - 2a d e
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R            d\|2 \|- 4d f + e  \|a
+--R         *
+--R             +-------------------------------------------+
+--R             |      +-----------+
+--R             |      |          2        2               2
+--R            \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-------------------------------------------------------+
+--R             |               +-------------+
+--R             |               |       2 2
+--R             |   3      2 2  |      a e                     2       2
+--R             |(8d f - 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R             |               |    5     4 2
+--R             |              \|  4d f - d e
+--R             |-------------------------------------------------------
+--R             |                        3     2 2
+--R            \|                      4d f - d e
+--R         *
+--R            log
+--R                                      +-------------+
+--R                                      |       2 2
+--R                          4     3 2   |      a e      +-+
+--R                     (- 4d f + d e )x |- ----------- \|a
+--R                                      |    5     4 2
+--R                                     \|  4d f - d e
+--R                  *
+--R                      +-------------------------------------------------------+
+--R                      |               +-------------+
+--R                      |               |       2 2
+--R                      |   3      2 2  |      a e                     2       2
+--R                      |(8d f - 2d e ) |- -----------  + 4a d f - 2a e  - 4c d
+--R                      |               |    5     4 2
+--R                      |              \|  4d f - d e
+--R                      |-------------------------------------------------------
+--R                      |                        3     2 2
+--R                     \|                      4d f - d e
+--R                 + 
+--R                                                              +-------------+
+--R                              +--------+                      |       2 2
+--R                          +-+ |   2             3       2 2   |      a e
+--R                   2a d e\|a \|c x  + a  + (4a d f - a d e )x |- -----------
+--R                                                              |    5     4 2
+--R                                                             \|  4d f - d e
+--R                 + 
+--R                      2 2      2
+--R                   - a e x - 2a d e
+--R              /
+--R                 x
+--R     + 
+--R                          +-----------+
+--R                          |          2                     +-+
+--R         ((- 2a f + 2c d)\|- 4d f + e   - 2a e f - 2c d e)\|a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                        +-----------+
+--R                        |          2                     +-+
+--R         ((2a f - 2c d)\|- 4d f + e   - 2a e f - 2c d e)\|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                        +--------+
+--R                  +-----------+     +-+ |   2
+--R              +-+ |          2     \|a \|c x  + a  - a
+--R           2a\|2 \|- 4d f + e  log(-------------------)
+--R                                            x
+--R         + 
+--R                                      +--------+
+--R                  +-----------+       |   2
+--R              +-+ |          2       \|c x  + a
+--R           2a\|2 \|- 4d f + e  atanh(-----------)
+--R                                          +-+
+--R                                         \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                +-------------------------------------------+
+--R              +-----------+     |      +-----------+
+--R          +-+ |          2  +-+ |      |          2        2               2
+--R       2d\|2 \|- 4d f + e  \|a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 1580
+t0:=sqrt(a+c*x^2)/(x^2*(d+e*x+f*x^2))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|c x  + a
+--R   (1)  ------------------
+--R           4      3      2
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 1580
+r0:=e*atanh(sqrt(a+c*x^2)/sqrt(a))*sqrt(a)/d^2-sqrt(a+c*x^2)/(d*x)-_
+   f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*c*d^2+a*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))/(d^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+f*atanh((2*a*f-c*x*(e+sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-_
+   4*d*f)))))*(2*c*d^2+a*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))/(d^2*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                    +-----------+
+--R                    |          2           2         2       2
+--R         (- a e f x\|- 4d f + e   + (2a d f  + (- a e  - 2c d )f)x)
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                  +-----------+
+--R                  |          2           2         2       2
+--R         (a e f x\|- 4d f + e   + (2a d f  + (- a e  - 2c d )f)x)
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                           +--------+
+--R                   +-----------+           |   2
+--R               +-+ |          2  +-+      \|c x  + a
+--R           e x\|2 \|- 4d f + e  \|a atanh(-----------)
+--R                                               +-+
+--R                                              \|a
+--R         + 
+--R                   +-----------+ +--------+
+--R               +-+ |          2  |   2
+--R           - d\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                             +-------------------------------------------+
+--R               +-----------+ |      +-----------+
+--R        2  +-+ |          2  |      |          2        2               2
+--R       d x\|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 1580
+--a0:=integrate(t0,x)
+--E 23
+
+--S 24 of 1580
+--m0:=a0-r0
+--E 24
+
+--S 25 of 1580
+--d0:=D(m0,x)
+--E 25
+
+)clear all
+
+--S 26 of 1580
+t0:=sqrt(a+c*x^2)/(x^3*(d+e*x+f*x^2))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|c x  + a
+--R   (1)  ------------------
+--R           5      4      3
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1580
+r0:=-1/2*c*atanh(sqrt(a+c*x^2)/sqrt(a))/(d*sqrt(a))-(e^2-d*f)*_
+   atanh(sqrt(a+c*x^2)/sqrt(a))*sqrt(a)/d^3-1/2*sqrt(a+c*x^2)/(d*x^2)+_
+   e*sqrt(a+c*x^2)/(d^2*x)+f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (2*e*(c*d^2+a*(e^2-2*d*f))-(c*d^2+a*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/_
+   (d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f))))-f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+_
+   c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*e*(c*d^2+_
+   a*(e^2-2*d*f))-(c*d^2+a*(e^2-d*f))*(e+sqrt(e^2-4*d*f)))/(d^3*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                            +-----------+
+--R                    2        2       2    2 |          2
+--R           (- 2a d f  + (2a e  + 2c d )f)x \|- 4d f + e
+--R         + 
+--R                      2        3       2     2
+--R           (- 6a d e f  + (2a e  + 2c d e)f)x
+--R      *
+--R              +-----------------------------------------+
+--R              |    +-----------+
+--R          +-+ |    |          2        2               2
+--R         \|a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                            +-----------+
+--R                  2          2       2    2 |          2
+--R           (2a d f  + (- 2a e  - 2c d )f)x \|- 4d f + e
+--R         + 
+--R                      2        3       2     2
+--R           (- 6a d e f  + (2a e  + 2c d e)f)x
+--R      *
+--R              +-------------------------------------------+
+--R              |      +-----------+
+--R          +-+ |      |          2        2               2
+--R         \|a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                             +--------+
+--R                                         +-----------+       |   2
+--R                         2      2  2 +-+ |          2       \|c x  + a
+--R           (2a d f - 2a e  - c d )x \|2 \|- 4d f + e  atanh(-----------)
+--R                                                                 +-+
+--R                                                                \|a
+--R         + 
+--R                             +-----------+     +--------+
+--R                      2  +-+ |          2  +-+ |   2
+--R           (2d e x - d )\|2 \|- 4d f + e  \|a \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                   +-------------------------------------------+
+--R                 +-----------+     |      +-----------+
+--R         3 2 +-+ |          2  +-+ |      |          2        2               2
+--R       2d x \|2 \|- 4d f + e  \|a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 1580
+--a0:=integrate(t0,x)
+--E 28
+
+--S 29 of 1580
+--m0:=a0-r0
+--E 29
+
+--S 30 of 1580
+--d0:=D(m0,x)
+--E 30
+
+)clear all
+
+--S 31 of 1580
+t0:=x^2*(a+c*x^2)^(3/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R                      +--------+
+--R            4      2  |   2
+--R        (c x  + a x )\|c x  + a
+--R   (1)  ------------------------
+--R                2
+--R             f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 1580
+r0:=-1/3*e*(a+c*x^2)^(3/2)/f^2+1/4*x*(a+c*x^2)^(3/2)/f+3/8*a^2*_
+   atanh(x*sqrt(c)/sqrt(a+c*x^2))/(f*sqrt(c))+1/2*a*(e^2-d*f)*_
+   atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f^3+(a*f^2*(e^2-d*f)+_
+   c*(e^4-3*d*e^2*f+d^2*f^2))*atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f^5-_
+   e*(a*f^2+c*(e^2-2*d*f))*sqrt(a+c*x^2)/f^4+3/8*a*x*sqrt(a+c*x^2)/f+_
+   1/2*c*(e^2-d*f)*x*sqrt(a+c*x^2)/f^3-atanh((2*a*f-c*x*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f)))))*(-2*d*f*(a^2*f^4+2*a*c*f^2*(e^2-d*f)+c^2*(e^4-3*d*e^2*f+_
+   d^2*f^2))+e*(a*f^2+c*(e^2-3*d*f))*(a*f^2+c*(e^2-d*f))*(e-sqrt(e^2-_
+   4*d*f)))/(f^5*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-_
+   e*sqrt(e^2-4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (-2*d*f*(a^2*f^4+2*a*c*f^2*(e^2-d*f)+c^2*(e^4-3*d*e^2*f+d^2*f^2))+_
+   e*(a*f^2+c*(e^2-3*d*f))*(a*f^2+c*(e^2-d*f))*(e+sqrt(e^2-4*d*f)))/_
+   (f^5*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                  2   4              3           3      2 2   2      2   3
+--R               24a e f  - 96a c d e f  + (48a c e  + 72c d e)f  - 96c d e f
+--R             + 
+--R                  2 5
+--R               24c e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R              2   5         2 2          2  4              2      2 3  3
+--R           48a d f  + (- 24a e  - 96a c d )f  + (192a c d e  + 48c d )f
+--R         + 
+--R                     4       2 2 2  2       2   4       2 6
+--R           (- 48a c e  - 216c d e )f  + 144c d e f - 24c e
+--R      *
+--R              +-----------------------------------------+
+--R              |    +-----------+
+--R          +-+ |    |          2        2               2
+--R         \|c \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                    2   4              3             3      2 2   2      2   3
+--R               - 24a e f  + 96a c d e f  + (- 48a c e  - 72c d e)f  + 96c d e f
+--R             + 
+--R                    2 5
+--R               - 24c e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R              2   5         2 2          2  4              2      2 3  3
+--R           48a d f  + (- 24a e  - 96a c d )f  + (192a c d e  + 48c d )f
+--R         + 
+--R                     4       2 2 2  2       2   4       2 6
+--R           (- 48a c e  - 216c d e )f  + 144c d e f - 24c e
+--R      *
+--R              +-------------------------------------------+
+--R              |      +-----------+
+--R          +-+ |      |          2        2               2
+--R         \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                2 4            3           2      2 2  2      2   2       2 4
+--R             (9a f  - 36a c d f  + (36a c e  + 24c d )f  - 72c d e f + 24c e )
+--R          *
+--R                  +-----------+           +-+
+--R              +-+ |          2          x\|c
+--R             \|2 \|- 4d f + e  atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|c x  + a
+--R         + 
+--R                   4 3         3 2         4          3        2 2            3
+--R               6c f x  - 8c e f x  + (15a f  - 12c d f  + 12c e f )x - 32a e f
+--R             + 
+--R                        2        3
+--R               48c d e f  - 24c e f
+--R          *
+--R                  +-----------+     +--------+
+--R              +-+ |          2  +-+ |   2
+--R             \|2 \|- 4d f + e  \|c \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                  +-------------------------------------------+
+--R                +-----------+     |      +-----------+
+--R          5 +-+ |          2  +-+ |      |          2        2               2
+--R       24f \|2 \|- 4d f + e  \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 1580
+--a0:=integrate(t0,x)
+--E 33
+
+--S 34 of 1580
+--m0:=a0-r0
+--E 34
+
+--S 35 of 1580
+--d0:=D(m0,x)
+--E 35
+
+)clear all
+
+--S 36 of 1580
+t0:=x*(a+c*x^2)^(3/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R                     +--------+
+--R            3        |   2
+--R        (c x  + a x)\|c x  + a
+--R   (1)  -----------------------
+--R                2
+--R             f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 1580
+r0:=1/3*(a+c*x^2)^(3/2)/f-1/2*a*e*atanh(x*sqrt(c)/sqrt(a+c*x^2))*_
+   sqrt(c)/f^2-e*(a*f^2+c*(e^2-2*d*f))*atanh(x*sqrt(c)/sqrt(a+c*x^2))*_
+   sqrt(c)/f^4+(a*f^2+c*(e^2-d*f))*sqrt(a+c*x^2)/f^3-1/2*c*e*x*sqrt(a+_
+   c*x^2)/f^2-atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+_
+   c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*c*d*e*f*_
+   (2*a*f^2+c*(e^2-2*d*f))+(c^2*d*e^2*f-(a*f^2+c*(e^2-d*f))^2)*(e-_
+   sqrt(e^2-4*d*f)))/(f^4*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f-e*sqrt(e^2-4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (2*c*d*e*f*(2*a*f^2+c*(e^2-2*d*f))+(c^2*d*e^2*f-(a*f^2+c*(e^2-d*f))^2)*_
+   (e+sqrt(e^2-4*d*f)))/(f^4*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                  2 4            3             2     2 2  2      2   2      2 4
+--R             (- 6a f  + 12a c d f  + (- 12a c e  - 6c d )f  + 18c d e f - 6c e )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R             2   4              3           3      2 2   2      2   3      2 5
+--R           6a e f  - 36a c d e f  + (12a c e  + 30c d e)f  - 30c d e f + 6c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                2 4            3           2     2 2  2      2   2      2 4
+--R             (6a f  - 12a c d f  + (12a c e  + 6c d )f  - 18c d e f + 6c e )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R             2   4              3           3      2 2   2      2   3      2 5
+--R           6a e f  - 36a c d e f  + (12a c e  + 30c d e)f  - 30c d e f + 6c e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                 +-----------+
+--R                      2                   3  +-+ |          2  +-+
+--R             (- 9a e f  + 12c d e f - 6c e )\|2 \|- 4d f + e  \|c
+--R          *
+--R                        +-+
+--R                      x\|c
+--R             atanh(-----------)
+--R                    +--------+
+--R                    |   2
+--R                   \|c x  + a
+--R         + 
+--R                                                                 +-----------+
+--R                  3 2         2        3         2       2   +-+ |          2
+--R             (2c f x  - 3c e f x + 8a f  - 6c d f  + 6c e f)\|2 \|- 4d f + e
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                             +-------------------------------------------+
+--R               +-----------+ |      +-----------+
+--R         4 +-+ |          2  |      |          2        2               2
+--R       6f \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 1580
+--a0:=integrate(t0,x)
+--E 38
+
+--S 39 of 1580
+--m0:=a0-r0
+--E 39
+
+--S 40 of 1580
+--d0:=D(m0,x)
+--E 40
+
+)clear all
+
+--S 41 of 1580
+t0:=(a+c*x^2)^(3/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (c x  + a)\|c x  + a
+--R   (1)  ---------------------
+--R               2
+--R            f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 1580
+r0:=1/2*a*atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f+(a*f^2+c*(e^2-d*f))*_
+   atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f^3-c*e*sqrt(a+c*x^2)/f^2+_
+   1/2*c*x*sqrt(a+c*x^2)/f+atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (2*f*(c^2*d*e^2-f*(c*d-a*f)^2)-c*e*(2*a*f^2+c*(e^2-2*d*f))*_
+   (e-sqrt(e^2-4*d*f)))/(f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*_
+   (e^2-2*d*f-e*sqrt(e^2-4*d*f))))-atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (2*f*(c^2*d*e^2-f*(c*d-a*f)^2)-c*e*(2*a*f^2+c*(e^2-2*d*f))*_
+   (e+sqrt(e^2-4*d*f)))/(f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                          +-----------+
+--R                    2     2          2 3  |          2      2 4           3
+--R           (4a c e f  - 4c d e f + 2c e )\|- 4d f + e   - 4a f  + 8a c d f
+--R         + 
+--R                    2     2 2  2     2   2      2 4
+--R           (- 4a c e  - 4c d )f  + 8c d e f - 2c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                            +-----------+
+--R                      2     2          2 3  |          2      2 4           3
+--R           (- 4a c e f  + 4c d e f - 2c e )\|- 4d f + e   - 4a f  + 8a c d f
+--R         + 
+--R                    2     2 2  2     2   2      2 4
+--R           (- 4a c e  - 4c d )f  + 8c d e f - 2c e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                        +-----------+               +-+
+--R                2                2  +-+ |          2  +-+         x\|c
+--R           (3a f  - 2c d f + 2c e )\|2 \|- 4d f + e  \|c atanh(-----------)
+--R                                                                +--------+
+--R                                                                |   2
+--R                                                               \|c x  + a
+--R         + 
+--R                                +-----------+ +--------+
+--R               2            +-+ |          2  |   2
+--R           (c f x - 2c e f)\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                             +-------------------------------------------+
+--R               +-----------+ |      +-----------+
+--R         3 +-+ |          2  |      |          2        2               2
+--R       2f \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 1580
+--a0:=integrate(t0,x)
+--E 43
+
+--S 44 of 1580
+--m0:=a0-r0
+--E 44
+
+--S 45 of 1580
+--d0:=D(m0,x)
+--E 45
+
+)clear all
+
+--S 46 of 1580
+t0:=(a+c*x^2)^(3/2)/(x*(d+e*x+f*x^2))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (c x  + a)\|c x  + a
+--R   (1)  ---------------------
+--R             3      2
+--R          f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 1580
+r0:=-c^(3/2)*e*atanh(x*sqrt(c)/sqrt(a+c*x^2))/f^2-a^(3/2)*atanh(sqrt(a+_
+   c*x^2)/sqrt(a))/d+a*sqrt(a+c*x^2)/d+(c*d-a*f)*sqrt(a+c*x^2)/(d*f)-_
+   atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*e*f*(c^2*d^2-_
+   a^2*f^2)-(2*a*c*d*f^2-a^2*f^3+c^2*d*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/_
+   (d*f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+_
+   c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*e*f*_
+   (c^2*d^2-a^2*f^2)-(2*a*c*d*f^2-a^2*f^3+c^2*d*(e^2-d*f))*(e+_
+   sqrt(e^2-4*d*f)))/(d*f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*_
+   (e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                               +-----------+
+--R             2 3           2    2 2     2   2  |          2     2   3
+--R           (a f  - 2a c d f  + c d f - c d e )\|- 4d f + e   + a e f
+--R         + 
+--R                     2     2 2       2   3
+--R           2a c d e f  - 3c d e f + c d e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                 +-----------+
+--R               2 3           2    2 2     2   2  |          2     2   3
+--R           (- a f  + 2a c d f  - c d f + c d e )\|- 4d f + e   + a e f
+--R         + 
+--R                     2     2 2       2   3
+--R           2a c d e f  - 3c d e f + c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                              +--------+
+--R                      +-----------+           |   2
+--R                2 +-+ |          2  +-+      \|c x  + a
+--R           - a f \|2 \|- 4d f + e  \|a atanh(-----------)
+--R                                                  +-+
+--R                                                 \|a
+--R         + 
+--R                       +-----------+               +-+
+--R                   +-+ |          2  +-+         x\|c
+--R           - c d e\|2 \|- 4d f + e  \|c atanh(-----------)
+--R                                               +--------+
+--R                                               |   2
+--R                                              \|c x  + a
+--R         + 
+--R                     +-----------+ +--------+
+--R                 +-+ |          2  |   2
+--R           c d f\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                              +-------------------------------------------+
+--R                +-----------+ |      +-----------+
+--R          2 +-+ |          2  |      |          2        2               2
+--R       d f \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 1580
+--a0:=integrate(t0,x)
+--E 48
+
+--S 49 of 1580
+--m0:=a0-r0
+--E 49
+
+--S 50 of 1580
+--d0:=D(m0,x)
+--E 50
+
+)clear all
+
+--S 51 of 1580
+t0:=(a+c*x^2)^(3/2)/(x^2*(d+e*x+f*x^2))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (c x  + a)\|c x  + a
+--R   (1)  ---------------------
+--R             4      3      2
+--R          f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 1580
+r0:=-(a+c*x^2)^(3/2)/(d*x)+a^(3/2)*e*atanh(sqrt(a+c*x^2)/sqrt(a))/d^2+_
+   a*atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/d+(c*d-a*f)*atanh(x*sqrt(c)/_
+   sqrt(a+c*x^2))*sqrt(c)/(d*f)+c*x*sqrt(a+c*x^2)/d-atanh((2*a*f-c*x*_
+   (e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f-e*sqrt(e^2-4*d*f)))))*(-2*f*(c^2*d^3-2*a*c*d^2*f-a^2*f*(e^2-_
+   d*f))+e*(c*d-a*f)*(c*d+a*f)*(e-sqrt(e^2-4*d*f)))/(d^2*f*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+_
+   atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(-2*f*(c^2*d^3-_
+   2*a*c*d^2*f-a^2*f*(e^2-d*f))+e*(c*d-a*f)*(c*d+a*f)*(e+sqrt(e^2-_
+   4*d*f)))/(d^2*f*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+_
+   e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                               +-----------+
+--R               2   2    2 2    |          2
+--R           (- a e f  + c d e)x\|- 4d f + e
+--R         + 
+--R              2   3       2 2         2  2     2 3     2 2 2
+--R           (2a d f  + (- a e  - 4a c d )f  + 2c d f - c d e )x
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                             +-----------+
+--R             2   2    2 2    |          2
+--R           (a e f  - c d e)x\|- 4d f + e
+--R         + 
+--R              2   3       2 2         2  2     2 3     2 2 2
+--R           (2a d f  + (- a e  - 4a c d )f  + 2c d f - c d e )x
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                               +--------+
+--R                       +-----------+           |   2
+--R                   +-+ |          2  +-+      \|c x  + a
+--R           a e f x\|2 \|- 4d f + e  \|a atanh(-----------)
+--R                                                   +-+
+--R                                                  \|a
+--R         + 
+--R                     +-----------+               +-+
+--R              2  +-+ |          2  +-+         x\|c
+--R           c d x\|2 \|- 4d f + e  \|c atanh(-----------)
+--R                                             +--------+
+--R                                             |   2
+--R                                            \|c x  + a
+--R         + 
+--R                       +-----------+ +--------+
+--R                   +-+ |          2  |   2
+--R           - a d f\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                               +-------------------------------------------+
+--R                 +-----------+ |      +-----------+
+--R        2    +-+ |          2  |      |          2        2               2
+--R       d f x\|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 1580
+--a0:=integrate(t0,x)
+--E 53
+
+--S 54 of 1580
+--m0:=a0-r0
+--E 54
+
+--S 55 of 1580
+--d0:=D(m0,x)
+--E 55
+
+)clear all
+
+--S 56 of 1580
+t0:=(a+c*x^2)^(3/2)/(x^3*(d+e*x+f*x^2))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (c x  + a)\|c x  + a
+--R   (1)  ---------------------
+--R             5      4      3
+--R          f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1580
+r0:=-1/2*(a+c*x^2)^(3/2)/(d*x^2)+e*(a+c*x^2)^(3/2)/(d^2*x)-a^(3/2)*_
+   (e^2-d*f)*atanh(sqrt(a+c*x^2)/sqrt(a))/d^3-3/2*c*atanh(sqrt(a+c*x^2)/_
+   sqrt(a))*sqrt(a)/d+3/2*c*sqrt(a+c*x^2)/d+a*(e^2-d*f)*sqrt(a+c*x^2)/d^3-_
+   (c*d^2+a*(e^2-d*f))*sqrt(a+c*x^2)/d^3-c*e*x*sqrt(a+c*x^2)/d^2+_
+   atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*a*e*f*(2*c*d^2+a*_
+   (e^2-2*d*f))+(c^2*d^3-2*a*c*d^2*f-a^2*f*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/_
+   (d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f))))-atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (2*a*e*f*(2*c*d^2+a*(e^2-2*d*f))+(c^2*d^3-2*a*c*d^2*f-a^2*f*(e^2-d*f))*_
+   (e+sqrt(e^2-4*d*f)))/(d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                                      +-----------+
+--R                2   2      2 2         2       2 3  2 |          2
+--R           (- 2a d f  + (2a e  + 4a c d )f - 2c d )x \|- 4d f + e
+--R         + 
+--R                2     2      2 3         2        2 3   2
+--R           (- 6a d e f  + (2a e  + 4a c d e)f + 2c d e)x
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                      +-----------+
+--R              2   2        2 2         2       2 3  2 |          2
+--R           (2a d f  + (- 2a e  - 4a c d )f + 2c d )x \|- 4d f + e
+--R         + 
+--R                2     2      2 3         2        2 3   2
+--R           (- 6a d e f  + (2a e  + 4a c d e)f + 2c d e)x
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                                  +--------+
+--R                                          +-----------+           |   2
+--R                         2       2  2 +-+ |          2  +-+      \|c x  + a
+--R           (2a d f - 2a e  - 3c d )x \|2 \|- 4d f + e  \|a atanh(-----------)
+--R                                                                      +-+
+--R                                                                     \|a
+--R         + 
+--R                                 +-----------+ +--------+
+--R                          2  +-+ |          2  |   2
+--R           (2a d e x - a d )\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                               +-------------------------------------------+
+--R                 +-----------+ |      +-----------+
+--R         3 2 +-+ |          2  |      |          2        2               2
+--R       2d x \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 57
+
+--S 58 of 1580
+--a0:=integrate(t0,x)
+--E 58
+
+--S 59 of 1580
+--m0:=a0-r0
+--E 59
+
+--S 60 of 1580
+--d0:=D(m0,x)
+--E 60
+
+)clear all
+
+--S 61 of 1580
+t0:=x^3/((d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                      3
+--R                     x
+--R   (1)  ---------------------------
+--R                         +--------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 1580
+r0:=-e*atanh(x*sqrt(c)/sqrt(a+c*x^2))/(f^2*sqrt(c))+sqrt(a+c*x^2)/(c*f)-_
+   atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*d*e*f-(e^2-d*f)*_
+   (e-sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (2*d*e*f-(e^2-d*f)*(e+sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                         +-----------+
+--R                      2  |          2                  3  +-+
+--R         ((c d f - c e )\|- 4d f + e   - 3c d e f + c e )\|c
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                           +-----------+
+--R                        2  |          2                  3  +-+
+--R         ((- c d f + c e )\|- 4d f + e   - 3c d e f + c e )\|c
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                     +-----------+           +-+
+--R                 +-+ |          2          x\|c
+--R           - c e\|2 \|- 4d f + e  atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|c x  + a
+--R         + 
+--R                 +-----------+     +--------+
+--R             +-+ |          2  +-+ |   2
+--R           f\|2 \|- 4d f + e  \|c \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                  +-------------------------------------------+
+--R                +-----------+     |      +-----------+
+--R          2 +-+ |          2  +-+ |      |          2        2               2
+--R       c f \|2 \|- 4d f + e  \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 1580
+--a0:=integrate(t0,x)
+--E 63
+
+--S 64 of 1580
+--m0:=a0-r0
+--E 64
+
+--S 65 of 1580
+--d0:=D(m0,x)
+--E 65
+
+)clear all
+
+--S 66 of 1580
+t0:=x^2/((d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R                         +--------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 1580
+r0:=atanh(x*sqrt(c)/sqrt(a+c*x^2))/(f*sqrt(c))-atanh((2*a*f-_
+   c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(e^2-2*d*f-e*sqrt(e^2-4*d*f))/_
+   (f*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f))))-atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+_
+   c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*d*f-_
+   e*(e+sqrt(e^2-4*d*f)))/(f*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R            +-----------+
+--R            |          2            2  +-+
+--R         (e\|- 4d f + e   + 2d f - e )\|c
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R              +-----------+
+--R              |          2            2  +-+
+--R         (- e\|- 4d f + e   + 2d f - e )\|c
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R              +-----------+           +-+
+--R          +-+ |          2          x\|c
+--R         \|2 \|- 4d f + e  atanh(-----------)
+--R                                  +--------+
+--R                                  |   2
+--R                                 \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                               +-------------------------------------------+
+--R             +-----------+     |      +-----------+
+--R         +-+ |          2  +-+ |      |          2        2               2
+--R       f\|2 \|- 4d f + e  \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 1580
+--a0:=integrate(t0,x)
+--E 68
+
+--S 69 of 1580
+--m0:=a0-r0
+--E 69
+
+--S 70 of 1580
+--d0:=D(m0,x)
+--E 70
+
+)clear all
+
+--S 71 of 1580
+t0:=x/((d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                     x
+--R   (1)  ---------------------------
+--R                         +--------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1580
+r0:=atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(e-sqrt(e^2-4*d*f))/_
+   (sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-_
+   atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(e+sqrt(e^2-4*d*f))/_
+   (sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                +-----------------------------------------+
+--R             +-----------+      |    +-----------+
+--R             |          2       |    |          2        2               2
+--R         (- \|- 4d f + e   + e)\|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                              +-------------------------------------------+
+--R           +-----------+      |      +-----------+
+--R           |          2       |      |          2        2               2
+--R         (\|- 4d f + e   + e)\|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                          +-------------------------------------------+
+--R            +-----------+ |      +-----------+
+--R        +-+ |          2  |      |          2        2               2
+--R       \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R                      2   3        2 2          2  2             2     2 3
+--R                    8a d f  + (- 2a e  - 16a c d )f  + (12a c d e  + 8c d )f
+--R                  + 
+--R                            4     2 2 2
+--R                    - 2a c e  - 2c d e
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 2
+--R                          a e
+--R                       /
+--R                              4   5       4 2      3   2  4
+--R                            4a d f  + (- a e  - 16a c d )f
+--R                          + 
+--R                                3     2      2 2 3  3
+--R                            (12a c d e  + 24a c d )f
+--R                          + 
+--R                                 3   4      2 2 2 2        3 4  2
+--R                            (- 2a c e  - 22a c d e  - 16a c d )f
+--R                          + 
+--R                               2 2   4        3 3 2     4 5      2 2 6
+--R                            (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                          + 
+--R                                  3 2 4    4 4 2
+--R                            - 2a c d e  - c d e
+--R              + 
+--R                             2       2
+--R                4a d f - 2a e  - 4c d
+--R           /
+--R                  2   3       2 2         2  2            2     2 3          4
+--R                4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f - a c e
+--R              + 
+--R                   2 2 2
+--R                - c d e
+--R      *
+--R         log
+--R                          3 2 4        3   2      2   3  3
+--R                        8a d f  + (- 6a d e  - 24a c d )f
+--R                      + 
+--R                          3 4      2   2 2        2 4  2
+--R                        (a e  + 22a c d e  + 24a c d )f
+--R                      + 
+--R                             2     4        2 3 2     3 5      2   6       2 2 4
+--R                        (- 8a c d e  - 18a c d e  - 8c d )f + a c e  + 3a c d e
+--R                      + 
+--R                          3 4 2
+--R                        2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              a e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                       2   2     2 4
+--R                    (4a d e f - a e )x
+--R               *
+--R                  ROOT
+--R                               2   3        2 2          2  2
+--R                             8a d f  + (- 2a e  - 16a c d )f
+--R                           + 
+--R                                       2     2 3           4     2 2 2
+--R                             (12a c d e  + 8c d )f - 2a c e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 2
+--R                                   a e
+--R                                /
+--R                                       4   5       4 2      3   2  4
+--R                                     4a d f  + (- a e  - 16a c d )f
+--R                                   + 
+--R                                         3     2      2 2 3  3
+--R                                     (12a c d e  + 24a c d )f
+--R                                   + 
+--R                                          3   4      2 2 2 2        3 4  2
+--R                                     (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                   + 
+--R                                        2 2   4        3 3 2     4 5      2 2 6
+--R                                     (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                   + 
+--R                                           3 2 4    4 4 2
+--R                                     - 2a c d e  - c d e
+--R                       + 
+--R                                      2       2
+--R                         4a d f - 2a e  - 4c d
+--R                    /
+--R                           2   3       2 2         2  2            2     2 3
+--R                         4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                       + 
+--R                                4    2 2 2
+--R                         - a c e  - c d e
+--R              + 
+--R                       +--------+
+--R                    2  |   2
+--R                4a d e\|c x  + a
+--R              + 
+--R                            2 2 3      2   2          3  2
+--R                        - 8a d f  + (2a d e  + 16a c d )f
+--R                      + 
+--R                                  2 2     2 4             4     2 3 2
+--R                        (- 12a c d e  - 8c d )f + 2a c d e  + 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              a e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                            2        2
+--R                    - 2a d e x - 4a d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                           2   3      2 2          2  2
+--R                       - 8a d f  + (2a e  + 16a c d )f
+--R                     + 
+--R                                   2     2 3           4     2 2 2
+--R                       (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 2
+--R                             a e
+--R                          /
+--R                                 4   5       4 2      3   2  4
+--R                               4a d f  + (- a e  - 16a c d )f
+--R                             + 
+--R                                   3     2      2 2 3  3
+--R                               (12a c d e  + 24a c d )f
+--R                             + 
+--R                                    3   4      2 2 2 2        3 4  2
+--R                               (- 2a c e  - 22a c d e  - 16a c d )f
+--R                             + 
+--R                                  2 2   4        3 3 2     4 5      2 2 6
+--R                               (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                             + 
+--R                                     3 2 4    4 4 2
+--R                               - 2a c d e  - c d e
+--R                 + 
+--R                                2       2
+--R                   4a d f - 2a e  - 4c d
+--R              /
+--R                     2   3       2 2         2  2            2     2 3
+--R                   4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                 + 
+--R                          4    2 2 2
+--R                   - a c e  - c d e
+--R         *
+--R            log
+--R                             3 2 4        3   2      2   3  3
+--R                           8a d f  + (- 6a d e  - 24a c d )f
+--R                         + 
+--R                             3 4      2   2 2        2 4  2
+--R                           (a e  + 22a c d e  + 24a c d )f
+--R                         + 
+--R                                2     4        2 3 2     3 5      2   6
+--R                           (- 8a c d e  - 18a c d e  - 8c d )f + a c e
+--R                         + 
+--R                               2 2 4     3 4 2
+--R                           3a c d e  + 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 a e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                            2   2     2 4
+--R                       (- 4a d e f + a e )x
+--R                  *
+--R                     ROOT
+--R                                    2   3      2 2          2  2
+--R                                - 8a d f  + (2a e  + 16a c d )f
+--R                              + 
+--R                                            2     2 3           4     2 2 2
+--R                                (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 2
+--R                                      a e
+--R                                   /
+--R                                          4   5       4 2      3   2  4
+--R                                        4a d f  + (- a e  - 16a c d )f
+--R                                      + 
+--R                                            3     2      2 2 3  3
+--R                                        (12a c d e  + 24a c d )f
+--R                                      + 
+--R                                             3   4      2 2 2 2        3 4  2
+--R                                        (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                      + 
+--R                                           2 2   4        3 3 2     4 5
+--R                                        (8a c d e  + 12a c d e  + 4c d )f
+--R                                      + 
+--R                                           2 2 6       3 2 4    4 4 2
+--R                                        - a c e  - 2a c d e  - c d e
+--R                          + 
+--R                                         2       2
+--R                            4a d f - 2a e  - 4c d
+--R                       /
+--R                              2   3       2 2         2  2
+--R                            4a d f  + (- a e  - 8a c d )f
+--R                          + 
+--R                                     2     2 3          4    2 2 2
+--R                            (6a c d e  + 4c d )f - a c e  - c d e
+--R                 + 
+--R                          +--------+
+--R                       2  |   2
+--R                   4a d e\|c x  + a
+--R                 + 
+--R                             2 2 3        2   2          3  2
+--R                           8a d f  + (- 2a d e  - 16a c d )f
+--R                         + 
+--R                                   2 2     2 4             4     2 3 2
+--R                           (12a c d e  + 8c d )f - 2a c d e  - 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 a e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                               2        2
+--R                       - 2a d e x - 4a d e
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R         ROOT
+--R                        2   3      2 2          2  2               2     2 3
+--R                    - 8a d f  + (2a e  + 16a c d )f  + (- 12a c d e  - 8c d )f
+--R                  + 
+--R                          4     2 2 2
+--R                    2a c e  + 2c d e
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 2
+--R                          a e
+--R                       /
+--R                              4   5       4 2      3   2  4
+--R                            4a d f  + (- a e  - 16a c d )f
+--R                          + 
+--R                                3     2      2 2 3  3
+--R                            (12a c d e  + 24a c d )f
+--R                          + 
+--R                                 3   4      2 2 2 2        3 4  2
+--R                            (- 2a c e  - 22a c d e  - 16a c d )f
+--R                          + 
+--R                               2 2   4        3 3 2     4 5      2 2 6
+--R                            (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                          + 
+--R                                  3 2 4    4 4 2
+--R                            - 2a c d e  - c d e
+--R              + 
+--R                             2       2
+--R                4a d f - 2a e  - 4c d
+--R           /
+--R                  2   3       2 2         2  2            2     2 3          4
+--R                4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f - a c e
+--R              + 
+--R                   2 2 2
+--R                - c d e
+--R      *
+--R         log
+--R                            3 2 4      3   2      2   3  3
+--R                        - 8a d f  + (6a d e  + 24a c d )f
+--R                      + 
+--R                            3 4      2   2 2        2 4  2
+--R                        (- a e  - 22a c d e  - 24a c d )f
+--R                      + 
+--R                           2     4        2 3 2     3 5      2   6       2 2 4
+--R                        (8a c d e  + 18a c d e  + 8c d )f - a c e  - 3a c d e
+--R                      + 
+--R                            3 4 2
+--R                        - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              a e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                       2   2     2 4
+--R                    (4a d e f - a e )x
+--R               *
+--R                  ROOT
+--R                                 2   3      2 2          2  2
+--R                             - 8a d f  + (2a e  + 16a c d )f
+--R                           + 
+--R                                         2     2 3           4     2 2 2
+--R                             (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 2
+--R                                   a e
+--R                                /
+--R                                       4   5       4 2      3   2  4
+--R                                     4a d f  + (- a e  - 16a c d )f
+--R                                   + 
+--R                                         3     2      2 2 3  3
+--R                                     (12a c d e  + 24a c d )f
+--R                                   + 
+--R                                          3   4      2 2 2 2        3 4  2
+--R                                     (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                   + 
+--R                                        2 2   4        3 3 2     4 5      2 2 6
+--R                                     (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                   + 
+--R                                           3 2 4    4 4 2
+--R                                     - 2a c d e  - c d e
+--R                       + 
+--R                                      2       2
+--R                         4a d f - 2a e  - 4c d
+--R                    /
+--R                           2   3       2 2         2  2            2     2 3
+--R                         4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                       + 
+--R                                4    2 2 2
+--R                         - a c e  - c d e
+--R              + 
+--R                       +--------+
+--R                    2  |   2
+--R                4a d e\|c x  + a
+--R              + 
+--R                          2 2 3        2   2          3  2
+--R                        8a d f  + (- 2a d e  - 16a c d )f
+--R                      + 
+--R                                2 2     2 4             4     2 3 2
+--R                        (12a c d e  + 8c d )f - 2a c d e  - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              a e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                            2        2
+--R                    - 2a d e x - 4a d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                         2   3        2 2          2  2             2     2 3
+--R                       8a d f  + (- 2a e  - 16a c d )f  + (12a c d e  + 8c d )f
+--R                     + 
+--R                               4     2 2 2
+--R                       - 2a c e  - 2c d e
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 2
+--R                             a e
+--R                          /
+--R                                 4   5       4 2      3   2  4
+--R                               4a d f  + (- a e  - 16a c d )f
+--R                             + 
+--R                                   3     2      2 2 3  3
+--R                               (12a c d e  + 24a c d )f
+--R                             + 
+--R                                    3   4      2 2 2 2        3 4  2
+--R                               (- 2a c e  - 22a c d e  - 16a c d )f
+--R                             + 
+--R                                  2 2   4        3 3 2     4 5      2 2 6
+--R                               (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                             + 
+--R                                     3 2 4    4 4 2
+--R                               - 2a c d e  - c d e
+--R                 + 
+--R                                2       2
+--R                   4a d f - 2a e  - 4c d
+--R              /
+--R                     2   3       2 2         2  2            2     2 3
+--R                   4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                 + 
+--R                          4    2 2 2
+--R                   - a c e  - c d e
+--R         *
+--R            log
+--R                               3 2 4      3   2      2   3  3
+--R                           - 8a d f  + (6a d e  + 24a c d )f
+--R                         + 
+--R                               3 4      2   2 2        2 4  2
+--R                           (- a e  - 22a c d e  - 24a c d )f
+--R                         + 
+--R                              2     4        2 3 2     3 5      2   6
+--R                           (8a c d e  + 18a c d e  + 8c d )f - a c e
+--R                         + 
+--R                                 2 2 4     3 4 2
+--R                           - 3a c d e  - 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 a e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                            2   2     2 4
+--R                       (- 4a d e f + a e )x
+--R                  *
+--R                     ROOT
+--R                                  2   3        2 2          2  2
+--R                                8a d f  + (- 2a e  - 16a c d )f
+--R                              + 
+--R                                          2     2 3           4     2 2 2
+--R                                (12a c d e  + 8c d )f - 2a c e  - 2c d e
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 2
+--R                                      a e
+--R                                   /
+--R                                          4   5       4 2      3   2  4
+--R                                        4a d f  + (- a e  - 16a c d )f
+--R                                      + 
+--R                                            3     2      2 2 3  3
+--R                                        (12a c d e  + 24a c d )f
+--R                                      + 
+--R                                             3   4      2 2 2 2        3 4  2
+--R                                        (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                      + 
+--R                                           2 2   4        3 3 2     4 5
+--R                                        (8a c d e  + 12a c d e  + 4c d )f
+--R                                      + 
+--R                                           2 2 6       3 2 4    4 4 2
+--R                                        - a c e  - 2a c d e  - c d e
+--R                          + 
+--R                                         2       2
+--R                            4a d f - 2a e  - 4c d
+--R                       /
+--R                              2   3       2 2         2  2
+--R                            4a d f  + (- a e  - 8a c d )f
+--R                          + 
+--R                                     2     2 3          4    2 2 2
+--R                            (6a c d e  + 4c d )f - a c e  - c d e
+--R                 + 
+--R                          +--------+
+--R                       2  |   2
+--R                   4a d e\|c x  + a
+--R                 + 
+--R                               2 2 3      2   2          3  2
+--R                           - 8a d f  + (2a d e  + 16a c d )f
+--R                         + 
+--R                                     2 2     2 4             4     2 3 2
+--R                           (- 12a c d e  - 8c d )f + 2a c d e  + 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 a e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                               2        2
+--R                       - 2a d e x - 4a d e
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 73
+
+--S 74 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            +-------------------------------------------+
+--R              +-----------+ |      +-----------+
+--R          +-+ |          2  |      |          2        2               2
+--R         \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         ROOT
+--R                      2   3        2 2          2  2             2     2 3
+--R                    8a d f  + (- 2a e  - 16a c d )f  + (12a c d e  + 8c d )f
+--R                  + 
+--R                            4     2 2 2
+--R                    - 2a c e  - 2c d e
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 2
+--R                          a e
+--R                       /
+--R                              4   5       4 2      3   2  4
+--R                            4a d f  + (- a e  - 16a c d )f
+--R                          + 
+--R                                3     2      2 2 3  3
+--R                            (12a c d e  + 24a c d )f
+--R                          + 
+--R                                 3   4      2 2 2 2        3 4  2
+--R                            (- 2a c e  - 22a c d e  - 16a c d )f
+--R                          + 
+--R                               2 2   4        3 3 2     4 5      2 2 6
+--R                            (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                          + 
+--R                                  3 2 4    4 4 2
+--R                            - 2a c d e  - c d e
+--R              + 
+--R                             2       2
+--R                4a d f - 2a e  - 4c d
+--R           /
+--R                  2   3       2 2         2  2            2     2 3          4
+--R                4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f - a c e
+--R              + 
+--R                   2 2 2
+--R                - c d e
+--R      *
+--R         log
+--R                          3 2 4        3   2      2   3  3
+--R                        8a d f  + (- 6a d e  - 24a c d )f
+--R                      + 
+--R                          3 4      2   2 2        2 4  2
+--R                        (a e  + 22a c d e  + 24a c d )f
+--R                      + 
+--R                             2     4        2 3 2     3 5      2   6       2 2 4
+--R                        (- 8a c d e  - 18a c d e  - 8c d )f + a c e  + 3a c d e
+--R                      + 
+--R                          3 4 2
+--R                        2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              a e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                       2   2     2 4
+--R                    (4a d e f - a e )x
+--R               *
+--R                  ROOT
+--R                               2   3        2 2          2  2
+--R                             8a d f  + (- 2a e  - 16a c d )f
+--R                           + 
+--R                                       2     2 3           4     2 2 2
+--R                             (12a c d e  + 8c d )f - 2a c e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 2
+--R                                   a e
+--R                                /
+--R                                       4   5       4 2      3   2  4
+--R                                     4a d f  + (- a e  - 16a c d )f
+--R                                   + 
+--R                                         3     2      2 2 3  3
+--R                                     (12a c d e  + 24a c d )f
+--R                                   + 
+--R                                          3   4      2 2 2 2        3 4  2
+--R                                     (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                   + 
+--R                                        2 2   4        3 3 2     4 5      2 2 6
+--R                                     (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                   + 
+--R                                           3 2 4    4 4 2
+--R                                     - 2a c d e  - c d e
+--R                       + 
+--R                                      2       2
+--R                         4a d f - 2a e  - 4c d
+--R                    /
+--R                           2   3       2 2         2  2            2     2 3
+--R                         4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                       + 
+--R                                4    2 2 2
+--R                         - a c e  - c d e
+--R              + 
+--R                       +--------+
+--R                    2  |   2
+--R                4a d e\|c x  + a
+--R              + 
+--R                            2 2 3      2   2          3  2
+--R                        - 8a d f  + (2a d e  + 16a c d )f
+--R                      + 
+--R                                  2 2     2 4             4     2 3 2
+--R                        (- 12a c d e  - 8c d )f + 2a c d e  + 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              a e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                            2        2
+--R                    - 2a d e x - 4a d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2
+--R            \|2 \|- 4d f + e
+--R         *
+--R            ROOT
+--R                           2   3      2 2          2  2
+--R                       - 8a d f  + (2a e  + 16a c d )f
+--R                     + 
+--R                                   2     2 3           4     2 2 2
+--R                       (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 2
+--R                             a e
+--R                          /
+--R                                 4   5       4 2      3   2  4
+--R                               4a d f  + (- a e  - 16a c d )f
+--R                             + 
+--R                                   3     2      2 2 3  3
+--R                               (12a c d e  + 24a c d )f
+--R                             + 
+--R                                    3   4      2 2 2 2        3 4  2
+--R                               (- 2a c e  - 22a c d e  - 16a c d )f
+--R                             + 
+--R                                  2 2   4        3 3 2     4 5      2 2 6
+--R                               (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                             + 
+--R                                     3 2 4    4 4 2
+--R                               - 2a c d e  - c d e
+--R                 + 
+--R                                2       2
+--R                   4a d f - 2a e  - 4c d
+--R              /
+--R                     2   3       2 2         2  2            2     2 3
+--R                   4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                 + 
+--R                          4    2 2 2
+--R                   - a c e  - c d e
+--R         *
+--R             +-------------------------------------------+
+--R             |      +-----------+
+--R             |      |          2        2               2
+--R            \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R            log
+--R                             3 2 4        3   2      2   3  3
+--R                           8a d f  + (- 6a d e  - 24a c d )f
+--R                         + 
+--R                             3 4      2   2 2        2 4  2
+--R                           (a e  + 22a c d e  + 24a c d )f
+--R                         + 
+--R                                2     4        2 3 2     3 5      2   6
+--R                           (- 8a c d e  - 18a c d e  - 8c d )f + a c e
+--R                         + 
+--R                               2 2 4     3 4 2
+--R                           3a c d e  + 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 a e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                            2   2     2 4
+--R                       (- 4a d e f + a e )x
+--R                  *
+--R                     ROOT
+--R                                    2   3      2 2          2  2
+--R                                - 8a d f  + (2a e  + 16a c d )f
+--R                              + 
+--R                                            2     2 3           4     2 2 2
+--R                                (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 2
+--R                                      a e
+--R                                   /
+--R                                          4   5       4 2      3   2  4
+--R                                        4a d f  + (- a e  - 16a c d )f
+--R                                      + 
+--R                                            3     2      2 2 3  3
+--R                                        (12a c d e  + 24a c d )f
+--R                                      + 
+--R                                             3   4      2 2 2 2        3 4  2
+--R                                        (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                      + 
+--R                                           2 2   4        3 3 2     4 5
+--R                                        (8a c d e  + 12a c d e  + 4c d )f
+--R                                      + 
+--R                                           2 2 6       3 2 4    4 4 2
+--R                                        - a c e  - 2a c d e  - c d e
+--R                          + 
+--R                                         2       2
+--R                            4a d f - 2a e  - 4c d
+--R                       /
+--R                              2   3       2 2         2  2
+--R                            4a d f  + (- a e  - 8a c d )f
+--R                          + 
+--R                                     2     2 3          4    2 2 2
+--R                            (6a c d e  + 4c d )f - a c e  - c d e
+--R                 + 
+--R                          +--------+
+--R                       2  |   2
+--R                   4a d e\|c x  + a
+--R                 + 
+--R                             2 2 3        2   2          3  2
+--R                           8a d f  + (- 2a d e  - 16a c d )f
+--R                         + 
+--R                                   2 2     2 4             4     2 3 2
+--R                           (12a c d e  + 8c d )f - 2a c d e  - 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 a e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                               2        2
+--R                       - 2a d e x - 4a d e
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R         ROOT
+--R                        2   3      2 2          2  2               2     2 3
+--R                    - 8a d f  + (2a e  + 16a c d )f  + (- 12a c d e  - 8c d )f
+--R                  + 
+--R                          4     2 2 2
+--R                    2a c e  + 2c d e
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 2
+--R                          a e
+--R                       /
+--R                              4   5       4 2      3   2  4
+--R                            4a d f  + (- a e  - 16a c d )f
+--R                          + 
+--R                                3     2      2 2 3  3
+--R                            (12a c d e  + 24a c d )f
+--R                          + 
+--R                                 3   4      2 2 2 2        3 4  2
+--R                            (- 2a c e  - 22a c d e  - 16a c d )f
+--R                          + 
+--R                               2 2   4        3 3 2     4 5      2 2 6
+--R                            (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                          + 
+--R                                  3 2 4    4 4 2
+--R                            - 2a c d e  - c d e
+--R              + 
+--R                             2       2
+--R                4a d f - 2a e  - 4c d
+--R           /
+--R                  2   3       2 2         2  2            2     2 3          4
+--R                4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f - a c e
+--R              + 
+--R                   2 2 2
+--R                - c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                            3 2 4      3   2      2   3  3
+--R                        - 8a d f  + (6a d e  + 24a c d )f
+--R                      + 
+--R                            3 4      2   2 2        2 4  2
+--R                        (- a e  - 22a c d e  - 24a c d )f
+--R                      + 
+--R                           2     4        2 3 2     3 5      2   6       2 2 4
+--R                        (8a c d e  + 18a c d e  + 8c d )f - a c e  - 3a c d e
+--R                      + 
+--R                            3 4 2
+--R                        - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              a e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                       2   2     2 4
+--R                    (4a d e f - a e )x
+--R               *
+--R                  ROOT
+--R                                 2   3      2 2          2  2
+--R                             - 8a d f  + (2a e  + 16a c d )f
+--R                           + 
+--R                                         2     2 3           4     2 2 2
+--R                             (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 2
+--R                                   a e
+--R                                /
+--R                                       4   5       4 2      3   2  4
+--R                                     4a d f  + (- a e  - 16a c d )f
+--R                                   + 
+--R                                         3     2      2 2 3  3
+--R                                     (12a c d e  + 24a c d )f
+--R                                   + 
+--R                                          3   4      2 2 2 2        3 4  2
+--R                                     (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                   + 
+--R                                        2 2   4        3 3 2     4 5      2 2 6
+--R                                     (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                   + 
+--R                                           3 2 4    4 4 2
+--R                                     - 2a c d e  - c d e
+--R                       + 
+--R                                      2       2
+--R                         4a d f - 2a e  - 4c d
+--R                    /
+--R                           2   3       2 2         2  2            2     2 3
+--R                         4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                       + 
+--R                                4    2 2 2
+--R                         - a c e  - c d e
+--R              + 
+--R                       +--------+
+--R                    2  |   2
+--R                4a d e\|c x  + a
+--R              + 
+--R                          2 2 3        2   2          3  2
+--R                        8a d f  + (- 2a d e  - 16a c d )f
+--R                      + 
+--R                                2 2     2 4             4     2 3 2
+--R                        (12a c d e  + 8c d )f - 2a c d e  - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              a e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                            2        2
+--R                    - 2a d e x - 4a d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                               +-------------------------------------------+
+--R                 +-----------+ |      +-----------+
+--R             +-+ |          2  |      |          2        2               2
+--R            \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R            ROOT
+--R                         2   3        2 2          2  2             2     2 3
+--R                       8a d f  + (- 2a e  - 16a c d )f  + (12a c d e  + 8c d )f
+--R                     + 
+--R                               4     2 2 2
+--R                       - 2a c e  - 2c d e
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 2
+--R                             a e
+--R                          /
+--R                                 4   5       4 2      3   2  4
+--R                               4a d f  + (- a e  - 16a c d )f
+--R                             + 
+--R                                   3     2      2 2 3  3
+--R                               (12a c d e  + 24a c d )f
+--R                             + 
+--R                                    3   4      2 2 2 2        3 4  2
+--R                               (- 2a c e  - 22a c d e  - 16a c d )f
+--R                             + 
+--R                                  2 2   4        3 3 2     4 5      2 2 6
+--R                               (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                             + 
+--R                                     3 2 4    4 4 2
+--R                               - 2a c d e  - c d e
+--R                 + 
+--R                                2       2
+--R                   4a d f - 2a e  - 4c d
+--R              /
+--R                     2   3       2 2         2  2            2     2 3
+--R                   4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                 + 
+--R                          4    2 2 2
+--R                   - a c e  - c d e
+--R         *
+--R            log
+--R                               3 2 4      3   2      2   3  3
+--R                           - 8a d f  + (6a d e  + 24a c d )f
+--R                         + 
+--R                               3 4      2   2 2        2 4  2
+--R                           (- a e  - 22a c d e  - 24a c d )f
+--R                         + 
+--R                              2     4        2 3 2     3 5      2   6
+--R                           (8a c d e  + 18a c d e  + 8c d )f - a c e
+--R                         + 
+--R                                 2 2 4     3 4 2
+--R                           - 3a c d e  - 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 a e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                            2   2     2 4
+--R                       (- 4a d e f + a e )x
+--R                  *
+--R                     ROOT
+--R                                  2   3        2 2          2  2
+--R                                8a d f  + (- 2a e  - 16a c d )f
+--R                              + 
+--R                                          2     2 3           4     2 2 2
+--R                                (12a c d e  + 8c d )f - 2a c e  - 2c d e
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 2
+--R                                      a e
+--R                                   /
+--R                                          4   5       4 2      3   2  4
+--R                                        4a d f  + (- a e  - 16a c d )f
+--R                                      + 
+--R                                            3     2      2 2 3  3
+--R                                        (12a c d e  + 24a c d )f
+--R                                      + 
+--R                                             3   4      2 2 2 2        3 4  2
+--R                                        (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                      + 
+--R                                           2 2   4        3 3 2     4 5
+--R                                        (8a c d e  + 12a c d e  + 4c d )f
+--R                                      + 
+--R                                           2 2 6       3 2 4    4 4 2
+--R                                        - a c e  - 2a c d e  - c d e
+--R                          + 
+--R                                         2       2
+--R                            4a d f - 2a e  - 4c d
+--R                       /
+--R                              2   3       2 2         2  2
+--R                            4a d f  + (- a e  - 8a c d )f
+--R                          + 
+--R                                     2     2 3          4    2 2 2
+--R                            (6a c d e  + 4c d )f - a c e  - c d e
+--R                 + 
+--R                          +--------+
+--R                       2  |   2
+--R                   4a d e\|c x  + a
+--R                 + 
+--R                               2 2 3      2   2          3  2
+--R                           - 8a d f  + (2a d e  + 16a c d )f
+--R                         + 
+--R                                     2 2     2 4             4     2 3 2
+--R                           (- 12a c d e  - 8c d )f + 2a c d e  + 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 a e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                               2        2
+--R                       - 2a d e x - 4a d e
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R                                +-----------------------------------------+
+--R            +-----------+       |    +-----------+
+--R            |          2        |    |          2        2               2
+--R         (2\|- 4d f + e   - 2e)\|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                  +-------------------------------------------+
+--R              +-----------+       |      +-----------+
+--R              |          2        |      |          2        2               2
+--R         (- 2\|- 4d f + e   - 2e)\|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                           +-------------------------------------------+
+--R             +-----------+ |      +-----------+
+--R         +-+ |          2  |      |          2        2               2
+--R       2\|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 1580
+t0:=1/((d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                         +--------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 1580
+r0:=-f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*sqrt(2)/(sqrt(e^2-_
+   4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+f*atanh((2*a*f-_
+   c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))))*sqrt(2)/(sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R       -
+--R                  +-----------------------------------------+
+--R                  |    +-----------+
+--R              +-+ |    |          2        2               2
+--R            f\|2 \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R                                   +-----------+
+--R                                   |          2
+--R                               c x\|- 4d f + e   - c e x + 2a f
+--R          atanh(-------------------------------------------------------------)
+--R                                +-------------------------------------------+
+--R                     +--------+ |      +-----------+
+--R                 +-+ |   2      |      |          2        2               2
+--R                \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R       -
+--R                  +-------------------------------------------+
+--R                  |      +-----------+
+--R              +-+ |      |          2        2               2
+--R            f\|2 \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R                                    +-----------+
+--R                                    |          2
+--R                                c x\|- 4d f + e   + c e x - 2a f
+--R            atanh(-----------------------------------------------------------)
+--R                                  +-----------------------------------------+
+--R                       +--------+ |    +-----------+
+--R                   +-+ |   2      |    |          2        2               2
+--R                  \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                      +-------------------------------------------+
+--R        +-----------+ |      +-----------+
+--R        |          2  |      |          2        2               2
+--R       \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                         2   3        2 2          2  2             2     2 3
+--R                       8a d f  + (- 2a e  - 16a c d )f  + (12a c d e  + 8c d )f
+--R                     + 
+--R                               4     2 2 2
+--R                       - 2a c e  - 2c d e
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 2
+--R                             c e
+--R                          /
+--R                                 4   5       4 2      3   2  4
+--R                               4a d f  + (- a e  - 16a c d )f
+--R                             + 
+--R                                   3     2      2 2 3  3
+--R                               (12a c d e  + 24a c d )f
+--R                             + 
+--R                                    3   4      2 2 2 2        3 4  2
+--R                               (- 2a c e  - 22a c d e  - 16a c d )f
+--R                             + 
+--R                                  2 2   4        3 3 2     4 5      2 2 6
+--R                               (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                             + 
+--R                                     3 2 4    4 4 2
+--R                               - 2a c d e  - c d e
+--R                 + 
+--R                         2                2
+--R                   - 4a f  + 4c d f - 2c e
+--R              /
+--R                     2   3       2 2         2  2            2     2 3
+--R                   4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                 + 
+--R                          4    2 2 2
+--R                   - a c e  - c d e
+--R         *
+--R            log
+--R                             3     4       3 3     2   2   3
+--R                           4a d e f  + (- a e  - 4a c d e)f
+--R                         + 
+--R                              2     3       2 3   2
+--R                           (5a c d e  - 4a c d e)f
+--R                         + 
+--R                               2   5       2 2 3     3 4         2   5    3 3 3
+--R                           (- a c e  + 5a c d e  + 4c d e)f - a c d e  - c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 c e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                                  2           3     2 2       2   3
+--R                       (4a c d e f  + (- a c e  - 4c d e)f + c d e )x
+--R                  *
+--R                     ROOT
+--R                                  2   3        2 2          2  2
+--R                                8a d f  + (- 2a e  - 16a c d )f
+--R                              + 
+--R                                          2     2 3           4     2 2 2
+--R                                (12a c d e  + 8c d )f - 2a c e  - 2c d e
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 2
+--R                                      c e
+--R                                   /
+--R                                          4   5       4 2      3   2  4
+--R                                        4a d f  + (- a e  - 16a c d )f
+--R                                      + 
+--R                                            3     2      2 2 3  3
+--R                                        (12a c d e  + 24a c d )f
+--R                                      + 
+--R                                             3   4      2 2 2 2        3 4  2
+--R                                        (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                      + 
+--R                                           2 2   4        3 3 2     4 5
+--R                                        (8a c d e  + 12a c d e  + 4c d )f
+--R                                      + 
+--R                                           2 2 6       3 2 4    4 4 2
+--R                                        - a c e  - 2a c d e  - c d e
+--R                          + 
+--R                                  2                2
+--R                            - 4a f  + 4c d f - 2c e
+--R                       /
+--R                              2   3       2 2         2  2
+--R                            4a d f  + (- a e  - 8a c d )f
+--R                          + 
+--R                                     2     2 3          4    2 2 2
+--R                            (6a c d e  + 4c d )f - a c e  - c d e
+--R                 + 
+--R                            +--------+
+--R                            |   2
+--R                   4c d e f\|c x  + a
+--R                 + 
+--R                             2   4        2 2          2  3
+--R                           8a d f  + (- 2a e  - 16a c d )f
+--R                         + 
+--R                                     2     2 3  2            4     2 2 2
+--R                           (12a c d e  + 8c d )f  + (- 2a c e  - 2c d e )f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 c e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                             2
+--R                       - 2c e f x - 4c d e f
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R         ROOT
+--R                        2   3      2 2          2  2               2     2 3
+--R                    - 8a d f  + (2a e  + 16a c d )f  + (- 12a c d e  - 8c d )f
+--R                  + 
+--R                          4     2 2 2
+--R                    2a c e  + 2c d e
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 2
+--R                          c e
+--R                       /
+--R                              4   5       4 2      3   2  4
+--R                            4a d f  + (- a e  - 16a c d )f
+--R                          + 
+--R                                3     2      2 2 3  3
+--R                            (12a c d e  + 24a c d )f
+--R                          + 
+--R                                 3   4      2 2 2 2        3 4  2
+--R                            (- 2a c e  - 22a c d e  - 16a c d )f
+--R                          + 
+--R                               2 2   4        3 3 2     4 5      2 2 6
+--R                            (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                          + 
+--R                                  3 2 4    4 4 2
+--R                            - 2a c d e  - c d e
+--R              + 
+--R                      2                2
+--R                - 4a f  + 4c d f - 2c e
+--R           /
+--R                  2   3       2 2         2  2            2     2 3          4
+--R                4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f - a c e
+--R              + 
+--R                   2 2 2
+--R                - c d e
+--R      *
+--R         log
+--R                          3     4       3 3     2   2   3
+--R                        4a d e f  + (- a e  - 4a c d e)f
+--R                      + 
+--R                           2     3       2 3   2
+--R                        (5a c d e  - 4a c d e)f
+--R                      + 
+--R                            2   5       2 2 3     3 4         2   5    3 3 3
+--R                        (- a c e  + 5a c d e  + 4c d e)f - a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              c e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                                 2         3     2 2       2   3
+--R                    (- 4a c d e f  + (a c e  + 4c d e)f - c d e )x
+--R               *
+--R                  ROOT
+--R                                 2   3      2 2          2  2
+--R                             - 8a d f  + (2a e  + 16a c d )f
+--R                           + 
+--R                                         2     2 3           4     2 2 2
+--R                             (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 2
+--R                                   c e
+--R                                /
+--R                                       4   5       4 2      3   2  4
+--R                                     4a d f  + (- a e  - 16a c d )f
+--R                                   + 
+--R                                         3     2      2 2 3  3
+--R                                     (12a c d e  + 24a c d )f
+--R                                   + 
+--R                                          3   4      2 2 2 2        3 4  2
+--R                                     (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                   + 
+--R                                        2 2   4        3 3 2     4 5      2 2 6
+--R                                     (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                   + 
+--R                                           3 2 4    4 4 2
+--R                                     - 2a c d e  - c d e
+--R                       + 
+--R                               2                2
+--R                         - 4a f  + 4c d f - 2c e
+--R                    /
+--R                           2   3       2 2         2  2            2     2 3
+--R                         4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                       + 
+--R                                4    2 2 2
+--R                         - a c e  - c d e
+--R              + 
+--R                         +--------+
+--R                         |   2
+--R                4c d e f\|c x  + a
+--R              + 
+--R                            2   4      2 2          2  3
+--R                        - 8a d f  + (2a e  + 16a c d )f
+--R                      + 
+--R                                    2     2 3  2          4     2 2 2
+--R                        (- 12a c d e  - 8c d )f  + (2a c e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              c e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                          2
+--R                    - 2c e f x - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                           2   3      2 2          2  2
+--R                       - 8a d f  + (2a e  + 16a c d )f
+--R                     + 
+--R                                   2     2 3           4     2 2 2
+--R                       (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 2
+--R                             c e
+--R                          /
+--R                                 4   5       4 2      3   2  4
+--R                               4a d f  + (- a e  - 16a c d )f
+--R                             + 
+--R                                   3     2      2 2 3  3
+--R                               (12a c d e  + 24a c d )f
+--R                             + 
+--R                                    3   4      2 2 2 2        3 4  2
+--R                               (- 2a c e  - 22a c d e  - 16a c d )f
+--R                             + 
+--R                                  2 2   4        3 3 2     4 5      2 2 6
+--R                               (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                             + 
+--R                                     3 2 4    4 4 2
+--R                               - 2a c d e  - c d e
+--R                 + 
+--R                         2                2
+--R                   - 4a f  + 4c d f - 2c e
+--R              /
+--R                     2   3       2 2         2  2            2     2 3
+--R                   4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                 + 
+--R                          4    2 2 2
+--R                   - a c e  - c d e
+--R         *
+--R            log
+--R                               3     4     3 3     2   2   3
+--R                           - 4a d e f  + (a e  + 4a c d e)f
+--R                         + 
+--R                                2     3       2 3   2
+--R                           (- 5a c d e  + 4a c d e)f
+--R                         + 
+--R                             2   5       2 2 3     3 4         2   5    3 3 3
+--R                           (a c e  - 5a c d e  - 4c d e)f + a c d e  + c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 c e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                                  2           3     2 2       2   3
+--R                       (4a c d e f  + (- a c e  - 4c d e)f + c d e )x
+--R                  *
+--R                     ROOT
+--R                                    2   3      2 2          2  2
+--R                                - 8a d f  + (2a e  + 16a c d )f
+--R                              + 
+--R                                            2     2 3           4     2 2 2
+--R                                (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 2
+--R                                      c e
+--R                                   /
+--R                                          4   5       4 2      3   2  4
+--R                                        4a d f  + (- a e  - 16a c d )f
+--R                                      + 
+--R                                            3     2      2 2 3  3
+--R                                        (12a c d e  + 24a c d )f
+--R                                      + 
+--R                                             3   4      2 2 2 2        3 4  2
+--R                                        (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                      + 
+--R                                           2 2   4        3 3 2     4 5
+--R                                        (8a c d e  + 12a c d e  + 4c d )f
+--R                                      + 
+--R                                           2 2 6       3 2 4    4 4 2
+--R                                        - a c e  - 2a c d e  - c d e
+--R                          + 
+--R                                  2                2
+--R                            - 4a f  + 4c d f - 2c e
+--R                       /
+--R                              2   3       2 2         2  2
+--R                            4a d f  + (- a e  - 8a c d )f
+--R                          + 
+--R                                     2     2 3          4    2 2 2
+--R                            (6a c d e  + 4c d )f - a c e  - c d e
+--R                 + 
+--R                            +--------+
+--R                            |   2
+--R                   4c d e f\|c x  + a
+--R                 + 
+--R                               2   4      2 2          2  3
+--R                           - 8a d f  + (2a e  + 16a c d )f
+--R                         + 
+--R                                       2     2 3  2          4     2 2 2
+--R                           (- 12a c d e  - 8c d )f  + (2a c e  + 2c d e )f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 c e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                             2
+--R                       - 2c e f x - 4c d e f
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R         ROOT
+--R                      2   3        2 2          2  2             2     2 3
+--R                    8a d f  + (- 2a e  - 16a c d )f  + (12a c d e  + 8c d )f
+--R                  + 
+--R                            4     2 2 2
+--R                    - 2a c e  - 2c d e
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 2
+--R                          c e
+--R                       /
+--R                              4   5       4 2      3   2  4
+--R                            4a d f  + (- a e  - 16a c d )f
+--R                          + 
+--R                                3     2      2 2 3  3
+--R                            (12a c d e  + 24a c d )f
+--R                          + 
+--R                                 3   4      2 2 2 2        3 4  2
+--R                            (- 2a c e  - 22a c d e  - 16a c d )f
+--R                          + 
+--R                               2 2   4        3 3 2     4 5      2 2 6
+--R                            (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                          + 
+--R                                  3 2 4    4 4 2
+--R                            - 2a c d e  - c d e
+--R              + 
+--R                      2                2
+--R                - 4a f  + 4c d f - 2c e
+--R           /
+--R                  2   3       2 2         2  2            2     2 3          4
+--R                4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f - a c e
+--R              + 
+--R                   2 2 2
+--R                - c d e
+--R      *
+--R         log
+--R                            3     4     3 3     2   2   3
+--R                        - 4a d e f  + (a e  + 4a c d e)f
+--R                      + 
+--R                             2     3       2 3   2
+--R                        (- 5a c d e  + 4a c d e)f
+--R                      + 
+--R                          2   5       2 2 3     3 4         2   5    3 3 3
+--R                        (a c e  - 5a c d e  - 4c d e)f + a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              c e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                                 2         3     2 2       2   3
+--R                    (- 4a c d e f  + (a c e  + 4c d e)f - c d e )x
+--R               *
+--R                  ROOT
+--R                               2   3        2 2          2  2
+--R                             8a d f  + (- 2a e  - 16a c d )f
+--R                           + 
+--R                                       2     2 3           4     2 2 2
+--R                             (12a c d e  + 8c d )f - 2a c e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 2
+--R                                   c e
+--R                                /
+--R                                       4   5       4 2      3   2  4
+--R                                     4a d f  + (- a e  - 16a c d )f
+--R                                   + 
+--R                                         3     2      2 2 3  3
+--R                                     (12a c d e  + 24a c d )f
+--R                                   + 
+--R                                          3   4      2 2 2 2        3 4  2
+--R                                     (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                   + 
+--R                                        2 2   4        3 3 2     4 5      2 2 6
+--R                                     (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                   + 
+--R                                           3 2 4    4 4 2
+--R                                     - 2a c d e  - c d e
+--R                       + 
+--R                               2                2
+--R                         - 4a f  + 4c d f - 2c e
+--R                    /
+--R                           2   3       2 2         2  2            2     2 3
+--R                         4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                       + 
+--R                                4    2 2 2
+--R                         - a c e  - c d e
+--R              + 
+--R                         +--------+
+--R                         |   2
+--R                4c d e f\|c x  + a
+--R              + 
+--R                          2   4        2 2          2  3
+--R                        8a d f  + (- 2a e  - 16a c d )f
+--R                      + 
+--R                                  2     2 3  2            4     2 2 2
+--R                        (12a c d e  + 8c d )f  + (- 2a c e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              c e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                          2
+--R                    - 2c e f x - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 78
+
+--S 79 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                           +-------------------------------------------+
+--R             +-----------+ |      +-----------+
+--R             |          2  |      |          2        2               2
+--R            \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R            ROOT
+--R                         2   3        2 2          2  2             2     2 3
+--R                       8a d f  + (- 2a e  - 16a c d )f  + (12a c d e  + 8c d )f
+--R                     + 
+--R                               4     2 2 2
+--R                       - 2a c e  - 2c d e
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 2
+--R                             c e
+--R                          /
+--R                                 4   5       4 2      3   2  4
+--R                               4a d f  + (- a e  - 16a c d )f
+--R                             + 
+--R                                   3     2      2 2 3  3
+--R                               (12a c d e  + 24a c d )f
+--R                             + 
+--R                                    3   4      2 2 2 2        3 4  2
+--R                               (- 2a c e  - 22a c d e  - 16a c d )f
+--R                             + 
+--R                                  2 2   4        3 3 2     4 5      2 2 6
+--R                               (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                             + 
+--R                                     3 2 4    4 4 2
+--R                               - 2a c d e  - c d e
+--R                 + 
+--R                         2                2
+--R                   - 4a f  + 4c d f - 2c e
+--R              /
+--R                     2   3       2 2         2  2            2     2 3
+--R                   4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                 + 
+--R                          4    2 2 2
+--R                   - a c e  - c d e
+--R         *
+--R            log
+--R                             3     4       3 3     2   2   3
+--R                           4a d e f  + (- a e  - 4a c d e)f
+--R                         + 
+--R                              2     3       2 3   2
+--R                           (5a c d e  - 4a c d e)f
+--R                         + 
+--R                               2   5       2 2 3     3 4         2   5    3 3 3
+--R                           (- a c e  + 5a c d e  + 4c d e)f - a c d e  - c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 c e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                                  2           3     2 2       2   3
+--R                       (4a c d e f  + (- a c e  - 4c d e)f + c d e )x
+--R                  *
+--R                     ROOT
+--R                                  2   3        2 2          2  2
+--R                                8a d f  + (- 2a e  - 16a c d )f
+--R                              + 
+--R                                          2     2 3           4     2 2 2
+--R                                (12a c d e  + 8c d )f - 2a c e  - 2c d e
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 2
+--R                                      c e
+--R                                   /
+--R                                          4   5       4 2      3   2  4
+--R                                        4a d f  + (- a e  - 16a c d )f
+--R                                      + 
+--R                                            3     2      2 2 3  3
+--R                                        (12a c d e  + 24a c d )f
+--R                                      + 
+--R                                             3   4      2 2 2 2        3 4  2
+--R                                        (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                      + 
+--R                                           2 2   4        3 3 2     4 5
+--R                                        (8a c d e  + 12a c d e  + 4c d )f
+--R                                      + 
+--R                                           2 2 6       3 2 4    4 4 2
+--R                                        - a c e  - 2a c d e  - c d e
+--R                          + 
+--R                                  2                2
+--R                            - 4a f  + 4c d f - 2c e
+--R                       /
+--R                              2   3       2 2         2  2
+--R                            4a d f  + (- a e  - 8a c d )f
+--R                          + 
+--R                                     2     2 3          4    2 2 2
+--R                            (6a c d e  + 4c d )f - a c e  - c d e
+--R                 + 
+--R                            +--------+
+--R                            |   2
+--R                   4c d e f\|c x  + a
+--R                 + 
+--R                             2   4        2 2          2  3
+--R                           8a d f  + (- 2a e  - 16a c d )f
+--R                         + 
+--R                                     2     2 3  2            4     2 2 2
+--R                           (12a c d e  + 8c d )f  + (- 2a c e  - 2c d e )f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 c e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                             2
+--R                       - 2c e f x - 4c d e f
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R          +-----------+
+--R          |          2
+--R         \|- 4d f + e
+--R      *
+--R         ROOT
+--R                        2   3      2 2          2  2               2     2 3
+--R                    - 8a d f  + (2a e  + 16a c d )f  + (- 12a c d e  - 8c d )f
+--R                  + 
+--R                          4     2 2 2
+--R                    2a c e  + 2c d e
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 2
+--R                          c e
+--R                       /
+--R                              4   5       4 2      3   2  4
+--R                            4a d f  + (- a e  - 16a c d )f
+--R                          + 
+--R                                3     2      2 2 3  3
+--R                            (12a c d e  + 24a c d )f
+--R                          + 
+--R                                 3   4      2 2 2 2        3 4  2
+--R                            (- 2a c e  - 22a c d e  - 16a c d )f
+--R                          + 
+--R                               2 2   4        3 3 2     4 5      2 2 6
+--R                            (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                          + 
+--R                                  3 2 4    4 4 2
+--R                            - 2a c d e  - c d e
+--R              + 
+--R                      2                2
+--R                - 4a f  + 4c d f - 2c e
+--R           /
+--R                  2   3       2 2         2  2            2     2 3          4
+--R                4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f - a c e
+--R              + 
+--R                   2 2 2
+--R                - c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                          3     4       3 3     2   2   3
+--R                        4a d e f  + (- a e  - 4a c d e)f
+--R                      + 
+--R                           2     3       2 3   2
+--R                        (5a c d e  - 4a c d e)f
+--R                      + 
+--R                            2   5       2 2 3     3 4         2   5    3 3 3
+--R                        (- a c e  + 5a c d e  + 4c d e)f - a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              c e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                                 2         3     2 2       2   3
+--R                    (- 4a c d e f  + (a c e  + 4c d e)f - c d e )x
+--R               *
+--R                  ROOT
+--R                                 2   3      2 2          2  2
+--R                             - 8a d f  + (2a e  + 16a c d )f
+--R                           + 
+--R                                         2     2 3           4     2 2 2
+--R                             (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 2
+--R                                   c e
+--R                                /
+--R                                       4   5       4 2      3   2  4
+--R                                     4a d f  + (- a e  - 16a c d )f
+--R                                   + 
+--R                                         3     2      2 2 3  3
+--R                                     (12a c d e  + 24a c d )f
+--R                                   + 
+--R                                          3   4      2 2 2 2        3 4  2
+--R                                     (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                   + 
+--R                                        2 2   4        3 3 2     4 5      2 2 6
+--R                                     (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                   + 
+--R                                           3 2 4    4 4 2
+--R                                     - 2a c d e  - c d e
+--R                       + 
+--R                               2                2
+--R                         - 4a f  + 4c d f - 2c e
+--R                    /
+--R                           2   3       2 2         2  2            2     2 3
+--R                         4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                       + 
+--R                                4    2 2 2
+--R                         - a c e  - c d e
+--R              + 
+--R                         +--------+
+--R                         |   2
+--R                4c d e f\|c x  + a
+--R              + 
+--R                            2   4      2 2          2  3
+--R                        - 8a d f  + (2a e  + 16a c d )f
+--R                      + 
+--R                                    2     2 3  2          4     2 2 2
+--R                        (- 12a c d e  - 8c d )f  + (2a c e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              c e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                          2
+--R                    - 2c e f x - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R             +-----------+
+--R             |          2
+--R            \|- 4d f + e
+--R         *
+--R            ROOT
+--R                           2   3      2 2          2  2
+--R                       - 8a d f  + (2a e  + 16a c d )f
+--R                     + 
+--R                                   2     2 3           4     2 2 2
+--R                       (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 2
+--R                             c e
+--R                          /
+--R                                 4   5       4 2      3   2  4
+--R                               4a d f  + (- a e  - 16a c d )f
+--R                             + 
+--R                                   3     2      2 2 3  3
+--R                               (12a c d e  + 24a c d )f
+--R                             + 
+--R                                    3   4      2 2 2 2        3 4  2
+--R                               (- 2a c e  - 22a c d e  - 16a c d )f
+--R                             + 
+--R                                  2 2   4        3 3 2     4 5      2 2 6
+--R                               (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                             + 
+--R                                     3 2 4    4 4 2
+--R                               - 2a c d e  - c d e
+--R                 + 
+--R                         2                2
+--R                   - 4a f  + 4c d f - 2c e
+--R              /
+--R                     2   3       2 2         2  2            2     2 3
+--R                   4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                 + 
+--R                          4    2 2 2
+--R                   - a c e  - c d e
+--R         *
+--R             +-------------------------------------------+
+--R             |      +-----------+
+--R             |      |          2        2               2
+--R            \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R            log
+--R                               3     4     3 3     2   2   3
+--R                           - 4a d e f  + (a e  + 4a c d e)f
+--R                         + 
+--R                                2     3       2 3   2
+--R                           (- 5a c d e  + 4a c d e)f
+--R                         + 
+--R                             2   5       2 2 3     3 4         2   5    3 3 3
+--R                           (a c e  - 5a c d e  - 4c d e)f + a c d e  + c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 c e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                                  2           3     2 2       2   3
+--R                       (4a c d e f  + (- a c e  - 4c d e)f + c d e )x
+--R                  *
+--R                     ROOT
+--R                                    2   3      2 2          2  2
+--R                                - 8a d f  + (2a e  + 16a c d )f
+--R                              + 
+--R                                            2     2 3           4     2 2 2
+--R                                (- 12a c d e  - 8c d )f + 2a c e  + 2c d e
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 2
+--R                                      c e
+--R                                   /
+--R                                          4   5       4 2      3   2  4
+--R                                        4a d f  + (- a e  - 16a c d )f
+--R                                      + 
+--R                                            3     2      2 2 3  3
+--R                                        (12a c d e  + 24a c d )f
+--R                                      + 
+--R                                             3   4      2 2 2 2        3 4  2
+--R                                        (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                      + 
+--R                                           2 2   4        3 3 2     4 5
+--R                                        (8a c d e  + 12a c d e  + 4c d )f
+--R                                      + 
+--R                                           2 2 6       3 2 4    4 4 2
+--R                                        - a c e  - 2a c d e  - c d e
+--R                          + 
+--R                                  2                2
+--R                            - 4a f  + 4c d f - 2c e
+--R                       /
+--R                              2   3       2 2         2  2
+--R                            4a d f  + (- a e  - 8a c d )f
+--R                          + 
+--R                                     2     2 3          4    2 2 2
+--R                            (6a c d e  + 4c d )f - a c e  - c d e
+--R                 + 
+--R                            +--------+
+--R                            |   2
+--R                   4c d e f\|c x  + a
+--R                 + 
+--R                               2   4      2 2          2  3
+--R                           - 8a d f  + (2a e  + 16a c d )f
+--R                         + 
+--R                                       2     2 3  2          4     2 2 2
+--R                           (- 12a c d e  - 8c d )f  + (2a c e  + 2c d e )f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 2
+--R                                 c e
+--R                              /
+--R                                     4   5       4 2      3   2  4
+--R                                   4a d f  + (- a e  - 16a c d )f
+--R                                 + 
+--R                                       3     2      2 2 3  3
+--R                                   (12a c d e  + 24a c d )f
+--R                                 + 
+--R                                        3   4      2 2 2 2        3 4  2
+--R                                   (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                 + 
+--R                                      2 2   4        3 3 2     4 5      2 2 6
+--R                                   (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                 + 
+--R                                         3 2 4    4 4 2
+--R                                   - 2a c d e  - c d e
+--R                     + 
+--R                             2
+--R                       - 2c e f x - 4c d e f
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R                        +-------------------------------------------+
+--R          +-----------+ |      +-----------+
+--R          |          2  |      |          2        2               2
+--R         \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         ROOT
+--R                      2   3        2 2          2  2             2     2 3
+--R                    8a d f  + (- 2a e  - 16a c d )f  + (12a c d e  + 8c d )f
+--R                  + 
+--R                            4     2 2 2
+--R                    - 2a c e  - 2c d e
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 2
+--R                          c e
+--R                       /
+--R                              4   5       4 2      3   2  4
+--R                            4a d f  + (- a e  - 16a c d )f
+--R                          + 
+--R                                3     2      2 2 3  3
+--R                            (12a c d e  + 24a c d )f
+--R                          + 
+--R                                 3   4      2 2 2 2        3 4  2
+--R                            (- 2a c e  - 22a c d e  - 16a c d )f
+--R                          + 
+--R                               2 2   4        3 3 2     4 5      2 2 6
+--R                            (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                          + 
+--R                                  3 2 4    4 4 2
+--R                            - 2a c d e  - c d e
+--R              + 
+--R                      2                2
+--R                - 4a f  + 4c d f - 2c e
+--R           /
+--R                  2   3       2 2         2  2            2     2 3          4
+--R                4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f - a c e
+--R              + 
+--R                   2 2 2
+--R                - c d e
+--R      *
+--R         log
+--R                            3     4     3 3     2   2   3
+--R                        - 4a d e f  + (a e  + 4a c d e)f
+--R                      + 
+--R                             2     3       2 3   2
+--R                        (- 5a c d e  + 4a c d e)f
+--R                      + 
+--R                          2   5       2 2 3     3 4         2   5    3 3 3
+--R                        (a c e  - 5a c d e  - 4c d e)f + a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              c e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                                 2         3     2 2       2   3
+--R                    (- 4a c d e f  + (a c e  + 4c d e)f - c d e )x
+--R               *
+--R                  ROOT
+--R                               2   3        2 2          2  2
+--R                             8a d f  + (- 2a e  - 16a c d )f
+--R                           + 
+--R                                       2     2 3           4     2 2 2
+--R                             (12a c d e  + 8c d )f - 2a c e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 2
+--R                                   c e
+--R                                /
+--R                                       4   5       4 2      3   2  4
+--R                                     4a d f  + (- a e  - 16a c d )f
+--R                                   + 
+--R                                         3     2      2 2 3  3
+--R                                     (12a c d e  + 24a c d )f
+--R                                   + 
+--R                                          3   4      2 2 2 2        3 4  2
+--R                                     (- 2a c e  - 22a c d e  - 16a c d )f
+--R                                   + 
+--R                                        2 2   4        3 3 2     4 5      2 2 6
+--R                                     (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                                   + 
+--R                                           3 2 4    4 4 2
+--R                                     - 2a c d e  - c d e
+--R                       + 
+--R                               2                2
+--R                         - 4a f  + 4c d f - 2c e
+--R                    /
+--R                           2   3       2 2         2  2            2     2 3
+--R                         4a d f  + (- a e  - 8a c d )f  + (6a c d e  + 4c d )f
+--R                       + 
+--R                                4    2 2 2
+--R                         - a c e  - c d e
+--R              + 
+--R                         +--------+
+--R                         |   2
+--R                4c d e f\|c x  + a
+--R              + 
+--R                          2   4        2 2          2  3
+--R                        8a d f  + (- 2a e  - 16a c d )f
+--R                      + 
+--R                                  2     2 3  2            4     2 2 2
+--R                        (12a c d e  + 8c d )f  + (- 2a c e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 2
+--R                              c e
+--R                           /
+--R                                  4   5       4 2      3   2  4
+--R                                4a d f  + (- a e  - 16a c d )f
+--R                              + 
+--R                                    3     2      2 2 3  3
+--R                                (12a c d e  + 24a c d )f
+--R                              + 
+--R                                     3   4      2 2 2 2        3 4  2
+--R                                (- 2a c e  - 22a c d e  - 16a c d )f
+--R                              + 
+--R                                   2 2   4        3 3 2     4 5      2 2 6
+--R                                (8a c d e  + 12a c d e  + 4c d )f - a c e
+--R                              + 
+--R                                      3 2 4    4 4 2
+--R                                - 2a c d e  - c d e
+--R                  + 
+--R                          2
+--R                    - 2c e f x - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                +-----------------------------------------+
+--R                |    +-----------+
+--R            +-+ |    |          2        2               2
+--R         2f\|2 \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                +-------------------------------------------+
+--R                |      +-----------+
+--R            +-+ |      |          2        2               2
+--R         2f\|2 \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                       +-------------------------------------------+
+--R         +-----------+ |      +-----------+
+--R         |          2  |      |          2        2               2
+--R       2\|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 80
+
+)clear all
+
+--S 81 of 1580
+t0:=1/(x*(d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                            +--------+
+--R            3      2        |   2
+--R        (f x  + e x  + d x)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 1580
+r0:=-atanh(sqrt(a+c*x^2)/sqrt(a))/(d*sqrt(a))+f*atanh((2*a*f-c*x*_
+   (e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f-e*sqrt(e^2-4*d*f)))))*(e+sqrt(e^2-4*d*f))/(d*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-_
+   f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(e-sqrt(e^2-4*d*f))/_
+   (d*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                     +-----------------------------------------+
+--R            +-----------+            |    +-----------+
+--R            |          2         +-+ |    |          2        2               2
+--R         (f\|- 4d f + e   + e f)\|a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R              +-----------+
+--R              |          2         +-+
+--R         (- f\|- 4d f + e   + e f)\|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R       -
+--R                                     +--------+
+--R                 +-----------+       |   2
+--R             +-+ |          2       \|c x  + a
+--R            \|2 \|- 4d f + e  atanh(-----------)
+--R                                         +-+
+--R                                        \|a
+--R         *
+--R             +-------------------------------------------+
+--R             |      +-----------+
+--R             |      |          2        2               2
+--R            \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                               +-------------------------------------------+
+--R             +-----------+     |      +-----------+
+--R         +-+ |          2  +-+ |      |          2        2               2
+--R       d\|2 \|- 4d f + e  \|a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 1580
+--a0:=integrate(t0,x)
+--E 83
+
+--S 84 of 1580
+--m0:=a0-r0
+--E 84
+
+--S 85 of 1580
+--d0:=D(m0,x)
+--E 85
+
+)clear all
+
+--S 86 of 1580
+t0:=1/(x^2*(d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                             +--------+
+--R            4      3      2  |   2
+--R        (f x  + e x  + d x )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 1580
+r0:=e*atanh(sqrt(a+c*x^2)/sqrt(a))/(d^2*sqrt(a))-sqrt(a+c*x^2)/(a*d*x)-_
+   f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(e^2-2*d*f+_
+   e*sqrt(e^2-4*d*f))/(d^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+f*atanh((2*a*f-c*x*(e+sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*_
+   sqrt(e^2-4*d*f)))))*(e^2-2*d*f-e*sqrt(e^2-4*d*f))/(d^2*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                    +-----------+
+--R                    |          2           2      2     +-+
+--R         (- a e f x\|- 4d f + e   + (2a d f  - a e f)x)\|a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                  +-----------+
+--R                  |          2           2      2     +-+
+--R         (a e f x\|- 4d f + e   + (2a d f  - a e f)x)\|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                         +--------+
+--R                     +-----------+       |   2
+--R                 +-+ |          2       \|c x  + a
+--R           a e x\|2 \|- 4d f + e  atanh(-----------)
+--R                                             +-+
+--R                                            \|a
+--R         + 
+--R                   +-----------+     +--------+
+--R               +-+ |          2  +-+ |   2
+--R           - d\|2 \|- 4d f + e  \|a \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                   +-------------------------------------------+
+--R                 +-----------+     |      +-----------+
+--R          2  +-+ |          2  +-+ |      |          2        2               2
+--R       a d x\|2 \|- 4d f + e  \|a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 1580
+--a0:=integrate(t0,x)
+--E 88
+
+--S 89 of 1580
+--m0:=a0-r0
+--E 89
+
+--S 90 of 1580
+--d0:=D(m0,x)
+--E 90
+
+)clear all
+
+--S 91 of 1580
+t0:=1/(x^3*(d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                             +--------+
+--R            5      4      3  |   2
+--R        (f x  + e x  + d x )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1580
+r0:=1/2*c*atanh(sqrt(a+c*x^2)/sqrt(a))/(a^(3/2)*d)-(e^2-d*f)*_
+   atanh(sqrt(a+c*x^2)/sqrt(a))/(d^3*sqrt(a))-1/2*sqrt(a+c*x^2)/_
+   (a*d*x^2)+e*sqrt(a+c*x^2)/(a*d^2*x)+f*atanh((2*a*f-c*x*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-_
+   e*sqrt(e^2-4*d*f)))))*(2*e^3-4*d*e*f-(e^2-d*f)*(e-sqrt(e^2-4*d*f)))/_
+   (d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f))))-f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+_
+   c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*e^3-_
+   4*d*e*f-(e^2-d*f)*(e+sqrt(e^2-4*d*f)))/(d^3*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                 +-----------+
+--R                   2       2   2 |          2               2       3   2  +-+
+--R         ((- 2a d f  + 2a e f)x \|- 4d f + e   + (- 6a d e f  + 2a e f)x )\|a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                               +-----------+
+--R                 2       2   2 |          2               2       3   2  +-+
+--R         ((2a d f  - 2a e f)x \|- 4d f + e   + (- 6a d e f  + 2a e f)x )\|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                             +--------+
+--R                                         +-----------+       |   2
+--R                         2      2  2 +-+ |          2       \|c x  + a
+--R           (2a d f - 2a e  + c d )x \|2 \|- 4d f + e  atanh(-----------)
+--R                                                                 +-+
+--R                                                                \|a
+--R         + 
+--R                             +-----------+     +--------+
+--R                      2  +-+ |          2  +-+ |   2
+--R           (2d e x - d )\|2 \|- 4d f + e  \|a \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                   +-----------+
+--R           3 2 +-+ |          2  +-+
+--R       2a d x \|2 \|- 4d f + e  \|a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 1580
+--a0:=integrate(t0,x)
+--E 93
+
+--S 94 of 1580
+--m0:=a0-r0
+--E 94
+
+--S 95 of 1580
+--d0:=D(m0,x)
+--E 95
+
+)clear all
+
+--S 96 of 1580
+t0:=x^3/((a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                     3
+--R                                    x
+--R   (1)  ----------------------------------------------------------
+--R                                                        +--------+
+--R              4        3               2                |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x + a d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 1580
+r0:=(-1)/(c*f*sqrt(a+c*x^2))-e*x/(a*f^2*sqrt(a+c*x^2))+(a*f*(c*d^2+_
+   a*(e^2-d*f))+c*e*(c*d^2+a*(e^2-2*d*f))*x)/(a*f^2*(c^2*d^2+a^2*f^2+_
+   a*c*(e^2-2*d*f))*sqrt(a+c*x^2))-atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (2*a*d*e*f-(c*d^2+a*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/((c^2*d^2+_
+   a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (2*a*d*e*f-(c*d^2+a*(e^2-d*f))*(e+sqrt(e^2-4*d*f)))/((c^2*d^2+_
+   a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                    +-----------+
+--R                          2    2 2  |          2                      3    2 2
+--R         ((a c d f - a c e  - c d )\|- 4d f + e   - 3a c d e f + a c e  + c d e)
+--R      *
+--R                     +-----------------------------------------+
+--R          +--------+ |    +-----------+
+--R          |   2      |    |          2        2               2
+--R         \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                         +-----------+
+--R                               2    2 2  |          2                      3
+--R             (- a c d f + a c e  + c d )\|- 4d f + e   - 3a c d e f + a c e
+--R           + 
+--R              2 2
+--R             c d e
+--R      *
+--R                     +-------------------------------------------+
+--R          +--------+ |      +-----------+
+--R          |   2      |      |          2        2               2
+--R         \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                       +-----------+
+--R                       2           +-+ |          2
+--R         (- a c e x - a f + a c d)\|2 \|- 4d f + e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                               +-----------+ +--------+
+--R         2   2       2         2 2    3 2  +-+ |          2  |   2
+--R       (a c f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                   +--------+
+--R               2 2                   2    2 2  +-+ |   2
+--R           (- a f  + 2a c d f - a c e  - c d )\|a \|c x  + a
+--R         + 
+--R             2   2       2         2 2    3 2  2    3 2     2         2   2
+--R           (a c f  - 2a c d f + a c e  + c d )x  + a f  - 2a c d f + a c e
+--R         + 
+--R              2 2
+--R           a c d
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             6 4 2 4       6 3 4      5   5 2  3
+--R                         - 9a d e f  + (24a d e  + 36a c d e )f
+--R                       + 
+--R                               6 2 6      5   4 4      4 2 6 2  2
+--R                         (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                       + 
+--R                            6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                         (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                       + 
+--R                          6 10     5   2 8      4 2 4 6      3 3 6 4     2 4 8 2
+--R                       - a e   - 6a c d e  - 15a c d e  - 18a c d e  - 9a c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3 3 3         3 2 2      2   4  2
+--R                4a d f  + (- 18a d e  - 12a c d )f
+--R              + 
+--R                    3   4      2   3 2        2 5       3 6     2   2 4
+--R                (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R              + 
+--R                      2 4 2     3 6
+--R                - 6a c d e  - 4c d
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                          8 3 9         8 2 2      7   4  8
+--R                        8a d f  + (- 18a d e  - 64a c d )f
+--R                      + 
+--R                           8   4       7   3 2       6 2 5  7
+--R                        (8a d e  + 144a c d e  + 224a c d )f
+--R                      + 
+--R                            8 6       7   2 4       6 2 4 2       5 3 6  6
+--R                        (- a e  - 104a c d e  - 488a c d e  - 448a c d )f
+--R                      + 
+--R                            7     6       6 2 3 4       5 3 5 2       4 4 7  5
+--R                        (30a c d e  + 408a c d e  + 912a c d e  + 560a c d )f
+--R                      + 
+--R                                7   8       6 2 2 6       5 3 4 4        4 4 6 2
+--R                            - 3a c e  - 171a c d e  - 760a c d e  - 1020a c d e
+--R                          + 
+--R                                  3 5 8
+--R                            - 448a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                               6 2   8       5 3 3 6       4 4 5 4       3 5 7 2
+--R                            36a c d e  + 340a c d e  + 760a c d e  + 688a c d e
+--R                          + 
+--R                                2 6 9
+--R                            224a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                                6 2 10      5 3 2 8       4 4 4 6       3 5 6 4
+--R                            - 3a c e   - 90a c d e  - 295a c d e  - 408a c d e
+--R                          + 
+--R                                  2 6 8 2        7 10
+--R                            - 264a c d e  - 64a c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               5 3   10      4 4 3 8       3 5 5 6       2 6 7 4
+--R                            14a c d e   + 60a c d e  + 110a c d e  + 104a c d e
+--R                          + 
+--R                                 7 9 2     8 11
+--R                            48a c d e  + 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                           5 3 12     4 4 2 10      3 5 4 8      2 6 6 6
+--R                        - a c e   - 5a c d e   - 11a c d e  - 13a c d e
+--R                      + 
+--R                              7 8 4     8 10 2
+--R                        - 8a c d e  - 2c d  e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                           5 4 2 4         5 3 4      4   5 2  3
+--R                        24a d e f  + (- 50a d e  - 72a c d e )f
+--R                      + 
+--R                            5 2 6      4   4 4      3 2 6 2  2
+--R                        (35a d e  + 98a c d e  + 72a c d e )f
+--R                      + 
+--R                              5   8      4   3 6      3 2 5 4      2 3 7 2
+--R                        (- 10a d e  - 40a c d e  - 54a c d e  - 24a c d e )f
+--R                      + 
+--R                         5 10     4   2 8     3 2 4 6     2 3 6 4
+--R                        a e   + 5a c d e  + 9a c d e  + 6a c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 4 2 4       6 3 4      5   5 2  3
+--R                                  - 9a d e f  + (24a d e  + 36a c d e )f
+--R                                + 
+--R                                        6 2 6      5   4 4      4 2 6 2  2
+--R                                  (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                                + 
+--R                                        6   8      5   3 6      4 2 5 4
+--R                                      8a d e  + 36a c d e  + 60a c d e
+--R                                    + 
+--R                                         3 3 7 2
+--R                                      36a c d e
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                                  - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                                + 
+--R                                      2 4 8 2
+--R                                  - 9a c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3 3 3         3 2 2      2   4  2
+--R                         4a d f  + (- 18a d e  - 12a c d )f
+--R                       + 
+--R                             3   4      2   3 2        2 5       3 6     2   2 4
+--R                         (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R                       + 
+--R                               2 4 2     3 6
+--R                         - 6a c d e  - 4c d
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       3 6   2         3 5 3      2   7        3 4 5
+--R                    12a d e f  + (- 16a d e  - 24a c d e)f + 4a d e
+--R                  + 
+--R                       2   6 3        2 8
+--R                    12a c d e  + 12a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                            6 4 7      6 3 2      5   5  6
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   4 2       4 2 6  5
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   3 4       4 2 5 2       3 3 7  4
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 4 4       3 3 6 2       2 4 8  3
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 3 6      3 3 5 4       2 4 7 2        5 9  2
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 4 6      2 4 6 4        5 8 2     6 10
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d  )f
+--R                      + 
+--R                          3 3 3 8     2 4 5 6       5 7 4     6 9 2
+--R                        2a c d e  + 6a c d e  + 6a c d e  + 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            3 5 2 2      3 4 4      2   6 2       3 3 6
+--R                        - 6a d e f  + (8a d e  + 12a c d e )f - 2a d e
+--R                      + 
+--R                            2   5 4       2 7 2
+--R                        - 6a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R                  + 
+--R                         3 6   2       3 5 3      2   7        3 4 5
+--R                    - 12a d e f  + (16a d e  + 24a c d e)f - 4a d e
+--R                  + 
+--R                         2   6 3        2 8
+--R                    - 12a c d e  - 12a c d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                 +--------+
+--R             2 2                   2    2 2  +-+ |   2
+--R           (a f  - 2a c d f + a c e  + c d )\|a \|c x  + a
+--R         + 
+--R               2   2       2         2 2    3 2  2    3 2     2         2   2
+--R           (- a c f  + 2a c d f - a c e  - c d )x  - a f  + 2a c d f - a c e
+--R         + 
+--R                2 2
+--R           - a c d
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             6 4 2 4       6 3 4      5   5 2  3
+--R                         - 9a d e f  + (24a d e  + 36a c d e )f
+--R                       + 
+--R                               6 2 6      5   4 4      4 2 6 2  2
+--R                         (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                       + 
+--R                            6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                         (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                       + 
+--R                          6 10     5   2 8      4 2 4 6      3 3 6 4     2 4 8 2
+--R                       - a e   - 6a c d e  - 15a c d e  - 18a c d e  - 9a c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3 3 3         3 2 2      2   4  2
+--R                4a d f  + (- 18a d e  - 12a c d )f
+--R              + 
+--R                    3   4      2   3 2        2 5       3 6     2   2 4
+--R                (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R              + 
+--R                      2 4 2     3 6
+--R                - 6a c d e  - 4c d
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                          8 3 9         8 2 2      7   4  8
+--R                        8a d f  + (- 18a d e  - 64a c d )f
+--R                      + 
+--R                           8   4       7   3 2       6 2 5  7
+--R                        (8a d e  + 144a c d e  + 224a c d )f
+--R                      + 
+--R                            8 6       7   2 4       6 2 4 2       5 3 6  6
+--R                        (- a e  - 104a c d e  - 488a c d e  - 448a c d )f
+--R                      + 
+--R                            7     6       6 2 3 4       5 3 5 2       4 4 7  5
+--R                        (30a c d e  + 408a c d e  + 912a c d e  + 560a c d )f
+--R                      + 
+--R                                7   8       6 2 2 6       5 3 4 4        4 4 6 2
+--R                            - 3a c e  - 171a c d e  - 760a c d e  - 1020a c d e
+--R                          + 
+--R                                  3 5 8
+--R                            - 448a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                               6 2   8       5 3 3 6       4 4 5 4       3 5 7 2
+--R                            36a c d e  + 340a c d e  + 760a c d e  + 688a c d e
+--R                          + 
+--R                                2 6 9
+--R                            224a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                                6 2 10      5 3 2 8       4 4 4 6       3 5 6 4
+--R                            - 3a c e   - 90a c d e  - 295a c d e  - 408a c d e
+--R                          + 
+--R                                  2 6 8 2        7 10
+--R                            - 264a c d e  - 64a c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               5 3   10      4 4 3 8       3 5 5 6       2 6 7 4
+--R                            14a c d e   + 60a c d e  + 110a c d e  + 104a c d e
+--R                          + 
+--R                                 7 9 2     8 11
+--R                            48a c d e  + 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                           5 3 12     4 4 2 10      3 5 4 8      2 6 6 6
+--R                        - a c e   - 5a c d e   - 11a c d e  - 13a c d e
+--R                      + 
+--R                              7 8 4     8 10 2
+--R                        - 8a c d e  - 2c d  e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                             5 4 2 4       5 3 4      4   5 2  3
+--R                        - 24a d e f  + (50a d e  + 72a c d e )f
+--R                      + 
+--R                              5 2 6      4   4 4      3 2 6 2  2
+--R                        (- 35a d e  - 98a c d e  - 72a c d e )f
+--R                      + 
+--R                            5   8      4   3 6      3 2 5 4      2 3 7 2
+--R                        (10a d e  + 40a c d e  + 54a c d e  + 24a c d e )f
+--R                      + 
+--R                           5 10     4   2 8     3 2 4 6     2 3 6 4
+--R                        - a e   - 5a c d e  - 9a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 4 2 4       6 3 4      5   5 2  3
+--R                                  - 9a d e f  + (24a d e  + 36a c d e )f
+--R                                + 
+--R                                        6 2 6      5   4 4      4 2 6 2  2
+--R                                  (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                                + 
+--R                                        6   8      5   3 6      4 2 5 4
+--R                                      8a d e  + 36a c d e  + 60a c d e
+--R                                    + 
+--R                                         3 3 7 2
+--R                                      36a c d e
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                                  - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                                + 
+--R                                      2 4 8 2
+--R                                  - 9a c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3 3 3         3 2 2      2   4  2
+--R                         4a d f  + (- 18a d e  - 12a c d )f
+--R                       + 
+--R                             3   4      2   3 2        2 5       3 6     2   2 4
+--R                         (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R                       + 
+--R                               2 4 2     3 6
+--R                         - 6a c d e  - 4c d
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       3 6   2         3 5 3      2   7        3 4 5
+--R                    12a d e f  + (- 16a d e  - 24a c d e)f + 4a d e
+--R                  + 
+--R                       2   6 3        2 8
+--R                    12a c d e  + 12a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                          6 4 7        6 3 2      5   5  6
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   4 2       4 2 6  5
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   3 4       4 2 5 2       3 3 7  4
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 4 4       3 3 6 2       2 4 8  3
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 3 6      3 3 5 4       2 4 7 2        5 9  2
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 4 6      2 4 6 4        5 8 2     6 10
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d  )f
+--R                      + 
+--R                            3 3 3 8     2 4 5 6       5 7 4     6 9 2
+--R                        - 2a c d e  - 6a c d e  - 6a c d e  - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            3 5 2 2      3 4 4      2   6 2       3 3 6
+--R                        - 6a d e f  + (8a d e  + 12a c d e )f - 2a d e
+--R                      + 
+--R                            2   5 4       2 7 2
+--R                        - 6a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R                  + 
+--R                         3 6   2       3 5 3      2   7        3 4 5
+--R                    - 12a d e f  + (16a d e  + 24a c d e)f - 4a d e
+--R                  + 
+--R                         2   6 3        2 8
+--R                    - 12a c d e  - 12a c d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +--------+
+--R               2 2                   2    2 2  +-+ |   2
+--R           (- a f  + 2a c d f - a c e  - c d )\|a \|c x  + a
+--R         + 
+--R             2   2       2         2 2    3 2  2    3 2     2         2   2
+--R           (a c f  - 2a c d f + a c e  + c d )x  + a f  - 2a c d f + a c e
+--R         + 
+--R              2 2
+--R           a c d
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             6 4 2 4       6 3 4      5   5 2  3
+--R                         - 9a d e f  + (24a d e  + 36a c d e )f
+--R                       + 
+--R                               6 2 6      5   4 4      4 2 6 2  2
+--R                         (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                       + 
+--R                            6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                         (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                       + 
+--R                          6 10     5   2 8      4 2 4 6      3 3 6 4     2 4 8 2
+--R                       - a e   - 6a c d e  - 15a c d e  - 18a c d e  - 9a c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3 3 3         3 2 2      2   4  2
+--R                4a d f  + (- 18a d e  - 12a c d )f
+--R              + 
+--R                    3   4      2   3 2        2 5       3 6     2   2 4
+--R                (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R              + 
+--R                      2 4 2     3 6
+--R                - 6a c d e  - 4c d
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                            8 3 9       8 2 2      7   4  8
+--R                        - 8a d f  + (18a d e  + 64a c d )f
+--R                      + 
+--R                             8   4       7   3 2       6 2 5  7
+--R                        (- 8a d e  - 144a c d e  - 224a c d )f
+--R                      + 
+--R                          8 6       7   2 4       6 2 4 2       5 3 6  6
+--R                        (a e  + 104a c d e  + 488a c d e  + 448a c d )f
+--R                      + 
+--R                              7     6       6 2 3 4       5 3 5 2       4 4 7  5
+--R                        (- 30a c d e  - 408a c d e  - 912a c d e  - 560a c d )f
+--R                      + 
+--R                              7   8       6 2 2 6       5 3 4 4        4 4 6 2
+--R                            3a c e  + 171a c d e  + 760a c d e  + 1020a c d e
+--R                          + 
+--R                                3 5 8
+--R                            448a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                                 6 2   8       5 3 3 6       4 4 5 4
+--R                            - 36a c d e  - 340a c d e  - 760a c d e
+--R                          + 
+--R                                  3 5 7 2       2 6 9
+--R                            - 688a c d e  - 224a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                              6 2 10      5 3 2 8       4 4 4 6       3 5 6 4
+--R                            3a c e   + 90a c d e  + 295a c d e  + 408a c d e
+--R                          + 
+--R                                2 6 8 2        7 10
+--R                            264a c d e  + 64a c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                                 5 3   10      4 4 3 8       3 5 5 6
+--R                            - 14a c d e   - 60a c d e  - 110a c d e
+--R                          + 
+--R                                  2 6 7 4        7 9 2     8 11
+--R                            - 104a c d e  - 48a c d e  - 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                         5 3 12     4 4 2 10      3 5 4 8      2 6 6 6
+--R                        a c e   + 5a c d e   + 11a c d e  + 13a c d e
+--R                      + 
+--R                            7 8 4     8 10 2
+--R                        8a c d e  + 2c d  e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                           5 4 2 4         5 3 4      4   5 2  3
+--R                        24a d e f  + (- 50a d e  - 72a c d e )f
+--R                      + 
+--R                            5 2 6      4   4 4      3 2 6 2  2
+--R                        (35a d e  + 98a c d e  + 72a c d e )f
+--R                      + 
+--R                              5   8      4   3 6      3 2 5 4      2 3 7 2
+--R                        (- 10a d e  - 40a c d e  - 54a c d e  - 24a c d e )f
+--R                      + 
+--R                         5 10     4   2 8     3 2 4 6     2 3 6 4
+--R                        a e   + 5a c d e  + 9a c d e  + 6a c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 4 2 4       6 3 4      5   5 2  3
+--R                                  - 9a d e f  + (24a d e  + 36a c d e )f
+--R                                + 
+--R                                        6 2 6      5   4 4      4 2 6 2  2
+--R                                  (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                                + 
+--R                                        6   8      5   3 6      4 2 5 4
+--R                                      8a d e  + 36a c d e  + 60a c d e
+--R                                    + 
+--R                                         3 3 7 2
+--R                                      36a c d e
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                                  - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                                + 
+--R                                      2 4 8 2
+--R                                  - 9a c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3 3 3         3 2 2      2   4  2
+--R                         4a d f  + (- 18a d e  - 12a c d )f
+--R                       + 
+--R                             3   4      2   3 2        2 5       3 6     2   2 4
+--R                         (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R                       + 
+--R                               2 4 2     3 6
+--R                         - 6a c d e  - 4c d
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       3 6   2         3 5 3      2   7        3 4 5
+--R                    12a d e f  + (- 16a d e  - 24a c d e)f + 4a d e
+--R                  + 
+--R                       2   6 3        2 8
+--R                    12a c d e  + 12a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                          6 4 7        6 3 2      5   5  6
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   4 2       4 2 6  5
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   3 4       4 2 5 2       3 3 7  4
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 4 4       3 3 6 2       2 4 8  3
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 3 6      3 3 5 4       2 4 7 2        5 9  2
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 4 6      2 4 6 4        5 8 2     6 10
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d  )f
+--R                      + 
+--R                            3 3 3 8     2 4 5 6       5 7 4     6 9 2
+--R                        - 2a c d e  - 6a c d e  - 6a c d e  - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            3 5 2 2      3 4 4      2   6 2       3 3 6
+--R                        - 6a d e f  + (8a d e  + 12a c d e )f - 2a d e
+--R                      + 
+--R                            2   5 4       2 7 2
+--R                        - 6a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R                  + 
+--R                         3 6   2       3 5 3      2   7        3 4 5
+--R                    - 12a d e f  + (16a d e  + 24a c d e)f - 4a d e
+--R                  + 
+--R                         2   6 3        2 8
+--R                    - 12a c d e  - 12a c d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                 +--------+
+--R             2 2                   2    2 2  +-+ |   2
+--R           (a f  - 2a c d f + a c e  + c d )\|a \|c x  + a
+--R         + 
+--R               2   2       2         2 2    3 2  2    3 2     2         2   2
+--R           (- a c f  + 2a c d f - a c e  - c d )x  - a f  + 2a c d f - a c e
+--R         + 
+--R                2 2
+--R           - a c d
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             6 4 2 4       6 3 4      5   5 2  3
+--R                         - 9a d e f  + (24a d e  + 36a c d e )f
+--R                       + 
+--R                               6 2 6      5   4 4      4 2 6 2  2
+--R                         (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                       + 
+--R                            6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                         (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                       + 
+--R                          6 10     5   2 8      4 2 4 6      3 3 6 4     2 4 8 2
+--R                       - a e   - 6a c d e  - 15a c d e  - 18a c d e  - 9a c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3 3 3         3 2 2      2   4  2
+--R                4a d f  + (- 18a d e  - 12a c d )f
+--R              + 
+--R                    3   4      2   3 2        2 5       3 6     2   2 4
+--R                (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R              + 
+--R                      2 4 2     3 6
+--R                - 6a c d e  - 4c d
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                            8 3 9       8 2 2      7   4  8
+--R                        - 8a d f  + (18a d e  + 64a c d )f
+--R                      + 
+--R                             8   4       7   3 2       6 2 5  7
+--R                        (- 8a d e  - 144a c d e  - 224a c d )f
+--R                      + 
+--R                          8 6       7   2 4       6 2 4 2       5 3 6  6
+--R                        (a e  + 104a c d e  + 488a c d e  + 448a c d )f
+--R                      + 
+--R                              7     6       6 2 3 4       5 3 5 2       4 4 7  5
+--R                        (- 30a c d e  - 408a c d e  - 912a c d e  - 560a c d )f
+--R                      + 
+--R                              7   8       6 2 2 6       5 3 4 4        4 4 6 2
+--R                            3a c e  + 171a c d e  + 760a c d e  + 1020a c d e
+--R                          + 
+--R                                3 5 8
+--R                            448a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                                 6 2   8       5 3 3 6       4 4 5 4
+--R                            - 36a c d e  - 340a c d e  - 760a c d e
+--R                          + 
+--R                                  3 5 7 2       2 6 9
+--R                            - 688a c d e  - 224a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                              6 2 10      5 3 2 8       4 4 4 6       3 5 6 4
+--R                            3a c e   + 90a c d e  + 295a c d e  + 408a c d e
+--R                          + 
+--R                                2 6 8 2        7 10
+--R                            264a c d e  + 64a c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                                 5 3   10      4 4 3 8       3 5 5 6
+--R                            - 14a c d e   - 60a c d e  - 110a c d e
+--R                          + 
+--R                                  2 6 7 4        7 9 2     8 11
+--R                            - 104a c d e  - 48a c d e  - 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                         5 3 12     4 4 2 10      3 5 4 8      2 6 6 6
+--R                        a c e   + 5a c d e   + 11a c d e  + 13a c d e
+--R                      + 
+--R                            7 8 4     8 10 2
+--R                        8a c d e  + 2c d  e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                             5 4 2 4       5 3 4      4   5 2  3
+--R                        - 24a d e f  + (50a d e  + 72a c d e )f
+--R                      + 
+--R                              5 2 6      4   4 4      3 2 6 2  2
+--R                        (- 35a d e  - 98a c d e  - 72a c d e )f
+--R                      + 
+--R                            5   8      4   3 6      3 2 5 4      2 3 7 2
+--R                        (10a d e  + 40a c d e  + 54a c d e  + 24a c d e )f
+--R                      + 
+--R                           5 10     4   2 8     3 2 4 6     2 3 6 4
+--R                        - a e   - 5a c d e  - 9a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 4 2 4       6 3 4      5   5 2  3
+--R                                  - 9a d e f  + (24a d e  + 36a c d e )f
+--R                                + 
+--R                                        6 2 6      5   4 4      4 2 6 2  2
+--R                                  (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                                + 
+--R                                        6   8      5   3 6      4 2 5 4
+--R                                      8a d e  + 36a c d e  + 60a c d e
+--R                                    + 
+--R                                         3 3 7 2
+--R                                      36a c d e
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                                  - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                                + 
+--R                                      2 4 8 2
+--R                                  - 9a c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3 3 3         3 2 2      2   4  2
+--R                         4a d f  + (- 18a d e  - 12a c d )f
+--R                       + 
+--R                             3   4      2   3 2        2 5       3 6     2   2 4
+--R                         (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R                       + 
+--R                               2 4 2     3 6
+--R                         - 6a c d e  - 4c d
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       3 6   2         3 5 3      2   7        3 4 5
+--R                    12a d e f  + (- 16a d e  - 24a c d e)f + 4a d e
+--R                  + 
+--R                       2   6 3        2 8
+--R                    12a c d e  + 12a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                            6 4 7      6 3 2      5   5  6
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   4 2       4 2 6  5
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   3 4       4 2 5 2       3 3 7  4
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 4 4       3 3 6 2       2 4 8  3
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 3 6      3 3 5 4       2 4 7 2        5 9  2
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 4 6      2 4 6 4        5 8 2     6 10
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d  )f
+--R                      + 
+--R                          3 3 3 8     2 4 5 6       5 7 4     6 9 2
+--R                        2a c d e  + 6a c d e  + 6a c d e  + 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            3 5 2 2      3 4 4      2   6 2       3 3 6
+--R                        - 6a d e f  + (8a d e  + 12a c d e )f - 2a d e
+--R                      + 
+--R                            2   5 4       2 7 2
+--R                        - 6a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R                  + 
+--R                         3 6   2       3 5 3      2   7        3 4 5
+--R                    - 12a d e f  + (16a d e  + 24a c d e)f - 4a d e
+--R                  + 
+--R                         2   6 3        2 8
+--R                    - 12a c d e  - 12a c d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R              +--------+
+--R              |   2                       2           +-+
+--R       2a e x\|c x  + a  + ((2a f - 2c d)x  - 2a e x)\|a
+--R  /
+--R                                                +--------+
+--R          2 2                    2     2 2  +-+ |   2
+--R       (2a f  - 4a c d f + 2a c e  + 2c d )\|a \|c x  + a
+--R     + 
+--R            2   2       2          2 2     3 2  2     3 2     2          2   2
+--R       (- 2a c f  + 4a c d f - 2a c e  - 2c d )x  - 2a f  + 4a c d f - 2a c e
+--R     + 
+--R             2 2
+--R       - 2a c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 98
+
+--S 99 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                     +-----------+ +--------+
+--R               2   2       2         2 2    3 2  +-+ |          2  |   2
+--R           (- a c f  + 2a c d f - a c e  - c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                   +-----------+
+--R             2   2       2         2 2    3 2  +-+ |          2  +-+
+--R           (a c f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             6 4 2 4       6 3 4      5   5 2  3
+--R                         - 9a d e f  + (24a d e  + 36a c d e )f
+--R                       + 
+--R                               6 2 6      5   4 4      4 2 6 2  2
+--R                         (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                       + 
+--R                            6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                         (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                       + 
+--R                          6 10     5   2 8      4 2 4 6      3 3 6 4     2 4 8 2
+--R                       - a e   - 6a c d e  - 15a c d e  - 18a c d e  - 9a c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3 3 3         3 2 2      2   4  2
+--R                4a d f  + (- 18a d e  - 12a c d )f
+--R              + 
+--R                    3   4      2   3 2        2 5       3 6     2   2 4
+--R                (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R              + 
+--R                      2 4 2     3 6
+--R                - 6a c d e  - 4c d
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                          8 3 9         8 2 2      7   4  8
+--R                        8a d f  + (- 18a d e  - 64a c d )f
+--R                      + 
+--R                           8   4       7   3 2       6 2 5  7
+--R                        (8a d e  + 144a c d e  + 224a c d )f
+--R                      + 
+--R                            8 6       7   2 4       6 2 4 2       5 3 6  6
+--R                        (- a e  - 104a c d e  - 488a c d e  - 448a c d )f
+--R                      + 
+--R                            7     6       6 2 3 4       5 3 5 2       4 4 7  5
+--R                        (30a c d e  + 408a c d e  + 912a c d e  + 560a c d )f
+--R                      + 
+--R                                7   8       6 2 2 6       5 3 4 4        4 4 6 2
+--R                            - 3a c e  - 171a c d e  - 760a c d e  - 1020a c d e
+--R                          + 
+--R                                  3 5 8
+--R                            - 448a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                               6 2   8       5 3 3 6       4 4 5 4       3 5 7 2
+--R                            36a c d e  + 340a c d e  + 760a c d e  + 688a c d e
+--R                          + 
+--R                                2 6 9
+--R                            224a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                                6 2 10      5 3 2 8       4 4 4 6       3 5 6 4
+--R                            - 3a c e   - 90a c d e  - 295a c d e  - 408a c d e
+--R                          + 
+--R                                  2 6 8 2        7 10
+--R                            - 264a c d e  - 64a c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               5 3   10      4 4 3 8       3 5 5 6       2 6 7 4
+--R                            14a c d e   + 60a c d e  + 110a c d e  + 104a c d e
+--R                          + 
+--R                                 7 9 2     8 11
+--R                            48a c d e  + 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                           5 3 12     4 4 2 10      3 5 4 8      2 6 6 6
+--R                        - a c e   - 5a c d e   - 11a c d e  - 13a c d e
+--R                      + 
+--R                              7 8 4     8 10 2
+--R                        - 8a c d e  - 2c d  e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                           5 4 2 4         5 3 4      4   5 2  3
+--R                        24a d e f  + (- 50a d e  - 72a c d e )f
+--R                      + 
+--R                            5 2 6      4   4 4      3 2 6 2  2
+--R                        (35a d e  + 98a c d e  + 72a c d e )f
+--R                      + 
+--R                              5   8      4   3 6      3 2 5 4      2 3 7 2
+--R                        (- 10a d e  - 40a c d e  - 54a c d e  - 24a c d e )f
+--R                      + 
+--R                         5 10     4   2 8     3 2 4 6     2 3 6 4
+--R                        a e   + 5a c d e  + 9a c d e  + 6a c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 4 2 4       6 3 4      5   5 2  3
+--R                                  - 9a d e f  + (24a d e  + 36a c d e )f
+--R                                + 
+--R                                        6 2 6      5   4 4      4 2 6 2  2
+--R                                  (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                                + 
+--R                                        6   8      5   3 6      4 2 5 4
+--R                                      8a d e  + 36a c d e  + 60a c d e
+--R                                    + 
+--R                                         3 3 7 2
+--R                                      36a c d e
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                                  - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                                + 
+--R                                      2 4 8 2
+--R                                  - 9a c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3 3 3         3 2 2      2   4  2
+--R                         4a d f  + (- 18a d e  - 12a c d )f
+--R                       + 
+--R                             3   4      2   3 2        2 5       3 6     2   2 4
+--R                         (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R                       + 
+--R                               2 4 2     3 6
+--R                         - 6a c d e  - 4c d
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       3 6   2         3 5 3      2   7        3 4 5
+--R                    12a d e f  + (- 16a d e  - 24a c d e)f + 4a d e
+--R                  + 
+--R                       2   6 3        2 8
+--R                    12a c d e  + 12a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                            6 4 7      6 3 2      5   5  6
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   4 2       4 2 6  5
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   3 4       4 2 5 2       3 3 7  4
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 4 4       3 3 6 2       2 4 8  3
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 3 6      3 3 5 4       2 4 7 2        5 9  2
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 4 6      2 4 6 4        5 8 2     6 10
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d  )f
+--R                      + 
+--R                          3 3 3 8     2 4 5 6       5 7 4     6 9 2
+--R                        2a c d e  + 6a c d e  + 6a c d e  + 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            3 5 2 2      3 4 4      2   6 2       3 3 6
+--R                        - 6a d e f  + (8a d e  + 12a c d e )f - 2a d e
+--R                      + 
+--R                            2   5 4       2 7 2
+--R                        - 6a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R                  + 
+--R                         3 6   2       3 5 3      2   7        3 4 5
+--R                    - 12a d e f  + (16a d e  + 24a c d e)f - 4a d e
+--R                  + 
+--R                         2   6 3        2 8
+--R                    - 12a c d e  - 12a c d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +-----------+ +--------+
+--R             2   2       2         2 2    3 2  +-+ |          2  |   2
+--R           (a c f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                     +-----------+
+--R               2   2       2         2 2    3 2  +-+ |          2  +-+
+--R           (- a c f  + 2a c d f - a c e  - c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             6 4 2 4       6 3 4      5   5 2  3
+--R                         - 9a d e f  + (24a d e  + 36a c d e )f
+--R                       + 
+--R                               6 2 6      5   4 4      4 2 6 2  2
+--R                         (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                       + 
+--R                            6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                         (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                       + 
+--R                          6 10     5   2 8      4 2 4 6      3 3 6 4     2 4 8 2
+--R                       - a e   - 6a c d e  - 15a c d e  - 18a c d e  - 9a c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3 3 3         3 2 2      2   4  2
+--R                4a d f  + (- 18a d e  - 12a c d )f
+--R              + 
+--R                    3   4      2   3 2        2 5       3 6     2   2 4
+--R                (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R              + 
+--R                      2 4 2     3 6
+--R                - 6a c d e  - 4c d
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                          8 3 9         8 2 2      7   4  8
+--R                        8a d f  + (- 18a d e  - 64a c d )f
+--R                      + 
+--R                           8   4       7   3 2       6 2 5  7
+--R                        (8a d e  + 144a c d e  + 224a c d )f
+--R                      + 
+--R                            8 6       7   2 4       6 2 4 2       5 3 6  6
+--R                        (- a e  - 104a c d e  - 488a c d e  - 448a c d )f
+--R                      + 
+--R                            7     6       6 2 3 4       5 3 5 2       4 4 7  5
+--R                        (30a c d e  + 408a c d e  + 912a c d e  + 560a c d )f
+--R                      + 
+--R                                7   8       6 2 2 6       5 3 4 4        4 4 6 2
+--R                            - 3a c e  - 171a c d e  - 760a c d e  - 1020a c d e
+--R                          + 
+--R                                  3 5 8
+--R                            - 448a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                               6 2   8       5 3 3 6       4 4 5 4       3 5 7 2
+--R                            36a c d e  + 340a c d e  + 760a c d e  + 688a c d e
+--R                          + 
+--R                                2 6 9
+--R                            224a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                                6 2 10      5 3 2 8       4 4 4 6       3 5 6 4
+--R                            - 3a c e   - 90a c d e  - 295a c d e  - 408a c d e
+--R                          + 
+--R                                  2 6 8 2        7 10
+--R                            - 264a c d e  - 64a c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               5 3   10      4 4 3 8       3 5 5 6       2 6 7 4
+--R                            14a c d e   + 60a c d e  + 110a c d e  + 104a c d e
+--R                          + 
+--R                                 7 9 2     8 11
+--R                            48a c d e  + 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                           5 3 12     4 4 2 10      3 5 4 8      2 6 6 6
+--R                        - a c e   - 5a c d e   - 11a c d e  - 13a c d e
+--R                      + 
+--R                              7 8 4     8 10 2
+--R                        - 8a c d e  - 2c d  e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                             5 4 2 4       5 3 4      4   5 2  3
+--R                        - 24a d e f  + (50a d e  + 72a c d e )f
+--R                      + 
+--R                              5 2 6      4   4 4      3 2 6 2  2
+--R                        (- 35a d e  - 98a c d e  - 72a c d e )f
+--R                      + 
+--R                            5   8      4   3 6      3 2 5 4      2 3 7 2
+--R                        (10a d e  + 40a c d e  + 54a c d e  + 24a c d e )f
+--R                      + 
+--R                           5 10     4   2 8     3 2 4 6     2 3 6 4
+--R                        - a e   - 5a c d e  - 9a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 4 2 4       6 3 4      5   5 2  3
+--R                                  - 9a d e f  + (24a d e  + 36a c d e )f
+--R                                + 
+--R                                        6 2 6      5   4 4      4 2 6 2  2
+--R                                  (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                                + 
+--R                                        6   8      5   3 6      4 2 5 4
+--R                                      8a d e  + 36a c d e  + 60a c d e
+--R                                    + 
+--R                                         3 3 7 2
+--R                                      36a c d e
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                                  - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                                + 
+--R                                      2 4 8 2
+--R                                  - 9a c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3 3 3         3 2 2      2   4  2
+--R                         4a d f  + (- 18a d e  - 12a c d )f
+--R                       + 
+--R                             3   4      2   3 2        2 5       3 6     2   2 4
+--R                         (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R                       + 
+--R                               2 4 2     3 6
+--R                         - 6a c d e  - 4c d
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       3 6   2         3 5 3      2   7        3 4 5
+--R                    12a d e f  + (- 16a d e  - 24a c d e)f + 4a d e
+--R                  + 
+--R                       2   6 3        2 8
+--R                    12a c d e  + 12a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                          6 4 7        6 3 2      5   5  6
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   4 2       4 2 6  5
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   3 4       4 2 5 2       3 3 7  4
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 4 4       3 3 6 2       2 4 8  3
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 3 6      3 3 5 4       2 4 7 2        5 9  2
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 4 6      2 4 6 4        5 8 2     6 10
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d  )f
+--R                      + 
+--R                            3 3 3 8     2 4 5 6       5 7 4     6 9 2
+--R                        - 2a c d e  - 6a c d e  - 6a c d e  - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            3 5 2 2      3 4 4      2   6 2       3 3 6
+--R                        - 6a d e f  + (8a d e  + 12a c d e )f - 2a d e
+--R                      + 
+--R                            2   5 4       2 7 2
+--R                        - 6a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R                  + 
+--R                         3 6   2       3 5 3      2   7        3 4 5
+--R                    - 12a d e f  + (16a d e  + 24a c d e)f - 4a d e
+--R                  + 
+--R                         2   6 3        2 8
+--R                    - 12a c d e  - 12a c d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                     +-----------+ +--------+
+--R               2   2       2         2 2    3 2  +-+ |          2  |   2
+--R           (- a c f  + 2a c d f - a c e  - c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                   +-----------+
+--R             2   2       2         2 2    3 2  +-+ |          2  +-+
+--R           (a c f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             6 4 2 4       6 3 4      5   5 2  3
+--R                         - 9a d e f  + (24a d e  + 36a c d e )f
+--R                       + 
+--R                               6 2 6      5   4 4      4 2 6 2  2
+--R                         (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                       + 
+--R                            6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                         (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                       + 
+--R                          6 10     5   2 8      4 2 4 6      3 3 6 4     2 4 8 2
+--R                       - a e   - 6a c d e  - 15a c d e  - 18a c d e  - 9a c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3 3 3         3 2 2      2   4  2
+--R                4a d f  + (- 18a d e  - 12a c d )f
+--R              + 
+--R                    3   4      2   3 2        2 5       3 6     2   2 4
+--R                (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R              + 
+--R                      2 4 2     3 6
+--R                - 6a c d e  - 4c d
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                            8 3 9       8 2 2      7   4  8
+--R                        - 8a d f  + (18a d e  + 64a c d )f
+--R                      + 
+--R                             8   4       7   3 2       6 2 5  7
+--R                        (- 8a d e  - 144a c d e  - 224a c d )f
+--R                      + 
+--R                          8 6       7   2 4       6 2 4 2       5 3 6  6
+--R                        (a e  + 104a c d e  + 488a c d e  + 448a c d )f
+--R                      + 
+--R                              7     6       6 2 3 4       5 3 5 2       4 4 7  5
+--R                        (- 30a c d e  - 408a c d e  - 912a c d e  - 560a c d )f
+--R                      + 
+--R                              7   8       6 2 2 6       5 3 4 4        4 4 6 2
+--R                            3a c e  + 171a c d e  + 760a c d e  + 1020a c d e
+--R                          + 
+--R                                3 5 8
+--R                            448a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                                 6 2   8       5 3 3 6       4 4 5 4
+--R                            - 36a c d e  - 340a c d e  - 760a c d e
+--R                          + 
+--R                                  3 5 7 2       2 6 9
+--R                            - 688a c d e  - 224a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                              6 2 10      5 3 2 8       4 4 4 6       3 5 6 4
+--R                            3a c e   + 90a c d e  + 295a c d e  + 408a c d e
+--R                          + 
+--R                                2 6 8 2        7 10
+--R                            264a c d e  + 64a c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                                 5 3   10      4 4 3 8       3 5 5 6
+--R                            - 14a c d e   - 60a c d e  - 110a c d e
+--R                          + 
+--R                                  2 6 7 4        7 9 2     8 11
+--R                            - 104a c d e  - 48a c d e  - 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                         5 3 12     4 4 2 10      3 5 4 8      2 6 6 6
+--R                        a c e   + 5a c d e   + 11a c d e  + 13a c d e
+--R                      + 
+--R                            7 8 4     8 10 2
+--R                        8a c d e  + 2c d  e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                           5 4 2 4         5 3 4      4   5 2  3
+--R                        24a d e f  + (- 50a d e  - 72a c d e )f
+--R                      + 
+--R                            5 2 6      4   4 4      3 2 6 2  2
+--R                        (35a d e  + 98a c d e  + 72a c d e )f
+--R                      + 
+--R                              5   8      4   3 6      3 2 5 4      2 3 7 2
+--R                        (- 10a d e  - 40a c d e  - 54a c d e  - 24a c d e )f
+--R                      + 
+--R                         5 10     4   2 8     3 2 4 6     2 3 6 4
+--R                        a e   + 5a c d e  + 9a c d e  + 6a c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 4 2 4       6 3 4      5   5 2  3
+--R                                  - 9a d e f  + (24a d e  + 36a c d e )f
+--R                                + 
+--R                                        6 2 6      5   4 4      4 2 6 2  2
+--R                                  (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                                + 
+--R                                        6   8      5   3 6      4 2 5 4
+--R                                      8a d e  + 36a c d e  + 60a c d e
+--R                                    + 
+--R                                         3 3 7 2
+--R                                      36a c d e
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                                  - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                                + 
+--R                                      2 4 8 2
+--R                                  - 9a c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3 3 3         3 2 2      2   4  2
+--R                         4a d f  + (- 18a d e  - 12a c d )f
+--R                       + 
+--R                             3   4      2   3 2        2 5       3 6     2   2 4
+--R                         (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R                       + 
+--R                               2 4 2     3 6
+--R                         - 6a c d e  - 4c d
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       3 6   2         3 5 3      2   7        3 4 5
+--R                    12a d e f  + (- 16a d e  - 24a c d e)f + 4a d e
+--R                  + 
+--R                       2   6 3        2 8
+--R                    12a c d e  + 12a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                          6 4 7        6 3 2      5   5  6
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   4 2       4 2 6  5
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   3 4       4 2 5 2       3 3 7  4
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 4 4       3 3 6 2       2 4 8  3
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 3 6      3 3 5 4       2 4 7 2        5 9  2
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 4 6      2 4 6 4        5 8 2     6 10
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d  )f
+--R                      + 
+--R                            3 3 3 8     2 4 5 6       5 7 4     6 9 2
+--R                        - 2a c d e  - 6a c d e  - 6a c d e  - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            3 5 2 2      3 4 4      2   6 2       3 3 6
+--R                        - 6a d e f  + (8a d e  + 12a c d e )f - 2a d e
+--R                      + 
+--R                            2   5 4       2 7 2
+--R                        - 6a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R                  + 
+--R                         3 6   2       3 5 3      2   7        3 4 5
+--R                    - 12a d e f  + (16a d e  + 24a c d e)f - 4a d e
+--R                  + 
+--R                         2   6 3        2 8
+--R                    - 12a c d e  - 12a c d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +-----------+ +--------+
+--R             2   2       2         2 2    3 2  +-+ |          2  |   2
+--R           (a c f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                     +-----------+
+--R               2   2       2         2 2    3 2  +-+ |          2  +-+
+--R           (- a c f  + 2a c d f - a c e  - c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             6 4 2 4       6 3 4      5   5 2  3
+--R                         - 9a d e f  + (24a d e  + 36a c d e )f
+--R                       + 
+--R                               6 2 6      5   4 4      4 2 6 2  2
+--R                         (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                       + 
+--R                            6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                         (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                       + 
+--R                          6 10     5   2 8      4 2 4 6      3 3 6 4     2 4 8 2
+--R                       - a e   - 6a c d e  - 15a c d e  - 18a c d e  - 9a c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3 3 3         3 2 2      2   4  2
+--R                4a d f  + (- 18a d e  - 12a c d )f
+--R              + 
+--R                    3   4      2   3 2        2 5       3 6     2   2 4
+--R                (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R              + 
+--R                      2 4 2     3 6
+--R                - 6a c d e  - 4c d
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                            8 3 9       8 2 2      7   4  8
+--R                        - 8a d f  + (18a d e  + 64a c d )f
+--R                      + 
+--R                             8   4       7   3 2       6 2 5  7
+--R                        (- 8a d e  - 144a c d e  - 224a c d )f
+--R                      + 
+--R                          8 6       7   2 4       6 2 4 2       5 3 6  6
+--R                        (a e  + 104a c d e  + 488a c d e  + 448a c d )f
+--R                      + 
+--R                              7     6       6 2 3 4       5 3 5 2       4 4 7  5
+--R                        (- 30a c d e  - 408a c d e  - 912a c d e  - 560a c d )f
+--R                      + 
+--R                              7   8       6 2 2 6       5 3 4 4        4 4 6 2
+--R                            3a c e  + 171a c d e  + 760a c d e  + 1020a c d e
+--R                          + 
+--R                                3 5 8
+--R                            448a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                                 6 2   8       5 3 3 6       4 4 5 4
+--R                            - 36a c d e  - 340a c d e  - 760a c d e
+--R                          + 
+--R                                  3 5 7 2       2 6 9
+--R                            - 688a c d e  - 224a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                              6 2 10      5 3 2 8       4 4 4 6       3 5 6 4
+--R                            3a c e   + 90a c d e  + 295a c d e  + 408a c d e
+--R                          + 
+--R                                2 6 8 2        7 10
+--R                            264a c d e  + 64a c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                                 5 3   10      4 4 3 8       3 5 5 6
+--R                            - 14a c d e   - 60a c d e  - 110a c d e
+--R                          + 
+--R                                  2 6 7 4        7 9 2     8 11
+--R                            - 104a c d e  - 48a c d e  - 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                         5 3 12     4 4 2 10      3 5 4 8      2 6 6 6
+--R                        a c e   + 5a c d e   + 11a c d e  + 13a c d e
+--R                      + 
+--R                            7 8 4     8 10 2
+--R                        8a c d e  + 2c d  e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                             5 4 2 4       5 3 4      4   5 2  3
+--R                        - 24a d e f  + (50a d e  + 72a c d e )f
+--R                      + 
+--R                              5 2 6      4   4 4      3 2 6 2  2
+--R                        (- 35a d e  - 98a c d e  - 72a c d e )f
+--R                      + 
+--R                            5   8      4   3 6      3 2 5 4      2 3 7 2
+--R                        (10a d e  + 40a c d e  + 54a c d e  + 24a c d e )f
+--R                      + 
+--R                           5 10     4   2 8     3 2 4 6     2 3 6 4
+--R                        - a e   - 5a c d e  - 9a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 4 2 4       6 3 4      5   5 2  3
+--R                                  - 9a d e f  + (24a d e  + 36a c d e )f
+--R                                + 
+--R                                        6 2 6      5   4 4      4 2 6 2  2
+--R                                  (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                                + 
+--R                                        6   8      5   3 6      4 2 5 4
+--R                                      8a d e  + 36a c d e  + 60a c d e
+--R                                    + 
+--R                                         3 3 7 2
+--R                                      36a c d e
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                                  - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                                + 
+--R                                      2 4 8 2
+--R                                  - 9a c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3 3 3         3 2 2      2   4  2
+--R                         4a d f  + (- 18a d e  - 12a c d )f
+--R                       + 
+--R                             3   4      2   3 2        2 5       3 6     2   2 4
+--R                         (12a d e  + 24a c d e  + 12a c d )f - 2a e  - 6a c d e
+--R                       + 
+--R                               2 4 2     3 6
+--R                         - 6a c d e  - 4c d
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       3 6   2         3 5 3      2   7        3 4 5
+--R                    12a d e f  + (- 16a d e  - 24a c d e)f + 4a d e
+--R                  + 
+--R                       2   6 3        2 8
+--R                    12a c d e  + 12a c d e
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                            6 4 7      6 3 2      5   5  6
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   4 2       4 2 6  5
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   3 4       4 2 5 2       3 3 7  4
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 4 4       3 3 6 2       2 4 8  3
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 3 6      3 3 5 4       2 4 7 2        5 9  2
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 4 6      2 4 6 4        5 8 2     6 10
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d  )f
+--R                      + 
+--R                          3 3 3 8     2 4 5 6       5 7 4     6 9 2
+--R                        2a c d e  + 6a c d e  + 6a c d e  + 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 4 2 4       6 3 4      5   5 2  3
+--R                             - 9a d e f  + (24a d e  + 36a c d e )f
+--R                           + 
+--R                                   6 2 6      5   4 4      4 2 6 2  2
+--R                             (- 22a d e  - 66a c d e  - 54a c d e )f
+--R                           + 
+--R                                6   8      5   3 6      4 2 5 4      3 3 7 2
+--R                             (8a d e  + 36a c d e  + 60a c d e  + 36a c d e )f
+--R                           + 
+--R                                6 10     5   2 8      4 2 4 6      3 3 6 4
+--R                             - a e   - 6a c d e  - 15a c d e  - 18a c d e
+--R                           + 
+--R                                 2 4 8 2
+--R                             - 9a c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            3 5 2 2      3 4 4      2   6 2       3 3 6
+--R                        - 6a d e f  + (8a d e  + 12a c d e )f - 2a d e
+--R                      + 
+--R                            2   5 4       2 7 2
+--R                        - 6a c d e  - 6a c d e
+--R                   *
+--R                      x
+--R                  + 
+--R                         3 6   2       3 5 3      2   7        3 4 5
+--R                    - 12a d e f  + (16a d e  + 24a c d e)f - 4a d e
+--R                  + 
+--R                         2   6 3        2 8
+--R                    - 12a c d e  - 12a c d e
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                              +-----------+
+--R                                   2     2 2  |          2
+--R               (- 2a c d f + 2a c e  + 2c d )\|- 4d f + e   + 6a c d e f
+--R             + 
+--R                       3     2 2
+--R               - 2a c e  - 2c d e
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + a
+--R         + 
+--R                                            +-----------+
+--R                                 2     2 2  |          2                       3
+--R               (2a c d f - 2a c e  - 2c d )\|- 4d f + e   - 6a c d e f + 2a c e
+--R             + 
+--R                 2 2
+--R               2c d e
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                            +-----------+
+--R                                 2     2 2  |          2                       3
+--R               (2a c d f - 2a c e  - 2c d )\|- 4d f + e   + 6a c d e f - 2a c e
+--R             + 
+--R                   2 2
+--R               - 2c d e
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + a
+--R         + 
+--R                                              +-----------+
+--R                                   2     2 2  |          2
+--R               (- 2a c d f + 2a c e  + 2c d )\|- 4d f + e   - 6a c d e f
+--R             + 
+--R                     3     2 2
+--R               2a c e  + 2c d e
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                               +-----------+     +--------+
+--R                           +-+ |          2  +-+ |   2
+--R           (- 2a f + 2c d)\|2 \|- 4d f + e  \|a \|c x  + a
+--R         + 
+--R                               +-----------+
+--R              2            +-+ |          2
+--R           (2a f - 2a c d)\|2 \|- 4d f + e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                                    +-----------+ +--------+
+--R            2   2       2          2 2     3 2  +-+ |          2  |   2
+--R         (2a c f  - 4a c d f + 2a c e  + 2c d )\|2 \|- 4d f + e  \|c x  + a
+--R       + 
+--R                                                      +-----------+
+--R              2   2       2          2 2     3 2  +-+ |          2  +-+
+--R         (- 2a c f  + 4a c d f - 2a c e  - 2c d )\|2 \|- 4d f + e  \|a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 1580
+--d0:=D(m0,x)
+--E 100
+
+)clear all
+
+--S 101 of 1580
+t0:=x^2/((a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                     2
+--R                                    x
+--R   (1)  ----------------------------------------------------------
+--R                                                        +--------+
+--R              4        3               2                |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x + a d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1580
+r0:=x/(a*f*sqrt(a+c*x^2))+(-a^2*e*f-c*(c*d^2+a*(e^2-d*f))*x)/(a*f*_
+   (c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(a+c*x^2))-f*atanh((2*a*f-_
+   c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*d*(c*d-a*f)+a*e*(e-sqrt(e^2-_
+   4*d*f)))/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+f*atanh((2*a*f-_
+   c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))))*(2*d*(c*d-a*f)+a*e*(e+sqrt(e^2-4*d*f)))/_
+   ((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                +-----------+                                +--------+
+--R                |          2          2         2       2    |   2
+--R         (a e f\|- 4d f + e   + 2a d f  + (- a e  - 2c d )f)\|c x  + a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                  +-----------+                                +--------+
+--R                  |          2          2         2       2    |   2
+--R         (- a e f\|- 4d f + e   + 2a d f  + (- a e  - 2c d )f)\|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                  +-----------+
+--R                              +-+ |          2
+--R         ((a f - c d)x - a e)\|2 \|- 4d f + e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                             +-----------+ +--------+
+--R         2 2                   2    2 2  +-+ |          2  |   2
+--R       (a f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                 +--------+
+--R             2 2                   2    2 2  +-+ |   2
+--R           (a f  - 2a c d f + a c e  + c d )\|a \|c x  + a
+--R         + 
+--R               2   2       2         2 2    3 2  2    3 2     2         2   2
+--R           (- a c f  + 2a c d f - a c e  - c d )x  - a f  + 2a c d f - a c e
+--R         + 
+--R                2 2
+--R           - a c d
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             6 2 2 6      6   4      5   3 2  5
+--R                         - 4a d e f  + (4a d e  + 12a c d e )f
+--R                       + 
+--R                             6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                         (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                       + 
+--R                            3 3 4 4     2 4 6 2  2    6 8 2
+--R                         (2a c d e  + 6a c d e )f  - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 2 4      3   2      2   3  3
+--R                - 4a d f  + (8a d e  + 12a c d )f
+--R              + 
+--R                     3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                           8 2   9        8   3      7   3   8
+--R                        12a d e f  + (- 7a d e  - 80a c d e)f
+--R                      + 
+--R                          8 5      7   2 3       6 2 4   7
+--R                        (a e  + 80a c d e  + 224a c d e)f
+--R                      + 
+--R                              7     5       6 2 3 3       5 3 5   6
+--R                        (- 27a c d e  - 284a c d e  - 336a c d e)f
+--R                      + 
+--R                           7   7       6 2 2 5       5 3 4 3       4 4 6   5
+--R                        (3a c e  + 141a c d e  + 464a c d e  + 280a c d e)f
+--R                      + 
+--R                                   6 2   7       5 3 3 5       4 4 5 3
+--R                              - 33a c d e  - 263a c d e  - 370a c d e
+--R                            + 
+--R                                    3 5 7
+--R                              - 112a c d e
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                           6 2 9      5 3 2 7       4 4 4 5       3 5 6 3  3
+--R                        (3a c e  + 78a c d e  + 195a c d e  + 112a c d e )f
+--R                      + 
+--R                                 5 3   9      4 4 3 7      3 5 5 5      2 6 7 3
+--R                            - 13a c d e  - 50a c d e  - 33a c d e  + 20a c d e
+--R                          + 
+--R                                 7 9
+--R                            16a c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                             5 3 11     4 4 2 9    3 5 4 7      2 6 6 5
+--R                            a c e   + 5a c d e  - a c d e  - 17a c d e
+--R                          + 
+--R                                   7 8 3     8 10
+--R                            - 16a c d e  - 4c d  e
+--R                       *
+--R                          f
+--R                      + 
+--R                         3 5 3 9     2 6 5 7       7 7 5    8 9 3
+--R                        a c d e  + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                          5 3   6         5 2 3      4   4   5
+--R                        8a d e f  + (- 14a d e  - 28a c d e)f
+--R                      + 
+--R                           5   5      4   3 3      3 2 5   4
+--R                        (7a d e  + 27a c d e  + 32a c d e)f
+--R                      + 
+--R                            5 7     4   2 5      3 2 4 3     2 3 6   3
+--R                        (- a e  - 5a c d e  - 12a c d e  - 8a c d e)f
+--R                      + 
+--R                          3 2 3 5     2 3 5 3       4 7   2
+--R                        (a c d e  - 2a c d e  - 8a c d e)f
+--R                      + 
+--R                          2 3 4 5       4 6 3     5 8       5 7 3
+--R                        (a c d e  + 2a c d e  + 4c d e)f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 2 2 6      6   4      5   3 2  5
+--R                                  - 4a d e f  + (4a d e  + 12a c d e )f
+--R                                + 
+--R                                      6 6     5   2 4     4 2 4 2  4
+--R                                  (- a e  - 6a c d e  - 9a c d e )f
+--R                                + 
+--R                                      3 3 5 2 3      3 3 4 4     2 4 6 2  2
+--R                                  - 4a c d e f  + (2a c d e  + 6a c d e )f
+--R                                + 
+--R                                     6 8 2
+--R                                  - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 2 4      3   2      2   3  3
+--R                         - 4a d f  + (8a d e  + 12a c d )f
+--R                       + 
+--R                              3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                         (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 4   4        3 3 3      2   5   3     3 7     |   2
+--R                (8a d e f  + (- 4a d e  - 12a c d e)f  + 4c d e f)\|c x  + a
+--R              + 
+--R                          6 3 8        6 2 2      5   4  7
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   3 2       4 2 5  6
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   2 4       4 2 4 2       3 3 6  5
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 3 4       3 3 5 2       2 4 7  4
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 2 6      3 3 4 4       2 4 6 2        5 8  3
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 3 6      2 4 5 4        5 7 2     6 9  2
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3 2 8     2 4 4 6       5 6 4     6 8 2
+--R                        (- 2a c d e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3 3 2 4      3 2 4     2   4 2  3     3 6 2
+--R                    (- 4a d e f  + (2a d e  + 6a c d e )f  - 2c d e f)x
+--R                  + 
+--R                        3 4   4      3 3 3      2   5   3     3 7
+--R                    - 8a d e f  + (4a d e  + 12a c d e)f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +--------+
+--R               2 2                   2    2 2  +-+ |   2
+--R           (- a f  + 2a c d f - a c e  - c d )\|a \|c x  + a
+--R         + 
+--R             2   2       2         2 2    3 2  2    3 2     2         2   2
+--R           (a c f  - 2a c d f + a c e  + c d )x  + a f  - 2a c d f + a c e
+--R         + 
+--R              2 2
+--R           a c d
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             6 2 2 6      6   4      5   3 2  5
+--R                         - 4a d e f  + (4a d e  + 12a c d e )f
+--R                       + 
+--R                             6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                         (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                       + 
+--R                            3 3 4 4     2 4 6 2  2    6 8 2
+--R                         (2a c d e  + 6a c d e )f  - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 2 4      3   2      2   3  3
+--R                - 4a d f  + (8a d e  + 12a c d )f
+--R              + 
+--R                     3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                           8 2   9        8   3      7   3   8
+--R                        12a d e f  + (- 7a d e  - 80a c d e)f
+--R                      + 
+--R                          8 5      7   2 3       6 2 4   7
+--R                        (a e  + 80a c d e  + 224a c d e)f
+--R                      + 
+--R                              7     5       6 2 3 3       5 3 5   6
+--R                        (- 27a c d e  - 284a c d e  - 336a c d e)f
+--R                      + 
+--R                           7   7       6 2 2 5       5 3 4 3       4 4 6   5
+--R                        (3a c e  + 141a c d e  + 464a c d e  + 280a c d e)f
+--R                      + 
+--R                                   6 2   7       5 3 3 5       4 4 5 3
+--R                              - 33a c d e  - 263a c d e  - 370a c d e
+--R                            + 
+--R                                    3 5 7
+--R                              - 112a c d e
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                           6 2 9      5 3 2 7       4 4 4 5       3 5 6 3  3
+--R                        (3a c e  + 78a c d e  + 195a c d e  + 112a c d e )f
+--R                      + 
+--R                                 5 3   9      4 4 3 7      3 5 5 5      2 6 7 3
+--R                            - 13a c d e  - 50a c d e  - 33a c d e  + 20a c d e
+--R                          + 
+--R                                 7 9
+--R                            16a c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                             5 3 11     4 4 2 9    3 5 4 7      2 6 6 5
+--R                            a c e   + 5a c d e  - a c d e  - 17a c d e
+--R                          + 
+--R                                   7 8 3     8 10
+--R                            - 16a c d e  - 4c d  e
+--R                       *
+--R                          f
+--R                      + 
+--R                         3 5 3 9     2 6 5 7       7 7 5    8 9 3
+--R                        a c d e  + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            5 3   6       5 2 3      4   4   5
+--R                        - 8a d e f  + (14a d e  + 28a c d e)f
+--R                      + 
+--R                             5   5      4   3 3      3 2 5   4
+--R                        (- 7a d e  - 27a c d e  - 32a c d e)f
+--R                      + 
+--R                          5 7     4   2 5      3 2 4 3     2 3 6   3
+--R                        (a e  + 5a c d e  + 12a c d e  + 8a c d e)f
+--R                      + 
+--R                            3 2 3 5     2 3 5 3       4 7   2
+--R                        (- a c d e  + 2a c d e  + 8a c d e)f
+--R                      + 
+--R                            2 3 4 5       4 6 3     5 8       5 7 3
+--R                        (- a c d e  - 2a c d e  - 4c d e)f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 2 2 6      6   4      5   3 2  5
+--R                                  - 4a d e f  + (4a d e  + 12a c d e )f
+--R                                + 
+--R                                      6 6     5   2 4     4 2 4 2  4
+--R                                  (- a e  - 6a c d e  - 9a c d e )f
+--R                                + 
+--R                                      3 3 5 2 3      3 3 4 4     2 4 6 2  2
+--R                                  - 4a c d e f  + (2a c d e  + 6a c d e )f
+--R                                + 
+--R                                     6 8 2
+--R                                  - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 2 4      3   2      2   3  3
+--R                         - 4a d f  + (8a d e  + 12a c d )f
+--R                       + 
+--R                              3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                         (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 4   4        3 3 3      2   5   3     3 7     |   2
+--R                (8a d e f  + (- 4a d e  - 12a c d e)f  + 4c d e f)\|c x  + a
+--R              + 
+--R                            6 3 8      6 2 2      5   4  7
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   3 2       4 2 5  6
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   2 4       4 2 4 2       3 3 6  5
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 3 4       3 3 5 2       2 4 7  4
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 2 6      3 3 4 4       2 4 6 2        5 8  3
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 3 6      2 4 5 4        5 7 2     6 9  2
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3 2 8     2 4 4 6       5 6 4     6 8 2
+--R                        (2a c d e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3 3 2 4      3 2 4     2   4 2  3     3 6 2
+--R                    (- 4a d e f  + (2a d e  + 6a c d e )f  - 2c d e f)x
+--R                  + 
+--R                        3 4   4      3 3 3      2   5   3     3 7
+--R                    - 8a d e f  + (4a d e  + 12a c d e)f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                 +--------+
+--R             2 2                   2    2 2  +-+ |   2
+--R           (a f  - 2a c d f + a c e  + c d )\|a \|c x  + a
+--R         + 
+--R               2   2       2         2 2    3 2  2    3 2     2         2   2
+--R           (- a c f  + 2a c d f - a c e  - c d )x  - a f  + 2a c d f - a c e
+--R         + 
+--R                2 2
+--R           - a c d
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             6 2 2 6      6   4      5   3 2  5
+--R                         - 4a d e f  + (4a d e  + 12a c d e )f
+--R                       + 
+--R                             6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                         (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                       + 
+--R                            3 3 4 4     2 4 6 2  2    6 8 2
+--R                         (2a c d e  + 6a c d e )f  - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 2 4      3   2      2   3  3
+--R                - 4a d f  + (8a d e  + 12a c d )f
+--R              + 
+--R                     3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                             8 2   9      8   3      7   3   8
+--R                        - 12a d e f  + (7a d e  + 80a c d e)f
+--R                      + 
+--R                            8 5      7   2 3       6 2 4   7
+--R                        (- a e  - 80a c d e  - 224a c d e)f
+--R                      + 
+--R                            7     5       6 2 3 3       5 3 5   6
+--R                        (27a c d e  + 284a c d e  + 336a c d e)f
+--R                      + 
+--R                             7   7       6 2 2 5       5 3 4 3       4 4 6   5
+--R                        (- 3a c e  - 141a c d e  - 464a c d e  - 280a c d e)f
+--R                      + 
+--R                            6 2   7       5 3 3 5       4 4 5 3       3 5 7   4
+--R                        (33a c d e  + 263a c d e  + 370a c d e  + 112a c d e)f
+--R                      + 
+--R                             6 2 9      5 3 2 7       4 4 4 5       3 5 6 3  3
+--R                        (- 3a c e  - 78a c d e  - 195a c d e  - 112a c d e )f
+--R                      + 
+--R                               5 3   9      4 4 3 7      3 5 5 5      2 6 7 3
+--R                            13a c d e  + 50a c d e  + 33a c d e  - 20a c d e
+--R                          + 
+--R                                   7 9
+--R                            - 16a c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               5 3 11     4 4 2 9    3 5 4 7      2 6 6 5
+--R                            - a c e   - 5a c d e  + a c d e  + 17a c d e
+--R                          + 
+--R                                 7 8 3     8 10
+--R                            16a c d e  + 4c d  e
+--R                       *
+--R                          f
+--R                      + 
+--R                           3 5 3 9     2 6 5 7       7 7 5    8 9 3
+--R                        - a c d e  - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                          5 3   6         5 2 3      4   4   5
+--R                        8a d e f  + (- 14a d e  - 28a c d e)f
+--R                      + 
+--R                           5   5      4   3 3      3 2 5   4
+--R                        (7a d e  + 27a c d e  + 32a c d e)f
+--R                      + 
+--R                            5 7     4   2 5      3 2 4 3     2 3 6   3
+--R                        (- a e  - 5a c d e  - 12a c d e  - 8a c d e)f
+--R                      + 
+--R                          3 2 3 5     2 3 5 3       4 7   2
+--R                        (a c d e  - 2a c d e  - 8a c d e)f
+--R                      + 
+--R                          2 3 4 5       4 6 3     5 8       5 7 3
+--R                        (a c d e  + 2a c d e  + 4c d e)f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 2 2 6      6   4      5   3 2  5
+--R                                  - 4a d e f  + (4a d e  + 12a c d e )f
+--R                                + 
+--R                                      6 6     5   2 4     4 2 4 2  4
+--R                                  (- a e  - 6a c d e  - 9a c d e )f
+--R                                + 
+--R                                      3 3 5 2 3      3 3 4 4     2 4 6 2  2
+--R                                  - 4a c d e f  + (2a c d e  + 6a c d e )f
+--R                                + 
+--R                                     6 8 2
+--R                                  - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 2 4      3   2      2   3  3
+--R                         - 4a d f  + (8a d e  + 12a c d )f
+--R                       + 
+--R                              3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                         (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 4   4        3 3 3      2   5   3     3 7     |   2
+--R                (8a d e f  + (- 4a d e  - 12a c d e)f  + 4c d e f)\|c x  + a
+--R              + 
+--R                            6 3 8      6 2 2      5   4  7
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   3 2       4 2 5  6
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   2 4       4 2 4 2       3 3 6  5
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 3 4       3 3 5 2       2 4 7  4
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 2 6      3 3 4 4       2 4 6 2        5 8  3
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 3 6      2 4 5 4        5 7 2     6 9  2
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3 2 8     2 4 4 6       5 6 4     6 8 2
+--R                        (2a c d e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3 3 2 4      3 2 4     2   4 2  3     3 6 2
+--R                    (- 4a d e f  + (2a d e  + 6a c d e )f  - 2c d e f)x
+--R                  + 
+--R                        3 4   4      3 3 3      2   5   3     3 7
+--R                    - 8a d e f  + (4a d e  + 12a c d e)f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +--------+
+--R               2 2                   2    2 2  +-+ |   2
+--R           (- a f  + 2a c d f - a c e  - c d )\|a \|c x  + a
+--R         + 
+--R             2   2       2         2 2    3 2  2    3 2     2         2   2
+--R           (a c f  - 2a c d f + a c e  + c d )x  + a f  - 2a c d f + a c e
+--R         + 
+--R              2 2
+--R           a c d
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             6 2 2 6      6   4      5   3 2  5
+--R                         - 4a d e f  + (4a d e  + 12a c d e )f
+--R                       + 
+--R                             6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                         (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                       + 
+--R                            3 3 4 4     2 4 6 2  2    6 8 2
+--R                         (2a c d e  + 6a c d e )f  - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 2 4      3   2      2   3  3
+--R                - 4a d f  + (8a d e  + 12a c d )f
+--R              + 
+--R                     3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                             8 2   9      8   3      7   3   8
+--R                        - 12a d e f  + (7a d e  + 80a c d e)f
+--R                      + 
+--R                            8 5      7   2 3       6 2 4   7
+--R                        (- a e  - 80a c d e  - 224a c d e)f
+--R                      + 
+--R                            7     5       6 2 3 3       5 3 5   6
+--R                        (27a c d e  + 284a c d e  + 336a c d e)f
+--R                      + 
+--R                             7   7       6 2 2 5       5 3 4 3       4 4 6   5
+--R                        (- 3a c e  - 141a c d e  - 464a c d e  - 280a c d e)f
+--R                      + 
+--R                            6 2   7       5 3 3 5       4 4 5 3       3 5 7   4
+--R                        (33a c d e  + 263a c d e  + 370a c d e  + 112a c d e)f
+--R                      + 
+--R                             6 2 9      5 3 2 7       4 4 4 5       3 5 6 3  3
+--R                        (- 3a c e  - 78a c d e  - 195a c d e  - 112a c d e )f
+--R                      + 
+--R                               5 3   9      4 4 3 7      3 5 5 5      2 6 7 3
+--R                            13a c d e  + 50a c d e  + 33a c d e  - 20a c d e
+--R                          + 
+--R                                   7 9
+--R                            - 16a c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               5 3 11     4 4 2 9    3 5 4 7      2 6 6 5
+--R                            - a c e   - 5a c d e  + a c d e  + 17a c d e
+--R                          + 
+--R                                 7 8 3     8 10
+--R                            16a c d e  + 4c d  e
+--R                       *
+--R                          f
+--R                      + 
+--R                           3 5 3 9     2 6 5 7       7 7 5    8 9 3
+--R                        - a c d e  - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            5 3   6       5 2 3      4   4   5
+--R                        - 8a d e f  + (14a d e  + 28a c d e)f
+--R                      + 
+--R                             5   5      4   3 3      3 2 5   4
+--R                        (- 7a d e  - 27a c d e  - 32a c d e)f
+--R                      + 
+--R                          5 7     4   2 5      3 2 4 3     2 3 6   3
+--R                        (a e  + 5a c d e  + 12a c d e  + 8a c d e)f
+--R                      + 
+--R                            3 2 3 5     2 3 5 3       4 7   2
+--R                        (- a c d e  + 2a c d e  + 8a c d e)f
+--R                      + 
+--R                            2 3 4 5       4 6 3     5 8       5 7 3
+--R                        (- a c d e  - 2a c d e  - 4c d e)f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 2 2 6      6   4      5   3 2  5
+--R                                  - 4a d e f  + (4a d e  + 12a c d e )f
+--R                                + 
+--R                                      6 6     5   2 4     4 2 4 2  4
+--R                                  (- a e  - 6a c d e  - 9a c d e )f
+--R                                + 
+--R                                      3 3 5 2 3      3 3 4 4     2 4 6 2  2
+--R                                  - 4a c d e f  + (2a c d e  + 6a c d e )f
+--R                                + 
+--R                                     6 8 2
+--R                                  - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 2 4      3   2      2   3  3
+--R                         - 4a d f  + (8a d e  + 12a c d )f
+--R                       + 
+--R                              3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                         (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 4   4        3 3 3      2   5   3     3 7     |   2
+--R                (8a d e f  + (- 4a d e  - 12a c d e)f  + 4c d e f)\|c x  + a
+--R              + 
+--R                          6 3 8        6 2 2      5   4  7
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   3 2       4 2 5  6
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   2 4       4 2 4 2       3 3 6  5
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 3 4       3 3 5 2       2 4 7  4
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 2 6      3 3 4 4       2 4 6 2        5 8  3
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 3 6      2 4 5 4        5 7 2     6 9  2
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3 2 8     2 4 4 6       5 6 4     6 8 2
+--R                        (- 2a c d e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3 3 2 4      3 2 4     2   4 2  3     3 6 2
+--R                    (- 4a d e f  + (2a d e  + 6a c d e )f  - 2c d e f)x
+--R                  + 
+--R                        3 4   4      3 3 3      2   5   3     3 7
+--R                    - 8a d e f  + (4a d e  + 12a c d e)f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                        +--------+
+--R                        |   2               2                   +-+
+--R       (- 2a f + 2c d)x\|c x  + a  + (2c e x  + (2a f - 2c d)x)\|a
+--R  /
+--R                                                +--------+
+--R          2 2                    2     2 2  +-+ |   2
+--R       (2a f  - 4a c d f + 2a c e  + 2c d )\|a \|c x  + a
+--R     + 
+--R            2   2       2          2 2     3 2  2     3 2     2          2   2
+--R       (- 2a c f  + 4a c d f - 2a c e  - 2c d )x  - 2a f  + 4a c d f - 2a c e
+--R     + 
+--R             2 2
+--R       - 2a c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 103
+
+--S 104 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +-----------+ +--------+
+--R             2 2                   2    2 2  +-+ |          2  |   2
+--R           (a f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                   +-----------+
+--R               2 2                   2    2 2  +-+ |          2  +-+
+--R           (- a f  + 2a c d f - a c e  - c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             6 2 2 6      6   4      5   3 2  5
+--R                         - 4a d e f  + (4a d e  + 12a c d e )f
+--R                       + 
+--R                             6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                         (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                       + 
+--R                            3 3 4 4     2 4 6 2  2    6 8 2
+--R                         (2a c d e  + 6a c d e )f  - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 2 4      3   2      2   3  3
+--R                - 4a d f  + (8a d e  + 12a c d )f
+--R              + 
+--R                     3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                           8 2   9        8   3      7   3   8
+--R                        12a d e f  + (- 7a d e  - 80a c d e)f
+--R                      + 
+--R                          8 5      7   2 3       6 2 4   7
+--R                        (a e  + 80a c d e  + 224a c d e)f
+--R                      + 
+--R                              7     5       6 2 3 3       5 3 5   6
+--R                        (- 27a c d e  - 284a c d e  - 336a c d e)f
+--R                      + 
+--R                           7   7       6 2 2 5       5 3 4 3       4 4 6   5
+--R                        (3a c e  + 141a c d e  + 464a c d e  + 280a c d e)f
+--R                      + 
+--R                                   6 2   7       5 3 3 5       4 4 5 3
+--R                              - 33a c d e  - 263a c d e  - 370a c d e
+--R                            + 
+--R                                    3 5 7
+--R                              - 112a c d e
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                           6 2 9      5 3 2 7       4 4 4 5       3 5 6 3  3
+--R                        (3a c e  + 78a c d e  + 195a c d e  + 112a c d e )f
+--R                      + 
+--R                                 5 3   9      4 4 3 7      3 5 5 5      2 6 7 3
+--R                            - 13a c d e  - 50a c d e  - 33a c d e  + 20a c d e
+--R                          + 
+--R                                 7 9
+--R                            16a c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                             5 3 11     4 4 2 9    3 5 4 7      2 6 6 5
+--R                            a c e   + 5a c d e  - a c d e  - 17a c d e
+--R                          + 
+--R                                   7 8 3     8 10
+--R                            - 16a c d e  - 4c d  e
+--R                       *
+--R                          f
+--R                      + 
+--R                         3 5 3 9     2 6 5 7       7 7 5    8 9 3
+--R                        a c d e  + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                          5 3   6         5 2 3      4   4   5
+--R                        8a d e f  + (- 14a d e  - 28a c d e)f
+--R                      + 
+--R                           5   5      4   3 3      3 2 5   4
+--R                        (7a d e  + 27a c d e  + 32a c d e)f
+--R                      + 
+--R                            5 7     4   2 5      3 2 4 3     2 3 6   3
+--R                        (- a e  - 5a c d e  - 12a c d e  - 8a c d e)f
+--R                      + 
+--R                          3 2 3 5     2 3 5 3       4 7   2
+--R                        (a c d e  - 2a c d e  - 8a c d e)f
+--R                      + 
+--R                          2 3 4 5       4 6 3     5 8       5 7 3
+--R                        (a c d e  + 2a c d e  + 4c d e)f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 2 2 6      6   4      5   3 2  5
+--R                                  - 4a d e f  + (4a d e  + 12a c d e )f
+--R                                + 
+--R                                      6 6     5   2 4     4 2 4 2  4
+--R                                  (- a e  - 6a c d e  - 9a c d e )f
+--R                                + 
+--R                                      3 3 5 2 3      3 3 4 4     2 4 6 2  2
+--R                                  - 4a c d e f  + (2a c d e  + 6a c d e )f
+--R                                + 
+--R                                     6 8 2
+--R                                  - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 2 4      3   2      2   3  3
+--R                         - 4a d f  + (8a d e  + 12a c d )f
+--R                       + 
+--R                              3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                         (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 4   4        3 3 3      2   5   3     3 7     |   2
+--R                (8a d e f  + (- 4a d e  - 12a c d e)f  + 4c d e f)\|c x  + a
+--R              + 
+--R                          6 3 8        6 2 2      5   4  7
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   3 2       4 2 5  6
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   2 4       4 2 4 2       3 3 6  5
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 3 4       3 3 5 2       2 4 7  4
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 2 6      3 3 4 4       2 4 6 2        5 8  3
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 3 6      2 4 5 4        5 7 2     6 9  2
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3 2 8     2 4 4 6       5 6 4     6 8 2
+--R                        (- 2a c d e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3 3 2 4      3 2 4     2   4 2  3     3 6 2
+--R                    (- 4a d e f  + (2a d e  + 6a c d e )f  - 2c d e f)x
+--R                  + 
+--R                        3 4   4      3 3 3      2   5   3     3 7
+--R                    - 8a d e f  + (4a d e  + 12a c d e)f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +-----------+ +--------+
+--R               2 2                   2    2 2  +-+ |          2  |   2
+--R           (- a f  + 2a c d f - a c e  - c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                 +-----------+
+--R             2 2                   2    2 2  +-+ |          2  +-+
+--R           (a f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             6 2 2 6      6   4      5   3 2  5
+--R                         - 4a d e f  + (4a d e  + 12a c d e )f
+--R                       + 
+--R                             6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                         (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                       + 
+--R                            3 3 4 4     2 4 6 2  2    6 8 2
+--R                         (2a c d e  + 6a c d e )f  - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 2 4      3   2      2   3  3
+--R                - 4a d f  + (8a d e  + 12a c d )f
+--R              + 
+--R                     3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                           8 2   9        8   3      7   3   8
+--R                        12a d e f  + (- 7a d e  - 80a c d e)f
+--R                      + 
+--R                          8 5      7   2 3       6 2 4   7
+--R                        (a e  + 80a c d e  + 224a c d e)f
+--R                      + 
+--R                              7     5       6 2 3 3       5 3 5   6
+--R                        (- 27a c d e  - 284a c d e  - 336a c d e)f
+--R                      + 
+--R                           7   7       6 2 2 5       5 3 4 3       4 4 6   5
+--R                        (3a c e  + 141a c d e  + 464a c d e  + 280a c d e)f
+--R                      + 
+--R                                   6 2   7       5 3 3 5       4 4 5 3
+--R                              - 33a c d e  - 263a c d e  - 370a c d e
+--R                            + 
+--R                                    3 5 7
+--R                              - 112a c d e
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                           6 2 9      5 3 2 7       4 4 4 5       3 5 6 3  3
+--R                        (3a c e  + 78a c d e  + 195a c d e  + 112a c d e )f
+--R                      + 
+--R                                 5 3   9      4 4 3 7      3 5 5 5      2 6 7 3
+--R                            - 13a c d e  - 50a c d e  - 33a c d e  + 20a c d e
+--R                          + 
+--R                                 7 9
+--R                            16a c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                             5 3 11     4 4 2 9    3 5 4 7      2 6 6 5
+--R                            a c e   + 5a c d e  - a c d e  - 17a c d e
+--R                          + 
+--R                                   7 8 3     8 10
+--R                            - 16a c d e  - 4c d  e
+--R                       *
+--R                          f
+--R                      + 
+--R                         3 5 3 9     2 6 5 7       7 7 5    8 9 3
+--R                        a c d e  + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            5 3   6       5 2 3      4   4   5
+--R                        - 8a d e f  + (14a d e  + 28a c d e)f
+--R                      + 
+--R                             5   5      4   3 3      3 2 5   4
+--R                        (- 7a d e  - 27a c d e  - 32a c d e)f
+--R                      + 
+--R                          5 7     4   2 5      3 2 4 3     2 3 6   3
+--R                        (a e  + 5a c d e  + 12a c d e  + 8a c d e)f
+--R                      + 
+--R                            3 2 3 5     2 3 5 3       4 7   2
+--R                        (- a c d e  + 2a c d e  + 8a c d e)f
+--R                      + 
+--R                            2 3 4 5       4 6 3     5 8       5 7 3
+--R                        (- a c d e  - 2a c d e  - 4c d e)f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 2 2 6      6   4      5   3 2  5
+--R                                  - 4a d e f  + (4a d e  + 12a c d e )f
+--R                                + 
+--R                                      6 6     5   2 4     4 2 4 2  4
+--R                                  (- a e  - 6a c d e  - 9a c d e )f
+--R                                + 
+--R                                      3 3 5 2 3      3 3 4 4     2 4 6 2  2
+--R                                  - 4a c d e f  + (2a c d e  + 6a c d e )f
+--R                                + 
+--R                                     6 8 2
+--R                                  - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 2 4      3   2      2   3  3
+--R                         - 4a d f  + (8a d e  + 12a c d )f
+--R                       + 
+--R                              3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                         (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 4   4        3 3 3      2   5   3     3 7     |   2
+--R                (8a d e f  + (- 4a d e  - 12a c d e)f  + 4c d e f)\|c x  + a
+--R              + 
+--R                            6 3 8      6 2 2      5   4  7
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   3 2       4 2 5  6
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   2 4       4 2 4 2       3 3 6  5
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 3 4       3 3 5 2       2 4 7  4
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 2 6      3 3 4 4       2 4 6 2        5 8  3
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 3 6      2 4 5 4        5 7 2     6 9  2
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3 2 8     2 4 4 6       5 6 4     6 8 2
+--R                        (2a c d e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3 3 2 4      3 2 4     2   4 2  3     3 6 2
+--R                    (- 4a d e f  + (2a d e  + 6a c d e )f  - 2c d e f)x
+--R                  + 
+--R                        3 4   4      3 3 3      2   5   3     3 7
+--R                    - 8a d e f  + (4a d e  + 12a c d e)f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                 +-----------+ +--------+
+--R             2 2                   2    2 2  +-+ |          2  |   2
+--R           (a f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                   +-----------+
+--R               2 2                   2    2 2  +-+ |          2  +-+
+--R           (- a f  + 2a c d f - a c e  - c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             6 2 2 6      6   4      5   3 2  5
+--R                         - 4a d e f  + (4a d e  + 12a c d e )f
+--R                       + 
+--R                             6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                         (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                       + 
+--R                            3 3 4 4     2 4 6 2  2    6 8 2
+--R                         (2a c d e  + 6a c d e )f  - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 2 4      3   2      2   3  3
+--R                - 4a d f  + (8a d e  + 12a c d )f
+--R              + 
+--R                     3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                             8 2   9      8   3      7   3   8
+--R                        - 12a d e f  + (7a d e  + 80a c d e)f
+--R                      + 
+--R                            8 5      7   2 3       6 2 4   7
+--R                        (- a e  - 80a c d e  - 224a c d e)f
+--R                      + 
+--R                            7     5       6 2 3 3       5 3 5   6
+--R                        (27a c d e  + 284a c d e  + 336a c d e)f
+--R                      + 
+--R                             7   7       6 2 2 5       5 3 4 3       4 4 6   5
+--R                        (- 3a c e  - 141a c d e  - 464a c d e  - 280a c d e)f
+--R                      + 
+--R                            6 2   7       5 3 3 5       4 4 5 3       3 5 7   4
+--R                        (33a c d e  + 263a c d e  + 370a c d e  + 112a c d e)f
+--R                      + 
+--R                             6 2 9      5 3 2 7       4 4 4 5       3 5 6 3  3
+--R                        (- 3a c e  - 78a c d e  - 195a c d e  - 112a c d e )f
+--R                      + 
+--R                               5 3   9      4 4 3 7      3 5 5 5      2 6 7 3
+--R                            13a c d e  + 50a c d e  + 33a c d e  - 20a c d e
+--R                          + 
+--R                                   7 9
+--R                            - 16a c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               5 3 11     4 4 2 9    3 5 4 7      2 6 6 5
+--R                            - a c e   - 5a c d e  + a c d e  + 17a c d e
+--R                          + 
+--R                                 7 8 3     8 10
+--R                            16a c d e  + 4c d  e
+--R                       *
+--R                          f
+--R                      + 
+--R                           3 5 3 9     2 6 5 7       7 7 5    8 9 3
+--R                        - a c d e  - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                          5 3   6         5 2 3      4   4   5
+--R                        8a d e f  + (- 14a d e  - 28a c d e)f
+--R                      + 
+--R                           5   5      4   3 3      3 2 5   4
+--R                        (7a d e  + 27a c d e  + 32a c d e)f
+--R                      + 
+--R                            5 7     4   2 5      3 2 4 3     2 3 6   3
+--R                        (- a e  - 5a c d e  - 12a c d e  - 8a c d e)f
+--R                      + 
+--R                          3 2 3 5     2 3 5 3       4 7   2
+--R                        (a c d e  - 2a c d e  - 8a c d e)f
+--R                      + 
+--R                          2 3 4 5       4 6 3     5 8       5 7 3
+--R                        (a c d e  + 2a c d e  + 4c d e)f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 2 2 6      6   4      5   3 2  5
+--R                                  - 4a d e f  + (4a d e  + 12a c d e )f
+--R                                + 
+--R                                      6 6     5   2 4     4 2 4 2  4
+--R                                  (- a e  - 6a c d e  - 9a c d e )f
+--R                                + 
+--R                                      3 3 5 2 3      3 3 4 4     2 4 6 2  2
+--R                                  - 4a c d e f  + (2a c d e  + 6a c d e )f
+--R                                + 
+--R                                     6 8 2
+--R                                  - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 2 4      3   2      2   3  3
+--R                         - 4a d f  + (8a d e  + 12a c d )f
+--R                       + 
+--R                              3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                         (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 4   4        3 3 3      2   5   3     3 7     |   2
+--R                (8a d e f  + (- 4a d e  - 12a c d e)f  + 4c d e f)\|c x  + a
+--R              + 
+--R                            6 3 8      6 2 2      5   4  7
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   3 2       4 2 5  6
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   2 4       4 2 4 2       3 3 6  5
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 3 4       3 3 5 2       2 4 7  4
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 2 6      3 3 4 4       2 4 6 2        5 8  3
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 3 6      2 4 5 4        5 7 2     6 9  2
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3 2 8     2 4 4 6       5 6 4     6 8 2
+--R                        (2a c d e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3 3 2 4      3 2 4     2   4 2  3     3 6 2
+--R                    (- 4a d e f  + (2a d e  + 6a c d e )f  - 2c d e f)x
+--R                  + 
+--R                        3 4   4      3 3 3      2   5   3     3 7
+--R                    - 8a d e f  + (4a d e  + 12a c d e)f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +-----------+ +--------+
+--R               2 2                   2    2 2  +-+ |          2  |   2
+--R           (- a f  + 2a c d f - a c e  - c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                 +-----------+
+--R             2 2                   2    2 2  +-+ |          2  +-+
+--R           (a f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             6 2 2 6      6   4      5   3 2  5
+--R                         - 4a d e f  + (4a d e  + 12a c d e )f
+--R                       + 
+--R                             6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                         (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                       + 
+--R                            3 3 4 4     2 4 6 2  2    6 8 2
+--R                         (2a c d e  + 6a c d e )f  - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 2 4      3   2      2   3  3
+--R                - 4a d f  + (8a d e  + 12a c d )f
+--R              + 
+--R                     3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                             8 2   9      8   3      7   3   8
+--R                        - 12a d e f  + (7a d e  + 80a c d e)f
+--R                      + 
+--R                            8 5      7   2 3       6 2 4   7
+--R                        (- a e  - 80a c d e  - 224a c d e)f
+--R                      + 
+--R                            7     5       6 2 3 3       5 3 5   6
+--R                        (27a c d e  + 284a c d e  + 336a c d e)f
+--R                      + 
+--R                             7   7       6 2 2 5       5 3 4 3       4 4 6   5
+--R                        (- 3a c e  - 141a c d e  - 464a c d e  - 280a c d e)f
+--R                      + 
+--R                            6 2   7       5 3 3 5       4 4 5 3       3 5 7   4
+--R                        (33a c d e  + 263a c d e  + 370a c d e  + 112a c d e)f
+--R                      + 
+--R                             6 2 9      5 3 2 7       4 4 4 5       3 5 6 3  3
+--R                        (- 3a c e  - 78a c d e  - 195a c d e  - 112a c d e )f
+--R                      + 
+--R                               5 3   9      4 4 3 7      3 5 5 5      2 6 7 3
+--R                            13a c d e  + 50a c d e  + 33a c d e  - 20a c d e
+--R                          + 
+--R                                   7 9
+--R                            - 16a c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               5 3 11     4 4 2 9    3 5 4 7      2 6 6 5
+--R                            - a c e   - 5a c d e  + a c d e  + 17a c d e
+--R                          + 
+--R                                 7 8 3     8 10
+--R                            16a c d e  + 4c d  e
+--R                       *
+--R                          f
+--R                      + 
+--R                           3 5 3 9     2 6 5 7       7 7 5    8 9 3
+--R                        - a c d e  - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            5 3   6       5 2 3      4   4   5
+--R                        - 8a d e f  + (14a d e  + 28a c d e)f
+--R                      + 
+--R                             5   5      4   3 3      3 2 5   4
+--R                        (- 7a d e  - 27a c d e  - 32a c d e)f
+--R                      + 
+--R                          5 7     4   2 5      3 2 4 3     2 3 6   3
+--R                        (a e  + 5a c d e  + 12a c d e  + 8a c d e)f
+--R                      + 
+--R                            3 2 3 5     2 3 5 3       4 7   2
+--R                        (- a c d e  + 2a c d e  + 8a c d e)f
+--R                      + 
+--R                            2 3 4 5       4 6 3     5 8       5 7 3
+--R                        (- a c d e  - 2a c d e  - 4c d e)f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      6 2 2 6      6   4      5   3 2  5
+--R                                  - 4a d e f  + (4a d e  + 12a c d e )f
+--R                                + 
+--R                                      6 6     5   2 4     4 2 4 2  4
+--R                                  (- a e  - 6a c d e  - 9a c d e )f
+--R                                + 
+--R                                      3 3 5 2 3      3 3 4 4     2 4 6 2  2
+--R                                  - 4a c d e f  + (2a c d e  + 6a c d e )f
+--R                                + 
+--R                                     6 8 2
+--R                                  - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 2 4      3   2      2   3  3
+--R                         - 4a d f  + (8a d e  + 12a c d )f
+--R                       + 
+--R                              3 4     2   2 2        2 4  2     3 5      3 4 2
+--R                         (- 2a e  - 6a c d e  - 12a c d )f  + 4c d f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 4   4        3 3 3      2   5   3     3 7     |   2
+--R                (8a d e f  + (- 4a d e  - 12a c d e)f  + 4c d e f)\|c x  + a
+--R              + 
+--R                          6 3 8        6 2 2      5   4  7
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   3 2       4 2 5  6
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   2 4       4 2 4 2       3 3 6  5
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 3 4       3 3 5 2       2 4 7  4
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 2 6      3 3 4 4       2 4 6 2        5 8  3
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 3 6      2 4 5 4        5 7 2     6 9  2
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3 2 8     2 4 4 6       5 6 4     6 8 2
+--R                        (- 2a c d e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 6 2 2 6      6   4      5   3 2  5
+--R                             - 4a d e f  + (4a d e  + 12a c d e )f
+--R                           + 
+--R                                 6 6     5   2 4     4 2 4 2  4     3 3 5 2 3
+--R                             (- a e  - 6a c d e  - 9a c d e )f  - 4a c d e f
+--R                           + 
+--R                                3 3 4 4     2 4 6 2  2    6 8 2
+--R                             (2a c d e  + 6a c d e )f  - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3 3 2 4      3 2 4     2   4 2  3     3 6 2
+--R                    (- 4a d e f  + (2a d e  + 6a c d e )f  - 2c d e f)x
+--R                  + 
+--R                        3 4   4      3 3 3      2   5   3     3 7
+--R                    - 8a d e f  + (4a d e  + 12a c d e)f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                     +-----------+                               +--------+
+--R                     |          2          2        2       2    |   2
+--R           (- 2a e f\|- 4d f + e   - 4a d f  + (2a e  + 4c d )f)\|c x  + a
+--R         + 
+--R                   +-----------+
+--R                   |          2          2          2       2    +-+
+--R           (2a e f\|- 4d f + e   + 4a d f  + (- 2a e  - 4c d )f)\|a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                   +-----------+                               +--------+
+--R                   |          2          2        2       2    |   2
+--R           (2a e f\|- 4d f + e   - 4a d f  + (2a e  + 4c d )f)\|c x  + a
+--R         + 
+--R                     +-----------+
+--R                     |          2          2          2       2    +-+
+--R           (- 2a e f\|- 4d f + e   + 4a d f  + (- 2a e  - 4c d )f)\|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                   +-----------+     +--------+            +-----------+
+--R               +-+ |          2  +-+ |   2             +-+ |          2
+--R         (- 2e\|2 \|- 4d f + e  \|a \|c x  + a  + 2a e\|2 \|- 4d f + e  )
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                                  +-----------+ +--------+
+--R            2 2                    2     2 2  +-+ |          2  |   2
+--R         (2a f  - 4a c d f + 2a c e  + 2c d )\|2 \|- 4d f + e  \|c x  + a
+--R       + 
+--R                                                    +-----------+
+--R              2 2                    2     2 2  +-+ |          2  +-+
+--R         (- 2a f  + 4a c d f - 2a c e  - 2c d )\|2 \|- 4d f + e  \|a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 1580
+--d0:=D(m0,x)
+--E 105
+
+)clear all
+
+--S 106 of 1580
+t0:=x/((a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                     x
+--R   (1)  ----------------------------------------------------------
+--R                                                        +--------+
+--R              4        3               2                |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x + a d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 1580
+r0:=(-c*d+a*f+c*e*x)/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(a+c*x^2))+_
+   f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*c*d*e-(c*d-a*f)*_
+   (e-sqrt(e^2-4*d*f)))/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-_
+   f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*c*d*e-(c*d-a*f)*_
+   (e+sqrt(e^2-4*d*f)))/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                           +-----------+                     +--------+
+--R                2          |          2         2            |   2
+--R         ((- a f  + c d f)\|- 4d f + e   + a e f  + c d e f)\|c x  + a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                         +-----------+                     +--------+
+--R              2          |          2         2            |   2
+--R         ((a f  - c d f)\|- 4d f + e   + a e f  + c d e f)\|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                 +-----------+
+--R                             +-+ |          2
+--R         (c e x + a f - c d)\|2 \|- 4d f + e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                             +-----------+ +--------+
+--R         2 2                   2    2 2  +-+ |          2  |   2
+--R       (a f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                   +--------+
+--R             3 2     2         2   2      2 2  +-+ |   2
+--R           (a f  - 2a c d f + a c e  + a c d )\|a \|c x  + a
+--R         + 
+--R               3   2     2 2       2 2 2      3 2  2    4 2     3         3   2
+--R           (- a c f  + 2a c d f - a c e  - a c d )x  - a f  + 2a c d f - a c e
+--R         + 
+--R              2 2 2
+--R           - a c d
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                            6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                         - a e f  + 6a c d e f  - 4a c d e f
+--R                       + 
+--R                            3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                         (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                       + 
+--R                                5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                         (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3   5        3 2      2   2  4        2 3 3
+--R                4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R              + 
+--R                       2 2 2     3 4  2     3 3 2      3 2 4
+--R                (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                          8 2 10        8   2      7   3  9
+--R                        8a d f   + (- 6a d e  - 64a c d )f
+--R                      + 
+--R                          8 4      7   2 2       6 2 4  8
+--R                        (a e  + 64a c d e  + 224a c d )f
+--R                      + 
+--R                              7     4       6 2 3 2       5 3 5  7
+--R                        (- 24a c d e  - 264a c d e  - 448a c d )f
+--R                      + 
+--R                           7   6       6 2 2 4       5 3 4 2       4 4 6  6
+--R                        (3a c e  + 124a c d e  + 576a c d e  + 560a c d )f
+--R                      + 
+--R                              6 2   6       5 3 3 4       4 4 5 2       3 5 7  5
+--R                        (- 30a c d e  - 296a c d e  - 740a c d e  - 448a c d )f
+--R                      + 
+--R                              6 2 8      5 3 2 6       4 4 4 4       3 5 6 2
+--R                            3a c e  + 77a c d e  + 390a c d e  + 576a c d e
+--R                          + 
+--R                                2 6 8
+--R                            224a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                                 5 3   8       4 4 3 6       3 5 5 4
+--R                            - 12a c d e  - 100a c d e  - 296a c d e
+--R                          + 
+--R                                  2 6 7 2        7 9
+--R                            - 264a c d e  - 64a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                             5 3 10      4 4 2 8      3 5 4 6       2 6 6 4
+--R                            a c e   + 10a c d e  + 77a c d e  + 124a c d e
+--R                          + 
+--R                                 7 8 2     8 10
+--R                            64a c d e  + 8c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                              3 5 3 8      2 6 5 6        7 7 4     8 9 2
+--R                        (- 12a c d e  - 30a c d e  - 24a c d e  - 6c d e )f
+--R                      + 
+--R                         3 5 2 10     2 6 4 8       7 6 6    8 8 4
+--R                        a c d e   + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                          5   2 7    5 4 6      3 2 3 2 5
+--R                        4a d e f  - a e f  - 16a c d e f
+--R                      + 
+--R                           3 2 2 4     2 3 4 2  4        2 3 3 4        4 5 2  3
+--R                        (4a c d e  + 8a c d e )f  + (- 6a c d e  + 12a c d e )f
+--R                      + 
+--R                          2 3 2 6       4 4 4     5 6 2  2     5 5 4     5 4 6
+--R                        (a c d e  - 3a c d e  - 8c d e )f  + 6c d e f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                     6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                                  - a e f  + 6a c d e f  - 4a c d e f
+--R                                + 
+--R                                     3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                                  (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                                + 
+--R                                         5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                                  (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3   5        3 2      2   2  4        2 3 3
+--R                         4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R                       + 
+--R                                2 2 2     3 4  2     3 3 2      3 2 4
+--R                         (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 2   6        2 4   4     3 5   3     3 4 3 2  |   2
+--R                (4a d e f  - 12a c d e f  + 8c d e f  - 4c d e f )\|c x  + a
+--R              + 
+--R                            6 2 9      6   2      5   3  8
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   2 2       4 2 4  7
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5     4       4 2 3 2       3 3 5  6
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 2 4       3 3 4 2       2 4 6  5
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2   6      3 3 3 4       2 4 5 2        5 7  4
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 2 6      2 4 4 4        5 6 2     6 8  3
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3   8     2 4 3 6       5 5 4     6 7 2  2
+--R                        (2a c d e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3   2 6       2 3 2 4     3 4 2 3     3 3 4 2
+--R                    (- 2a d e f  + 6a c d e f  - 4c d e f  + 2c d e f )x
+--R                  + 
+--R                        3 2   6        2 4   4     3 5   3     3 4 3 2
+--R                    - 4a d e f  + 12a c d e f  - 8c d e f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                     +--------+
+--R               3 2     2         2   2      2 2  +-+ |   2
+--R           (- a f  + 2a c d f - a c e  - a c d )\|a \|c x  + a
+--R         + 
+--R             3   2     2 2       2 2 2      3 2  2    4 2     3         3   2
+--R           (a c f  - 2a c d f + a c e  + a c d )x  + a f  - 2a c d f + a c e
+--R         + 
+--R            2 2 2
+--R           a c d
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                            6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                         - a e f  + 6a c d e f  - 4a c d e f
+--R                       + 
+--R                            3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                         (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                       + 
+--R                                5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                         (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3   5        3 2      2   2  4        2 3 3
+--R                4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R              + 
+--R                       2 2 2     3 4  2     3 3 2      3 2 4
+--R                (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                          8 2 10        8   2      7   3  9
+--R                        8a d f   + (- 6a d e  - 64a c d )f
+--R                      + 
+--R                          8 4      7   2 2       6 2 4  8
+--R                        (a e  + 64a c d e  + 224a c d )f
+--R                      + 
+--R                              7     4       6 2 3 2       5 3 5  7
+--R                        (- 24a c d e  - 264a c d e  - 448a c d )f
+--R                      + 
+--R                           7   6       6 2 2 4       5 3 4 2       4 4 6  6
+--R                        (3a c e  + 124a c d e  + 576a c d e  + 560a c d )f
+--R                      + 
+--R                              6 2   6       5 3 3 4       4 4 5 2       3 5 7  5
+--R                        (- 30a c d e  - 296a c d e  - 740a c d e  - 448a c d )f
+--R                      + 
+--R                              6 2 8      5 3 2 6       4 4 4 4       3 5 6 2
+--R                            3a c e  + 77a c d e  + 390a c d e  + 576a c d e
+--R                          + 
+--R                                2 6 8
+--R                            224a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                                 5 3   8       4 4 3 6       3 5 5 4
+--R                            - 12a c d e  - 100a c d e  - 296a c d e
+--R                          + 
+--R                                  2 6 7 2        7 9
+--R                            - 264a c d e  - 64a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                             5 3 10      4 4 2 8      3 5 4 6       2 6 6 4
+--R                            a c e   + 10a c d e  + 77a c d e  + 124a c d e
+--R                          + 
+--R                                 7 8 2     8 10
+--R                            64a c d e  + 8c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                              3 5 3 8      2 6 5 6        7 7 4     8 9 2
+--R                        (- 12a c d e  - 30a c d e  - 24a c d e  - 6c d e )f
+--R                      + 
+--R                         3 5 2 10     2 6 4 8       7 6 6    8 8 4
+--R                        a c d e   + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            5   2 7    5 4 6      3 2 3 2 5
+--R                        - 4a d e f  + a e f  + 16a c d e f
+--R                      + 
+--R                             3 2 2 4     2 3 4 2  4      2 3 3 4        4 5 2  3
+--R                        (- 4a c d e  - 8a c d e )f  + (6a c d e  - 12a c d e )f
+--R                      + 
+--R                          2 3 2 6       4 4 4     5 6 2  2     5 5 4     5 4 6
+--R                      (- a c d e  + 3a c d e  + 8c d e )f  - 6c d e f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                     6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                                  - a e f  + 6a c d e f  - 4a c d e f
+--R                                + 
+--R                                     3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                                  (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                                + 
+--R                                         5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                                  (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3   5        3 2      2   2  4        2 3 3
+--R                         4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R                       + 
+--R                                2 2 2     3 4  2     3 3 2      3 2 4
+--R                         (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 2   6        2 4   4     3 5   3     3 4 3 2  |   2
+--R                (4a d e f  - 12a c d e f  + 8c d e f  - 4c d e f )\|c x  + a
+--R              + 
+--R                          6 2 9        6   2      5   3  8
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   2 2       4 2 4  7
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5     4       4 2 3 2       3 3 5  6
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 2 4       3 3 4 2       2 4 6  5
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2   6      3 3 3 4       2 4 5 2        5 7  4
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 2 6      2 4 4 4        5 6 2     6 8  3
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3   8     2 4 3 6       5 5 4     6 7 2  2
+--R                        (- 2a c d e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3   2 6       2 3 2 4     3 4 2 3     3 3 4 2
+--R                    (- 2a d e f  + 6a c d e f  - 4c d e f  + 2c d e f )x
+--R                  + 
+--R                        3 2   6        2 4   4     3 5   3     3 4 3 2
+--R                    - 4a d e f  + 12a c d e f  - 8c d e f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +--------+
+--R             3 2     2         2   2      2 2  +-+ |   2
+--R           (a f  - 2a c d f + a c e  + a c d )\|a \|c x  + a
+--R         + 
+--R               3   2     2 2       2 2 2      3 2  2    4 2     3         3   2
+--R           (- a c f  + 2a c d f - a c e  - a c d )x  - a f  + 2a c d f - a c e
+--R         + 
+--R              2 2 2
+--R           - a c d
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                            6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                         - a e f  + 6a c d e f  - 4a c d e f
+--R                       + 
+--R                            3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                         (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                       + 
+--R                                5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                         (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3   5        3 2      2   2  4        2 3 3
+--R                4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R              + 
+--R                       2 2 2     3 4  2     3 3 2      3 2 4
+--R                (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                            8 2 10      8   2      7   3  9
+--R                        - 8a d f   + (6a d e  + 64a c d )f
+--R                      + 
+--R                            8 4      7   2 2       6 2 4  8
+--R                        (- a e  - 64a c d e  - 224a c d )f
+--R                      + 
+--R                            7     4       6 2 3 2       5 3 5  7
+--R                        (24a c d e  + 264a c d e  + 448a c d )f
+--R                      + 
+--R                             7   6       6 2 2 4       5 3 4 2       4 4 6  6
+--R                        (- 3a c e  - 124a c d e  - 576a c d e  - 560a c d )f
+--R                      + 
+--R                            6 2   6       5 3 3 4       4 4 5 2       3 5 7  5
+--R                        (30a c d e  + 296a c d e  + 740a c d e  + 448a c d )f
+--R                      + 
+--R                                6 2 8      5 3 2 6       4 4 4 4       3 5 6 2
+--R                            - 3a c e  - 77a c d e  - 390a c d e  - 576a c d e
+--R                          + 
+--R                                  2 6 8
+--R                            - 224a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                               5 3   8       4 4 3 6       3 5 5 4       2 6 7 2
+--R                            12a c d e  + 100a c d e  + 296a c d e  + 264a c d e
+--R                          + 
+--R                                 7 9
+--R                            64a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                               5 3 10      4 4 2 8      3 5 4 6       2 6 6 4
+--R                            - a c e   - 10a c d e  - 77a c d e  - 124a c d e
+--R                          + 
+--R                                   7 8 2     8 10
+--R                            - 64a c d e  - 8c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                            3 5 3 8      2 6 5 6        7 7 4     8 9 2
+--R                        (12a c d e  + 30a c d e  + 24a c d e  + 6c d e )f
+--R                      + 
+--R                           3 5 2 10     2 6 4 8       7 6 6    8 8 4
+--R                        - a c d e   - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                          5   2 7    5 4 6      3 2 3 2 5
+--R                        4a d e f  - a e f  - 16a c d e f
+--R                      + 
+--R                           3 2 2 4     2 3 4 2  4        2 3 3 4        4 5 2  3
+--R                        (4a c d e  + 8a c d e )f  + (- 6a c d e  + 12a c d e )f
+--R                      + 
+--R                          2 3 2 6       4 4 4     5 6 2  2     5 5 4     5 4 6
+--R                        (a c d e  - 3a c d e  - 8c d e )f  + 6c d e f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                     6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                                  - a e f  + 6a c d e f  - 4a c d e f
+--R                                + 
+--R                                     3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                                  (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                                + 
+--R                                         5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                                  (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3   5        3 2      2   2  4        2 3 3
+--R                         4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R                       + 
+--R                                2 2 2     3 4  2     3 3 2      3 2 4
+--R                         (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 2   6        2 4   4     3 5   3     3 4 3 2  |   2
+--R                (4a d e f  - 12a c d e f  + 8c d e f  - 4c d e f )\|c x  + a
+--R              + 
+--R                          6 2 9        6   2      5   3  8
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   2 2       4 2 4  7
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5     4       4 2 3 2       3 3 5  6
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 2 4       3 3 4 2       2 4 6  5
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2   6      3 3 3 4       2 4 5 2        5 7  4
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 2 6      2 4 4 4        5 6 2     6 8  3
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3   8     2 4 3 6       5 5 4     6 7 2  2
+--R                        (- 2a c d e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3   2 6       2 3 2 4     3 4 2 3     3 3 4 2
+--R                    (- 2a d e f  + 6a c d e f  - 4c d e f  + 2c d e f )x
+--R                  + 
+--R                        3 2   6        2 4   4     3 5   3     3 4 3 2
+--R                    - 4a d e f  + 12a c d e f  - 8c d e f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                     +--------+
+--R               3 2     2         2   2      2 2  +-+ |   2
+--R           (- a f  + 2a c d f - a c e  - a c d )\|a \|c x  + a
+--R         + 
+--R             3   2     2 2       2 2 2      3 2  2    4 2     3         3   2
+--R           (a c f  - 2a c d f + a c e  + a c d )x  + a f  - 2a c d f + a c e
+--R         + 
+--R            2 2 2
+--R           a c d
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                            6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                         - a e f  + 6a c d e f  - 4a c d e f
+--R                       + 
+--R                            3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                         (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                       + 
+--R                                5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                         (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3   5        3 2      2   2  4        2 3 3
+--R                4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R              + 
+--R                       2 2 2     3 4  2     3 3 2      3 2 4
+--R                (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                            8 2 10      8   2      7   3  9
+--R                        - 8a d f   + (6a d e  + 64a c d )f
+--R                      + 
+--R                            8 4      7   2 2       6 2 4  8
+--R                        (- a e  - 64a c d e  - 224a c d )f
+--R                      + 
+--R                            7     4       6 2 3 2       5 3 5  7
+--R                        (24a c d e  + 264a c d e  + 448a c d )f
+--R                      + 
+--R                             7   6       6 2 2 4       5 3 4 2       4 4 6  6
+--R                        (- 3a c e  - 124a c d e  - 576a c d e  - 560a c d )f
+--R                      + 
+--R                            6 2   6       5 3 3 4       4 4 5 2       3 5 7  5
+--R                        (30a c d e  + 296a c d e  + 740a c d e  + 448a c d )f
+--R                      + 
+--R                                6 2 8      5 3 2 6       4 4 4 4       3 5 6 2
+--R                            - 3a c e  - 77a c d e  - 390a c d e  - 576a c d e
+--R                          + 
+--R                                  2 6 8
+--R                            - 224a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                               5 3   8       4 4 3 6       3 5 5 4       2 6 7 2
+--R                            12a c d e  + 100a c d e  + 296a c d e  + 264a c d e
+--R                          + 
+--R                                 7 9
+--R                            64a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                               5 3 10      4 4 2 8      3 5 4 6       2 6 6 4
+--R                            - a c e   - 10a c d e  - 77a c d e  - 124a c d e
+--R                          + 
+--R                                   7 8 2     8 10
+--R                            - 64a c d e  - 8c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                            3 5 3 8      2 6 5 6        7 7 4     8 9 2
+--R                        (12a c d e  + 30a c d e  + 24a c d e  + 6c d e )f
+--R                      + 
+--R                           3 5 2 10     2 6 4 8       7 6 6    8 8 4
+--R                        - a c d e   - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            5   2 7    5 4 6      3 2 3 2 5
+--R                        - 4a d e f  + a e f  + 16a c d e f
+--R                      + 
+--R                             3 2 2 4     2 3 4 2  4      2 3 3 4        4 5 2  3
+--R                        (- 4a c d e  - 8a c d e )f  + (6a c d e  - 12a c d e )f
+--R                      + 
+--R                          2 3 2 6       4 4 4     5 6 2  2     5 5 4     5 4 6
+--R                      (- a c d e  + 3a c d e  + 8c d e )f  - 6c d e f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                     6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                                  - a e f  + 6a c d e f  - 4a c d e f
+--R                                + 
+--R                                     3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                                  (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                                + 
+--R                                         5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                                  (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3   5        3 2      2   2  4        2 3 3
+--R                         4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R                       + 
+--R                                2 2 2     3 4  2     3 3 2      3 2 4
+--R                         (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 2   6        2 4   4     3 5   3     3 4 3 2  |   2
+--R                (4a d e f  - 12a c d e f  + 8c d e f  - 4c d e f )\|c x  + a
+--R              + 
+--R                            6 2 9      6   2      5   3  8
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   2 2       4 2 4  7
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5     4       4 2 3 2       3 3 5  6
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 2 4       3 3 4 2       2 4 6  5
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2   6      3 3 3 4       2 4 5 2        5 7  4
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 2 6      2 4 4 4        5 6 2     6 8  3
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3   8     2 4 3 6       5 5 4     6 7 2  2
+--R                        (2a c d e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3   2 6       2 3 2 4     3 4 2 3     3 3 4 2
+--R                    (- 2a d e f  + 6a c d e f  - 4c d e f  + 2c d e f )x
+--R                  + 
+--R                        3 2   6        2 4   4     3 5   3     3 4 3 2
+--R                    - 4a d e f  + 12a c d e f  - 8c d e f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                  +--------+
+--R                  |   2                       2   2             +-+
+--R       - 2a c e x\|c x  + a  + ((- 2a c f + 2c d)x  + 2a c e x)\|a
+--R  /
+--R                                                  +--------+
+--R          3 2     2          2   2       2 2  +-+ |   2
+--R       (2a f  - 4a c d f + 2a c e  + 2a c d )\|a \|c x  + a
+--R     + 
+--R            3   2     2 2        2 2 2       3 2  2     4 2     3          3   2
+--R       (- 2a c f  + 4a c d f - 2a c e  - 2a c d )x  - 2a f  + 4a c d f - 2a c e
+--R     + 
+--R           2 2 2
+--R       - 2a c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 108
+
+--S 109 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                   +-----------+ +--------+
+--R             3 2     2         2   2      2 2  +-+ |          2  |   2
+--R           (a f  - 2a c d f + a c e  + a c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                     +-----------+
+--R               3 2     2         2   2      2 2  +-+ |          2  +-+
+--R           (- a f  + 2a c d f - a c e  - a c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                            6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                         - a e f  + 6a c d e f  - 4a c d e f
+--R                       + 
+--R                            3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                         (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                       + 
+--R                                5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                         (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3   5        3 2      2   2  4        2 3 3
+--R                4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R              + 
+--R                       2 2 2     3 4  2     3 3 2      3 2 4
+--R                (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                          8 2 10        8   2      7   3  9
+--R                        8a d f   + (- 6a d e  - 64a c d )f
+--R                      + 
+--R                          8 4      7   2 2       6 2 4  8
+--R                        (a e  + 64a c d e  + 224a c d )f
+--R                      + 
+--R                              7     4       6 2 3 2       5 3 5  7
+--R                        (- 24a c d e  - 264a c d e  - 448a c d )f
+--R                      + 
+--R                           7   6       6 2 2 4       5 3 4 2       4 4 6  6
+--R                        (3a c e  + 124a c d e  + 576a c d e  + 560a c d )f
+--R                      + 
+--R                              6 2   6       5 3 3 4       4 4 5 2       3 5 7  5
+--R                        (- 30a c d e  - 296a c d e  - 740a c d e  - 448a c d )f
+--R                      + 
+--R                              6 2 8      5 3 2 6       4 4 4 4       3 5 6 2
+--R                            3a c e  + 77a c d e  + 390a c d e  + 576a c d e
+--R                          + 
+--R                                2 6 8
+--R                            224a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                                 5 3   8       4 4 3 6       3 5 5 4
+--R                            - 12a c d e  - 100a c d e  - 296a c d e
+--R                          + 
+--R                                  2 6 7 2        7 9
+--R                            - 264a c d e  - 64a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                             5 3 10      4 4 2 8      3 5 4 6       2 6 6 4
+--R                            a c e   + 10a c d e  + 77a c d e  + 124a c d e
+--R                          + 
+--R                                 7 8 2     8 10
+--R                            64a c d e  + 8c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                              3 5 3 8      2 6 5 6        7 7 4     8 9 2
+--R                        (- 12a c d e  - 30a c d e  - 24a c d e  - 6c d e )f
+--R                      + 
+--R                         3 5 2 10     2 6 4 8       7 6 6    8 8 4
+--R                        a c d e   + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                          5   2 7    5 4 6      3 2 3 2 5
+--R                        4a d e f  - a e f  - 16a c d e f
+--R                      + 
+--R                           3 2 2 4     2 3 4 2  4        2 3 3 4        4 5 2  3
+--R                        (4a c d e  + 8a c d e )f  + (- 6a c d e  + 12a c d e )f
+--R                      + 
+--R                          2 3 2 6       4 4 4     5 6 2  2     5 5 4     5 4 6
+--R                        (a c d e  - 3a c d e  - 8c d e )f  + 6c d e f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                     6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                                  - a e f  + 6a c d e f  - 4a c d e f
+--R                                + 
+--R                                     3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                                  (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                                + 
+--R                                         5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                                  (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3   5        3 2      2   2  4        2 3 3
+--R                         4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R                       + 
+--R                                2 2 2     3 4  2     3 3 2      3 2 4
+--R                         (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 2   6        2 4   4     3 5   3     3 4 3 2  |   2
+--R                (4a d e f  - 12a c d e f  + 8c d e f  - 4c d e f )\|c x  + a
+--R              + 
+--R                            6 2 9      6   2      5   3  8
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   2 2       4 2 4  7
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5     4       4 2 3 2       3 3 5  6
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 2 4       3 3 4 2       2 4 6  5
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2   6      3 3 3 4       2 4 5 2        5 7  4
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 2 6      2 4 4 4        5 6 2     6 8  3
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3   8     2 4 3 6       5 5 4     6 7 2  2
+--R                        (2a c d e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3   2 6       2 3 2 4     3 4 2 3     3 3 4 2
+--R                    (- 2a d e f  + 6a c d e f  - 4c d e f  + 2c d e f )x
+--R                  + 
+--R                        3 2   6        2 4   4     3 5   3     3 4 3 2
+--R                    - 4a d e f  + 12a c d e f  - 8c d e f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                     +-----------+ +--------+
+--R               3 2     2         2   2      2 2  +-+ |          2  |   2
+--R           (- a f  + 2a c d f - a c e  - a c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                   +-----------+
+--R             3 2     2         2   2      2 2  +-+ |          2  +-+
+--R           (a f  - 2a c d f + a c e  + a c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                            6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                         - a e f  + 6a c d e f  - 4a c d e f
+--R                       + 
+--R                            3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                         (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                       + 
+--R                                5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                         (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3   5        3 2      2   2  4        2 3 3
+--R                4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R              + 
+--R                       2 2 2     3 4  2     3 3 2      3 2 4
+--R                (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                          8 2 10        8   2      7   3  9
+--R                        8a d f   + (- 6a d e  - 64a c d )f
+--R                      + 
+--R                          8 4      7   2 2       6 2 4  8
+--R                        (a e  + 64a c d e  + 224a c d )f
+--R                      + 
+--R                              7     4       6 2 3 2       5 3 5  7
+--R                        (- 24a c d e  - 264a c d e  - 448a c d )f
+--R                      + 
+--R                           7   6       6 2 2 4       5 3 4 2       4 4 6  6
+--R                        (3a c e  + 124a c d e  + 576a c d e  + 560a c d )f
+--R                      + 
+--R                              6 2   6       5 3 3 4       4 4 5 2       3 5 7  5
+--R                        (- 30a c d e  - 296a c d e  - 740a c d e  - 448a c d )f
+--R                      + 
+--R                              6 2 8      5 3 2 6       4 4 4 4       3 5 6 2
+--R                            3a c e  + 77a c d e  + 390a c d e  + 576a c d e
+--R                          + 
+--R                                2 6 8
+--R                            224a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                                 5 3   8       4 4 3 6       3 5 5 4
+--R                            - 12a c d e  - 100a c d e  - 296a c d e
+--R                          + 
+--R                                  2 6 7 2        7 9
+--R                            - 264a c d e  - 64a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                             5 3 10      4 4 2 8      3 5 4 6       2 6 6 4
+--R                            a c e   + 10a c d e  + 77a c d e  + 124a c d e
+--R                          + 
+--R                                 7 8 2     8 10
+--R                            64a c d e  + 8c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                              3 5 3 8      2 6 5 6        7 7 4     8 9 2
+--R                        (- 12a c d e  - 30a c d e  - 24a c d e  - 6c d e )f
+--R                      + 
+--R                         3 5 2 10     2 6 4 8       7 6 6    8 8 4
+--R                        a c d e   + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            5   2 7    5 4 6      3 2 3 2 5
+--R                        - 4a d e f  + a e f  + 16a c d e f
+--R                      + 
+--R                             3 2 2 4     2 3 4 2  4      2 3 3 4        4 5 2  3
+--R                        (- 4a c d e  - 8a c d e )f  + (6a c d e  - 12a c d e )f
+--R                      + 
+--R                          2 3 2 6       4 4 4     5 6 2  2     5 5 4     5 4 6
+--R                      (- a c d e  + 3a c d e  + 8c d e )f  - 6c d e f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                     6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                                  - a e f  + 6a c d e f  - 4a c d e f
+--R                                + 
+--R                                     3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                                  (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                                + 
+--R                                         5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                                  (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3   5        3 2      2   2  4        2 3 3
+--R                         4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R                       + 
+--R                                2 2 2     3 4  2     3 3 2      3 2 4
+--R                         (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 2   6        2 4   4     3 5   3     3 4 3 2  |   2
+--R                (4a d e f  - 12a c d e f  + 8c d e f  - 4c d e f )\|c x  + a
+--R              + 
+--R                          6 2 9        6   2      5   3  8
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   2 2       4 2 4  7
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5     4       4 2 3 2       3 3 5  6
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 2 4       3 3 4 2       2 4 6  5
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2   6      3 3 3 4       2 4 5 2        5 7  4
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 2 6      2 4 4 4        5 6 2     6 8  3
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3   8     2 4 3 6       5 5 4     6 7 2  2
+--R                        (- 2a c d e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3   2 6       2 3 2 4     3 4 2 3     3 3 4 2
+--R                    (- 2a d e f  + 6a c d e f  - 4c d e f  + 2c d e f )x
+--R                  + 
+--R                        3 2   6        2 4   4     3 5   3     3 4 3 2
+--R                    - 4a d e f  + 12a c d e f  - 8c d e f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +-----------+ +--------+
+--R             3 2     2         2   2      2 2  +-+ |          2  |   2
+--R           (a f  - 2a c d f + a c e  + a c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                     +-----------+
+--R               3 2     2         2   2      2 2  +-+ |          2  +-+
+--R           (- a f  + 2a c d f - a c e  - a c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                            6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                         - a e f  + 6a c d e f  - 4a c d e f
+--R                       + 
+--R                            3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                         (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                       + 
+--R                                5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                         (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3   5        3 2      2   2  4        2 3 3
+--R                4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R              + 
+--R                       2 2 2     3 4  2     3 3 2      3 2 4
+--R                (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                            8 2 10      8   2      7   3  9
+--R                        - 8a d f   + (6a d e  + 64a c d )f
+--R                      + 
+--R                            8 4      7   2 2       6 2 4  8
+--R                        (- a e  - 64a c d e  - 224a c d )f
+--R                      + 
+--R                            7     4       6 2 3 2       5 3 5  7
+--R                        (24a c d e  + 264a c d e  + 448a c d )f
+--R                      + 
+--R                             7   6       6 2 2 4       5 3 4 2       4 4 6  6
+--R                        (- 3a c e  - 124a c d e  - 576a c d e  - 560a c d )f
+--R                      + 
+--R                            6 2   6       5 3 3 4       4 4 5 2       3 5 7  5
+--R                        (30a c d e  + 296a c d e  + 740a c d e  + 448a c d )f
+--R                      + 
+--R                                6 2 8      5 3 2 6       4 4 4 4       3 5 6 2
+--R                            - 3a c e  - 77a c d e  - 390a c d e  - 576a c d e
+--R                          + 
+--R                                  2 6 8
+--R                            - 224a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                               5 3   8       4 4 3 6       3 5 5 4       2 6 7 2
+--R                            12a c d e  + 100a c d e  + 296a c d e  + 264a c d e
+--R                          + 
+--R                                 7 9
+--R                            64a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                               5 3 10      4 4 2 8      3 5 4 6       2 6 6 4
+--R                            - a c e   - 10a c d e  - 77a c d e  - 124a c d e
+--R                          + 
+--R                                   7 8 2     8 10
+--R                            - 64a c d e  - 8c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                            3 5 3 8      2 6 5 6        7 7 4     8 9 2
+--R                        (12a c d e  + 30a c d e  + 24a c d e  + 6c d e )f
+--R                      + 
+--R                           3 5 2 10     2 6 4 8       7 6 6    8 8 4
+--R                        - a c d e   - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                          5   2 7    5 4 6      3 2 3 2 5
+--R                        4a d e f  - a e f  - 16a c d e f
+--R                      + 
+--R                           3 2 2 4     2 3 4 2  4        2 3 3 4        4 5 2  3
+--R                        (4a c d e  + 8a c d e )f  + (- 6a c d e  + 12a c d e )f
+--R                      + 
+--R                          2 3 2 6       4 4 4     5 6 2  2     5 5 4     5 4 6
+--R                        (a c d e  - 3a c d e  - 8c d e )f  + 6c d e f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                     6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                                  - a e f  + 6a c d e f  - 4a c d e f
+--R                                + 
+--R                                     3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                                  (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                                + 
+--R                                         5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                                  (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3   5        3 2      2   2  4        2 3 3
+--R                         4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R                       + 
+--R                                2 2 2     3 4  2     3 3 2      3 2 4
+--R                         (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 2   6        2 4   4     3 5   3     3 4 3 2  |   2
+--R                (4a d e f  - 12a c d e f  + 8c d e f  - 4c d e f )\|c x  + a
+--R              + 
+--R                          6 2 9        6   2      5   3  8
+--R                        8a d f  + (- 2a d e  - 48a c d )f
+--R                      + 
+--R                            5   2 2       4 2 4  7
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5     4       4 2 3 2       3 3 5  6
+--R                        (- 6a c d e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2 2 4       3 3 4 2       2 4 6  5
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2   6      3 3 3 4       2 4 5 2        5 7  4
+--R                        (- 6a c d e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3 2 6      2 4 4 4        5 6 2     6 8  3
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3   8     2 4 3 6       5 5 4     6 7 2  2
+--R                        (- 2a c d e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3   2 6       2 3 2 4     3 4 2 3     3 3 4 2
+--R                    (- 2a d e f  + 6a c d e f  - 4c d e f  + 2c d e f )x
+--R                  + 
+--R                        3 2   6        2 4   4     3 5   3     3 4 3 2
+--R                    - 4a d e f  + 12a c d e f  - 8c d e f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                     +-----------+ +--------+
+--R               3 2     2         2   2      2 2  +-+ |          2  |   2
+--R           (- a f  + 2a c d f - a c e  - a c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                   +-----------+
+--R             3 2     2         2   2      2 2  +-+ |          2  +-+
+--R           (a f  - 2a c d f + a c e  + a c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                            6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                         - a e f  + 6a c d e f  - 4a c d e f
+--R                       + 
+--R                            3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                         (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                       + 
+--R                                5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                         (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                  3   5        3 2      2   2  4        2 3 3
+--R                4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R              + 
+--R                       2 2 2     3 4  2     3 3 2      3 2 4
+--R                (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                            8 2 10      8   2      7   3  9
+--R                        - 8a d f   + (6a d e  + 64a c d )f
+--R                      + 
+--R                            8 4      7   2 2       6 2 4  8
+--R                        (- a e  - 64a c d e  - 224a c d )f
+--R                      + 
+--R                            7     4       6 2 3 2       5 3 5  7
+--R                        (24a c d e  + 264a c d e  + 448a c d )f
+--R                      + 
+--R                             7   6       6 2 2 4       5 3 4 2       4 4 6  6
+--R                        (- 3a c e  - 124a c d e  - 576a c d e  - 560a c d )f
+--R                      + 
+--R                            6 2   6       5 3 3 4       4 4 5 2       3 5 7  5
+--R                        (30a c d e  + 296a c d e  + 740a c d e  + 448a c d )f
+--R                      + 
+--R                                6 2 8      5 3 2 6       4 4 4 4       3 5 6 2
+--R                            - 3a c e  - 77a c d e  - 390a c d e  - 576a c d e
+--R                          + 
+--R                                  2 6 8
+--R                            - 224a c d
+--R                       *
+--R                           4
+--R                          f
+--R                      + 
+--R                               5 3   8       4 4 3 6       3 5 5 4       2 6 7 2
+--R                            12a c d e  + 100a c d e  + 296a c d e  + 264a c d e
+--R                          + 
+--R                                 7 9
+--R                            64a c d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                               5 3 10      4 4 2 8      3 5 4 6       2 6 6 4
+--R                            - a c e   - 10a c d e  - 77a c d e  - 124a c d e
+--R                          + 
+--R                                   7 8 2     8 10
+--R                            - 64a c d e  - 8c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                            3 5 3 8      2 6 5 6        7 7 4     8 9 2
+--R                        (12a c d e  + 30a c d e  + 24a c d e  + 6c d e )f
+--R                      + 
+--R                           3 5 2 10     2 6 4 8       7 6 6    8 8 4
+--R                        - a c d e   - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            5   2 7    5 4 6      3 2 3 2 5
+--R                        - 4a d e f  + a e f  + 16a c d e f
+--R                      + 
+--R                             3 2 2 4     2 3 4 2  4      2 3 3 4        4 5 2  3
+--R                        (- 4a c d e  - 8a c d e )f  + (6a c d e  - 12a c d e )f
+--R                      + 
+--R                          2 3 2 6       4 4 4     5 6 2  2     5 5 4     5 4 6
+--R                      (- a c d e  + 3a c d e  + 8c d e )f  - 6c d e f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                     6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                                  - a e f  + 6a c d e f  - 4a c d e f
+--R                                + 
+--R                                     3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                                  (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                                + 
+--R                                         5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                                  (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                           3   5        3 2      2   2  4        2 3 3
+--R                         4a d f  + (- 2a e  - 12a c d )f  + 12a c d f
+--R                       + 
+--R                                2 2 2     3 4  2     3 3 2      3 2 4
+--R                         (- 6a c d e  - 4c d )f  + 8c d e f - 2c d e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                                                                   +--------+
+--R                   3 2   6        2 4   4     3 5   3     3 4 3 2  |   2
+--R                (4a d e f  - 12a c d e f  + 8c d e f  - 4c d e f )\|c x  + a
+--R              + 
+--R                            6 2 9      6   2      5   3  8
+--R                        - 8a d f  + (2a d e  + 48a c d )f
+--R                      + 
+--R                              5   2 2       4 2 4  7
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5     4       4 2 3 2       3 3 5  6
+--R                        (6a c d e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2 2 4       3 3 4 2       2 4 6  5
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2   6      3 3 3 4       2 4 5 2        5 7  4
+--R                        (6a c d e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3 2 6      2 4 4 4        5 6 2     6 8  3
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3   8     2 4 3 6       5 5 4     6 7 2  2
+--R                        (2a c d e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                6 2 8     4 2 2 2 6     3 3 3 2 5
+--R                             - a e f  + 6a c d e f  - 4a c d e f
+--R                           + 
+--R                                3 3 2 4     2 4 4 2  4        5 5 2 3
+--R                             (2a c d e  - 9a c d e )f  + 12a c d e f
+--R                           + 
+--R                                    5 4 4     6 6 2  2     6 5 4     6 4 6
+--R                             (- 6a c d e  - 4c d e )f  + 4c d e f - c d e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                         3   2 6       2 3 2 4     3 4 2 3     3 3 4 2
+--R                    (- 2a d e f  + 6a c d e f  - 4c d e f  + 2c d e f )x
+--R                  + 
+--R                        3 2   6        2 4   4     3 5   3     3 4 3 2
+--R                    - 4a d e f  + 12a c d e f  - 8c d e f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                               +-----------+                         +--------+
+--R               2 2             |          2      2   2               |   2
+--R           ((2a f  - 2a c d f)\|- 4d f + e   - 2a e f  - 2a c d e f)\|c x  + a
+--R         + 
+--R                                 +-----------+
+--R                 2 2             |          2      2   2               +-+
+--R           ((- 2a f  + 2a c d f)\|- 4d f + e   + 2a e f  + 2a c d e f)\|a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                   +-----------+
+--R                   2 2             |          2      2   2
+--R             ((- 2a f  + 2a c d f)\|- 4d f + e   - 2a e f  - 2a c d e f)
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + a
+--R         + 
+--R                               +-----------+
+--R               2 2             |          2      2   2               +-+
+--R           ((2a f  - 2a c d f)\|- 4d f + e   + 2a e f  + 2a c d e f)\|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                             +-----------+     +--------+
+--R                         +-+ |          2  +-+ |   2
+--R           (2a f - 2c d)\|2 \|- 4d f + e  \|a \|c x  + a
+--R         + 
+--R                                 +-----------+
+--R                2            +-+ |          2
+--R           (- 2a f + 2a c d)\|2 \|- 4d f + e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                                    +-----------+ +--------+
+--R            3 2     2          2   2       2 2  +-+ |          2  |   2
+--R         (2a f  - 4a c d f + 2a c e  + 2a c d )\|2 \|- 4d f + e  \|c x  + a
+--R       + 
+--R                                                      +-----------+
+--R              3 2     2          2   2       2 2  +-+ |          2  +-+
+--R         (- 2a f  + 4a c d f - 2a c e  - 2a c d )\|2 \|- 4d f + e  \|a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 1580
+--d0:=D(m0,x)
+--E 110
+
+)clear all
+
+--S 111 of 1580
+t0:=1/((a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                     1
+--R   (1)  ----------------------------------------------------------
+--R                                                        +--------+
+--R              4        3               2                |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x + a d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 1580
+r0:=c*(a*e+(c*d-a*f)*x)/(a*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(a+c*x^2))-_
+   f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+_
+   f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*a*f^2+c*(e^2-_
+   2*d*f-e*sqrt(e^2-4*d*f)))/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                    +-----------+                                +--------+
+--R                    |          2      2 3           2        2   |   2
+--R         (- a c e f\|- 4d f + e   - 2a f  + 2a c d f  - a c e f)\|c x  + a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                  +-----------+                                +--------+
+--R                  |          2      2 3           2        2   |   2
+--R         (a c e f\|- 4d f + e   - 2a f  + 2a c d f  - a c e f)\|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                        +-----------+
+--R                      2             +-+ |          2
+--R         ((- a c f + c d)x + a c e)\|2 \|- 4d f + e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                               +-----------+ +--------+
+--R         3 2     2         2   2      2 2  +-+ |          2  |   2
+--R       (a f  - 2a c d f + a c e  + a c d )\|2 \|- 4d f + e  \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                     +--------+
+--R               3 2     2         2   2      2 2  +-+ |   2
+--R           (- a f  + 2a c d f - a c e  - a c d )\|a \|c x  + a
+--R         + 
+--R             3   2     2 2       2 2 2      3 2  2    4 2     3         3   2
+--R           (a c f  - 2a c d f + a c e  + a c d )x  + a f  - 2a c d f + a c e
+--R         + 
+--R            2 2 2
+--R           a c d
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             4 2 2 8      3 3   2 7
+--R                         - 9a c e f  + 36a c d e f
+--R                       + 
+--R                               3 3 4      2 4 2 2  6
+--R                         (- 18a c e  - 54a c d e )f
+--R                       + 
+--R                             2 4   4        5 3 2  5
+--R                         (60a c d e  + 36a c d e )f
+--R                       + 
+--R                               2 4 6        5 2 4     6 4 2  4
+--R                         (- 15a c e  - 66a c d e  - 9c d e )f
+--R                       + 
+--R                               5   6      6 3 4  3          5 8      6 2 6  2
+--R                         (36a c d e  + 24c d e )f  + (- 6a c e  - 22c d e )f
+--R                       + 
+--R                           6   8     6 10
+--R                         8c d e f - c e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 6      2     5        2   2        2 2  4
+--R                - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R              + 
+--R                      2   2     3 3  3          2 4      3 2 2  2      3   4
+--R                (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f  + 12c d e f
+--R              + 
+--R                    3 6
+--R                - 2c e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                          8     10       8 3      7   2   9      7     3 8
+--R                        4a d e f   + (- a e  - 16a c d e)f  + 16a c d e f
+--R                      + 
+--R                             7   5      6 2 2 3       5 3 4   7
+--R                        (- 3a c e  - 20a c d e  + 112a c d e)f
+--R                      + 
+--R                            6 2   5       5 3 3 3       4 4 5   6
+--R                        (17a c d e  - 112a c d e  - 280a c d e)f
+--R                      + 
+--R                             6 2 7      5 3 2 5       4 4 4 3       3 5 6   5
+--R                        (- 3a c e  + 33a c d e  + 370a c d e  + 336a c d e)f
+--R                      + 
+--R                          5 3   7       4 4 3 5       3 5 5 3       2 6 7   4
+--R                        (a c d e  - 195a c d e  - 464a c d e  - 224a c d e)f
+--R                      + 
+--R                               5 3 9      4 4 2 7       3 5 4 5       2 6 6 3
+--R                            - a c e  + 50a c d e  + 263a c d e  + 284a c d e
+--R                          + 
+--R                                 7 8
+--R                            80a c d e
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                                4 4   9      3 5 3 7       2 6 5 5        7 7 3
+--R                            - 5a c d e  - 78a c d e  - 141a c d e  - 80a c d e
+--R                          + 
+--R                                 8 9
+--R                            - 12c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                            3 5 2 9      2 6 4 7        7 6 5     8 8 3
+--R                        (13a c d e  + 33a c d e  + 27a c d e  + 7c d e )f
+--R                      + 
+--R                           3 5   11     2 6 3 9       7 5 7    8 7 5
+--R                        - a c d e   - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                           4       8        4   3      3 2 2   7
+--R                        12a c d e f  + (- 3a c e  - 48a c d e)f
+--R                      + 
+--R                            3 2   3      2 3 3   6
+--R                        (24a c d e  + 72a c d e)f
+--R                      + 
+--R                             3 2 5      2 3 2 3        4 4   5
+--R                        (- 3a c e  - 70a c d e  - 48a c d e)f
+--R                      + 
+--R                            2 3   5        4 3 3      5 5   4
+--R                        (17a c d e  + 80a c d e  + 12c d e)f
+--R                      + 
+--R                            2 3 7        4 2 5      5 4 3  3
+--R                        (- a c e  - 37a c d e  - 31c d e )f
+--R                      + 
+--R                             4   7      5 3 5  2     5 2 7     5   9
+--R                        (5a c d e  + 27c d e )f  - 9c d e f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      4 2 2 8      3 3   2 7
+--R                                  - 9a c e f  + 36a c d e f
+--R                                + 
+--R                                        3 3 4      2 4 2 2  6
+--R                                  (- 18a c e  - 54a c d e )f
+--R                                + 
+--R                                      2 4   4        5 3 2  5
+--R                                  (60a c d e  + 36a c d e )f
+--R                                + 
+--R                                        2 4 6        5 2 4     6 4 2  4
+--R                                  (- 15a c e  - 66a c d e  - 9c d e )f
+--R                                + 
+--R                                        5   6      6 3 4  3
+--R                                  (36a c d e  + 24c d e )f
+--R                                + 
+--R                                         5 8      6 2 6  2     6   8     6 10
+--R                                  (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 6      2     5        2   2        2 2  4
+--R                         - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R                       + 
+--R                               2   2     3 3  3          2 4      3 2 2  2
+--R                         (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f
+--R                       + 
+--R                            3   4      3 6
+--R                         12c d e f - 2c e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       2       7        2 2   6         2   3      3 3   5
+--R                    12a c d e f  - 24a c d e f  + (12a c d e  + 12c d e)f
+--R                  + 
+--R                         3 2 3 4     3   5 3
+--R                    - 16c d e f  + 4c d e f
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                          6   10        6 2      5   2  9
+--R                        8a d f   + (- 2a e  - 48a c d )f
+--R                      + 
+--R                            5     2       4 2 3  8
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   4       4 2 2 2       3 3 4  7
+--R                        (- 6a c e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2   4       3 3 3 2       2 4 5  6
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 6      3 3 2 4       2 4 4 2        5 6  5
+--R                        (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3   6      2 4 3 4        5 5 2     6 7  4
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3 8     2 4 2 6       5 4 4     6 6 2  3
+--R                        (- 2a c e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            2   2 7        2   2 6          2 4     3 2 2  5
+--R                        - 6a c e f  + 12a c d e f  + (- 6a c e  - 6c d e )f
+--R                      + 
+--R                          3   4 4     3 6 3
+--R                        8c d e f  - 2c e f
+--R                   *
+--R                      x
+--R                  + 
+--R                         2       7        2 2   6           2   3      3 3   5
+--R                    - 12a c d e f  + 24a c d e f  + (- 12a c d e  - 12c d e)f
+--R                  + 
+--R                       3 2 3 4     3   5 3
+--R                    16c d e f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +--------+
+--R             3 2     2         2   2      2 2  +-+ |   2
+--R           (a f  - 2a c d f + a c e  + a c d )\|a \|c x  + a
+--R         + 
+--R               3   2     2 2       2 2 2      3 2  2    4 2     3         3   2
+--R           (- a c f  + 2a c d f - a c e  - a c d )x  - a f  + 2a c d f - a c e
+--R         + 
+--R              2 2 2
+--R           - a c d
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             4 2 2 8      3 3   2 7
+--R                         - 9a c e f  + 36a c d e f
+--R                       + 
+--R                               3 3 4      2 4 2 2  6
+--R                         (- 18a c e  - 54a c d e )f
+--R                       + 
+--R                             2 4   4        5 3 2  5
+--R                         (60a c d e  + 36a c d e )f
+--R                       + 
+--R                               2 4 6        5 2 4     6 4 2  4
+--R                         (- 15a c e  - 66a c d e  - 9c d e )f
+--R                       + 
+--R                               5   6      6 3 4  3          5 8      6 2 6  2
+--R                         (36a c d e  + 24c d e )f  + (- 6a c e  - 22c d e )f
+--R                       + 
+--R                           6   8     6 10
+--R                         8c d e f - c e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 6      2     5        2   2        2 2  4
+--R                - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R              + 
+--R                      2   2     3 3  3          2 4      3 2 2  2      3   4
+--R                (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f  + 12c d e f
+--R              + 
+--R                    3 6
+--R                - 2c e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                          8     10       8 3      7   2   9      7     3 8
+--R                        4a d e f   + (- a e  - 16a c d e)f  + 16a c d e f
+--R                      + 
+--R                             7   5      6 2 2 3       5 3 4   7
+--R                        (- 3a c e  - 20a c d e  + 112a c d e)f
+--R                      + 
+--R                            6 2   5       5 3 3 3       4 4 5   6
+--R                        (17a c d e  - 112a c d e  - 280a c d e)f
+--R                      + 
+--R                             6 2 7      5 3 2 5       4 4 4 3       3 5 6   5
+--R                        (- 3a c e  + 33a c d e  + 370a c d e  + 336a c d e)f
+--R                      + 
+--R                          5 3   7       4 4 3 5       3 5 5 3       2 6 7   4
+--R                        (a c d e  - 195a c d e  - 464a c d e  - 224a c d e)f
+--R                      + 
+--R                               5 3 9      4 4 2 7       3 5 4 5       2 6 6 3
+--R                            - a c e  + 50a c d e  + 263a c d e  + 284a c d e
+--R                          + 
+--R                                 7 8
+--R                            80a c d e
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                                4 4   9      3 5 3 7       2 6 5 5        7 7 3
+--R                            - 5a c d e  - 78a c d e  - 141a c d e  - 80a c d e
+--R                          + 
+--R                                 8 9
+--R                            - 12c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                            3 5 2 9      2 6 4 7        7 6 5     8 8 3
+--R                        (13a c d e  + 33a c d e  + 27a c d e  + 7c d e )f
+--R                      + 
+--R                           3 5   11     2 6 3 9       7 5 7    8 7 5
+--R                        - a c d e   - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                             4       8      4   3      3 2 2   7
+--R                        - 12a c d e f  + (3a c e  + 48a c d e)f
+--R                      + 
+--R                              3 2   3      2 3 3   6
+--R                        (- 24a c d e  - 72a c d e)f
+--R                      + 
+--R                           3 2 5      2 3 2 3        4 4   5
+--R                        (3a c e  + 70a c d e  + 48a c d e)f
+--R                      + 
+--R                              2 3   5        4 3 3      5 5   4
+--R                        (- 17a c d e  - 80a c d e  - 12c d e)f
+--R                      + 
+--R                          2 3 7        4 2 5      5 4 3  3
+--R                        (a c e  + 37a c d e  + 31c d e )f
+--R                      + 
+--R                               4   7      5 3 5  2     5 2 7     5   9
+--R                        (- 5a c d e  - 27c d e )f  + 9c d e f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      4 2 2 8      3 3   2 7
+--R                                  - 9a c e f  + 36a c d e f
+--R                                + 
+--R                                        3 3 4      2 4 2 2  6
+--R                                  (- 18a c e  - 54a c d e )f
+--R                                + 
+--R                                      2 4   4        5 3 2  5
+--R                                  (60a c d e  + 36a c d e )f
+--R                                + 
+--R                                        2 4 6        5 2 4     6 4 2  4
+--R                                  (- 15a c e  - 66a c d e  - 9c d e )f
+--R                                + 
+--R                                        5   6      6 3 4  3
+--R                                  (36a c d e  + 24c d e )f
+--R                                + 
+--R                                         5 8      6 2 6  2     6   8     6 10
+--R                                  (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 6      2     5        2   2        2 2  4
+--R                         - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R                       + 
+--R                               2   2     3 3  3          2 4      3 2 2  2
+--R                         (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f
+--R                       + 
+--R                            3   4      3 6
+--R                         12c d e f - 2c e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       2       7        2 2   6         2   3      3 3   5
+--R                    12a c d e f  - 24a c d e f  + (12a c d e  + 12c d e)f
+--R                  + 
+--R                         3 2 3 4     3   5 3
+--R                    - 16c d e f  + 4c d e f
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                            6   10      6 2      5   2  9
+--R                        - 8a d f   + (2a e  + 48a c d )f
+--R                      + 
+--R                              5     2       4 2 3  8
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   4       4 2 2 2       3 3 4  7
+--R                        (6a c e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2   4       3 3 3 2       2 4 5  6
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 6      3 3 2 4       2 4 4 2        5 6  5
+--R                        (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3   6      2 4 3 4        5 5 2     6 7  4
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3 8     2 4 2 6       5 4 4     6 6 2  3
+--R                        (2a c e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            2   2 7        2   2 6          2 4     3 2 2  5
+--R                        - 6a c e f  + 12a c d e f  + (- 6a c e  - 6c d e )f
+--R                      + 
+--R                          3   4 4     3 6 3
+--R                        8c d e f  - 2c e f
+--R                   *
+--R                      x
+--R                  + 
+--R                         2       7        2 2   6           2   3      3 3   5
+--R                    - 12a c d e f  + 24a c d e f  + (- 12a c d e  - 12c d e)f
+--R                  + 
+--R                       3 2 3 4     3   5 3
+--R                    16c d e f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                     +--------+
+--R               3 2     2         2   2      2 2  +-+ |   2
+--R           (- a f  + 2a c d f - a c e  - a c d )\|a \|c x  + a
+--R         + 
+--R             3   2     2 2       2 2 2      3 2  2    4 2     3         3   2
+--R           (a c f  - 2a c d f + a c e  + a c d )x  + a f  - 2a c d f + a c e
+--R         + 
+--R            2 2 2
+--R           a c d
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             4 2 2 8      3 3   2 7
+--R                         - 9a c e f  + 36a c d e f
+--R                       + 
+--R                               3 3 4      2 4 2 2  6
+--R                         (- 18a c e  - 54a c d e )f
+--R                       + 
+--R                             2 4   4        5 3 2  5
+--R                         (60a c d e  + 36a c d e )f
+--R                       + 
+--R                               2 4 6        5 2 4     6 4 2  4
+--R                         (- 15a c e  - 66a c d e  - 9c d e )f
+--R                       + 
+--R                               5   6      6 3 4  3          5 8      6 2 6  2
+--R                         (36a c d e  + 24c d e )f  + (- 6a c e  - 22c d e )f
+--R                       + 
+--R                           6   8     6 10
+--R                         8c d e f - c e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 6      2     5        2   2        2 2  4
+--R                - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R              + 
+--R                      2   2     3 3  3          2 4      3 2 2  2      3   4
+--R                (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f  + 12c d e f
+--R              + 
+--R                    3 6
+--R                - 2c e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                            8     10     8 3      7   2   9      7     3 8
+--R                        - 4a d e f   + (a e  + 16a c d e)f  - 16a c d e f
+--R                      + 
+--R                           7   5      6 2 2 3       5 3 4   7
+--R                        (3a c e  + 20a c d e  - 112a c d e)f
+--R                      + 
+--R                              6 2   5       5 3 3 3       4 4 5   6
+--R                        (- 17a c d e  + 112a c d e  + 280a c d e)f
+--R                      + 
+--R                           6 2 7      5 3 2 5       4 4 4 3       3 5 6   5
+--R                        (3a c e  - 33a c d e  - 370a c d e  - 336a c d e)f
+--R                      + 
+--R                            5 3   7       4 4 3 5       3 5 5 3       2 6 7   4
+--R                        (- a c d e  + 195a c d e  + 464a c d e  + 224a c d e)f
+--R                      + 
+--R                             5 3 9      4 4 2 7       3 5 4 5       2 6 6 3
+--R                            a c e  - 50a c d e  - 263a c d e  - 284a c d e
+--R                          + 
+--R                                   7 8
+--R                            - 80a c d e
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                              4 4   9      3 5 3 7       2 6 5 5        7 7 3
+--R                            5a c d e  + 78a c d e  + 141a c d e  + 80a c d e
+--R                          + 
+--R                               8 9
+--R                            12c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                              3 5 2 9      2 6 4 7        7 6 5     8 8 3
+--R                        (- 13a c d e  - 33a c d e  - 27a c d e  - 7c d e )f
+--R                      + 
+--R                         3 5   11     2 6 3 9       7 5 7    8 7 5
+--R                        a c d e   + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                           4       8        4   3      3 2 2   7
+--R                        12a c d e f  + (- 3a c e  - 48a c d e)f
+--R                      + 
+--R                            3 2   3      2 3 3   6
+--R                        (24a c d e  + 72a c d e)f
+--R                      + 
+--R                             3 2 5      2 3 2 3        4 4   5
+--R                        (- 3a c e  - 70a c d e  - 48a c d e)f
+--R                      + 
+--R                            2 3   5        4 3 3      5 5   4
+--R                        (17a c d e  + 80a c d e  + 12c d e)f
+--R                      + 
+--R                            2 3 7        4 2 5      5 4 3  3
+--R                        (- a c e  - 37a c d e  - 31c d e )f
+--R                      + 
+--R                             4   7      5 3 5  2     5 2 7     5   9
+--R                        (5a c d e  + 27c d e )f  - 9c d e f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      4 2 2 8      3 3   2 7
+--R                                  - 9a c e f  + 36a c d e f
+--R                                + 
+--R                                        3 3 4      2 4 2 2  6
+--R                                  (- 18a c e  - 54a c d e )f
+--R                                + 
+--R                                      2 4   4        5 3 2  5
+--R                                  (60a c d e  + 36a c d e )f
+--R                                + 
+--R                                        2 4 6        5 2 4     6 4 2  4
+--R                                  (- 15a c e  - 66a c d e  - 9c d e )f
+--R                                + 
+--R                                        5   6      6 3 4  3
+--R                                  (36a c d e  + 24c d e )f
+--R                                + 
+--R                                         5 8      6 2 6  2     6   8     6 10
+--R                                  (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 6      2     5        2   2        2 2  4
+--R                         - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R                       + 
+--R                               2   2     3 3  3          2 4      3 2 2  2
+--R                         (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f
+--R                       + 
+--R                            3   4      3 6
+--R                         12c d e f - 2c e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       2       7        2 2   6         2   3      3 3   5
+--R                    12a c d e f  - 24a c d e f  + (12a c d e  + 12c d e)f
+--R                  + 
+--R                         3 2 3 4     3   5 3
+--R                    - 16c d e f  + 4c d e f
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                            6   10      6 2      5   2  9
+--R                        - 8a d f   + (2a e  + 48a c d )f
+--R                      + 
+--R                              5     2       4 2 3  8
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   4       4 2 2 2       3 3 4  7
+--R                        (6a c e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2   4       3 3 3 2       2 4 5  6
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 6      3 3 2 4       2 4 4 2        5 6  5
+--R                        (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3   6      2 4 3 4        5 5 2     6 7  4
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3 8     2 4 2 6       5 4 4     6 6 2  3
+--R                        (2a c e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            2   2 7        2   2 6          2 4     3 2 2  5
+--R                        - 6a c e f  + 12a c d e f  + (- 6a c e  - 6c d e )f
+--R                      + 
+--R                          3   4 4     3 6 3
+--R                        8c d e f  - 2c e f
+--R                   *
+--R                      x
+--R                  + 
+--R                         2       7        2 2   6           2   3      3 3   5
+--R                    - 12a c d e f  + 24a c d e f  + (- 12a c d e  - 12c d e)f
+--R                  + 
+--R                       3 2 3 4     3   5 3
+--R                    16c d e f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +--------+
+--R             3 2     2         2   2      2 2  +-+ |   2
+--R           (a f  - 2a c d f + a c e  + a c d )\|a \|c x  + a
+--R         + 
+--R               3   2     2 2       2 2 2      3 2  2    4 2     3         3   2
+--R           (- a c f  + 2a c d f - a c e  - a c d )x  - a f  + 2a c d f - a c e
+--R         + 
+--R              2 2 2
+--R           - a c d
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             4 2 2 8      3 3   2 7
+--R                         - 9a c e f  + 36a c d e f
+--R                       + 
+--R                               3 3 4      2 4 2 2  6
+--R                         (- 18a c e  - 54a c d e )f
+--R                       + 
+--R                             2 4   4        5 3 2  5
+--R                         (60a c d e  + 36a c d e )f
+--R                       + 
+--R                               2 4 6        5 2 4     6 4 2  4
+--R                         (- 15a c e  - 66a c d e  - 9c d e )f
+--R                       + 
+--R                               5   6      6 3 4  3          5 8      6 2 6  2
+--R                         (36a c d e  + 24c d e )f  + (- 6a c e  - 22c d e )f
+--R                       + 
+--R                           6   8     6 10
+--R                         8c d e f - c e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 6      2     5        2   2        2 2  4
+--R                - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R              + 
+--R                      2   2     3 3  3          2 4      3 2 2  2      3   4
+--R                (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f  + 12c d e f
+--R              + 
+--R                    3 6
+--R                - 2c e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                            8     10     8 3      7   2   9      7     3 8
+--R                        - 4a d e f   + (a e  + 16a c d e)f  - 16a c d e f
+--R                      + 
+--R                           7   5      6 2 2 3       5 3 4   7
+--R                        (3a c e  + 20a c d e  - 112a c d e)f
+--R                      + 
+--R                              6 2   5       5 3 3 3       4 4 5   6
+--R                        (- 17a c d e  + 112a c d e  + 280a c d e)f
+--R                      + 
+--R                           6 2 7      5 3 2 5       4 4 4 3       3 5 6   5
+--R                        (3a c e  - 33a c d e  - 370a c d e  - 336a c d e)f
+--R                      + 
+--R                            5 3   7       4 4 3 5       3 5 5 3       2 6 7   4
+--R                        (- a c d e  + 195a c d e  + 464a c d e  + 224a c d e)f
+--R                      + 
+--R                             5 3 9      4 4 2 7       3 5 4 5       2 6 6 3
+--R                            a c e  - 50a c d e  - 263a c d e  - 284a c d e
+--R                          + 
+--R                                   7 8
+--R                            - 80a c d e
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                              4 4   9      3 5 3 7       2 6 5 5        7 7 3
+--R                            5a c d e  + 78a c d e  + 141a c d e  + 80a c d e
+--R                          + 
+--R                               8 9
+--R                            12c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                              3 5 2 9      2 6 4 7        7 6 5     8 8 3
+--R                        (- 13a c d e  - 33a c d e  - 27a c d e  - 7c d e )f
+--R                      + 
+--R                         3 5   11     2 6 3 9       7 5 7    8 7 5
+--R                        a c d e   + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                             4       8      4   3      3 2 2   7
+--R                        - 12a c d e f  + (3a c e  + 48a c d e)f
+--R                      + 
+--R                              3 2   3      2 3 3   6
+--R                        (- 24a c d e  - 72a c d e)f
+--R                      + 
+--R                           3 2 5      2 3 2 3        4 4   5
+--R                        (3a c e  + 70a c d e  + 48a c d e)f
+--R                      + 
+--R                              2 3   5        4 3 3      5 5   4
+--R                        (- 17a c d e  - 80a c d e  - 12c d e)f
+--R                      + 
+--R                          2 3 7        4 2 5      5 4 3  3
+--R                        (a c e  + 37a c d e  + 31c d e )f
+--R                      + 
+--R                               4   7      5 3 5  2     5 2 7     5   9
+--R                        (- 5a c d e  - 27c d e )f  + 9c d e f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      4 2 2 8      3 3   2 7
+--R                                  - 9a c e f  + 36a c d e f
+--R                                + 
+--R                                        3 3 4      2 4 2 2  6
+--R                                  (- 18a c e  - 54a c d e )f
+--R                                + 
+--R                                      2 4   4        5 3 2  5
+--R                                  (60a c d e  + 36a c d e )f
+--R                                + 
+--R                                        2 4 6        5 2 4     6 4 2  4
+--R                                  (- 15a c e  - 66a c d e  - 9c d e )f
+--R                                + 
+--R                                        5   6      6 3 4  3
+--R                                  (36a c d e  + 24c d e )f
+--R                                + 
+--R                                         5 8      6 2 6  2     6   8     6 10
+--R                                  (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 6      2     5        2   2        2 2  4
+--R                         - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R                       + 
+--R                               2   2     3 3  3          2 4      3 2 2  2
+--R                         (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f
+--R                       + 
+--R                            3   4      3 6
+--R                         12c d e f - 2c e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       2       7        2 2   6         2   3      3 3   5
+--R                    12a c d e f  - 24a c d e f  + (12a c d e  + 12c d e)f
+--R                  + 
+--R                         3 2 3 4     3   5 3
+--R                    - 16c d e f  + 4c d e f
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                          6   10        6 2      5   2  9
+--R                        8a d f   + (- 2a e  - 48a c d )f
+--R                      + 
+--R                            5     2       4 2 3  8
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   4       4 2 2 2       3 3 4  7
+--R                        (- 6a c e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2   4       3 3 3 2       2 4 5  6
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 6      3 3 2 4       2 4 4 2        5 6  5
+--R                        (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3   6      2 4 3 4        5 5 2     6 7  4
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3 8     2 4 2 6       5 4 4     6 6 2  3
+--R                        (- 2a c e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            2   2 7        2   2 6          2 4     3 2 2  5
+--R                        - 6a c e f  + 12a c d e f  + (- 6a c e  - 6c d e )f
+--R                      + 
+--R                          3   4 4     3 6 3
+--R                        8c d e f  - 2c e f
+--R                   *
+--R                      x
+--R                  + 
+--R                         2       7        2 2   6           2   3      3 3   5
+--R                    - 12a c d e f  + 24a c d e f  + (- 12a c d e  - 12c d e)f
+--R                  + 
+--R                       3 2 3 4     3   5 3
+--R                    16c d e f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                        +--------+
+--R                   2    |   2             2   2                 2     +-+
+--R       (2a c f - 2c d)x\|c x  + a  + (- 2c e x  + (- 2a c f + 2c d)x)\|a
+--R  /
+--R                                                  +--------+
+--R          3 2     2          2   2       2 2  +-+ |   2
+--R       (2a f  - 4a c d f + 2a c e  + 2a c d )\|a \|c x  + a
+--R     + 
+--R            3   2     2 2        2 2 2       3 2  2     4 2     3          3   2
+--R       (- 2a c f  + 4a c d f - 2a c e  - 2a c d )x  - 2a f  + 4a c d f - 2a c e
+--R     + 
+--R           2 2 2
+--R       - 2a c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 113
+
+--S 114 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                     +-----------+ +--------+
+--R               3 2     2         2   2      2 2  +-+ |          2  |   2
+--R           (- a f  + 2a c d f - a c e  - a c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                   +-----------+
+--R             3 2     2         2   2      2 2  +-+ |          2  +-+
+--R           (a f  - 2a c d f + a c e  + a c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             4 2 2 8      3 3   2 7
+--R                         - 9a c e f  + 36a c d e f
+--R                       + 
+--R                               3 3 4      2 4 2 2  6
+--R                         (- 18a c e  - 54a c d e )f
+--R                       + 
+--R                             2 4   4        5 3 2  5
+--R                         (60a c d e  + 36a c d e )f
+--R                       + 
+--R                               2 4 6        5 2 4     6 4 2  4
+--R                         (- 15a c e  - 66a c d e  - 9c d e )f
+--R                       + 
+--R                               5   6      6 3 4  3          5 8      6 2 6  2
+--R                         (36a c d e  + 24c d e )f  + (- 6a c e  - 22c d e )f
+--R                       + 
+--R                           6   8     6 10
+--R                         8c d e f - c e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 6      2     5        2   2        2 2  4
+--R                - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R              + 
+--R                      2   2     3 3  3          2 4      3 2 2  2      3   4
+--R                (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f  + 12c d e f
+--R              + 
+--R                    3 6
+--R                - 2c e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                          8     10       8 3      7   2   9      7     3 8
+--R                        4a d e f   + (- a e  - 16a c d e)f  + 16a c d e f
+--R                      + 
+--R                             7   5      6 2 2 3       5 3 4   7
+--R                        (- 3a c e  - 20a c d e  + 112a c d e)f
+--R                      + 
+--R                            6 2   5       5 3 3 3       4 4 5   6
+--R                        (17a c d e  - 112a c d e  - 280a c d e)f
+--R                      + 
+--R                             6 2 7      5 3 2 5       4 4 4 3       3 5 6   5
+--R                        (- 3a c e  + 33a c d e  + 370a c d e  + 336a c d e)f
+--R                      + 
+--R                          5 3   7       4 4 3 5       3 5 5 3       2 6 7   4
+--R                        (a c d e  - 195a c d e  - 464a c d e  - 224a c d e)f
+--R                      + 
+--R                               5 3 9      4 4 2 7       3 5 4 5       2 6 6 3
+--R                            - a c e  + 50a c d e  + 263a c d e  + 284a c d e
+--R                          + 
+--R                                 7 8
+--R                            80a c d e
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                                4 4   9      3 5 3 7       2 6 5 5        7 7 3
+--R                            - 5a c d e  - 78a c d e  - 141a c d e  - 80a c d e
+--R                          + 
+--R                                 8 9
+--R                            - 12c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                            3 5 2 9      2 6 4 7        7 6 5     8 8 3
+--R                        (13a c d e  + 33a c d e  + 27a c d e  + 7c d e )f
+--R                      + 
+--R                           3 5   11     2 6 3 9       7 5 7    8 7 5
+--R                        - a c d e   - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                           4       8        4   3      3 2 2   7
+--R                        12a c d e f  + (- 3a c e  - 48a c d e)f
+--R                      + 
+--R                            3 2   3      2 3 3   6
+--R                        (24a c d e  + 72a c d e)f
+--R                      + 
+--R                             3 2 5      2 3 2 3        4 4   5
+--R                        (- 3a c e  - 70a c d e  - 48a c d e)f
+--R                      + 
+--R                            2 3   5        4 3 3      5 5   4
+--R                        (17a c d e  + 80a c d e  + 12c d e)f
+--R                      + 
+--R                            2 3 7        4 2 5      5 4 3  3
+--R                        (- a c e  - 37a c d e  - 31c d e )f
+--R                      + 
+--R                             4   7      5 3 5  2     5 2 7     5   9
+--R                        (5a c d e  + 27c d e )f  - 9c d e f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      4 2 2 8      3 3   2 7
+--R                                  - 9a c e f  + 36a c d e f
+--R                                + 
+--R                                        3 3 4      2 4 2 2  6
+--R                                  (- 18a c e  - 54a c d e )f
+--R                                + 
+--R                                      2 4   4        5 3 2  5
+--R                                  (60a c d e  + 36a c d e )f
+--R                                + 
+--R                                        2 4 6        5 2 4     6 4 2  4
+--R                                  (- 15a c e  - 66a c d e  - 9c d e )f
+--R                                + 
+--R                                        5   6      6 3 4  3
+--R                                  (36a c d e  + 24c d e )f
+--R                                + 
+--R                                         5 8      6 2 6  2     6   8     6 10
+--R                                  (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 6      2     5        2   2        2 2  4
+--R                         - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R                       + 
+--R                               2   2     3 3  3          2 4      3 2 2  2
+--R                         (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f
+--R                       + 
+--R                            3   4      3 6
+--R                         12c d e f - 2c e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       2       7        2 2   6         2   3      3 3   5
+--R                    12a c d e f  - 24a c d e f  + (12a c d e  + 12c d e)f
+--R                  + 
+--R                         3 2 3 4     3   5 3
+--R                    - 16c d e f  + 4c d e f
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                          6   10        6 2      5   2  9
+--R                        8a d f   + (- 2a e  - 48a c d )f
+--R                      + 
+--R                            5     2       4 2 3  8
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   4       4 2 2 2       3 3 4  7
+--R                        (- 6a c e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2   4       3 3 3 2       2 4 5  6
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 6      3 3 2 4       2 4 4 2        5 6  5
+--R                        (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3   6      2 4 3 4        5 5 2     6 7  4
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3 8     2 4 2 6       5 4 4     6 6 2  3
+--R                        (- 2a c e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            2   2 7        2   2 6          2 4     3 2 2  5
+--R                        - 6a c e f  + 12a c d e f  + (- 6a c e  - 6c d e )f
+--R                      + 
+--R                          3   4 4     3 6 3
+--R                        8c d e f  - 2c e f
+--R                   *
+--R                      x
+--R                  + 
+--R                         2       7        2 2   6           2   3      3 3   5
+--R                    - 12a c d e f  + 24a c d e f  + (- 12a c d e  - 12c d e)f
+--R                  + 
+--R                       3 2 3 4     3   5 3
+--R                    16c d e f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +-----------+ +--------+
+--R             3 2     2         2   2      2 2  +-+ |          2  |   2
+--R           (a f  - 2a c d f + a c e  + a c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                     +-----------+
+--R               3 2     2         2   2      2 2  +-+ |          2  +-+
+--R           (- a f  + 2a c d f - a c e  - a c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             4 2 2 8      3 3   2 7
+--R                         - 9a c e f  + 36a c d e f
+--R                       + 
+--R                               3 3 4      2 4 2 2  6
+--R                         (- 18a c e  - 54a c d e )f
+--R                       + 
+--R                             2 4   4        5 3 2  5
+--R                         (60a c d e  + 36a c d e )f
+--R                       + 
+--R                               2 4 6        5 2 4     6 4 2  4
+--R                         (- 15a c e  - 66a c d e  - 9c d e )f
+--R                       + 
+--R                               5   6      6 3 4  3          5 8      6 2 6  2
+--R                         (36a c d e  + 24c d e )f  + (- 6a c e  - 22c d e )f
+--R                       + 
+--R                           6   8     6 10
+--R                         8c d e f - c e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 6      2     5        2   2        2 2  4
+--R                - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R              + 
+--R                      2   2     3 3  3          2 4      3 2 2  2      3   4
+--R                (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f  + 12c d e f
+--R              + 
+--R                    3 6
+--R                - 2c e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                          8     10       8 3      7   2   9      7     3 8
+--R                        4a d e f   + (- a e  - 16a c d e)f  + 16a c d e f
+--R                      + 
+--R                             7   5      6 2 2 3       5 3 4   7
+--R                        (- 3a c e  - 20a c d e  + 112a c d e)f
+--R                      + 
+--R                            6 2   5       5 3 3 3       4 4 5   6
+--R                        (17a c d e  - 112a c d e  - 280a c d e)f
+--R                      + 
+--R                             6 2 7      5 3 2 5       4 4 4 3       3 5 6   5
+--R                        (- 3a c e  + 33a c d e  + 370a c d e  + 336a c d e)f
+--R                      + 
+--R                          5 3   7       4 4 3 5       3 5 5 3       2 6 7   4
+--R                        (a c d e  - 195a c d e  - 464a c d e  - 224a c d e)f
+--R                      + 
+--R                               5 3 9      4 4 2 7       3 5 4 5       2 6 6 3
+--R                            - a c e  + 50a c d e  + 263a c d e  + 284a c d e
+--R                          + 
+--R                                 7 8
+--R                            80a c d e
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                                4 4   9      3 5 3 7       2 6 5 5        7 7 3
+--R                            - 5a c d e  - 78a c d e  - 141a c d e  - 80a c d e
+--R                          + 
+--R                                 8 9
+--R                            - 12c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                            3 5 2 9      2 6 4 7        7 6 5     8 8 3
+--R                        (13a c d e  + 33a c d e  + 27a c d e  + 7c d e )f
+--R                      + 
+--R                           3 5   11     2 6 3 9       7 5 7    8 7 5
+--R                        - a c d e   - 3a c d e  - 3a c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                             4       8      4   3      3 2 2   7
+--R                        - 12a c d e f  + (3a c e  + 48a c d e)f
+--R                      + 
+--R                              3 2   3      2 3 3   6
+--R                        (- 24a c d e  - 72a c d e)f
+--R                      + 
+--R                           3 2 5      2 3 2 3        4 4   5
+--R                        (3a c e  + 70a c d e  + 48a c d e)f
+--R                      + 
+--R                              2 3   5        4 3 3      5 5   4
+--R                        (- 17a c d e  - 80a c d e  - 12c d e)f
+--R                      + 
+--R                          2 3 7        4 2 5      5 4 3  3
+--R                        (a c e  + 37a c d e  + 31c d e )f
+--R                      + 
+--R                               4   7      5 3 5  2     5 2 7     5   9
+--R                        (- 5a c d e  - 27c d e )f  + 9c d e f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      4 2 2 8      3 3   2 7
+--R                                  - 9a c e f  + 36a c d e f
+--R                                + 
+--R                                        3 3 4      2 4 2 2  6
+--R                                  (- 18a c e  - 54a c d e )f
+--R                                + 
+--R                                      2 4   4        5 3 2  5
+--R                                  (60a c d e  + 36a c d e )f
+--R                                + 
+--R                                        2 4 6        5 2 4     6 4 2  4
+--R                                  (- 15a c e  - 66a c d e  - 9c d e )f
+--R                                + 
+--R                                        5   6      6 3 4  3
+--R                                  (36a c d e  + 24c d e )f
+--R                                + 
+--R                                         5 8      6 2 6  2     6   8     6 10
+--R                                  (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 6      2     5        2   2        2 2  4
+--R                         - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R                       + 
+--R                               2   2     3 3  3          2 4      3 2 2  2
+--R                         (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f
+--R                       + 
+--R                            3   4      3 6
+--R                         12c d e f - 2c e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       2       7        2 2   6         2   3      3 3   5
+--R                    12a c d e f  - 24a c d e f  + (12a c d e  + 12c d e)f
+--R                  + 
+--R                         3 2 3 4     3   5 3
+--R                    - 16c d e f  + 4c d e f
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                            6   10      6 2      5   2  9
+--R                        - 8a d f   + (2a e  + 48a c d )f
+--R                      + 
+--R                              5     2       4 2 3  8
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   4       4 2 2 2       3 3 4  7
+--R                        (6a c e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2   4       3 3 3 2       2 4 5  6
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 6      3 3 2 4       2 4 4 2        5 6  5
+--R                        (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3   6      2 4 3 4        5 5 2     6 7  4
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3 8     2 4 2 6       5 4 4     6 6 2  3
+--R                        (2a c e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            2   2 7        2   2 6          2 4     3 2 2  5
+--R                        - 6a c e f  + 12a c d e f  + (- 6a c e  - 6c d e )f
+--R                      + 
+--R                          3   4 4     3 6 3
+--R                        8c d e f  - 2c e f
+--R                   *
+--R                      x
+--R                  + 
+--R                         2       7        2 2   6           2   3      3 3   5
+--R                    - 12a c d e f  + 24a c d e f  + (- 12a c d e  - 12c d e)f
+--R                  + 
+--R                       3 2 3 4     3   5 3
+--R                    16c d e f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                     +-----------+ +--------+
+--R               3 2     2         2   2      2 2  +-+ |          2  |   2
+--R           (- a f  + 2a c d f - a c e  - a c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                   +-----------+
+--R             3 2     2         2   2      2 2  +-+ |          2  +-+
+--R           (a f  - 2a c d f + a c e  + a c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R         ROOT
+--R                        6   7      6 2      5   2  6
+--R                    - 8a d f  + (2a e  + 48a c d )f
+--R                  + 
+--R                          5     2       4 2 3  5
+--R                    (- 36a c d e  - 120a c d )f
+--R                  + 
+--R                       5   4       4 2 2 2       3 3 4  4
+--R                    (6a c e  + 126a c d e  + 160a c d )f
+--R                  + 
+--R                          4 2   4       3 3 3 2       2 4 5  3
+--R                    (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                  + 
+--R                       4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                  + 
+--R                          3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f + 2a c e
+--R                  + 
+--R                      2 4 2 6       5 4 4     6 6 2
+--R                    6a c d e  + 6a c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                             4 2 2 8      3 3   2 7
+--R                         - 9a c e f  + 36a c d e f
+--R                       + 
+--R                               3 3 4      2 4 2 2  6
+--R                         (- 18a c e  - 54a c d e )f
+--R                       + 
+--R                             2 4   4        5 3 2  5
+--R                         (60a c d e  + 36a c d e )f
+--R                       + 
+--R                               2 4 6        5 2 4     6 4 2  4
+--R                         (- 15a c e  - 66a c d e  - 9c d e )f
+--R                       + 
+--R                               5   6      6 3 4  3          5 8      6 2 6  2
+--R                         (36a c d e  + 24c d e )f  + (- 6a c e  - 22c d e )f
+--R                       + 
+--R                           6   8     6 10
+--R                         8c d e f - c e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 6      2     5        2   2        2 2  4
+--R                - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R              + 
+--R                      2   2     3 3  3          2 4      3 2 2  2      3   4
+--R                (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f  + 12c d e f
+--R              + 
+--R                    3 6
+--R                - 2c e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         log
+--R                            8     10     8 3      7   2   9      7     3 8
+--R                        - 4a d e f   + (a e  + 16a c d e)f  - 16a c d e f
+--R                      + 
+--R                           7   5      6 2 2 3       5 3 4   7
+--R                        (3a c e  + 20a c d e  - 112a c d e)f
+--R                      + 
+--R                              6 2   5       5 3 3 3       4 4 5   6
+--R                        (- 17a c d e  + 112a c d e  + 280a c d e)f
+--R                      + 
+--R                           6 2 7      5 3 2 5       4 4 4 3       3 5 6   5
+--R                        (3a c e  - 33a c d e  - 370a c d e  - 336a c d e)f
+--R                      + 
+--R                            5 3   7       4 4 3 5       3 5 5 3       2 6 7   4
+--R                        (- a c d e  + 195a c d e  + 464a c d e  + 224a c d e)f
+--R                      + 
+--R                             5 3 9      4 4 2 7       3 5 4 5       2 6 6 3
+--R                            a c e  - 50a c d e  - 263a c d e  - 284a c d e
+--R                          + 
+--R                                   7 8
+--R                            - 80a c d e
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                              4 4   9      3 5 3 7       2 6 5 5        7 7 3
+--R                            5a c d e  + 78a c d e  + 141a c d e  + 80a c d e
+--R                          + 
+--R                               8 9
+--R                            12c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                              3 5 2 9      2 6 4 7        7 6 5     8 8 3
+--R                        (- 13a c d e  - 33a c d e  - 27a c d e  - 7c d e )f
+--R                      + 
+--R                         3 5   11     2 6 3 9       7 5 7    8 7 5
+--R                        a c d e   + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                           4       8        4   3      3 2 2   7
+--R                        12a c d e f  + (- 3a c e  - 48a c d e)f
+--R                      + 
+--R                            3 2   3      2 3 3   6
+--R                        (24a c d e  + 72a c d e)f
+--R                      + 
+--R                             3 2 5      2 3 2 3        4 4   5
+--R                        (- 3a c e  - 70a c d e  - 48a c d e)f
+--R                      + 
+--R                            2 3   5        4 3 3      5 5   4
+--R                        (17a c d e  + 80a c d e  + 12c d e)f
+--R                      + 
+--R                            2 3 7        4 2 5      5 4 3  3
+--R                        (- a c e  - 37a c d e  - 31c d e )f
+--R                      + 
+--R                             4   7      5 3 5  2     5 2 7     5   9
+--R                        (5a c d e  + 27c d e )f  - 9c d e f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   7      6 2      5   2  6
+--R                             - 8a d f  + (2a e  + 48a c d )f
+--R                           + 
+--R                                   5     2       4 2 3  5
+--R                             (- 36a c d e  - 120a c d )f
+--R                           + 
+--R                                5   4       4 2 2 2       3 3 4  4
+--R                             (6a c e  + 126a c d e  + 160a c d )f
+--R                           + 
+--R                                   4 2   4       3 3 3 2       2 4 5  3
+--R                             (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                           + 
+--R                                4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                           + 
+--R                                   3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                           + 
+--R                               3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             2a c e  + 6a c d e  + 6a c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                      4 2 2 8      3 3   2 7
+--R                                  - 9a c e f  + 36a c d e f
+--R                                + 
+--R                                        3 3 4      2 4 2 2  6
+--R                                  (- 18a c e  - 54a c d e )f
+--R                                + 
+--R                                      2 4   4        5 3 2  5
+--R                                  (60a c d e  + 36a c d e )f
+--R                                + 
+--R                                        2 4 6        5 2 4     6 4 2  4
+--R                                  (- 15a c e  - 66a c d e  - 9c d e )f
+--R                                + 
+--R                                        5   6      6 3 4  3
+--R                                  (36a c d e  + 24c d e )f
+--R                                + 
+--R                                         5 8      6 2 6  2     6   8     6 10
+--R                                  (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 6      2     5        2   2        2 2  4
+--R                         - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R                       + 
+--R                               2   2     3 3  3          2 4      3 2 2  2
+--R                         (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f
+--R                       + 
+--R                            3   4      3 6
+--R                         12c d e f - 2c e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       2       7        2 2   6         2   3      3 3   5
+--R                    12a c d e f  - 24a c d e f  + (12a c d e  + 12c d e)f
+--R                  + 
+--R                         3 2 3 4     3   5 3
+--R                    - 16c d e f  + 4c d e f
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                            6   10      6 2      5   2  9
+--R                        - 8a d f   + (2a e  + 48a c d )f
+--R                      + 
+--R                              5     2       4 2 3  8
+--R                        (- 36a c d e  - 120a c d )f
+--R                      + 
+--R                           5   4       4 2 2 2       3 3 4  7
+--R                        (6a c e  + 126a c d e  + 160a c d )f
+--R                      + 
+--R                              4 2   4       3 3 3 2       2 4 5  6
+--R                        (- 48a c d e  - 184a c d e  - 120a c d )f
+--R                      + 
+--R                           4 2 6      3 3 2 4       2 4 4 2        5 6  5
+--R                        (6a c e  + 84a c d e  + 126a c d e  + 48a c d )f
+--R                      + 
+--R                              3 3   6      2 4 3 4        5 5 2     6 7  4
+--R                        (- 20a c d e  - 48a c d e  - 36a c d e  - 8c d )f
+--R                      + 
+--R                           3 3 8     2 4 2 6       5 4 4     6 6 2  3
+--R                        (2a c e  + 6a c d e  + 6a c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            2   2 7        2   2 6          2 4     3 2 2  5
+--R                        - 6a c e f  + 12a c d e f  + (- 6a c e  - 6c d e )f
+--R                      + 
+--R                          3   4 4     3 6 3
+--R                        8c d e f  - 2c e f
+--R                   *
+--R                      x
+--R                  + 
+--R                         2       7        2 2   6           2   3      3 3   5
+--R                    - 12a c d e f  + 24a c d e f  + (- 12a c d e  - 12c d e)f
+--R                  + 
+--R                       3 2 3 4     3   5 3
+--R                    16c d e f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                                                   +-----------+ +--------+
+--R             3 2     2         2   2      2 2  +-+ |          2  |   2
+--R           (a f  - 2a c d f + a c e  + a c d )\|2 \|- 4d f + e  \|c x  + a
+--R         + 
+--R                                                     +-----------+
+--R               3 2     2         2   2      2 2  +-+ |          2  +-+
+--R           (- a f  + 2a c d f - a c e  - a c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R         ROOT
+--R                      6   7        6 2      5   2  6
+--R                    8a d f  + (- 2a e  - 48a c d )f
+--R                  + 
+--R                        5     2       4 2 3  5
+--R                    (36a c d e  + 120a c d )f
+--R                  + 
+--R                         5   4       4 2 2 2       3 3 4  4
+--R                    (- 6a c e  - 126a c d e  - 160a c d )f
+--R                  + 
+--R                        4 2   4       3 3 3 2       2 4 5  3
+--R                    (48a c d e  + 184a c d e  + 120a c d )f
+--R                  + 
+--R                         4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                    (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                  + 
+--R                        3 3   6      2 4 3 4        5 5 2     6 7       3 3 8
+--R                    (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f - 2a c e
+--R                  + 
+--R                        2 4 2 6       5 4 4     6 6 2
+--R                    - 6a c d e  - 6a c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                             4 2 2 8      3 3   2 7
+--R                         - 9a c e f  + 36a c d e f
+--R                       + 
+--R                               3 3 4      2 4 2 2  6
+--R                         (- 18a c e  - 54a c d e )f
+--R                       + 
+--R                             2 4   4        5 3 2  5
+--R                         (60a c d e  + 36a c d e )f
+--R                       + 
+--R                               2 4 6        5 2 4     6 4 2  4
+--R                         (- 15a c e  - 66a c d e  - 9c d e )f
+--R                       + 
+--R                               5   6      6 3 4  3          5 8      6 2 6  2
+--R                         (36a c d e  + 24c d e )f  + (- 6a c e  - 22c d e )f
+--R                       + 
+--R                           6   8     6 10
+--R                         8c d e f - c e
+--R                    /
+--R                           12   13       12 2      11   2  12
+--R                         4a  d f   + (- a  e  - 48a  c d )f
+--R                       + 
+--R                             11     2       10 2 3  11
+--R                         (36a  c d e  + 264a  c d )f
+--R                       + 
+--R                              11   4       10 2 2 2       9 3 4  10
+--R                         (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                       + 
+--R                              10 2   4        9 3 3 2        8 4 5  9
+--R                         (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                       + 
+--R                                    10 2 6       9 3 2 4        8 4 4 2
+--R                               - 15a  c e  - 750a c d e  - 3375a c d e
+--R                             + 
+--R                                      7 5 6
+--R                               - 3168a c d
+--R                        *
+--R                            8
+--R                           f
+--R                       + 
+--R                                 9 3   6        8 4 3 4        7 5 5 2
+--R                             200a c d e  + 2400a c d e  + 5832a c d e
+--R                           + 
+--R                                  6 6 7
+--R                             3696a c d
+--R                        *
+--R                            7
+--R                           f
+--R                       + 
+--R                                  9 3 8       8 4 2 6        7 5 4 4
+--R                             - 20a c e  - 900a c d e  - 4620a c d e
+--R                           + 
+--R                                    6 6 6 2        5 7 8
+--R                             - 6972a c d e  - 3168a c d
+--R                        *
+--R                            6
+--R                           f
+--R                       + 
+--R                                 8 4   8        7 5 3 6        6 6 5 4
+--R                             180a c d e  + 2040a c d e  + 5712a c d e
+--R                           + 
+--R                                  5 7 7 2        4 8 9
+--R                             5832a c d e  + 1980a c d
+--R                        *
+--R                            5
+--R                           f
+--R                       + 
+--R                                  8 4 10       7 5 2 8        6 6 4 6
+--R                             - 15a c e   - 540a c d e  - 2650a c d e
+--R                           + 
+--R                                    5 7 6 4        4 8 8 2       3 9 10
+--R                             - 4620a c d e  - 3375a c d e  - 880a c d
+--R                        *
+--R                            4
+--R                           f
+--R                       + 
+--R                                7 5   10       6 6 3 8        5 7 5 6
+--R                             84a c d e   + 760a c d e  + 2040a c d e
+--R                           + 
+--R                                  4 8 7 4        3 9 9 2       2 10 11
+--R                             2400a c d e  + 1300a c d e  + 264a c  d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                 7 5 12       6 6 2 10       5 7 4 8
+--R                             - 6a c e   - 138a c d e   - 540a c d e
+--R                           + 
+--R                                   4 8 6 6       3 9 8 4       2 10 10 2
+--R                             - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                           + 
+--R                                    11 12
+--R                             - 48a c  d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                                6 6   12      5 7 3 10       4 8 5 8
+--R                             16a c d e   + 84a c d e   + 180a c d e
+--R                           + 
+--R                               3 9 7 6       2 10 9 4        11 11 2     12 13
+--R                           200a c d e  + 120a c  d e  + 36a c  d  e  + 4c  d
+--R                        *
+--R                           f
+--R                       + 
+--R                            6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                         - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                       + 
+--R                              2 10 8 6       11 10 4    12 12 2
+--R                         - 15a c  d e  - 6a c  d  e  - c  d  e
+--R              + 
+--R                    3 6      2     5        2   2        2 2  4
+--R                - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R              + 
+--R                      2   2     3 3  3          2 4      3 2 2  2      3   4
+--R                (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f  + 12c d e f
+--R              + 
+--R                    3 6
+--R                - 2c e
+--R           /
+--R                  6   7       6 2      5   2  6       5     2      4 2 3  5
+--R                4a d f  + (- a e  - 24a c d )f  + (18a c d e  + 60a c d )f
+--R              + 
+--R                     5   4      4 2 2 2      3 3 4  4
+--R                (- 3a c e  - 63a c d e  - 80a c d )f
+--R              + 
+--R                    4 2   4      3 3 3 2      2 4 5  3
+--R                (24a c d e  + 92a c d e  + 60a c d )f
+--R              + 
+--R                     4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R              + 
+--R                    3 3   6      2 4 3 4        5 5 2     6 7      3 3 8
+--R                (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f - a c e
+--R              + 
+--R                    2 4 2 6       5 4 4    6 6 2
+--R                - 3a c d e  - 3a c d e  - c d e
+--R      *
+--R         log
+--R                            8     10     8 3      7   2   9      7     3 8
+--R                        - 4a d e f   + (a e  + 16a c d e)f  - 16a c d e f
+--R                      + 
+--R                           7   5      6 2 2 3       5 3 4   7
+--R                        (3a c e  + 20a c d e  - 112a c d e)f
+--R                      + 
+--R                              6 2   5       5 3 3 3       4 4 5   6
+--R                        (- 17a c d e  + 112a c d e  + 280a c d e)f
+--R                      + 
+--R                           6 2 7      5 3 2 5       4 4 4 3       3 5 6   5
+--R                        (3a c e  - 33a c d e  - 370a c d e  - 336a c d e)f
+--R                      + 
+--R                            5 3   7       4 4 3 5       3 5 5 3       2 6 7   4
+--R                        (- a c d e  + 195a c d e  + 464a c d e  + 224a c d e)f
+--R                      + 
+--R                             5 3 9      4 4 2 7       3 5 4 5       2 6 6 3
+--R                            a c e  - 50a c d e  - 263a c d e  - 284a c d e
+--R                          + 
+--R                                   7 8
+--R                            - 80a c d e
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                              4 4   9      3 5 3 7       2 6 5 5        7 7 3
+--R                            5a c d e  + 78a c d e  + 141a c d e  + 80a c d e
+--R                          + 
+--R                               8 9
+--R                            12c d e
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                              3 5 2 9      2 6 4 7        7 6 5     8 8 3
+--R                        (- 13a c d e  - 33a c d e  - 27a c d e  - 7c d e )f
+--R                      + 
+--R                         3 5   11     2 6 3 9       7 5 7    8 7 5
+--R                        a c d e   + 3a c d e  + 3a c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                             4       8      4   3      3 2 2   7
+--R                        - 12a c d e f  + (3a c e  + 48a c d e)f
+--R                      + 
+--R                              3 2   3      2 3 3   6
+--R                        (- 24a c d e  - 72a c d e)f
+--R                      + 
+--R                           3 2 5      2 3 2 3        4 4   5
+--R                        (3a c e  + 70a c d e  + 48a c d e)f
+--R                      + 
+--R                              2 3   5        4 3 3      5 5   4
+--R                        (- 17a c d e  - 80a c d e  - 12c d e)f
+--R                      + 
+--R                          2 3 7        4 2 5      5 4 3  3
+--R                        (a c e  + 37a c d e  + 31c d e )f
+--R                      + 
+--R                               4   7      5 3 5  2     5 2 7     5   9
+--R                        (- 5a c d e  - 27c d e )f  + 9c d e f - c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   7        6 2      5   2  6
+--R                             8a d f  + (- 2a e  - 48a c d )f
+--R                           + 
+--R                                 5     2       4 2 3  5
+--R                             (36a c d e  + 120a c d )f
+--R                           + 
+--R                                  5   4       4 2 2 2       3 3 4  4
+--R                             (- 6a c e  - 126a c d e  - 160a c d )f
+--R                           + 
+--R                                 4 2   4       3 3 3 2       2 4 5  3
+--R                             (48a c d e  + 184a c d e  + 120a c d )f
+--R                           + 
+--R                                  4 2 6      3 3 2 4       2 4 4 2        5 6  2
+--R                             (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                           + 
+--R                                 3 3   6      2 4 3 4        5 5 2     6 7
+--R                             (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                           + 
+--R                                 3 3 8     2 4 2 6       5 4 4     6 6 2
+--R                             - 2a c e  - 6a c d e  - 6a c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                      4 2 2 8      3 3   2 7
+--R                                  - 9a c e f  + 36a c d e f
+--R                                + 
+--R                                        3 3 4      2 4 2 2  6
+--R                                  (- 18a c e  - 54a c d e )f
+--R                                + 
+--R                                      2 4   4        5 3 2  5
+--R                                  (60a c d e  + 36a c d e )f
+--R                                + 
+--R                                        2 4 6        5 2 4     6 4 2  4
+--R                                  (- 15a c e  - 66a c d e  - 9c d e )f
+--R                                + 
+--R                                        5   6      6 3 4  3
+--R                                  (36a c d e  + 24c d e )f
+--R                                + 
+--R                                         5 8      6 2 6  2     6   8     6 10
+--R                                  (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                             /
+--R                                    12   13       12 2      11   2  12
+--R                                  4a  d f   + (- a  e  - 48a  c d )f
+--R                                + 
+--R                                      11     2       10 2 3  11
+--R                                  (36a  c d e  + 264a  c d )f
+--R                                + 
+--R                                       11   4       10 2 2 2       9 3 4  10
+--R                                  (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                                + 
+--R                                       10 2   4        9 3 3 2        8 4 5  9
+--R                                  (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                                + 
+--R                                           10 2 6       9 3 2 4        8 4 4 2
+--R                                      - 15a  c e  - 750a c d e  - 3375a c d e
+--R                                    + 
+--R                                             7 5 6
+--R                                      - 3168a c d
+--R                                 *
+--R                                     8
+--R                                    f
+--R                                + 
+--R                                          9 3   6        8 4 3 4        7 5 5 2
+--R                                      200a c d e  + 2400a c d e  + 5832a c d e
+--R                                    + 
+--R                                           6 6 7
+--R                                      3696a c d
+--R                                 *
+--R                                     7
+--R                                    f
+--R                                + 
+--R                                           9 3 8       8 4 2 6        7 5 4 4
+--R                                      - 20a c e  - 900a c d e  - 4620a c d e
+--R                                    + 
+--R                                             6 6 6 2        5 7 8
+--R                                      - 6972a c d e  - 3168a c d
+--R                                 *
+--R                                     6
+--R                                    f
+--R                                + 
+--R                                          8 4   8        7 5 3 6        6 6 5 4
+--R                                      180a c d e  + 2040a c d e  + 5712a c d e
+--R                                    + 
+--R                                           5 7 7 2        4 8 9
+--R                                      5832a c d e  + 1980a c d
+--R                                 *
+--R                                     5
+--R                                    f
+--R                                + 
+--R                                           8 4 10       7 5 2 8        6 6 4 6
+--R                                      - 15a c e   - 540a c d e  - 2650a c d e
+--R                                    + 
+--R                                           5 7 6 4        4 8 8 2       3 9 10
+--R                                    - 4620a c d e  - 3375a c d e  - 880a c d
+--R                                 *
+--R                                     4
+--R                                    f
+--R                                + 
+--R                                         7 5   10       6 6 3 8        5 7 5 6
+--R                                      84a c d e   + 760a c d e  + 2040a c d e
+--R                                    + 
+--R                                           4 8 7 4        3 9 9 2       2 10 11
+--R                                      2400a c d e  + 1300a c d e  + 264a c  d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                          7 5 12       6 6 2 10       5 7 4 8
+--R                                      - 6a c e   - 138a c d e   - 540a c d e
+--R                                    + 
+--R                                            4 8 6 6       3 9 8 4
+--R                                      - 900a c d e  - 750a c d e
+--R                                    + 
+--R                                            2 10 10 2        11 12
+--R                                      - 306a c  d  e  - 48a c  d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                         6 6   12      5 7 3 10       4 8 5 8
+--R                                      16a c d e   + 84a c d e   + 180a c d e
+--R                                    + 
+--R                                          3 9 7 6       2 10 9 4        11 11 2
+--R                                      200a c d e  + 120a c  d e  + 36a c  d  e
+--R                                    + 
+--R                                        12 13
+--R                                      4c  d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     6 6 14     5 7 2 12      4 8 4 10
+--R                                  - a c e   - 6a c d e   - 15a c d e
+--R                                + 
+--R                                       3 9 6 8      2 10 8 6       11 10 4
+--R                                  - 20a c d e  - 15a c  d e  - 6a c  d  e
+--R                                + 
+--R                                     12 12 2
+--R                                  - c  d  e
+--R                       + 
+--R                             3 6      2     5        2   2        2 2  4
+--R                         - 4a f  + 12a c d f  + (- 6a c e  - 12a c d )f
+--R                       + 
+--R                               2   2     3 3  3          2 4      3 2 2  2
+--R                         (24a c d e  + 4c d )f  + (- 6a c e  - 18c d e )f
+--R                       + 
+--R                            3   4      3 6
+--R                         12c d e f - 2c e
+--R                    /
+--R                           6   7       6 2      5   2  6
+--R                         4a d f  + (- a e  - 24a c d )f
+--R                       + 
+--R                             5     2      4 2 3  5
+--R                         (18a c d e  + 60a c d )f
+--R                       + 
+--R                              5   4      4 2 2 2      3 3 4  4
+--R                         (- 3a c e  - 63a c d e  - 80a c d )f
+--R                       + 
+--R                             4 2   4      3 3 3 2      2 4 5  3
+--R                         (24a c d e  + 92a c d e  + 60a c d )f
+--R                       + 
+--R                              4 2 6      3 3 2 4      2 4 4 2        5 6  2
+--R                         (- 3a c e  - 42a c d e  - 63a c d e  - 24a c d )f
+--R                       + 
+--R                             3 3   6      2 4 3 4        5 5 2     6 7
+--R                         (10a c d e  + 24a c d e  + 18a c d e  + 4c d )f
+--R                       + 
+--R                            3 3 8     2 4 2 6       5 4 4    6 6 2
+--R                         - a c e  - 3a c d e  - 3a c d e  - c d e
+--R              + 
+--R                       2       7        2 2   6         2   3      3 3   5
+--R                    12a c d e f  - 24a c d e f  + (12a c d e  + 12c d e)f
+--R                  + 
+--R                         3 2 3 4     3   5 3
+--R                    - 16c d e f  + 4c d e f
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|c x  + a
+--R              + 
+--R                          6   10        6 2      5   2  9
+--R                        8a d f   + (- 2a e  - 48a c d )f
+--R                      + 
+--R                            5     2       4 2 3  8
+--R                        (36a c d e  + 120a c d )f
+--R                      + 
+--R                             5   4       4 2 2 2       3 3 4  7
+--R                        (- 6a c e  - 126a c d e  - 160a c d )f
+--R                      + 
+--R                            4 2   4       3 3 3 2       2 4 5  6
+--R                        (48a c d e  + 184a c d e  + 120a c d )f
+--R                      + 
+--R                             4 2 6      3 3 2 4       2 4 4 2        5 6  5
+--R                        (- 6a c e  - 84a c d e  - 126a c d e  - 48a c d )f
+--R                      + 
+--R                            3 3   6      2 4 3 4        5 5 2     6 7  4
+--R                        (20a c d e  + 48a c d e  + 36a c d e  + 8c d )f
+--R                      + 
+--R                             3 3 8     2 4 2 6       5 4 4     6 6 2  3
+--R                        (- 2a c e  - 6a c d e  - 6a c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 2 8      3 3   2 7
+--R                             - 9a c e f  + 36a c d e f
+--R                           + 
+--R                                   3 3 4      2 4 2 2  6
+--R                             (- 18a c e  - 54a c d e )f
+--R                           + 
+--R                                 2 4   4        5 3 2  5
+--R                             (60a c d e  + 36a c d e )f
+--R                           + 
+--R                                   2 4 6        5 2 4     6 4 2  4
+--R                             (- 15a c e  - 66a c d e  - 9c d e )f
+--R                           + 
+--R                                   5   6      6 3 4  3
+--R                             (36a c d e  + 24c d e )f
+--R                           + 
+--R                                    5 8      6 2 6  2     6   8     6 10
+--R                             (- 6a c e  - 22c d e )f  + 8c d e f - c e
+--R                        /
+--R                               12   13       12 2      11   2  12
+--R                             4a  d f   + (- a  e  - 48a  c d )f
+--R                           + 
+--R                                 11     2       10 2 3  11
+--R                             (36a  c d e  + 264a  c d )f
+--R                           + 
+--R                                  11   4       10 2 2 2       9 3 4  10
+--R                             (- 6a  c e  - 306a  c d e  - 880a c d )f
+--R                           + 
+--R                                  10 2   4        9 3 3 2        8 4 5  9
+--R                             (120a  c d e  + 1300a c d e  + 1980a c d )f
+--R                           + 
+--R                                      10 2 6       9 3 2 4        8 4 4 2
+--R                                 - 15a  c e  - 750a c d e  - 3375a c d e
+--R                               + 
+--R                                        7 5 6
+--R                                 - 3168a c d
+--R                            *
+--R                                8
+--R                               f
+--R                           + 
+--R                                     9 3   6        8 4 3 4        7 5 5 2
+--R                                 200a c d e  + 2400a c d e  + 5832a c d e
+--R                               + 
+--R                                      6 6 7
+--R                                 3696a c d
+--R                            *
+--R                                7
+--R                               f
+--R                           + 
+--R                                      9 3 8       8 4 2 6        7 5 4 4
+--R                                 - 20a c e  - 900a c d e  - 4620a c d e
+--R                               + 
+--R                                        6 6 6 2        5 7 8
+--R                                 - 6972a c d e  - 3168a c d
+--R                            *
+--R                                6
+--R                               f
+--R                           + 
+--R                                     8 4   8        7 5 3 6        6 6 5 4
+--R                                 180a c d e  + 2040a c d e  + 5712a c d e
+--R                               + 
+--R                                      5 7 7 2        4 8 9
+--R                                 5832a c d e  + 1980a c d
+--R                            *
+--R                                5
+--R                               f
+--R                           + 
+--R                                      8 4 10       7 5 2 8        6 6 4 6
+--R                                 - 15a c e   - 540a c d e  - 2650a c d e
+--R                               + 
+--R                                        5 7 6 4        4 8 8 2       3 9 10
+--R                                 - 4620a c d e  - 3375a c d e  - 880a c d
+--R                            *
+--R                                4
+--R                               f
+--R                           + 
+--R                                    7 5   10       6 6 3 8        5 7 5 6
+--R                                 84a c d e   + 760a c d e  + 2040a c d e
+--R                               + 
+--R                                      4 8 7 4        3 9 9 2       2 10 11
+--R                                 2400a c d e  + 1300a c d e  + 264a c  d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                     7 5 12       6 6 2 10       5 7 4 8
+--R                                 - 6a c e   - 138a c d e   - 540a c d e
+--R                               + 
+--R                                       4 8 6 6       3 9 8 4       2 10 10 2
+--R                                 - 900a c d e  - 750a c d e  - 306a c  d  e
+--R                               + 
+--R                                        11 12
+--R                                 - 48a c  d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                    6 6   12      5 7 3 10       4 8 5 8
+--R                                 16a c d e   + 84a c d e   + 180a c d e
+--R                               + 
+--R                                     3 9 7 6       2 10 9 4        11 11 2
+--R                                 200a c d e  + 120a c  d e  + 36a c  d  e
+--R                               + 
+--R                                   12 13
+--R                                 4c  d
+--R                            *
+--R                               f
+--R                           + 
+--R                                6 6 14     5 7 2 12      4 8 4 10      3 9 6 8
+--R                             - a c e   - 6a c d e   - 15a c d e   - 20a c d e
+--R                           + 
+--R                                  2 10 8 6       11 10 4    12 12 2
+--R                             - 15a c  d e  - 6a c  d  e  - c  d  e
+--R                  + 
+--R                            2   2 7        2   2 6          2 4     3 2 2  5
+--R                        - 6a c e f  + 12a c d e f  + (- 6a c e  - 6c d e )f
+--R                      + 
+--R                          3   4 4     3 6 3
+--R                        8c d e f  - 2c e f
+--R                   *
+--R                      x
+--R                  + 
+--R                         2       7        2 2   6           2   3      3 3   5
+--R                    - 12a c d e f  + 24a c d e f  + (- 12a c d e  - 12c d e)f
+--R                  + 
+--R                       3 2 3 4     3   5 3
+--R                    16c d e f  - 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                     +-----------+                                 +--------+
+--R                     |          2      2 3           2         2   |   2
+--R           (2a c e f\|- 4d f + e   + 4a f  - 4a c d f  + 2a c e f)\|c x  + a
+--R         + 
+--R                       +-----------+
+--R                       |          2      2 3           2         2   +-+
+--R           (- 2a c e f\|- 4d f + e   - 4a f  + 4a c d f  - 2a c e f)\|a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                       +-----------+                                 +--------+
+--R                       |          2      2 3           2         2   |   2
+--R           (- 2a c e f\|- 4d f + e   + 4a f  - 4a c d f  + 2a c e f)\|c x  + a
+--R         + 
+--R                     +-----------+
+--R                     |          2      2 3           2         2   +-+
+--R           (2a c e f\|- 4d f + e   - 4a f  + 4a c d f  - 2a c e f)\|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                   +-----------+     +--------+              +-----------+
+--R               +-+ |          2  +-+ |   2               +-+ |          2
+--R         (2c e\|2 \|- 4d f + e  \|a \|c x  + a  - 2a c e\|2 \|- 4d f + e  )
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                                    +-----------+ +--------+
+--R            3 2     2          2   2       2 2  +-+ |          2  |   2
+--R         (2a f  - 4a c d f + 2a c e  + 2a c d )\|2 \|- 4d f + e  \|c x  + a
+--R       + 
+--R                                                      +-----------+
+--R              3 2     2          2   2       2 2  +-+ |          2  +-+
+--R         (- 2a f  + 4a c d f - 2a c e  - 2a c d )\|2 \|- 4d f + e  \|a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 1580
+--d0:=D(m0,x)
+--E 115
+
+)clear all
+
+--S 116 of 1580
+t0:=1/(x*(a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                      1
+--R   (1)  -------------------------------------------------------------
+--R                                                           +--------+
+--R              5        4               3        2          |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x  + a d x)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1580
+r0:=-atanh(sqrt(a+c*x^2)/sqrt(a))/(a^(3/2)*d)+1/(a*d*sqrt(a+c*x^2))+_
+   (-a*(a*f^2+c*(e^2-d*f))-c^2*d*e*x)/(a*d*(c^2*d^2+a^2*f^2+a*c*_
+   (e^2-2*d*f))*sqrt(a+c*x^2))+f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (2*e*(a*f^2+c*(e^2-2*d*f))-(a*f^2+c*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/_
+   (d*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-f*atanh((2*a*f-_
+   c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))))*(2*e*(a*f^2+c*(e^2-2*d*f))-(a*f^2+c*(e^2-_
+   d*f))*(e+sqrt(e^2-4*d*f)))/(d*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*_
+   sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                       +-----------+
+--R             2 3          2        2   |          2     2   3             2
+--R           (a f  - a c d f  + a c e f)\|- 4d f + e   + a e f  - 3a c d e f
+--R         + 
+--R                3
+--R           a c e f
+--R      *
+--R                         +-----------------------------------------+
+--R              +--------+ |    +-----------+
+--R          +-+ |   2      |    |          2        2               2
+--R         \|a \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                         +-----------+
+--R               2 3          2        2   |          2     2   3             2
+--R           (- a f  + a c d f  - a c e f)\|- 4d f + e   + a e f  - 3a c d e f
+--R         + 
+--R                3
+--R           a c e f
+--R      *
+--R                         +-------------------------------------------+
+--R              +--------+ |      +-----------+
+--R          +-+ |   2      |      |          2        2               2
+--R         \|a \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                     +-----------+ +--------+
+--R                 2 2                   2    2 2  +-+ |          2  |   2
+--R             (- a f  + 2a c d f - a c e  - c d )\|2 \|- 4d f + e  \|c x  + a
+--R          *
+--R                    +--------+
+--R                    |   2
+--R                   \|c x  + a
+--R             atanh(-----------)
+--R                        +-+
+--R                       \|a
+--R         + 
+--R                                            +-----------+
+--R               2                   2 2  +-+ |          2  +-+
+--R           (- c d e x - a c d f + c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                                   +-----------+     +--------+
+--R         3   2     2   2     2     2      2 3  +-+ |          2  +-+ |   2
+--R       (a d f  - 2a c d f + a c d e  + a c d )\|2 \|- 4d f + e  \|a \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 1580
+--a0:=integrate(t0,x)
+--E 118
+
+--S 119 of 1580
+--m0:=a0-r0
+--E 119
+
+--S 120 of 1580
+--d0:=D(m0,x)
+--E 120
+
+)clear all
+
+--S 121 of 1580
+t0:=1/(x^2*(a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                       1
+--R   (1)  --------------------------------------------------------------
+--R                                                            +--------+
+--R              6        5               4        3        2  |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x  + a d x )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1580
+r0:=e*atanh(sqrt(a+c*x^2)/sqrt(a))/(a^(3/2)*d^2)-e/(a*d^2*sqrt(a+c*x^2))+_
+   1/(a*d*x*sqrt(a+c*x^2))+(a*e*(a*f^2+c*(e^2-2*d*f))+c*d*(a*f^2+c*(e^2-_
+   d*f))*x)/(a*d^2*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(a+c*x^2))-_
+   2*sqrt(a+c*x^2)/(a^2*d*x)+f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (2*(c*d*e^2*f-(e^2-d*f)*(a*f^2+c*(e^2-d*f)))+e*(a*f^2+c*(e^2-2*d*f))*_
+   (e-sqrt(e^2-4*d*f)))/(d^2*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-_
+   f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*(c*d*e^2*f-_
+   (e^2-d*f)*(a*f^2+c*(e^2-d*f)))+e*(a*f^2+c*(e^2-2*d*f))*(e+sqrt(e^2-_
+   4*d*f)))/(d^2*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-_
+   4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                               +-----------+
+--R               3   3     2       2    2   3    |          2
+--R           (- a e f  + 2a c d e f  - a c e f)x\|- 4d f + e
+--R         + 
+--R              3   4       3 2     2   2  3     2     2 2    2   4
+--R           (2a d f  + (- a e  - 2a c d )f  + 4a c d e f  - a c e f)x
+--R      *
+--R                         +-----------------------------------------+
+--R              +--------+ |    +-----------+
+--R          +-+ |   2      |    |          2        2               2
+--R         \|a \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                             +-----------+
+--R             3   3     2       2    2   3    |          2
+--R           (a e f  - 2a c d e f  + a c e f)x\|- 4d f + e
+--R         + 
+--R              3   4       3 2     2   2  3     2     2 2    2   4
+--R           (2a d f  + (- a e  - 2a c d )f  + 4a c d e f  - a c e f)x
+--R      *
+--R                         +-------------------------------------------+
+--R              +--------+ |      +-----------+
+--R          +-+ |   2      |      |          2        2               2
+--R         \|a \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                           +-----------+
+--R               3   2     2           2   3      2 2    +-+ |          2
+--R             (a e f  - 2a c d e f + a c e  + a c d e)x\|2 \|- 4d f + e
+--R          *
+--R                               +--------+
+--R              +--------+       |   2
+--R              |   2           \|c x  + a
+--R             \|c x  + a atanh(-----------)
+--R                                   +-+
+--R                                  \|a
+--R         + 
+--R                   2     2       2 2       2   2     3 3  2      2 2       3   2
+--R               (- a c d f  + 3a c d f - a c d e  - 2c d )x  - a c d e x - a d f
+--R             + 
+--R                 2   2     2     2      2 3
+--R               2a c d f - a c d e  - a c d
+--R          *
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R             \|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                                    +-----------+     +--------+
+--R         4 2 2     3   3     3   2 2    2 2 4   +-+ |          2  +-+ |   2
+--R       (a d f  - 2a c d f + a c d e  + a c d )x\|2 \|- 4d f + e  \|a \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 1580
+--a0:=integrate(t0,x)
+--E 123
+
+--S 124 of 1580
+--m0:=a0-r0
+--E 124
+
+--S 125 of 1580
+--d0:=D(m0,x)
+--E 125
+
+)clear all
+
+--S 126 of 1580
+t0:=x^3*(a+b*x+c*x^2)^(1/2)/(d+f*x^2)
+--R 
+--R
+--R           +--------------+
+--R         3 |   2
+--R        x \|c x  + b x + a
+--R   (1)  -------------------
+--R                 2
+--R              f x  + d
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 1580
+r0:=1/3*(a+b*x+c*x^2)^(3/2)/(c*f)+1/16*b*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(5/2)*f)-1/2*b*d*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(f^2*sqrt(c))-d*sqrt(a+b*x+c*x^2)/f^2-_
+   1/8*b*(b+2*c*x)*sqrt(a+b*x+c*x^2)/(c^2*f)+1/2*d*atan(1/2*(b*sqrt(-d)+_
+   2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-_
+   a*f-b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))/f^(5/2)-_
+   1/2*d*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f+_
+   b*sqrt(-d)*sqrt(f))/f^(5/2)
+--R 
+--R
+--R   (2)
+--R                   +-------------------------+
+--R            2  +-+ |    +---+ +-+
+--R         24c d\|c \|- b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                   +-----------------------+
+--R            2  +-+ |  +---+ +-+
+--R         24c d\|c \|b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                       3          2   +-+             2c x + b
+--R       ((- 12a b c + 3b )f - 24b c d)\|f atanh(----------------------)
+--R                                                     +--------------+
+--R                                                 +-+ |   2
+--R                                               2\|c \|c x  + b x + a
+--R     + 
+--R                                                              +--------------+
+--R           2   2                         2        2   +-+ +-+ |   2
+--R       (16c f x  + 4b c f x + (16a c - 6b )f - 48c d)\|c \|f \|c x  + b x + a
+--R  /
+--R        2 2 +-+ +-+
+--R     48c f \|c \|f
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 1580
+--a0:=integrate(t0,x)
+--E 128
+
+--S 129 of 1580
+--m0:=a0-r0
+--E 129
+
+--S 130 of 1580
+--d0:=D(m0,x)
+--E 130
+
+)clear all
+
+--S 131 of 1580
+t0:=x^2*(a+b*x+c*x^2)^(1/2)/(d+f*x^2)
+--R 
+--R
+--R           +--------------+
+--R         2 |   2
+--R        x \|c x  + b x + a
+--R   (1)  -------------------
+--R                 2
+--R              f x  + d
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 1580
+r0:=-1/8*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (c^(3/2)*f)-d*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(c)/f^2+1/4*(b+2*c*x)*sqrt(a+b*x+c*x^2)/(c*f)-1/2*atan(1/2*(b*_
+   sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(-d)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))/f^2-1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-_
+   b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*_
+   sqrt(-d)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))/f^2
+--R 
+--R
+--R   (2)
+--R       -
+--R                         +-------------------------+
+--R               +---+ +-+ |    +---+ +-+
+--R            4c\|- d \|c \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                      +-----------------------+
+--R            +---+ +-+ |  +---+ +-+
+--R         4c\|- d \|c \|b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                 2       2               2c x + b
+--R       ((4a c - b )f - 8c d)atanh(----------------------)
+--R                                        +--------------+
+--R                                    +-+ |   2
+--R                                  2\|c \|c x  + b x + a
+--R     + 
+--R                           +--------------+
+--R                       +-+ |   2
+--R       (4c f x + 2b f)\|c \|c x  + b x + a
+--R  /
+--R         2 +-+
+--R     8c f \|c
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 1580
+--a0:=integrate(t0,x)
+--E 133
+
+--S 134 of 1580
+--m0:=a0-r0
+--E 134
+
+--S 135 of 1580
+--d0:=D(m0,x)
+--E 135
+
+)clear all
+
+--S 136 of 1580
+t0:=x*(a+b*x+c*x^2)^(1/2)/(d+f*x^2)
+--R 
+--R
+--R          +--------------+
+--R          |   2
+--R        x\|c x  + b x + a
+--R   (1)  ------------------
+--R                2
+--R             f x  + d
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 1580
+r0:=1/2*b*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f*sqrt(c))+_
+   sqrt(a+b*x+c*x^2)/f-1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*_
+   sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))/f^(3/2)+1/2*atan(1/2*(b*_
+   sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))/f^(3/2)
+--R 
+--R
+--R   (2)
+--R       -
+--R                 +-------------------------+
+--R             +-+ |    +---+ +-+
+--R            \|c \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                 +-----------------------+
+--R             +-+ |  +---+ +-+
+--R            \|c \|b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                                                      +--------------+
+--R         +-+             2c x + b             +-+ +-+ |   2
+--R       b\|f atanh(----------------------) + 2\|c \|f \|c x  + b x + a
+--R                        +--------------+
+--R                    +-+ |   2
+--R                  2\|c \|c x  + b x + a
+--R  /
+--R        +-+ +-+
+--R     2f\|c \|f
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 1580
+--a0:=integrate(t0,x)
+--E 138
+
+--S 139 of 1580
+--m0a:=a0.1-r0
+--E 139
+
+--S 140 of 1580
+--d0a:=D(m0a,x)
+--E 140
+
+--S 141 of 1580
+--m0b:=a0.2-r0
+--E 141
+
+--S 142 of 1580
+--d0b:=D(m0b,x)
+--E 142
+
+)clear all
+
+--S 143 of 1580
+t0:=(a+b*x+c*x^2)^(1/2)/(d+f*x^2)
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R                2
+--R             f x  + d
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 1580
+r0:=atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(c)/f-_
+   1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))/(f*sqrt(-d))-1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*_
+   sqrt(f))))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))/(f*sqrt(-d))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +-------------------------+
+--R             |    +---+ +-+
+--R            \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R         +---+ +-+             2c x + b
+--R       2\|- d \|c atanh(----------------------)
+--R                              +--------------+
+--R                          +-+ |   2
+--R                        2\|c \|c x  + b x + a
+--R  /
+--R        +---+
+--R     2f\|- d
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R         -
+--R                +---------------------------+
+--R                |      +-------+
+--R                |      |     2
+--R                |    2 |    b
+--R                |2d f  |- -----  - a f + c d
+--R                |      |      3
+--R                |     \|  4d f
+--R              f |---------------------------
+--R                |               2
+--R               \|            d f
+--R           *
+--R              log
+--R                           +---------------------------+
+--R                           |      +-------+
+--R                           |      |     2
+--R                           |    2 |    b
+--R                           |2d f  |- -----  - a f + c d
+--R                           |      |      3                   +--------------+
+--R                           |     \|  4d f                    |   2
+--R                     b f x |---------------------------  + b\|c x  + b x + a
+--R                           |               2
+--R                          \|            d f
+--R                   + 
+--R                           +-------+
+--R                           |     2
+--R                        2  |    b         +-+
+--R                     (2f x |- -----  - b)\|a
+--R                           |      3
+--R                          \|  4d f
+--R                /
+--R                   x
+--R       + 
+--R         -
+--R                +-----------------------------+
+--R                |        +-------+
+--R                |        |     2
+--R                |      2 |    b
+--R                |- 2d f  |- -----  - a f + c d
+--R                |        |      3
+--R                |       \|  4d f
+--R              f |-----------------------------
+--R                |                2
+--R               \|             d f
+--R           *
+--R              log
+--R                           +-----------------------------+
+--R                           |        +-------+
+--R                           |        |     2
+--R                           |      2 |    b
+--R                           |- 2d f  |- -----  - a f + c d
+--R                           |        |      3                   +--------------+
+--R                           |       \|  4d f                    |   2
+--R                     b f x |-----------------------------  + b\|c x  + b x + a
+--R                           |                2
+--R                          \|             d f
+--R                   + 
+--R                             +-------+
+--R                             |     2
+--R                          2  |    b         +-+
+--R                     (- 2f x |- -----  - b)\|a
+--R                             |      3
+--R                            \|  4d f
+--R                /
+--R                   x
+--R       + 
+--R             +-----------------------------+
+--R             |        +-------+
+--R             |        |     2
+--R             |      2 |    b
+--R             |- 2d f  |- -----  - a f + c d
+--R             |        |      3
+--R             |       \|  4d f
+--R           f |-----------------------------
+--R             |                2
+--R            \|             d f
+--R        *
+--R           log
+--R                          +-----------------------------+
+--R                          |        +-------+
+--R                          |        |     2
+--R                          |      2 |    b
+--R                          |- 2d f  |- -----  - a f + c d
+--R                          |        |      3                   +--------------+
+--R                          |       \|  4d f                    |   2
+--R                  - b f x |-----------------------------  + b\|c x  + b x + a
+--R                          |                2
+--R                         \|             d f
+--R                + 
+--R                          +-------+
+--R                          |     2
+--R                       2  |    b         +-+
+--R                  (- 2f x |- -----  - b)\|a
+--R                          |      3
+--R                         \|  4d f
+--R             /
+--R                x
+--R       + 
+--R             +---------------------------+
+--R             |      +-------+
+--R             |      |     2
+--R             |    2 |    b
+--R             |2d f  |- -----  - a f + c d
+--R             |      |      3
+--R             |     \|  4d f
+--R           f |---------------------------
+--R             |               2
+--R            \|            d f
+--R        *
+--R           log
+--R                          +---------------------------+
+--R                          |      +-------+
+--R                          |      |     2
+--R                          |    2 |    b
+--R                          |2d f  |- -----  - a f + c d
+--R                          |      |      3                   +--------------+
+--R                          |     \|  4d f                    |   2
+--R                  - b f x |---------------------------  + b\|c x  + b x + a
+--R                          |               2
+--R                         \|            d f
+--R                + 
+--R                        +-------+
+--R                        |     2
+--R                     2  |    b         +-+
+--R                  (2f x |- -----  - b)\|a
+--R                        |      3
+--R                       \|  4d f
+--R             /
+--R                x
+--R       + 
+--R             +-+
+--R           2\|c
+--R        *
+--R           log
+--R                                     +--------------+
+--R                        +-+     +-+  |   2                 +-+ +-+       2
+--R                  (- 2x\|c  + 2\|a )\|c x  + b x + a  + 2x\|a \|c  - 2c x  - b x
+--R                + 
+--R                  - 2a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R    /
+--R       2f
+--R     ,
+--R
+--R         -
+--R                +---------------------------+
+--R                |      +-------+
+--R                |      |     2
+--R                |    2 |    b
+--R                |2d f  |- -----  - a f + c d
+--R                |      |      3
+--R                |     \|  4d f
+--R              f |---------------------------
+--R                |               2
+--R               \|            d f
+--R           *
+--R              log
+--R                           +---------------------------+
+--R                           |      +-------+
+--R                           |      |     2
+--R                           |    2 |    b
+--R                           |2d f  |- -----  - a f + c d
+--R                           |      |      3                   +--------------+
+--R                           |     \|  4d f                    |   2
+--R                     b f x |---------------------------  + b\|c x  + b x + a
+--R                           |               2
+--R                          \|            d f
+--R                   + 
+--R                           +-------+
+--R                           |     2
+--R                        2  |    b         +-+
+--R                     (2f x |- -----  - b)\|a
+--R                           |      3
+--R                          \|  4d f
+--R                /
+--R                   x
+--R       + 
+--R         -
+--R                +-----------------------------+
+--R                |        +-------+
+--R                |        |     2
+--R                |      2 |    b
+--R                |- 2d f  |- -----  - a f + c d
+--R                |        |      3
+--R                |       \|  4d f
+--R              f |-----------------------------
+--R                |                2
+--R               \|             d f
+--R           *
+--R              log
+--R                           +-----------------------------+
+--R                           |        +-------+
+--R                           |        |     2
+--R                           |      2 |    b
+--R                           |- 2d f  |- -----  - a f + c d
+--R                           |        |      3                   +--------------+
+--R                           |       \|  4d f                    |   2
+--R                     b f x |-----------------------------  + b\|c x  + b x + a
+--R                           |                2
+--R                          \|             d f
+--R                   + 
+--R                             +-------+
+--R                             |     2
+--R                          2  |    b         +-+
+--R                     (- 2f x |- -----  - b)\|a
+--R                             |      3
+--R                            \|  4d f
+--R                /
+--R                   x
+--R       + 
+--R             +-----------------------------+
+--R             |        +-------+
+--R             |        |     2
+--R             |      2 |    b
+--R             |- 2d f  |- -----  - a f + c d
+--R             |        |      3
+--R             |       \|  4d f
+--R           f |-----------------------------
+--R             |                2
+--R            \|             d f
+--R        *
+--R           log
+--R                          +-----------------------------+
+--R                          |        +-------+
+--R                          |        |     2
+--R                          |      2 |    b
+--R                          |- 2d f  |- -----  - a f + c d
+--R                          |        |      3                   +--------------+
+--R                          |       \|  4d f                    |   2
+--R                  - b f x |-----------------------------  + b\|c x  + b x + a
+--R                          |                2
+--R                         \|             d f
+--R                + 
+--R                          +-------+
+--R                          |     2
+--R                       2  |    b         +-+
+--R                  (- 2f x |- -----  - b)\|a
+--R                          |      3
+--R                         \|  4d f
+--R             /
+--R                x
+--R       + 
+--R             +---------------------------+
+--R             |      +-------+
+--R             |      |     2
+--R             |    2 |    b
+--R             |2d f  |- -----  - a f + c d
+--R             |      |      3
+--R             |     \|  4d f
+--R           f |---------------------------
+--R             |               2
+--R            \|            d f
+--R        *
+--R           log
+--R                          +---------------------------+
+--R                          |      +-------+
+--R                          |      |     2
+--R                          |    2 |    b
+--R                          |2d f  |- -----  - a f + c d
+--R                          |      |      3                   +--------------+
+--R                          |     \|  4d f                    |   2
+--R                  - b f x |---------------------------  + b\|c x  + b x + a
+--R                          |               2
+--R                         \|            d f
+--R                + 
+--R                        +-------+
+--R                        |     2
+--R                     2  |    b         +-+
+--R                  (2f x |- -----  - b)\|a
+--R                        |      3
+--R                       \|  4d f
+--R             /
+--R                x
+--R       + 
+--R                      +--------------+
+--R                      |   2               +-+
+--R           +---+     \|c x  + b x + a  - \|a
+--R         4\|- c atan(------------------------)
+--R                                +---+
+--R                              x\|- c
+--R    /
+--R       2f
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 145
+
+--S 146 of 1580
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                    +---------------------------+
+--R                    |      +-------+
+--R                    |      |     2
+--R                    |    2 |    b
+--R                    |2d f  |- -----  - a f + c d
+--R                    |      |      3
+--R              +---+ |     \|  4d f
+--R            f\|- d  |---------------------------
+--R                    |               2
+--R                   \|            d f
+--R         *
+--R            log
+--R                         +---------------------------+
+--R                         |      +-------+
+--R                         |      |     2
+--R                         |    2 |    b
+--R                         |2d f  |- -----  - a f + c d
+--R                         |      |      3                   +--------------+
+--R                         |     \|  4d f                    |   2
+--R                   b f x |---------------------------  + b\|c x  + b x + a
+--R                         |               2
+--R                        \|            d f
+--R                 + 
+--R                         +-------+
+--R                         |     2
+--R                      2  |    b         +-+
+--R                   (2f x |- -----  - b)\|a
+--R                         |      3
+--R                        \|  4d f
+--R              /
+--R                 x
+--R     + 
+--R       -
+--R                    +-----------------------------+
+--R                    |        +-------+
+--R                    |        |     2
+--R                    |      2 |    b
+--R                    |- 2d f  |- -----  - a f + c d
+--R                    |        |      3
+--R              +---+ |       \|  4d f
+--R            f\|- d  |-----------------------------
+--R                    |                2
+--R                   \|             d f
+--R         *
+--R            log
+--R                         +-----------------------------+
+--R                         |        +-------+
+--R                         |        |     2
+--R                         |      2 |    b
+--R                         |- 2d f  |- -----  - a f + c d
+--R                         |        |      3                   +--------------+
+--R                         |       \|  4d f                    |   2
+--R                   b f x |-----------------------------  + b\|c x  + b x + a
+--R                         |                2
+--R                        \|             d f
+--R                 + 
+--R                           +-------+
+--R                           |     2
+--R                        2  |    b         +-+
+--R                   (- 2f x |- -----  - b)\|a
+--R                           |      3
+--R                          \|  4d f
+--R              /
+--R                 x
+--R     + 
+--R                 +-----------------------------+
+--R                 |        +-------+
+--R                 |        |     2
+--R                 |      2 |    b
+--R                 |- 2d f  |- -----  - a f + c d
+--R                 |        |      3
+--R           +---+ |       \|  4d f
+--R         f\|- d  |-----------------------------
+--R                 |                2
+--R                \|             d f
+--R      *
+--R         log
+--R                        +-----------------------------+
+--R                        |        +-------+
+--R                        |        |     2
+--R                        |      2 |    b
+--R                        |- 2d f  |- -----  - a f + c d
+--R                        |        |      3                   +--------------+
+--R                        |       \|  4d f                    |   2
+--R                - b f x |-----------------------------  + b\|c x  + b x + a
+--R                        |                2
+--R                       \|             d f
+--R              + 
+--R                        +-------+
+--R                        |     2
+--R                     2  |    b         +-+
+--R                (- 2f x |- -----  - b)\|a
+--R                        |      3
+--R                       \|  4d f
+--R           /
+--R              x
+--R     + 
+--R                 +---------------------------+
+--R                 |      +-------+
+--R                 |      |     2
+--R                 |    2 |    b
+--R                 |2d f  |- -----  - a f + c d
+--R                 |      |      3
+--R           +---+ |     \|  4d f
+--R         f\|- d  |---------------------------
+--R                 |               2
+--R                \|            d f
+--R      *
+--R         log
+--R                        +---------------------------+
+--R                        |      +-------+
+--R                        |      |     2
+--R                        |    2 |    b
+--R                        |2d f  |- -----  - a f + c d
+--R                        |      |      3                   +--------------+
+--R                        |     \|  4d f                    |   2
+--R                - b f x |---------------------------  + b\|c x  + b x + a
+--R                        |               2
+--R                       \|            d f
+--R              + 
+--R                      +-------+
+--R                      |     2
+--R                   2  |    b         +-+
+--R                (2f x |- -----  - b)\|a
+--R                      |      3
+--R                     \|  4d f
+--R           /
+--R              x
+--R     + 
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R           +---+ +-+
+--R         2\|- d \|c
+--R      *
+--R                              +--------------+
+--R                 +-+     +-+  |   2                 +-+ +-+       2
+--R           (- 2x\|c  + 2\|a )\|c x  + b x + a  + 2x\|a \|c  - 2c x  - b x - 2a
+--R       log(-------------------------------------------------------------------)
+--R                                  +--------------+
+--R                              +-+ |   2
+--R                            2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R           +---+ +-+             2c x + b
+--R       - 2\|- d \|c atanh(----------------------)
+--R                                +--------------+
+--R                            +-+ |   2
+--R                          2\|c \|c x  + b x + a
+--R  /
+--R        +---+
+--R     2f\|- d
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 1580
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 1580
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       -
+--R                    +---------------------------+
+--R                    |      +-------+
+--R                    |      |     2
+--R                    |    2 |    b
+--R                    |2d f  |- -----  - a f + c d
+--R                    |      |      3
+--R              +---+ |     \|  4d f
+--R            f\|- d  |---------------------------
+--R                    |               2
+--R                   \|            d f
+--R         *
+--R            log
+--R                         +---------------------------+
+--R                         |      +-------+
+--R                         |      |     2
+--R                         |    2 |    b
+--R                         |2d f  |- -----  - a f + c d
+--R                         |      |      3                   +--------------+
+--R                         |     \|  4d f                    |   2
+--R                   b f x |---------------------------  + b\|c x  + b x + a
+--R                         |               2
+--R                        \|            d f
+--R                 + 
+--R                         +-------+
+--R                         |     2
+--R                      2  |    b         +-+
+--R                   (2f x |- -----  - b)\|a
+--R                         |      3
+--R                        \|  4d f
+--R              /
+--R                 x
+--R     + 
+--R       -
+--R                    +-----------------------------+
+--R                    |        +-------+
+--R                    |        |     2
+--R                    |      2 |    b
+--R                    |- 2d f  |- -----  - a f + c d
+--R                    |        |      3
+--R              +---+ |       \|  4d f
+--R            f\|- d  |-----------------------------
+--R                    |                2
+--R                   \|             d f
+--R         *
+--R            log
+--R                         +-----------------------------+
+--R                         |        +-------+
+--R                         |        |     2
+--R                         |      2 |    b
+--R                         |- 2d f  |- -----  - a f + c d
+--R                         |        |      3                   +--------------+
+--R                         |       \|  4d f                    |   2
+--R                   b f x |-----------------------------  + b\|c x  + b x + a
+--R                         |                2
+--R                        \|             d f
+--R                 + 
+--R                           +-------+
+--R                           |     2
+--R                        2  |    b         +-+
+--R                   (- 2f x |- -----  - b)\|a
+--R                           |      3
+--R                          \|  4d f
+--R              /
+--R                 x
+--R     + 
+--R                 +-----------------------------+
+--R                 |        +-------+
+--R                 |        |     2
+--R                 |      2 |    b
+--R                 |- 2d f  |- -----  - a f + c d
+--R                 |        |      3
+--R           +---+ |       \|  4d f
+--R         f\|- d  |-----------------------------
+--R                 |                2
+--R                \|             d f
+--R      *
+--R         log
+--R                        +-----------------------------+
+--R                        |        +-------+
+--R                        |        |     2
+--R                        |      2 |    b
+--R                        |- 2d f  |- -----  - a f + c d
+--R                        |        |      3                   +--------------+
+--R                        |       \|  4d f                    |   2
+--R                - b f x |-----------------------------  + b\|c x  + b x + a
+--R                        |                2
+--R                       \|             d f
+--R              + 
+--R                        +-------+
+--R                        |     2
+--R                     2  |    b         +-+
+--R                (- 2f x |- -----  - b)\|a
+--R                        |      3
+--R                       \|  4d f
+--R           /
+--R              x
+--R     + 
+--R                 +---------------------------+
+--R                 |      +-------+
+--R                 |      |     2
+--R                 |    2 |    b
+--R                 |2d f  |- -----  - a f + c d
+--R                 |      |      3
+--R           +---+ |     \|  4d f
+--R         f\|- d  |---------------------------
+--R                 |               2
+--R                \|            d f
+--R      *
+--R         log
+--R                        +---------------------------+
+--R                        |      +-------+
+--R                        |      |     2
+--R                        |    2 |    b
+--R                        |2d f  |- -----  - a f + c d
+--R                        |      |      3                   +--------------+
+--R                        |     \|  4d f                    |   2
+--R                - b f x |---------------------------  + b\|c x  + b x + a
+--R                        |               2
+--R                       \|            d f
+--R              + 
+--R                      +-------+
+--R                      |     2
+--R                   2  |    b         +-+
+--R                (2f x |- -----  - b)\|a
+--R                      |      3
+--R                     \|  4d f
+--R           /
+--R              x
+--R     + 
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R           +---+ +-+             2c x + b
+--R       - 2\|- d \|c atanh(----------------------)
+--R                                +--------------+
+--R                            +-+ |   2
+--R                          2\|c \|c x  + b x + a
+--R     + 
+--R                          +--------------+
+--R                          |   2               +-+
+--R         +---+ +---+     \|c x  + b x + a  - \|a
+--R       4\|- d \|- c atan(------------------------)
+--R                                    +---+
+--R                                  x\|- c
+--R  /
+--R        +---+
+--R     2f\|- d
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 1580
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 149
+
+)clear all
+
+--S 150 of 1580
+t0:=(a+b*x+c*x^2)^(1/2)/(x*(d+f*x^2))
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R               3
+--R            f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 150
+
+--S 151 of 1580
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a)/d+_
+   1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))/(d*sqrt(f))-1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*_
+   sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))/(d*sqrt(f))
+--R 
+--R
+--R   (2)
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R           +-+ +-+             b x + 2a
+--R       - 2\|a \|f atanh(----------------------)
+--R                              +--------------+
+--R                          +-+ |   2
+--R                        2\|a \|c x  + b x + a
+--R  /
+--R        +-+
+--R     2d\|f
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                  +-------------------------+
+--R                  |     +------+
+--R                  |     |    2
+--R                  |  2  |   b
+--R                  |2d f |- ----  + a f - c d
+--R                  |     |    3
+--R              +-+ |    \|  4d f
+--R            d\|a  |-------------------------
+--R                  |            2
+--R                 \|           d f
+--R         *
+--R            log
+--R                                       +-------------------------+
+--R                                       |     +------+
+--R                                       |     |    2
+--R                                       |  2  |   b
+--R                          +------+     |2d f |- ----  + a f - c d
+--R                          |    2       |     |    3
+--R                     2    |   b    +-+ |    \|  4d f
+--R                   2d f x |- ---- \|a  |-------------------------
+--R                          |    3       |            2
+--R                         \|  4d f     \|           d f
+--R                 + 
+--R                                                     +------+
+--R                         +--------------+            |    2
+--R                     +-+ |   2                       |   b
+--R                   b\|a \|c x  + b x + a  - 2a d f x |- ----  - a b
+--R                                                     |    3
+--R                                                    \|  4d f
+--R              /
+--R                 x
+--R     + 
+--R               +---------------------------+
+--R               |       +------+
+--R               |       |    2
+--R               |    2  |   b
+--R               |- 2d f |- ----  + a f - c d
+--R               |       |    3
+--R           +-+ |      \|  4d f
+--R         d\|a  |---------------------------
+--R               |             2
+--R              \|            d f
+--R      *
+--R         log
+--R                                    +---------------------------+
+--R                                    |       +------+
+--R                                    |       |    2
+--R                                    |    2  |   b
+--R                       +------+     |- 2d f |- ----  + a f - c d
+--R                       |    2       |       |    3
+--R                  2    |   b    +-+ |      \|  4d f
+--R                2d f x |- ---- \|a  |---------------------------
+--R                       |    3       |             2
+--R                      \|  4d f     \|            d f
+--R              + 
+--R                                                  +------+
+--R                      +--------------+            |    2
+--R                  +-+ |   2                       |   b
+--R                b\|a \|c x  + b x + a  + 2a d f x |- ----  - a b
+--R                                                  |    3
+--R                                                 \|  4d f
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                  +---------------------------+
+--R                  |       +------+
+--R                  |       |    2
+--R                  |    2  |   b
+--R                  |- 2d f |- ----  + a f - c d
+--R                  |       |    3
+--R              +-+ |      \|  4d f
+--R            d\|a  |---------------------------
+--R                  |             2
+--R                 \|            d f
+--R         *
+--R            log
+--R                                         +---------------------------+
+--R                                         |       +------+
+--R                                         |       |    2
+--R                                         |    2  |   b
+--R                            +------+     |- 2d f |- ----  + a f - c d
+--R                            |    2       |       |    3
+--R                       2    |   b    +-+ |      \|  4d f
+--R                   - 2d f x |- ---- \|a  |---------------------------
+--R                            |    3       |             2
+--R                           \|  4d f     \|            d f
+--R                 + 
+--R                                                     +------+
+--R                         +--------------+            |    2
+--R                     +-+ |   2                       |   b
+--R                   b\|a \|c x  + b x + a  + 2a d f x |- ----  - a b
+--R                                                     |    3
+--R                                                    \|  4d f
+--R              /
+--R                 x
+--R     + 
+--R               +-------------------------+
+--R               |     +------+
+--R               |     |    2
+--R               |  2  |   b
+--R               |2d f |- ----  + a f - c d
+--R               |     |    3
+--R           +-+ |    \|  4d f
+--R         d\|a  |-------------------------
+--R               |            2
+--R              \|           d f
+--R      *
+--R         log
+--R                                      +-------------------------+
+--R                                      |     +------+
+--R                                      |     |    2
+--R                                      |  2  |   b
+--R                         +------+     |2d f |- ----  + a f - c d
+--R                         |    2       |     |    3
+--R                    2    |   b    +-+ |    \|  4d f
+--R                - 2d f x |- ---- \|a  |-------------------------
+--R                         |    3       |            2
+--R                        \|  4d f     \|           d f
+--R              + 
+--R                                                  +------+
+--R                      +--------------+            |    2
+--R                  +-+ |   2                       |   b
+--R                b\|a \|c x  + b x + a  - 2a d f x |- ----  - a b
+--R                                                  |    3
+--R                                                 \|  4d f
+--R           /
+--R              x
+--R     + 
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R       2a log(---------------------------------)
+--R                              x
+--R  /
+--R        +-+
+--R     2d\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 152
+
+--S 153 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                      +-------------------------+
+--R                      |     +------+
+--R                      |     |    2
+--R                      |  2  |   b
+--R                      |2d f |- ----  + a f - c d
+--R                      |     |    3
+--R              +-+ +-+ |    \|  4d f
+--R            d\|a \|f  |-------------------------
+--R                      |            2
+--R                     \|           d f
+--R         *
+--R            log
+--R                                       +-------------------------+
+--R                                       |     +------+
+--R                                       |     |    2
+--R                                       |  2  |   b
+--R                          +------+     |2d f |- ----  + a f - c d
+--R                          |    2       |     |    3
+--R                     2    |   b    +-+ |    \|  4d f
+--R                   2d f x |- ---- \|a  |-------------------------
+--R                          |    3       |            2
+--R                         \|  4d f     \|           d f
+--R                 + 
+--R                                                     +------+
+--R                         +--------------+            |    2
+--R                     +-+ |   2                       |   b
+--R                   b\|a \|c x  + b x + a  - 2a d f x |- ----  - a b
+--R                                                     |    3
+--R                                                    \|  4d f
+--R              /
+--R                 x
+--R     + 
+--R                   +---------------------------+
+--R                   |       +------+
+--R                   |       |    2
+--R                   |    2  |   b
+--R                   |- 2d f |- ----  + a f - c d
+--R                   |       |    3
+--R           +-+ +-+ |      \|  4d f
+--R         d\|a \|f  |---------------------------
+--R                   |             2
+--R                  \|            d f
+--R      *
+--R         log
+--R                                    +---------------------------+
+--R                                    |       +------+
+--R                                    |       |    2
+--R                                    |    2  |   b
+--R                       +------+     |- 2d f |- ----  + a f - c d
+--R                       |    2       |       |    3
+--R                  2    |   b    +-+ |      \|  4d f
+--R                2d f x |- ---- \|a  |---------------------------
+--R                       |    3       |             2
+--R                      \|  4d f     \|            d f
+--R              + 
+--R                                                  +------+
+--R                      +--------------+            |    2
+--R                  +-+ |   2                       |   b
+--R                b\|a \|c x  + b x + a  + 2a d f x |- ----  - a b
+--R                                                  |    3
+--R                                                 \|  4d f
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                      +---------------------------+
+--R                      |       +------+
+--R                      |       |    2
+--R                      |    2  |   b
+--R                      |- 2d f |- ----  + a f - c d
+--R                      |       |    3
+--R              +-+ +-+ |      \|  4d f
+--R            d\|a \|f  |---------------------------
+--R                      |             2
+--R                     \|            d f
+--R         *
+--R            log
+--R                                         +---------------------------+
+--R                                         |       +------+
+--R                                         |       |    2
+--R                                         |    2  |   b
+--R                            +------+     |- 2d f |- ----  + a f - c d
+--R                            |    2       |       |    3
+--R                       2    |   b    +-+ |      \|  4d f
+--R                   - 2d f x |- ---- \|a  |---------------------------
+--R                            |    3       |             2
+--R                           \|  4d f     \|            d f
+--R                 + 
+--R                                                     +------+
+--R                         +--------------+            |    2
+--R                     +-+ |   2                       |   b
+--R                   b\|a \|c x  + b x + a  + 2a d f x |- ----  - a b
+--R                                                     |    3
+--R                                                    \|  4d f
+--R              /
+--R                 x
+--R     + 
+--R                   +-------------------------+
+--R                   |     +------+
+--R                   |     |    2
+--R                   |  2  |   b
+--R                   |2d f |- ----  + a f - c d
+--R                   |     |    3
+--R           +-+ +-+ |    \|  4d f
+--R         d\|a \|f  |-------------------------
+--R                   |            2
+--R                  \|           d f
+--R      *
+--R         log
+--R                                      +-------------------------+
+--R                                      |     +------+
+--R                                      |     |    2
+--R                                      |  2  |   b
+--R                         +------+     |2d f |- ----  + a f - c d
+--R                         |    2       |     |    3
+--R                    2    |   b    +-+ |    \|  4d f
+--R                - 2d f x |- ---- \|a  |-------------------------
+--R                         |    3       |            2
+--R                        \|  4d f     \|           d f
+--R              + 
+--R                                                  +------+
+--R                      +--------------+            |    2
+--R                  +-+ |   2                       |   b
+--R                b\|a \|c x  + b x + a  - 2a d f x |- ----  - a b
+--R                                                  |    3
+--R                                                 \|  4d f
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                 +-------------------------+
+--R             +-+ |    +---+ +-+
+--R            \|a \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                 +-----------------------+
+--R             +-+ |  +---+ +-+
+--R            \|a \|b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                       +--------------+
+--R                   +-+ |   2
+--R          +-+    2\|a \|c x  + b x + a  - b x - 2a
+--R       2a\|f log(---------------------------------)
+--R                                 x
+--R     + 
+--R          +-+             b x + 2a
+--R       2a\|f atanh(----------------------)
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|a \|c x  + b x + a
+--R  /
+--R        +-+ +-+
+--R     2d\|a \|f
+--R                                                    Type: Expression(Integer)
+--E 153
+
+--S 154 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 154
+
+)clear all
+
+--S 155 of 1580
+t0:=(a+b*x+c*x^2)^(1/2)/(x^2*(d+f*x^2))
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R              4      2
+--R           f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 1580
+r0:=-1/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(d*sqrt(a))-_
+   sqrt(a+b*x+c*x^2)/(d*x)-1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*_
+   sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))/(-d)^(3/2)-1/2*atan(1/2*_
+   (b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f+b*sqrt(-d)*_
+   sqrt(f))/(-d)^(3/2)
+--R 
+--R
+--R   (2)
+--R               +-------------------------+
+--R           +-+ |    +---+ +-+
+--R         x\|a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                  +-----------------------+
+--R              +-+ |  +---+ +-+
+--R            x\|a \|b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                                                              +--------------+
+--R             +---+             b x + 2a             +---+ +-+ |   2
+--R       - b x\|- d atanh(----------------------) - 2\|- d \|a \|c x  + b x + a
+--R                              +--------------+
+--R                          +-+ |   2
+--R                        2\|a \|c x  + b x + a
+--R  /
+--R          +---+ +-+
+--R     2d x\|- d \|a
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 +--------------+
+--R                 |   2                       2           +-+
+--R         (4a d x\|c x  + b x + a  + (- 2b d x  - 4a d x)\|a )
+--R      *
+--R          +-----------------------+
+--R          |    +-----+
+--R          |    |   2
+--R          |  3 |  b f
+--R          |2d  |- ---  - a f + c d
+--R          |    |    5
+--R          |   \|  4d
+--R          |-----------------------
+--R          |            3
+--R         \|           d
+--R      *
+--R         log
+--R                      +-----------------------+
+--R                      |    +-----+
+--R                      |    |   2
+--R                      |  3 |  b f
+--R                      |2d  |- ---  - a f + c d
+--R                      |    |    5                   +--------------+
+--R                      |   \|  4d                    |   2
+--R                b d x |-----------------------  + b\|c x  + b x + a
+--R                      |            3
+--R                     \|           d
+--R              + 
+--R                      +-----+
+--R                      |   2
+--R                   2  |  b f       +-+
+--R                (2d x |- ---  - b)\|a
+--R                      |    5
+--R                     \|  4d
+--R           /
+--R              x
+--R     + 
+--R                 +--------------+
+--R                 |   2                       2           +-+
+--R         (4a d x\|c x  + b x + a  + (- 2b d x  - 4a d x)\|a )
+--R      *
+--R          +-------------------------+
+--R          |      +-----+
+--R          |      |   2
+--R          |    3 |  b f
+--R          |- 2d  |- ---  - a f + c d
+--R          |      |    5
+--R          |     \|  4d
+--R          |-------------------------
+--R          |             3
+--R         \|            d
+--R      *
+--R         log
+--R                      +-------------------------+
+--R                      |      +-----+
+--R                      |      |   2
+--R                      |    3 |  b f
+--R                      |- 2d  |- ---  - a f + c d
+--R                      |      |    5                   +--------------+
+--R                      |     \|  4d                    |   2
+--R                b d x |-------------------------  + b\|c x  + b x + a
+--R                      |             3
+--R                     \|            d
+--R              + 
+--R                        +-----+
+--R                        |   2
+--R                     2  |  b f       +-+
+--R                (- 2d x |- ---  - b)\|a
+--R                        |    5
+--R                       \|  4d
+--R           /
+--R              x
+--R     + 
+--R                   +--------------+
+--R                   |   2                     2           +-+
+--R         (- 4a d x\|c x  + b x + a  + (2b d x  + 4a d x)\|a )
+--R      *
+--R          +-------------------------+
+--R          |      +-----+
+--R          |      |   2
+--R          |    3 |  b f
+--R          |- 2d  |- ---  - a f + c d
+--R          |      |    5
+--R          |     \|  4d
+--R          |-------------------------
+--R          |             3
+--R         \|            d
+--R      *
+--R         log
+--R                        +-------------------------+
+--R                        |      +-----+
+--R                        |      |   2
+--R                        |    3 |  b f
+--R                        |- 2d  |- ---  - a f + c d
+--R                        |      |    5                   +--------------+
+--R                        |     \|  4d                    |   2
+--R                - b d x |-------------------------  + b\|c x  + b x + a
+--R                        |             3
+--R                       \|            d
+--R              + 
+--R                        +-----+
+--R                        |   2
+--R                     2  |  b f       +-+
+--R                (- 2d x |- ---  - b)\|a
+--R                        |    5
+--R                       \|  4d
+--R           /
+--R              x
+--R     + 
+--R                   +--------------+
+--R                   |   2                     2           +-+
+--R         (- 4a d x\|c x  + b x + a  + (2b d x  + 4a d x)\|a )
+--R      *
+--R          +-----------------------+
+--R          |    +-----+
+--R          |    |   2
+--R          |  3 |  b f
+--R          |2d  |- ---  - a f + c d
+--R          |    |    5
+--R          |   \|  4d
+--R          |-----------------------
+--R          |            3
+--R         \|           d
+--R      *
+--R         log
+--R                        +-----------------------+
+--R                        |    +-----+
+--R                        |    |   2
+--R                        |  3 |  b f
+--R                        |2d  |- ---  - a f + c d
+--R                        |    |    5                   +--------------+
+--R                        |   \|  4d                    |   2
+--R                - b d x |-----------------------  + b\|c x  + b x + a
+--R                        |            3
+--R                       \|           d
+--R              + 
+--R                      +-----+
+--R                      |   2
+--R                   2  |  b f       +-+
+--R                (2d x |- ---  - b)\|a
+--R                      |    5
+--R                     \|  4d
+--R           /
+--R              x
+--R     + 
+--R                   +--------------+
+--R               +-+ |   2                2 2
+--R         (4b x\|a \|c x  + b x + a  - 2b x  - 4a b x)
+--R      *
+--R                +--------------+
+--R                |   2                           +-+
+--R             2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         log(--------------------------------------)
+--R                              2a x
+--R     + 
+--R                       +--------------+
+--R                   +-+ |   2                         2  2              2
+--R       (2b x + 8a)\|a \|c x  + b x + a  + (- 8a c + b )x  - 6a b x - 8a
+--R  /
+--R            +--------------+
+--R            |   2                       2           +-+
+--R     8a d x\|c x  + b x + a  + (- 4b d x  - 8a d x)\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 157
+
+--S 158 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +--------------+
+--R               +---+ +-+ |   2                              2   +---+
+--R         (4a d\|- d \|a \|c x  + b x + a  + (- 2a b d x - 4a d)\|- d )
+--R      *
+--R          +-----------------------+
+--R          |    +-----+
+--R          |    |   2
+--R          |  3 |  b f
+--R          |2d  |- ---  - a f + c d
+--R          |    |    5
+--R          |   \|  4d
+--R          |-----------------------
+--R          |            3
+--R         \|           d
+--R      *
+--R         log
+--R                      +-----------------------+
+--R                      |    +-----+
+--R                      |    |   2
+--R                      |  3 |  b f
+--R                      |2d  |- ---  - a f + c d
+--R                      |    |    5                   +--------------+
+--R                      |   \|  4d                    |   2
+--R                b d x |-----------------------  + b\|c x  + b x + a
+--R                      |            3
+--R                     \|           d
+--R              + 
+--R                      +-----+
+--R                      |   2
+--R                   2  |  b f       +-+
+--R                (2d x |- ---  - b)\|a
+--R                      |    5
+--R                     \|  4d
+--R           /
+--R              x
+--R     + 
+--R                         +--------------+
+--R               +---+ +-+ |   2                              2   +---+
+--R         (4a d\|- d \|a \|c x  + b x + a  + (- 2a b d x - 4a d)\|- d )
+--R      *
+--R          +-------------------------+
+--R          |      +-----+
+--R          |      |   2
+--R          |    3 |  b f
+--R          |- 2d  |- ---  - a f + c d
+--R          |      |    5
+--R          |     \|  4d
+--R          |-------------------------
+--R          |             3
+--R         \|            d
+--R      *
+--R         log
+--R                      +-------------------------+
+--R                      |      +-----+
+--R                      |      |   2
+--R                      |    3 |  b f
+--R                      |- 2d  |- ---  - a f + c d
+--R                      |      |    5                   +--------------+
+--R                      |     \|  4d                    |   2
+--R                b d x |-------------------------  + b\|c x  + b x + a
+--R                      |             3
+--R                     \|            d
+--R              + 
+--R                        +-----+
+--R                        |   2
+--R                     2  |  b f       +-+
+--R                (- 2d x |- ---  - b)\|a
+--R                        |    5
+--R                       \|  4d
+--R           /
+--R              x
+--R     + 
+--R                           +--------------+
+--R                 +---+ +-+ |   2                            2   +---+
+--R         (- 4a d\|- d \|a \|c x  + b x + a  + (2a b d x + 4a d)\|- d )
+--R      *
+--R          +-------------------------+
+--R          |      +-----+
+--R          |      |   2
+--R          |    3 |  b f
+--R          |- 2d  |- ---  - a f + c d
+--R          |      |    5
+--R          |     \|  4d
+--R          |-------------------------
+--R          |             3
+--R         \|            d
+--R      *
+--R         log
+--R                        +-------------------------+
+--R                        |      +-----+
+--R                        |      |   2
+--R                        |    3 |  b f
+--R                        |- 2d  |- ---  - a f + c d
+--R                        |      |    5                   +--------------+
+--R                        |     \|  4d                    |   2
+--R                - b d x |-------------------------  + b\|c x  + b x + a
+--R                        |             3
+--R                       \|            d
+--R              + 
+--R                        +-----+
+--R                        |   2
+--R                     2  |  b f       +-+
+--R                (- 2d x |- ---  - b)\|a
+--R                        |    5
+--R                       \|  4d
+--R           /
+--R              x
+--R     + 
+--R                           +--------------+
+--R                 +---+ +-+ |   2                            2   +---+
+--R         (- 4a d\|- d \|a \|c x  + b x + a  + (2a b d x + 4a d)\|- d )
+--R      *
+--R          +-----------------------+
+--R          |    +-----+
+--R          |    |   2
+--R          |  3 |  b f
+--R          |2d  |- ---  - a f + c d
+--R          |    |    5
+--R          |   \|  4d
+--R          |-----------------------
+--R          |            3
+--R         \|           d
+--R      *
+--R         log
+--R                        +-----------------------+
+--R                        |    +-----+
+--R                        |    |   2
+--R                        |  3 |  b f
+--R                        |2d  |- ---  - a f + c d
+--R                        |    |    5                   +--------------+
+--R                        |   \|  4d                    |   2
+--R                - b d x |-----------------------  + b\|c x  + b x + a
+--R                        |            3
+--R                       \|           d
+--R              + 
+--R                      +-----+
+--R                      |   2
+--R                   2  |  b f       +-+
+--R                (2d x |- ---  - b)\|a
+--R                      |    5
+--R                     \|  4d
+--R           /
+--R              x
+--R     + 
+--R                   +--------------+                 +-------------------------+
+--R               +-+ |   2                         2  |    +---+ +-+
+--R         (- 4a\|a \|c x  + b x + a  + 2a b x + 4a )\|- b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                 +--------------+                 +-----------------------+
+--R             +-+ |   2                         2  |  +---+ +-+
+--R         (4a\|a \|c x  + b x + a  - 2a b x - 4a )\|b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                     +--------------+
+--R               +---+ |   2                   2          +---+ +-+
+--R         (4a b\|- d \|c x  + b x + a  + (- 2b x - 4a b)\|- d \|a )
+--R      *
+--R                +--------------+
+--R                |   2                           +-+
+--R             2a\|c x  + b x + a  + (- b x - 2a)\|a
+--R         log(--------------------------------------)
+--R                              2a x
+--R     + 
+--R                     +--------------+
+--R               +---+ |   2                   2          +---+ +-+
+--R         (4a b\|- d \|c x  + b x + a  + (- 2b x - 4a b)\|- d \|a )
+--R      *
+--R                      b x + 2a
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|a \|c x  + b x + a
+--R     + 
+--R                    +--------------+
+--R              +---+ |   2                2          +---+ +-+
+--R       - 2a b\|- d \|c x  + b x + a  + (b x + 2a b)\|- d \|a
+--R  /
+--R                    +--------------+
+--R          +---+ +-+ |   2                              2   +---+
+--R     8a d\|- d \|a \|c x  + b x + a  + (- 4a b d x - 8a d)\|- d
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 1580
+t0:=(a+b*x+c*x^2)^(1/2)/(x^3*(d+f*x^2))
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R              5      3
+--R           f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 1580
+r0:=1/8*(b^2-4*a*c)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (a^(3/2)*d)+f*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a)/d^2-1/4*(2*a+b*x)*sqrt(a+b*x+c*x^2)/(a*d*x^2)-1/2*atan(1/2*_
+   (b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+_
+   c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(f)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))/d^2+1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*_
+   sqrt(-d)*sqrt(f))))*sqrt(f)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))/d^2
+--R 
+--R
+--R   (2)
+--R       -
+--R                          +-------------------------+
+--R                2 +-+ +-+ |    +---+ +-+
+--R            4a x \|a \|f \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                          +-----------------------+
+--R                2 +-+ +-+ |  +---+ +-+
+--R            4a x \|a \|f \|b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R          2               2    2             b x + 2a
+--R       (8a f + (- 4a c + b )d)x atanh(----------------------)
+--R                                            +--------------+
+--R                                        +-+ |   2
+--R                                      2\|a \|c x  + b x + a
+--R     + 
+--R                             +--------------+
+--R                         +-+ |   2
+--R       (- 2b d x - 4a d)\|a \|c x  + b x + a
+--R  /
+--R         2 2 +-+
+--R     8a d x \|a
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 1580
+--a0:=integrate(t0,x)
+--E 162
+
+--S 163 of 1580
+--m0:=a0-r0
+--E 163
+
+--S 164 of 1580
+--d0:=D(m0,x)
+--E 164
+
+)clear all
+
+--S 165 of 1580
+t0:=x^3*(a+b*x+c*x^2)^(3/2)/(d+f*x^2)
+--R 
+--R
+--R                             +--------------+
+--R            5      4      3  |   2
+--R        (c x  + b x  + a x )\|c x  + b x + a
+--R   (1)  -------------------------------------
+--R                          2
+--R                       f x  + d
+--R                                                    Type: Expression(Integer)
+--E 165
+
+--S 166 of 1580
+r0:=-1/3*d*(a+b*x+c*x^2)^(3/2)/f^2-1/16*b*(b+2*c*x)*(a+b*x+c*x^2)^(3/2)/_
+   (c^2*f)+1/5*(a+b*x+c*x^2)^(5/2)/(c*f)+1/16*b*(b^2-4*a*c)*d*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f^2)-3/256*b*(b^2-_
+   4*a*c)^2*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(7/2)*f)+_
+   1/2*b*d*(3*c*d-a*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f^3*sqrt(c))+d*(c*d-a*f)*sqrt(a+b*x+c*x^2)/f^3-1/8*b*d*(b+2*c*x)*_
+   sqrt(a+b*x+c*x^2)/(c*f^2)+3/128*b*(b^2-4*a*c)*(b+2*c*x)*sqrt(a+b*x+_
+   c*x^2)/(c^3*f)+1/2*d*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+_
+   b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*_
+   (b^2*d*f-(c*d-a*f)^2+2*b*(c*d-a*f)*sqrt(-d)*sqrt(f))/(f^(7/2)*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*d*atan(1/2*(b*sqrt(-d)-2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+_
+   b*sqrt(-d)*sqrt(f))))*(b^2*d*f-(c*d-a*f)^2-2*b*(c*d-a*f)*sqrt(-d)*_
+   sqrt(f))/(f^(7/2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                       3             4 2  +---+ +-+ +-+
+--R           (- 3840a b c d f + 3840b c d )\|- d \|c \|f
+--R         + 
+--R                   2 3   2           4        2 3  2         5 3  +-+
+--R           (- 1920a c d f  + (3840a c  + 1920b c )d f - 1920c d )\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                     3             4 2  +---+ +-+ +-+
+--R           (3840a b c d f - 3840b c d )\|- d \|c \|f
+--R         + 
+--R                   2 3   2           4        2 3  2         5 3  +-+
+--R           (- 1920a c d f  + (3840a c  + 1920b c )d f - 1920c d )\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                      2   2         3       5  2               3       3 2
+--R               (- 720a b c  + 360a b c - 45b )f  + (- 2880a b c  + 240b c )d f
+--R             + 
+--R                      4 2
+--R               5760b c d
+--R          *
+--R              +-+             2c x + b
+--R             \|f atanh(----------------------)
+--R                             +--------------+
+--R                         +-+ |   2
+--R                       2\|c \|c x  + b x + a
+--R         + 
+--R                   4 2 4          3 2 3            3      2 2  2        4     2
+--R               768c f x  + 1056b c f x  + ((1536a c  + 48b c )f  - 1280c d f)x
+--R             + 
+--R                         2      3   2          3
+--R               ((336a b c  - 60b c)f  - 2240b c d f)x
+--R             + 
+--R                    2 2         2       4  2             3       2 2
+--R               (768a c  - 600a b c + 90b )f  + (- 5120a c  - 480b c )d f
+--R             + 
+--R                    4 2
+--R               3840c d
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|c \|f \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                      +-------------------------+ +-----------------------+
+--R          3 3 +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     3840c f \|c \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 1580
+--a0:=integrate(t0,x)
+--E 167
+
+--S 168 of 1580
+--m0:=a0-r0
+--E 168
+
+--S 169 of 1580
+--d0:=D(m0,x)
+--E 169
+
+)clear all
+
+--S 170 of 1580
+t0:=x^2*(a+b*x+c*x^2)^(3/2)/(d+f*x^2)
+--R 
+--R
+--R                             +--------------+
+--R            4      3      2  |   2
+--R        (c x  + b x  + a x )\|c x  + b x + a
+--R   (1)  -------------------------------------
+--R                          2
+--R                       f x  + d
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 1580
+r0:=1/8*(b+2*c*x)*(a+b*x+c*x^2)^(3/2)/(c*f)+3/128*(b^2-4*a*c)^2*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(5/2)*f)+_
+   1/8*(b^2-4*a*c)*d*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f^2*sqrt(c))+1/2*d*(2*c^2*d-b^2*f-2*a*c*f)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(f^3*sqrt(c))-b*d*sqrt(a+b*x+c*x^2)/f^2-_
+   1/4*d*(b+2*c*x)*sqrt(a+b*x+c*x^2)/f^2-3/64*(b^2-4*a*c)*(b+2*c*x)*_
+   sqrt(a+b*x+c*x^2)/(c^2*f)+1/2*d*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*_
+   sqrt(-d)*sqrt(f))))*((b^2*d*f-(c*d-a*f)^2)/sqrt(-d)+2*b*(c*d-a*f)*_
+   sqrt(f))/(f^3*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*d*atan(1/2*(b*_
+   sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*((-b^2*d*f+(c*d-a*f)^2)/sqrt(-d)+_
+   2*b*(c*d-a*f)*sqrt(f))/(f^3*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                      2            3 2  +---+ +-+ +-+
+--R           (- 128a b c d f + 128b c d )\|- d \|c \|f
+--R         + 
+--R                 2 2   2          3      2 2  2       4 3  +-+
+--R           (- 64a c d f  + (128a c  + 64b c )d f - 64c d )\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                      2            3 2  +---+ +-+ +-+
+--R           (- 128a b c d f + 128b c d )\|- d \|c \|f
+--R         + 
+--R               2 2   2            3      2 2  2       4 3  +-+
+--R           (64a c d f  + (- 128a c  - 64b c )d f + 64c d )\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                  2 2        2      4  2            3      2 2           4 2
+--R             ((48a c  - 24a b c + 3b )f  + (- 192a c  - 48b c )d f + 128c d )
+--R          *
+--R              +---+             2c x + b
+--R             \|- d atanh(----------------------)
+--R                               +--------------+
+--R                           +-+ |   2
+--R                         2\|c \|c x  + b x + a
+--R         + 
+--R                  3 2 3        2 2 2          2     2   2      3
+--R               32c f x  + 48b c f x  + ((80a c  + 4b c)f  - 64c d f)x
+--R             + 
+--R                            3  2         2
+--R               (40a b c - 6b )f  - 160b c d f
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- d \|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                       +-------------------------+ +-----------------------+
+--R         2 3 +---+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     128c f \|- d \|c \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 1580
+--a0:=integrate(t0,x)
+--E 172
+
+--S 173 of 1580
+--m0:=a0-r0
+--E 173
+
+--S 174 of 1580
+--d0:=D(m0,x)
+--E 174
+
+)clear all
+
+--S 175 of 1580
+t0:=x*(a+b*x+c*x^2)^(3/2)/(d+f*x^2)
+--R 
+--R
+--R                            +--------------+
+--R            3      2        |   2
+--R        (c x  + b x  + a x)\|c x  + b x + a
+--R   (1)  ------------------------------------
+--R                         2
+--R                      f x  + d
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 1580
+r0:=1/3*(a+b*x+c*x^2)^(3/2)/f-1/16*b*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f)-1/2*b*(3*c*d-a*f)*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f^2*sqrt(c))-(c*d-a*f)*_
+   sqrt(a+b*x+c*x^2)/f^2+1/8*b*(b+2*c*x)*sqrt(a+b*x+c*x^2)/(c*f)-_
+   1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*(b^2*d*f-_
+   (c*d-a*f)^2+2*b*(c*d-a*f)*sqrt(-d)*sqrt(f))/(f^(5/2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f)))+1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*_
+   sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*_
+   sqrt(f))))*(b^2*d*f-(c*d-a*f)^2-2*b*(c*d-a*f)*sqrt(-d)*sqrt(f))/_
+   (f^(5/2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                             2   +---+ +-+ +-+
+--R           (48a b c f - 48b c d)\|- d \|c \|f
+--R         + 
+--R               2   2           2      2           3 2  +-+
+--R           (24a c f  + (- 48a c  - 24b c)d f + 24c d )\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                               2   +---+ +-+ +-+
+--R           (- 48a b c f + 48b c d)\|- d \|c \|f
+--R         + 
+--R               2   2           2      2           3 2  +-+
+--R           (24a c f  + (- 48a c  - 24b c)d f + 24c d )\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                         3          2   +-+             2c x + b
+--R           ((36a b c - 3b )f - 72b c d)\|f atanh(----------------------)
+--R                                                       +--------------+
+--R                                                   +-+ |   2
+--R                                                 2\|c \|c x  + b x + a
+--R         + 
+--R                 2   2                          2        2   +-+ +-+
+--R             (16c f x  + 28b c f x + (64a c + 6b )f - 48c d)\|c \|f
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                    +-------------------------+ +-----------------------+
+--R          2 +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     48c f \|c \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 1580
+--a0:=integrate(t0,x)
+--E 177
+
+--S 178 of 1580
+--m0:=a0-r0
+--E 178
+
+--S 179 of 1580
+--d0:=D(m0,x)
+--E 179
+
+)clear all
+
+--S 180 of 1580
+t0:=(a+b*x+c*x^2)^(3/2)/(d+f*x^2)
+--R 
+--R
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R   (1)  ---------------------------------
+--R                        2
+--R                     f x  + d
+--R                                                    Type: Expression(Integer)
+--E 180
+
+--S 181 of 1580
+r0:=-1/8*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f*sqrt(c))-1/2*(2*c^2*d-b^2*f-2*a*c*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/(f^2*sqrt(c))+b*sqrt(a+b*x+c*x^2)/f+1/4*(b+2*c*x)*_
+   sqrt(a+b*x+c*x^2)/f-1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*_
+   sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))))*((b^2*d*f-(c*d-a*f)^2)/sqrt(-d)+2*b*(c*d-a*f)*sqrt(f))/_
+   (f^2*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+1/2*atan(1/2*(b*sqrt(-d)-_
+   2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f))))*((-b^2*d*f+(c*d-a*f)^2)/sqrt(-d)+2*b*_
+   (c*d-a*f)*sqrt(f))/(f^2*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                             +---+ +-+ +-+
+--R           (8a b f - 8b c d)\|- d \|c \|f
+--R         + 
+--R              2 2               2         2 2  +-+
+--R           (4a f  + (- 8a c - 4b )d f + 4c d )\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                             +---+ +-+ +-+
+--R           (8a b f - 8b c d)\|- d \|c \|f
+--R         + 
+--R                2 2             2         2 2  +-+
+--R           (- 4a f  + (8a c + 4b )d f - 4c d )\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                       2       2   +---+             2c x + b
+--R           ((12a c + 3b )f - 8c d)\|- d atanh(----------------------)
+--R                                                    +--------------+
+--R                                                +-+ |   2
+--R                                              2\|c \|c x  + b x + a
+--R         + 
+--R                                      +--------------+
+--R                            +---+ +-+ |   2
+--R           (4c f x + 10b f)\|- d \|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                   +-------------------------+ +-----------------------+
+--R       2 +---+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     8f \|- d \|c \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1580
+--a0:=integrate(t0,x)
+--E 182
+
+--S 183 of 1580
+--m0:=a0-r0
+--E 183
+
+--S 184 of 1580
+--d0:=D(m0,x)
+--E 184
+
+)clear all
+
+--S 185 of 1580
+t0:=(a+b*x+c*x^2)^(3/2)/(x*(d+f*x^2))
+--R 
+--R
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R   (1)  ---------------------------------
+--R                       3
+--R                    f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 1580
+r0:=-a^(3/2)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/d-_
+   1/16*b*(b^2-12*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (c^(3/2)*d)+1/16*b*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+_
+   b*x+c*x^2)))/(c^(3/2)*d)+1/2*b*(3*c*d-a*f)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(d*f*sqrt(c))+(c*d-a*f)*sqrt(a+b*x+_
+   c*x^2)/(d*f)-1/8*b*(b+2*c*x)*sqrt(a+b*x+c*x^2)/(c*d)+1/8*(b^2+8*a*c+_
+   2*b*c*x)*sqrt(a+b*x+c*x^2)/(c*d)+1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*_
+   sqrt(-d)*sqrt(f))))*(b^2*d*f-(c*d-a*f)^2+2*b*(c*d-a*f)*sqrt(-d)*_
+   sqrt(f))/(d*f^(3/2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*atan(1/2*_
+   (b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*(b^2*d*f-(c*d-a*f)^2-2*b*(c*d-a*f)*_
+   sqrt(-d)*sqrt(f))/(d*f^(3/2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                               +---+ +-+ +-+
+--R           (- 2a b f + 2b c d)\|- d \|c \|f
+--R         + 
+--R               2 2            2        2 2  +-+
+--R           (- a f  + (2a c + b )d f - c d )\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                               +---+ +-+ +-+
+--R             (2a b f - 2b c d)\|- d \|c \|f
+--R           + 
+--R                 2 2            2        2 2  +-+
+--R             (- a f  + (2a c + b )d f - c d )\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                  +-+ +-+ +-+             b x + 2a
+--R           - 2a f\|a \|c \|f atanh(----------------------)
+--R                                         +--------------+
+--R                                     +-+ |   2
+--R                                   2\|a \|c x  + b x + a
+--R         + 
+--R                                                                +--------------+
+--R                +-+             2c x + b                +-+ +-+ |   2
+--R         3b c d\|f atanh(----------------------) + 2c d\|c \|f \|c x  + b x + a
+--R                               +--------------+
+--R                           +-+ |   2
+--R                         2\|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                  +-------------------------+ +-----------------------+
+--R          +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2d f\|c \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 1580
+--a0:=integrate(t0,x)
+--E 187
+
+--S 188 of 1580
+--m0:=a0-r0
+--E 188
+
+--S 189 of 1580
+--d0:=D(m0,x)
+--E 189
+
+)clear all
+
+--S 190 of 1580
+t0:=(a+b*x+c*x^2)^(3/2)/(x^2*(d+f*x^2))
+--R 
+--R
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R   (1)  ---------------------------------
+--R                      4      2
+--R                   f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 1580
+r0:=-(a+b*x+c*x^2)^(3/2)/(d*x)-3/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a)/d+1/8*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(d*sqrt(c))+3/8*(b^2+4*a*c)*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(d*sqrt(c))+1/2*(2*c^2*d-b^2*f-_
+   2*a*c*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(d*f*_
+   sqrt(c))-b*sqrt(a+b*x+c*x^2)/d-1/4*(b+2*c*x)*sqrt(a+b*x+c*x^2)/d+_
+   3/4*(3*b+2*c*x)*sqrt(a+b*x+c*x^2)/d+1/2*atan(1/2*(b*sqrt(-d)+2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))))*((b^2*d*f-(c*d-a*f)^2)/sqrt(-d)+2*b*(c*d-a*f)*_
+   sqrt(f))/(d*f*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*atan(1/2*(b*_
+   sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*((-b^2*d*f+(c*d-a*f)^2)/sqrt(-d)+_
+   2*b*(c*d-a*f)*sqrt(f))/(d*f*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                                +---+ +-+ +-+
+--R           (- 2a b f + 2b c d)x\|- d \|c \|f
+--R         + 
+--R               2 2            2        2 2   +-+
+--R           (- a f  + (2a c + b )d f - c d )x\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                                +---+ +-+ +-+
+--R           (- 2a b f + 2b c d)x\|- d \|c \|f
+--R         + 
+--R             2 2              2        2 2   +-+
+--R           (a f  + (- 2a c - b )d f + c d )x\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                    +---+ +-+ +-+             b x + 2a
+--R           - 3b f x\|- d \|a \|c atanh(----------------------)
+--R                                             +--------------+
+--R                                         +-+ |   2
+--R                                       2\|a \|c x  + b x + a
+--R         + 
+--R             2    +---+             2c x + b
+--R           2c d x\|- d atanh(----------------------)
+--R                                   +--------------+
+--R                               +-+ |   2
+--R                             2\|c \|c x  + b x + a
+--R         + 
+--R                            +--------------+
+--R                  +---+ +-+ |   2
+--R           - 2a f\|- d \|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                      +-------------------------+ +-----------------------+
+--R            +---+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2d f x\|- d \|c \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1580
+--a0:=integrate(t0,x)
+--E 192
+
+--S 193 of 1580
+--m0:=a0-r0
+--E 193
+
+--S 194 of 1580
+--d0:=D(m0,x)
+--E 194
+
+)clear all
+
+--S 195 of 1580
+t0:=(a+b*x+c*x^2)^(3/2)/(x^3*(d+f*x^2))
+--R 
+--R
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R   (1)  ---------------------------------
+--R                      5      3
+--R                   f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 195
+
+--S 196 of 1580
+r0:=-1/2*(a+b*x+c*x^2)^(3/2)/(d*x^2)+a^(3/2)*f*atanh(1/2*(2*a+b*x)/_
+   (sqrt(a)*sqrt(a+b*x+c*x^2)))/d^2+1/16*b*(b^2-12*a*c)*f*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*d^2)-1/16*b*(b^2-4*a*c)*_
+   f*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*d^2)-_
+   3/8*(b^2+4*a*c)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (d*sqrt(a))-1/2*b*(3*c*d-a*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/(d^2*sqrt(c))+3/2*b*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(c)/d-(c*d-a*f)*sqrt(a+b*x+c*x^2)/d^2-_
+   3/4*(b-2*c*x)*sqrt(a+b*x+c*x^2)/(d*x)+1/8*b*f*(b+2*c*x)*sqrt(a+b*x+_
+   c*x^2)/(c*d^2)-1/8*f*(b^2+8*a*c+2*b*c*x)*sqrt(a+b*x+c*x^2)/(c*d^2)-_
+   1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*(b^2*d*f-_
+   (c*d-a*f)^2+2*b*(c*d-a*f)*sqrt(-d)*sqrt(f))/(d^2*sqrt(f)*sqrt(c*d-_
+   a*f-b*sqrt(-d)*sqrt(f)))+1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+_
+   b*sqrt(-d)*sqrt(f))))*(b^2*d*f-(c*d-a*f)^2-2*b*(c*d-a*f)*sqrt(-d)*_
+   sqrt(f))/(d^2*sqrt(f)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                             2 +---+ +-+ +-+
+--R           (8a b f - 8b c d)x \|- d \|a \|f
+--R         + 
+--R              2 2               2         2 2  2 +-+
+--R           (4a f  + (- 8a c - 4b )d f + 4c d )x \|a
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                               2 +---+ +-+ +-+
+--R           (- 8a b f + 8b c d)x \|- d \|a \|f
+--R         + 
+--R              2 2               2         2 2  2 +-+
+--R           (4a f  + (- 8a c - 4b )d f + 4c d )x \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R              2                 2    2 +-+             b x + 2a
+--R           (8a f + (- 12a c - 3b )d)x \|f atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|a \|c x  + b x + a
+--R         + 
+--R                                      +--------------+
+--R                              +-+ +-+ |   2
+--R           (- 10b d x - 4a d)\|a \|f \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                   +-------------------------+ +-----------------------+
+--R       2 2 +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     8d x \|a \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1580
+--a0:=integrate(t0,x)
+--E 197
+
+--S 198 of 1580
+--m0:=a0-r0
+--E 198
+
+--S 199 of 1580
+--d0:=D(m0,x)
+--E 199
+
+)clear all
+
+--S 200 of 1580
+t0:=(a+b*x+c*x^2)^(3/2)/(1-x^2)
+--R 
+--R
+--R                           +--------------+
+--R              2            |   2
+--R        (- c x  - b x - a)\|c x  + b x + a
+--R   (1)  -----------------------------------
+--R                        2
+--R                       x  - 1
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 1580
+r0:=-1/2*(a-b+c)^(3/2)*atanh(1/2*(2*a-b+(b-2*c)*x)/(sqrt(a-b+c)*_
+   sqrt(a+b*x+c*x^2)))+1/2*(a+b+c)^(3/2)*atanh(1/2*(2*a+b+(b+2*c)*x)/_
+   (sqrt(a+b+c)*sqrt(a+b*x+c*x^2)))+1/8*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/sqrt(c)-1/2*(b^2+2*c*(a+c))*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/sqrt(c)-b*sqrt(a+b*x+c*x^2)-_
+   1/4*(b+2*c*x)*sqrt(a+b*x+c*x^2)
+--R 
+--R
+--R   (2)
+--R                      +---------+ +-+            (2c - b)x + b - 2a
+--R       (4c - 4b + 4a)\|c - b + a \|c atanh(------------------------------)
+--R                                                         +--------------+
+--R                                             +---------+ |   2
+--R                                           2\|c - b + a \|c x  + b x + a
+--R     + 
+--R            2             2              2c x + b
+--R       (- 8c  - 12a c - 3b )atanh(----------------------)
+--R                                        +--------------+
+--R                                    +-+ |   2
+--R                                  2\|c \|c x  + b x + a
+--R     + 
+--R                      +-+ +---------+            (2c + b)x + b + 2a
+--R       (4c + 4b + 4a)\|c \|c + b + a atanh(------------------------------)
+--R                                                         +--------------+
+--R                                             +---------+ |   2
+--R                                           2\|c + b + a \|c x  + b x + a
+--R     + 
+--R                          +--------------+
+--R                      +-+ |   2
+--R       (- 4c x - 10b)\|c \|c x  + b x + a
+--R  /
+--R       +-+
+--R     8\|c
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            2                                2  +-+ +-+
+--R               ((16b c + 16b  + 16a b)x + 32a c + 32a b + 32a )\|a \|c
+--R            *
+--R                            +--------------+
+--R                +---------+ |   2
+--R               \|c + b + a \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 16a c  + (- 4b  - 16a b - 16a )c - 4b  - 4a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 32a b c - 32a b  - 32a b)x - 32a c - 32a b - 32a
+--R            *
+--R                +-+ +---------+
+--R               \|c \|c + b + a
+--R        *
+--R           log
+--R                                                  +--------------+
+--R                      +---------+            +-+  |   2
+--R                  (2x\|c + b + a  + (2x - 2)\|a )\|c x  + b x + a
+--R                + 
+--R                     2       +-+ +---------+                 2
+--R                  (2x  - 2x)\|a \|c + b + a  + (2c + b + 2a)x  + (b - 2a)x + 2a
+--R             /
+--R                             +--------------+
+--R                         +-+ |   2                 2
+--R                (2x - 2)\|a \|c x  + b x + a  - b x  + (b - 2a)x + 2a
+--R       + 
+--R                      2                3          2      2         2  +-+
+--R               ((32b c  + 48a b c + 12b )x + 64a c  + 96a c + 24a b )\|a
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                     3        2      2  2        2      4  2
+--R             (- 32a c  + (- 8b  - 48a )c  - 24a b c - 3b )x
+--R           + 
+--R                       2      2           3        2 2      3       2 2
+--R             (- 64a b c  - 96a b c - 24a b )x - 64a c  - 96a c - 24a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                            2                                2  +-+ +---------+
+--R               ((16b c - 16b  + 16a b)x + 32a c - 32a b + 32a )\|a \|c - b + a
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|c \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 16a c  + (- 4b  + 16a b - 16a )c + 4b  - 4a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 32a b c + 32a b  - 32a b)x - 32a c + 32a b - 32a
+--R            *
+--R                +---------+ +-+
+--R               \|c - b + a \|c
+--R        *
+--R           log
+--R                                                    +--------------+
+--R                        +---------+            +-+  |   2
+--R                  (- 2x\|c - b + a  + (2x + 2)\|a )\|c x  + b x + a
+--R                + 
+--R                     2       +-+ +---------+                   2
+--R                  (2x  + 2x)\|a \|c - b + a  + (- 2c + b - 2a)x  + (- b - 2a)x
+--R                + 
+--R                  - 2a
+--R             /
+--R                             +--------------+
+--R                         +-+ |   2                 2
+--R                (2x + 2)\|a \|c x  + b x + a  - b x  + (- b - 2a)x - 2a
+--R       + 
+--R                  2     2   3                 3  2       2         2    +-+
+--R           ((16a c  + 4b c)x  + (72a b c + 10b )x  + (32a c + 40a b )x)\|c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2 4           2      2   3                   3  2
+--R             - 16b c x  + (- 32a c  - 56b c)x  + (- 88a b c - 30b )x
+--R           + 
+--R                   2         2
+--R             (- 32a c - 40a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                               +--------------+
+--R                       +-+ +-+ |   2
+--R         (32b x + 64a)\|a \|c \|c x  + b x + a
+--R       + 
+--R                       2  2                2  +-+
+--R         ((- 32a c - 8b )x  - 64a b x - 64a )\|c
+--R     ,
+--R
+--R                            2                                2  +-+ +-+
+--R               ((16b c + 16b  + 16a b)x + 32a c + 32a b + 32a )\|a \|c
+--R            *
+--R                            +--------------+
+--R                +---------+ |   2
+--R               \|c + b + a \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 16a c  + (- 4b  - 16a b - 16a )c - 4b  - 4a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 32a b c - 32a b  - 32a b)x - 32a c - 32a b - 32a
+--R            *
+--R                +-+ +---------+
+--R               \|c \|c + b + a
+--R        *
+--R           log
+--R                                                  +--------------+
+--R                      +---------+            +-+  |   2
+--R                  (2x\|c + b + a  + (2x - 2)\|a )\|c x  + b x + a
+--R                + 
+--R                     2       +-+ +---------+                 2
+--R                  (2x  - 2x)\|a \|c + b + a  + (2c + b + 2a)x  + (b - 2a)x + 2a
+--R             /
+--R                             +--------------+
+--R                         +-+ |   2                 2
+--R                (2x - 2)\|a \|c x  + b x + a  - b x  + (b - 2a)x + 2a
+--R       + 
+--R                      2                3          2      2         2  +-+
+--R               ((32b c  + 48a b c + 12b )x + 64a c  + 96a c + 24a b )\|a
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                     3        2      2  2        2      4  2
+--R             (- 32a c  + (- 8b  - 48a )c  - 24a b c - 3b )x
+--R           + 
+--R                       2      2           3        2 2      3       2 2
+--R             (- 64a b c  - 96a b c - 24a b )x - 64a c  - 96a c - 24a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                            2                                2  +-----------+
+--R               ((32b c - 32b  + 32a b)x + 64a c - 64a b + 64a )\|- c + b - a
+--R            *
+--R                        +--------------+
+--R                +-+ +-+ |   2
+--R               \|a \|c \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 32a c  + (- 8b  + 32a b - 32a )c + 8b  - 8a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 64a b c + 64a b  - 64a b)x - 64a c + 64a b - 64a
+--R            *
+--R                +-----------+ +-+
+--R               \|- c + b - a \|c
+--R        *
+--R                 +--------------+
+--R                 |   2                        +-+
+--R                \|c x  + b x + a  + (- x - 1)\|a
+--R           atan(---------------------------------)
+--R                           +-----------+
+--R                         x\|- c + b - a
+--R       + 
+--R                  2     2   3                 3  2       2         2    +-+
+--R           ((16a c  + 4b c)x  + (72a b c + 10b )x  + (32a c + 40a b )x)\|c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2 4           2      2   3                   3  2
+--R             - 16b c x  + (- 32a c  - 56b c)x  + (- 88a b c - 30b )x
+--R           + 
+--R                   2         2
+--R             (- 32a c - 40a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                               +--------------+
+--R                       +-+ +-+ |   2
+--R         (32b x + 64a)\|a \|c \|c x  + b x + a
+--R       + 
+--R                       2  2                2  +-+
+--R         ((- 32a c - 8b )x  - 64a b x - 64a )\|c
+--R     ,
+--R
+--R                      2                3          2      2         2  +-+
+--R               ((32b c  + 48a b c + 12b )x + 64a c  + 96a c + 24a b )\|a
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                     3        2      2  2        2      4  2
+--R             (- 32a c  + (- 8b  - 48a )c  - 24a b c - 3b )x
+--R           + 
+--R                       2      2           3        2 2      3       2 2
+--R             (- 64a b c  - 96a b c - 24a b )x - 64a c  - 96a c - 24a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                            2                                2  +-+ +---------+
+--R               ((16b c - 16b  + 16a b)x + 32a c - 32a b + 32a )\|a \|c - b + a
+--R            *
+--R                    +--------------+
+--R                +-+ |   2
+--R               \|c \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 16a c  + (- 4b  + 16a b - 16a )c + 4b  - 4a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 32a b c + 32a b  - 32a b)x - 32a c + 32a b - 32a
+--R            *
+--R                +---------+ +-+
+--R               \|c - b + a \|c
+--R        *
+--R           log
+--R                                                    +--------------+
+--R                        +---------+            +-+  |   2
+--R                  (- 2x\|c - b + a  + (2x + 2)\|a )\|c x  + b x + a
+--R                + 
+--R                     2       +-+ +---------+                   2
+--R                  (2x  + 2x)\|a \|c - b + a  + (- 2c + b - 2a)x  + (- b - 2a)x
+--R                + 
+--R                  - 2a
+--R             /
+--R                             +--------------+
+--R                         +-+ |   2                 2
+--R                (2x + 2)\|a \|c x  + b x + a  - b x  + (- b - 2a)x - 2a
+--R       + 
+--R                            2                                2  +-----------+
+--R               ((32b c + 32b  + 32a b)x + 64a c + 64a b + 64a )\|- c - b - a
+--R            *
+--R                        +--------------+
+--R                +-+ +-+ |   2
+--R               \|a \|c \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 32a c  + (- 8b  - 32a b - 32a )c - 8b  - 8a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 64a b c - 64a b  - 64a b)x - 64a c - 64a b - 64a
+--R            *
+--R                +-----------+ +-+
+--R               \|- c - b - a \|c
+--R        *
+--R                 +--------------+
+--R                 |   2                      +-+
+--R                \|c x  + b x + a  + (x - 1)\|a
+--R           atan(-------------------------------)
+--R                          +-----------+
+--R                        x\|- c - b - a
+--R       + 
+--R                  2     2   3                 3  2       2         2    +-+
+--R           ((16a c  + 4b c)x  + (72a b c + 10b )x  + (32a c + 40a b )x)\|c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2 4           2      2   3                   3  2
+--R             - 16b c x  + (- 32a c  - 56b c)x  + (- 88a b c - 30b )x
+--R           + 
+--R                   2         2
+--R             (- 32a c - 40a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                               +--------------+
+--R                       +-+ +-+ |   2
+--R         (32b x + 64a)\|a \|c \|c x  + b x + a
+--R       + 
+--R                       2  2                2  +-+
+--R         ((- 32a c - 8b )x  - 64a b x - 64a )\|c
+--R     ,
+--R
+--R                      2                3          2      2         2  +-+
+--R               ((32b c  + 48a b c + 12b )x + 64a c  + 96a c + 24a b )\|a
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                     3        2      2  2        2      4  2
+--R             (- 32a c  + (- 8b  - 48a )c  - 24a b c - 3b )x
+--R           + 
+--R                       2      2           3        2 2      3       2 2
+--R             (- 64a b c  - 96a b c - 24a b )x - 64a c  - 96a c - 24a b
+--R        *
+--R           log
+--R                                     +--------------+
+--R                     +-+ +-+         |   2                     2             +-+
+--R                  (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R                + 
+--R                         +-+
+--R                  - 2c x\|a
+--R             /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R       + 
+--R                            2                                2  +-----------+
+--R               ((32b c + 32b  + 32a b)x + 64a c + 64a b + 64a )\|- c - b - a
+--R            *
+--R                        +--------------+
+--R                +-+ +-+ |   2
+--R               \|a \|c \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 32a c  + (- 8b  - 32a b - 32a )c - 8b  - 8a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 64a b c - 64a b  - 64a b)x - 64a c - 64a b - 64a
+--R            *
+--R                +-----------+ +-+
+--R               \|- c - b - a \|c
+--R        *
+--R                 +--------------+
+--R                 |   2                      +-+
+--R                \|c x  + b x + a  + (x - 1)\|a
+--R           atan(-------------------------------)
+--R                          +-----------+
+--R                        x\|- c - b - a
+--R       + 
+--R                            2                                2  +-----------+
+--R               ((32b c - 32b  + 32a b)x + 64a c - 64a b + 64a )\|- c + b - a
+--R            *
+--R                        +--------------+
+--R                +-+ +-+ |   2
+--R               \|a \|c \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 32a c  + (- 8b  + 32a b - 32a )c + 8b  - 8a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 64a b c + 64a b  - 64a b)x - 64a c + 64a b - 64a
+--R            *
+--R                +-----------+ +-+
+--R               \|- c + b - a \|c
+--R        *
+--R                 +--------------+
+--R                 |   2                        +-+
+--R                \|c x  + b x + a  + (- x - 1)\|a
+--R           atan(---------------------------------)
+--R                           +-----------+
+--R                         x\|- c + b - a
+--R       + 
+--R                  2     2   3                 3  2       2         2    +-+
+--R           ((16a c  + 4b c)x  + (72a b c + 10b )x  + (32a c + 40a b )x)\|c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                    2 4           2      2   3                   3  2
+--R             - 16b c x  + (- 32a c  - 56b c)x  + (- 88a b c - 30b )x
+--R           + 
+--R                   2         2
+--R             (- 32a c - 40a b )x
+--R        *
+--R            +-+ +-+
+--R           \|a \|c
+--R    /
+--R                               +--------------+
+--R                       +-+ +-+ |   2
+--R         (32b x + 64a)\|a \|c \|c x  + b x + a
+--R       + 
+--R                       2  2                2  +-+
+--R         ((- 32a c - 8b )x  - 64a b x - 64a )\|c
+--R     ,
+--R
+--R                          2                               2  +---+ +-+
+--R               ((8b c + 8b  + 8a b)x + 16a c + 16a b + 16a )\|- c \|a
+--R            *
+--R                            +--------------+
+--R                +---------+ |   2
+--R               \|c + b + a \|c x  + b x + a
+--R           + 
+--R                        2        2            2       3       2  2
+--R                 (- 8a c  + (- 2b  - 8a b - 8a )c - 2b  - 2a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 16a b c - 16a b  - 16a b)x - 16a c - 16a b - 16a
+--R            *
+--R                +---+ +---------+
+--R               \|- c \|c + b + a
+--R        *
+--R           log
+--R                                                  +--------------+
+--R                      +---------+            +-+  |   2
+--R                  (2x\|c + b + a  + (2x - 2)\|a )\|c x  + b x + a
+--R                + 
+--R                     2       +-+ +---------+                 2
+--R                  (2x  - 2x)\|a \|c + b + a  + (2c + b + 2a)x  + (b - 2a)x + 2a
+--R             /
+--R                             +--------------+
+--R                         +-+ |   2                 2
+--R                (2x - 2)\|a \|c x  + b x + a  - b x  + (b - 2a)x + 2a
+--R       + 
+--R                          2                               2  +---+ +-+
+--R               ((8b c - 8b  + 8a b)x + 16a c - 16a b + 16a )\|- c \|a
+--R            *
+--R                            +--------------+
+--R                +---------+ |   2
+--R               \|c - b + a \|c x  + b x + a
+--R           + 
+--R                        2        2            2       3       2  2
+--R                 (- 8a c  + (- 2b  + 8a b - 8a )c + 2b  - 2a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 16a b c + 16a b  - 16a b)x - 16a c + 16a b - 16a
+--R            *
+--R                +---+ +---------+
+--R               \|- c \|c - b + a
+--R        *
+--R           log
+--R                                                    +--------------+
+--R                        +---------+            +-+  |   2
+--R                  (- 2x\|c - b + a  + (2x + 2)\|a )\|c x  + b x + a
+--R                + 
+--R                     2       +-+ +---------+                   2
+--R                  (2x  + 2x)\|a \|c - b + a  + (- 2c + b - 2a)x  + (- b - 2a)x
+--R                + 
+--R                  - 2a
+--R             /
+--R                             +--------------+
+--R                         +-+ |   2                 2
+--R                (2x + 2)\|a \|c x  + b x + a  - b x  + (- b - 2a)x - 2a
+--R       + 
+--R                        2                3          2      2         2  +-+
+--R               ((- 32b c  - 48a b c - 12b )x - 64a c  - 96a c - 24a b )\|a
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                   3      2      2  2        2      4  2
+--R             (32a c  + (8b  + 48a )c  + 24a b c + 3b )x
+--R           + 
+--R                     2      2           3        2 2      3       2 2
+--R             (64a b c  + 96a b c + 24a b )x + 64a c  + 96a c + 24a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                 2     2   3                3  2       2         2    +---+
+--R           ((8a c  + 2b c)x  + (36a b c + 5b )x  + (16a c + 20a b )x)\|- c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   2 4           2      2   3                   3  2
+--R             - 8b c x  + (- 16a c  - 28b c)x  + (- 44a b c - 15b )x
+--R           + 
+--R                   2         2
+--R             (- 16a c - 20a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                 +--------------+
+--R                       +---+ +-+ |   2
+--R         (16b x + 32a)\|- c \|a \|c x  + b x + a
+--R       + 
+--R                       2  2                2  +---+
+--R         ((- 16a c - 4b )x  - 32a b x - 32a )\|- c
+--R     ,
+--R
+--R                          2                               2  +---+ +-+
+--R               ((8b c + 8b  + 8a b)x + 16a c + 16a b + 16a )\|- c \|a
+--R            *
+--R                            +--------------+
+--R                +---------+ |   2
+--R               \|c + b + a \|c x  + b x + a
+--R           + 
+--R                        2        2            2       3       2  2
+--R                 (- 8a c  + (- 2b  - 8a b - 8a )c - 2b  - 2a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 16a b c - 16a b  - 16a b)x - 16a c - 16a b - 16a
+--R            *
+--R                +---+ +---------+
+--R               \|- c \|c + b + a
+--R        *
+--R           log
+--R                                                  +--------------+
+--R                      +---------+            +-+  |   2
+--R                  (2x\|c + b + a  + (2x - 2)\|a )\|c x  + b x + a
+--R                + 
+--R                     2       +-+ +---------+                 2
+--R                  (2x  - 2x)\|a \|c + b + a  + (2c + b + 2a)x  + (b - 2a)x + 2a
+--R             /
+--R                             +--------------+
+--R                         +-+ |   2                 2
+--R                (2x - 2)\|a \|c x  + b x + a  - b x  + (b - 2a)x + 2a
+--R       + 
+--R                        2                3          2      2         2  +-+
+--R               ((- 32b c  - 48a b c - 12b )x - 64a c  - 96a c - 24a b )\|a
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                   3      2      2  2        2      4  2
+--R             (32a c  + (8b  + 48a )c  + 24a b c + 3b )x
+--R           + 
+--R                     2      2           3        2 2      3       2 2
+--R             (64a b c  + 96a b c + 24a b )x + 64a c  + 96a c + 24a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                            2                                2  +---+
+--R               ((16b c - 16b  + 16a b)x + 32a c - 32a b + 32a )\|- c
+--R            *
+--R                                  +--------------+
+--R                +-----------+ +-+ |   2
+--R               \|- c + b - a \|a \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 16a c  + (- 4b  + 16a b - 16a )c + 4b  - 4a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 32a b c + 32a b  - 32a b)x - 32a c + 32a b - 32a
+--R            *
+--R                +---+ +-----------+
+--R               \|- c \|- c + b - a
+--R        *
+--R                 +--------------+
+--R                 |   2                        +-+
+--R                \|c x  + b x + a  + (- x - 1)\|a
+--R           atan(---------------------------------)
+--R                           +-----------+
+--R                         x\|- c + b - a
+--R       + 
+--R                 2     2   3                3  2       2         2    +---+
+--R           ((8a c  + 2b c)x  + (36a b c + 5b )x  + (16a c + 20a b )x)\|- c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   2 4           2      2   3                   3  2
+--R             - 8b c x  + (- 16a c  - 28b c)x  + (- 44a b c - 15b )x
+--R           + 
+--R                   2         2
+--R             (- 16a c - 20a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                 +--------------+
+--R                       +---+ +-+ |   2
+--R         (16b x + 32a)\|- c \|a \|c x  + b x + a
+--R       + 
+--R                       2  2                2  +---+
+--R         ((- 16a c - 4b )x  - 32a b x - 32a )\|- c
+--R     ,
+--R
+--R                          2                               2  +---+ +-+
+--R               ((8b c - 8b  + 8a b)x + 16a c - 16a b + 16a )\|- c \|a
+--R            *
+--R                            +--------------+
+--R                +---------+ |   2
+--R               \|c - b + a \|c x  + b x + a
+--R           + 
+--R                        2        2            2       3       2  2
+--R                 (- 8a c  + (- 2b  + 8a b - 8a )c + 2b  - 2a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 16a b c + 16a b  - 16a b)x - 16a c + 16a b - 16a
+--R            *
+--R                +---+ +---------+
+--R               \|- c \|c - b + a
+--R        *
+--R           log
+--R                                                    +--------------+
+--R                        +---------+            +-+  |   2
+--R                  (- 2x\|c - b + a  + (2x + 2)\|a )\|c x  + b x + a
+--R                + 
+--R                     2       +-+ +---------+                   2
+--R                  (2x  + 2x)\|a \|c - b + a  + (- 2c + b - 2a)x  + (- b - 2a)x
+--R                + 
+--R                  - 2a
+--R             /
+--R                             +--------------+
+--R                         +-+ |   2                 2
+--R                (2x + 2)\|a \|c x  + b x + a  - b x  + (- b - 2a)x - 2a
+--R       + 
+--R                        2                3          2      2         2  +-+
+--R               ((- 32b c  - 48a b c - 12b )x - 64a c  - 96a c - 24a b )\|a
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                   3      2      2  2        2      4  2
+--R             (32a c  + (8b  + 48a )c  + 24a b c + 3b )x
+--R           + 
+--R                     2      2           3        2 2      3       2 2
+--R             (64a b c  + 96a b c + 24a b )x + 64a c  + 96a c + 24a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                            2                                2  +-----------+
+--R               ((16b c + 16b  + 16a b)x + 32a c + 32a b + 32a )\|- c - b - a
+--R            *
+--R                          +--------------+
+--R                +---+ +-+ |   2
+--R               \|- c \|a \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 16a c  + (- 4b  - 16a b - 16a )c - 4b  - 4a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 32a b c - 32a b  - 32a b)x - 32a c - 32a b - 32a
+--R            *
+--R                +-----------+ +---+
+--R               \|- c - b - a \|- c
+--R        *
+--R                 +--------------+
+--R                 |   2                      +-+
+--R                \|c x  + b x + a  + (x - 1)\|a
+--R           atan(-------------------------------)
+--R                          +-----------+
+--R                        x\|- c - b - a
+--R       + 
+--R                 2     2   3                3  2       2         2    +---+
+--R           ((8a c  + 2b c)x  + (36a b c + 5b )x  + (16a c + 20a b )x)\|- c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   2 4           2      2   3                   3  2
+--R             - 8b c x  + (- 16a c  - 28b c)x  + (- 44a b c - 15b )x
+--R           + 
+--R                   2         2
+--R             (- 16a c - 20a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                 +--------------+
+--R                       +---+ +-+ |   2
+--R         (16b x + 32a)\|- c \|a \|c x  + b x + a
+--R       + 
+--R                       2  2                2  +---+
+--R         ((- 16a c - 4b )x  - 32a b x - 32a )\|- c
+--R     ,
+--R
+--R                        2                3          2      2         2  +-+
+--R               ((- 32b c  - 48a b c - 12b )x - 64a c  - 96a c - 24a b )\|a
+--R            *
+--R                +--------------+
+--R                |   2
+--R               \|c x  + b x + a
+--R           + 
+--R                   3      2      2  2        2      4  2
+--R             (32a c  + (8b  + 48a )c  + 24a b c + 3b )x
+--R           + 
+--R                     2      2           3        2 2      3       2 2
+--R             (64a b c  + 96a b c + 24a b )x + 64a c  + 96a c + 24a b
+--R        *
+--R                       +--------------+
+--R                 +---+ |   2               +---+ +-+
+--R                \|- c \|c x  + b x + a  - \|- c \|a
+--R           atan(------------------------------------)
+--R                                 c x
+--R       + 
+--R                            2                                2  +-----------+
+--R               ((16b c + 16b  + 16a b)x + 32a c + 32a b + 32a )\|- c - b - a
+--R            *
+--R                          +--------------+
+--R                +---+ +-+ |   2
+--R               \|- c \|a \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 16a c  + (- 4b  - 16a b - 16a )c - 4b  - 4a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 32a b c - 32a b  - 32a b)x - 32a c - 32a b - 32a
+--R            *
+--R                +-----------+ +---+
+--R               \|- c - b - a \|- c
+--R        *
+--R                 +--------------+
+--R                 |   2                      +-+
+--R                \|c x  + b x + a  + (x - 1)\|a
+--R           atan(-------------------------------)
+--R                          +-----------+
+--R                        x\|- c - b - a
+--R       + 
+--R                            2                                2  +---+
+--R               ((16b c - 16b  + 16a b)x + 32a c - 32a b + 32a )\|- c
+--R            *
+--R                                  +--------------+
+--R                +-----------+ +-+ |   2
+--R               \|- c + b - a \|a \|c x  + b x + a
+--R           + 
+--R                         2        2              2       3       2  2
+--R                 (- 16a c  + (- 4b  + 16a b - 16a )c + 4b  - 4a b )x
+--R               + 
+--R                                   2      2         2       2       3
+--R                 (- 32a b c + 32a b  - 32a b)x - 32a c + 32a b - 32a
+--R            *
+--R                +---+ +-----------+
+--R               \|- c \|- c + b - a
+--R        *
+--R                 +--------------+
+--R                 |   2                        +-+
+--R                \|c x  + b x + a  + (- x - 1)\|a
+--R           atan(---------------------------------)
+--R                           +-----------+
+--R                         x\|- c + b - a
+--R       + 
+--R                 2     2   3                3  2       2         2    +---+
+--R           ((8a c  + 2b c)x  + (36a b c + 5b )x  + (16a c + 20a b )x)\|- c
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                   2 4           2      2   3                   3  2
+--R             - 8b c x  + (- 16a c  - 28b c)x  + (- 44a b c - 15b )x
+--R           + 
+--R                   2         2
+--R             (- 16a c - 20a b )x
+--R        *
+--R            +---+ +-+
+--R           \|- c \|a
+--R    /
+--R                                 +--------------+
+--R                       +---+ +-+ |   2
+--R         (16b x + 32a)\|- c \|a \|c x  + b x + a
+--R       + 
+--R                       2  2                2  +---+
+--R         ((- 16a c - 4b )x  - 32a b x - 32a )\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 202
+
+--S 203 of 1580
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          2                                2  +-+ +-+
+--R             ((16b c + 16b  + 16a b)x + 32a c + 32a b + 32a )\|a \|c
+--R          *
+--R                          +--------------+
+--R              +---------+ |   2
+--R             \|c + b + a \|c x  + b x + a
+--R         + 
+--R                       2        2              2       3       2  2
+--R               (- 16a c  + (- 4b  - 16a b - 16a )c - 4b  - 4a b )x
+--R             + 
+--R                                 2      2         2       2       3
+--R               (- 32a b c - 32a b  - 32a b)x - 32a c - 32a b - 32a
+--R          *
+--R              +-+ +---------+
+--R             \|c \|c + b + a
+--R      *
+--R         log
+--R                                                +--------------+
+--R                    +---------+            +-+  |   2
+--R                (2x\|c + b + a  + (2x - 2)\|a )\|c x  + b x + a
+--R              + 
+--R                   2       +-+ +---------+                 2
+--R                (2x  - 2x)\|a \|c + b + a  + (2c + b + 2a)x  + (b - 2a)x + 2a
+--R           /
+--R                           +--------------+
+--R                       +-+ |   2                 2
+--R              (2x - 2)\|a \|c x  + b x + a  - b x  + (b - 2a)x + 2a
+--R     + 
+--R                    2                3          2      2         2  +-+
+--R             ((32b c  + 48a b c + 12b )x + 64a c  + 96a c + 24a b )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   3        2      2  2        2      4  2
+--R           (- 32a c  + (- 8b  - 48a )c  - 24a b c - 3b )x
+--R         + 
+--R                     2      2           3        2 2      3       2 2
+--R           (- 64a b c  - 96a b c - 24a b )x - 64a c  - 96a c - 24a b
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                          2                                2  +-+ +---------+
+--R             ((16b c - 16b  + 16a b)x + 32a c - 32a b + 32a )\|a \|c - b + a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                       2        2              2       3       2  2
+--R               (- 16a c  + (- 4b  + 16a b - 16a )c + 4b  - 4a b )x
+--R             + 
+--R                                 2      2         2       2       3
+--R               (- 32a b c + 32a b  - 32a b)x - 32a c + 32a b - 32a
+--R          *
+--R              +---------+ +-+
+--R             \|c - b + a \|c
+--R      *
+--R         log
+--R                                                  +--------------+
+--R                      +---------+            +-+  |   2
+--R                (- 2x\|c - b + a  + (2x + 2)\|a )\|c x  + b x + a
+--R              + 
+--R                 2       +-+ +---------+                   2
+--R              (2x  + 2x)\|a \|c - b + a  + (- 2c + b - 2a)x  + (- b - 2a)x - 2a
+--R           /
+--R                           +--------------+
+--R                       +-+ |   2                 2
+--R              (2x + 2)\|a \|c x  + b x + a  - b x  + (- b - 2a)x - 2a
+--R     + 
+--R                            2                                2  +-+ +---------+
+--R             ((- 16b c + 16b  - 16a b)x - 32a c + 32a b - 32a )\|a \|c - b + a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                     2      2              2       3       2  2
+--R               (16a c  + (4b  - 16a b + 16a )c - 4b  + 4a b )x
+--R             + 
+--R                               2      2         2       2       3
+--R               (32a b c - 32a b  + 32a b)x + 32a c - 32a b + 32a
+--R          *
+--R              +---------+ +-+
+--R             \|c - b + a \|c
+--R      *
+--R                     (2c - b)x + b - 2a
+--R         atanh(------------------------------)
+--R                             +--------------+
+--R                 +---------+ |   2
+--R               2\|c - b + a \|c x  + b x + a
+--R     + 
+--R                    2                3          2      2         2  +-+
+--R             ((32b c  + 48a b c + 12b )x + 64a c  + 96a c + 24a b )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   3        2      2  2        2      4  2
+--R           (- 32a c  + (- 8b  - 48a )c  - 24a b c - 3b )x
+--R         + 
+--R                     2      2           3        2 2      3       2 2
+--R           (- 64a b c  - 96a b c - 24a b )x - 64a c  - 96a c - 24a b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                            2                                2  +-+ +-+
+--R             ((- 16b c - 16b  - 16a b)x - 32a c - 32a b - 32a )\|a \|c
+--R          *
+--R                          +--------------+
+--R              +---------+ |   2
+--R             \|c + b + a \|c x  + b x + a
+--R         + 
+--R                     2      2              2       3       2  2
+--R               (16a c  + (4b  + 16a b + 16a )c + 4b  + 4a b )x
+--R             + 
+--R                               2      2         2       2       3
+--R               (32a b c + 32a b  + 32a b)x + 32a c + 32a b + 32a
+--R          *
+--R              +-+ +---------+
+--R             \|c \|c + b + a
+--R      *
+--R                     (2c + b)x + b + 2a
+--R         atanh(------------------------------)
+--R                             +--------------+
+--R                 +---------+ |   2
+--R               2\|c + b + a \|c x  + b x + a
+--R     + 
+--R                               +--------------+
+--R               2       2   +-+ |   2
+--R       (- 40a b x - 80a b)\|c \|c x  + b x + a
+--R     + 
+--R                      3  2        2       2   +-+ +-+
+--R       ((40a b c + 10b )x  + 80a b x + 80a b)\|a \|c
+--R  /
+--R                             +--------------+
+--R                     +-+ +-+ |   2
+--R       (32b x + 64a)\|a \|c \|c x  + b x + a
+--R     + 
+--R                     2  2                2  +-+
+--R       ((- 32a c - 8b )x  - 64a b x - 64a )\|c
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 1580
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 1580
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          2                                2  +-+ +-+
+--R             ((16b c + 16b  + 16a b)x + 32a c + 32a b + 32a )\|a \|c
+--R          *
+--R                          +--------------+
+--R              +---------+ |   2
+--R             \|c + b + a \|c x  + b x + a
+--R         + 
+--R                       2        2              2       3       2  2
+--R               (- 16a c  + (- 4b  - 16a b - 16a )c - 4b  - 4a b )x
+--R             + 
+--R                                 2      2         2       2       3
+--R               (- 32a b c - 32a b  - 32a b)x - 32a c - 32a b - 32a
+--R          *
+--R              +-+ +---------+
+--R             \|c \|c + b + a
+--R      *
+--R         log
+--R                                                +--------------+
+--R                    +---------+            +-+  |   2
+--R                (2x\|c + b + a  + (2x - 2)\|a )\|c x  + b x + a
+--R              + 
+--R                   2       +-+ +---------+                 2
+--R                (2x  - 2x)\|a \|c + b + a  + (2c + b + 2a)x  + (b - 2a)x + 2a
+--R           /
+--R                           +--------------+
+--R                       +-+ |   2                 2
+--R              (2x - 2)\|a \|c x  + b x + a  - b x  + (b - 2a)x + 2a
+--R     + 
+--R                    2                3          2      2         2  +-+
+--R             ((32b c  + 48a b c + 12b )x + 64a c  + 96a c + 24a b )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   3        2      2  2        2      4  2
+--R           (- 32a c  + (- 8b  - 48a )c  - 24a b c - 3b )x
+--R         + 
+--R                     2      2           3        2 2      3       2 2
+--R           (- 64a b c  - 96a b c - 24a b )x - 64a c  - 96a c - 24a b
+--R      *
+--R         log
+--R                                   +--------------+
+--R                   +-+ +-+         |   2                     2             +-+
+--R                (2\|a \|c  + 2c x)\|c x  + b x + a  + (- 2c x  - b x - 2a)\|c
+--R              + 
+--R                       +-+
+--R                - 2c x\|a
+--R           /
+--R                    +--------------+
+--R                +-+ |   2
+--R              2\|a \|c x  + b x + a  - b x - 2a
+--R     + 
+--R                            2                                2  +-+ +---------+
+--R             ((- 16b c + 16b  - 16a b)x - 32a c + 32a b - 32a )\|a \|c - b + a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                     2      2              2       3       2  2
+--R               (16a c  + (4b  - 16a b + 16a )c - 4b  + 4a b )x
+--R             + 
+--R                               2      2         2       2       3
+--R               (32a b c - 32a b  + 32a b)x + 32a c - 32a b + 32a
+--R          *
+--R              +---------+ +-+
+--R             \|c - b + a \|c
+--R      *
+--R                     (2c - b)x + b - 2a
+--R         atanh(------------------------------)
+--R                             +--------------+
+--R                 +---------+ |   2
+--R               2\|c - b + a \|c x  + b x + a
+--R     + 
+--R                    2                3          2      2         2  +-+
+--R             ((32b c  + 48a b c + 12b )x + 64a c  + 96a c + 24a b )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   3        2      2  2        2      4  2
+--R           (- 32a c  + (- 8b  - 48a )c  - 24a b c - 3b )x
+--R         + 
+--R                     2      2           3        2 2      3       2 2
+--R           (- 64a b c  - 96a b c - 24a b )x - 64a c  - 96a c - 24a b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                            2                                2  +-+ +-+
+--R             ((- 16b c - 16b  - 16a b)x - 32a c - 32a b - 32a )\|a \|c
+--R          *
+--R                          +--------------+
+--R              +---------+ |   2
+--R             \|c + b + a \|c x  + b x + a
+--R         + 
+--R                     2      2              2       3       2  2
+--R               (16a c  + (4b  + 16a b + 16a )c + 4b  + 4a b )x
+--R             + 
+--R                               2      2         2       2       3
+--R               (32a b c + 32a b  + 32a b)x + 32a c + 32a b + 32a
+--R          *
+--R              +-+ +---------+
+--R             \|c \|c + b + a
+--R      *
+--R                     (2c + b)x + b + 2a
+--R         atanh(------------------------------)
+--R                             +--------------+
+--R                 +---------+ |   2
+--R               2\|c + b + a \|c x  + b x + a
+--R     + 
+--R                          2                                2  +-----------+ +-+
+--R             ((32b c - 32b  + 32a b)x + 64a c - 64a b + 64a )\|- c + b - a \|a
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|c \|c x  + b x + a
+--R         + 
+--R                       2        2              2       3       2  2
+--R               (- 32a c  + (- 8b  + 32a b - 32a )c + 8b  - 8a b )x
+--R             + 
+--R                                 2      2         2       2       3
+--R               (- 64a b c + 64a b  - 64a b)x - 64a c + 64a b - 64a
+--R          *
+--R              +-----------+ +-+
+--R             \|- c + b - a \|c
+--R      *
+--R               +--------------+
+--R               |   2                        +-+
+--R              \|c x  + b x + a  + (- x - 1)\|a
+--R         atan(---------------------------------)
+--R                         +-----------+
+--R                       x\|- c + b - a
+--R     + 
+--R                               +--------------+
+--R               2       2   +-+ |   2
+--R       (- 40a b x - 80a b)\|c \|c x  + b x + a
+--R     + 
+--R                      3  2        2       2   +-+ +-+
+--R       ((40a b c + 10b )x  + 80a b x + 80a b)\|a \|c
+--R  /
+--R                             +--------------+
+--R                     +-+ +-+ |   2
+--R       (32b x + 64a)\|a \|c \|c x  + b x + a
+--R     + 
+--R                     2  2                2  +-+
+--R       ((- 32a c - 8b )x  - 64a b x - 64a )\|c
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 1580
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 206
+
+)clear all
+
+--S 207 of 1580
+t0:=sqrt(-1-x+x^2)/(1-x^2)
+--R 
+--R
+--R           +----------+
+--R           | 2
+--R          \|x  - x - 1
+--R   (1)  - -------------
+--R               2
+--R              x  - 1
+--R                                                    Type: Expression(Integer)
+--E 207
+
+--S 208 of 1580
+r0:=-1/2*atan(1/2*(3-x)/sqrt(-1-x+x^2))+atanh(1/2*(1-2*x)/sqrt(-1-x+x^2))+_
+   1/2*atanh(1/2*(1+3*x)/sqrt(-1-x+x^2))
+--R 
+--R
+--R                  3x + 1                   2x - 1                  x - 3
+--R        atanh(--------------) - 2atanh(--------------) + atan(--------------)
+--R                +----------+             +----------+           +----------+
+--R                | 2                      | 2                    | 2
+--R              2\|x  - x - 1            2\|x  - x - 1          2\|x  - x - 1
+--R   (2)  ---------------------------------------------------------------------
+--R                                          2
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +----------+                  +----------+
+--R              | 2                           | 2
+--R       2log(2\|x  - x - 1  - 2x + 1) - log(\|x  - x - 1  - x)
+--R     + 
+--R            +----------+                   +----------+
+--R            | 2                            | 2
+--R       log(\|x  - x - 1  - x - 2) + 2atan(\|x  - x - 1  - x + 1)
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 209
+
+--S 210 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +----------+                  +----------+
+--R              | 2                           | 2
+--R       2log(2\|x  - x - 1  - 2x + 1) - log(\|x  - x - 1  - x)
+--R     + 
+--R            +----------+
+--R            | 2                               3x + 1
+--R       log(\|x  - x - 1  - x - 2) - atanh(--------------)
+--R                                            +----------+
+--R                                            | 2
+--R                                          2\|x  - x - 1
+--R     + 
+--R                                       +----------+
+--R                  2x - 1               | 2
+--R       2atanh(--------------) + 2atan(\|x  - x - 1  - x + 1)
+--R                +----------+
+--R                | 2
+--R              2\|x  - x - 1
+--R     + 
+--R                   x - 3
+--R       - atan(--------------)
+--R                +----------+
+--R                | 2
+--R              2\|x  - x - 1
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 210
+
+--S 211 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 211
+
+)clear all
+
+--S 212 of 1580
+t0:=(x+x^2)^(3/2)/(1+x^2)
+--R 
+--R
+--R                 +------+
+--R          2      | 2
+--R        (x  + x)\|x  + x
+--R   (1)  -----------------
+--R               2
+--R              x  + 1
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 1580
+r0:=-5/4*atanh(x/sqrt(x+x^2))-atan(1/2*(%i+(1+2*%i)*x)/(sqrt(1-%i)*_
+   sqrt(x+x^2)))/sqrt(1-%i)+atan(1/2*(%i+(-1+2*%i)*x)/(sqrt(1+%i)*_
+   sqrt(x+x^2)))/sqrt(1+%i)+5/4*sqrt(x+x^2)+1/2*x*sqrt(x+x^2)
+--R 
+--R
+--R   (2)
+--R           +------+ +------+          x
+--R       - 5\|1 - %i \|1 + %i atanh(---------)
+--R                                   +------+
+--R                                   | 2
+--R                                  \|x  + x
+--R     + 
+--R           +------+       (1 + 2%i)x + %i
+--R       - 4\|1 + %i atan(-------------------)
+--R                                   +------+
+--R                          +------+ | 2
+--R                        2\|1 - %i \|x  + x
+--R     + 
+--R                                                                        +------+
+--R         +------+       (1 - 2%i)x - %i               +------+ +------+ | 2
+--R     - 4\|1 - %i atan(-------------------) + (2x + 5)\|1 - %i \|1 + %i \|x  + x
+--R                                 +------+
+--R                        +------+ | 2
+--R                      2\|1 + %i \|x  + x
+--R  /
+--R       +------+ +------+
+--R     4\|1 - %i \|1 + %i
+--R                                           Type: Expression(Complex(Integer))
+--E 213
+
+--S 214 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                    +------+
+--R                       4+-+    %pi  | 2             2             4+-+    %pi
+--R         ((- 128x - 64)\|8 cos(---)\|x  + x  + (128x  + 128x + 16)\|8 cos(---))
+--R                                8                                          8
+--R      *
+--R         log
+--R                                                   +------+
+--R                4+-+    %pi     4+-+    %pi        | 2        4+-+2    %pi 2
+--R              (2\|8 sin(---) + 2\|8 cos(---) - 4x)\|x  + x  + \|8  sin(---)
+--R                         8               8                              8
+--R            + 
+--R                        4+-+    %pi    4+-+2    %pi 2             4+-+    %pi
+--R              (- 2x + 2)\|8 sin(---) + \|8  cos(---)  + (- 2x - 2)\|8 cos(---)
+--R                                 8               8                         8
+--R            + 
+--R                2
+--R              4x  + 2x + 2
+--R     + 
+--R                    +------+                           +------+
+--R                    | 2            2                   | 2
+--R       ((160x + 80)\|x  + x  - 160x  - 160x - 20)log(2\|x  + x  - 2x - 1)
+--R     + 
+--R                                  +------+
+--R                     4+-+    %pi  | 2               2             4+-+    %pi
+--R         ((128x + 64)\|8 cos(---)\|x  + x  + (- 128x  - 128x - 16)\|8 cos(---))
+--R                              8                                            8
+--R      *
+--R         log
+--R                                                     +------+
+--R                  4+-+    %pi     4+-+    %pi        | 2        4+-+2    %pi 2
+--R              (- 2\|8 sin(---) - 2\|8 cos(---) - 4x)\|x  + x  + \|8  sin(---)
+--R                           8               8                              8
+--R            + 
+--R                      4+-+    %pi    4+-+2    %pi 2           4+-+    %pi      2
+--R              (2x - 2)\|8 sin(---) + \|8  cos(---)  + (2x + 2)\|8 cos(---) + 4x
+--R                               8               8                       8
+--R            + 
+--R              2x + 2
+--R     + 
+--R                                   +------+
+--R                      4+-+    %pi  | 2               2             4+-+    %pi
+--R         ((256x + 128)\|8 sin(---)\|x  + x  + (- 256x  - 256x - 32)\|8 sin(---))
+--R                               8                                            8
+--R      *
+--R                     4+-+    %pi    4+-+    %pi
+--R                     \|8 sin(---) - \|8 cos(---) + 2
+--R                              8              8
+--R         atan(---------------------------------------------)
+--R                +------+
+--R                | 2        4+-+    %pi    4+-+    %pi
+--R              2\|x  + x  + \|8 sin(---) + \|8 cos(---) - 2x
+--R                                    8              8
+--R     + 
+--R                                   +------+
+--R                      4+-+    %pi  | 2               2             4+-+    %pi
+--R         ((256x + 128)\|8 sin(---)\|x  + x  + (- 256x  - 256x - 32)\|8 sin(---))
+--R                               8                                            8
+--R      *
+--R                     4+-+    %pi    4+-+    %pi
+--R                     \|8 sin(---) - \|8 cos(---) - 2
+--R                              8              8
+--R         atan(---------------------------------------------)
+--R                +------+
+--R                | 2        4+-+    %pi    4+-+    %pi
+--R              2\|x  + x  - \|8 sin(---) - \|8 cos(---) - 2x
+--R                                    8              8
+--R     + 
+--R                                    +------+
+--R              3       2             | 2            4       3       2
+--R       (- 128x  - 448x  - 264x - 4)\|x  + x  + 128x  + 512x  + 472x  + 88x - 9
+--R  /
+--R                  +------+
+--R                  | 2            2
+--R     (256x + 128)\|x  + x  - 256x  - 256x - 32
+--R                                         Type: Union(Expression(Integer),...)
+--E 214
+
+--S 215 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R               +------+ +------+4+-+    %pi
+--R            16\|1 - %i \|1 + %i \|8 cos(---)
+--R                                         8
+--R         *
+--R            log
+--R                                                      +------+
+--R                   4+-+    %pi     4+-+    %pi        | 2        4+-+2    %pi 2
+--R                 (2\|8 sin(---) + 2\|8 cos(---) - 4x)\|x  + x  + \|8  sin(---)
+--R                            8               8                              8
+--R               + 
+--R                           4+-+    %pi    4+-+2    %pi 2
+--R                 (- 2x + 2)\|8 sin(---) + \|8  cos(---)
+--R                                    8               8
+--R               + 
+--R                           4+-+    %pi      2
+--R                 (- 2x - 2)\|8 cos(---) + 4x  + 2x + 2
+--R                                    8
+--R     + 
+--R                                 +------+
+--R          +------+ +------+      | 2
+--R       20\|1 - %i \|1 + %i log(2\|x  + x  - 2x - 1)
+--R     + 
+--R            +------+ +------+4+-+    %pi
+--R         16\|1 - %i \|1 + %i \|8 cos(---)
+--R                                      8
+--R      *
+--R         log
+--R                                                     +------+
+--R                  4+-+    %pi     4+-+    %pi        | 2        4+-+2    %pi 2
+--R              (- 2\|8 sin(---) - 2\|8 cos(---) - 4x)\|x  + x  + \|8  sin(---)
+--R                           8               8                              8
+--R            + 
+--R                      4+-+    %pi    4+-+2    %pi 2           4+-+    %pi      2
+--R              (2x - 2)\|8 sin(---) + \|8  cos(---)  + (2x + 2)\|8 cos(---) + 4x
+--R                               8               8                       8
+--R            + 
+--R              2x + 2
+--R     + 
+--R          +------+ +------+          x
+--R       40\|1 - %i \|1 + %i atanh(---------)
+--R                                  +------+
+--R                                  | 2
+--R                                 \|x  + x
+--R     + 
+--R            +------+ +------+4+-+    %pi
+--R         32\|1 - %i \|1 + %i \|8 sin(---)
+--R                                      8
+--R      *
+--R                     4+-+    %pi    4+-+    %pi
+--R                     \|8 sin(---) - \|8 cos(---) + 2
+--R                              8              8
+--R         atan(---------------------------------------------)
+--R                +------+
+--R                | 2        4+-+    %pi    4+-+    %pi
+--R              2\|x  + x  + \|8 sin(---) + \|8 cos(---) - 2x
+--R                                    8              8
+--R     + 
+--R            +------+ +------+4+-+    %pi
+--R         32\|1 - %i \|1 + %i \|8 sin(---)
+--R                                      8
+--R      *
+--R                     4+-+    %pi    4+-+    %pi
+--R                     \|8 sin(---) - \|8 cos(---) - 2
+--R                              8              8
+--R         atan(---------------------------------------------)
+--R                +------+
+--R                | 2        4+-+    %pi    4+-+    %pi
+--R              2\|x  + x  - \|8 sin(---) - \|8 cos(---) - 2x
+--R                                    8              8
+--R     + 
+--R          +------+       (1 + 2%i)x + %i
+--R       32\|1 + %i atan(-------------------)
+--R                                  +------+
+--R                         +------+ | 2
+--R                       2\|1 - %i \|x  + x
+--R     + 
+--R          +------+       (1 - 2%i)x - %i        +------+ +------+
+--R       32\|1 - %i atan(-------------------) + 9\|1 - %i \|1 + %i
+--R                                  +------+
+--R                         +------+ | 2
+--R                       2\|1 + %i \|x  + x
+--R  /
+--R        +------+ +------+
+--R     32\|1 - %i \|1 + %i
+--R                                           Type: Expression(Complex(Integer))
+--E 215
+
+--S 216 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 3     2         %pi 12         3      2          %pi     %pi 11
+--R           (- 16x  - 8x  - 8)sin(---)   + (- 64x  - 32x  - 32)cos(---)sin(---)
+--R                                  8                                8       8
+--R         + 
+--R                      3      2          %pi 2
+--R               (- 160x  - 80x  - 80)cos(---)
+--R                                         8
+--R             + 
+--R                   5      3      2           4+-+2
+--R               (48x  - 10x  + 18x  - 26x + 2)\|8
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      3       2           %pi 3
+--R               (- 320x  - 160x  - 160)cos(---)
+--R                                           8
+--R             + 
+--R                    5      4       3     2            4+-+2    %pi
+--R               (160x  - 64x  - 124x  - 4x  - 124x - 4)\|8  cos(---)
+--R                                                                8
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      3       2           %pi 4
+--R               (- 496x  - 248x  - 248)cos(---)
+--R                                           8
+--R             + 
+--R                    5       4       3       2             4+-+2    %pi 2       7
+--R               (592x  + 128x  - 166x  + 110x  - 214x - 34)\|8  cos(---)  - 128x
+--R                                                                    8
+--R             + 
+--R                    6        5       4       3       2
+--R               1088x  + 1336x  + 460x  + 664x  + 168x  - 4
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      3       2           %pi 5
+--R               (- 640x  - 320x  - 320)cos(---)
+--R                                           8
+--R             + 
+--R                     5       4       3       2             4+-+2    %pi 3
+--R               (1152x  + 512x  - 112x  + 304x  - 240x - 80)\|8  cos(---)
+--R                                                                     8
+--R             + 
+--R                         7        6        5       4        3       2
+--R                 (- 2048x  + 1024x  + 2944x  + 192x  + 1024x  + 320x  - 128x)
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      8
+--R          *
+--R                 %pi 7
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      3       2           %pi 6
+--R               (- 704x  - 352x  - 352)cos(---)
+--R                                           8
+--R             + 
+--R                     5        4      3       2              4+-+2    %pi 4
+--R               (1696x  + 1024x  + 52x  + 540x  - 172x - 132)\|8  cos(---)
+--R                                                                      8
+--R             + 
+--R                         7        6        5        4       3       2
+--R                 (- 7168x  - 1536x  + 4672x  - 1696x  - 160x  - 160x  - 864x)
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         9       8       7       6       5       4       3
+--R                   - 128x  - 896x  - 544x  + 768x  + 471x  + 359x  + 248x
+--R                 + 
+--R                        2
+--R                   - 24x  + x + 1
+--R              *
+--R                 4+-+2
+--R                 \|8
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      3       2           %pi 7
+--R               (- 640x  - 320x  - 320)cos(---)
+--R                                           8
+--R             + 
+--R                     5        4       3       2             4+-+2    %pi 5
+--R               (2112x  + 1664x  + 424x  + 856x  + 40x - 168)\|8  cos(---)
+--R                                                                      8
+--R             + 
+--R                           7       6         5        4        3        2
+--R                   - 11264x  - 512x  + 15168x  + 6816x  + 4864x  + 1984x
+--R                 + 
+--R                   - 1344x - 96
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                        9       8        7        6        5        4        3
+--R                   1792x  - 256x  - 1472x  + 3904x  + 4934x  + 3310x  + 1680x
+--R                 + 
+--R                       2
+--R                   144x  - 22x + 2
+--R              *
+--R                 4+-+2    %pi
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      3       2           %pi 8
+--R               (- 496x  - 248x  - 248)cos(---)
+--R                                           8
+--R             + 
+--R                     5        4       3       2              4+-+2    %pi 6
+--R               (1888x  + 1792x  + 652x  + 900x  + 236x - 156)\|8  cos(---)
+--R                                                                       8
+--R             + 
+--R                           7         6        5        4        3        2
+--R                   - 23296x  - 22144x  + 5072x  + 4424x  + 4976x  + 5264x
+--R                 + 
+--R                   - 160x - 248
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                        9         8         7         6        5        4
+--R                   1408x  - 13696x  - 29344x  - 20224x  - 8797x  - 1205x
+--R                 + 
+--R                        3       2
+--R                   2552x  + 840x  - 11x - 3
+--R              *
+--R                 4+-+2    %pi 2
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                      10         9         8         7         6        5
+--R               - 4096x   - 13824x  - 24320x  - 23040x  - 14608x  - 5924x
+--R             + 
+--R                     4      3      2
+--R               - 384x  + 40x  + 16x  - 4x
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      3       2           %pi 9
+--R               (- 320x  - 160x  - 160)cos(---)
+--R                                           8
+--R             + 
+--R                     5        4       3       2              4+-+2    %pi 7
+--R               (1408x  + 1536x  + 688x  + 784x  + 304x - 112)\|8  cos(---)
+--R                                                                       8
+--R             + 
+--R                           7         6        5       4        3        2
+--R                   - 18432x  - 27648x  - 8320x  - 576x  + 1920x  + 4672x
+--R                 + 
+--R                   1280x - 256
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         9         8         7         6         5         4
+--R                   17920x  + 19968x  - 13184x  - 25728x  - 18916x  - 11796x
+--R                 + 
+--R                          3       2
+--R                   - 2400x  + 672x  + 68x - 12
+--R              *
+--R                 4+-+2    %pi 3
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                         11         10          9          8         7         6
+--R                   16384x   + 90112x   + 156672x  + 124416x  + 59968x  + 15584x
+--R                 + 
+--R                          5        4       3       2
+--R                   - 5424x  - 2560x  + 736x  + 288x  + 16x
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      8
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      3      2          %pi 10
+--R               (- 160x  - 80x  - 80)cos(---)
+--R                                         8
+--R             + 
+--R                    5        4       3       2             4+-+2    %pi 8
+--R               (816x  + 1024x  + 534x  + 530x  + 262x - 62)\|8  cos(---)
+--R                                                                     8
+--R             + 
+--R                           7         6         5        4        3        2
+--R                   - 13312x  - 25088x  - 16192x  - 8928x  - 3552x  + 1696x
+--R                 + 
+--R                   1248x - 128
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         9         8         7       6        5        4
+--R                   11904x  + 28032x  + 18336x  - 512x  - 6267x  - 6923x
+--R                 + 
+--R                          3       2
+--R                   - 3656x  - 280x  + 83x - 13
+--R              *
+--R                 4+-+2    %pi 4
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                           11         10         9          8          7
+--R                   - 57344x   - 77824x   + 66048x  + 186624x  + 172320x
+--R                 + 
+--R                          6         5        4       3       2
+--R                   107408x  + 40024x  + 5120x  + 336x  + 368x  + 56x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                          13         12         11         10         9
+--R                   - 4096x   - 16384x   - 32256x   - 36352x   - 27408x
+--R                 + 
+--R                           8        7        6       5       4      3     2
+--R                   - 15840x  - 6890x  - 2446x  - 648x  - 128x  - 14x  - 2x
+--R              *
+--R                 4+-+2
+--R                 \|8
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  8
+--R         + 
+--R                     3      2          %pi 11
+--R               (- 64x  - 32x  - 32)cos(---)
+--R                                        8
+--R             + 
+--R                    5       4       3       2             4+-+2    %pi 9
+--R               (288x  + 448x  + 276x  + 236x  + 148x - 20)\|8  cos(---)
+--R                                                                    8
+--R             + 
+--R                          7         6         5        4        3       2
+--R                   - 5120x  - 11776x  - 10048x  - 6560x  - 3712x  - 320x  + 448x
+--R                 + 
+--R                   - 32
+--R              *
+--R                     %pi 7
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                        9         8         7         6        5       4
+--R                   6912x  + 19200x  + 20288x  + 12096x  + 4782x  - 298x
+--R                 + 
+--R                          3       2
+--R                   - 1488x  - 400x  + 34x - 6
+--R              *
+--R                 4+-+2    %pi 5
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                           11          10          9         8         7
+--R                   - 32768x   - 114688x   - 139264x  - 60416x  + 11648x
+--R                 + 
+--R                         6         5         4        3       2
+--R                   36160x  + 31408x  + 12288x  + 1952x  + 192x  + 48x
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                        13         12        11         10         9         8
+--R                   8192x   + 16384x   - 5120x   - 41984x   - 57568x  - 47872x
+--R                 + 
+--R                           7         6        5       4       3      2
+--R                   - 27964x  - 12084x  - 3952x  - 928x  - 148x  - 12x
+--R              *
+--R                 4+-+2    %pi
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  8
+--R         + 
+--R                 3     2         %pi 12
+--R           (- 16x  - 8x  - 8)cos(---)
+--R                                  8
+--R         + 
+--R               5       4      3      2           4+-+2    %pi 10
+--R           (80x  + 128x  + 90x  + 78x  + 42x - 2)\|8  cos(---)
+--R                                                           8
+--R         + 
+--R                     7        6        5        4        3       2
+--R             (- 1152x  - 3520x  - 3848x  - 2836x  - 1928x  - 568x  + 32x - 4)
+--R          *
+--R                 %pi 8
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    9        8        7        6        5        4       3
+--R               1152x  + 4992x  + 7968x  + 7168x  + 4913x  + 2409x  + 472x
+--R             + 
+--R                    2
+--R               - 24x  + 7x - 1
+--R          *
+--R             4+-+2    %pi 6
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                      11         10         9         8         7         6
+--R               - 8192x   - 32768x   - 60416x  - 65024x  - 46624x  - 24640x
+--R             + 
+--R                      5       4       3
+--R               - 8436x  - 960x  + 136x  + 12x
+--R          *
+--R                 %pi 4
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    13         12         11         10         9        8
+--R               4096x   + 16384x   + 28160x   + 26112x   + 14352x  + 4448x
+--R             + 
+--R                     7       6       5       4      3     2
+--R               - 166x  - 890x  - 504x  - 176x  - 34x  - 6x
+--R          *
+--R             4+-+2    %pi 2
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                 13         12         11         10         9         8
+--R           16384x   + 49152x   + 71680x   + 69632x   + 48704x  + 25664x
+--R         + 
+--R                 7        6       5      4     3
+--R           10312x  + 3104x  + 688x  + 96x  + 8x
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + x
+--R     + 
+--R           4      3      2           %pi 12
+--R       (16x  + 16x  + 16x  + 16x)sin(---)
+--R                                      8
+--R     + 
+--R           4      3      2           %pi     %pi 11
+--R       (64x  + 64x  + 64x  + 64x)cos(---)sin(---)
+--R                                      8       8
+--R     + 
+--R                4       3       2            %pi 2
+--R           (160x  + 160x  + 160x  + 160x)cos(---)
+--R                                              8
+--R         + 
+--R                 6      5      4      3      4+-+2
+--R           (- 48x  - 24x  + 16x  - 16x  + 8x)\|8
+--R      *
+--R             %pi 10
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 3
+--R           (320x  + 320x  + 320x  + 320x)cos(---)
+--R                                              8
+--R         + 
+--R                  6      5       4      3      2       4+-+2    %pi
+--R           (- 160x  - 16x  + 176x  + 48x  + 80x  + 64x)\|8  cos(---)
+--R                                                                 8
+--R      *
+--R             %pi 9
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 4
+--R           (496x  + 496x  + 496x  + 496x)cos(---)
+--R                                              8
+--R         + 
+--R                  6       5       4      3       2        4+-+2    %pi 2       8
+--R           (- 592x  - 424x  + 176x  - 48x  + 128x  + 184x)\|8  cos(---)  + 128x
+--R                                                                    8
+--R         + 
+--R                  7        6       5       4       3      2
+--R           - 1024x  - 1896x  - 984x  - 800x  - 480x  + 72x  - 8x
+--R      *
+--R             %pi 8
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 5
+--R           (640x  + 640x  + 640x  + 640x)cos(---)
+--R                                              8
+--R         + 
+--R                   6        5       3       2        4+-+2    %pi 3
+--R           (- 1152x  - 1088x  - 256x  + 128x  + 320x)\|8  cos(---)
+--R                                                               8
+--R         + 
+--R                 8        6        5       4       3       2     %pi
+--R           (2048x  - 3712x  - 1408x  - 896x  - 896x  + 256x )cos(---)
+--R                                                                  8
+--R      *
+--R             %pi 7
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 6
+--R           (704x  + 704x  + 704x  + 704x)cos(---)
+--R                                              8
+--R         + 
+--R                   6        5       4       3      2        4+-+2    %pi 4
+--R           (- 1696x  - 1872x  - 352x  - 544x  + 64x  + 432x)\|8  cos(---)
+--R                                                                      8
+--R         + 
+--R                   8        7        6       5        4       3        2
+--R             (7168x  + 5120x  - 4800x  - 384x  + 1408x  - 128x  + 1088x  + 256x)
+--R          *
+--R                 %pi 2
+--R             cos(---)
+--R                  8
+--R         + 
+--R                     10       9       8       7       6       5       4      3
+--R                 128x   + 960x  + 976x  - 600x  - 872x  - 496x  - 416x  - 56x
+--R               + 
+--R                     2
+--R                 - 8x
+--R          *
+--R             4+-+2
+--R             \|8
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 7
+--R           (640x  + 640x  + 640x  + 640x)cos(---)
+--R                                              8
+--R         + 
+--R                   6        5       4       3       2        4+-+2    %pi 5
+--R           (- 2112x  - 2720x  - 992x  - 992x  - 160x  + 448x)\|8  cos(---)
+--R                                                                       8
+--R         + 
+--R                     8        7         6         5        4        3       2
+--R               11264x  + 6144x  - 16320x  - 13760x  - 6784x  - 4224x  + 832x
+--R             + 
+--R               832x
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      10       9        8        7        6        5        4
+--R               - 1792x   - 640x  + 1824x  - 3312x  - 6984x  - 5256x  - 2976x
+--R             + 
+--R                     3     2
+--R               - 720x  + 8x  + 8x
+--R          *
+--R             4+-+2    %pi
+--R             \|8  cos(---)
+--R                       8
+--R      *
+--R             %pi 5
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 8
+--R           (496x  + 496x  + 496x  + 496x)cos(---)
+--R                                              8
+--R         + 
+--R                   6        5        4        3       2        4+-+2    %pi 6
+--R           (- 1888x  - 2736x  - 1312x  - 1120x  - 320x  + 336x)\|8  cos(---)
+--R                                                                         8
+--R         + 
+--R                     8         7        6        5        4        3        2
+--R               23296x  + 33792x  + 3088x  - 8272x  - 6080x  - 7744x  - 1488x
+--R             + 
+--R               1040x
+--R          *
+--R                 %pi 4
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      10         9         8         7         6        5
+--R               - 1408x   + 12992x  + 36368x  + 33096x  + 16152x  + 4336x
+--R             + 
+--R                      4        3       2
+--R               - 2528x  - 2008x  - 136x  + 32x
+--R          *
+--R             4+-+2    %pi 2
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                11         10         9         8         7         6        5
+--R           4096x   + 15872x   + 30720x  + 33728x  + 23792x  + 11440x  + 2304x
+--R         + 
+--R                 4      3      2
+--R           - 128x  + 16x  + 16x
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 9
+--R           (320x  + 320x  + 320x  + 320x)cos(---)
+--R                                              8
+--R         + 
+--R                   6        5        4        3       2        4+-+2    %pi 7
+--R           (- 1408x  - 2240x  - 1280x  - 1024x  - 384x  + 192x)\|8  cos(---)
+--R                                                                         8
+--R         + 
+--R                     8         7         6        5        4        3        2
+--R               18432x  + 36864x  + 19840x  + 2432x  - 1664x  - 5760x  - 2560x
+--R             + 
+--R               512x
+--R          *
+--R                 %pi 5
+--R             cos(---)
+--R                  8
+--R         + 
+--R                       10         9        8         7         6         5
+--R               - 17920x   - 28928x  + 5440x  + 33696x  + 29584x  + 19152x
+--R             + 
+--R                    4       3       2
+--R               6848x  - 288x  - 272x  + 48x
+--R          *
+--R             4+-+2    %pi 3
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                       12         11          10          9          8         7
+--R               - 16384x   - 98304x   - 199680x   - 192512x  - 107584x  - 36736x
+--R             + 
+--R                    6        5       4       3      2
+--R               1344x  + 5632x  - 192x  - 640x  - 64x
+--R          *
+--R                 %pi
+--R             cos(---)
+--R                  8
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 10
+--R           (160x  + 160x  + 160x  + 160x)cos(---)
+--R                                              8
+--R         + 
+--R                  6        5       4       3       2       4+-+2    %pi 8
+--R           (- 816x  - 1432x  - 944x  - 720x  - 320x  + 72x)\|8  cos(---)
+--R                                                                     8
+--R         + 
+--R                    8         7         6         5        4       3        2
+--R             (13312x  + 31744x  + 27072x  + 14720x  + 7040x  - 640x  - 1600x )
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  8
+--R         + 
+--R                       10         9         8        7        6        5
+--R               - 11904x   - 33984x  - 30864x  - 5896x  + 7528x  + 9616x
+--R             + 
+--R                    4        3      2
+--R               6560x  + 1496x  - 56x  + 32x
+--R          *
+--R             4+-+2    %pi 4
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                     12          11         10          9          8          7
+--R               57344x   + 106496x   - 34304x   - 225792x  - 254752x  - 175840x
+--R             + 
+--R                       6         5        4       3       2
+--R               - 80320x  - 17664x  - 1120x  - 544x  - 192x
+--R          *
+--R                 %pi 2
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    14         13         12         11         10         9
+--R               4096x   + 18432x   + 39936x   + 50688x   + 42416x   + 26488x
+--R             + 
+--R                     8        7        6       5      4
+--R               12760x  + 4816x  + 1472x  + 312x  + 56x
+--R          *
+--R             4+-+2
+--R             \|8
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              8
+--R     + 
+--R               4      3      2           %pi 11
+--R           (64x  + 64x  + 64x  + 64x)cos(---)
+--R                                          8
+--R         + 
+--R                  6       5       4       3       2 4+-+2    %pi 9
+--R           (- 288x  - 592x  - 464x  - 336x  - 176x )\|8  cos(---)
+--R                                                              8
+--R         + 
+--R                    8         7         6         5        4        3       2
+--R               5120x  + 14336x  + 15296x  + 10432x  + 6272x  + 1664x  - 320x
+--R             + 
+--R               - 64x
+--R          *
+--R                 %pi 7
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      10         9         8         7        6        5
+--R               - 6912x   - 22656x  - 29024x  - 20272x  - 9224x  - 1288x
+--R             + 
+--R                    4        3      2
+--R               1888x  + 1008x  + 72x  + 8x
+--R          *
+--R             4+-+2    %pi 5
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                     12          11          10          9        8         7
+--R               32768x   + 131072x   + 192512x   + 117760x  + 7040x  - 44416x
+--R             + 
+--R                       6         5        4       3       2
+--R               - 47232x  - 24576x  - 5760x  - 640x  - 128x
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      14         13        12         11         10         9
+--R               - 8192x   - 20480x   - 2048x   + 46080x   + 77216x   + 72144x
+--R             + 
+--R                     8         7        6        5       4      3
+--R               46848x  + 22384x  + 8128x  + 2192x  + 416x  + 48x
+--R          *
+--R             4+-+2    %pi
+--R             \|8  cos(---)
+--R                       8
+--R      *
+--R             %pi
+--R         sin(---)
+--R              8
+--R     + 
+--R           4      3      2           %pi 12
+--R       (16x  + 16x  + 16x  + 16x)cos(---)
+--R                                      8
+--R     + 
+--R             6       5       4       3      2      4+-+2    %pi 10
+--R       (- 80x  - 168x  - 144x  - 112x  - 64x  - 8x)\|8  cos(---)
+--R                                                             8
+--R     + 
+--R               8        7        6        5        4        3       2
+--R         (1152x  + 4096x  + 5464x  + 4392x  + 3040x  + 1312x  + 136x  - 8x)
+--R      *
+--R             %pi 8
+--R         cos(---)
+--R              8
+--R     + 
+--R                  10        9         8         7        6        5        4
+--R           - 1152x   - 5568x  - 10320x  - 10600x  - 7768x  - 4304x  - 1312x
+--R         + 
+--R                3     2
+--R           - 72x  + 8x
+--R      *
+--R         4+-+2    %pi 6
+--R         \|8  cos(---)
+--R                   8
+--R     + 
+--R                12         11         10         9         8         7         6
+--R           8192x   + 36864x   + 75776x   + 91648x  + 73312x  + 42544x  + 17360x
+--R         + 
+--R                5      4      3      2
+--R           3584x  - 32x  - 48x  - 16x
+--R      *
+--R             %pi 4
+--R         cos(---)
+--R              8
+--R     + 
+--R                  14         13         12         11         10        9
+--R           - 4096x   - 18432x   - 35840x   - 38400x   - 24752x   - 9592x
+--R         + 
+--R                  8        7       6       5      4      3
+--R           - 1160x  + 1152x  + 864x  + 360x  + 88x  + 16x
+--R      *
+--R         4+-+2    %pi 2
+--R         \|8  cos(---)
+--R                   8
+--R     + 
+--R               14         13         12          11         10         9
+--R       - 16384x   - 57344x   - 94208x   - 100352x   - 76992x   - 44320x
+--R     + 
+--R               8        7        6       5      4
+--R       - 19616x  - 6592x  - 1664x  - 288x  - 32x
+--R  /
+--R               5       4+-+2    %pi 10       5       4+-+2    %pi     %pi 9
+--R           (16x  - 16x)\|8  sin(---)   + (64x  - 64x)\|8  cos(---)sin(---)
+--R                                 8                             8       8
+--R         + 
+--R                    5      4      3      2        4+-+2    %pi 2       7       6
+--R               (208x  + 96x  + 96x  + 96x  - 112x)\|8  cos(---)  - 192x  + 224x
+--R                                                            8
+--R             + 
+--R                   5       4       3      2
+--R               192x  + 192x  + 384x  - 32x
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  8
+--R         + 
+--R                    5       4       3       2        4+-+2    %pi 3
+--R               (384x  + 256x  + 256x  + 256x  - 128x)\|8  cos(---)
+--R                                                               8
+--R             + 
+--R                     7       6       5       4       3       2            %pi
+--R             (- 1280x  - 384x  - 384x  - 512x  + 768x  - 128x  - 128x)cos(---)
+--R                                                                           8
+--R          *
+--R                 %pi 7
+--R             sin(---)
+--R                  8
+--R         + 
+--R                    5       4       3       2       4+-+2    %pi 4
+--R               (544x  + 448x  + 448x  + 448x  - 96x)\|8  cos(---)
+--R                                                              8
+--R             + 
+--R                         7        6        5        4        3       2
+--R                 (- 3584x  - 2304x  - 1536x  - 2048x  + 1536x  + 256x  - 512x)
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         9       8      7       6      5       4       3     2
+--R                     256x  - 128x  + 80x  + 296x  + 40x  + 416x  + 208x  - 8x
+--R                   + 
+--R                     - 8x
+--R              *
+--R                 4+-+2
+--R                 \|8
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  8
+--R         + 
+--R                    5       4       3       2 4+-+2    %pi 5
+--R               (640x  + 640x  + 640x  + 640x )\|8  cos(---)
+--R                                                        8
+--R             + 
+--R                         7        6        5        4        3        2
+--R                 (- 5888x  - 5248x  - 2432x  - 3072x  + 2816x  + 2176x  - 640x)
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                        9        8       7        6       5       4       3
+--R                   1792x  + 1024x  + 528x  + 1168x  - 544x  + 192x  + 688x
+--R                 + 
+--R                      2
+--R                   48x  - 32x
+--R              *
+--R                 4+-+2    %pi
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  8
+--R         + 
+--R                    5       4       3       2       4+-+2    %pi 6
+--R               (544x  + 640x  + 640x  + 640x  + 96x)\|8  cos(---)
+--R                                                              8
+--R             + 
+--R                       7         6        5        4        3        2     %pi 4
+--R               (- 8832x  - 13248x  - 9856x  - 9856x  - 1024x  + 3392x )cos(---)
+--R                                                                            8
+--R             + 
+--R                        9        8        7        6        5        4       3
+--R                   3840x  + 2432x  - 1680x  - 1752x  - 5304x  - 3936x  + 176x
+--R                 + 
+--R                       2
+--R                   248x  - 40x
+--R              *
+--R                 4+-+2    %pi 2
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                      11        10        9        8        7        6        5
+--R               - 2304x   - 1664x   - 3360x  - 5296x  - 2624x  - 2992x  - 1248x
+--R             + 
+--R                   4       3      2
+--R               688x  + 320x  + 48x
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  8
+--R         + 
+--R                    5       4       3       2        4+-+2    %pi 7
+--R               (384x  + 512x  + 512x  + 512x  + 128x)\|8  cos(---)
+--R                                                               8
+--R             + 
+--R                            7         6         5         4        3        2
+--R                     - 5888x  - 12416x  - 11392x  - 10752x  - 4864x  + 1664x
+--R                   + 
+--R                     640x
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                        9         8         7         6        5        4
+--R                   8704x  + 17408x  + 15328x  + 13472x  + 4992x  - 3712x
+--R                 + 
+--R                          3       2
+--R                   - 1632x  + 224x
+--R              *
+--R                 4+-+2    %pi 3
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                          11        10         9         8         7         6
+--R                   - 9216x   + 1536x   + 23424x  + 28992x  + 38144x  + 27968x
+--R                 + 
+--R                        5       4       3       2
+--R                   6272x  + 704x  + 768x  + 192x
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      8
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  8
+--R         + 
+--R                    5       4       3       2        4+-+2    %pi 8
+--R               (208x  + 320x  + 320x  + 320x  + 112x)\|8  cos(---)
+--R                                                               8
+--R             + 
+--R                         7        6        5        4        3       2
+--R                 (- 3584x  - 8448x  - 9216x  - 8704x  - 5120x  - 256x  + 512x)
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                        9         8         7         6         5        4
+--R                   3840x  + 12928x  + 16688x  + 15864x  + 11960x  + 2912x
+--R                 + 
+--R                         3      2
+--R                   - 848x  - 24x  + 40x
+--R              *
+--R                 4+-+2    %pi 4
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                           11         10          9          8         7
+--R                   - 38400x   - 96000x   - 111296x  - 104992x  - 65792x
+--R                 + 
+--R                          6        5       4       3       2
+--R                   - 8608x  + 6848x  + 544x  - 256x  + 160x
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                        13        12        11        10         9         8
+--R                   1024x   - 1024x   - 5824x   - 9856x   - 13036x  - 11580x
+--R                 + 
+--R                          7        6       5      4      3     2
+--R                   - 6868x  - 2820x  - 660x  - 68x  + 20x  + 4x
+--R              *
+--R                 4+-+2
+--R                 \|8
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  8
+--R         + 
+--R                   5       4       3       2       4+-+2    %pi 9
+--R               (64x  + 128x  + 128x  + 128x  + 64x)\|8  cos(---)
+--R                                                             8
+--R             + 
+--R                         7        6        5        4        3       2
+--R                 (- 1280x  - 3456x  - 4224x  - 4096x  - 2816x  - 640x  + 128x)
+--R              *
+--R                     %pi 7
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                        9        8        7        6        5        4       3
+--R                   1792x  + 6144x  + 9488x  + 9936x  + 8096x  + 3776x  + 432x
+--R                 + 
+--R                        2
+--R                   - 16x  + 32x
+--R              *
+--R                 4+-+2    %pi 5
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                          11         10         9          8         7         6
+--R                   - 9216x   - 47616x   - 87168x  - 100032x  - 91648x  - 53696x
+--R                 + 
+--R                           5        4       3      2
+--R                   - 14208x  - 1344x  - 512x  - 64x
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         13         12         11         10         9         8
+--R                   10240x   + 30720x   + 48256x   + 57600x   + 50376x  + 30408x
+--R                 + 
+--R                         7        6       5      4     3     2
+--R                   12920x  + 3576x  + 568x  + 56x  + 8x  + 8x
+--R              *
+--R                 4+-+2    %pi
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  8
+--R         + 
+--R               5      4      3      2       4+-+2    %pi 10
+--R           (16x  + 32x  + 32x  + 32x  + 16x)\|8  cos(---)
+--R                                                      8
+--R         + 
+--R                  7       6        5        4       3       2     %pi 8
+--R           (- 192x  - 800x  - 1088x  - 1088x  - 896x  - 288x )cos(---)
+--R                                                                   8
+--R         + 
+--R                   9        8        7        6        5        4       3      2
+--R               256x  + 1152x  + 2320x  + 2744x  + 2520x  + 1632x  + 464x  + 40x
+--R             + 
+--R               8x
+--R          *
+--R             4+-+2    %pi 6
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                      11        10         9         8         7         6
+--R               - 2304x   - 9856x   - 21792x  - 30896x  - 31424x  - 24368x
+--R             + 
+--R                       5        4       3      2
+--R               - 12512x  - 3408x  - 576x  - 80x
+--R          *
+--R                 %pi 4
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    13        12         11         10         9         8
+--R               1024x   + 7168x   + 16704x   + 24448x   + 27668x  + 23012x
+--R             + 
+--R                     7        6        5       4      3     2
+--R               13836x  + 6140x  + 1900x  + 412x  + 52x  + 4x
+--R          *
+--R             4+-+2    %pi 2
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                  15         14         13         12         11         10
+--R           - 8192x   - 28672x   - 55296x   - 78848x   - 85600x   - 72336x
+--R         + 
+--R                   9         8         7        6       5       4      3
+--R           - 48304x  - 25456x  - 10640x  - 3440x  - 848x  - 144x  - 16x
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + x
+--R     + 
+--R          4     3     2          %pi 12
+--R       (8x  + 8x  + 8x  + 8x)sin(---)
+--R                                  8
+--R     + 
+--R           4      3      2           %pi     %pi 11
+--R       (32x  + 32x  + 32x  + 32x)cos(---)sin(---)
+--R                                      8       8
+--R     + 
+--R               4      3      2           %pi 2
+--R           (80x  + 80x  + 80x  + 80x)cos(---)
+--R                                          8
+--R         + 
+--R                 6     5     4     3     2 4+-+2
+--R           (- 16x  - 8x  - 8x  - 8x  + 8x )\|8
+--R      *
+--R             %pi 10
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 3
+--R           (160x  + 160x  + 160x  + 160x)cos(---)
+--R                                              8
+--R         + 
+--R                 6      5      4      3      2       4+-+2    %pi
+--R           (- 64x  - 32x  - 16x  - 16x  + 48x  + 16x)\|8  cos(---)
+--R                                                               8
+--R      *
+--R             %pi 9
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 4
+--R           (248x  + 248x  + 248x  + 248x)cos(---)
+--R                                              8
+--R         + 
+--R                  6       5       4       3      2       4+-+2    %pi 2       8
+--R           (- 208x  - 200x  - 136x  - 136x  + 72x  + 64x)\|8  cos(---)  + 192x
+--R                                                                   8
+--R         + 
+--R                 7       6       5       4       3      2
+--R           - 128x  - 328x  - 248x  - 432x  - 112x  + 88x  + 8x
+--R      *
+--R             %pi 8
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 5
+--R           (320x  + 320x  + 320x  + 320x)cos(---)
+--R                                              8
+--R         + 
+--R                  6       5       4       3      2        4+-+2    %pi 3
+--R           (- 384x  - 448x  - 320x  - 320x  + 64x  + 128x)\|8  cos(---)
+--R                                                                    8
+--R         + 
+--R               8        7       6       5       4       3       2           %pi
+--R         (1280x  + 1024x  + 416x  + 736x  - 512x  - 256x  + 352x  + 32x)cos(---)
+--R                                                                             8
+--R      *
+--R             %pi 7
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 6
+--R           (352x  + 352x  + 352x  + 352x)cos(---)
+--R                                              8
+--R         + 
+--R                  6       5       4       3      2        4+-+2    %pi 4
+--R           (- 544x  - 720x  - 528x  - 528x  + 16x  + 192x)\|8  cos(---)
+--R                                                                    8
+--R         + 
+--R                   8        7        6        5       4        3       2
+--R             (3584x  + 4096x  + 2240x  + 2752x  - 704x  - 1216x  + 640x  + 128x)
+--R          *
+--R                 %pi 2
+--R             cos(---)
+--R                  8
+--R         + 
+--R                  10      8       7       6       5       4      3 4+-+2
+--R           (- 256x   + 16x  - 368x  - 160x  - 416x  - 432x  - 48x )\|8
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 7
+--R           (320x  + 320x  + 320x  + 320x)cos(---)
+--R                                              8
+--R         + 
+--R                  6       5       4       3      2        4+-+2    %pi 5
+--R           (- 640x  - 960x  - 736x  - 736x  - 96x  + 224x)\|8  cos(---)
+--R                                                                    8
+--R         + 
+--R                   8        7        6        5        4        3      2
+--R             (5888x  + 8192x  + 4320x  + 4000x  - 1536x  - 3840x  + 32x  + 352x)
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      10        9       8        7      6       5       4
+--R               - 1792x   - 1920x  - 816x  - 1416x  + 32x  + 184x  - 912x
+--R             + 
+--R                     3      2
+--R               - 312x  + 32x  + 8x
+--R          *
+--R             4+-+2    %pi
+--R             \|8  cos(---)
+--R                       8
+--R      *
+--R             %pi 5
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 8
+--R           (248x  + 248x  + 248x  + 248x)cos(---)
+--R                                              8
+--R         + 
+--R                  6       5       4       3       2        4+-+2    %pi 6
+--R           (- 544x  - 912x  - 720x  - 720x  - 176x  + 192x)\|8  cos(---)
+--R                                                                     8
+--R         + 
+--R                    8         7         6         5        4        3        2
+--R               8832x  + 17664x  + 15376x  + 13680x  + 5344x  - 3488x  - 1200x
+--R             + 
+--R               496x
+--R          *
+--R                 %pi 4
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      10        9       8        7        6        5        4
+--R               - 3840x   - 4352x  + 944x  + 2656x  + 5968x  + 6464x  + 1200x
+--R             + 
+--R                     3      2
+--R               - 512x  + 16x  + 32x
+--R          *
+--R             4+-+2    %pi 2
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                12        11        10        9        8        7        6
+--R           2304x   + 2816x   + 3904x   + 6912x  + 4866x  + 3850x  + 2614x
+--R         + 
+--R                 5       4       3      2
+--R           - 386x  - 642x  - 138x  + 10x  + 2x
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              8
+--R     + 
+--R                4       3       2            %pi 9
+--R           (160x  + 160x  + 160x  + 160x)cos(---)
+--R                                              8
+--R         + 
+--R                  6       5       4       3       2        4+-+2    %pi 7
+--R           (- 384x  - 704x  - 576x  - 576x  - 192x  + 128x)\|8  cos(---)
+--R                                                                     8
+--R         + 
+--R                    8         7         6         5        4       3        2
+--R               5888x  + 15360x  + 16864x  + 15264x  + 9728x  + 256x  - 1248x
+--R             + 
+--R               352x
+--R          *
+--R                 %pi 5
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      10         9         8         7         6        5
+--R               - 8704x   - 21760x  - 22944x  - 19504x  - 10560x  + 2384x
+--R             + 
+--R                    4       3      2
+--R               3616x  + 176x  - 64x  + 48x
+--R          *
+--R             4+-+2    %pi 3
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                    12        11         10         9         8         7
+--R               9216x   + 3072x   - 25344x   - 39936x  - 50168x  - 44568x
+--R             + 
+--R                       6        5        4       3      2
+--R               - 16616x  - 2056x  - 1032x  - 488x  - 24x  + 8x
+--R          *
+--R                 %pi
+--R             cos(---)
+--R                  8
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              8
+--R     + 
+--R               4      3      2           %pi 10
+--R           (80x  + 80x  + 80x  + 80x)cos(---)
+--R                                          8
+--R         + 
+--R                  6       5       4       3       2       4+-+2    %pi 8
+--R           (- 208x  - 424x  - 360x  - 360x  - 152x  + 64x)\|8  cos(---)
+--R                                                                    8
+--R         + 
+--R                    8         7         6         5        4        3       2
+--R               3584x  + 10240x  + 12992x  + 12480x  + 9024x  + 2368x  - 384x
+--R             + 
+--R               128x
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      10         9         8         7         6        5
+--R               - 3840x   - 14848x  - 22672x  - 22832x  - 18464x  - 7552x
+--R             + 
+--R                   4       3      2
+--R               304x  + 464x  - 64x  + 32x
+--R          *
+--R             4+-+2    %pi 4
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                     12          11          10          9          8         7
+--R               38400x   + 115200x   + 154496x   + 151040x  + 108876x  + 32636x
+--R             + 
+--R                      6        5       4       3      2
+--R               - 6716x  - 3340x  + 436x  - 124x  - 68x  + 12x
+--R          *
+--R                 %pi 2
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      14       13        12         11         10         9
+--R               - 1024x   + 512x   + 6464x   + 12576x   + 17340x   + 17162x
+--R             + 
+--R                     8        7        6       5      4      3     2
+--R               11466x  + 5358x  + 1606x  + 246x  - 10x  - 14x  - 2x
+--R          *
+--R             4+-+2
+--R             \|8
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              8
+--R     + 
+--R               4      3      2           %pi 11
+--R           (32x  + 32x  + 32x  + 32x)cos(---)
+--R                                          8
+--R         + 
+--R                 6       5       4       3      2       4+-+2    %pi 9
+--R           (- 64x  - 160x  - 144x  - 144x  - 80x  + 16x)\|8  cos(---)
+--R                                                                  8
+--R         + 
+--R                   8        7        6        5        4        3      2
+--R             (1280x  + 4096x  + 5792x  + 5856x  + 4608x  + 1792x  + 96x  + 32x)
+--R          *
+--R                 %pi 7
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      10        9         8         7         6        5
+--R               - 1792x   - 7040x  - 12336x  - 14024x  - 12192x  - 6984x
+--R             + 
+--R                      4     3      2
+--R               - 1680x  + 8x  - 32x  + 8x
+--R          *
+--R             4+-+2    %pi 5
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                    12         11          10          9          8         7
+--R               9216x   + 52224x   + 109824x   + 138240x  + 133384x  + 90856x
+--R             + 
+--R                     6        5       4       3      2
+--R               33560x  + 5112x  + 760x  + 280x  - 24x  + 8x
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  8
+--R         + 
+--R                       14         13         12         11         10         9
+--R               - 10240x   - 35840x   - 62336x   - 78528x   - 74664x   - 50492x
+--R             + 
+--R                       8        7        6       5      4      3     2
+--R               - 24172x  - 7988x  - 1620x  - 196x  - 20x  - 12x  - 4x
+--R          *
+--R             4+-+2    %pi
+--R             \|8  cos(---)
+--R                       8
+--R      *
+--R             %pi
+--R         sin(---)
+--R              8
+--R     + 
+--R          4     3     2          %pi 12
+--R       (8x  + 8x  + 8x  + 8x)cos(---)
+--R                                  8
+--R     + 
+--R             6      5      4      3      2 4+-+2    %pi 10
+--R       (- 16x  - 40x  - 40x  - 40x  - 24x )\|8  cos(---)
+--R                                                     8
+--R     + 
+--R            8       7        6        5        4       3      2          %pi 8
+--R       (192x  + 896x  + 1464x  + 1544x  + 1360x  + 656x  + 88x  + 8x)cos(---)
+--R                                                                          8
+--R     + 
+--R                 10        9        8        7        6        5        4
+--R           - 256x   - 1280x  - 2864x  - 3776x  - 3664x  - 2656x  - 1072x
+--R         + 
+--R                 3      2
+--R           - 160x  - 16x
+--R      *
+--R         4+-+2    %pi 6
+--R         \|8  cos(---)
+--R                   8
+--R     + 
+--R                12         11         10         9         8         7         6
+--R           2304x   + 11008x   + 26432x   + 40704x  + 44674x  + 37258x  + 22070x
+--R         + 
+--R                5        4       3      2
+--R           7806x  + 1534x  + 246x  + 10x  + 2x
+--R      *
+--R             %pi 4
+--R         cos(---)
+--R              8
+--R     + 
+--R                  14        13         12         11         10         9
+--R           - 1024x   - 7680x   - 20160x   - 31968x   - 38212x   - 34582x
+--R         + 
+--R                   8         7        6        5       4      3     2
+--R           - 22934x  - 11282x  - 4026x  - 1002x  - 170x  - 14x  - 2x
+--R      *
+--R         4+-+2    %pi 2
+--R         \|8  cos(---)
+--R                   8
+--R     + 
+--R            16         15         14          13          12          11
+--R       8192x   + 32768x   + 68608x   + 103424x   + 119584x   + 107840x
+--R     + 
+--R             10         9         8        7        6       5      4     3
+--R       77156x   + 43892x  + 19884x  + 7100x  + 1948x  + 396x  + 52x  + 4x
+--R                                           Type: Expression(Complex(Integer))
+--E 216
+
+)clear all
+
+--S 217 of 1580
+t0:=x^4/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                      4
+--R                     x
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 1580
+r0:=1/8*(3*b^2-4*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (c^(5/2)*f)-d*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f^2*sqrt(c))-3/4*b*sqrt(a+b*x+c*x^2)/(c^2*f)+1/2*x*sqrt(a+b*x+c*x^2)/_
+   (c*f)+1/2*(-d)^(3/2)*atanh(1/2*(b*d+2*a*sqrt(-d)*sqrt(f)+x*(2*c*d+_
+   b*sqrt(-d)*sqrt(f)))/(sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f-_
+   b*sqrt(-d)*sqrt(f))))/(f^2*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*(-d)^(3/2)*atanh(1/2*(b*d-2*a*sqrt(-d)*sqrt(f)+x*(2*c*d-_
+   b*sqrt(-d)*sqrt(f)))/(sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f+_
+   b*sqrt(-d)*sqrt(f))))/(f^2*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R       -
+--R                           +-----------------------+
+--R              2  +---+ +-+ |  +---+ +-+
+--R            4c d\|- d \|c \|b\|- d \|f  + a f - c d
+--R         *
+--R                                      +---+ +-+
+--R                           (b x + 2a)\|- d \|f  + 2c d x + b d
+--R            atanh(----------------------------------------------------)
+--R                          +--------------+ +-------------------------+
+--R                    +---+ |   2            |    +---+ +-+
+--R                  2\|- d \|c x  + b x + a \|- b\|- d \|f  + a f - c d
+--R     + 
+--R                        +-------------------------+
+--R           2  +---+ +-+ |    +---+ +-+
+--R         4c d\|- d \|c \|- b\|- d \|f  + a f - c d
+--R      *
+--R                                  +---+ +-+
+--R                       (b x + 2a)\|- d \|f  - 2c d x - b d
+--R         atanh(--------------------------------------------------)
+--R                       +--------------+ +-----------------------+
+--R                 +---+ |   2            |  +---+ +-+
+--R               2\|- d \|c x  + b x + a \|b\|- d \|f  + a f - c d
+--R     + 
+--R                        2       2               2c x + b
+--R           ((- 4a c + 3b )f - 8c d)atanh(----------------------)
+--R                                               +--------------+
+--R                                           +-+ |   2
+--R                                         2\|c \|c x  + b x + a
+--R         + 
+--R                               +--------------+
+--R                           +-+ |   2
+--R           (4c f x - 6b f)\|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R  /
+--R               +-------------------------+ +-----------------------+
+--R       2 2 +-+ |    +---+ +-+              |  +---+ +-+
+--R     8c f \|c \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 1580
+--a0:=integrate(t0,x)
+--E 219
+
+--S 220 of 1580
+--m0:=a0-r0
+--E 220
+
+-- (1 . failed) cannot be coerced to mode
+--    (SparseUnivariatePolynomial (Integer))
+--S 221 of 1580
+--d0:=D(m0,x)
+--E 221
+
+)clear all
+
+--S 222 of 1580
+t0:=x^3/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                      3
+--R                     x
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 1580
+r0:=-1/2*b*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f)+_
+   sqrt(a+b*x+c*x^2)/(c*f)-1/2*d*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))))/(f^(3/2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*d*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))/(f^(3/2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R       -
+--R                    +-----------------------+
+--R                +-+ |  +---+ +-+
+--R            c d\|c \|b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                    +-------------------------+
+--R                +-+ |    +---+ +-+
+--R            c d\|c \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                                                           +--------------+
+--R              +-+             2c x + b             +-+ +-+ |   2
+--R         (- b\|f atanh(----------------------) + 2\|c \|f \|c x  + b x + a )
+--R                             +--------------+
+--R                         +-+ |   2
+--R                       2\|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                  +-------------------------+ +-----------------------+
+--R          +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2c f\|c \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 1580
+--a0:=integrate(t0,x)
+--E 224
+
+--S 225 of 1580
+--m0:=a0-r0
+--E 225
+
+--S 226 of 1580
+--d0:=D(m0,x)
+--E 226
+
+)clear all
+
+--S 227 of 1580
+t0:=x^2/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 1580
+r0:=atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f*sqrt(c))+_
+   1/2*atanh(1/2*(b*d+2*a*sqrt(-d)*sqrt(f)+x*(2*c*d+b*sqrt(-d)*sqrt(f)))/_
+   (sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f))))*_
+   sqrt(-d)/(f*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f)))+1/2*atanh(1/2*(b*d-_
+   2*a*sqrt(-d)*sqrt(f)+x*(2*c*d-b*sqrt(-d)*sqrt(f)))/(sqrt(-d)*_
+   sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f))))*sqrt(-d)/_
+   (f*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                    +-----------------------+
+--R          +---+ +-+ |  +---+ +-+
+--R         \|- d \|c \|b\|- d \|f  + a f - c d
+--R      *
+--R                                   +---+ +-+
+--R                        (b x + 2a)\|- d \|f  + 2c d x + b d
+--R         atanh(----------------------------------------------------)
+--R                       +--------------+ +-------------------------+
+--R                 +---+ |   2            |    +---+ +-+
+--R               2\|- d \|c x  + b x + a \|- b\|- d \|f  + a f - c d
+--R     + 
+--R       -
+--R                       +-------------------------+
+--R             +---+ +-+ |    +---+ +-+
+--R            \|- d \|c \|- b\|- d \|f  + a f - c d
+--R         *
+--R                                     +---+ +-+
+--R                          (b x + 2a)\|- d \|f  - 2c d x - b d
+--R            atanh(--------------------------------------------------)
+--R                          +--------------+ +-----------------------+
+--R                    +---+ |   2            |  +---+ +-+
+--R                  2\|- d \|c x  + b x + a \|b\|- d \|f  + a f - c d
+--R     + 
+--R                                        +-------------------------+
+--R                       2c x + b         |    +---+ +-+
+--R         2atanh(----------------------)\|- b\|- d \|f  + a f - c d
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|c \|c x  + b x + a
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  + a f - c d
+--R  /
+--R            +-------------------------+ +-----------------------+
+--R        +-+ |    +---+ +-+              |  +---+ +-+
+--R     2f\|c \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R                                                    Type: Expression(Integer)
+--E 228
+
+--S 229 of 1580
+--a0:=integrate(t0,x)
+--E 229
+
+--S 230 of 1580
+--m0:=a0-r0
+--E 230
+
+--S 231 of 1580
+--d0:=D(m0,x)
+--E 231
+
+)clear all
+
+--S 232 of 1580
+t0:=x/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                     x
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 1580
+r0:=1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))/(sqrt(f)*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*atan(1/2*(b*sqrt(-d)-2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+_
+   b*sqrt(-d)*sqrt(f))))/(sqrt(f)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R  /
+--R           +-------------------------+ +-----------------------+
+--R       +-+ |    +---+ +-+              |  +---+ +-+
+--R     2\|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                        2 3               2    2     2 2
+--R                     (2a f  + (- 4a c + 2b )d f  + 2c d f)
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2
+--R                             b d
+--R                          /
+--R                                 4 5         3      2 2    4
+--R                               4a f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  2 3
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  3 2     4 4
+--R                               (- 16a c  + 8b c )d f  + 4c d f
+--R                 + 
+--R                   a f - c d
+--R              /
+--R                  2 3              2    2    2 2
+--R                 a f  + (- 2a c + b )d f  + c d f
+--R         *
+--R            log
+--R                             3 4        2        2    3        2     2   2 2
+--R                           2a f  + (- 6a c + 2a b )d f  + (6a c  - 2b c)d f
+--R                         + 
+--R                               3 3
+--R                           - 2c d f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b d
+--R                              /
+--R                                     4 5         3      2 2    4
+--R                                   4a f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  2 3
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  3 2     4 4
+--R                                   (- 16a c  + 8b c )d f  + 4c d f
+--R                     + 
+--R                        2
+--R                       b d f x
+--R                  *
+--R                     ROOT
+--R                                 2 3               2    2     2 2
+--R                              (2a f  + (- 4a c + 2b )d f  + 2c d f)
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2
+--R                                      b d
+--R                                   /
+--R                                          4 5         3      2 2    4
+--R                                        4a f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  2 3
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  3 2     4 4
+--R                                        (- 16a c  + 8b c )d f  + 4c d f
+--R                          + 
+--R                            a f - c d
+--R                       /
+--R                           2 3              2    2    2 2
+--R                          a f  + (- 2a c + b )d f  + c d f
+--R                 + 
+--R                       +--------------+
+--R                       |   2
+--R                   b d\|c x  + b x + a
+--R                 + 
+--R                            2 3               2    2     2 2
+--R                         (2a f  + (- 4a c + 2b )d f  + 2c d f)x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b d
+--R                              /
+--R                                     4 5         3      2 2    4
+--R                                   4a f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  2 3
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  3 2     4 4
+--R                                   (- 16a c  + 8b c )d f  + 4c d f
+--R                     + 
+--R                       - b d
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R         ROOT
+--R                       2 3             2    2     2 2
+--R                  (- 2a f  + (4a c - 2b )d f  - 2c d f)
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2
+--R                          b d
+--R                       /
+--R                              4 5         3      2 2    4
+--R                            4a f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  2 3
+--R                            (24a c  - 16a b c + 4b )d f
+--R                          + 
+--R                                    3     2 2  3 2     4 4
+--R                            (- 16a c  + 8b c )d f  + 4c d f
+--R              + 
+--R                a f - c d
+--R           /
+--R               2 3              2    2    2 2
+--R              a f  + (- 2a c + b )d f  + c d f
+--R      *
+--R         log
+--R                            3 4        2        2    3        2     2   2 2
+--R                          2a f  + (- 6a c + 2a b )d f  + (6a c  - 2b c)d f
+--R                        + 
+--R                              3 3
+--R                          - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b d
+--R                           /
+--R                                  4 5         3      2 2    4
+--R                                4a f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  2 3
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  3 2     4 4
+--R                                (- 16a c  + 8b c )d f  + 4c d f
+--R                  + 
+--R                       2
+--R                    - b d f x
+--R               *
+--R                  ROOT
+--R                                2 3             2    2     2 2
+--R                           (- 2a f  + (4a c - 2b )d f  - 2c d f)
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2
+--R                                   b d
+--R                                /
+--R                                       4 5         3      2 2    4
+--R                                     4a f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  2 3
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  3 2     4 4
+--R                                     (- 16a c  + 8b c )d f  + 4c d f
+--R                       + 
+--R                         a f - c d
+--R                    /
+--R                        2 3              2    2    2 2
+--R                       a f  + (- 2a c + b )d f  + c d f
+--R              + 
+--R                    +--------------+
+--R                    |   2
+--R                b d\|c x  + b x + a
+--R              + 
+--R                           2 3             2    2     2 2
+--R                      (- 2a f  + (4a c - 2b )d f  - 2c d f)x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b d
+--R                           /
+--R                                  4 5         3      2 2    4
+--R                                4a f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  2 3
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  3 2     4 4
+--R                                (- 16a c  + 8b c )d f  + 4c d f
+--R                  + 
+--R                    - b d
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                          2 3             2    2     2 2
+--R                     (- 2a f  + (4a c - 2b )d f  - 2c d f)
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2
+--R                             b d
+--R                          /
+--R                                 4 5         3      2 2    4
+--R                               4a f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  2 3
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  3 2     4 4
+--R                               (- 16a c  + 8b c )d f  + 4c d f
+--R                 + 
+--R                   a f - c d
+--R              /
+--R                  2 3              2    2    2 2
+--R                 a f  + (- 2a c + b )d f  + c d f
+--R         *
+--R            log
+--R                               3 4      2        2    3          2     2   2 2
+--R                           - 2a f  + (6a c - 2a b )d f  + (- 6a c  + 2b c)d f
+--R                         + 
+--R                             3 3
+--R                           2c d f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b d
+--R                              /
+--R                                     4 5         3      2 2    4
+--R                                   4a f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  2 3
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  3 2     4 4
+--R                                   (- 16a c  + 8b c )d f  + 4c d f
+--R                     + 
+--R                        2
+--R                       b d f x
+--R                  *
+--R                     ROOT
+--R                                   2 3             2    2     2 2
+--R                              (- 2a f  + (4a c - 2b )d f  - 2c d f)
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2
+--R                                      b d
+--R                                   /
+--R                                          4 5         3      2 2    4
+--R                                        4a f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  2 3
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  3 2     4 4
+--R                                        (- 16a c  + 8b c )d f  + 4c d f
+--R                          + 
+--R                            a f - c d
+--R                       /
+--R                           2 3              2    2    2 2
+--R                          a f  + (- 2a c + b )d f  + c d f
+--R                 + 
+--R                       +--------------+
+--R                       |   2
+--R                   b d\|c x  + b x + a
+--R                 + 
+--R                              2 3             2    2     2 2
+--R                         (- 2a f  + (4a c - 2b )d f  - 2c d f)x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b d
+--R                              /
+--R                                     4 5         3      2 2    4
+--R                                   4a f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  2 3
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  3 2     4 4
+--R                                   (- 16a c  + 8b c )d f  + 4c d f
+--R                     + 
+--R                       - b d
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R         ROOT
+--R                     2 3               2    2     2 2
+--R                  (2a f  + (- 4a c + 2b )d f  + 2c d f)
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2
+--R                          b d
+--R                       /
+--R                              4 5         3      2 2    4
+--R                            4a f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  2 3
+--R                            (24a c  - 16a b c + 4b )d f
+--R                          + 
+--R                                    3     2 2  3 2     4 4
+--R                            (- 16a c  + 8b c )d f  + 4c d f
+--R              + 
+--R                a f - c d
+--R           /
+--R               2 3              2    2    2 2
+--R              a f  + (- 2a c + b )d f  + c d f
+--R      *
+--R         log
+--R                            3 4      2        2    3          2     2   2 2
+--R                        - 2a f  + (6a c - 2a b )d f  + (- 6a c  + 2b c)d f
+--R                      + 
+--R                          3 3
+--R                        2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b d
+--R                           /
+--R                                  4 5         3      2 2    4
+--R                                4a f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  2 3
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  3 2     4 4
+--R                                (- 16a c  + 8b c )d f  + 4c d f
+--R                  + 
+--R                       2
+--R                    - b d f x
+--R               *
+--R                  ROOT
+--R                              2 3               2    2     2 2
+--R                           (2a f  + (- 4a c + 2b )d f  + 2c d f)
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2
+--R                                   b d
+--R                                /
+--R                                       4 5         3      2 2    4
+--R                                     4a f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  2 3
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  3 2     4 4
+--R                                     (- 16a c  + 8b c )d f  + 4c d f
+--R                       + 
+--R                         a f - c d
+--R                    /
+--R                        2 3              2    2    2 2
+--R                       a f  + (- 2a c + b )d f  + c d f
+--R              + 
+--R                    +--------------+
+--R                    |   2
+--R                b d\|c x  + b x + a
+--R              + 
+--R                         2 3               2    2     2 2
+--R                      (2a f  + (- 4a c + 2b )d f  + 2c d f)x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b d
+--R                           /
+--R                                  4 5         3      2 2    4
+--R                                4a f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  2 3
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  3 2     4 4
+--R                                (- 16a c  + 8b c )d f  + 4c d f
+--R                  + 
+--R                    - b d
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 234
+
+--S 235 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                 +-------------------------+
+--R             +-+ |    +---+ +-+
+--R            \|f \|- b\|- d \|f  - a f + c d
+--R         *
+--R            ROOT
+--R                        2 3               2    2     2 2
+--R                     (2a f  + (- 4a c + 2b )d f  + 2c d f)
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2
+--R                             b d
+--R                          /
+--R                                 4 5         3      2 2    4
+--R                               4a f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  2 3
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  3 2     4 4
+--R                               (- 16a c  + 8b c )d f  + 4c d f
+--R                 + 
+--R                   a f - c d
+--R              /
+--R                  2 3              2    2    2 2
+--R                 a f  + (- 2a c + b )d f  + c d f
+--R         *
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  - a f + c d
+--R         *
+--R            log
+--R                             3 4        2        2    3        2     2   2 2
+--R                           2a f  + (- 6a c + 2a b )d f  + (6a c  - 2b c)d f
+--R                         + 
+--R                               3 3
+--R                           - 2c d f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b d
+--R                              /
+--R                                     4 5         3      2 2    4
+--R                                   4a f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  2 3
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  3 2     4 4
+--R                                   (- 16a c  + 8b c )d f  + 4c d f
+--R                     + 
+--R                        2
+--R                       b d f x
+--R                  *
+--R                     ROOT
+--R                                 2 3               2    2     2 2
+--R                              (2a f  + (- 4a c + 2b )d f  + 2c d f)
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2
+--R                                      b d
+--R                                   /
+--R                                          4 5         3      2 2    4
+--R                                        4a f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  2 3
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  3 2     4 4
+--R                                        (- 16a c  + 8b c )d f  + 4c d f
+--R                          + 
+--R                            a f - c d
+--R                       /
+--R                           2 3              2    2    2 2
+--R                          a f  + (- 2a c + b )d f  + c d f
+--R                 + 
+--R                       +--------------+
+--R                       |   2
+--R                   b d\|c x  + b x + a
+--R                 + 
+--R                            2 3               2    2     2 2
+--R                         (2a f  + (- 4a c + 2b )d f  + 2c d f)x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b d
+--R                              /
+--R                                     4 5         3      2 2    4
+--R                                   4a f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  2 3
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  3 2     4 4
+--R                                   (- 16a c  + 8b c )d f  + 4c d f
+--R                     + 
+--R                       - b d
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R              +-------------------------+
+--R          +-+ |    +---+ +-+
+--R         \|f \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                       2 3             2    2     2 2
+--R                  (- 2a f  + (4a c - 2b )d f  - 2c d f)
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2
+--R                          b d
+--R                       /
+--R                              4 5         3      2 2    4
+--R                            4a f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  2 3
+--R                            (24a c  - 16a b c + 4b )d f
+--R                          + 
+--R                                    3     2 2  3 2     4 4
+--R                            (- 16a c  + 8b c )d f  + 4c d f
+--R              + 
+--R                a f - c d
+--R           /
+--R               2 3              2    2    2 2
+--R              a f  + (- 2a c + b )d f  + c d f
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            3 4        2        2    3        2     2   2 2
+--R                          2a f  + (- 6a c + 2a b )d f  + (6a c  - 2b c)d f
+--R                        + 
+--R                              3 3
+--R                          - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b d
+--R                           /
+--R                                  4 5         3      2 2    4
+--R                                4a f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  2 3
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  3 2     4 4
+--R                                (- 16a c  + 8b c )d f  + 4c d f
+--R                  + 
+--R                       2
+--R                    - b d f x
+--R               *
+--R                  ROOT
+--R                                2 3             2    2     2 2
+--R                           (- 2a f  + (4a c - 2b )d f  - 2c d f)
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2
+--R                                   b d
+--R                                /
+--R                                       4 5         3      2 2    4
+--R                                     4a f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  2 3
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  3 2     4 4
+--R                                     (- 16a c  + 8b c )d f  + 4c d f
+--R                       + 
+--R                         a f - c d
+--R                    /
+--R                        2 3              2    2    2 2
+--R                       a f  + (- 2a c + b )d f  + c d f
+--R              + 
+--R                    +--------------+
+--R                    |   2
+--R                b d\|c x  + b x + a
+--R              + 
+--R                           2 3             2    2     2 2
+--R                      (- 2a f  + (4a c - 2b )d f  - 2c d f)x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b d
+--R                           /
+--R                                  4 5         3      2 2    4
+--R                                4a f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  2 3
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  3 2     4 4
+--R                                (- 16a c  + 8b c )d f  + 4c d f
+--R                  + 
+--R                    - b d
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                 +-------------------------+
+--R             +-+ |    +---+ +-+
+--R            \|f \|- b\|- d \|f  - a f + c d
+--R         *
+--R            ROOT
+--R                          2 3             2    2     2 2
+--R                     (- 2a f  + (4a c - 2b )d f  - 2c d f)
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2
+--R                             b d
+--R                          /
+--R                                 4 5         3      2 2    4
+--R                               4a f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  2 3
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  3 2     4 4
+--R                               (- 16a c  + 8b c )d f  + 4c d f
+--R                 + 
+--R                   a f - c d
+--R              /
+--R                  2 3              2    2    2 2
+--R                 a f  + (- 2a c + b )d f  + c d f
+--R         *
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  - a f + c d
+--R         *
+--R            log
+--R                               3 4      2        2    3          2     2   2 2
+--R                           - 2a f  + (6a c - 2a b )d f  + (- 6a c  + 2b c)d f
+--R                         + 
+--R                             3 3
+--R                           2c d f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b d
+--R                              /
+--R                                     4 5         3      2 2    4
+--R                                   4a f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  2 3
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  3 2     4 4
+--R                                   (- 16a c  + 8b c )d f  + 4c d f
+--R                     + 
+--R                        2
+--R                       b d f x
+--R                  *
+--R                     ROOT
+--R                                   2 3             2    2     2 2
+--R                              (- 2a f  + (4a c - 2b )d f  - 2c d f)
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2
+--R                                      b d
+--R                                   /
+--R                                          4 5         3      2 2    4
+--R                                        4a f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  2 3
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  3 2     4 4
+--R                                        (- 16a c  + 8b c )d f  + 4c d f
+--R                          + 
+--R                            a f - c d
+--R                       /
+--R                           2 3              2    2    2 2
+--R                          a f  + (- 2a c + b )d f  + c d f
+--R                 + 
+--R                       +--------------+
+--R                       |   2
+--R                   b d\|c x  + b x + a
+--R                 + 
+--R                              2 3             2    2     2 2
+--R                         (- 2a f  + (4a c - 2b )d f  - 2c d f)x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b d
+--R                              /
+--R                                     4 5         3      2 2    4
+--R                                   4a f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  2 3
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  3 2     4 4
+--R                                   (- 16a c  + 8b c )d f  + 4c d f
+--R                     + 
+--R                       - b d
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R              +-------------------------+
+--R          +-+ |    +---+ +-+
+--R         \|f \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                     2 3               2    2     2 2
+--R                  (2a f  + (- 4a c + 2b )d f  + 2c d f)
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2
+--R                          b d
+--R                       /
+--R                              4 5         3      2 2    4
+--R                            4a f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  2 3
+--R                            (24a c  - 16a b c + 4b )d f
+--R                          + 
+--R                                    3     2 2  3 2     4 4
+--R                            (- 16a c  + 8b c )d f  + 4c d f
+--R              + 
+--R                a f - c d
+--R           /
+--R               2 3              2    2    2 2
+--R              a f  + (- 2a c + b )d f  + c d f
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            3 4      2        2    3          2     2   2 2
+--R                        - 2a f  + (6a c - 2a b )d f  + (- 6a c  + 2b c)d f
+--R                      + 
+--R                          3 3
+--R                        2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b d
+--R                           /
+--R                                  4 5         3      2 2    4
+--R                                4a f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  2 3
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  3 2     4 4
+--R                                (- 16a c  + 8b c )d f  + 4c d f
+--R                  + 
+--R                       2
+--R                    - b d f x
+--R               *
+--R                  ROOT
+--R                              2 3               2    2     2 2
+--R                           (2a f  + (- 4a c + 2b )d f  + 2c d f)
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2
+--R                                   b d
+--R                                /
+--R                                       4 5         3      2 2    4
+--R                                     4a f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  2 3
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  3 2     4 4
+--R                                     (- 16a c  + 8b c )d f  + 4c d f
+--R                       + 
+--R                         a f - c d
+--R                    /
+--R                        2 3              2    2    2 2
+--R                       a f  + (- 2a c + b )d f  + c d f
+--R              + 
+--R                    +--------------+
+--R                    |   2
+--R                b d\|c x  + b x + a
+--R              + 
+--R                         2 3               2    2     2 2
+--R                      (2a f  + (- 4a c + 2b )d f  + 2c d f)x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b d
+--R                           /
+--R                                  4 5         3      2 2    4
+--R                                4a f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  2 3
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  3 2     4 4
+--R                                (- 16a c  + 8b c )d f  + 4c d f
+--R                  + 
+--R                    - b d
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R             +-------------------------+
+--R             |    +---+ +-+
+--R            \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R  /
+--R           +-------------------------+ +-----------------------+
+--R       +-+ |    +---+ +-+              |  +---+ +-+
+--R     2\|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 236
+
+)clear all
+
+--S 237 of 1580
+t0:=1/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 237
+
+--S 238 of 1580
+r0:=1/2*atanh(1/2*(b*d+2*a*sqrt(-d)*sqrt(f)+x*(2*c*d+b*sqrt(-d)*sqrt(f)))/_
+   (sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f))))/_
+   (sqrt(-d)*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f)))+1/2*atanh(1/2*(b*d-_
+   2*a*sqrt(-d)*sqrt(f)+x*(2*c*d-b*sqrt(-d)*sqrt(f)))/(sqrt(-d)*_
+   sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f))))/(sqrt(-d)*_
+   sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  + a f - c d
+--R      *
+--R                                   +---+ +-+
+--R                        (b x + 2a)\|- d \|f  + 2c d x + b d
+--R         atanh(----------------------------------------------------)
+--R                       +--------------+ +-------------------------+
+--R                 +---+ |   2            |    +---+ +-+
+--R               2\|- d \|c x  + b x + a \|- b\|- d \|f  + a f - c d
+--R     + 
+--R       -
+--R             +-------------------------+
+--R             |    +---+ +-+
+--R            \|- b\|- d \|f  + a f - c d
+--R         *
+--R                                     +---+ +-+
+--R                          (b x + 2a)\|- d \|f  - 2c d x - b d
+--R            atanh(--------------------------------------------------)
+--R                          +--------------+ +-----------------------+
+--R                    +---+ |   2            |  +---+ +-+
+--R                  2\|- d \|c x  + b x + a \|b\|- d \|f  + a f - c d
+--R  /
+--R             +-------------------------+ +-----------------------+
+--R       +---+ |    +---+ +-+              |  +---+ +-+
+--R     2\|- d \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                        2   2               2  2      2 3
+--R                     (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2
+--R                             b f
+--R                          /
+--R                                 4   4         3      2 2  2 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  3 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  4      4 5
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                   - a f + c d
+--R              /
+--R                  2   2              2  2     2 3
+--R                 a d f  + (- 2a c + b )d f + c d
+--R         *
+--R            log
+--R                            2     2                 3  2        2 3
+--R                         (2a b d f  + (- 4a b c + 2b )d f + 2b c d )x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b f
+--R                              /
+--R                                     4   4         3      2 2  2 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  3 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  4      4 5
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                       (a b f - b c d)x
+--R                  *
+--R                     ROOT
+--R                                 2   2               2  2      2 3
+--R                              (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2
+--R                                      b f
+--R                                   /
+--R                                          4   4         3      2 2  2 3
+--R                                        4a d f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  3 2
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  4      4 5
+--R                                        (- 16a c  + 8b c )d f + 4c d
+--R                          + 
+--R                            - a f + c d
+--R                       /
+--R                           2   2              2  2     2 3
+--R                          a d f  + (- 2a c + b )d f + c d
+--R                 + 
+--R                     +--------------+
+--R                     |   2
+--R                   b\|c x  + b x + a
+--R                 + 
+--R                              2 2             2         2 2
+--R                         (- 2a f  + (4a c - 2b )d f - 2c d )x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b f
+--R                              /
+--R                                     4   4         3      2 2  2 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  3 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  4      4 5
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                       - b
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R         ROOT
+--R                       2   2             2  2      2 3
+--R                  (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2
+--R                          b f
+--R                       /
+--R                              4   4         3      2 2  2 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  3 2           3     2 2  4
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 5
+--R                            4c d
+--R              + 
+--R                - a f + c d
+--R           /
+--R               2   2              2  2     2 3
+--R              a d f  + (- 2a c + b )d f + c d
+--R      *
+--R         log
+--R                         2     2                 3  2        2 3
+--R                      (2a b d f  + (- 4a b c + 2b )d f + 2b c d )x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b f
+--R                           /
+--R                                  4   4         3      2 2  2 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  3 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  4      4 5
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                    (- a b f + b c d)x
+--R               *
+--R                  ROOT
+--R                                2   2             2  2      2 3
+--R                           (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2
+--R                                   b f
+--R                                /
+--R                                       4   4         3      2 2  2 3
+--R                                     4a d f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  3 2
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  4      4 5
+--R                                     (- 16a c  + 8b c )d f + 4c d
+--R                       + 
+--R                         - a f + c d
+--R                    /
+--R                        2   2              2  2     2 3
+--R                       a d f  + (- 2a c + b )d f + c d
+--R              + 
+--R                  +--------------+
+--R                  |   2
+--R                b\|c x  + b x + a
+--R              + 
+--R                         2 2               2         2 2
+--R                      (2a f  + (- 4a c + 2b )d f + 2c d )x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b f
+--R                           /
+--R                                  4   4         3      2 2  2 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  3 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  4      4 5
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                    - b
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                          2   2             2  2      2 3
+--R                     (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2
+--R                             b f
+--R                          /
+--R                                 4   4         3      2 2  2 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  3 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  4      4 5
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                   - a f + c d
+--R              /
+--R                  2   2              2  2     2 3
+--R                 a d f  + (- 2a c + b )d f + c d
+--R         *
+--R            log
+--R                              2     2               3  2        2 3
+--R                         (- 2a b d f  + (4a b c - 2b )d f - 2b c d )x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b f
+--R                              /
+--R                                     4   4         3      2 2  2 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  3 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  4      4 5
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                       (a b f - b c d)x
+--R                  *
+--R                     ROOT
+--R                                   2   2             2  2      2 3
+--R                              (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2
+--R                                      b f
+--R                                   /
+--R                                          4   4         3      2 2  2 3
+--R                                        4a d f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  3 2
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  4      4 5
+--R                                        (- 16a c  + 8b c )d f + 4c d
+--R                          + 
+--R                            - a f + c d
+--R                       /
+--R                           2   2              2  2     2 3
+--R                          a d f  + (- 2a c + b )d f + c d
+--R                 + 
+--R                     +--------------+
+--R                     |   2
+--R                   b\|c x  + b x + a
+--R                 + 
+--R                            2 2               2         2 2
+--R                         (2a f  + (- 4a c + 2b )d f + 2c d )x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b f
+--R                              /
+--R                                     4   4         3      2 2  2 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  3 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  4      4 5
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                       - b
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R         ROOT
+--R                     2   2               2  2      2 3
+--R                  (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2
+--R                          b f
+--R                       /
+--R                              4   4         3      2 2  2 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  3 2           3     2 2  4
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 5
+--R                            4c d
+--R              + 
+--R                - a f + c d
+--R           /
+--R               2   2              2  2     2 3
+--R              a d f  + (- 2a c + b )d f + c d
+--R      *
+--R         log
+--R                           2     2               3  2        2 3
+--R                      (- 2a b d f  + (4a b c - 2b )d f - 2b c d )x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b f
+--R                           /
+--R                                  4   4         3      2 2  2 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  3 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  4      4 5
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                    (- a b f + b c d)x
+--R               *
+--R                  ROOT
+--R                              2   2               2  2      2 3
+--R                           (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2
+--R                                   b f
+--R                                /
+--R                                       4   4         3      2 2  2 3
+--R                                     4a d f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  3 2
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  4      4 5
+--R                                     (- 16a c  + 8b c )d f + 4c d
+--R                       + 
+--R                         - a f + c d
+--R                    /
+--R                        2   2              2  2     2 3
+--R                       a d f  + (- 2a c + b )d f + c d
+--R              + 
+--R                  +--------------+
+--R                  |   2
+--R                b\|c x  + b x + a
+--R              + 
+--R                           2 2             2         2 2
+--R                      (- 2a f  + (4a c - 2b )d f - 2c d )x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b f
+--R                           /
+--R                                  4   4         3      2 2  2 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  3 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  4      4 5
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                    - b
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 239
+
+--S 240 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                   +-------------------------+
+--R             +---+ |    +---+ +-+
+--R            \|- d \|- b\|- d \|f  + a f - c d
+--R         *
+--R            ROOT
+--R                        2   2               2  2      2 3
+--R                     (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2
+--R                             b f
+--R                          /
+--R                                 4   4         3      2 2  2 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  3 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  4      4 5
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                   - a f + c d
+--R              /
+--R                  2   2              2  2     2 3
+--R                 a d f  + (- 2a c + b )d f + c d
+--R         *
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  + a f - c d
+--R         *
+--R            log
+--R                            2     2                 3  2        2 3
+--R                         (2a b d f  + (- 4a b c + 2b )d f + 2b c d )x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b f
+--R                              /
+--R                                     4   4         3      2 2  2 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  3 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  4      4 5
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                       (a b f - b c d)x
+--R                  *
+--R                     ROOT
+--R                                 2   2               2  2      2 3
+--R                              (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2
+--R                                      b f
+--R                                   /
+--R                                          4   4         3      2 2  2 3
+--R                                        4a d f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  3 2
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  4      4 5
+--R                                        (- 16a c  + 8b c )d f + 4c d
+--R                          + 
+--R                            - a f + c d
+--R                       /
+--R                           2   2              2  2     2 3
+--R                          a d f  + (- 2a c + b )d f + c d
+--R                 + 
+--R                     +--------------+
+--R                     |   2
+--R                   b\|c x  + b x + a
+--R                 + 
+--R                              2 2             2         2 2
+--R                         (- 2a f  + (4a c - 2b )d f - 2c d )x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b f
+--R                              /
+--R                                     4   4         3      2 2  2 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  3 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  4      4 5
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                       - b
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R                +-------------------------+
+--R          +---+ |    +---+ +-+
+--R         \|- d \|- b\|- d \|f  + a f - c d
+--R      *
+--R         ROOT
+--R                       2   2             2  2      2 3
+--R                  (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2
+--R                          b f
+--R                       /
+--R                              4   4         3      2 2  2 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  3 2           3     2 2  4
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 5
+--R                            4c d
+--R              + 
+--R                - a f + c d
+--R           /
+--R               2   2              2  2     2 3
+--R              a d f  + (- 2a c + b )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  + a f - c d
+--R      *
+--R         log
+--R                         2     2                 3  2        2 3
+--R                      (2a b d f  + (- 4a b c + 2b )d f + 2b c d )x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b f
+--R                           /
+--R                                  4   4         3      2 2  2 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  3 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  4      4 5
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                    (- a b f + b c d)x
+--R               *
+--R                  ROOT
+--R                                2   2             2  2      2 3
+--R                           (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2
+--R                                   b f
+--R                                /
+--R                                       4   4         3      2 2  2 3
+--R                                     4a d f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  3 2
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  4      4 5
+--R                                     (- 16a c  + 8b c )d f + 4c d
+--R                       + 
+--R                         - a f + c d
+--R                    /
+--R                        2   2              2  2     2 3
+--R                       a d f  + (- 2a c + b )d f + c d
+--R              + 
+--R                  +--------------+
+--R                  |   2
+--R                b\|c x  + b x + a
+--R              + 
+--R                         2 2               2         2 2
+--R                      (2a f  + (- 4a c + 2b )d f + 2c d )x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b f
+--R                           /
+--R                                  4   4         3      2 2  2 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  3 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  4      4 5
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                    - b
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                   +-------------------------+
+--R             +---+ |    +---+ +-+
+--R            \|- d \|- b\|- d \|f  + a f - c d
+--R         *
+--R            ROOT
+--R                          2   2             2  2      2 3
+--R                     (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2
+--R                             b f
+--R                          /
+--R                                 4   4         3      2 2  2 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  3 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  4      4 5
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                   - a f + c d
+--R              /
+--R                  2   2              2  2     2 3
+--R                 a d f  + (- 2a c + b )d f + c d
+--R         *
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  + a f - c d
+--R         *
+--R            log
+--R                              2     2               3  2        2 3
+--R                         (- 2a b d f  + (4a b c - 2b )d f - 2b c d )x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b f
+--R                              /
+--R                                     4   4         3      2 2  2 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  3 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  4      4 5
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                       (a b f - b c d)x
+--R                  *
+--R                     ROOT
+--R                                   2   2             2  2      2 3
+--R                              (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2
+--R                                      b f
+--R                                   /
+--R                                          4   4         3      2 2  2 3
+--R                                        4a d f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  3 2
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  4      4 5
+--R                                        (- 16a c  + 8b c )d f + 4c d
+--R                          + 
+--R                            - a f + c d
+--R                       /
+--R                           2   2              2  2     2 3
+--R                          a d f  + (- 2a c + b )d f + c d
+--R                 + 
+--R                     +--------------+
+--R                     |   2
+--R                   b\|c x  + b x + a
+--R                 + 
+--R                            2 2               2         2 2
+--R                         (2a f  + (- 4a c + 2b )d f + 2c d )x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2
+--R                                 b f
+--R                              /
+--R                                     4   4         3      2 2  2 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  3 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  4      4 5
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                       - b
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R                +-------------------------+
+--R          +---+ |    +---+ +-+
+--R         \|- d \|- b\|- d \|f  + a f - c d
+--R      *
+--R         ROOT
+--R                     2   2               2  2      2 3
+--R                  (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2
+--R                          b f
+--R                       /
+--R                              4   4         3      2 2  2 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  3 2           3     2 2  4
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 5
+--R                            4c d
+--R              + 
+--R                - a f + c d
+--R           /
+--R               2   2              2  2     2 3
+--R              a d f  + (- 2a c + b )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  + a f - c d
+--R      *
+--R         log
+--R                           2     2               3  2        2 3
+--R                      (- 2a b d f  + (4a b c - 2b )d f - 2b c d )x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b f
+--R                           /
+--R                                  4   4         3      2 2  2 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  3 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  4      4 5
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                    (- a b f + b c d)x
+--R               *
+--R                  ROOT
+--R                              2   2               2  2      2 3
+--R                           (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2
+--R                                   b f
+--R                                /
+--R                                       4   4         3      2 2  2 3
+--R                                     4a d f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  3 2
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  4      4 5
+--R                                     (- 16a c  + 8b c )d f + 4c d
+--R                       + 
+--R                         - a f + c d
+--R                    /
+--R                        2   2              2  2     2 3
+--R                       a d f  + (- 2a c + b )d f + c d
+--R              + 
+--R                  +--------------+
+--R                  |   2
+--R                b\|c x  + b x + a
+--R              + 
+--R                           2 2             2         2 2
+--R                      (- 2a f  + (4a c - 2b )d f - 2c d )x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2
+--R                              b f
+--R                           /
+--R                                  4   4         3      2 2  2 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  3 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  4      4 5
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                    - b
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  + a f - c d
+--R         *
+--R                                      +---+ +-+
+--R                           (b x + 2a)\|- d \|f  + 2c d x + b d
+--R            atanh(----------------------------------------------------)
+--R                          +--------------+ +-------------------------+
+--R                    +---+ |   2            |    +---+ +-+
+--R                  2\|- d \|c x  + b x + a \|- b\|- d \|f  + a f - c d
+--R     + 
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  + a f - c d
+--R      *
+--R                                  +---+ +-+
+--R                       (b x + 2a)\|- d \|f  - 2c d x - b d
+--R         atanh(--------------------------------------------------)
+--R                       +--------------+ +-----------------------+
+--R                 +---+ |   2            |  +---+ +-+
+--R               2\|- d \|c x  + b x + a \|b\|- d \|f  + a f - c d
+--R  /
+--R             +-------------------------+ +-----------------------+
+--R       +---+ |    +---+ +-+              |  +---+ +-+
+--R     2\|- d \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R                                                    Type: Expression(Integer)
+--E 240
+
+--S 241 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 241
+
+)clear all
+
+--S 242 of 1580
+t0:=1/(x*(a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R                     +--------------+
+--R            3        |   2
+--R        (f x  + d x)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 1580
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(d*sqrt(a))-_
+   1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(f)/(d*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+1/2*atan(1/2*(b*sqrt(-d)-2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+_
+   b*sqrt(-d)*sqrt(f))))*sqrt(f)/(d*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R       -
+--R                     +-----------------------+
+--R             +-+ +-+ |  +---+ +-+
+--R            \|a \|f \|b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                     +-------------------------+
+--R             +-+ +-+ |    +---+ +-+
+--R            \|a \|f \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                                           +-------------------------+
+--R                          b x + 2a         |    +---+ +-+
+--R            2atanh(----------------------)\|- b\|- d \|f  - a f + c d
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|a \|c x  + b x + a
+--R         *
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  - a f + c d
+--R  /
+--R            +-------------------------+ +-----------------------+
+--R        +-+ |    +---+ +-+              |  +---+ +-+
+--R     2d\|a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 243
+
+--S 244 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-+
+--R         d\|a
+--R      *
+--R         ROOT
+--R                     2 2 2               2  3      2 4
+--R                  (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 3
+--R                          b f
+--R                       /
+--R                              4 3 4         3      2 2  4 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  5 2           3     2 2  6
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 7
+--R                            4c d
+--R              + 
+--R                   2
+--R                a f  - c d f
+--R           /
+--R               2 2 2              2  3     2 4
+--R              a d f  + (- 2a c + b )d f + c d
+--R      *
+--R         log
+--R                            3 2 3        2        2  3 2        2     2   4
+--R                          2a d f  + (- 6a c + 2a b )d f  + (6a c  - 2b c)d f
+--R                        + 
+--R                              3 5
+--R                          - 2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 3
+--R                              b f
+--R                           /
+--R                                  4 3 4         3      2 2  4 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  5 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  6      4 7
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                     2   2
+--R                    b d f x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                              2 2 2               2  3      2 4
+--R                           (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 3
+--R                                   b f
+--R                                /
+--R                                       4 3 4         3      2 2  4 3
+--R                                     4a d f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  5 2
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  6      4 7
+--R                                     (- 16a c  + 8b c )d f + 4c d
+--R                       + 
+--R                            2
+--R                         a f  - c d f
+--R                    /
+--R                        2 2 2              2  3     2 4
+--R                       a d f  + (- 2a c + b )d f + c d
+--R              + 
+--R                         +--------------+
+--R                   2 +-+ |   2
+--R                b f \|a \|c x  + b x + a
+--R              + 
+--R                     3   3        2        2  2 2       2 3
+--R                  (2a d f  + (- 4a c + 2a b )d f  + 2a c d f)x
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 3
+--R                          b f
+--R                       /
+--R                              4 3 4         3      2 2  4 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  5 2           3     2 2  6
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 7
+--R                            4c d
+--R              + 
+--R                       2
+--R                - a b f
+--R           /
+--R              x
+--R     + 
+--R       -
+--R              +-+
+--R            d\|a
+--R         *
+--R            ROOT
+--R                          2 2 2             2  3      2 4
+--R                     (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 3
+--R                             b f
+--R                          /
+--R                                 4 3 4         3      2 2  4 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  5 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  6      4 7
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                      2
+--R                   a f  - c d f
+--R              /
+--R                  2 2 2              2  3     2 4
+--R                 a d f  + (- 2a c + b )d f + c d
+--R         *
+--R            log
+--R                             3 2 3        2        2  3 2        2     2   4
+--R                           2a d f  + (- 6a c + 2a b )d f  + (6a c  - 2b c)d f
+--R                         + 
+--R                               3 5
+--R                           - 2c d
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 3
+--R                                 b f
+--R                              /
+--R                                     4 3 4         3      2 2  4 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  5 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  6      4 7
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                          2   2
+--R                       - b d f x
+--R                  *
+--R                      +-+
+--R                     \|a
+--R                  *
+--R                     ROOT
+--R                                   2 2 2             2  3      2 4
+--R                              (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 3
+--R                                      b f
+--R                                   /
+--R                                          4 3 4         3      2 2  4 3
+--R                                        4a d f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  5 2
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  6      4 7
+--R                                        (- 16a c  + 8b c )d f + 4c d
+--R                          + 
+--R                               2
+--R                            a f  - c d f
+--R                       /
+--R                           2 2 2              2  3     2 4
+--R                          a d f  + (- 2a c + b )d f + c d
+--R                 + 
+--R                            +--------------+
+--R                      2 +-+ |   2
+--R                   b f \|a \|c x  + b x + a
+--R                 + 
+--R                          3   3      2        2  2 2       2 3
+--R                     (- 2a d f  + (4a c - 2a b )d f  - 2a c d f)x
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 3
+--R                             b f
+--R                          /
+--R                                 4 3 4         3      2 2  4 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  5 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  6      4 7
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                          2
+--R                   - a b f
+--R              /
+--R                 x
+--R     + 
+--R           +-+
+--R         d\|a
+--R      *
+--R         ROOT
+--R                       2 2 2             2  3      2 4
+--R                  (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 3
+--R                          b f
+--R                       /
+--R                              4 3 4         3      2 2  4 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  5 2           3     2 2  6
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 7
+--R                            4c d
+--R              + 
+--R                   2
+--R                a f  - c d f
+--R           /
+--R               2 2 2              2  3     2 4
+--R              a d f  + (- 2a c + b )d f + c d
+--R      *
+--R         log
+--R                            3 2 3      2        2  3 2          2     2   4
+--R                        - 2a d f  + (6a c - 2a b )d f  + (- 6a c  + 2b c)d f
+--R                      + 
+--R                          3 5
+--R                        2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 3
+--R                              b f
+--R                           /
+--R                                  4 3 4         3      2 2  4 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  5 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  6      4 7
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                     2   2
+--R                    b d f x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                                2 2 2             2  3      2 4
+--R                           (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 3
+--R                                   b f
+--R                                /
+--R                                       4 3 4         3      2 2  4 3
+--R                                     4a d f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  5 2
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  6      4 7
+--R                                     (- 16a c  + 8b c )d f + 4c d
+--R                       + 
+--R                            2
+--R                         a f  - c d f
+--R                    /
+--R                        2 2 2              2  3     2 4
+--R                       a d f  + (- 2a c + b )d f + c d
+--R              + 
+--R                         +--------------+
+--R                   2 +-+ |   2
+--R                b f \|a \|c x  + b x + a
+--R              + 
+--R                       3   3      2        2  2 2       2 3
+--R                  (- 2a d f  + (4a c - 2a b )d f  - 2a c d f)x
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 3
+--R                          b f
+--R                       /
+--R                              4 3 4         3      2 2  4 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  5 2           3     2 2  6
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 7
+--R                            4c d
+--R              + 
+--R                       2
+--R                - a b f
+--R           /
+--R              x
+--R     + 
+--R       -
+--R              +-+
+--R            d\|a
+--R         *
+--R            ROOT
+--R                        2 2 2               2  3      2 4
+--R                     (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 3
+--R                             b f
+--R                          /
+--R                                 4 3 4         3      2 2  4 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  5 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  6      4 7
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                      2
+--R                   a f  - c d f
+--R              /
+--R                  2 2 2              2  3     2 4
+--R                 a d f  + (- 2a c + b )d f + c d
+--R         *
+--R            log
+--R                               3 2 3      2        2  3 2          2     2   4
+--R                           - 2a d f  + (6a c - 2a b )d f  + (- 6a c  + 2b c)d f
+--R                         + 
+--R                             3 5
+--R                           2c d
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 3
+--R                                 b f
+--R                              /
+--R                                     4 3 4         3      2 2  4 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  5 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  6      4 7
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                          2   2
+--R                       - b d f x
+--R                  *
+--R                      +-+
+--R                     \|a
+--R                  *
+--R                     ROOT
+--R                                 2 2 2               2  3      2 4
+--R                              (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 3
+--R                                      b f
+--R                                   /
+--R                                          4 3 4         3      2 2  4 3
+--R                                        4a d f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  5 2
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  6      4 7
+--R                                        (- 16a c  + 8b c )d f + 4c d
+--R                          + 
+--R                               2
+--R                            a f  - c d f
+--R                       /
+--R                           2 2 2              2  3     2 4
+--R                          a d f  + (- 2a c + b )d f + c d
+--R                 + 
+--R                            +--------------+
+--R                      2 +-+ |   2
+--R                   b f \|a \|c x  + b x + a
+--R                 + 
+--R                        3   3        2        2  2 2       2 3
+--R                     (2a d f  + (- 4a c + 2a b )d f  + 2a c d f)x
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 3
+--R                             b f
+--R                          /
+--R                                 4 3 4         3      2 2  4 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  5 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  6      4 7
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                          2
+--R                   - a b f
+--R              /
+--R                 x
+--R     + 
+--R                  +--------------+
+--R              +-+ |   2
+--R            2\|a \|c x  + b x + a  - b x - 2a
+--R       2log(---------------------------------)
+--R                            x
+--R  /
+--R        +-+
+--R     2d\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 244
+
+--S 245 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-------------------------+
+--R           +-+ |    +---+ +-+
+--R         d\|a \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                     2 2 2               2  3      2 4
+--R                  (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 3
+--R                          b f
+--R                       /
+--R                              4 3 4         3      2 2  4 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  5 2           3     2 2  6
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 7
+--R                            4c d
+--R              + 
+--R                   2
+--R                a f  - c d f
+--R           /
+--R               2 2 2              2  3     2 4
+--R              a d f  + (- 2a c + b )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            3 2 3        2        2  3 2        2     2   4
+--R                          2a d f  + (- 6a c + 2a b )d f  + (6a c  - 2b c)d f
+--R                        + 
+--R                              3 5
+--R                          - 2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 3
+--R                              b f
+--R                           /
+--R                                  4 3 4         3      2 2  4 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  5 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  6      4 7
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                     2   2
+--R                    b d f x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                              2 2 2               2  3      2 4
+--R                           (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 3
+--R                                   b f
+--R                                /
+--R                                       4 3 4         3      2 2  4 3
+--R                                     4a d f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  5 2
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  6      4 7
+--R                                     (- 16a c  + 8b c )d f + 4c d
+--R                       + 
+--R                            2
+--R                         a f  - c d f
+--R                    /
+--R                        2 2 2              2  3     2 4
+--R                       a d f  + (- 2a c + b )d f + c d
+--R              + 
+--R                         +--------------+
+--R                   2 +-+ |   2
+--R                b f \|a \|c x  + b x + a
+--R              + 
+--R                     3   3        2        2  2 2       2 3
+--R                  (2a d f  + (- 4a c + 2a b )d f  + 2a c d f)x
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 3
+--R                          b f
+--R                       /
+--R                              4 3 4         3      2 2  4 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  5 2           3     2 2  6
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 7
+--R                            4c d
+--R              + 
+--R                       2
+--R                - a b f
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                  +-------------------------+
+--R              +-+ |    +---+ +-+
+--R            d\|a \|- b\|- d \|f  - a f + c d
+--R         *
+--R            ROOT
+--R                          2 2 2             2  3      2 4
+--R                     (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 3
+--R                             b f
+--R                          /
+--R                                 4 3 4         3      2 2  4 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  5 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  6      4 7
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                      2
+--R                   a f  - c d f
+--R              /
+--R                  2 2 2              2  3     2 4
+--R                 a d f  + (- 2a c + b )d f + c d
+--R         *
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  - a f + c d
+--R         *
+--R            log
+--R                             3 2 3        2        2  3 2        2     2   4
+--R                           2a d f  + (- 6a c + 2a b )d f  + (6a c  - 2b c)d f
+--R                         + 
+--R                               3 5
+--R                           - 2c d
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 3
+--R                                 b f
+--R                              /
+--R                                     4 3 4         3      2 2  4 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  5 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  6      4 7
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                          2   2
+--R                       - b d f x
+--R                  *
+--R                      +-+
+--R                     \|a
+--R                  *
+--R                     ROOT
+--R                                   2 2 2             2  3      2 4
+--R                              (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 3
+--R                                      b f
+--R                                   /
+--R                                          4 3 4         3      2 2  4 3
+--R                                        4a d f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  5 2
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  6      4 7
+--R                                        (- 16a c  + 8b c )d f + 4c d
+--R                          + 
+--R                               2
+--R                            a f  - c d f
+--R                       /
+--R                           2 2 2              2  3     2 4
+--R                          a d f  + (- 2a c + b )d f + c d
+--R                 + 
+--R                            +--------------+
+--R                      2 +-+ |   2
+--R                   b f \|a \|c x  + b x + a
+--R                 + 
+--R                          3   3      2        2  2 2       2 3
+--R                     (- 2a d f  + (4a c - 2a b )d f  - 2a c d f)x
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 3
+--R                             b f
+--R                          /
+--R                                 4 3 4         3      2 2  4 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  5 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  6      4 7
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                          2
+--R                   - a b f
+--R              /
+--R                 x
+--R     + 
+--R               +-------------------------+
+--R           +-+ |    +---+ +-+
+--R         d\|a \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                       2 2 2             2  3      2 4
+--R                  (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 3
+--R                          b f
+--R                       /
+--R                              4 3 4         3      2 2  4 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  5 2           3     2 2  6
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 7
+--R                            4c d
+--R              + 
+--R                   2
+--R                a f  - c d f
+--R           /
+--R               2 2 2              2  3     2 4
+--R              a d f  + (- 2a c + b )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            3 2 3      2        2  3 2          2     2   4
+--R                        - 2a d f  + (6a c - 2a b )d f  + (- 6a c  + 2b c)d f
+--R                      + 
+--R                          3 5
+--R                        2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                         -
+--R                               2 3
+--R                              b f
+--R                           /
+--R                                  4 3 4         3      2 2  4 3
+--R                                4a d f  + (- 16a c + 8a b )d f
+--R                              + 
+--R                                    2 2        2      4  5 2
+--R                                (24a c  - 16a b c + 4b )d f
+--R                              + 
+--R                                        3     2 2  6      4 7
+--R                                (- 16a c  + 8b c )d f + 4c d
+--R                  + 
+--R                     2   2
+--R                    b d f x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                                2 2 2             2  3      2 4
+--R                           (- 2a d f  + (4a c - 2b )d f - 2c d )
+--R                        *
+--R                           ROOT
+--R                              -
+--R                                    2 3
+--R                                   b f
+--R                                /
+--R                                       4 3 4         3      2 2  4 3
+--R                                     4a d f  + (- 16a c + 8a b )d f
+--R                                   + 
+--R                                         2 2        2      4  5 2
+--R                                     (24a c  - 16a b c + 4b )d f
+--R                                   + 
+--R                                             3     2 2  6      4 7
+--R                                     (- 16a c  + 8b c )d f + 4c d
+--R                       + 
+--R                            2
+--R                         a f  - c d f
+--R                    /
+--R                        2 2 2              2  3     2 4
+--R                       a d f  + (- 2a c + b )d f + c d
+--R              + 
+--R                         +--------------+
+--R                   2 +-+ |   2
+--R                b f \|a \|c x  + b x + a
+--R              + 
+--R                       3   3      2        2  2 2       2 3
+--R                  (- 2a d f  + (4a c - 2a b )d f  - 2a c d f)x
+--R               *
+--R                  ROOT
+--R                     -
+--R                           2 3
+--R                          b f
+--R                       /
+--R                              4 3 4         3      2 2  4 3
+--R                            4a d f  + (- 16a c + 8a b )d f
+--R                          + 
+--R                                2 2        2      4  5 2           3     2 2  6
+--R                            (24a c  - 16a b c + 4b )d f  + (- 16a c  + 8b c )d f
+--R                          + 
+--R                              4 7
+--R                            4c d
+--R              + 
+--R                       2
+--R                - a b f
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                  +-------------------------+
+--R              +-+ |    +---+ +-+
+--R            d\|a \|- b\|- d \|f  - a f + c d
+--R         *
+--R            ROOT
+--R                        2 2 2               2  3      2 4
+--R                     (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 3
+--R                             b f
+--R                          /
+--R                                 4 3 4         3      2 2  4 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  5 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  6      4 7
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                      2
+--R                   a f  - c d f
+--R              /
+--R                  2 2 2              2  3     2 4
+--R                 a d f  + (- 2a c + b )d f + c d
+--R         *
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  - a f + c d
+--R         *
+--R            log
+--R                               3 2 3      2        2  3 2          2     2   4
+--R                           - 2a d f  + (6a c - 2a b )d f  + (- 6a c  + 2b c)d f
+--R                         + 
+--R                             3 5
+--R                           2c d
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                            -
+--R                                  2 3
+--R                                 b f
+--R                              /
+--R                                     4 3 4         3      2 2  4 3
+--R                                   4a d f  + (- 16a c + 8a b )d f
+--R                                 + 
+--R                                       2 2        2      4  5 2
+--R                                   (24a c  - 16a b c + 4b )d f
+--R                                 + 
+--R                                           3     2 2  6      4 7
+--R                                   (- 16a c  + 8b c )d f + 4c d
+--R                     + 
+--R                          2   2
+--R                       - b d f x
+--R                  *
+--R                      +-+
+--R                     \|a
+--R                  *
+--R                     ROOT
+--R                                 2 2 2               2  3      2 4
+--R                              (2a d f  + (- 4a c + 2b )d f + 2c d )
+--R                           *
+--R                              ROOT
+--R                                 -
+--R                                       2 3
+--R                                      b f
+--R                                   /
+--R                                          4 3 4         3      2 2  4 3
+--R                                        4a d f  + (- 16a c + 8a b )d f
+--R                                      + 
+--R                                            2 2        2      4  5 2
+--R                                        (24a c  - 16a b c + 4b )d f
+--R                                      + 
+--R                                                3     2 2  6      4 7
+--R                                        (- 16a c  + 8b c )d f + 4c d
+--R                          + 
+--R                               2
+--R                            a f  - c d f
+--R                       /
+--R                           2 2 2              2  3     2 4
+--R                          a d f  + (- 2a c + b )d f + c d
+--R                 + 
+--R                            +--------------+
+--R                      2 +-+ |   2
+--R                   b f \|a \|c x  + b x + a
+--R                 + 
+--R                        3   3        2        2  2 2       2 3
+--R                     (2a d f  + (- 4a c + 2a b )d f  + 2a c d f)x
+--R                  *
+--R                     ROOT
+--R                        -
+--R                              2 3
+--R                             b f
+--R                          /
+--R                                 4 3 4         3      2 2  4 3
+--R                               4a d f  + (- 16a c + 8a b )d f
+--R                             + 
+--R                                   2 2        2      4  5 2
+--R                               (24a c  - 16a b c + 4b )d f
+--R                             + 
+--R                                       3     2 2  6      4 7
+--R                               (- 16a c  + 8b c )d f + 4c d
+--R                 + 
+--R                          2
+--R                   - a b f
+--R              /
+--R                 x
+--R     + 
+--R                  +-----------------------+
+--R          +-+ +-+ |  +---+ +-+
+--R         \|a \|f \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                  +-------------------------+
+--R          +-+ +-+ |    +---+ +-+
+--R         \|a \|f \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|a \|c x  + b x + a  - b x - 2a
+--R           2log(---------------------------------)
+--R                                x
+--R         + 
+--R                         b x + 2a
+--R           2atanh(----------------------)
+--R                        +--------------+
+--R                    +-+ |   2
+--R                  2\|a \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R            +-------------------------+ +-----------------------+
+--R        +-+ |    +---+ +-+              |  +---+ +-+
+--R     2d\|a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 245
+
+-- (1 . failed) cannot be coerced to mode
+--   (SparseUnivariatePolynomial (Integer))
+--S 246 of 1580
+--d0:=D(m0,x)
+--E 246
+
+)clear all
+
+--S 247 of 1580
+t0:=1/(x^2*(a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                      +--------------+
+--R            4      2  |   2
+--R        (f x  + d x )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 1580
+r0:=1/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(a^(3/2)*d)-_
+   sqrt(a+b*x+c*x^2)/(a*d*x)+1/2*f*atanh(1/2*(b*d+2*a*sqrt(-d)*sqrt(f)+_
+   x*(2*c*d+b*sqrt(-d)*sqrt(f)))/(sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+_
+   a*f-b*sqrt(-d)*sqrt(f))))/((-d)^(3/2)*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*f*atanh(1/2*(b*d-2*a*sqrt(-d)*sqrt(f)+x*(2*c*d-b*sqrt(-d)*sqrt(f)))/_
+   (sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f))))/_
+   ((-d)^(3/2)*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R       -
+--R                      +-----------------------+
+--R                  +-+ |  +---+ +-+
+--R            a f x\|a \|b\|- d \|f  + a f - c d
+--R         *
+--R                                      +---+ +-+
+--R                           (b x + 2a)\|- d \|f  + 2c d x + b d
+--R            atanh(----------------------------------------------------)
+--R                          +--------------+ +-------------------------+
+--R                    +---+ |   2            |    +---+ +-+
+--R                  2\|- d \|c x  + b x + a \|- b\|- d \|f  + a f - c d
+--R     + 
+--R                   +-------------------------+
+--R               +-+ |    +---+ +-+
+--R         a f x\|a \|- b\|- d \|f  + a f - c d
+--R      *
+--R                                  +---+ +-+
+--R                       (b x + 2a)\|- d \|f  - 2c d x - b d
+--R         atanh(--------------------------------------------------)
+--R                       +--------------+ +-----------------------+
+--R                 +---+ |   2            |  +---+ +-+
+--R               2\|- d \|c x  + b x + a \|b\|- d \|f  + a f - c d
+--R     + 
+--R                                                               +--------------+
+--R              +---+             b x + 2a             +---+ +-+ |   2
+--R         (b x\|- d atanh(----------------------) - 2\|- d \|a \|c x  + b x + a )
+--R                               +--------------+
+--R                           +-+ |   2
+--R                         2\|a \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R  /
+--R                      +-------------------------+ +-----------------------+
+--R            +---+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2a d x\|- d \|a \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 1580
+--a0:=integrate(t0,x)
+--E 249
+
+--S 250 of 1580
+--m0:=a0-r0
+--E 250
+
+--S 251 of 1580
+--d0:=D(m0,x)
+--E 251
+
+)clear all
+
+--S 252 of 1580
+t0:=1/(x^3*(a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                      +--------------+
+--R            5      3  |   2
+--R        (f x  + d x )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 1580
+r0:=-1/8*(3*b^2-4*a*c)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (a^(5/2)*d)+f*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (d^2*sqrt(a))-1/2*sqrt(a+b*x+c*x^2)/(a*d*x^2)+3/4*b*sqrt(a+b*x+c*x^2)/_
+   (a^2*d*x)+1/2*f^(3/2)*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+_
+   b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))/_
+   (d^2*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*f^(3/2)*atan(1/2*(b*sqrt(-d)-_
+   2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f))))/(d^2*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                         +-----------------------+
+--R           2   2 +-+ +-+ |  +---+ +-+
+--R         4a f x \|a \|f \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                         +-------------------------+
+--R           2   2 +-+ +-+ |    +---+ +-+
+--R         4a f x \|a \|f \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R              2              2    2             b x + 2a
+--R           (8a f + (4a c - 3b )d)x atanh(----------------------)
+--R                                               +--------------+
+--R                                           +-+ |   2
+--R                                         2\|a \|c x  + b x + a
+--R         + 
+--R                               +--------------+
+--R                           +-+ |   2
+--R           (6b d x - 4a d)\|a \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                 +-------------------------+ +-----------------------+
+--R       2 2 2 +-+ |    +---+ +-+              |  +---+ +-+
+--R     8a d x \|a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 1580
+--a0:=integrate(t0,x)
+--E 254
+
+--S 255 of 1580
+--m0:=a0-r0
+--E 255
+
+--S 256 of 1580
+--d0:=D(m0,x)
+--E 256
+
+)clear all
+
+--S 257 of 1580
+t0:=x^4/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                        4
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 1580
+r0:=atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f)+2*x*_
+   (2*a+b*x)/((b^2-4*a*c)*f*sqrt(a+b*x+c*x^2))+2*d*(b+2*c*x)/((b^2-4*a*c)*_
+   f^2*sqrt(a+b*x+c*x^2))-2*d^2*(b*(c^2*d+b^2*f-3*a*c*f)+c*(2*c^2*d+_
+   b^2*f-2*a*c*f)*x)/((b^2-4*a*c)*f^2*(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*_
+   sqrt(a+b*x+c*x^2))-2*b*sqrt(a+b*x+c*x^2)/(c*(b^2-4*a*c)*f)-_
+   1/2*d^2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*((c*d-a*f)/_
+   sqrt(-d)+b*sqrt(f))/(f*(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-_
+   a*f-b*sqrt(-d)*sqrt(f)))+1/2*d^2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*_
+   sqrt(-d)*sqrt(f))))*((-c*d+a*f)/sqrt(-d)+b*sqrt(f))/(f*(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                    2    3   2 +---+ +-+ +-+
+--R           (- 4a b c  + b c)d \|- d \|c \|f
+--R         + 
+--R               2 2      2   2           3    2 2  3  +-+
+--R           ((4a c  - a b c)d f + (- 4a c  + b c )d )\|c
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                    2    3   2 +---+ +-+ +-+
+--R           (- 4a b c  + b c)d \|- d \|c \|f
+--R         + 
+--R                 2 2      2   2         3    2 2  3  +-+
+--R           ((- 4a c  + a b c)d f + (4a c  - b c )d )\|c
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                  3      2 2  2         2 2        2      4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f
+--R             + 
+--R                    3     2 2  2
+--R               (8a c  - 2b c )d
+--R          *
+--R                    +--------------+
+--R              +---+ |   2                        2c x + b
+--R             \|- d \|c x  + b x + a atanh(----------------------)
+--R                                                +--------------+
+--R                                            +-+ |   2
+--R                                          2\|c \|c x  + b x + a
+--R         + 
+--R                     3      2 2  2      2 2        2      4           3   2
+--R               ((- 8a c + 4a b )f  + (8a c  - 16a b c + 4b )d f)x + 4a b f
+--R             + 
+--R                     2          3
+--R               (- 12a b c + 4a b )d f
+--R          *
+--R              +---+ +-+
+--R             \|- d \|c
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R            3 2     2 2   3         2 3        2 2     4     2
+--R         (8a c  - 2a b c)f  + (- 16a c  + 12a b c  - 2b c)d f
+--R       + 
+--R              4     2 3  2
+--R         (8a c  - 2b c )d f
+--R    *
+--R                  +--------------+ +-------------------------+
+--R        +---+ +-+ |   2            |    +---+ +-+
+--R       \|- d \|c \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 258
+
+--S 259 of 1580
+--a0:=integrate(t0,x)
+--E 259
+
+--S 260 of 1580
+--m0:=a0-r0
+--E 260
+
+--S 261 of 1580
+--d0:=D(m0,x)
+--E 261
+
+)clear all
+
+--S 262 of 1580
+t0:=x^3/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                        3
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 1580
+r0:=2*(2*a+b*x)/((b^2-4*a*c)*f*sqrt(a+b*x+c*x^2))-2*d*(a*(2*c^2*d+b^2*f-_
+   2*a*c*f)+b*c*(c*d+a*f)*x)/((b^2-4*a*c)*f*(c^2*d^2-2*a*c*d*f+f*(b^2*d+_
+   a^2*f))*sqrt(a+b*x+c*x^2))+1/2*d*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*_
+   sqrt(-d)*sqrt(f))))*(c*d-a*f+b*sqrt(-d)*sqrt(f))/((c^2*d^2-2*a*c*d*f+_
+   f*(b^2*d+a^2*f))*sqrt(f)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*d*_
+   atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(f)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                     3   +---+ +-+        2       2            2    2   2
+--R         ((4a b c - b )d\|- d \|f  + (- 4a c + a b )d f + (4a c  - b c)d )
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                       3   +---+ +-+        2       2            2    2   2
+--R         ((- 4a b c + b )d\|- d \|f  + (- 4a c + a b )d f + (4a c  - b c)d )
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R               2                   3         3       2        2    +-+
+--R         ((- 4a b f + (12a b c - 4b )d)x - 8a f + (8a c - 4a b )d)\|f
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R           3      2 2  2         2 2        2      4            3     2 2  2
+--R       ((8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f + (8a c  - 2b c )d )
+--R    *
+--R          +--------------+ +-------------------------+ +-----------------------+
+--R      +-+ |   2            |    +---+ +-+              |  +---+ +-+
+--R     \|f \|c x  + b x + a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2   2                3          2 2       3 2
+--R               (a b f  + (- 2a b c + b )d f + b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2   2        2     2          3 2  2
+--R               (- 2a c f  + (4a c  - 2b c)d f - 2c d )x
+--R             + 
+--R                    2   2               3           2 2       3 2
+--R               (- 2a b f  + (4a b c - 2b )d f - 2b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         ROOT
+--R                      6 7         5      4 2    6
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 5
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 4
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d f
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                 3 2 3        2        2  3 2        2     2   4     3 5
+--R                a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R           /
+--R                 6 7        5      4 2    6       4 2      3 2      2 4  2 5
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 4
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 3          5     2 4  5 2    6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f  + c d f
+--R      *
+--R         log
+--R                          8 9         7      6 2    8       6 2      5 2   2 7
+--R                        2a f  + (- 16a c + 4a b )d f  + (56a c  - 24a b c)d f
+--R                      + 
+--R                               5 3      4 2 2     2 6  3 6
+--R                        (- 112a c  + 60a b c  - 4a b )d f
+--R                      + 
+--R                             4 4      3 2 3       6      8  4 5
+--R                        (140a c  - 80a b c  + 8a b c - 2b )d f
+--R                      + 
+--R                               3 5      2 2 4     6 2  5 4
+--R                        (- 112a c  + 60a b c  - 4b c )d f
+--R                      + 
+--R                          2 6        2 5  6 3           7     2 6  7 2     8 8
+--R                      (56a c  - 24a b c )d f  + (- 16a c  + 4b c )d f  + 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 5 4       3 2      2 4  6 3
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  7 2
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  8      2 4 9
+--R                             (36a b c  + 6b c )d f - 9b c d
+--R                        /
+--R                               12 13         11       10 2    12
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 11
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 10
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 9
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 4
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 3
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11 2     12 12
+--R                             (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                  + 
+--R                          3 2 3 4         2 2        4  4 3
+--R                        6a b d f  + (- 18a b c - 2a b )d f
+--R                      + 
+--R                              2 2     4   5 2     2 3 6
+--R                        (18a b c  + 2b c)d f  - 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                               6 7         5      4 2    6
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 5
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 4
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 3
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5 2     6 6
+--R                             (- 12a c  + 6b c )d f  + 2c d f
+--R                        *
+--R                           ROOT
+--R                                      4 2 5 4       3 2      2 4  6 3
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  7 2
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  8      2 4 9
+--R                                  (36a b c  + 6b c )d f - 9b c d
+--R                             /
+--R                                    12 13         11       10 2    12
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 11
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 10
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 3
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11 2     12 12
+--R                                  (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                       + 
+--R                        3 2 3        2        2  3 2        2     2   4     3 5
+--R                       a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R                    /
+--R                          6 7        5      4 2    6
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 5
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 4
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 3          5     2 4  5 2
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d f
+--R              + 
+--R                                                               +--------------+
+--R                   2   4 2                3  5        2 6  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                      7   7         6      5 2  2 6
+--R                    2a d f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        5 2      4 2      3 4  3 5
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          4 3      3 2 2      2 4        6  4 4
+--R                    (- 40a c  + 36a b c  - 12a b c + 2a b )d f
+--R                  + 
+--R                        3 4      2 2 3       4 2  5 3         2 5       2 4  6 2
+--R                    (30a c  - 24a b c  + 6a b c )d f  + (- 12a c  + 6a b c )d f
+--R                  + 
+--R                        6 7
+--R                    2a c d f
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                    3   4 2      2         3  5          2 6
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                   2   2              3          2 2       3 2
+--R               (- a b f  + (2a b c - b )d f - b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                  2   2          2     2          3 2  2
+--R               (2a c f  + (- 4a c  + 2b c)d f + 2c d )x
+--R             + 
+--R                  2   2                 3           2 2       3 2
+--R               (2a b f  + (- 4a b c + 2b )d f + 2b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         ROOT
+--R                        6 7       5      4 2    6
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 5
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 4
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d f
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                 3 2 3        2        2  3 2        2     2   4     3 5
+--R                a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R           /
+--R                 6 7        5      4 2    6       4 2      3 2      2 4  2 5
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 4
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 3          5     2 4  5 2    6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f  + c d f
+--R      *
+--R         log
+--R                          8 9         7      6 2    8       6 2      5 2   2 7
+--R                        2a f  + (- 16a c + 4a b )d f  + (56a c  - 24a b c)d f
+--R                      + 
+--R                               5 3      4 2 2     2 6  3 6
+--R                        (- 112a c  + 60a b c  - 4a b )d f
+--R                      + 
+--R                             4 4      3 2 3       6      8  4 5
+--R                        (140a c  - 80a b c  + 8a b c - 2b )d f
+--R                      + 
+--R                               3 5      2 2 4     6 2  5 4
+--R                        (- 112a c  + 60a b c  - 4b c )d f
+--R                      + 
+--R                          2 6        2 5  6 3           7     2 6  7 2     8 8
+--R                      (56a c  - 24a b c )d f  + (- 16a c  + 4b c )d f  + 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 5 4       3 2      2 4  6 3
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  7 2
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  8      2 4 9
+--R                             (36a b c  + 6b c )d f - 9b c d
+--R                        /
+--R                               12 13         11       10 2    12
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 11
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 10
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 9
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 4
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 3
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11 2     12 12
+--R                             (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                  + 
+--R                            3 2 3 4       2 2        4  4 3
+--R                        - 6a b d f  + (18a b c + 2a b )d f
+--R                      + 
+--R                                2 2     4   5 2     2 3 6
+--R                        (- 18a b c  - 2b c)d f  + 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                                 6 7       5      4 2    6
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 5
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 4
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 3
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5 2     6 6
+--R                             (12a c  - 6b c )d f  - 2c d f
+--R                        *
+--R                           ROOT
+--R                                      4 2 5 4       3 2      2 4  6 3
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  7 2
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  8      2 4 9
+--R                                  (36a b c  + 6b c )d f - 9b c d
+--R                             /
+--R                                    12 13         11       10 2    12
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 11
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 10
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 3
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11 2     12 12
+--R                                  (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                       + 
+--R                        3 2 3        2        2  3 2        2     2   4     3 5
+--R                       a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R                    /
+--R                          6 7        5      4 2    6
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 5
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 4
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 3          5     2 4  5 2
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d f
+--R              + 
+--R                                                               +--------------+
+--R                   2   4 2                3  5        2 6  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                        7   7       6      5 2  2 6
+--R                    - 2a d f  + (12a c - 6a b )d f
+--R                  + 
+--R                          5 2      4 2      3 4  3 5
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        4 3      3 2 2      2 4        6  4 4
+--R                    (40a c  - 36a b c  + 12a b c - 2a b )d f
+--R                  + 
+--R                          3 4      2 2 3       4 2  5 3       2 5       2 4  6 2
+--R                    (- 30a c  + 24a b c  - 6a b c )d f  + (12a c  - 6a b c )d f
+--R                  + 
+--R                          6 7
+--R                    - 2a c d f
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                    3   4 2      2         3  5          2 6
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                 2   2                3          2 2       3 2
+--R               (a b f  + (- 2a b c + b )d f + b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2   2        2     2          3 2  2
+--R               (- 2a c f  + (4a c  - 2b c)d f - 2c d )x
+--R             + 
+--R                    2   2               3           2 2       3 2
+--R               (- 2a b f  + (4a b c - 2b )d f - 2b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         ROOT
+--R                        6 7       5      4 2    6
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 5
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 4
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d f
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                 3 2 3        2        2  3 2        2     2   4     3 5
+--R                a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R           /
+--R                 6 7        5      4 2    6       4 2      3 2      2 4  2 5
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 4
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 3          5     2 4  5 2    6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f  + c d f
+--R      *
+--R         log
+--R                            8 9       7      6 2    8         6 2      5 2   2 7
+--R                        - 2a f  + (16a c - 4a b )d f  + (- 56a c  + 24a b c)d f
+--R                      + 
+--R                             5 3      4 2 2     2 6  3 6
+--R                        (112a c  - 60a b c  + 4a b )d f
+--R                      + 
+--R                               4 4      3 2 3       6      8  4 5
+--R                        (- 140a c  + 80a b c  - 8a b c + 2b )d f
+--R                      + 
+--R                             3 5      2 2 4     6 2  5 4
+--R                        (112a c  - 60a b c  + 4b c )d f
+--R                      + 
+--R                            2 6        2 5  6 3         7     2 6  7 2     8 8
+--R                      (- 56a c  + 24a b c )d f  + (16a c  - 4b c )d f  - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 5 4       3 2      2 4  6 3
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  7 2
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  8      2 4 9
+--R                             (36a b c  + 6b c )d f - 9b c d
+--R                        /
+--R                               12 13         11       10 2    12
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 11
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 10
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 9
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 4
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 3
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11 2     12 12
+--R                             (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                  + 
+--R                          3 2 3 4         2 2        4  4 3
+--R                        6a b d f  + (- 18a b c - 2a b )d f
+--R                      + 
+--R                              2 2     4   5 2     2 3 6
+--R                        (18a b c  + 2b c)d f  - 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                                 6 7       5      4 2    6
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 5
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 4
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 3
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5 2     6 6
+--R                             (12a c  - 6b c )d f  - 2c d f
+--R                        *
+--R                           ROOT
+--R                                      4 2 5 4       3 2      2 4  6 3
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  7 2
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  8      2 4 9
+--R                                  (36a b c  + 6b c )d f - 9b c d
+--R                             /
+--R                                    12 13         11       10 2    12
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 11
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 10
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 3
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11 2     12 12
+--R                                  (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                       + 
+--R                        3 2 3        2        2  3 2        2     2   4     3 5
+--R                       a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R                    /
+--R                          6 7        5      4 2    6
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 5
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 4
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 3          5     2 4  5 2
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d f
+--R              + 
+--R                                                               +--------------+
+--R                   2   4 2                3  5        2 6  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                        7   7       6      5 2  2 6
+--R                    - 2a d f  + (12a c - 6a b )d f
+--R                  + 
+--R                          5 2      4 2      3 4  3 5
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        4 3      3 2 2      2 4        6  4 4
+--R                    (40a c  - 36a b c  + 12a b c - 2a b )d f
+--R                  + 
+--R                          3 4      2 2 3       4 2  5 3       2 5       2 4  6 2
+--R                    (- 30a c  + 24a b c  - 6a b c )d f  + (12a c  - 6a b c )d f
+--R                  + 
+--R                          6 7
+--R                    - 2a c d f
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                    3   4 2      2         3  5          2 6
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                   2   2              3          2 2       3 2
+--R               (- a b f  + (2a b c - b )d f - b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                  2   2          2     2          3 2  2
+--R               (2a c f  + (- 4a c  + 2b c)d f + 2c d )x
+--R             + 
+--R                  2   2                 3           2 2       3 2
+--R               (2a b f  + (- 4a b c + 2b )d f + 2b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         ROOT
+--R                      6 7         5      4 2    6
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 5
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 4
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d f
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                 3 2 3        2        2  3 2        2     2   4     3 5
+--R                a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R           /
+--R                 6 7        5      4 2    6       4 2      3 2      2 4  2 5
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 4
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 3          5     2 4  5 2    6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f  + c d f
+--R      *
+--R         log
+--R                            8 9       7      6 2    8         6 2      5 2   2 7
+--R                        - 2a f  + (16a c - 4a b )d f  + (- 56a c  + 24a b c)d f
+--R                      + 
+--R                             5 3      4 2 2     2 6  3 6
+--R                        (112a c  - 60a b c  + 4a b )d f
+--R                      + 
+--R                               4 4      3 2 3       6      8  4 5
+--R                        (- 140a c  + 80a b c  - 8a b c + 2b )d f
+--R                      + 
+--R                             3 5      2 2 4     6 2  5 4
+--R                        (112a c  - 60a b c  + 4b c )d f
+--R                      + 
+--R                            2 6        2 5  6 3         7     2 6  7 2     8 8
+--R                      (- 56a c  + 24a b c )d f  + (16a c  - 4b c )d f  - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 5 4       3 2      2 4  6 3
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  7 2
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  8      2 4 9
+--R                             (36a b c  + 6b c )d f - 9b c d
+--R                        /
+--R                               12 13         11       10 2    12
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 11
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 10
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 9
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 4
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 3
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11 2     12 12
+--R                             (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                  + 
+--R                            3 2 3 4       2 2        4  4 3
+--R                        - 6a b d f  + (18a b c + 2a b )d f
+--R                      + 
+--R                                2 2     4   5 2     2 3 6
+--R                        (- 18a b c  - 2b c)d f  + 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                               6 7         5      4 2    6
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 5
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 4
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 3
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5 2     6 6
+--R                             (- 12a c  + 6b c )d f  + 2c d f
+--R                        *
+--R                           ROOT
+--R                                      4 2 5 4       3 2      2 4  6 3
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  7 2
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  8      2 4 9
+--R                                  (36a b c  + 6b c )d f - 9b c d
+--R                             /
+--R                                    12 13         11       10 2    12
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 11
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 10
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 3
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11 2     12 12
+--R                                  (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                       + 
+--R                        3 2 3        2        2  3 2        2     2   4     3 5
+--R                       a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R                    /
+--R                          6 7        5      4 2    6
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 5
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 4
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 3          5     2 4  5 2
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d f
+--R              + 
+--R                                                               +--------------+
+--R                   2   4 2                3  5        2 6  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                      7   7         6      5 2  2 6
+--R                    2a d f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        5 2      4 2      3 4  3 5
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          4 3      3 2 2      2 4        6  4 4
+--R                    (- 40a c  + 36a b c  - 12a b c + 2a b )d f
+--R                  + 
+--R                        3 4      2 2 3       4 2  5 3         2 5       2 4  6 2
+--R                    (30a c  - 24a b c  + 6a b c )d f  + (- 12a c  + 6a b c )d f
+--R                  + 
+--R                        6 7
+--R                    2a c d f
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                    3   4 2      2         3  5          2 6
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                    +--------------+
+--R                +-+ |   2                 2                2    2
+--R       - 4b d x\|a \|c x  + b x + a  + (4a f + (- 4a c + 4b )d)x  + 4a b d x
+--R  /
+--R              2   2                 3           2 2       3 2
+--R           (2a b f  + (- 4a b c + 2b )d f + 2b c d )x + 4a f
+--R         + 
+--R                2        2           2 2
+--R           (- 8a c + 4a b )d f + 4a c d
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                2   2        2     2          3 2  2
+--R           (- 4a c f  + (8a c  - 4b c)d f - 4c d )x
+--R         + 
+--R                2   2               3           2 2       3 2
+--R           (- 4a b f  + (8a b c - 4b )d f - 4b c d )x - 4a f
+--R         + 
+--R              2        2           2 2
+--R           (8a c - 4a b )d f - 4a c d
+--R      *
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 264
+
+--S 265 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  3      2 2  2         2 2        2      4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f
+--R             + 
+--R                    3     2 2  2
+--R               (8a c  - 2b c )d
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|f \|c x  + b x + a
+--R         + 
+--R                        3       2 3  2      2   2       3     5
+--R                   (- 4a b c + a b )f  + (8a b c  - 6a b c + b )d f
+--R                 + 
+--R                            3    3 2  2
+--R                   (- 4a b c  + b c )d
+--R              *
+--R                 x
+--R             + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +-+
+--R             \|f
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                      6 7         5      4 2    6
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 5
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 4
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d f
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                 3 2 3        2        2  3 2        2     2   4     3 5
+--R                a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R           /
+--R                 6 7        5      4 2    6       4 2      3 2      2 4  2 5
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 4
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 3          5     2 4  5 2    6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f  + c d f
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                          8 9         7      6 2    8       6 2      5 2   2 7
+--R                        2a f  + (- 16a c + 4a b )d f  + (56a c  - 24a b c)d f
+--R                      + 
+--R                               5 3      4 2 2     2 6  3 6
+--R                        (- 112a c  + 60a b c  - 4a b )d f
+--R                      + 
+--R                             4 4      3 2 3       6      8  4 5
+--R                        (140a c  - 80a b c  + 8a b c - 2b )d f
+--R                      + 
+--R                               3 5      2 2 4     6 2  5 4
+--R                        (- 112a c  + 60a b c  - 4b c )d f
+--R                      + 
+--R                          2 6        2 5  6 3           7     2 6  7 2     8 8
+--R                      (56a c  - 24a b c )d f  + (- 16a c  + 4b c )d f  + 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 5 4       3 2      2 4  6 3
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  7 2
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  8      2 4 9
+--R                             (36a b c  + 6b c )d f - 9b c d
+--R                        /
+--R                               12 13         11       10 2    12
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 11
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 10
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 9
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 4
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 3
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11 2     12 12
+--R                             (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                  + 
+--R                          3 2 3 4         2 2        4  4 3
+--R                        6a b d f  + (- 18a b c - 2a b )d f
+--R                      + 
+--R                              2 2     4   5 2     2 3 6
+--R                        (18a b c  + 2b c)d f  - 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                               6 7         5      4 2    6
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 5
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 4
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 3
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5 2     6 6
+--R                             (- 12a c  + 6b c )d f  + 2c d f
+--R                        *
+--R                           ROOT
+--R                                      4 2 5 4       3 2      2 4  6 3
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  7 2
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  8      2 4 9
+--R                                  (36a b c  + 6b c )d f - 9b c d
+--R                             /
+--R                                    12 13         11       10 2    12
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 11
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 10
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 3
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11 2     12 12
+--R                                  (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                       + 
+--R                        3 2 3        2        2  3 2        2     2   4     3 5
+--R                       a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R                    /
+--R                          6 7        5      4 2    6
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 5
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 4
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 3          5     2 4  5 2
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d f
+--R              + 
+--R                                                               +--------------+
+--R                   2   4 2                3  5        2 6  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                      7   7         6      5 2  2 6
+--R                    2a d f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        5 2      4 2      3 4  3 5
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          4 3      3 2 2      2 4        6  4 4
+--R                    (- 40a c  + 36a b c  - 12a b c + 2a b )d f
+--R                  + 
+--R                        3 4      2 2 3       4 2  5 3         2 5       2 4  6 2
+--R                    (30a c  - 24a b c  + 6a b c )d f  + (- 12a c  + 6a b c )d f
+--R                  + 
+--R                        6 7
+--R                    2a c d f
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                    3   4 2      2         3  5          2 6
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                    3      2 2  2       2 2        2      4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2b )d f
+--R             + 
+--R                      3     2 2  2
+--R               (- 8a c  + 2b c )d
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|f \|c x  + b x + a
+--R         + 
+--R                      3       2 3  2        2   2       3     5
+--R                   (4a b c - a b )f  + (- 8a b c  + 6a b c - b )d f
+--R                 + 
+--R                          3    3 2  2
+--R                   (4a b c  - b c )d
+--R              *
+--R                 x
+--R             + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R              +-+
+--R             \|f
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                        6 7       5      4 2    6
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 5
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 4
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d f
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                 3 2 3        2        2  3 2        2     2   4     3 5
+--R                a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R           /
+--R                 6 7        5      4 2    6       4 2      3 2      2 4  2 5
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 4
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 3          5     2 4  5 2    6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f  + c d f
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                          8 9         7      6 2    8       6 2      5 2   2 7
+--R                        2a f  + (- 16a c + 4a b )d f  + (56a c  - 24a b c)d f
+--R                      + 
+--R                               5 3      4 2 2     2 6  3 6
+--R                        (- 112a c  + 60a b c  - 4a b )d f
+--R                      + 
+--R                             4 4      3 2 3       6      8  4 5
+--R                        (140a c  - 80a b c  + 8a b c - 2b )d f
+--R                      + 
+--R                               3 5      2 2 4     6 2  5 4
+--R                        (- 112a c  + 60a b c  - 4b c )d f
+--R                      + 
+--R                          2 6        2 5  6 3           7     2 6  7 2     8 8
+--R                      (56a c  - 24a b c )d f  + (- 16a c  + 4b c )d f  + 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 5 4       3 2      2 4  6 3
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  7 2
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  8      2 4 9
+--R                             (36a b c  + 6b c )d f - 9b c d
+--R                        /
+--R                               12 13         11       10 2    12
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 11
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 10
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 9
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 4
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 3
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11 2     12 12
+--R                             (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                  + 
+--R                            3 2 3 4       2 2        4  4 3
+--R                        - 6a b d f  + (18a b c + 2a b )d f
+--R                      + 
+--R                                2 2     4   5 2     2 3 6
+--R                        (- 18a b c  - 2b c)d f  + 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                                 6 7       5      4 2    6
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 5
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 4
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 3
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5 2     6 6
+--R                             (12a c  - 6b c )d f  - 2c d f
+--R                        *
+--R                           ROOT
+--R                                      4 2 5 4       3 2      2 4  6 3
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  7 2
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  8      2 4 9
+--R                                  (36a b c  + 6b c )d f - 9b c d
+--R                             /
+--R                                    12 13         11       10 2    12
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 11
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 10
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 3
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11 2     12 12
+--R                                  (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                       + 
+--R                        3 2 3        2        2  3 2        2     2   4     3 5
+--R                       a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R                    /
+--R                          6 7        5      4 2    6
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 5
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 4
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 3          5     2 4  5 2
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d f
+--R              + 
+--R                                                               +--------------+
+--R                   2   4 2                3  5        2 6  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                        7   7       6      5 2  2 6
+--R                    - 2a d f  + (12a c - 6a b )d f
+--R                  + 
+--R                          5 2      4 2      3 4  3 5
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        4 3      3 2 2      2 4        6  4 4
+--R                    (40a c  - 36a b c  + 12a b c - 2a b )d f
+--R                  + 
+--R                          3 4      2 2 3       4 2  5 3       2 5       2 4  6 2
+--R                    (- 30a c  + 24a b c  - 6a b c )d f  + (12a c  - 6a b c )d f
+--R                  + 
+--R                          6 7
+--R                    - 2a c d f
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                    3   4 2      2         3  5          2 6
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                  3      2 2  2         2 2        2      4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f
+--R             + 
+--R                    3     2 2  2
+--R               (8a c  - 2b c )d
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|f \|c x  + b x + a
+--R         + 
+--R                        3       2 3  2      2   2       3     5
+--R                   (- 4a b c + a b )f  + (8a b c  - 6a b c + b )d f
+--R                 + 
+--R                            3    3 2  2
+--R                   (- 4a b c  + b c )d
+--R              *
+--R                 x
+--R             + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +-+
+--R             \|f
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                        6 7       5      4 2    6
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 5
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 4
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d f
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                 3 2 3        2        2  3 2        2     2   4     3 5
+--R                a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R           /
+--R                 6 7        5      4 2    6       4 2      3 2      2 4  2 5
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 4
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 3          5     2 4  5 2    6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f  + c d f
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            8 9       7      6 2    8         6 2      5 2   2 7
+--R                        - 2a f  + (16a c - 4a b )d f  + (- 56a c  + 24a b c)d f
+--R                      + 
+--R                             5 3      4 2 2     2 6  3 6
+--R                        (112a c  - 60a b c  + 4a b )d f
+--R                      + 
+--R                               4 4      3 2 3       6      8  4 5
+--R                        (- 140a c  + 80a b c  - 8a b c + 2b )d f
+--R                      + 
+--R                             3 5      2 2 4     6 2  5 4
+--R                        (112a c  - 60a b c  + 4b c )d f
+--R                      + 
+--R                            2 6        2 5  6 3         7     2 6  7 2     8 8
+--R                      (- 56a c  + 24a b c )d f  + (16a c  - 4b c )d f  - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 5 4       3 2      2 4  6 3
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  7 2
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  8      2 4 9
+--R                             (36a b c  + 6b c )d f - 9b c d
+--R                        /
+--R                               12 13         11       10 2    12
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 11
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 10
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 9
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 4
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 3
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11 2     12 12
+--R                             (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                  + 
+--R                          3 2 3 4         2 2        4  4 3
+--R                        6a b d f  + (- 18a b c - 2a b )d f
+--R                      + 
+--R                              2 2     4   5 2     2 3 6
+--R                        (18a b c  + 2b c)d f  - 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                                 6 7       5      4 2    6
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 5
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 4
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 3
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5 2     6 6
+--R                             (12a c  - 6b c )d f  - 2c d f
+--R                        *
+--R                           ROOT
+--R                                      4 2 5 4       3 2      2 4  6 3
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  7 2
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  8      2 4 9
+--R                                  (36a b c  + 6b c )d f - 9b c d
+--R                             /
+--R                                    12 13         11       10 2    12
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 11
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 10
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 3
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11 2     12 12
+--R                                  (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                       + 
+--R                        3 2 3        2        2  3 2        2     2   4     3 5
+--R                       a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R                    /
+--R                          6 7        5      4 2    6
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 5
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 4
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 3          5     2 4  5 2
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d f
+--R              + 
+--R                                                               +--------------+
+--R                   2   4 2                3  5        2 6  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                        7   7       6      5 2  2 6
+--R                    - 2a d f  + (12a c - 6a b )d f
+--R                  + 
+--R                          5 2      4 2      3 4  3 5
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        4 3      3 2 2      2 4        6  4 4
+--R                    (40a c  - 36a b c  + 12a b c - 2a b )d f
+--R                  + 
+--R                          3 4      2 2 3       4 2  5 3       2 5       2 4  6 2
+--R                    (- 30a c  + 24a b c  - 6a b c )d f  + (12a c  - 6a b c )d f
+--R                  + 
+--R                          6 7
+--R                    - 2a c d f
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                    3   4 2      2         3  5          2 6
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                    3      2 2  2       2 2        2      4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2b )d f
+--R             + 
+--R                      3     2 2  2
+--R               (- 8a c  + 2b c )d
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|a \|f \|c x  + b x + a
+--R         + 
+--R                      3       2 3  2        2   2       3     5
+--R                   (4a b c - a b )f  + (- 8a b c  + 6a b c - b )d f
+--R                 + 
+--R                          3    3 2  2
+--R                   (4a b c  - b c )d
+--R              *
+--R                 x
+--R             + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R              +-+
+--R             \|f
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                      6 7         5      4 2    6
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 5
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 4
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d f
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                 3 2 3        2        2  3 2        2     2   4     3 5
+--R                a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R           /
+--R                 6 7        5      4 2    6       4 2      3 2      2 4  2 5
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 4
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 3          5     2 4  5 2    6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f  + c d f
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            8 9       7      6 2    8         6 2      5 2   2 7
+--R                        - 2a f  + (16a c - 4a b )d f  + (- 56a c  + 24a b c)d f
+--R                      + 
+--R                             5 3      4 2 2     2 6  3 6
+--R                        (112a c  - 60a b c  + 4a b )d f
+--R                      + 
+--R                               4 4      3 2 3       6      8  4 5
+--R                        (- 140a c  + 80a b c  - 8a b c + 2b )d f
+--R                      + 
+--R                             3 5      2 2 4     6 2  5 4
+--R                        (112a c  - 60a b c  + 4b c )d f
+--R                      + 
+--R                            2 6        2 5  6 3         7     2 6  7 2     8 8
+--R                      (- 56a c  + 24a b c )d f  + (16a c  - 4b c )d f  - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 5 4       3 2      2 4  6 3
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  7 2
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  8      2 4 9
+--R                             (36a b c  + 6b c )d f - 9b c d
+--R                        /
+--R                               12 13         11       10 2    12
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 11
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 10
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 9
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 4
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 3
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11 2     12 12
+--R                             (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                  + 
+--R                            3 2 3 4       2 2        4  4 3
+--R                        - 6a b d f  + (18a b c + 2a b )d f
+--R                      + 
+--R                                2 2     4   5 2     2 3 6
+--R                        (- 18a b c  - 2b c)d f  + 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                               6 7         5      4 2    6
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 5
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 4
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 3
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5 2     6 6
+--R                             (- 12a c  + 6b c )d f  + 2c d f
+--R                        *
+--R                           ROOT
+--R                                      4 2 5 4       3 2      2 4  6 3
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  7 2
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  8      2 4 9
+--R                                  (36a b c  + 6b c )d f - 9b c d
+--R                             /
+--R                                    12 13         11       10 2    12
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 11
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 10
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 3
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11 2     12 12
+--R                                  (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R                       + 
+--R                        3 2 3        2        2  3 2        2     2   4     3 5
+--R                       a d f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f - c d
+--R                    /
+--R                          6 7        5      4 2    6
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 5
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 4
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 3          5     2 4  5 2
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d f
+--R              + 
+--R                                                               +--------------+
+--R                   2   4 2                3  5        2 6  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                      7   7         6      5 2  2 6
+--R                    2a d f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        5 2      4 2      3 4  3 5
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          4 3      3 2 2      2 4        6  4 4
+--R                    (- 40a c  + 36a b c  - 12a b c + 2a b )d f
+--R                  + 
+--R                        3 4      2 2 3       4 2  5 3         2 5       2 4  6 2
+--R                    (30a c  - 24a b c  + 6a b c )d f  + (- 12a c  + 6a b c )d f
+--R                  + 
+--R                        6 7
+--R                    2a c d f
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 5 4       3 2      2 4  6 3
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  7 2         2 3     4 2  8
+--R                         (- 54a b c  - 12a b c - b )d f  + (36a b c  + 6b c )d f
+--R                       + 
+--R                             2 4 9
+--R                         - 9b c d
+--R                    /
+--R                           12 13         11       10 2    12
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 11
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 10
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 9
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 4
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 3
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11 2     12 12
+--R                         (- 48a c   + 24b c  )d  f  + 4c  d  f
+--R              + 
+--R                    3   4 2      2         3  5          2 6
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                             3   +---+ +-+ +-+
+--R               (- 8a b c + 2b )d\|- d \|a \|f
+--R             + 
+--R                   2        2              2     2   2  +-+
+--R               ((8a c - 2a b )d f + (- 8a c  + 2b c)d )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                 2     4          2          3    +---+ +-+
+--R           ((4a b c - b )d x + (8a b c - 2a b )d)\|- d \|f
+--R         + 
+--R                 2         3              2    3   2          3      2 2
+--R           ((- 4a b c + a b )d f + (4a b c  - b c)d )x + (- 8a c + 2a b )d f
+--R         + 
+--R              2 2       2   2
+--R           (8a c  - 2a b c)d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                           3   +---+ +-+ +-+
+--R               (8a b c - 2b )d\|- d \|a \|f
+--R             + 
+--R                   2        2              2     2   2  +-+
+--R               ((8a c - 2a b )d f + (- 8a c  + 2b c)d )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   2     4            2          3    +---+ +-+
+--R           ((- 4a b c + b )d x + (- 8a b c + 2a b )d)\|- d \|f
+--R         + 
+--R                 2         3              2    3   2          3      2 2
+--R           ((- 4a b c + a b )d f + (4a b c  - b c)d )x + (- 8a c + 2a b )d f
+--R         + 
+--R              2 2       2   2
+--R           (8a c  - 2a b c)d
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                                            +--------------+
+--R                 3        2        2    +-+ |   2
+--R           (- 16a f + (16a c - 8a b )d)\|f \|c x  + b x + a
+--R         + 
+--R               2                    3          3          2        2    +-+ +-+
+--R           ((8a b f + (- 8a b c + 4b )d)x + 16a f + (- 16a c + 8a b )d)\|a \|f
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                 3      2 2  2         2 2        2      4
+--R             (16a c - 4a b )f  + (- 32a c  + 24a b c - 4b )d f
+--R           + 
+--R                   3     2 2  2
+--R             (16a c  - 4b c )d
+--R        *
+--R                    +--------------+
+--R            +-+ +-+ |   2
+--R           \|a \|f \|c x  + b x + a
+--R       + 
+--R                      3        2 3  2       2   2        3      5
+--R                 (- 8a b c + 2a b )f  + (16a b c  - 12a b c + 2b )d f
+--R               + 
+--R                          3     3 2  2
+--R                 (- 8a b c  + 2b c )d
+--R            *
+--R               x
+--R           + 
+--R                   4      3 2  2       3 2      2 2        4
+--R             (- 16a c + 4a b )f  + (32a c  - 24a b c + 4a b )d f
+--R           + 
+--R                   2 3       2 2  2
+--R             (- 16a c  + 4a b c )d
+--R        *
+--R            +-+
+--R           \|f
+--R    *
+--R        +-------------------------+ +-----------------------+
+--R        |    +---+ +-+              |  +---+ +-+
+--R       \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 1580
+--d0:=D(m0,x)
+--E 266
+
+)clear all
+
+--S 267 of 1580
+t0:=x^2/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                        2
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 1580
+r0:=-2*(b+2*c*x)/((b^2-4*a*c)*f*sqrt(a+b*x+c*x^2))+2*d*(b*(c^2*d+b^2*f-_
+   3*a*c*f)+c*(2*c^2*d+b^2*f-2*a*c*f)*x)/((b^2-4*a*c)*f*(c^2*d^2-2*a*c*d*f+_
+   f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))+1/2*d*atan(1/2*(b*sqrt(-d)+2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))))*((c*d-a*f)/sqrt(-d)+b*sqrt(f))/((c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-_
+   1/2*d*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*((-c*d+a*f)/_
+   sqrt(-d)+b*sqrt(f))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                     3   +---+ +-+        2       2            2    2   2
+--R         ((4a b c - b )d\|- d \|f  + (- 4a c + a b )d f + (4a c  - b c)d )
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                     3   +---+ +-+      2       2              2    2   2
+--R         ((4a b c - b )d\|- d \|f  + (4a c - a b )d f + (- 4a c  + b c)d )
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R             2             2     2          2                +---+
+--R         ((8a c f + (- 8a c  + 4b c)d)x + 4a b f + 4a b c d)\|- d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R           3      2 2  2         2 2        2      4            3     2 2  2
+--R       ((8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f + (8a c  - 2b c )d )
+--R    *
+--R              +--------------+ +-------------------------+
+--R        +---+ |   2            |    +---+ +-+
+--R       \|- d \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2   2                3          2 2       3 2
+--R               (a b f  + (- 2a b c + b )d f + b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2   2        2     2          3 2  2
+--R               (- 2a c f  + (4a c  - 2b c)d f - 2c d )x
+--R             + 
+--R                    2   2               3           2 2       3 2
+--R               (- 2a b f  + (4a b c - 2b )d f - 2b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         ROOT
+--R                      6 6         5      4 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 2           5     2 4  5
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3   3      2        2  2 2          2     2   3     3 4
+--R                - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f + c d
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                          7   7         6         5 3    6
+--R                        4a b f  + (- 28a b c + 12a b )d f
+--R                      + 
+--R                            5   2      4 3       3 5  2 5
+--R                        (84a b c  - 60a b c + 12a b )d f
+--R                      + 
+--R                               4   3       3 3 2      2 5        7  3 4
+--R                        (- 140a b c  + 120a b c  - 36a b c + 4a b )d f
+--R                      + 
+--R                             3   4       2 3 3        5 2     7   4 3
+--R                        (140a b c  - 120a b c  + 36a b c  - 4b c)d f
+--R                      + 
+--R                              2   5        3 4      5 3  5 2
+--R                        (- 84a b c  + 60a b c  - 12b c )d f
+--R                      + 
+--R                                6      3 5  6        7 7
+--R                        (28a b c  - 12b c )d f - 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 3 5       3 2      2 4  4 4
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  5 3
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  6 2     2 4 7
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          4     4         3        2 3  2 3
+--R                        3a b d f  + (- 12a b c - 4a b )d f
+--R                      + 
+--R                            2   2       3     5  3 2             3     3 2  4
+--R                        (18a b c  + 8a b c + b )d f  + (- 12a b c  - 4b c )d f
+--R                      + 
+--R                            4 5
+--R                        3b c d
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                               6 6         5      4 2    5
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5      6 6
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 3 5       3 2      2 4  4 4
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  5 3
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  6 2     2 4 7
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3   3      2        2  2 2          2     2   3
+--R                         - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 4
+--R                         c d
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                               +--------------+
+--R                   2   2 2                3  3        2 4  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                        7 6       6      5 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          5 2      4 2      3 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        4 3      3 2 2      2 4        6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2a b )d f
+--R                  + 
+--R                          3 4      2 2 3       4 2  4 2       2 5       2 4  5
+--R                    (- 30a c  + 24a b c  - 6a b c )d f  + (12a c  - 6a b c )d f
+--R                  + 
+--R                          6 6
+--R                    - 2a c d
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                    3   2 2      2         3  3          2 4
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                   2   2              3          2 2       3 2
+--R               (- a b f  + (2a b c - b )d f - b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                  2   2          2     2          3 2  2
+--R               (2a c f  + (- 4a c  + 2b c)d f + 2c d )x
+--R             + 
+--R                  2   2                 3           2 2       3 2
+--R               (2a b f  + (- 4a b c + 2b )d f + 2b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         ROOT
+--R                        6 6       5      4 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 2         5     2 4  5
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3   3      2        2  2 2          2     2   3     3 4
+--R                - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f + c d
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                          7   7         6         5 3    6
+--R                        4a b f  + (- 28a b c + 12a b )d f
+--R                      + 
+--R                            5   2      4 3       3 5  2 5
+--R                        (84a b c  - 60a b c + 12a b )d f
+--R                      + 
+--R                               4   3       3 3 2      2 5        7  3 4
+--R                        (- 140a b c  + 120a b c  - 36a b c + 4a b )d f
+--R                      + 
+--R                             3   4       2 3 3        5 2     7   4 3
+--R                        (140a b c  - 120a b c  + 36a b c  - 4b c)d f
+--R                      + 
+--R                              2   5        3 4      5 3  5 2
+--R                        (- 84a b c  + 60a b c  - 12b c )d f
+--R                      + 
+--R                                6      3 5  6        7 7
+--R                        (28a b c  - 12b c )d f - 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 3 5       3 2      2 4  4 4
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  5 3
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  6 2     2 4 7
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            4     4       3        2 3  2 3
+--R                        - 3a b d f  + (12a b c + 4a b )d f
+--R                      + 
+--R                              2   2       3     5  3 2           3     3 2  4
+--R                        (- 18a b c  - 8a b c - b )d f  + (12a b c  + 4b c )d f
+--R                      + 
+--R                              4 5
+--R                        - 3b c d
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                                 6 6       5      4 2    5
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5      6 6
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 3 5       3 2      2 4  4 4
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  5 3
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  6 2     2 4 7
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3   3      2        2  2 2          2     2   3
+--R                         - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 4
+--R                         c d
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                               +--------------+
+--R                   2   2 2                3  3        2 4  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                      7 6         6      5 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        5 2      4 2      3 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          4 3      3 2 2      2 4        6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2a b )d f
+--R                  + 
+--R                        3 4      2 2 3       4 2  4 2         2 5       2 4  5
+--R                    (30a c  - 24a b c  + 6a b c )d f  + (- 12a c  + 6a b c )d f
+--R                  + 
+--R                        6 6
+--R                    2a c d
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                    3   2 2      2         3  3          2 4
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                 2   2                3          2 2       3 2
+--R               (a b f  + (- 2a b c + b )d f + b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                    2   2        2     2          3 2  2
+--R               (- 2a c f  + (4a c  - 2b c)d f - 2c d )x
+--R             + 
+--R                    2   2               3           2 2       3 2
+--R               (- 2a b f  + (4a b c - 2b )d f - 2b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         ROOT
+--R                        6 6       5      4 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 2         5     2 4  5
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3   3      2        2  2 2          2     2   3     3 4
+--R                - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f + c d
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                            7   7       6         5 3    6
+--R                        - 4a b f  + (28a b c - 12a b )d f
+--R                      + 
+--R                              5   2      4 3       3 5  2 5
+--R                        (- 84a b c  + 60a b c - 12a b )d f
+--R                      + 
+--R                             4   3       3 3 2      2 5        7  3 4
+--R                        (140a b c  - 120a b c  + 36a b c - 4a b )d f
+--R                      + 
+--R                               3   4       2 3 3        5 2     7   4 3
+--R                        (- 140a b c  + 120a b c  - 36a b c  + 4b c)d f
+--R                      + 
+--R                            2   5        3 4      5 3  5 2
+--R                        (84a b c  - 60a b c  + 12b c )d f
+--R                      + 
+--R                                  6      3 5  6        7 7
+--R                        (- 28a b c  + 12b c )d f + 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 3 5       3 2      2 4  4 4
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  5 3
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  6 2     2 4 7
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          4     4         3        2 3  2 3
+--R                        3a b d f  + (- 12a b c - 4a b )d f
+--R                      + 
+--R                            2   2       3     5  3 2             3     3 2  4
+--R                        (18a b c  + 8a b c + b )d f  + (- 12a b c  - 4b c )d f
+--R                      + 
+--R                            4 5
+--R                        3b c d
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                                 6 6       5      4 2    5
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5      6 6
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 3 5       3 2      2 4  4 4
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  5 3
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  6 2     2 4 7
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3   3      2        2  2 2          2     2   3
+--R                         - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 4
+--R                         c d
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                               +--------------+
+--R                   2   2 2                3  3        2 4  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                      7 6         6      5 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        5 2      4 2      3 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          4 3      3 2 2      2 4        6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2a b )d f
+--R                  + 
+--R                        3 4      2 2 3       4 2  4 2         2 5       2 4  5
+--R                    (30a c  - 24a b c  + 6a b c )d f  + (- 12a c  + 6a b c )d f
+--R                  + 
+--R                        6 6
+--R                    2a c d
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                    3   2 2      2         3  3          2 4
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                   2   2              3          2 2       3 2
+--R               (- a b f  + (2a b c - b )d f - b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                  2   2          2     2          3 2  2
+--R               (2a c f  + (- 4a c  + 2b c)d f + 2c d )x
+--R             + 
+--R                  2   2                 3           2 2       3 2
+--R               (2a b f  + (- 4a b c + 2b )d f + 2b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         ROOT
+--R                      6 6         5      4 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 2           5     2 4  5
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3   3      2        2  2 2          2     2   3     3 4
+--R                - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f + c d
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                            7   7       6         5 3    6
+--R                        - 4a b f  + (28a b c - 12a b )d f
+--R                      + 
+--R                              5   2      4 3       3 5  2 5
+--R                        (- 84a b c  + 60a b c - 12a b )d f
+--R                      + 
+--R                             4   3       3 3 2      2 5        7  3 4
+--R                        (140a b c  - 120a b c  + 36a b c - 4a b )d f
+--R                      + 
+--R                               3   4       2 3 3        5 2     7   4 3
+--R                        (- 140a b c  + 120a b c  - 36a b c  + 4b c)d f
+--R                      + 
+--R                            2   5        3 4      5 3  5 2
+--R                        (84a b c  - 60a b c  + 12b c )d f
+--R                      + 
+--R                                  6      3 5  6        7 7
+--R                        (- 28a b c  + 12b c )d f + 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 3 5       3 2      2 4  4 4
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  5 3
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  6 2     2 4 7
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            4     4       3        2 3  2 3
+--R                        - 3a b d f  + (12a b c + 4a b )d f
+--R                      + 
+--R                              2   2       3     5  3 2           3     3 2  4
+--R                        (- 18a b c  - 8a b c - b )d f  + (12a b c  + 4b c )d f
+--R                      + 
+--R                              4 5
+--R                        - 3b c d
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                               6 6         5      4 2    5
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5      6 6
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 3 5       3 2      2 4  4 4
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  5 3
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  6 2     2 4 7
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3   3      2        2  2 2          2     2   3
+--R                         - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 4
+--R                         c d
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                               +--------------+
+--R                   2   2 2                3  3        2 4  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                        7 6       6      5 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          5 2      4 2      3 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        4 3      3 2 2      2 4        6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2a b )d f
+--R                  + 
+--R                          3 4      2 2 3       4 2  4 2       2 5       2 4  5
+--R                    (- 30a c  + 24a b c  - 6a b c )d f  + (12a c  - 6a b c )d f
+--R                  + 
+--R                          6 6
+--R                    - 2a c d
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                    3   2 2      2         3  3          2 4
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                            +--------------+
+--R                        +-+ |   2                      2      2
+--R       (- 4a f + 4c d)x\|a \|c x  + b x + a  - 4b c d x  + (4a f - 4a c d)x
+--R  /
+--R              2   2                 3           2 2       3 2
+--R           (2a b f  + (- 4a b c + 2b )d f + 2b c d )x + 4a f
+--R         + 
+--R                2        2           2 2
+--R           (- 8a c + 4a b )d f + 4a c d
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R     + 
+--R                2   2        2     2          3 2  2
+--R           (- 4a c f  + (8a c  - 4b c)d f - 4c d )x
+--R         + 
+--R                2   2               3           2 2       3 2
+--R           (- 4a b f  + (8a b c - 4b )d f - 4b c d )x - 4a f
+--R         + 
+--R              2        2           2 2
+--R           (8a c - 4a b )d f - 4a c d
+--R      *
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 269
+
+--S 270 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  3      2 2  2         2 2        2      4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f
+--R             + 
+--R                    3     2 2  2
+--R               (8a c  - 2b c )d
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- d \|a \|c x  + b x + a
+--R         + 
+--R                        3       2 3  2      2   2       3     5
+--R                   (- 4a b c + a b )f  + (8a b c  - 6a b c + b )d f
+--R                 + 
+--R                            3    3 2  2
+--R                   (- 4a b c  + b c )d
+--R              *
+--R                 x
+--R             + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +---+
+--R             \|- d
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                      6 6         5      4 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 2           5     2 4  5
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3   3      2        2  2 2          2     2   3     3 4
+--R                - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f + c d
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                          7   7         6         5 3    6
+--R                        4a b f  + (- 28a b c + 12a b )d f
+--R                      + 
+--R                            5   2      4 3       3 5  2 5
+--R                        (84a b c  - 60a b c + 12a b )d f
+--R                      + 
+--R                               4   3       3 3 2      2 5        7  3 4
+--R                        (- 140a b c  + 120a b c  - 36a b c + 4a b )d f
+--R                      + 
+--R                             3   4       2 3 3        5 2     7   4 3
+--R                        (140a b c  - 120a b c  + 36a b c  - 4b c)d f
+--R                      + 
+--R                              2   5        3 4      5 3  5 2
+--R                        (- 84a b c  + 60a b c  - 12b c )d f
+--R                      + 
+--R                                6      3 5  6        7 7
+--R                        (28a b c  - 12b c )d f - 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 3 5       3 2      2 4  4 4
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  5 3
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  6 2     2 4 7
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          4     4         3        2 3  2 3
+--R                        3a b d f  + (- 12a b c - 4a b )d f
+--R                      + 
+--R                            2   2       3     5  3 2             3     3 2  4
+--R                        (18a b c  + 8a b c + b )d f  + (- 12a b c  - 4b c )d f
+--R                      + 
+--R                            4 5
+--R                        3b c d
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                               6 6         5      4 2    5
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5      6 6
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 3 5       3 2      2 4  4 4
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  5 3
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  6 2     2 4 7
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3   3      2        2  2 2          2     2   3
+--R                         - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 4
+--R                         c d
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                               +--------------+
+--R                   2   2 2                3  3        2 4  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                        7 6       6      5 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          5 2      4 2      3 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        4 3      3 2 2      2 4        6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2a b )d f
+--R                  + 
+--R                          3 4      2 2 3       4 2  4 2       2 5       2 4  5
+--R                    (- 30a c  + 24a b c  - 6a b c )d f  + (12a c  - 6a b c )d f
+--R                  + 
+--R                          6 6
+--R                    - 2a c d
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                    3   2 2      2         3  3          2 4
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                    3      2 2  2       2 2        2      4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2b )d f
+--R             + 
+--R                      3     2 2  2
+--R               (- 8a c  + 2b c )d
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- d \|a \|c x  + b x + a
+--R         + 
+--R                      3       2 3  2        2   2       3     5
+--R                   (4a b c - a b )f  + (- 8a b c  + 6a b c - b )d f
+--R                 + 
+--R                          3    3 2  2
+--R                   (4a b c  - b c )d
+--R              *
+--R                 x
+--R             + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R              +---+
+--R             \|- d
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                        6 6       5      4 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 2         5     2 4  5
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3   3      2        2  2 2          2     2   3     3 4
+--R                - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f + c d
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                          7   7         6         5 3    6
+--R                        4a b f  + (- 28a b c + 12a b )d f
+--R                      + 
+--R                            5   2      4 3       3 5  2 5
+--R                        (84a b c  - 60a b c + 12a b )d f
+--R                      + 
+--R                               4   3       3 3 2      2 5        7  3 4
+--R                        (- 140a b c  + 120a b c  - 36a b c + 4a b )d f
+--R                      + 
+--R                             3   4       2 3 3        5 2     7   4 3
+--R                        (140a b c  - 120a b c  + 36a b c  - 4b c)d f
+--R                      + 
+--R                              2   5        3 4      5 3  5 2
+--R                        (- 84a b c  + 60a b c  - 12b c )d f
+--R                      + 
+--R                                6      3 5  6        7 7
+--R                        (28a b c  - 12b c )d f - 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 3 5       3 2      2 4  4 4
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  5 3
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  6 2     2 4 7
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            4     4       3        2 3  2 3
+--R                        - 3a b d f  + (12a b c + 4a b )d f
+--R                      + 
+--R                              2   2       3     5  3 2           3     3 2  4
+--R                        (- 18a b c  - 8a b c - b )d f  + (12a b c  + 4b c )d f
+--R                      + 
+--R                              4 5
+--R                        - 3b c d
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                                 6 6       5      4 2    5
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5      6 6
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 3 5       3 2      2 4  4 4
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  5 3
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  6 2     2 4 7
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3   3      2        2  2 2          2     2   3
+--R                         - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 4
+--R                         c d
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                               +--------------+
+--R                   2   2 2                3  3        2 4  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                      7 6         6      5 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        5 2      4 2      3 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          4 3      3 2 2      2 4        6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2a b )d f
+--R                  + 
+--R                        3 4      2 2 3       4 2  4 2         2 5       2 4  5
+--R                    (30a c  - 24a b c  + 6a b c )d f  + (- 12a c  + 6a b c )d f
+--R                  + 
+--R                        6 6
+--R                    2a c d
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                    3   2 2      2         3  3          2 4
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                  3      2 2  2         2 2        2      4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f
+--R             + 
+--R                    3     2 2  2
+--R               (8a c  - 2b c )d
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- d \|a \|c x  + b x + a
+--R         + 
+--R                        3       2 3  2      2   2       3     5
+--R                   (- 4a b c + a b )f  + (8a b c  - 6a b c + b )d f
+--R                 + 
+--R                            3    3 2  2
+--R                   (- 4a b c  + b c )d
+--R              *
+--R                 x
+--R             + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +---+
+--R             \|- d
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                        6 6       5      4 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 2         5     2 4  5
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3   3      2        2  2 2          2     2   3     3 4
+--R                - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f + c d
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            7   7       6         5 3    6
+--R                        - 4a b f  + (28a b c - 12a b )d f
+--R                      + 
+--R                              5   2      4 3       3 5  2 5
+--R                        (- 84a b c  + 60a b c - 12a b )d f
+--R                      + 
+--R                             4   3       3 3 2      2 5        7  3 4
+--R                        (140a b c  - 120a b c  + 36a b c - 4a b )d f
+--R                      + 
+--R                               3   4       2 3 3        5 2     7   4 3
+--R                        (- 140a b c  + 120a b c  - 36a b c  + 4b c)d f
+--R                      + 
+--R                            2   5        3 4      5 3  5 2
+--R                        (84a b c  - 60a b c  + 12b c )d f
+--R                      + 
+--R                                  6      3 5  6        7 7
+--R                        (- 28a b c  + 12b c )d f + 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 3 5       3 2      2 4  4 4
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  5 3
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  6 2     2 4 7
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          4     4         3        2 3  2 3
+--R                        3a b d f  + (- 12a b c - 4a b )d f
+--R                      + 
+--R                            2   2       3     5  3 2             3     3 2  4
+--R                        (18a b c  + 8a b c + b )d f  + (- 12a b c  - 4b c )d f
+--R                      + 
+--R                            4 5
+--R                        3b c d
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                                 6 6       5      4 2    5
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5      6 6
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 3 5       3 2      2 4  4 4
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  5 3
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  6 2     2 4 7
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3   3      2        2  2 2          2     2   3
+--R                         - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 4
+--R                         c d
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                               +--------------+
+--R                   2   2 2                3  3        2 4  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                      7 6         6      5 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        5 2      4 2      3 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          4 3      3 2 2      2 4        6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2a b )d f
+--R                  + 
+--R                        3 4      2 2 3       4 2  4 2         2 5       2 4  5
+--R                    (30a c  - 24a b c  + 6a b c )d f  + (- 12a c  + 6a b c )d f
+--R                  + 
+--R                        6 6
+--R                    2a c d
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                    3   2 2      2         3  3          2 4
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                    3      2 2  2       2 2        2      4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2b )d f
+--R             + 
+--R                      3     2 2  2
+--R               (- 8a c  + 2b c )d
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- d \|a \|c x  + b x + a
+--R         + 
+--R                      3       2 3  2        2   2       3     5
+--R                   (4a b c - a b )f  + (- 8a b c  + 6a b c - b )d f
+--R                 + 
+--R                          3    3 2  2
+--R                   (4a b c  - b c )d
+--R              *
+--R                 x
+--R             + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R              +---+
+--R             \|- d
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                      6 6         5      4 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 2           5     2 4  5
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3   3      2        2  2 2          2     2   3     3 4
+--R                - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f + c d
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            7   7       6         5 3    6
+--R                        - 4a b f  + (28a b c - 12a b )d f
+--R                      + 
+--R                              5   2      4 3       3 5  2 5
+--R                        (- 84a b c  + 60a b c - 12a b )d f
+--R                      + 
+--R                             4   3       3 3 2      2 5        7  3 4
+--R                        (140a b c  - 120a b c  + 36a b c - 4a b )d f
+--R                      + 
+--R                               3   4       2 3 3        5 2     7   4 3
+--R                        (- 140a b c  + 120a b c  - 36a b c  + 4b c)d f
+--R                      + 
+--R                            2   5        3 4      5 3  5 2
+--R                        (84a b c  - 60a b c  + 12b c )d f
+--R                      + 
+--R                                  6      3 5  6        7 7
+--R                        (- 28a b c  + 12b c )d f + 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 3 5       3 2      2 4  4 4
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  5 3
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  6 2     2 4 7
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            4     4       3        2 3  2 3
+--R                        - 3a b d f  + (12a b c + 4a b )d f
+--R                      + 
+--R                              2   2       3     5  3 2           3     3 2  4
+--R                        (- 18a b c  - 8a b c - b )d f  + (12a b c  + 4b c )d f
+--R                      + 
+--R                              4 5
+--R                        - 3b c d
+--R                   *
+--R                      x
+--R               *
+--R                   +-+
+--R                  \|a
+--R               *
+--R                  ROOT
+--R                               6 6         5      4 2    5
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5      6 6
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 3 5       3 2      2 4  4 4
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  5 3
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  6 2     2 4 7
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3   3      2        2  2 2          2     2   3
+--R                         - a d f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 4
+--R                         c d
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                               +--------------+
+--R                   2   2 2                3  3        2 4  +-+ |   2
+--R                (3a b d f  + (- 6a b c - b )d f + 3b c d )\|a \|c x  + b x + a
+--R              + 
+--R                        7 6       6      5 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          5 2      4 2      3 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        4 3      3 2 2      2 4        6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2a b )d f
+--R                  + 
+--R                          3 4      2 2 3       4 2  4 2       2 5       2 4  5
+--R                    (- 30a c  + 24a b c  - 6a b c )d f  + (12a c  - 6a b c )d f
+--R                  + 
+--R                          6 6
+--R                    - 2a c d
+--R               *
+--R                  x
+--R               *
+--R                  ROOT
+--R                             4 2 3 5       3 2      2 4  4 4
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  5 3
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  6 2     2 4 7
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                    3   2 2      2         3  3          2 4
+--R                - 3a b d f  + (6a b c + a b )d f - 3a b c d
+--R           /
+--R              x
+--R     + 
+--R                             3   +---+ +-+ +-+
+--R               (- 8a b c + 2b )d\|- d \|a \|f
+--R             + 
+--R                   2        2              2     2   2  +-+
+--R               ((8a c - 2a b )d f + (- 8a c  + 2b c)d )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                 2     4          2          3    +---+ +-+
+--R           ((4a b c - b )d x + (8a b c - 2a b )d)\|- d \|f
+--R         + 
+--R                 2         3              2    3   2          3      2 2
+--R           ((- 4a b c + a b )d f + (4a b c  - b c)d )x + (- 8a c + 2a b )d f
+--R         + 
+--R              2 2       2   2
+--R           (8a c  - 2a b c)d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                             3   +---+ +-+ +-+
+--R               (- 8a b c + 2b )d\|- d \|a \|f
+--R             + 
+--R                     2        2            2     2   2  +-+
+--R               ((- 8a c + 2a b )d f + (8a c  - 2b c)d )\|a
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                 2     4          2          3    +---+ +-+
+--R           ((4a b c - b )d x + (8a b c - 2a b )d)\|- d \|f
+--R         + 
+--R               2         3                2    3   2        3      2 2
+--R           ((4a b c - a b )d f + (- 4a b c  + b c)d )x + (8a c - 2a b )d f
+--R         + 
+--R                2 2       2   2
+--R           (- 8a c  + 2a b c)d
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                                     +--------------+
+--R              2                +---+ |   2
+--R           (8a b f + 8a b c d)\|- d \|c x  + b x + a
+--R         + 
+--R                   2      2          2                +---+ +-+
+--R           ((- 4a b f - 4b c d)x - 8a b f - 8a b c d)\|- d \|a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                 3      2 2  2         2 2        2      4
+--R             (16a c - 4a b )f  + (- 32a c  + 24a b c - 4b )d f
+--R           + 
+--R                   3     2 2  2
+--R             (16a c  - 4b c )d
+--R        *
+--R                      +--------------+
+--R            +---+ +-+ |   2
+--R           \|- d \|a \|c x  + b x + a
+--R       + 
+--R                      3        2 3  2       2   2        3      5
+--R                 (- 8a b c + 2a b )f  + (16a b c  - 12a b c + 2b )d f
+--R               + 
+--R                          3     3 2  2
+--R                 (- 8a b c  + 2b c )d
+--R            *
+--R               x
+--R           + 
+--R                   4      3 2  2       3 2      2 2        4
+--R             (- 16a c + 4a b )f  + (32a c  - 24a b c + 4a b )d f
+--R           + 
+--R                   2 3       2 2  2
+--R             (- 16a c  + 4a b c )d
+--R        *
+--R            +---+
+--R           \|- d
+--R    *
+--R        +-------------------------+ +-----------------------+
+--R        |    +---+ +-+              |  +---+ +-+
+--R       \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 270
+
+--S 271 of 1580
+--d0:=D(m0,x)
+--E 271
+
+)clear all
+
+--S 272 of 1580
+t0:=x/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                        x
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 1580
+r0:=2*(a*(2*c^2*d+b^2*f-2*a*c*f)+b*c*(c*d+a*f)*x)/((b^2-4*a*c)*(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))-1/2*atan(1/2*(b*sqrt(-d)+_
+   2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))))*sqrt(f)*(c*d-a*f+b*sqrt(-d)*sqrt(f))/((c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*sqrt(f)*(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R              2       2            2    2     +-+                3   +---+
+--R         (((4a c - a b )f + (- 4a c  + b c)d)\|f  + (- 4a b c + b )f\|- d )
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R              2       2            2    2     +-+              3   +---+
+--R         (((4a c - a b )f + (- 4a c  + b c)d)\|f  + (4a b c - b )f\|- d )
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                            2         2        2         2
+--R         ((- 4a b c f - 4b c d)x + (8a c - 4a b )f - 8a c d)
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R           3      2 2  2         2 2        2      4            3     2 2  2
+--R       ((8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f + (8a c  - 2b c )d )
+--R    *
+--R        +--------------+ +-------------------------+ +-----------------------+
+--R        |   2            |    +---+ +-+              |  +---+ +-+
+--R       \|c x  + b x + a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 273
+
+--S 274 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   2   2              3          2 2       3 2
+--R               (- a b f  + (2a b c - b )d f - b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R              3   2        2 2       2            3 2  2
+--R           (2a c f  + (- 4a c  + 2a b c)d f + 2a c d )x
+--R         + 
+--R              3   2        2          3             2 2       4 2
+--R           (2a b f  + (- 4a b c + 2a b )d f + 2a b c d )x + 2a f
+--R         + 
+--R                3      2 2         2 2 2
+--R           (- 4a c + 2a b )d f + 2a c d
+--R      *
+--R         ROOT
+--R                      6 6         5      4 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 2           5     2 4  5
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2   7       3 2      2 4  2 6
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  3 5
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  4 4     2 4 5 3
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                 3 4        2        2    3        2     2   2 2    3 3
+--R                a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                          8 8         7      6 2    7       6 2      5 2   2 6
+--R                        2a f  + (- 16a c + 4a b )d f  + (56a c  - 24a b c)d f
+--R                      + 
+--R                               5 3      4 2 2     2 6  3 5
+--R                        (- 112a c  + 60a b c  - 4a b )d f
+--R                      + 
+--R                             4 4      3 2 3       6      8  4 4
+--R                        (140a c  - 80a b c  + 8a b c - 2b )d f
+--R                      + 
+--R                               3 5      2 2 4     6 2  5 3
+--R                        (- 112a c  + 60a b c  - 4b c )d f
+--R                      + 
+--R                            2 6        2 5  6 2           7     2 6  7      8 8
+--R                        (56a c  - 24a b c )d f  + (- 16a c  + 4b c )d f + 2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          3 2   5         2 2        4  2 4
+--R                        6a b d f  + (- 18a b c - 2a b )d f
+--R                      + 
+--R                              2 2     4   3 3     2 3 4 2
+--R                        (18a b c  + 2b c)d f  - 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6 6         5      4 2    5
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5      6 6
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2   7       3 2      2 4  2 6
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  3 5
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  4 4     2 4 5 3
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                        3 4        2        2    3        2     2   2 2    3 3
+--R                       a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                              +--------------+
+--R                   2     4                3  2 3       2 3 2  |   2
+--R                (3a b d f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                          6 7         5      4 2    6
+--R                        2a f  + (- 12a c + 6a b )d f
+--R                      + 
+--R                            4 2      3 2      2 4  2 5
+--R                        (30a c  - 24a b c + 6a b )d f
+--R                      + 
+--R                              3 3      2 2 2        4      6  3 4
+--R                        (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                      + 
+--R                            2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                        (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                      + 
+--R                          6 6
+--R                        2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2     4              3  2 3       2 3 2
+--R                    - 3a b d f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                 2   2                3          2 2       3 2
+--R               (a b f  + (- 2a b c + b )d f + b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                3   2      2 2       2            3 2  2
+--R           (- 2a c f  + (4a c  - 2a b c)d f - 2a c d )x
+--R         + 
+--R                3   2      2          3             2 2       4 2
+--R           (- 2a b f  + (4a b c - 2a b )d f - 2a b c d )x - 2a f
+--R         + 
+--R              3      2 2         2 2 2
+--R           (4a c - 2a b )d f - 2a c d
+--R      *
+--R         ROOT
+--R                        6 6       5      4 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 2         5     2 4  5
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2   7       3 2      2 4  2 6
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  3 5
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  4 4     2 4 5 3
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                 3 4        2        2    3        2     2   2 2    3 3
+--R                a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                          8 8         7      6 2    7       6 2      5 2   2 6
+--R                        2a f  + (- 16a c + 4a b )d f  + (56a c  - 24a b c)d f
+--R                      + 
+--R                               5 3      4 2 2     2 6  3 5
+--R                        (- 112a c  + 60a b c  - 4a b )d f
+--R                      + 
+--R                             4 4      3 2 3       6      8  4 4
+--R                        (140a c  - 80a b c  + 8a b c - 2b )d f
+--R                      + 
+--R                               3 5      2 2 4     6 2  5 3
+--R                        (- 112a c  + 60a b c  - 4b c )d f
+--R                      + 
+--R                            2 6        2 5  6 2           7     2 6  7      8 8
+--R                        (56a c  - 24a b c )d f  + (- 16a c  + 4b c )d f + 2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            3 2   5       2 2        4  2 4
+--R                        - 6a b d f  + (18a b c + 2a b )d f
+--R                      + 
+--R                                2 2     4   3 3     2 3 4 2
+--R                        (- 18a b c  - 2b c)d f  + 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6 6       5      4 2    5
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5      6 6
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2   7       3 2      2 4  2 6
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  3 5
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  4 4     2 4 5 3
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                        3 4        2        2    3        2     2   2 2    3 3
+--R                       a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                              +--------------+
+--R                   2     4                3  2 3       2 3 2  |   2
+--R                (3a b d f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                            6 7       5      4 2    6
+--R                        - 2a f  + (12a c - 6a b )d f
+--R                      + 
+--R                              4 2      3 2      2 4  2 5
+--R                        (- 30a c  + 24a b c - 6a b )d f
+--R                      + 
+--R                            3 3      2 2 2        4      6  3 4
+--R                        (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                      + 
+--R                              2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                        (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                      + 
+--R                            6 6
+--R                        - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2     4              3  2 3       2 3 2
+--R                    - 3a b d f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                   2   2              3          2 2       3 2
+--R               (- a b f  + (2a b c - b )d f - b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R              3   2        2 2       2            3 2  2
+--R           (2a c f  + (- 4a c  + 2a b c)d f + 2a c d )x
+--R         + 
+--R              3   2        2          3             2 2       4 2
+--R           (2a b f  + (- 4a b c + 2a b )d f + 2a b c d )x + 2a f
+--R         + 
+--R                3      2 2         2 2 2
+--R           (- 4a c + 2a b )d f + 2a c d
+--R      *
+--R         ROOT
+--R                        6 6       5      4 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 2         5     2 4  5
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2   7       3 2      2 4  2 6
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  3 5
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  4 4     2 4 5 3
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                 3 4        2        2    3        2     2   2 2    3 3
+--R                a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                            8 8       7      6 2    7         6 2      5 2   2 6
+--R                        - 2a f  + (16a c - 4a b )d f  + (- 56a c  + 24a b c)d f
+--R                      + 
+--R                             5 3      4 2 2     2 6  3 5
+--R                        (112a c  - 60a b c  + 4a b )d f
+--R                      + 
+--R                               4 4      3 2 3       6      8  4 4
+--R                        (- 140a c  + 80a b c  - 8a b c + 2b )d f
+--R                      + 
+--R                             3 5      2 2 4     6 2  5 3
+--R                        (112a c  - 60a b c  + 4b c )d f
+--R                      + 
+--R                              2 6        2 5  6 2         7     2 6  7      8 8
+--R                        (- 56a c  + 24a b c )d f  + (16a c  - 4b c )d f - 2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          3 2   5         2 2        4  2 4
+--R                        6a b d f  + (- 18a b c - 2a b )d f
+--R                      + 
+--R                              2 2     4   3 3     2 3 4 2
+--R                        (18a b c  + 2b c)d f  - 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6 6       5      4 2    5
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5      6 6
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2   7       3 2      2 4  2 6
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  3 5
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  4 4     2 4 5 3
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                        3 4        2        2    3        2     2   2 2    3 3
+--R                       a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                              +--------------+
+--R                   2     4                3  2 3       2 3 2  |   2
+--R                (3a b d f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                            6 7       5      4 2    6
+--R                        - 2a f  + (12a c - 6a b )d f
+--R                      + 
+--R                              4 2      3 2      2 4  2 5
+--R                        (- 30a c  + 24a b c - 6a b )d f
+--R                      + 
+--R                            3 3      2 2 2        4      6  3 4
+--R                        (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                      + 
+--R                              2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                        (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                      + 
+--R                            6 6
+--R                        - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2     4              3  2 3       2 3 2
+--R                    - 3a b d f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                 2   2                3          2 2       3 2
+--R               (a b f  + (- 2a b c + b )d f + b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                3   2      2 2       2            3 2  2
+--R           (- 2a c f  + (4a c  - 2a b c)d f - 2a c d )x
+--R         + 
+--R                3   2      2          3             2 2       4 2
+--R           (- 2a b f  + (4a b c - 2a b )d f - 2a b c d )x - 2a f
+--R         + 
+--R              3      2 2         2 2 2
+--R           (4a c - 2a b )d f - 2a c d
+--R      *
+--R         ROOT
+--R                      6 6         5      4 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 2           5     2 4  5
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2   7       3 2      2 4  2 6
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  3 5
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  4 4     2 4 5 3
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                 3 4        2        2    3        2     2   2 2    3 3
+--R                a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                            8 8       7      6 2    7         6 2      5 2   2 6
+--R                        - 2a f  + (16a c - 4a b )d f  + (- 56a c  + 24a b c)d f
+--R                      + 
+--R                             5 3      4 2 2     2 6  3 5
+--R                        (112a c  - 60a b c  + 4a b )d f
+--R                      + 
+--R                               4 4      3 2 3       6      8  4 4
+--R                        (- 140a c  + 80a b c  - 8a b c + 2b )d f
+--R                      + 
+--R                             3 5      2 2 4     6 2  5 3
+--R                        (112a c  - 60a b c  + 4b c )d f
+--R                      + 
+--R                              2 6        2 5  6 2         7     2 6  7      8 8
+--R                        (- 56a c  + 24a b c )d f  + (16a c  - 4b c )d f - 2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            3 2   5       2 2        4  2 4
+--R                        - 6a b d f  + (18a b c + 2a b )d f
+--R                      + 
+--R                                2 2     4   3 3     2 3 4 2
+--R                        (- 18a b c  - 2b c)d f  + 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6 6         5      4 2    5
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5      6 6
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2   7       3 2      2 4  2 6
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  3 5
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  4 4     2 4 5 3
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                        3 4        2        2    3        2     2   2 2    3 3
+--R                       a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                              +--------------+
+--R                   2     4                3  2 3       2 3 2  |   2
+--R                (3a b d f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                          6 7         5      4 2    6
+--R                        2a f  + (- 12a c + 6a b )d f
+--R                      + 
+--R                            4 2      3 2      2 4  2 5
+--R                        (30a c  - 24a b c + 6a b )d f
+--R                      + 
+--R                              3 3      2 2 2        4      6  3 4
+--R                        (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                      + 
+--R                            2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                        (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                      + 
+--R                          6 6
+--R                        2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2     4              3  2 3       2 3 2
+--R                    - 3a b d f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                +--------------+
+--R                |   2                             2   2             +-+
+--R       4a b f x\|c x  + b x + a  + ((- 4a c f + 4c d)x  - 4a b f x)\|a
+--R  /
+--R              2   2                 3           2 2       3 2
+--R           (2a b f  + (- 4a b c + 2b )d f + 2b c d )x + 4a f
+--R         + 
+--R                2        2           2 2
+--R           (- 8a c + 4a b )d f + 4a c d
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R            3   2      2 2       2            3 2  2
+--R       (- 4a c f  + (8a c  - 4a b c)d f - 4a c d )x
+--R     + 
+--R            3   2      2          3             2 2       4 2
+--R       (- 4a b f  + (8a b c - 4a b )d f - 4a b c d )x - 4a f
+--R     + 
+--R          3      2 2         2 2 2
+--R       (8a c - 4a b )d f - 4a c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 274
+
+--S 275 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      3       2 3  2        2   2       3     5
+--R                   (4a b c - a b )f  + (- 8a b c  + 6a b c - b )d f
+--R                 + 
+--R                          3    3 2  2
+--R                   (4a b c  - b c )d
+--R              *
+--R                 x
+--R             + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                      6 6         5      4 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 2           5     2 4  5
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2   7       3 2      2 4  2 6
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  3 5
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  4 4     2 4 5 3
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                 3 4        2        2    3        2     2   2 2    3 3
+--R                a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                          8 8         7      6 2    7       6 2      5 2   2 6
+--R                        2a f  + (- 16a c + 4a b )d f  + (56a c  - 24a b c)d f
+--R                      + 
+--R                               5 3      4 2 2     2 6  3 5
+--R                        (- 112a c  + 60a b c  - 4a b )d f
+--R                      + 
+--R                             4 4      3 2 3       6      8  4 4
+--R                        (140a c  - 80a b c  + 8a b c - 2b )d f
+--R                      + 
+--R                               3 5      2 2 4     6 2  5 3
+--R                        (- 112a c  + 60a b c  - 4b c )d f
+--R                      + 
+--R                            2 6        2 5  6 2           7     2 6  7      8 8
+--R                        (56a c  - 24a b c )d f  + (- 16a c  + 4b c )d f + 2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          3 2   5         2 2        4  2 4
+--R                        6a b d f  + (- 18a b c - 2a b )d f
+--R                      + 
+--R                              2 2     4   3 3     2 3 4 2
+--R                        (18a b c  + 2b c)d f  - 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6 6         5      4 2    5
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5      6 6
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2   7       3 2      2 4  2 6
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  3 5
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  4 4     2 4 5 3
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                        3 4        2        2    3        2     2   2 2    3 3
+--R                       a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                              +--------------+
+--R                   2     4                3  2 3       2 3 2  |   2
+--R                (3a b d f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                          6 7         5      4 2    6
+--R                        2a f  + (- 12a c + 6a b )d f
+--R                      + 
+--R                            4 2      3 2      2 4  2 5
+--R                        (30a c  - 24a b c + 6a b )d f
+--R                      + 
+--R                              3 3      2 2 2        4      6  3 4
+--R                        (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                      + 
+--R                            2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                        (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                      + 
+--R                          6 6
+--R                        2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2     4              3  2 3       2 3 2
+--R                    - 3a b d f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        3       2 3  2      2   2       3     5
+--R                   (- 4a b c + a b )f  + (8a b c  - 6a b c + b )d f
+--R                 + 
+--R                            3    3 2  2
+--R                   (- 4a b c  + b c )d
+--R              *
+--R                 x
+--R             + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                        6 6       5      4 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 2         5     2 4  5
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2   7       3 2      2 4  2 6
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  3 5
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  4 4     2 4 5 3
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                 3 4        2        2    3        2     2   2 2    3 3
+--R                a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                          8 8         7      6 2    7       6 2      5 2   2 6
+--R                        2a f  + (- 16a c + 4a b )d f  + (56a c  - 24a b c)d f
+--R                      + 
+--R                               5 3      4 2 2     2 6  3 5
+--R                        (- 112a c  + 60a b c  - 4a b )d f
+--R                      + 
+--R                             4 4      3 2 3       6      8  4 4
+--R                        (140a c  - 80a b c  + 8a b c - 2b )d f
+--R                      + 
+--R                               3 5      2 2 4     6 2  5 3
+--R                        (- 112a c  + 60a b c  - 4b c )d f
+--R                      + 
+--R                            2 6        2 5  6 2           7     2 6  7      8 8
+--R                        (56a c  - 24a b c )d f  + (- 16a c  + 4b c )d f + 2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            3 2   5       2 2        4  2 4
+--R                        - 6a b d f  + (18a b c + 2a b )d f
+--R                      + 
+--R                                2 2     4   3 3     2 3 4 2
+--R                        (- 18a b c  - 2b c)d f  + 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6 6       5      4 2    5
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5      6 6
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2   7       3 2      2 4  2 6
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  3 5
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  4 4     2 4 5 3
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                        3 4        2        2    3        2     2   2 2    3 3
+--R                       a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                              +--------------+
+--R                   2     4                3  2 3       2 3 2  |   2
+--R                (3a b d f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                            6 7       5      4 2    6
+--R                        - 2a f  + (12a c - 6a b )d f
+--R                      + 
+--R                              4 2      3 2      2 4  2 5
+--R                        (- 30a c  + 24a b c - 6a b )d f
+--R                      + 
+--R                            3 3      2 2 2        4      6  3 4
+--R                        (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                      + 
+--R                              2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                        (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                      + 
+--R                            6 6
+--R                        - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2     4              3  2 3       2 3 2
+--R                    - 3a b d f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                      3       2 3  2        2   2       3     5
+--R                   (4a b c - a b )f  + (- 8a b c  + 6a b c - b )d f
+--R                 + 
+--R                          3    3 2  2
+--R                   (4a b c  - b c )d
+--R              *
+--R                 x
+--R             + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                        6 6       5      4 2    5
+--R                    - 2a f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  2 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  3 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  4 2         5     2 4  5
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 6
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2   7       3 2      2 4  2 6
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  3 5
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  4 4     2 4 5 3
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                 3 4        2        2    3        2     2   2 2    3 3
+--R                a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            8 8       7      6 2    7         6 2      5 2   2 6
+--R                        - 2a f  + (16a c - 4a b )d f  + (- 56a c  + 24a b c)d f
+--R                      + 
+--R                             5 3      4 2 2     2 6  3 5
+--R                        (112a c  - 60a b c  + 4a b )d f
+--R                      + 
+--R                               4 4      3 2 3       6      8  4 4
+--R                        (- 140a c  + 80a b c  - 8a b c + 2b )d f
+--R                      + 
+--R                             3 5      2 2 4     6 2  5 3
+--R                        (112a c  - 60a b c  + 4b c )d f
+--R                      + 
+--R                              2 6        2 5  6 2         7     2 6  7      8 8
+--R                        (- 56a c  + 24a b c )d f  + (16a c  - 4b c )d f - 2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          3 2   5         2 2        4  2 4
+--R                        6a b d f  + (- 18a b c - 2a b )d f
+--R                      + 
+--R                              2 2     4   3 3     2 3 4 2
+--R                        (18a b c  + 2b c)d f  - 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6 6       5      4 2    5
+--R                             - 2a f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  2 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  3 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  4 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  5      6 6
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2   7       3 2      2 4  2 6
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  3 5
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  4 4     2 4 5 3
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                        3 4        2        2    3        2     2   2 2    3 3
+--R                       a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                              +--------------+
+--R                   2     4                3  2 3       2 3 2  |   2
+--R                (3a b d f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                            6 7       5      4 2    6
+--R                        - 2a f  + (12a c - 6a b )d f
+--R                      + 
+--R                              4 2      3 2      2 4  2 5
+--R                        (- 30a c  + 24a b c - 6a b )d f
+--R                      + 
+--R                            3 3      2 2 2        4      6  3 4
+--R                        (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                      + 
+--R                              2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                        (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                      + 
+--R                            6 6
+--R                        - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2     4              3  2 3       2 3 2
+--R                    - 3a b d f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                        3       2 3  2      2   2       3     5
+--R                   (- 4a b c + a b )f  + (8a b c  - 6a b c + b )d f
+--R                 + 
+--R                            3    3 2  2
+--R                   (- 4a b c  + b c )d
+--R              *
+--R                 x
+--R             + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                      6 6         5      4 2    5
+--R                    2a f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  2 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  3 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  4 2           5     2 4  5
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 6
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2   7       3 2      2 4  2 6
+--R                         - 9a b d f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  3 5
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  4 4     2 4 5 3
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12 12         11       10 2    11
+--R                         4a  f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  2 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  3 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            4 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            5 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            6 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            7 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            8 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  9 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                       + 
+--R                              2 10         2 9      4 8  10 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  11      12 12
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                 3 4        2        2    3        2     2   2 2    3 3
+--R                a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R           /
+--R                 6 6        5      4 2    5       4 2      3 2      2 4  2 4
+--R                a f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  3 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  4 2          5     2 4  5     6 6
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            8 8       7      6 2    7         6 2      5 2   2 6
+--R                        - 2a f  + (16a c - 4a b )d f  + (- 56a c  + 24a b c)d f
+--R                      + 
+--R                             5 3      4 2 2     2 6  3 5
+--R                        (112a c  - 60a b c  + 4a b )d f
+--R                      + 
+--R                               4 4      3 2 3       6      8  4 4
+--R                        (- 140a c  + 80a b c  - 8a b c + 2b )d f
+--R                      + 
+--R                             3 5      2 2 4     6 2  5 3
+--R                        (112a c  - 60a b c  + 4b c )d f
+--R                      + 
+--R                              2 6        2 5  6 2         7     2 6  7      8 8
+--R                        (- 56a c  + 24a b c )d f  + (16a c  - 4b c )d f - 2c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            3 2   5       2 2        4  2 4
+--R                        - 6a b d f  + (18a b c + 2a b )d f
+--R                      + 
+--R                                2 2     4   3 3     2 3 4 2
+--R                        (- 18a b c  - 2b c)d f  + 6b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6 6         5      4 2    5
+--R                             2a f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  2 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  3 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  4 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  5      6 6
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2   7       3 2      2 4  2 6
+--R                                  - 9a b d f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  3 5
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  4 4     2 4 5 3
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12 12         11       10 2    11
+--R                                  4a  f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  2 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     3 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     4 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     5 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     6 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     7 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     8 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     9 3
+--R                                    d f
+--R                                + 
+--R                                       2 10         2 9      4 8  10 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  11      12 12
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                        3 4        2        2    3        2     2   2 2    3 3
+--R                       a f  + (- 3a c - 3a b )d f  + (3a c  + 3b c)d f  - c d f
+--R                    /
+--R                          6 6        5      4 2    5
+--R                         a f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  2 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  3 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  4 2          5     2 4  5
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 6
+--R                         c d
+--R              + 
+--R                                                              +--------------+
+--R                   2     4                3  2 3       2 3 2  |   2
+--R                (3a b d f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                          6 7         5      4 2    6
+--R                        2a f  + (- 12a c + 6a b )d f
+--R                      + 
+--R                            4 2      3 2      2 4  2 5
+--R                        (30a c  - 24a b c + 6a b )d f
+--R                      + 
+--R                              3 3      2 2 2        4      6  3 4
+--R                        (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                      + 
+--R                            2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                        (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                      + 
+--R                          6 6
+--R                        2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2   7       3 2      2 4  2 6
+--R                             - 9a b d f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  3 5
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  4 4     2 4 5 3
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12 12         11       10 2    11
+--R                             4a  f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  2 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  3 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                4 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                5 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                6 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                7 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                8 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  9 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d f
+--R                           + 
+--R                                  2 10         2 9      4 8  10 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  11      12 12
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2     4              3  2 3       2 3 2
+--R                    - 3a b d f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                     3      2 2        2 2       2     +-+
+--R               ((- 8a c + 2a b )f + (8a c  - 2a b c)d)\|f
+--R             + 
+--R                  2          3   +---+
+--R               (8a b c - 2a b )f\|- d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   2         3              2    3           3      2 2
+--R               ((4a b c - a b )f + (- 4a b c  + b c)d)x + (8a c - 2a b )f
+--R             + 
+--R                    2 2       2
+--R               (- 8a c  + 2a b c)d
+--R          *
+--R              +-+ +-+
+--R             \|a \|f
+--R         + 
+--R                   2     4            2          3    +---+ +-+
+--R           ((- 4a b c + b )f x + (- 8a b c + 2a b )f)\|- d \|a
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                     3      2 2        2 2       2     +-+
+--R               ((- 8a c + 2a b )f + (8a c  - 2a b c)d)\|f
+--R             + 
+--R                    2          3   +---+
+--R               (- 8a b c + 2a b )f\|- d
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   2         3              2    3           3      2 2
+--R               ((4a b c - a b )f + (- 4a b c  + b c)d)x + (8a c - 2a b )f
+--R             + 
+--R                    2 2       2
+--R               (- 8a c  + 2a b c)d
+--R          *
+--R              +-+ +-+
+--R             \|a \|f
+--R         + 
+--R                 2     4          2          3    +---+ +-+
+--R           ((4a b c - b )f x + (8a b c - 2a b )f)\|- d \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                                            +--------------+
+--R                2        2          2   +-+ |   2
+--R           ((16a c - 8a b )f - 16a c d)\|a \|c x  + b x + a
+--R         + 
+--R                 2          3           2            3      2 2        2 2
+--R           ((- 8a b c + 4a b )f + 8a b c d)x + (- 16a c + 8a b )f + 16a c d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                 4      3 2  2         3 2      2 2        4
+--R             (16a c - 4a b )f  + (- 32a c  + 24a b c - 4a b )d f
+--R           + 
+--R                 2 3       2 2  2
+--R             (16a c  - 4a b c )d
+--R        *
+--R            +--------------+
+--R            |   2
+--R           \|c x  + b x + a
+--R       + 
+--R                      3        2 3  2       2   2        3      5
+--R                 (- 8a b c + 2a b )f  + (16a b c  - 12a b c + 2b )d f
+--R               + 
+--R                          3     3 2  2
+--R                 (- 8a b c  + 2b c )d
+--R            *
+--R               x
+--R           + 
+--R                   4      3 2  2       3 2      2 2        4
+--R             (- 16a c + 4a b )f  + (32a c  - 24a b c + 4a b )d f
+--R           + 
+--R                   2 3       2 2  2
+--R             (- 16a c  + 4a b c )d
+--R        *
+--R            +-+
+--R           \|a
+--R    *
+--R        +-------------------------+ +-----------------------+
+--R        |    +---+ +-+              |  +---+ +-+
+--R       \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 1580
+--d0:=D(m0,x)
+--E 276
+
+)clear all
+
+--S 277 of 1580
+t0:=1/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                        1
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 1580
+r0:=-2*(b*(c^2*d+b^2*f-3*a*c*f)+c*(2*c^2*d+b^2*f-2*a*c*f)*x)/((b^2-4*a*c)*_
+   (c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))-1/2*f*atan(1/2*_
+   (b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*((c*d-a*f)/sqrt(-d)+b*sqrt(f))/_
+   ((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*f*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*((-c*d+a*f)/_
+   sqrt(-d)+b*sqrt(f))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                       3   +---+ +-+      2       2  2          2    2
+--R         ((- 4a b c + b )f\|- d \|f  + (4a c - a b )f  + (- 4a c  + b c)d f)
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                       3   +---+ +-+        2       2  2        2    2
+--R         ((- 4a b c + b )f\|- d \|f  + (- 4a c + a b )f  + (4a c  - b c)d f)
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                  2     2        3                     3         2   +---+
+--R         (((- 8a c  + 4b c)f + 8c d)x + (- 12a b c + 4b )f + 4b c d)\|- d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R           3      2 2  2         2 2        2      4            3     2 2  2
+--R       ((8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f + (8a c  - 2b c )d )
+--R    *
+--R              +--------------+ +-------------------------+
+--R        +---+ |   2            |    +---+ +-+
+--R       \|- d \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   2   2              3          2 2       3 2
+--R               (- a b f  + (2a b c - b )d f - b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R              3   2        2 2       2            3 2  2
+--R           (2a c f  + (- 4a c  + 2a b c)d f + 2a c d )x
+--R         + 
+--R              3   2        2          3             2 2       4 2
+--R           (2a b f  + (- 4a b c + 2a b )d f + 2a b c d )x + 2a f
+--R         + 
+--R                3      2 2         2 2 2
+--R           (- 4a c + 2a b )d f + 2a c d
+--R      *
+--R         ROOT
+--R                      6   6         5      4 2  2 5
+--R                    2a d f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  3 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  4 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  5 2           5     2 4  6
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 7
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2 9       3 2      2 4    8
+--R                         - 9a b f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  2 7
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  3 6     2 4 4 5
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12   12         11       10 2  2 11
+--R                         4a  d f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  3 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  4 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            9 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  10 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                       + 
+--R                              2 10         2 9      4 8  11 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  12      12 13
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3 5      2        2    4          2     2   2 3    3 3 2
+--R                - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f  + c d f
+--R           /
+--R                 6   6        5      4 2  2 5       4 2      3 2      2 4  3 4
+--R                a d f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  4 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  5 2          5     2 4  6     6 7
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                          7     7         6         5 3  2 6
+--R                        4a b d f  + (- 28a b c + 12a b )d f
+--R                      + 
+--R                            5   2      4 3       3 5  3 5
+--R                        (84a b c  - 60a b c + 12a b )d f
+--R                      + 
+--R                               4   3       3 3 2      2 5        7  4 4
+--R                        (- 140a b c  + 120a b c  - 36a b c + 4a b )d f
+--R                      + 
+--R                             3   4       2 3 3        5 2     7   5 3
+--R                        (140a b c  - 120a b c  + 36a b c  - 4b c)d f
+--R                      + 
+--R                              2   5        3 4      5 3  6 2
+--R                        (- 84a b c  + 60a b c  - 12b c )d f
+--R                      + 
+--R                                6      3 5  7        7 8
+--R                        (28a b c  - 12b c )d f - 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          4   6         3        2 3    5
+--R                        3a b f  + (- 12a b c - 4a b )d f
+--R                      + 
+--R                            2   2       3     5  2 4             3     3 2  3 3
+--R                        (18a b c  + 8a b c + b )d f  + (- 12a b c  - 4b c )d f
+--R                      + 
+--R                            4 4 2
+--R                        3b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   6         5      4 2  2 5
+--R                             2a d f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  3 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  4 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  5 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  6      6 7
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 9       3 2      2 4    8
+--R                                  - 9a b f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  2 7
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  3 6     2 4 4 5
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12   12         11       10 2  2 11
+--R                                  4a  d f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  3 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     10 3
+--R                                    d  f
+--R                                + 
+--R                                       2 10         2 9      4 8  11 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  12      12 13
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3 5      2        2    4          2     2   2 3
+--R                         - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 3 2
+--R                         c d f
+--R                    /
+--R                          6   6        5      4 2  2 5
+--R                         a d f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  3 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  4 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  5 2          5     2 4  6
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 7
+--R                         c d
+--R              + 
+--R                                                            +--------------+
+--R                   2   5                3    4       2 2 3  |   2
+--R                (3a b f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                            6 7       5      4 2    6
+--R                        - 2a f  + (12a c - 6a b )d f
+--R                      + 
+--R                              4 2      3 2      2 4  2 5
+--R                        (- 30a c  + 24a b c - 6a b )d f
+--R                      + 
+--R                            3 3      2 2 2        4      6  3 4
+--R                        (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                      + 
+--R                              2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                        (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                      + 
+--R                            6 6
+--R                        - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2   5              3    4       2 2 3
+--R                    - 3a b f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                 2   2                3          2 2       3 2
+--R               (a b f  + (- 2a b c + b )d f + b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                3   2      2 2       2            3 2  2
+--R           (- 2a c f  + (4a c  - 2a b c)d f - 2a c d )x
+--R         + 
+--R                3   2      2          3             2 2       4 2
+--R           (- 2a b f  + (4a b c - 2a b )d f - 2a b c d )x - 2a f
+--R         + 
+--R              3      2 2         2 2 2
+--R           (4a c - 2a b )d f - 2a c d
+--R      *
+--R         ROOT
+--R                        6   6       5      4 2  2 5
+--R                    - 2a d f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  3 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  4 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  5 2         5     2 4  6
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 7
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2 9       3 2      2 4    8
+--R                         - 9a b f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  2 7
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  3 6     2 4 4 5
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12   12         11       10 2  2 11
+--R                         4a  d f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  3 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  4 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            9 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  10 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                       + 
+--R                              2 10         2 9      4 8  11 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  12      12 13
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3 5      2        2    4          2     2   2 3    3 3 2
+--R                - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f  + c d f
+--R           /
+--R                 6   6        5      4 2  2 5       4 2      3 2      2 4  3 4
+--R                a d f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  4 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  5 2          5     2 4  6     6 7
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                          7     7         6         5 3  2 6
+--R                        4a b d f  + (- 28a b c + 12a b )d f
+--R                      + 
+--R                            5   2      4 3       3 5  3 5
+--R                        (84a b c  - 60a b c + 12a b )d f
+--R                      + 
+--R                               4   3       3 3 2      2 5        7  4 4
+--R                        (- 140a b c  + 120a b c  - 36a b c + 4a b )d f
+--R                      + 
+--R                             3   4       2 3 3        5 2     7   5 3
+--R                        (140a b c  - 120a b c  + 36a b c  - 4b c)d f
+--R                      + 
+--R                              2   5        3 4      5 3  6 2
+--R                        (- 84a b c  + 60a b c  - 12b c )d f
+--R                      + 
+--R                                6      3 5  7        7 8
+--R                        (28a b c  - 12b c )d f - 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            4   6       3        2 3    5
+--R                        - 3a b f  + (12a b c + 4a b )d f
+--R                      + 
+--R                              2   2       3     5  2 4           3     3 2  3 3
+--R                        (- 18a b c  - 8a b c - b )d f  + (12a b c  + 4b c )d f
+--R                      + 
+--R                              4 4 2
+--R                        - 3b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   6       5      4 2  2 5
+--R                             - 2a d f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  3 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  4 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  5 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  6      6 7
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 9       3 2      2 4    8
+--R                                  - 9a b f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  2 7
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  3 6     2 4 4 5
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12   12         11       10 2  2 11
+--R                                  4a  d f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  3 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     10 3
+--R                                    d  f
+--R                                + 
+--R                                       2 10         2 9      4 8  11 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  12      12 13
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3 5      2        2    4          2     2   2 3
+--R                         - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 3 2
+--R                         c d f
+--R                    /
+--R                          6   6        5      4 2  2 5
+--R                         a d f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  3 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  4 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  5 2          5     2 4  6
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 7
+--R                         c d
+--R              + 
+--R                                                            +--------------+
+--R                   2   5                3    4       2 2 3  |   2
+--R                (3a b f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                          6 7         5      4 2    6
+--R                        2a f  + (- 12a c + 6a b )d f
+--R                      + 
+--R                            4 2      3 2      2 4  2 5
+--R                        (30a c  - 24a b c + 6a b )d f
+--R                      + 
+--R                              3 3      2 2 2        4      6  3 4
+--R                        (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                      + 
+--R                            2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                        (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                      + 
+--R                          6 6
+--R                        2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2   5              3    4       2 2 3
+--R                    - 3a b f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                   2   2              3          2 2       3 2
+--R               (- a b f  + (2a b c - b )d f - b c d )x - 2a f
+--R             + 
+--R                  2        2           2 2
+--R               (4a c - 2a b )d f - 2a c d
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R              3   2        2 2       2            3 2  2
+--R           (2a c f  + (- 4a c  + 2a b c)d f + 2a c d )x
+--R         + 
+--R              3   2        2          3             2 2       4 2
+--R           (2a b f  + (- 4a b c + 2a b )d f + 2a b c d )x + 2a f
+--R         + 
+--R                3      2 2         2 2 2
+--R           (- 4a c + 2a b )d f + 2a c d
+--R      *
+--R         ROOT
+--R                        6   6       5      4 2  2 5
+--R                    - 2a d f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  3 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  4 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  5 2         5     2 4  6
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 7
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2 9       3 2      2 4    8
+--R                         - 9a b f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  2 7
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  3 6     2 4 4 5
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12   12         11       10 2  2 11
+--R                         4a  d f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  3 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  4 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            9 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  10 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                       + 
+--R                              2 10         2 9      4 8  11 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  12      12 13
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3 5      2        2    4          2     2   2 3    3 3 2
+--R                - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f  + c d f
+--R           /
+--R                 6   6        5      4 2  2 5       4 2      3 2      2 4  3 4
+--R                a d f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  4 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  5 2          5     2 4  6     6 7
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                            7     7       6         5 3  2 6
+--R                        - 4a b d f  + (28a b c - 12a b )d f
+--R                      + 
+--R                              5   2      4 3       3 5  3 5
+--R                        (- 84a b c  + 60a b c - 12a b )d f
+--R                      + 
+--R                             4   3       3 3 2      2 5        7  4 4
+--R                        (140a b c  - 120a b c  + 36a b c - 4a b )d f
+--R                      + 
+--R                               3   4       2 3 3        5 2     7   5 3
+--R                        (- 140a b c  + 120a b c  - 36a b c  + 4b c)d f
+--R                      + 
+--R                            2   5        3 4      5 3  6 2
+--R                        (84a b c  - 60a b c  + 12b c )d f
+--R                      + 
+--R                                  6      3 5  7        7 8
+--R                        (- 28a b c  + 12b c )d f + 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          4   6         3        2 3    5
+--R                        3a b f  + (- 12a b c - 4a b )d f
+--R                      + 
+--R                            2   2       3     5  2 4             3     3 2  3 3
+--R                        (18a b c  + 8a b c + b )d f  + (- 12a b c  - 4b c )d f
+--R                      + 
+--R                            4 4 2
+--R                        3b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   6       5      4 2  2 5
+--R                             - 2a d f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  3 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  4 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  5 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  6      6 7
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 9       3 2      2 4    8
+--R                                  - 9a b f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  2 7
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  3 6     2 4 4 5
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12   12         11       10 2  2 11
+--R                                  4a  d f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  3 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     10 3
+--R                                    d  f
+--R                                + 
+--R                                       2 10         2 9      4 8  11 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  12      12 13
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3 5      2        2    4          2     2   2 3
+--R                         - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 3 2
+--R                         c d f
+--R                    /
+--R                          6   6        5      4 2  2 5
+--R                         a d f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  3 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  4 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  5 2          5     2 4  6
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 7
+--R                         c d
+--R              + 
+--R                                                            +--------------+
+--R                   2   5                3    4       2 2 3  |   2
+--R                (3a b f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                          6 7         5      4 2    6
+--R                        2a f  + (- 12a c + 6a b )d f
+--R                      + 
+--R                            4 2      3 2      2 4  2 5
+--R                        (30a c  - 24a b c + 6a b )d f
+--R                      + 
+--R                              3 3      2 2 2        4      6  3 4
+--R                        (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                      + 
+--R                            2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                        (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                      + 
+--R                          6 6
+--R                        2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2   5              3    4       2 2 3
+--R                    - 3a b f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                 2   2                3          2 2       3 2
+--R               (a b f  + (- 2a b c + b )d f + b c d )x + 2a f
+--R             + 
+--R                    2        2           2 2
+--R               (- 4a c + 2a b )d f + 2a c d
+--R          *
+--R                  +--------------+
+--R              +-+ |   2
+--R             \|a \|c x  + b x + a
+--R         + 
+--R                3   2      2 2       2            3 2  2
+--R           (- 2a c f  + (4a c  - 2a b c)d f - 2a c d )x
+--R         + 
+--R                3   2      2          3             2 2       4 2
+--R           (- 2a b f  + (4a b c - 2a b )d f - 2a b c d )x - 2a f
+--R         + 
+--R              3      2 2         2 2 2
+--R           (4a c - 2a b )d f - 2a c d
+--R      *
+--R         ROOT
+--R                      6   6         5      4 2  2 5
+--R                    2a d f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  3 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  4 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  5 2           5     2 4  6
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 7
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2 9       3 2      2 4    8
+--R                         - 9a b f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  2 7
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  3 6     2 4 4 5
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12   12         11       10 2  2 11
+--R                         4a  d f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  3 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  4 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            9 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  10 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                       + 
+--R                              2 10         2 9      4 8  11 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  12      12 13
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3 5      2        2    4          2     2   2 3    3 3 2
+--R                - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f  + c d f
+--R           /
+--R                 6   6        5      4 2  2 5       4 2      3 2      2 4  3 4
+--R                a d f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  4 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  5 2          5     2 4  6     6 7
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R         log
+--R                            7     7       6         5 3  2 6
+--R                        - 4a b d f  + (28a b c - 12a b )d f
+--R                      + 
+--R                              5   2      4 3       3 5  3 5
+--R                        (- 84a b c  + 60a b c - 12a b )d f
+--R                      + 
+--R                             4   3       3 3 2      2 5        7  4 4
+--R                        (140a b c  - 120a b c  + 36a b c - 4a b )d f
+--R                      + 
+--R                               3   4       2 3 3        5 2     7   5 3
+--R                        (- 140a b c  + 120a b c  - 36a b c  + 4b c)d f
+--R                      + 
+--R                            2   5        3 4      5 3  6 2
+--R                        (84a b c  - 60a b c  + 12b c )d f
+--R                      + 
+--R                                  6      3 5  7        7 8
+--R                        (- 28a b c  + 12b c )d f + 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            4   6       3        2 3    5
+--R                        - 3a b f  + (12a b c + 4a b )d f
+--R                      + 
+--R                              2   2       3     5  2 4           3     3 2  3 3
+--R                        (- 18a b c  - 8a b c - b )d f  + (12a b c  + 4b c )d f
+--R                      + 
+--R                              4 4 2
+--R                        - 3b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   6         5      4 2  2 5
+--R                             2a d f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  3 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  4 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  5 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  6      6 7
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 9       3 2      2 4    8
+--R                                  - 9a b f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  2 7
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  3 6     2 4 4 5
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12   12         11       10 2  2 11
+--R                                  4a  d f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  3 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     10 3
+--R                                    d  f
+--R                                + 
+--R                                       2 10         2 9      4 8  11 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  12      12 13
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3 5      2        2    4          2     2   2 3
+--R                         - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 3 2
+--R                         c d f
+--R                    /
+--R                          6   6        5      4 2  2 5
+--R                         a d f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  3 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  4 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  5 2          5     2 4  6
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 7
+--R                         c d
+--R              + 
+--R                                                            +--------------+
+--R                   2   5                3    4       2 2 3  |   2
+--R                (3a b f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                            6 7       5      4 2    6
+--R                        - 2a f  + (12a c - 6a b )d f
+--R                      + 
+--R                              4 2      3 2      2 4  2 5
+--R                        (- 30a c  + 24a b c - 6a b )d f
+--R                      + 
+--R                            3 3      2 2 2        4      6  3 4
+--R                        (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                      + 
+--R                              2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                        (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                      + 
+--R                            6 6
+--R                        - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2   5              3    4       2 2 3
+--R                    - 3a b f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                               +--------------+
+--R                  2       2    |   2
+--R       ((4a c - 4b )f - 4c d)x\|c x  + b x + a
+--R     + 
+--R                2                2       2     +-+
+--R       (4b c f x  + ((- 4a c + 4b )f + 4c d)x)\|a
+--R  /
+--R              2   2                 3           2 2       3 2
+--R           (2a b f  + (- 4a b c + 2b )d f + 2b c d )x + 4a f
+--R         + 
+--R                2        2           2 2
+--R           (- 8a c + 4a b )d f + 4a c d
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R     + 
+--R            3   2      2 2       2            3 2  2
+--R       (- 4a c f  + (8a c  - 4a b c)d f - 4a c d )x
+--R     + 
+--R            3   2      2          3             2 2       4 2
+--R       (- 4a b f  + (8a b c - 4a b )d f - 4a b c d )x - 4a f
+--R     + 
+--R          3      2 2         2 2 2
+--R       (8a c - 4a b )d f - 4a c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 279
+
+--S 280 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- d \|c x  + b x + a
+--R         + 
+--R                      3       2 3  2        2   2       3     5
+--R                   (4a b c - a b )f  + (- 8a b c  + 6a b c - b )d f
+--R                 + 
+--R                          3    3 2  2
+--R                   (4a b c  - b c )d
+--R              *
+--R                 x
+--R             + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R              +---+ +-+
+--R             \|- d \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                      6   6         5      4 2  2 5
+--R                    2a d f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  3 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  4 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  5 2           5     2 4  6
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 7
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2 9       3 2      2 4    8
+--R                         - 9a b f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  2 7
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  3 6     2 4 4 5
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12   12         11       10 2  2 11
+--R                         4a  d f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  3 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  4 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            9 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  10 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                       + 
+--R                              2 10         2 9      4 8  11 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  12      12 13
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3 5      2        2    4          2     2   2 3    3 3 2
+--R                - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f  + c d f
+--R           /
+--R                 6   6        5      4 2  2 5       4 2      3 2      2 4  3 4
+--R                a d f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  4 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  5 2          5     2 4  6     6 7
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                          7     7         6         5 3  2 6
+--R                        4a b d f  + (- 28a b c + 12a b )d f
+--R                      + 
+--R                            5   2      4 3       3 5  3 5
+--R                        (84a b c  - 60a b c + 12a b )d f
+--R                      + 
+--R                               4   3       3 3 2      2 5        7  4 4
+--R                        (- 140a b c  + 120a b c  - 36a b c + 4a b )d f
+--R                      + 
+--R                             3   4       2 3 3        5 2     7   5 3
+--R                        (140a b c  - 120a b c  + 36a b c  - 4b c)d f
+--R                      + 
+--R                              2   5        3 4      5 3  6 2
+--R                        (- 84a b c  + 60a b c  - 12b c )d f
+--R                      + 
+--R                                6      3 5  7        7 8
+--R                        (28a b c  - 12b c )d f - 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          4   6         3        2 3    5
+--R                        3a b f  + (- 12a b c - 4a b )d f
+--R                      + 
+--R                            2   2       3     5  2 4             3     3 2  3 3
+--R                        (18a b c  + 8a b c + b )d f  + (- 12a b c  - 4b c )d f
+--R                      + 
+--R                            4 4 2
+--R                        3b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   6         5      4 2  2 5
+--R                             2a d f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  3 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  4 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  5 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  6      6 7
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 9       3 2      2 4    8
+--R                                  - 9a b f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  2 7
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  3 6     2 4 4 5
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12   12         11       10 2  2 11
+--R                                  4a  d f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  3 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     10 3
+--R                                    d  f
+--R                                + 
+--R                                       2 10         2 9      4 8  11 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  12      12 13
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3 5      2        2    4          2     2   2 3
+--R                         - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 3 2
+--R                         c d f
+--R                    /
+--R                          6   6        5      4 2  2 5
+--R                         a d f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  3 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  4 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  5 2          5     2 4  6
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 7
+--R                         c d
+--R              + 
+--R                                                            +--------------+
+--R                   2   5                3    4       2 2 3  |   2
+--R                (3a b f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                            6 7       5      4 2    6
+--R                        - 2a f  + (12a c - 6a b )d f
+--R                      + 
+--R                              4 2      3 2      2 4  2 5
+--R                        (- 30a c  + 24a b c - 6a b )d f
+--R                      + 
+--R                            3 3      2 2 2        4      6  3 4
+--R                        (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                      + 
+--R                              2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                        (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                      + 
+--R                            6 6
+--R                        - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2   5              3    4       2 2 3
+--R                    - 3a b f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- d \|c x  + b x + a
+--R         + 
+--R                        3       2 3  2      2   2       3     5
+--R                   (- 4a b c + a b )f  + (8a b c  - 6a b c + b )d f
+--R                 + 
+--R                            3    3 2  2
+--R                   (- 4a b c  + b c )d
+--R              *
+--R                 x
+--R             + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +---+ +-+
+--R             \|- d \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                        6   6       5      4 2  2 5
+--R                    - 2a d f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  3 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  4 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  5 2         5     2 4  6
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 7
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2 9       3 2      2 4    8
+--R                         - 9a b f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  2 7
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  3 6     2 4 4 5
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12   12         11       10 2  2 11
+--R                         4a  d f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  3 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  4 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            9 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  10 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                       + 
+--R                              2 10         2 9      4 8  11 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  12      12 13
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3 5      2        2    4          2     2   2 3    3 3 2
+--R                - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f  + c d f
+--R           /
+--R                 6   6        5      4 2  2 5       4 2      3 2      2 4  3 4
+--R                a d f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  4 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  5 2          5     2 4  6     6 7
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                          7     7         6         5 3  2 6
+--R                        4a b d f  + (- 28a b c + 12a b )d f
+--R                      + 
+--R                            5   2      4 3       3 5  3 5
+--R                        (84a b c  - 60a b c + 12a b )d f
+--R                      + 
+--R                               4   3       3 3 2      2 5        7  4 4
+--R                        (- 140a b c  + 120a b c  - 36a b c + 4a b )d f
+--R                      + 
+--R                             3   4       2 3 3        5 2     7   5 3
+--R                        (140a b c  - 120a b c  + 36a b c  - 4b c)d f
+--R                      + 
+--R                              2   5        3 4      5 3  6 2
+--R                        (- 84a b c  + 60a b c  - 12b c )d f
+--R                      + 
+--R                                6      3 5  7        7 8
+--R                        (28a b c  - 12b c )d f - 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            4   6       3        2 3    5
+--R                        - 3a b f  + (12a b c + 4a b )d f
+--R                      + 
+--R                              2   2       3     5  2 4           3     3 2  3 3
+--R                        (- 18a b c  - 8a b c - b )d f  + (12a b c  + 4b c )d f
+--R                      + 
+--R                              4 4 2
+--R                        - 3b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   6       5      4 2  2 5
+--R                             - 2a d f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  3 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  4 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  5 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  6      6 7
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 9       3 2      2 4    8
+--R                                  - 9a b f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  2 7
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  3 6     2 4 4 5
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12   12         11       10 2  2 11
+--R                                  4a  d f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  3 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     10 3
+--R                                    d  f
+--R                                + 
+--R                                       2 10         2 9      4 8  11 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  12      12 13
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3 5      2        2    4          2     2   2 3
+--R                         - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 3 2
+--R                         c d f
+--R                    /
+--R                          6   6        5      4 2  2 5
+--R                         a d f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  3 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  4 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  5 2          5     2 4  6
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 7
+--R                         c d
+--R              + 
+--R                                                            +--------------+
+--R                   2   5                3    4       2 2 3  |   2
+--R                (3a b f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                          6 7         5      4 2    6
+--R                        2a f  + (- 12a c + 6a b )d f
+--R                      + 
+--R                            4 2      3 2      2 4  2 5
+--R                        (30a c  - 24a b c + 6a b )d f
+--R                      + 
+--R                              3 3      2 2 2        4      6  3 4
+--R                        (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                      + 
+--R                            2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                        (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                      + 
+--R                          6 6
+--R                        2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2   5              3    4       2 2 3
+--R                    - 3a b f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- d \|c x  + b x + a
+--R         + 
+--R                      3       2 3  2        2   2       3     5
+--R                   (4a b c - a b )f  + (- 8a b c  + 6a b c - b )d f
+--R                 + 
+--R                          3    3 2  2
+--R                   (4a b c  - b c )d
+--R              *
+--R                 x
+--R             + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R              +---+ +-+
+--R             \|- d \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                        6   6       5      4 2  2 5
+--R                    - 2a d f  + (12a c - 6a b )d f
+--R                  + 
+--R                          4 2      3 2      2 4  3 4
+--R                    (- 30a c  + 24a b c - 6a b )d f
+--R                  + 
+--R                        3 3      2 2 2        4      6  4 3
+--R                    (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                  + 
+--R                          2 4        2 3     4 2  5 2         5     2 4  6
+--R                    (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                  + 
+--R                        6 7
+--R                    - 2c d
+--R               *
+--R                  ROOT
+--R                             4 2 9       3 2      2 4    8
+--R                         - 9a b f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  2 7
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  3 6     2 4 4 5
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12   12         11       10 2  2 11
+--R                         4a  d f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  3 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  4 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            9 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  10 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                       + 
+--R                              2 10         2 9      4 8  11 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  12      12 13
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3 5      2        2    4          2     2   2 3    3 3 2
+--R                - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f  + c d f
+--R           /
+--R                 6   6        5      4 2  2 5       4 2      3 2      2 4  3 4
+--R                a d f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  4 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  5 2          5     2 4  6     6 7
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            7     7       6         5 3  2 6
+--R                        - 4a b d f  + (28a b c - 12a b )d f
+--R                      + 
+--R                              5   2      4 3       3 5  3 5
+--R                        (- 84a b c  + 60a b c - 12a b )d f
+--R                      + 
+--R                             4   3       3 3 2      2 5        7  4 4
+--R                        (140a b c  - 120a b c  + 36a b c - 4a b )d f
+--R                      + 
+--R                               3   4       2 3 3        5 2     7   5 3
+--R                        (- 140a b c  + 120a b c  - 36a b c  + 4b c)d f
+--R                      + 
+--R                            2   5        3 4      5 3  6 2
+--R                        (84a b c  - 60a b c  + 12b c )d f
+--R                      + 
+--R                                  6      3 5  7        7 8
+--R                        (- 28a b c  + 12b c )d f + 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                          4   6         3        2 3    5
+--R                        3a b f  + (- 12a b c - 4a b )d f
+--R                      + 
+--R                            2   2       3     5  2 4             3     3 2  3 3
+--R                        (18a b c  + 8a b c + b )d f  + (- 12a b c  - 4b c )d f
+--R                      + 
+--R                            4 4 2
+--R                        3b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 6   6       5      4 2  2 5
+--R                             - 2a d f  + (12a c - 6a b )d f
+--R                           + 
+--R                                   4 2      3 2      2 4  3 4
+--R                             (- 30a c  + 24a b c - 6a b )d f
+--R                           + 
+--R                                 3 3      2 2 2        4      6  4 3
+--R                             (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                           + 
+--R                                   2 4        2 3     4 2  5 2
+--R                             (- 30a c  + 24a b c  - 6b c )d f
+--R                           + 
+--R                                   5     2 4  6      6 7
+--R                             (12a c  - 6b c )d f - 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 9       3 2      2 4    8
+--R                                  - 9a b f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  2 7
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  3 6     2 4 4 5
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12   12         11       10 2  2 11
+--R                                  4a  d f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  3 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     10 3
+--R                                    d  f
+--R                                + 
+--R                                       2 10         2 9      4 8  11 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  12      12 13
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3 5      2        2    4          2     2   2 3
+--R                         - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 3 2
+--R                         c d f
+--R                    /
+--R                          6   6        5      4 2  2 5
+--R                         a d f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  3 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  4 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  5 2          5     2 4  6
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 7
+--R                         c d
+--R              + 
+--R                                                            +--------------+
+--R                   2   5                3    4       2 2 3  |   2
+--R                (3a b f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                          6 7         5      4 2    6
+--R                        2a f  + (- 12a c + 6a b )d f
+--R                      + 
+--R                            4 2      3 2      2 4  2 5
+--R                        (30a c  - 24a b c + 6a b )d f
+--R                      + 
+--R                              3 3      2 2 2        4      6  3 4
+--R                        (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                      + 
+--R                            2 4        2 3     4 2  4 3           5     2 4  5 2
+--R                        (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                      + 
+--R                          6 6
+--R                        2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2   5              3    4       2 2 3
+--R                    - 3a b f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                  4      3 2  2         3 2      2 2        4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2a b )d f
+--R             + 
+--R                  2 3       2 2  2
+--R               (8a c  - 2a b c )d
+--R          *
+--R                    +--------------+
+--R              +---+ |   2
+--R             \|- d \|c x  + b x + a
+--R         + 
+--R                        3       2 3  2      2   2       3     5
+--R                   (- 4a b c + a b )f  + (8a b c  - 6a b c + b )d f
+--R                 + 
+--R                            3    3 2  2
+--R                   (- 4a b c  + b c )d
+--R              *
+--R                 x
+--R             + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +---+ +-+
+--R             \|- d \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R         ROOT
+--R                      6   6         5      4 2  2 5
+--R                    2a d f  + (- 12a c + 6a b )d f
+--R                  + 
+--R                        4 2      3 2      2 4  3 4
+--R                    (30a c  - 24a b c + 6a b )d f
+--R                  + 
+--R                          3 3      2 2 2        4      6  4 3
+--R                    (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                  + 
+--R                        2 4        2 3     4 2  5 2           5     2 4  6
+--R                    (30a c  - 24a b c  + 6b c )d f  + (- 12a c  + 6b c )d f
+--R                  + 
+--R                      6 7
+--R                    2c d
+--R               *
+--R                  ROOT
+--R                             4 2 9       3 2      2 4    8
+--R                         - 9a b f  + (36a b c + 6a b )d f
+--R                       + 
+--R                               2 2 2        4     6  2 7
+--R                         (- 54a b c  - 12a b c - b )d f
+--R                       + 
+--R                               2 3     4 2  3 6     2 4 4 5
+--R                         (36a b c  + 6b c )d f  - 9b c d f
+--R                    /
+--R                           12   12         11       10 2  2 11
+--R                         4a  d f   + (- 48a  c + 24a  b )d f
+--R                       + 
+--R                              10 2       9 2       8 4  3 10
+--R                         (264a  c  - 240a b c + 60a b )d f
+--R                       + 
+--R                                9 3        8 2 2       7 4       6 6  4 9
+--R                         (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                       + 
+--R                                  8 4        7 2 3        6 4 2       5 6
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                4 8
+--R                             60a b
+--R                        *
+--R                            5 8
+--R                           d f
+--R                       + 
+--R                                    7 5        6 2 4        5 4 3        4 6 2
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                   3 8       2 10
+--R                             - 240a b c + 24a b
+--R                        *
+--R                            6 7
+--R                           d f
+--R                       + 
+--R                                  6 6        5 2 5        4 4 4        3 6 3
+--R                             3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                           + 
+--R                                 2 8 2        10      12
+--R                             360a b c  - 48a b  c + 4b
+--R                        *
+--R                            7 6
+--R                           d f
+--R                       + 
+--R                                    5 7        4 2 6        3 4 5        2 6 4
+--R                             - 3168a c  + 5040a b c  - 3360a b c  + 1200a b c
+--R                           + 
+--R                                     8 3      10 2
+--R                             - 240a b c  + 24b  c
+--R                        *
+--R                            8 5
+--R                           d f
+--R                       + 
+--R                                  4 8        3 2 7        2 4 6         6 5
+--R                             1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                           + 
+--R                                8 4
+--R                             60b c
+--R                        *
+--R                            9 4
+--R                           d f
+--R                       + 
+--R                                3 9        2 2 8         4 7      6 6  10 3
+--R                         (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                       + 
+--R                              2 10         2 9      4 8  11 2
+--R                         (264a c   - 240a b c  + 60b c )d  f
+--R                       + 
+--R                                 11      2 10  12      12 13
+--R                         (- 48a c   + 24b c  )d  f + 4c  d
+--R              + 
+--R                   3 5      2        2    4          2     2   2 3    3 3 2
+--R                - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f  + c d f
+--R           /
+--R                 6   6        5      4 2  2 5       4 2      3 2      2 4  3 4
+--R                a d f  + (- 6a c + 3a b )d f  + (15a c  - 12a b c + 3a b )d f
+--R              + 
+--R                      3 3      2 2 2       4     6  4 3
+--R                (- 20a c  + 18a b c  - 6a b c + b )d f
+--R              + 
+--R                    2 4        2 3     4 2  5 2          5     2 4  6     6 7
+--R                (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f + c d
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R         log
+--R                            7     7       6         5 3  2 6
+--R                        - 4a b d f  + (28a b c - 12a b )d f
+--R                      + 
+--R                              5   2      4 3       3 5  3 5
+--R                        (- 84a b c  + 60a b c - 12a b )d f
+--R                      + 
+--R                             4   3       3 3 2      2 5        7  4 4
+--R                        (140a b c  - 120a b c  + 36a b c - 4a b )d f
+--R                      + 
+--R                               3   4       2 3 3        5 2     7   5 3
+--R                        (- 140a b c  + 120a b c  - 36a b c  + 4b c)d f
+--R                      + 
+--R                            2   5        3 4      5 3  6 2
+--R                        (84a b c  - 60a b c  + 12b c )d f
+--R                      + 
+--R                                  6      3 5  7        7 8
+--R                        (- 28a b c  + 12b c )d f + 4b c d
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                            4   6       3        2 3    5
+--R                        - 3a b f  + (12a b c + 4a b )d f
+--R                      + 
+--R                              2   2       3     5  2 4           3     3 2  3 3
+--R                        (- 18a b c  - 8a b c - b )d f  + (12a b c  + 4b c )d f
+--R                      + 
+--R                              4 4 2
+--R                        - 3b c d f
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               6   6         5      4 2  2 5
+--R                             2a d f  + (- 12a c + 6a b )d f
+--R                           + 
+--R                                 4 2      3 2      2 4  3 4
+--R                             (30a c  - 24a b c + 6a b )d f
+--R                           + 
+--R                                   3 3      2 2 2        4      6  4 3
+--R                             (- 40a c  + 36a b c  - 12a b c + 2b )d f
+--R                           + 
+--R                                 2 4        2 3     4 2  5 2
+--R                             (30a c  - 24a b c  + 6b c )d f
+--R                           + 
+--R                                     5     2 4  6      6 7
+--R                             (- 12a c  + 6b c )d f + 2c d
+--R                        *
+--R                           ROOT
+--R                                      4 2 9       3 2      2 4    8
+--R                                  - 9a b f  + (36a b c + 6a b )d f
+--R                                + 
+--R                                        2 2 2        4     6  2 7
+--R                                  (- 54a b c  - 12a b c - b )d f
+--R                                + 
+--R                                        2 3     4 2  3 6     2 4 4 5
+--R                                  (36a b c  + 6b c )d f  - 9b c d f
+--R                             /
+--R                                    12   12         11       10 2  2 11
+--R                                  4a  d f   + (- 48a  c + 24a  b )d f
+--R                                + 
+--R                                       10 2       9 2       8 4  3 10
+--R                                  (264a  c  - 240a b c + 60a b )d f
+--R                                + 
+--R                                           9 3        8 2 2       7 4       6 6
+--R                                    (- 880a c  + 1080a b c  - 480a b c + 80a b )
+--R                                 *
+--R                                     4 9
+--R                                    d f
+--R                                + 
+--R                                           8 4        7 2 3        6 4 2
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                            5 6       4 8
+--R                                      - 480a b c + 60a b
+--R                                 *
+--R                                     5 8
+--R                                    d f
+--R                                + 
+--R                                             7 5        6 2 4        5 4 3
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           4 6 2       3 8       2 10
+--R                                      1200a b c  - 240a b c + 24a b
+--R                                 *
+--R                                     6 7
+--R                                    d f
+--R                                + 
+--R                                           6 6        5 2 5        4 4 4
+--R                                      3696a c  - 6048a b c  + 4200a b c
+--R                                    + 
+--R                                           3 6 3       2 8 2        10      12
+--R                                    - 1600a b c  + 360a b c  - 48a b  c + 4b
+--R                                 *
+--R                                     7 6
+--R                                    d f
+--R                                + 
+--R                                             5 7        4 2 6        3 4 5
+--R                                      - 3168a c  + 5040a b c  - 3360a b c
+--R                                    + 
+--R                                           2 6 4         8 3      10 2
+--R                                      1200a b c  - 240a b c  + 24b  c
+--R                                 *
+--R                                     8 5
+--R                                    d f
+--R                                + 
+--R                                           4 8        3 2 7        2 4 6
+--R                                      1980a c  - 2880a b c  + 1680a b c
+--R                                    + 
+--R                                              6 5      8 4
+--R                                      - 480a b c  + 60b c
+--R                                 *
+--R                                     9 4
+--R                                    d f
+--R                                + 
+--R                                              3 9        2 2 8         4 7
+--R                                        - 880a c  + 1080a b c  - 480a b c
+--R                                      + 
+--R                                           6 6
+--R                                        80b c
+--R                                 *
+--R                                     10 3
+--R                                    d  f
+--R                                + 
+--R                                       2 10         2 9      4 8  11 2
+--R                                  (264a c   - 240a b c  + 60b c )d  f
+--R                                + 
+--R                                          11      2 10  12      12 13
+--R                                  (- 48a c   + 24b c  )d  f + 4c  d
+--R                       + 
+--R                            3 5      2        2    4          2     2   2 3
+--R                         - a f  + (3a c + 3a b )d f  + (- 3a c  - 3b c)d f
+--R                       + 
+--R                          3 3 2
+--R                         c d f
+--R                    /
+--R                          6   6        5      4 2  2 5
+--R                         a d f  + (- 6a c + 3a b )d f
+--R                       + 
+--R                             4 2      3 2      2 4  3 4
+--R                         (15a c  - 12a b c + 3a b )d f
+--R                       + 
+--R                               3 3      2 2 2       4     6  4 3
+--R                         (- 20a c  + 18a b c  - 6a b c + b )d f
+--R                       + 
+--R                             2 4        2 3     4 2  5 2          5     2 4  6
+--R                         (15a c  - 12a b c  + 3b c )d f  + (- 6a c  + 3b c )d f
+--R                       + 
+--R                          6 7
+--R                         c d
+--R              + 
+--R                                                            +--------------+
+--R                   2   5                3    4       2 2 3  |   2
+--R                (3a b f  + (- 6a b c - b )d f  + 3b c d f )\|c x  + b x + a
+--R              + 
+--R                            6 7       5      4 2    6
+--R                        - 2a f  + (12a c - 6a b )d f
+--R                      + 
+--R                              4 2      3 2      2 4  2 5
+--R                        (- 30a c  + 24a b c - 6a b )d f
+--R                      + 
+--R                            3 3      2 2 2        4      6  3 4
+--R                        (40a c  - 36a b c  + 12a b c - 2b )d f
+--R                      + 
+--R                              2 4        2 3     4 2  4 3         5     2 4  5 2
+--R                        (- 30a c  + 24a b c  - 6b c )d f  + (12a c  - 6b c )d f
+--R                      + 
+--R                            6 6
+--R                        - 2c d f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                                 4 2 9       3 2      2 4    8
+--R                             - 9a b f  + (36a b c + 6a b )d f
+--R                           + 
+--R                                   2 2 2        4     6  2 7
+--R                             (- 54a b c  - 12a b c - b )d f
+--R                           + 
+--R                                   2 3     4 2  3 6     2 4 4 5
+--R                             (36a b c  + 6b c )d f  - 9b c d f
+--R                        /
+--R                               12   12         11       10 2  2 11
+--R                             4a  d f   + (- 48a  c + 24a  b )d f
+--R                           + 
+--R                                  10 2       9 2       8 4  3 10
+--R                             (264a  c  - 240a b c + 60a b )d f
+--R                           + 
+--R                                    9 3        8 2 2       7 4       6 6  4 9
+--R                             (- 880a c  + 1080a b c  - 480a b c + 80a b )d f
+--R                           + 
+--R                                      8 4        7 2 3        6 4 2       5 6
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    4 8
+--R                                 60a b
+--R                            *
+--R                                5 8
+--R                               d f
+--R                           + 
+--R                                        7 5        6 2 4        5 4 3
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      4 6 2       3 8       2 10
+--R                                 1200a b c  - 240a b c + 24a b
+--R                            *
+--R                                6 7
+--R                               d f
+--R                           + 
+--R                                      6 6        5 2 5        4 4 4        3 6 3
+--R                                 3696a c  - 6048a b c  + 4200a b c  - 1600a b c
+--R                               + 
+--R                                     2 8 2        10      12
+--R                                 360a b c  - 48a b  c + 4b
+--R                            *
+--R                                7 6
+--R                               d f
+--R                           + 
+--R                                        5 7        4 2 6        3 4 5
+--R                                 - 3168a c  + 5040a b c  - 3360a b c
+--R                               + 
+--R                                      2 6 4         8 3      10 2
+--R                                 1200a b c  - 240a b c  + 24b  c
+--R                            *
+--R                                8 5
+--R                               d f
+--R                           + 
+--R                                      4 8        3 2 7        2 4 6         6 5
+--R                                 1980a c  - 2880a b c  + 1680a b c  - 480a b c
+--R                               + 
+--R                                    8 4
+--R                                 60b c
+--R                            *
+--R                                9 4
+--R                               d f
+--R                           + 
+--R                                    3 9        2 2 8         4 7      6 6  10 3
+--R                             (- 880a c  + 1080a b c  - 480a b c  + 80b c )d  f
+--R                           + 
+--R                                  2 10         2 9      4 8  11 2
+--R                             (264a c   - 240a b c  + 60b c )d  f
+--R                           + 
+--R                                     11      2 10  12      12 13
+--R                             (- 48a c   + 24b c  )d  f + 4c  d
+--R                  + 
+--R                        2   5              3    4       2 2 3
+--R                    - 3a b f  + (6a b c + b )d f  - 3b c d f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R                  2          3   +---+ +-+        3      2 2  2
+--R               (8a b c - 2a b )f\|- d \|f  + (- 8a c + 2a b )f
+--R             + 
+--R                  2 2       2
+--R               (8a c  - 2a b c)d f
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   2     4            2          3    +---+ +-+ +-+
+--R           ((- 4a b c + b )f x + (- 8a b c + 2a b )f)\|- d \|a \|f
+--R         + 
+--R                   2         3  2            2    3             3      2 2  2
+--R               ((4a b c - a b )f  + (- 4a b c  + b c)d f)x + (8a c - 2a b )f
+--R             + 
+--R                    2 2       2
+--R               (- 8a c  + 2a b c)d f
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                  2          3   +---+ +-+      3      2 2  2
+--R               (8a b c - 2a b )f\|- d \|f  + (8a c - 2a b )f
+--R             + 
+--R                    2 2       2
+--R               (- 8a c  + 2a b c)d f
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R         + 
+--R                   2     4            2          3    +---+ +-+ +-+
+--R           ((- 4a b c + b )f x + (- 8a b c + 2a b )f)\|- d \|a \|f
+--R         + 
+--R                     2         3  2          2    3               3      2 2  2
+--R               ((- 4a b c + a b )f  + (4a b c  - b c)d f)x + (- 8a c + 2a b )f
+--R             + 
+--R                  2 2       2
+--R               (8a c  - 2a b c)d f
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                                                   +--------------+
+--R                           3         2   +---+ +-+ |   2
+--R           ((- 24a b c + 8b )f + 8b c d)\|- d \|a \|c x  + b x + a
+--R         + 
+--R                   2      4       2 2          2          3           2   +---+
+--R           (((12a b c - 4b )f - 4b c d)x + (24a b c - 8a b )f - 8a b c d)\|- d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                 4      3 2  2         3 2      2 2        4
+--R             (16a c - 4a b )f  + (- 32a c  + 24a b c - 4a b )d f
+--R           + 
+--R                 2 3       2 2  2
+--R             (16a c  - 4a b c )d
+--R        *
+--R                  +--------------+
+--R            +---+ |   2
+--R           \|- d \|c x  + b x + a
+--R       + 
+--R                      3        2 3  2       2   2        3      5
+--R                 (- 8a b c + 2a b )f  + (16a b c  - 12a b c + 2b )d f
+--R               + 
+--R                          3     3 2  2
+--R                 (- 8a b c  + 2b c )d
+--R            *
+--R               x
+--R           + 
+--R                   4      3 2  2       3 2      2 2        4
+--R             (- 16a c + 4a b )f  + (32a c  - 24a b c + 4a b )d f
+--R           + 
+--R                   2 3       2 2  2
+--R             (- 16a c  + 4a b c )d
+--R        *
+--R            +---+ +-+
+--R           \|- d \|a
+--R    *
+--R        +-------------------------+ +-----------------------+
+--R        |    +---+ +-+              |  +---+ +-+
+--R       \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 1580
+--d0:=D(m0,x)
+--E 281
+
+)clear all
+
+--S 282 of 1580
+t0:=1/(x*(a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R                                                           +--------------+
+--R              5        4               3        2          |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x  + a d x)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 1580
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(a^(3/2)*d)+2*(b^2-_
+   2*a*c+b*c*x)/(a*(b^2-4*a*c)*d*sqrt(a+b*x+c*x^2))-2*f*(a*(2*c^2*d+b^2*f-_
+   2*a*c*f)+b*c*(c*d+a*f)*x)/((b^2-4*a*c)*d*(c^2*d^2-2*a*c*d*f+f*(b^2*d+_
+   a^2*f))*sqrt(a+b*x+c*x^2))+1/2*f^(3/2)*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))))*(c*d-a*f+b*sqrt(-d)*sqrt(f))/(d*(c^2*d^2-2*a*c*d*f+f*(b^2*d+_
+   a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*f^(3/2)*atan(1/2*(b*_
+   sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*(c*d-a*f-b*sqrt(-d)*sqrt(f))/(d*_
+   (c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                 3     2 2  2      2 2      2       +-+ +-+
+--R           ((- 4a c + a b )f  + (4a c  - a b c)d f)\|a \|f
+--R         + 
+--R              2         3  2 +---+ +-+
+--R           (4a b c - a b )f \|- d \|a
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                 3     2 2  2      2 2      2       +-+ +-+
+--R           ((- 4a c + a b )f  + (4a c  - a b c)d f)\|a \|f
+--R         + 
+--R                2         3  2 +---+ +-+
+--R           (- 4a b c + a b )f \|- d \|a
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                    3      2 2  2       2 2        2      4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2b )d f
+--R             + 
+--R                      3     2 2  2
+--R               (- 8a c  + 2b c )d
+--R          *
+--R              +--------------+
+--R              |   2                        b x + 2a
+--R             \|c x  + b x + a atanh(----------------------)
+--R                                          +--------------+
+--R                                      +-+ |   2
+--R                                    2\|a \|c x  + b x + a
+--R         + 
+--R                        2     3            3 2          2 2        2      4
+--R               ((12a b c  - 4b c)d f - 4b c d )x + (- 8a c  + 16a b c - 4b )d f
+--R             + 
+--R                    3     2 2  2
+--R               (8a c  - 4b c )d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R            4      3 2    2         3 2      2 2        4  2
+--R         (8a c - 2a b )d f  + (- 16a c  + 12a b c - 2a b )d f
+--R       + 
+--R            2 3       2 2  3
+--R         (8a c  - 2a b c )d
+--R    *
+--R          +--------------+ +-------------------------+ +-----------------------+
+--R      +-+ |   2            |    +---+ +-+              |  +---+ +-+
+--R     \|a \|c x  + b x + a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 1580
+--a0:=integrate(t0,x)
+--E 284
+
+--S 285 of 1580
+--m0:=a0-r0
+--E 285
+
+--S 286 of 1580
+--d0:=D(m0,x)
+--E 286
+
+)clear all
+
+--S 287 of 1580
+t0:=1/(x^2*(a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R                                                            +--------------+
+--R              6        5               4        3        2  |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x  + a d x )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 1580
+r0:=3/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(a^(5/2)*d)+_
+   2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*d*x*sqrt(a+b*x+c*x^2))+2*f*(b*(c^2*d+_
+   b^2*f-3*a*c*f)+c*(2*c^2*d+b^2*f-2*a*c*f)*x)/((b^2-4*a*c)*d*(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))-(3*b^2-8*a*c)*sqrt(a+b*x+_
+   c*x^2)/(a^2*(b^2-4*a*c)*d*x)+1/2*f^2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))))*((c*d-a*f)/sqrt(-d)+b*sqrt(f))/(d*(c^2*d^2-2*a*c*d*f+f*(b^2*d+_
+   a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*f^2*atan(1/2*(b*sqrt(-d)-_
+   2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f))))*((-c*d+a*f)/sqrt(-d)+b*sqrt(f))/(d*(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R              3       2 3  2  +---+ +-+ +-+
+--R           (4a b c - a b )f x\|- d \|a \|f
+--R         + 
+--R                 4     3 2  3      3 2    2 2     2   +-+
+--R           ((- 4a c + a b )f  + (4a c  - a b c)d f )x\|a
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R              3       2 3  2  +---+ +-+ +-+
+--R           (4a b c - a b )f x\|- d \|a \|f
+--R         + 
+--R               4     3 2  3        3 2    2 2     2   +-+
+--R           ((4a c - a b )f  + (- 4a c  + a b c)d f )x\|a
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                   3        2 3  2         2   2        3      5
+--R               (12a b c - 3a b )f  + (- 24a b c  + 18a b c - 3b )d f
+--R             + 
+--R                       3     3 2  2
+--R               (12a b c  - 3b c )d
+--R          *
+--R                     +--------------+
+--R               +---+ |   2                        b x + 2a
+--R             x\|- d \|c x  + b x + a atanh(----------------------)
+--R                                                 +--------------+
+--R                                             +-+ |   2
+--R                                           2\|a \|c x  + b x + a
+--R         + 
+--R                        3 2     2 2   2       2 3        2 2     4
+--R                   (- 8a c  + 2a b c)f  + (24a c  - 28a b c  + 6b c)d f
+--R                 + 
+--R                           4     2 3  2
+--R                   (- 16a c  + 6b c )d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        3        2 3  2       2   2        3      5
+--R                   (- 8a b c + 2a b )f  + (36a b c  - 32a b c + 6b )d f
+--R                 + 
+--R                             3     3 2  2
+--R                   (- 20a b c  + 6b c )d
+--R              *
+--R                 x
+--R             + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +---+ +-+
+--R             \|- d \|a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R            5      4 2    2         4 2      3 2      2 4  2
+--R         (8a c - 2a b )d f  + (- 16a c  + 12a b c - 2a b )d f
+--R       + 
+--R            3 3     2 2 2  3
+--R         (8a c  - 2a b c )d
+--R    *
+--R                   +--------------+ +-------------------------+
+--R         +---+ +-+ |   2            |    +---+ +-+
+--R       x\|- d \|a \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 288
+
+--S 289 of 1580
+--a0:=integrate(t0,x)
+--E 289
+
+--S 290 of 1580
+--m0:=a0-r0
+--E 290
+
+--S 291 of 1580
+--d0:=D(m0,x)
+--E 291
+
+)clear all
+
+--S 292 of 1580
+t0:=x^2*(a+b*x+c*x^2)^(1/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R           +--------------+
+--R         2 |   2
+--R        x \|c x  + b x + a
+--R   (1)  -------------------
+--R              2
+--R           f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 1580
+r0:=-1/8*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (c^(3/2)*f)+1/2*(2*c*e^2-2*c*d*f-b*e*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/(f^3*sqrt(c))-e*sqrt(a+b*x+c*x^2)/f^2+1/4*(b+2*c*x)*_
+   sqrt(a+b*x+c*x^2)/(c*f)+atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-_
+   b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*f*(c*e^2-c*d*f-b*e*f+_
+   a*f^2)+(f*(b*e^2-b*d*f-a*e*f)-c*(e^3-2*d*e*f))*(e-sqrt(e^2-4*d*f)))/_
+   (f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f)))-atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-_
+   c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*f*(c*e^2-c*d*f-b*e*f+_
+   a*f^2)+(f*(b*e^2-b*d*f-a*e*f)-c*(e^3-2*d*e*f))*(e+sqrt(e^2-4*d*f)))/_
+   (f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                                                  +-----------+
+--R                                2          2      2          2 3  |          2
+--R           ((- 8a c e - 8b c d)f  + (8b c e  + 16c d e)f - 8c e )\|- 4d f + e
+--R         + 
+--R                    3            2                  2 2  2
+--R           16a c d f  + (- 8a c e  - 24b c d e - 16c d )f
+--R         + 
+--R                  3      2   2       2 4
+--R           (8b c e  + 32c d e )f - 8c e
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|c \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                                  +-----------+
+--R                              2            2      2          2 3  |          2
+--R           ((8a c e + 8b c d)f  + (- 8b c e  - 16c d e)f + 8c e )\|- 4d f + e
+--R         + 
+--R                    3            2                  2 2  2
+--R           16a c d f  + (- 8a c e  - 24b c d e - 16c d )f
+--R         + 
+--R                  3      2   2       2 4
+--R           (8b c e  + 32c d e )f - 8c e
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|c \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                              +-----------+
+--R                       2  2                 2        2 2  +-+ |          2
+--R             ((4a c - b )f  + (- 4b c e - 8c d)f + 8c e )\|2 \|- 4d f + e
+--R          *
+--R                          2c x + b
+--R             atanh(----------------------)
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|c \|c x  + b x + a
+--R         + 
+--R                                         +-----------+     +--------------+
+--R                2        2           +-+ |          2  +-+ |   2
+--R           (4c f x + 2b f  - 8c e f)\|2 \|- 4d f + e  \|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                 +-----------+
+--R           3 +-+ |          2  +-+
+--R       8c f \|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 1580
+--a0:=integrate(t0,x)
+--E 294
+
+--S 295 of 1580
+--m0:=a0-r0
+--E 295
+
+--S 296 of 1580
+--d0:=D(m0,x)
+--E 296
+
+)clear all
+
+--S 297 of 1580
+t0:=x*(a+b*x+c*x^2)^(1/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R          +--------------+
+--R          |   2
+--R        x\|c x  + b x + a
+--R   (1)  ------------------
+--R             2
+--R          f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 297
+
+--S 298 of 1580
+r0:=-1/2*(2*c*e-b*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f^2*sqrt(c))+sqrt(a+b*x+c*x^2)/f-atanh(1/2*(4*a*f+2*x*(b*f-c*(e-_
+   sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*f*_
+   (c*e-b*f)+(f*(b*e-a*f)-c*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f)))+atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*f*(c*e-b*f)+(f*(b*e-a*f)-c*(e^2-d*f))*_
+   (e+sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                              +-----------+
+--R                2                          2  |          2                  2
+--R           (2a f  + (- 2b e - 2c d)f + 2c e )\|- 4d f + e   + (2a e + 4b d)f
+--R         + 
+--R                  2                  3
+--R           (- 2b e  - 6c d e)f + 2c e
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|c \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                              +-----------+
+--R                  2                        2  |          2                  2
+--R           (- 2a f  + (2b e + 2c d)f - 2c e )\|- 4d f + e   + (2a e + 4b d)f
+--R         + 
+--R                  2                  3
+--R           (- 2b e  - 6c d e)f + 2c e
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|c \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                            +-----------+
+--R                        +-+ |          2              2c x + b
+--R           (b f - 2c e)\|2 \|- 4d f + e  atanh(----------------------)
+--R                                                     +--------------+
+--R                                                 +-+ |   2
+--R                                               2\|c \|c x  + b x + a
+--R         + 
+--R                  +-----------+     +--------------+
+--R              +-+ |          2  +-+ |   2
+--R           2f\|2 \|- 4d f + e  \|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R               +-----------+
+--R         2 +-+ |          2  +-+
+--R       2f \|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 1580
+--a0:=integrate(t0,x)
+--E 299
+
+--S 300 of 1580
+--m0:=a0-r0
+--E 300
+
+--S 301 of 1580
+--d0:=D(m0,x)
+--E 301
+
+)clear all
+
+--S 302 of 1580
+t0:=(a+b*x+c*x^2)^(1/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R             2
+--R          f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 1580
+r0:=atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(c)/f-atanh(1/2*_
+   (4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f))))*sqrt(f*(2*a*f-b*(e-sqrt(e^2-4*d*f)))+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f)))/(f*sqrt(2)*sqrt(e^2-4*d*f))+atanh(1/2*(4*a*f-b*(e+sqrt(e^2-_
+   4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*sqrt(c*_
+   (e^2-2*d*f+e*sqrt(e^2-4*d*f))+f*(2*a*f-b*(e+sqrt(e^2-4*d*f))))/(f*_
+   sqrt(2)*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +------------------------------------------------------------+
+--R             |              +-----------+
+--R             |              |          2        2                        2
+--R            \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            atanh
+--R                            +-----------+
+--R                            |          2
+--R                 (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R              /
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|2 \|c x  + b x + a
+--R                *
+--R                  +------------------------------------------------------------+
+--R                  |              +-----------+
+--R                  |              |          2        2                        2
+--R                 \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R       -
+--R             +----------------------------------------------------------+
+--R             |            +-----------+
+--R             |            |          2        2                        2
+--R            \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            atanh
+--R                            +-----------+
+--R                            |          2
+--R                 (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R              /
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|2 \|c x  + b x + a
+--R                *
+--R                  +----------------------------------------------------------+
+--R                  |            +-----------+
+--R                  |            |          2        2                        2
+--R                 \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R            +-----------+
+--R        +-+ |          2  +-+             2c x + b
+--R       \|2 \|- 4d f + e  \|c atanh(----------------------)
+--R                                         +--------------+
+--R                                     +-+ |   2
+--R                                   2\|c \|c x  + b x + a
+--R  /
+--R           +-----------+
+--R       +-+ |          2
+--R     f\|2 \|- 4d f + e
+--R                                                    Type: Expression(Integer)
+--E 303
+
+--S 304 of 1580
+--a0:=integrate(t0,x)
+--E 304
+
+--S 305 of 1580
+--m0:=a0-r0
+--E 305
+
+--S 306 of 1580
+--d0:=D(m0,x)
+--E 306
+
+)clear all
+
+--S 307 of 1580
+t0:=(a+b*x+c*x^2)^(1/2)/(x*(d+e*x+f*x^2))
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R           3      2
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 1580
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a)/d-atanh(1/2*_
+   (4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f))))*(2*(b*d-a*e)*f-(c*d-a*f)*(e-sqrt(e^2-4*d*f)))/(d*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f)))+atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(2*(b*d-a*e)*f-(c*d-a*f)*(e+sqrt(e^2-_
+   4*d*f)))/(d*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                        +-----------+
+--R                        |          2
+--R         ((- a f + c d)\|- 4d f + e   + (a e - 2b d)f + c d e)
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                      +-----------+
+--R                      |          2
+--R         ((a f - c d)\|- 4d f + e   + (a e - 2b d)f + c d e)
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2  +-+             b x + 2a
+--R            \|2 \|- 4d f + e  \|a atanh(----------------------)
+--R                                              +--------------+
+--R                                          +-+ |   2
+--R                                        2\|a \|c x  + b x + a
+--R         *
+--R             +------------------------------------------------------------+
+--R             |              +-----------+
+--R             |              |          2        2                        2
+--R            \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R             +----------------------------------------------------------+
+--R             |            +-----------+
+--R             |            |          2        2                        2
+--R            \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R             +-----------+
+--R         +-+ |          2
+--R       d\|2 \|- 4d f + e
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 1580
+--a0:=integrate(t0,x)
+--E 309
+
+--S 310 of 1580
+--m0:=a0-r0
+--E 310
+
+--S 311 of 1580
+--d0:=D(m0,x)
+--E 311
+
+)clear all
+
+--S 312 of 1580
+t0:=(a+b*x+c*x^2)^(1/2)/(x^2*(d+e*x+f*x^2))
+--R 
+--R
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R   (1)  ------------------
+--R           4      3      2
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 1580
+r0:=-1/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(d*sqrt(a))+_
+   e*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a)/d^2-1/2*b*_
+   e*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(d^2*sqrt(c))-_
+   1/2*(2*c*d-b*e)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (d^2*sqrt(c))+atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(c)/d-sqrt(a+b*x+c*x^2)/(d*x)-f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-_
+   sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*c*d^2-_
+   b*d*(e+sqrt(e^2-4*d*f))+a*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))/(d^2*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f)))+f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+_
+   sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*(c*d^2-b*d*e+a*(e^2-d*f))+_
+   (b*d-a*e)*(e+sqrt(e^2-4*d*f)))/(d^2*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                            +-----------+
+--R                            |          2
+--R           (2a e - 2b d)f x\|- 4d f + e
+--R         + 
+--R                  2          2                2
+--R           (4a d f  + (- 2a e  + 2b d e - 4c d )f)x
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|a \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                              +-----------+
+--R                              |          2
+--R           (- 2a e + 2b d)f x\|- 4d f + e
+--R         + 
+--R                  2          2                2
+--R           (4a d f  + (- 2a e  + 2b d e - 4c d )f)x
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|a \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                             +-----------+
+--R                         +-+ |          2              b x + 2a
+--R           (2a e - b d)x\|2 \|- 4d f + e  atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|a \|c x  + b x + a
+--R         + 
+--R                    +-----------+     +--------------+
+--R                +-+ |          2  +-+ |   2
+--R           - 2d\|2 \|- 4d f + e  \|a \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                +-----------+
+--R         2  +-+ |          2  +-+
+--R       2d x\|2 \|- 4d f + e  \|a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 1580
+--a0:=integrate(t0,x)
+--E 314
+
+--S 315 of 1580
+--m0:=a0-r0
+--E 315
+
+--S 316 of 1580
+--d0:=D(m0,x)
+--E 316
+
+)clear all
+
+--S 317 of 1580
+t0:=(a+b*x+c*x^2)^(1/2)/(x^3*(d+e*x+f*x^2))
+--R 
+--R
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R   (1)  ------------------
+--R           5      4      3
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 1580
+r0:=1/8*(b^2-4*a*c)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (a^(3/2)*d)+1/2*b*e*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (d^2*sqrt(a))-(e^2-d*f)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+_
+   c*x^2)))*sqrt(a)/d^3+1/2*b*(e^2-d*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/(d^3*sqrt(c))+1/2*(2*c*d*e-b*e^2+b*d*f)*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(d^3*sqrt(c))-_
+   e*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(c)/d^2+_
+   e*sqrt(a+b*x+c*x^2)/(d^2*x)-1/4*(2*a+b*x)*sqrt(a+b*x+c*x^2)/(a*d*x^2)-_
+   f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(-2*(c*d^2*e+a*e*(e^2-2*d*f)-b*d*(e^2-_
+   d*f))+(c*d^2-b*d*e+a*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/(d^3*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f)))+f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+_
+   sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(-2*(c*d^2*e+a*e*(e^2-_
+   2*d*f)-b*d*(e^2-d*f))+(c*d^2-b*d*e+a*(e^2-d*f))*(e+sqrt(e^2-4*d*f)))/_
+   (d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                                         +-----------+
+--R              2   2        2 2                    2    2 |          2
+--R           (8a d f  + (- 8a e  + 8a b d e - 8a c d )f)x \|- 4d f + e
+--R         + 
+--R                  2             2  2      2 3           2         2     2
+--R           ((- 24a d e + 16a b d )f  + (8a e  - 8a b d e  + 8a c d e)f)x
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|a \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                         +-----------+
+--R                2   2      2 2                    2    2 |          2
+--R           (- 8a d f  + (8a e  - 8a b d e + 8a c d )f)x \|- 4d f + e
+--R         + 
+--R                  2             2  2      2 3           2         2     2
+--R           ((- 24a d e + 16a b d )f  + (8a e  - 8a b d e  + 8a c d e)f)x
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|a \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                                 +-----------+
+--R                2        2 2                         2  2  2 +-+ |          2
+--R             (8a d f - 8a e  + 4a b d e + (- 4a c + b )d )x \|2 \|- 4d f + e
+--R          *
+--R                          b x + 2a
+--R             atanh(----------------------)
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|a \|c x  + b x + a
+--R         + 
+--R                                           +-----------+     +--------------+
+--R                          2         2  +-+ |          2  +-+ |   2
+--R           ((8a d e - 2b d )x - 4a d )\|2 \|- 4d f + e  \|a \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                   +-----------+
+--R           3 2 +-+ |          2  +-+
+--R       8a d x \|2 \|- 4d f + e  \|a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 318
+
+--S 319 of 1580
+--a0:=integrate(t0,x)
+--E 319
+
+--S 320 of 1580
+--m0:=a0-r0
+--E 320
+
+--S 321 of 1580
+--d0:=D(m0,x)
+--E 321
+
+)clear all
+
+--S 322 of 1580
+t0:=sqrt(-3-4*x-x^2)/(3+4*x+2*x^2)
+--R 
+--R
+--R         +-------------+
+--R         |   2
+--R        \|- x  - 4x - 3
+--R   (1)  ----------------
+--R            2
+--R          2x  + 4x + 3
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 1580
+r0:=atan(sqrt(-1-x)/sqrt(3+x))-1/4*log(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/_
+   sqrt(3+x))+1/4*log(1-3*(1+x)/(3+x)+2*sqrt(-1-x)/sqrt(3+x))+atan((1-_
+   3*sqrt(-1-x)/sqrt(3+x))/sqrt(2))/sqrt(2)-atan((1+3*sqrt(-1-x)/_
+   sqrt(3+x))/sqrt(2))/sqrt(2),-1/2*asin(2+x)-1/4*%i*atanh((2*(1+%i*_
+   sqrt(2))+x*(2+%i*sqrt(2)))/(sqrt(-3-4*x-x^2)*sqrt(2*(1-2*%i*sqrt(2)))))*_
+   sqrt(1-2*%i*sqrt(2))+1/4*%i*atanh((2*(1-%i*sqrt(2))+x*(2-%i*sqrt(2)))/_
+   (sqrt(-3-4*x-x^2)*sqrt(2*(1+2*%i*sqrt(2)))))*sqrt(1+2*%i*sqrt(2))
+--R 
+--R
+--R   (2)
+--R   [
+--R                        +-----+            +-------+
+--R         1  +-+    - 2x\|x + 3  + (2x + 6)\|- x - 1
+--R         - \|2 log(---------------------------------)
+--R         4                          +-----+
+--R                            (x + 3)\|x + 3
+--R       + 
+--R                          +-----+              +-------+
+--R           1  +-+    - 2x\|x + 3  + (- 2x - 6)\|- x - 1
+--R         - - \|2 log(-----------------------------------)
+--R           4                           +-----+
+--R                               (x + 3)\|x + 3
+--R       + 
+--R                 +-----+     +-------+          +-----+     +-------+
+--R                \|x + 3  + 3\|- x - 1          \|x + 3  - 3\|- x - 1
+--R         - atan(----------------------) + atan(----------------------)
+--R                      +-+ +-----+                    +-+ +-----+
+--R                     \|2 \|x + 3                    \|2 \|x + 3
+--R       + 
+--R                   +-------+
+--R          +-+     \|- x - 1
+--R         \|2 atan(----------)
+--R                    +-----+
+--R                   \|x + 3
+--R    /
+--R        +-+
+--R       \|2
+--R     ,
+--R
+--R              +-------------+                       +-+
+--R         1    |      +-+               (%i x + 2%i)\|2  + 2x + 2
+--R       - - %i\|- 2%i\|2  + 1 atanh(--------------------------------)
+--R         4                          +-------------+ +-------------+
+--R                                    |      +-+      |   2
+--R                                   \|- 4%i\|2  + 2 \|- x  - 4x - 3
+--R     + 
+--R            +-----------+                      +-+
+--R       1    |    +-+              (%i x + 2%i)\|2  - 2x - 2      1
+--R     - - %i\|2%i\|2  + 1 atanh(------------------------------) - - asin(x + 2)
+--R       4                        +-------------+ +-----------+    2
+--R                                |   2           |    +-+
+--R                               \|- x  - 4x - 3 \|4%i\|2  + 2
+--R     ]
+--R                          Type: Tuple(Expression(Complex(Fraction(Integer))))
+--E 323
+
+--S 324 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +-------------+
+--R                    |   2
+--R          +-+    2x\|- x  - 4x - 3  - 4x - 3
+--R       - \|2 log(---------------------------)
+--R                               2
+--R                              x
+--R     + 
+--R                    +-------------+                        +-------------+
+--R                    |   2                                  |   2
+--R        +-+    - 2x\|- x  - 4x - 3  - 4x - 3      +-+     \|- x  - 4x - 3
+--R       \|2 log(-----------------------------) + 4\|2 atan(----------------)
+--R                              2                                 x + 2
+--R                             x
+--R     + 
+--R                                      2 +-+
+--R                                    4x \|3
+--R       - 8atan(------------------------------------------------)
+--R                                +-------------+
+--R                        +-+ +-+ |   2               2
+--R               (4x + 6)\|2 \|3 \|- x  - 4x - 3  - 3x  - 12x - 9
+--R  /
+--R       +-+
+--R     8\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 324
+
+--S 325 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    +-------------+
+--R                    |   2
+--R          +-+    2x\|- x  - 4x - 3  - 4x - 3
+--R       - \|2 log(---------------------------)
+--R                               2
+--R                              x
+--R     + 
+--R                       +-----+            +-------+
+--R           +-+    - 2x\|x + 3  + (2x + 6)\|- x - 1
+--R       - 2\|2 log(---------------------------------)
+--R                                   +-----+
+--R                           (x + 3)\|x + 3
+--R     + 
+--R                     +-----+              +-------+
+--R         +-+    - 2x\|x + 3  + (- 2x - 6)\|- x - 1
+--R       2\|2 log(-----------------------------------)
+--R                                  +-----+
+--R                          (x + 3)\|x + 3
+--R     + 
+--R                    +-------------+                        +-------------+
+--R                    |   2                                  |   2
+--R        +-+    - 2x\|- x  - 4x - 3  - 4x - 3      +-+     \|- x  - 4x - 3
+--R       \|2 log(-----------------------------) + 4\|2 atan(----------------)
+--R                              2                                 x + 2
+--R                             x
+--R     + 
+--R              +-----+     +-------+           +-----+     +-------+
+--R             \|x + 3  + 3\|- x - 1           \|x + 3  - 3\|- x - 1
+--R       8atan(----------------------) - 8atan(----------------------)
+--R                   +-+ +-----+                     +-+ +-----+
+--R                  \|2 \|x + 3                     \|2 \|x + 3
+--R     + 
+--R                                      2 +-+
+--R                                    4x \|3
+--R       - 8atan(------------------------------------------------)
+--R                                +-------------+
+--R                        +-+ +-+ |   2               2
+--R               (4x + 6)\|2 \|3 \|- x  - 4x - 3  - 3x  - 12x - 9
+--R     + 
+--R                    +-------+
+--R           +-+     \|- x - 1
+--R       - 8\|2 atan(----------)
+--R                     +-----+
+--R                    \|x + 3
+--R  /
+--R       +-+
+--R     8\|2
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                   8        7         6          5          4          3
+--R               - 7x  + 5127x  + 41296x  + 142599x  + 273726x  + 314901x
+--R             + 
+--R                      2
+--R               216432x  + 81405x + 12393
+--R          *
+--R              +-------------+
+--R              |   2
+--R             \|- x  - 4x - 3
+--R         + 
+--R                     9        8         7          6          5           4
+--R               - 336x  - 7416x  - 59168x  - 247160x  - 621996x  - 1000512x
+--R             + 
+--R                         3          2
+--R               - 1041768x  - 681048x  - 253692x - 40824
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R      *
+--R          +-------+ +-----+
+--R         \|- x - 1 \|x + 3
+--R     + 
+--R               9        8         7          6          5          4          3
+--R           336x  + 6392x  + 49600x  + 209888x  + 541536x  + 894672x  + 955584x
+--R         + 
+--R                  2
+--R           640224x  + 244944x + 40824
+--R      *
+--R                  +-------------+
+--R          +-+ +-+ |   2
+--R         \|2 \|3 \|- x  - 4x - 3
+--R     + 
+--R           10        9         8          7          6           5           4
+--R       - 7x   + 2612x  + 34375x  + 190576x  + 594906x  + 1168056x  + 1515726x
+--R     + 
+--R               3          2
+--R       1315440x  + 742365x  + 247860x + 37179
+--R  /
+--R                 9         8         7          6          5           4
+--R             672x  + 11440x  + 78000x  + 291032x  + 673296x  + 1018872x
+--R           + 
+--R                     3          2
+--R             1019088x  + 653832x  + 244944x + 40824
+--R        *
+--R                    +-------------+
+--R            +-+ +-+ |   2
+--R           \|2 \|3 \|- x  - 4x - 3
+--R       + 
+--R              10        9         8          7          6           5
+--R         - 14x   + 5252x  + 58211x  + 277888x  + 769056x  + 1377576x
+--R       + 
+--R                 4           3          2
+--R         1670922x  + 1381536x  + 754758x  + 247860x + 37179
+--R    *
+--R        +-------+ +-----+
+--R       \|- x - 1 \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 326
+
+)clear all
+
+--S 327 of 1580
+t0:=x^3/((a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                         3
+--R                        x
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 1580
+r0:=-1/2*b*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f)-_
+   e*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f^2*sqrt(c))+_
+   sqrt(a+b*x+c*x^2)/(c*f)-atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-_
+   4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*e*f-(e^2-d*f)*_
+   (e-sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))+atanh(1/2*(4*a*f-b*(e+_
+   sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(2*d*e*f-(e^2-d*f)*(e+sqrt(e^2-4*d*f)))/(f^2*_
+   sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                             +-----------+
+--R                          2  |          2                   3  +-+
+--R         ((- 2c d f + 2c e )\|- 4d f + e   - 6c d e f + 2c e )\|c
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                           +-----------+
+--R                        2  |          2                   3  +-+
+--R         ((2c d f - 2c e )\|- 4d f + e   - 6c d e f + 2c e )\|c
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                              +-----------+
+--R                          +-+ |          2              2c x + b
+--R           (- b f - 2c e)\|2 \|- 4d f + e  atanh(----------------------)
+--R                                                       +--------------+
+--R                                                   +-+ |   2
+--R                                                 2\|c \|c x  + b x + a
+--R         + 
+--R                  +-----------+     +--------------+
+--R              +-+ |          2  +-+ |   2
+--R           2f\|2 \|- 4d f + e  \|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                 +-----------+
+--R           2 +-+ |          2  +-+
+--R       2c f \|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 1580
+--a0:=integrate(t0,x)
+--E 329
+
+--S 330 of 1580
+--m0:=a0-r0
+--E 330
+
+--S 331 of 1580
+--d0:=D(m0,x)
+--E 331
+
+)clear all
+
+--S 332 of 1580
+t0:=x^2/((a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                         2
+--R                        x
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 1580
+r0:=atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f*sqrt(c))-_
+   atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(e^2-2*d*f-e*sqrt(e^2-4*d*f))/(f*sqrt(2)*sqrt(e^2-_
+   4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*f-e*(e+sqrt(e^2-4*d*f)))/_
+   (f*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R              +-----------+
+--R              |          2            2  +-+
+--R         (- e\|- 4d f + e   + 2d f - e )\|c
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R            +-----------+
+--R            |          2            2  +-+
+--R         (e\|- 4d f + e   + 2d f - e )\|c
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R              +-----------+
+--R          +-+ |          2              2c x + b
+--R         \|2 \|- 4d f + e  atanh(----------------------)
+--R                                       +--------------+
+--R                                   +-+ |   2
+--R                                 2\|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R             +-----------+
+--R         +-+ |          2  +-+
+--R       f\|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 333
+
+--S 334 of 1580
+--a0:=integrate(t0,x)
+--E 334
+
+--S 335 of 1580
+--m0:=a0-r0
+--E 335
+
+--S 336 of 1580
+--d0:=D(m0,x)
+--E 336
+
+)clear all
+
+--S 337 of 1580
+t0:=x/((a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                        x
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 1580
+r0:=atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(e-sqrt(e^2-4*d*f))/(sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/_
+   (sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(e+sqrt(e^2-4*d*f))/(sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R           +-----------+
+--R           |          2
+--R         (\|- 4d f + e   + e)
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R             +-----------+
+--R             |          2
+--R         (- \|- 4d f + e   + e)
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            +-----------+
+--R        +-+ |          2
+--R       \|2 \|- 4d f + e
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R                      2   3        2 2                           2  2  2
+--R                    8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                  + 
+--R                           3              2    2         2      2 3           4
+--R                    (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f - 2a c e
+--R                  + 
+--R                            3     2 2 2
+--R                    2b c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                          2 2               2 2
+--R                       - a e  + 2a b d e - b d
+--R                    /
+--R                           4   5       4 2     3              3      2 2  2  4
+--R                         4a d f  + (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                       + 
+--R                               3   3       3      2 2    2      2          3  2
+--R                             2a b e  + (12a c + 2a b )d e  + (8a b c - 8a b )d e
+--R                           + 
+--R                                 2 2        2      4  3
+--R                             (24a c  - 16a b c + 4b )d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                  3     2 2  4         2          3    3
+--R                             (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                           + 
+--R                                   2 2        2     4  2 2          2     3   3
+--R                             (- 22a c  + 20a b c - b )d e  + (8a b c  - 8b c)d e
+--R                           + 
+--R                                     3     2 2  4
+--R                             (- 16a c  + 8b c )d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                               2     5      2 2       2     4
+--R                             2a b c e  + (8a c  - 4a b c)d e
+--R                           + 
+--R                                       2     3   2 3         3     2 2  3 2
+--R                             (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                           + 
+--R                                   3 4      4 5
+--R                             - 8b c d e + 4c d
+--R                        *
+--R                           f
+--R                       + 
+--R                            2 2 6         2   5          3    2 2  2 4
+--R                         - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                       + 
+--R                             3 3 3    4 4 2
+--R                         2b c d e  - c d e
+--R              + 
+--R                             2                2
+--R                4a d f - 2a e  + 2b d e - 4c d
+--R           /
+--R                  2   3       2 2                          2  2  2
+--R                4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R              + 
+--R                      3            2    2         2      2 3          4
+--R                (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R              + 
+--R                       3    2 2 2
+--R                b c d e  - c d e
+--R      *
+--R         log
+--R                          3 2 4        3   2     2   2          2        2  3  3
+--R                        8a d f  + (- 6a d e  - 4a b d e + (- 24a c + 8a b )d )f
+--R                      + 
+--R                             3 4     2     3       2         2  2 2
+--R                            a e  + 5a b d e  + (22a c - 10a b )d e
+--R                          + 
+--R                                          3  3          2     2   4
+--R                            (- 8a b c + 4b )d e + (24a c  - 8b c)d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               2   5        2        2    4               3  2 3
+--R                            - a b e  + (- 8a c + 2a b )d e  + (10a b c - b )d e
+--R                          + 
+--R                                    2     2   3 2        2 4      3 5
+--R                            (- 18a c  - 2b c)d e  + 12b c d e - 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                         2   6             5        2    2   2 4       2 3 3
+--R                        a c e  - 2a b c d e  + (3a c  + b c)d e  - 3b c d e
+--R                      + 
+--R                          3 4 2
+--R                        2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - a e  + 2a b d e - b d
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                      2   2         2      2 3      2 4           3    2 2 2
+--R                  ((4a d e  - 8a b d e + 4b d )f - a e  + 2a b d e  - b d e )x
+--R               *
+--R                  ROOT
+--R                               2   3
+--R                             8a d f
+--R                           + 
+--R                                  2 2                           2  2  2
+--R                             (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                           + 
+--R                                    3              2    2         2      2 3
+--R                             (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                           + 
+--R                                     4           3     2 2 2
+--R                             - 2a c e  + 2b c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                   2 2               2 2
+--R                                - a e  + 2a b d e - b d
+--R                             /
+--R                                    4   5
+--R                                  4a d f
+--R                                + 
+--R                                      4 2     3              3      2 2  2  4
+--R                                  (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                + 
+--R                                        3   3       3      2 2    2
+--R                                      2a b e  + (12a c + 2a b )d e
+--R                                    + 
+--R                                         2          3  2
+--R                                      (8a b c - 8a b )d e
+--R                                    + 
+--R                                          2 2        2      4  3
+--R                                      (24a c  - 16a b c + 4b )d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                           3     2 2  4
+--R                                      (- 2a c - a b )e
+--R                                    + 
+--R                                            2          3    3
+--R                                      (- 10a b c + 2a b )d e
+--R                                    + 
+--R                                            2 2        2     4  2 2
+--R                                      (- 22a c  + 20a b c - b )d e
+--R                                    + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                        2     5      2 2       2     4
+--R                                      2a b c e  + (8a c  - 4a b c)d e
+--R                                    + 
+--R                                                2     3   2 3
+--R                                      (- 10a b c  + 2b c)d e
+--R                                    + 
+--R                                            3     2 2  3 2       3 4      4 5
+--R                                      (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     2 2 6         2   5          3    2 2  2 4
+--R                                  - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                                + 
+--R                                      3 3 3    4 4 2
+--R                                  2b c d e  - c d e
+--R                       + 
+--R                                      2                2
+--R                         4a d f - 2a e  + 2b d e - 4c d
+--R                    /
+--R                           2   3       2 2                          2  2  2
+--R                         4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                       + 
+--R                               3            2    2         2      2 3          4
+--R                         (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                       + 
+--R                                3    2 2 2
+--R                         b c d e  - c d e
+--R              + 
+--R                                 +--------------+
+--R                     2        3  |   2
+--R                (4a d e - 4b d )\|c x  + b x + a
+--R              + 
+--R                            2 2 3      2   2         2               2  3  2
+--R                        - 8a d f  + (2a d e  + 8a b d e + (16a c - 8b )d )f
+--R                      + 
+--R                                   3                2  2 2         3      2 4
+--R                        (- 2a b d e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                      + 
+--R                                4         2 3     2 3 2
+--R                        2a c d e  - 2b c d e  + 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - a e  + 2a b d e - b d
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                             2       2          2        3
+--R                    (- 2a d e  + 2b d e)x - 4a d e + 4b d
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                           2   3      2 2                         2  2  2
+--R                       - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                     + 
+--R                                3                2    2         2      2 3
+--R                       (- 2a b e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                     + 
+--R                             4           3     2 2 2
+--R                       2a c e  - 2b c d e  + 2c d e
+--R                  *
+--R                     ROOT
+--R                             2 2               2 2
+--R                          - a e  + 2a b d e - b d
+--R                       /
+--R                              4   5
+--R                            4a d f
+--R                          + 
+--R                                4 2     3              3      2 2  2  4
+--R                            (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                          + 
+--R                                  3   3       3      2 2    2
+--R                                2a b e  + (12a c + 2a b )d e
+--R                              + 
+--R                                 2          3  2        2 2        2      4  3
+--R                              (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                           *
+--R                               3
+--R                              f
+--R                          + 
+--R                                     3     2 2  4         2          3    3
+--R                                (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                              + 
+--R                                      2 2        2     4  2 2
+--R                                (- 22a c  + 20a b c - b )d e
+--R                              + 
+--R                                       2     3   3            3     2 2  4
+--R                                (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                           *
+--R                               2
+--R                              f
+--R                          + 
+--R                                  2     5      2 2       2     4
+--R                                2a b c e  + (8a c  - 4a b c)d e
+--R                              + 
+--R                                          2     3   2 3         3     2 2  3 2
+--R                                (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                              + 
+--R                                      3 4      4 5
+--R                                - 8b c d e + 4c d
+--R                           *
+--R                              f
+--R                          + 
+--R                               2 2 6         2   5          3    2 2  2 4
+--R                            - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                          + 
+--R                                3 3 3    4 4 2
+--R                            2b c d e  - c d e
+--R                 + 
+--R                                2                2
+--R                   4a d f - 2a e  + 2b d e - 4c d
+--R              /
+--R                     2   3       2 2                          2  2  2
+--R                   4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                 + 
+--R                         3            2    2         2      2 3          4
+--R                   (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                 + 
+--R                          3    2 2 2
+--R                   b c d e  - c d e
+--R         *
+--R            log
+--R                             3 2 4
+--R                           8a d f
+--R                         + 
+--R                                3   2     2   2          2        2  3  3
+--R                           (- 6a d e  - 4a b d e + (- 24a c + 8a b )d )f
+--R                         + 
+--R                                3 4     2     3       2         2  2 2
+--R                               a e  + 5a b d e  + (22a c - 10a b )d e
+--R                             + 
+--R                                             3  3          2     2   4
+--R                               (- 8a b c + 4b )d e + (24a c  - 8b c)d
+--R                          *
+--R                              2
+--R                             f
+--R                         + 
+--R                                  2   5        2        2    4
+--R                               - a b e  + (- 8a c + 2a b )d e
+--R                             + 
+--R                                           3  2 3           2     2   3 2
+--R                               (10a b c - b )d e  + (- 18a c  - 2b c)d e
+--R                             + 
+--R                                    2 4      3 5
+--R                               12b c d e - 8c d
+--R                          *
+--R                             f
+--R                         + 
+--R                            2   6             5        2    2   2 4       2 3 3
+--R                           a c e  - 2a b c d e  + (3a c  + b c)d e  - 3b c d e
+--R                         + 
+--R                             3 4 2
+--R                           2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - a e  + 2a b d e - b d
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2   2         2      2 3      2 4           3
+--R                           (- 4a d e  + 8a b d e - 4b d )f + a e  - 2a b d e
+--R                         + 
+--R                            2 2 2
+--R                           b d e
+--R                      *
+--R                         x
+--R                  *
+--R                     ROOT
+--R                                    2   3
+--R                                - 8a d f
+--R                              + 
+--R                                   2 2                         2  2  2
+--R                                (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                              + 
+--R                                            3                2    2         2
+--R                                    - 2a b e  + (- 12a c + 2b )d e  + 8b c d e
+--R                                  + 
+--R                                        2 3
+--R                                    - 8c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                      4           3     2 2 2
+--R                                2a c e  - 2b c d e  + 2c d e
+--R                           *
+--R                              ROOT
+--R                                      2 2               2 2
+--R                                   - a e  + 2a b d e - b d
+--R                                /
+--R                                       4   5
+--R                                     4a d f
+--R                                   + 
+--R                                         4 2     3              3      2 2  2  4
+--R                                     (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                   + 
+--R                                           3   3       3      2 2    2
+--R                                         2a b e  + (12a c + 2a b )d e
+--R                                       + 
+--R                                            2          3  2
+--R                                         (8a b c - 8a b )d e
+--R                                       + 
+--R                                             2 2        2      4  3
+--R                                         (24a c  - 16a b c + 4b )d
+--R                                    *
+--R                                        3
+--R                                       f
+--R                                   + 
+--R                                              3     2 2  4
+--R                                         (- 2a c - a b )e
+--R                                       + 
+--R                                               2          3    3
+--R                                         (- 10a b c + 2a b )d e
+--R                                       + 
+--R                                               2 2        2     4  2 2
+--R                                         (- 22a c  + 20a b c - b )d e
+--R                                       + 
+--R                                                2     3   3
+--R                                         (8a b c  - 8b c)d e
+--R                                       + 
+--R                                                 3     2 2  4
+--R                                         (- 16a c  + 8b c )d
+--R                                    *
+--R                                        2
+--R                                       f
+--R                                   + 
+--R                                           2     5      2 2       2     4
+--R                                         2a b c e  + (8a c  - 4a b c)d e
+--R                                       + 
+--R                                                   2     3   2 3
+--R                                         (- 10a b c  + 2b c)d e
+--R                                       + 
+--R                                             3     2 2  3 2       3 4      4 5
+--R                                       (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                    *
+--R                                       f
+--R                                   + 
+--R                                        2 2 6         2   5
+--R                                     - a c e  + 2a b c d e
+--R                                   + 
+--R                                            3    2 2  2 4       3 3 3    4 4 2
+--R                                     (- 2a c  - b c )d e  + 2b c d e  - c d e
+--R                          + 
+--R                                         2                2
+--R                            4a d f - 2a e  + 2b d e - 4c d
+--R                       /
+--R                              2   3       2 2                          2  2  2
+--R                            4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                          + 
+--R                                  3            2    2         2      2 3
+--R                            (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f
+--R                          + 
+--R                                   4          3    2 2 2
+--R                            - a c e  + b c d e  - c d e
+--R                 + 
+--R                                    +--------------+
+--R                        2        3  |   2
+--R                   (4a d e - 4b d )\|c x  + b x + a
+--R                 + 
+--R                             2 2 3
+--R                           8a d f
+--R                         + 
+--R                                2   2         2                 2  3  2
+--R                           (- 2a d e  - 8a b d e + (- 16a c + 8b )d )f
+--R                         + 
+--R                                    3              2  2 2         3      2 4
+--R                           (2a b d e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                         + 
+--R                                     4         2 3     2 3 2
+--R                           - 2a c d e  + 2b c d e  - 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - a e  + 2a b d e - b d
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2       2          2        3
+--R                       (- 2a d e  + 2b d e)x - 4a d e + 4b d
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R         ROOT
+--R                        2   3      2 2                         2  2  2
+--R                    - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                  + 
+--R                             3                2    2         2      2 3
+--R                    (- 2a b e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                  + 
+--R                          4           3     2 2 2
+--R                    2a c e  - 2b c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                          2 2               2 2
+--R                       - a e  + 2a b d e - b d
+--R                    /
+--R                           4   5       4 2     3              3      2 2  2  4
+--R                         4a d f  + (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                       + 
+--R                               3   3       3      2 2    2      2          3  2
+--R                             2a b e  + (12a c + 2a b )d e  + (8a b c - 8a b )d e
+--R                           + 
+--R                                 2 2        2      4  3
+--R                             (24a c  - 16a b c + 4b )d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                  3     2 2  4         2          3    3
+--R                             (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                           + 
+--R                                   2 2        2     4  2 2          2     3   3
+--R                             (- 22a c  + 20a b c - b )d e  + (8a b c  - 8b c)d e
+--R                           + 
+--R                                     3     2 2  4
+--R                             (- 16a c  + 8b c )d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                               2     5      2 2       2     4
+--R                             2a b c e  + (8a c  - 4a b c)d e
+--R                           + 
+--R                                       2     3   2 3         3     2 2  3 2
+--R                             (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                           + 
+--R                                   3 4      4 5
+--R                             - 8b c d e + 4c d
+--R                        *
+--R                           f
+--R                       + 
+--R                            2 2 6         2   5          3    2 2  2 4
+--R                         - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                       + 
+--R                             3 3 3    4 4 2
+--R                         2b c d e  - c d e
+--R              + 
+--R                             2                2
+--R                4a d f - 2a e  + 2b d e - 4c d
+--R           /
+--R                  2   3       2 2                          2  2  2
+--R                4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R              + 
+--R                      3            2    2         2      2 3          4
+--R                (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R              + 
+--R                       3    2 2 2
+--R                b c d e  - c d e
+--R      *
+--R         log
+--R                            3 2 4      3   2     2   2        2        2  3  3
+--R                        - 8a d f  + (6a d e  + 4a b d e + (24a c - 8a b )d )f
+--R                      + 
+--R                               3 4     2     3         2         2  2 2
+--R                            - a e  - 5a b d e  + (- 22a c + 10a b )d e
+--R                          + 
+--R                                        3  3            2     2   4
+--R                            (8a b c - 4b )d e + (- 24a c  + 8b c)d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                             2   5      2        2    4                 3  2 3
+--R                            a b e  + (8a c - 2a b )d e  + (- 10a b c + b )d e
+--R                          + 
+--R                                  2     2   3 2        2 4      3 5
+--R                            (18a c  + 2b c)d e  - 12b c d e + 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                           2   6             5          2    2   2 4       2 3 3
+--R                        - a c e  + 2a b c d e  + (- 3a c  - b c)d e  + 3b c d e
+--R                      + 
+--R                            3 4 2
+--R                        - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - a e  + 2a b d e - b d
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                      2   2         2      2 3      2 4           3    2 2 2
+--R                  ((4a d e  - 8a b d e + 4b d )f - a e  + 2a b d e  - b d e )x
+--R               *
+--R                  ROOT
+--R                                 2   3      2 2                         2  2  2
+--R                             - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                           + 
+--R                                         3                2    2         2
+--R                                 - 2a b e  + (- 12a c + 2b )d e  + 8b c d e
+--R                               + 
+--R                                     2 3
+--R                                 - 8c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                   4           3     2 2 2
+--R                             2a c e  - 2b c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                   2 2               2 2
+--R                                - a e  + 2a b d e - b d
+--R                             /
+--R                                    4   5
+--R                                  4a d f
+--R                                + 
+--R                                      4 2     3              3      2 2  2  4
+--R                                  (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                + 
+--R                                        3   3       3      2 2    2
+--R                                      2a b e  + (12a c + 2a b )d e
+--R                                    + 
+--R                                         2          3  2
+--R                                      (8a b c - 8a b )d e
+--R                                    + 
+--R                                          2 2        2      4  3
+--R                                      (24a c  - 16a b c + 4b )d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                           3     2 2  4
+--R                                      (- 2a c - a b )e
+--R                                    + 
+--R                                            2          3    3
+--R                                      (- 10a b c + 2a b )d e
+--R                                    + 
+--R                                            2 2        2     4  2 2
+--R                                      (- 22a c  + 20a b c - b )d e
+--R                                    + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                        2     5      2 2       2     4
+--R                                      2a b c e  + (8a c  - 4a b c)d e
+--R                                    + 
+--R                                                2     3   2 3
+--R                                      (- 10a b c  + 2b c)d e
+--R                                    + 
+--R                                            3     2 2  3 2       3 4      4 5
+--R                                      (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     2 2 6         2   5          3    2 2  2 4
+--R                                  - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                                + 
+--R                                      3 3 3    4 4 2
+--R                                  2b c d e  - c d e
+--R                       + 
+--R                                      2                2
+--R                         4a d f - 2a e  + 2b d e - 4c d
+--R                    /
+--R                           2   3       2 2                          2  2  2
+--R                         4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                       + 
+--R                               3            2    2         2      2 3          4
+--R                         (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                       + 
+--R                                3    2 2 2
+--R                         b c d e  - c d e
+--R              + 
+--R                                 +--------------+
+--R                     2        3  |   2
+--R                (4a d e - 4b d )\|c x  + b x + a
+--R              + 
+--R                          2 2 3        2   2         2                 2  3  2
+--R                        8a d f  + (- 2a d e  - 8a b d e + (- 16a c + 8b )d )f
+--R                      + 
+--R                                 3              2  2 2         3      2 4
+--R                        (2a b d e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                      + 
+--R                                  4         2 3     2 3 2
+--R                        - 2a c d e  + 2b c d e  - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - a e  + 2a b d e - b d
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                             2       2          2        3
+--R                    (- 2a d e  + 2b d e)x - 4a d e + 4b d
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                         2   3        2 2                           2  2  2
+--R                       8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                     + 
+--R                              3              2    2         2      2 3
+--R                       (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                     + 
+--R                               4           3     2 2 2
+--R                       - 2a c e  + 2b c d e  - 2c d e
+--R                  *
+--R                     ROOT
+--R                             2 2               2 2
+--R                          - a e  + 2a b d e - b d
+--R                       /
+--R                              4   5
+--R                            4a d f
+--R                          + 
+--R                                4 2     3              3      2 2  2  4
+--R                            (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                          + 
+--R                                  3   3       3      2 2    2
+--R                                2a b e  + (12a c + 2a b )d e
+--R                              + 
+--R                                 2          3  2        2 2        2      4  3
+--R                              (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                           *
+--R                               3
+--R                              f
+--R                          + 
+--R                                     3     2 2  4         2          3    3
+--R                                (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                              + 
+--R                                      2 2        2     4  2 2
+--R                                (- 22a c  + 20a b c - b )d e
+--R                              + 
+--R                                       2     3   3            3     2 2  4
+--R                                (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                           *
+--R                               2
+--R                              f
+--R                          + 
+--R                                  2     5      2 2       2     4
+--R                                2a b c e  + (8a c  - 4a b c)d e
+--R                              + 
+--R                                          2     3   2 3         3     2 2  3 2
+--R                                (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                              + 
+--R                                      3 4      4 5
+--R                                - 8b c d e + 4c d
+--R                           *
+--R                              f
+--R                          + 
+--R                               2 2 6         2   5          3    2 2  2 4
+--R                            - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                          + 
+--R                                3 3 3    4 4 2
+--R                            2b c d e  - c d e
+--R                 + 
+--R                                2                2
+--R                   4a d f - 2a e  + 2b d e - 4c d
+--R              /
+--R                     2   3       2 2                          2  2  2
+--R                   4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                 + 
+--R                         3            2    2         2      2 3          4
+--R                   (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                 + 
+--R                          3    2 2 2
+--R                   b c d e  - c d e
+--R         *
+--R            log
+--R                               3 2 4
+--R                           - 8a d f
+--R                         + 
+--R                              3   2     2   2        2        2  3  3
+--R                           (6a d e  + 4a b d e + (24a c - 8a b )d )f
+--R                         + 
+--R                                  3 4     2     3         2         2  2 2
+--R                               - a e  - 5a b d e  + (- 22a c + 10a b )d e
+--R                             + 
+--R                                           3  3            2     2   4
+--R                               (8a b c - 4b )d e + (- 24a c  + 8b c)d
+--R                          *
+--R                              2
+--R                             f
+--R                         + 
+--R                                2   5      2        2    4
+--R                               a b e  + (8a c - 2a b )d e
+--R                             + 
+--R                                             3  2 3         2     2   3 2
+--R                               (- 10a b c + b )d e  + (18a c  + 2b c)d e
+--R                             + 
+--R                                      2 4      3 5
+--R                               - 12b c d e + 8c d
+--R                          *
+--R                             f
+--R                         + 
+--R                              2   6             5          2    2   2 4
+--R                           - a c e  + 2a b c d e  + (- 3a c  - b c)d e
+--R                         + 
+--R                               2 3 3     3 4 2
+--R                           3b c d e  - 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - a e  + 2a b d e - b d
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2   2         2      2 3      2 4           3
+--R                           (- 4a d e  + 8a b d e - 4b d )f + a e  - 2a b d e
+--R                         + 
+--R                            2 2 2
+--R                           b d e
+--R                      *
+--R                         x
+--R                  *
+--R                     ROOT
+--R                                  2   3
+--R                                8a d f
+--R                              + 
+--R                                     2 2                           2  2  2
+--R                                (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                              + 
+--R                                            3              2    2         2
+--R                                      2a b e  + (12a c - 2b )d e  - 8b c d e
+--R                                    + 
+--R                                        2 3
+--R                                      8c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                        4           3     2 2 2
+--R                                - 2a c e  + 2b c d e  - 2c d e
+--R                           *
+--R                              ROOT
+--R                                      2 2               2 2
+--R                                   - a e  + 2a b d e - b d
+--R                                /
+--R                                       4   5
+--R                                     4a d f
+--R                                   + 
+--R                                         4 2     3              3      2 2  2  4
+--R                                     (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                   + 
+--R                                           3   3       3      2 2    2
+--R                                         2a b e  + (12a c + 2a b )d e
+--R                                       + 
+--R                                            2          3  2
+--R                                         (8a b c - 8a b )d e
+--R                                       + 
+--R                                             2 2        2      4  3
+--R                                         (24a c  - 16a b c + 4b )d
+--R                                    *
+--R                                        3
+--R                                       f
+--R                                   + 
+--R                                              3     2 2  4
+--R                                         (- 2a c - a b )e
+--R                                       + 
+--R                                               2          3    3
+--R                                         (- 10a b c + 2a b )d e
+--R                                       + 
+--R                                               2 2        2     4  2 2
+--R                                         (- 22a c  + 20a b c - b )d e
+--R                                       + 
+--R                                                2     3   3
+--R                                         (8a b c  - 8b c)d e
+--R                                       + 
+--R                                                 3     2 2  4
+--R                                         (- 16a c  + 8b c )d
+--R                                    *
+--R                                        2
+--R                                       f
+--R                                   + 
+--R                                           2     5      2 2       2     4
+--R                                         2a b c e  + (8a c  - 4a b c)d e
+--R                                       + 
+--R                                                   2     3   2 3
+--R                                         (- 10a b c  + 2b c)d e
+--R                                       + 
+--R                                             3     2 2  3 2       3 4      4 5
+--R                                       (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                    *
+--R                                       f
+--R                                   + 
+--R                                        2 2 6         2   5
+--R                                     - a c e  + 2a b c d e
+--R                                   + 
+--R                                            3    2 2  2 4       3 3 3    4 4 2
+--R                                     (- 2a c  - b c )d e  + 2b c d e  - c d e
+--R                          + 
+--R                                         2                2
+--R                            4a d f - 2a e  + 2b d e - 4c d
+--R                       /
+--R                              2   3       2 2                          2  2  2
+--R                            4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                          + 
+--R                                  3            2    2         2      2 3
+--R                            (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f
+--R                          + 
+--R                                   4          3    2 2 2
+--R                            - a c e  + b c d e  - c d e
+--R                 + 
+--R                                    +--------------+
+--R                        2        3  |   2
+--R                   (4a d e - 4b d )\|c x  + b x + a
+--R                 + 
+--R                               2 2 3      2   2         2               2  3  2
+--R                           - 8a d f  + (2a d e  + 8a b d e + (16a c - 8b )d )f
+--R                         + 
+--R                                         3                2  2 2         3
+--R                               - 2a b d e  + (- 12a c + 2b )d e  + 8b c d e
+--R                             + 
+--R                                   2 4
+--R                               - 8c d
+--R                          *
+--R                             f
+--R                         + 
+--R                                   4         2 3     2 3 2
+--R                           2a c d e  - 2b c d e  + 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - a e  + 2a b d e - b d
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2       2          2        3
+--R                       (- 2a d e  + 2b d e)x - 4a d e + 4b d
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 339
+
+--S 340 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         ROOT
+--R                      2   3        2 2                           2  2  2
+--R                    8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                  + 
+--R                           3              2    2         2      2 3           4
+--R                    (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f - 2a c e
+--R                  + 
+--R                            3     2 2 2
+--R                    2b c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                          2 2               2 2
+--R                       - a e  + 2a b d e - b d
+--R                    /
+--R                           4   5       4 2     3              3      2 2  2  4
+--R                         4a d f  + (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                       + 
+--R                               3   3       3      2 2    2      2          3  2
+--R                             2a b e  + (12a c + 2a b )d e  + (8a b c - 8a b )d e
+--R                           + 
+--R                                 2 2        2      4  3
+--R                             (24a c  - 16a b c + 4b )d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                  3     2 2  4         2          3    3
+--R                             (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                           + 
+--R                                   2 2        2     4  2 2          2     3   3
+--R                             (- 22a c  + 20a b c - b )d e  + (8a b c  - 8b c)d e
+--R                           + 
+--R                                     3     2 2  4
+--R                             (- 16a c  + 8b c )d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                               2     5      2 2       2     4
+--R                             2a b c e  + (8a c  - 4a b c)d e
+--R                           + 
+--R                                       2     3   2 3         3     2 2  3 2
+--R                             (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                           + 
+--R                                   3 4      4 5
+--R                             - 8b c d e + 4c d
+--R                        *
+--R                           f
+--R                       + 
+--R                            2 2 6         2   5          3    2 2  2 4
+--R                         - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                       + 
+--R                             3 3 3    4 4 2
+--R                         2b c d e  - c d e
+--R              + 
+--R                             2                2
+--R                4a d f - 2a e  + 2b d e - 4c d
+--R           /
+--R                  2   3       2 2                          2  2  2
+--R                4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R              + 
+--R                      3            2    2         2      2 3          4
+--R                (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R              + 
+--R                       3    2 2 2
+--R                b c d e  - c d e
+--R      *
+--R         log
+--R                          3 2 4        3   2     2   2          2        2  3  3
+--R                        8a d f  + (- 6a d e  - 4a b d e + (- 24a c + 8a b )d )f
+--R                      + 
+--R                             3 4     2     3       2         2  2 2
+--R                            a e  + 5a b d e  + (22a c - 10a b )d e
+--R                          + 
+--R                                          3  3          2     2   4
+--R                            (- 8a b c + 4b )d e + (24a c  - 8b c)d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               2   5        2        2    4               3  2 3
+--R                            - a b e  + (- 8a c + 2a b )d e  + (10a b c - b )d e
+--R                          + 
+--R                                    2     2   3 2        2 4      3 5
+--R                            (- 18a c  - 2b c)d e  + 12b c d e - 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                         2   6             5        2    2   2 4       2 3 3
+--R                        a c e  - 2a b c d e  + (3a c  + b c)d e  - 3b c d e
+--R                      + 
+--R                          3 4 2
+--R                        2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - a e  + 2a b d e - b d
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                      2   2         2      2 3      2 4           3    2 2 2
+--R                  ((4a d e  - 8a b d e + 4b d )f - a e  + 2a b d e  - b d e )x
+--R               *
+--R                  ROOT
+--R                               2   3
+--R                             8a d f
+--R                           + 
+--R                                  2 2                           2  2  2
+--R                             (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                           + 
+--R                                    3              2    2         2      2 3
+--R                             (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                           + 
+--R                                     4           3     2 2 2
+--R                             - 2a c e  + 2b c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                   2 2               2 2
+--R                                - a e  + 2a b d e - b d
+--R                             /
+--R                                    4   5
+--R                                  4a d f
+--R                                + 
+--R                                      4 2     3              3      2 2  2  4
+--R                                  (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                + 
+--R                                        3   3       3      2 2    2
+--R                                      2a b e  + (12a c + 2a b )d e
+--R                                    + 
+--R                                         2          3  2
+--R                                      (8a b c - 8a b )d e
+--R                                    + 
+--R                                          2 2        2      4  3
+--R                                      (24a c  - 16a b c + 4b )d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                           3     2 2  4
+--R                                      (- 2a c - a b )e
+--R                                    + 
+--R                                            2          3    3
+--R                                      (- 10a b c + 2a b )d e
+--R                                    + 
+--R                                            2 2        2     4  2 2
+--R                                      (- 22a c  + 20a b c - b )d e
+--R                                    + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                        2     5      2 2       2     4
+--R                                      2a b c e  + (8a c  - 4a b c)d e
+--R                                    + 
+--R                                                2     3   2 3
+--R                                      (- 10a b c  + 2b c)d e
+--R                                    + 
+--R                                            3     2 2  3 2       3 4      4 5
+--R                                      (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     2 2 6         2   5          3    2 2  2 4
+--R                                  - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                                + 
+--R                                      3 3 3    4 4 2
+--R                                  2b c d e  - c d e
+--R                       + 
+--R                                      2                2
+--R                         4a d f - 2a e  + 2b d e - 4c d
+--R                    /
+--R                           2   3       2 2                          2  2  2
+--R                         4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                       + 
+--R                               3            2    2         2      2 3          4
+--R                         (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                       + 
+--R                                3    2 2 2
+--R                         b c d e  - c d e
+--R              + 
+--R                                 +--------------+
+--R                     2        3  |   2
+--R                (4a d e - 4b d )\|c x  + b x + a
+--R              + 
+--R                            2 2 3      2   2         2               2  3  2
+--R                        - 8a d f  + (2a d e  + 8a b d e + (16a c - 8b )d )f
+--R                      + 
+--R                                   3                2  2 2         3      2 4
+--R                        (- 2a b d e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                      + 
+--R                                4         2 3     2 3 2
+--R                        2a c d e  - 2b c d e  + 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - a e  + 2a b d e - b d
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                             2       2          2        3
+--R                    (- 2a d e  + 2b d e)x - 4a d e + 4b d
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2
+--R            \|2 \|- 4d f + e
+--R         *
+--R            ROOT
+--R                           2   3      2 2                         2  2  2
+--R                       - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                     + 
+--R                                3                2    2         2      2 3
+--R                       (- 2a b e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                     + 
+--R                             4           3     2 2 2
+--R                       2a c e  - 2b c d e  + 2c d e
+--R                  *
+--R                     ROOT
+--R                             2 2               2 2
+--R                          - a e  + 2a b d e - b d
+--R                       /
+--R                              4   5
+--R                            4a d f
+--R                          + 
+--R                                4 2     3              3      2 2  2  4
+--R                            (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                          + 
+--R                                  3   3       3      2 2    2
+--R                                2a b e  + (12a c + 2a b )d e
+--R                              + 
+--R                                 2          3  2        2 2        2      4  3
+--R                              (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                           *
+--R                               3
+--R                              f
+--R                          + 
+--R                                     3     2 2  4         2          3    3
+--R                                (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                              + 
+--R                                      2 2        2     4  2 2
+--R                                (- 22a c  + 20a b c - b )d e
+--R                              + 
+--R                                       2     3   3            3     2 2  4
+--R                                (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                           *
+--R                               2
+--R                              f
+--R                          + 
+--R                                  2     5      2 2       2     4
+--R                                2a b c e  + (8a c  - 4a b c)d e
+--R                              + 
+--R                                          2     3   2 3         3     2 2  3 2
+--R                                (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                              + 
+--R                                      3 4      4 5
+--R                                - 8b c d e + 4c d
+--R                           *
+--R                              f
+--R                          + 
+--R                               2 2 6         2   5          3    2 2  2 4
+--R                            - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                          + 
+--R                                3 3 3    4 4 2
+--R                            2b c d e  - c d e
+--R                 + 
+--R                                2                2
+--R                   4a d f - 2a e  + 2b d e - 4c d
+--R              /
+--R                     2   3       2 2                          2  2  2
+--R                   4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                 + 
+--R                         3            2    2         2      2 3          4
+--R                   (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                 + 
+--R                          3    2 2 2
+--R                   b c d e  - c d e
+--R         *
+--R             +------------------------------------------------------------+
+--R             |              +-----------+
+--R             |              |          2        2                        2
+--R            \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R             +----------------------------------------------------------+
+--R             |            +-----------+
+--R             |            |          2        2                        2
+--R            \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            log
+--R                             3 2 4
+--R                           8a d f
+--R                         + 
+--R                                3   2     2   2          2        2  3  3
+--R                           (- 6a d e  - 4a b d e + (- 24a c + 8a b )d )f
+--R                         + 
+--R                                3 4     2     3       2         2  2 2
+--R                               a e  + 5a b d e  + (22a c - 10a b )d e
+--R                             + 
+--R                                             3  3          2     2   4
+--R                               (- 8a b c + 4b )d e + (24a c  - 8b c)d
+--R                          *
+--R                              2
+--R                             f
+--R                         + 
+--R                                  2   5        2        2    4
+--R                               - a b e  + (- 8a c + 2a b )d e
+--R                             + 
+--R                                           3  2 3           2     2   3 2
+--R                               (10a b c - b )d e  + (- 18a c  - 2b c)d e
+--R                             + 
+--R                                    2 4      3 5
+--R                               12b c d e - 8c d
+--R                          *
+--R                             f
+--R                         + 
+--R                            2   6             5        2    2   2 4       2 3 3
+--R                           a c e  - 2a b c d e  + (3a c  + b c)d e  - 3b c d e
+--R                         + 
+--R                             3 4 2
+--R                           2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - a e  + 2a b d e - b d
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2   2         2      2 3      2 4           3
+--R                           (- 4a d e  + 8a b d e - 4b d )f + a e  - 2a b d e
+--R                         + 
+--R                            2 2 2
+--R                           b d e
+--R                      *
+--R                         x
+--R                  *
+--R                     ROOT
+--R                                    2   3
+--R                                - 8a d f
+--R                              + 
+--R                                   2 2                         2  2  2
+--R                                (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                              + 
+--R                                            3                2    2         2
+--R                                    - 2a b e  + (- 12a c + 2b )d e  + 8b c d e
+--R                                  + 
+--R                                        2 3
+--R                                    - 8c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                      4           3     2 2 2
+--R                                2a c e  - 2b c d e  + 2c d e
+--R                           *
+--R                              ROOT
+--R                                      2 2               2 2
+--R                                   - a e  + 2a b d e - b d
+--R                                /
+--R                                       4   5
+--R                                     4a d f
+--R                                   + 
+--R                                         4 2     3              3      2 2  2  4
+--R                                     (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                   + 
+--R                                           3   3       3      2 2    2
+--R                                         2a b e  + (12a c + 2a b )d e
+--R                                       + 
+--R                                            2          3  2
+--R                                         (8a b c - 8a b )d e
+--R                                       + 
+--R                                             2 2        2      4  3
+--R                                         (24a c  - 16a b c + 4b )d
+--R                                    *
+--R                                        3
+--R                                       f
+--R                                   + 
+--R                                              3     2 2  4
+--R                                         (- 2a c - a b )e
+--R                                       + 
+--R                                               2          3    3
+--R                                         (- 10a b c + 2a b )d e
+--R                                       + 
+--R                                               2 2        2     4  2 2
+--R                                         (- 22a c  + 20a b c - b )d e
+--R                                       + 
+--R                                                2     3   3
+--R                                         (8a b c  - 8b c)d e
+--R                                       + 
+--R                                                 3     2 2  4
+--R                                         (- 16a c  + 8b c )d
+--R                                    *
+--R                                        2
+--R                                       f
+--R                                   + 
+--R                                           2     5      2 2       2     4
+--R                                         2a b c e  + (8a c  - 4a b c)d e
+--R                                       + 
+--R                                                   2     3   2 3
+--R                                         (- 10a b c  + 2b c)d e
+--R                                       + 
+--R                                             3     2 2  3 2       3 4      4 5
+--R                                       (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                    *
+--R                                       f
+--R                                   + 
+--R                                        2 2 6         2   5
+--R                                     - a c e  + 2a b c d e
+--R                                   + 
+--R                                            3    2 2  2 4       3 3 3    4 4 2
+--R                                     (- 2a c  - b c )d e  + 2b c d e  - c d e
+--R                          + 
+--R                                         2                2
+--R                            4a d f - 2a e  + 2b d e - 4c d
+--R                       /
+--R                              2   3       2 2                          2  2  2
+--R                            4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                          + 
+--R                                  3            2    2         2      2 3
+--R                            (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f
+--R                          + 
+--R                                   4          3    2 2 2
+--R                            - a c e  + b c d e  - c d e
+--R                 + 
+--R                                    +--------------+
+--R                        2        3  |   2
+--R                   (4a d e - 4b d )\|c x  + b x + a
+--R                 + 
+--R                             2 2 3
+--R                           8a d f
+--R                         + 
+--R                                2   2         2                 2  3  2
+--R                           (- 2a d e  - 8a b d e + (- 16a c + 8b )d )f
+--R                         + 
+--R                                    3              2  2 2         3      2 4
+--R                           (2a b d e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                         + 
+--R                                     4         2 3     2 3 2
+--R                           - 2a c d e  + 2b c d e  - 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - a e  + 2a b d e - b d
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2       2          2        3
+--R                       (- 2a d e  + 2b d e)x - 4a d e + 4b d
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R         ROOT
+--R                        2   3      2 2                         2  2  2
+--R                    - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                  + 
+--R                             3                2    2         2      2 3
+--R                    (- 2a b e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                  + 
+--R                          4           3     2 2 2
+--R                    2a c e  - 2b c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                          2 2               2 2
+--R                       - a e  + 2a b d e - b d
+--R                    /
+--R                           4   5       4 2     3              3      2 2  2  4
+--R                         4a d f  + (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                       + 
+--R                               3   3       3      2 2    2      2          3  2
+--R                             2a b e  + (12a c + 2a b )d e  + (8a b c - 8a b )d e
+--R                           + 
+--R                                 2 2        2      4  3
+--R                             (24a c  - 16a b c + 4b )d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                  3     2 2  4         2          3    3
+--R                             (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                           + 
+--R                                   2 2        2     4  2 2          2     3   3
+--R                             (- 22a c  + 20a b c - b )d e  + (8a b c  - 8b c)d e
+--R                           + 
+--R                                     3     2 2  4
+--R                             (- 16a c  + 8b c )d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                               2     5      2 2       2     4
+--R                             2a b c e  + (8a c  - 4a b c)d e
+--R                           + 
+--R                                       2     3   2 3         3     2 2  3 2
+--R                             (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                           + 
+--R                                   3 4      4 5
+--R                             - 8b c d e + 4c d
+--R                        *
+--R                           f
+--R                       + 
+--R                            2 2 6         2   5          3    2 2  2 4
+--R                         - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                       + 
+--R                             3 3 3    4 4 2
+--R                         2b c d e  - c d e
+--R              + 
+--R                             2                2
+--R                4a d f - 2a e  + 2b d e - 4c d
+--R           /
+--R                  2   3       2 2                          2  2  2
+--R                4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R              + 
+--R                      3            2    2         2      2 3          4
+--R                (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R              + 
+--R                       3    2 2 2
+--R                b c d e  - c d e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         log
+--R                            3 2 4      3   2     2   2        2        2  3  3
+--R                        - 8a d f  + (6a d e  + 4a b d e + (24a c - 8a b )d )f
+--R                      + 
+--R                               3 4     2     3         2         2  2 2
+--R                            - a e  - 5a b d e  + (- 22a c + 10a b )d e
+--R                          + 
+--R                                        3  3            2     2   4
+--R                            (8a b c - 4b )d e + (- 24a c  + 8b c)d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                             2   5      2        2    4                 3  2 3
+--R                            a b e  + (8a c - 2a b )d e  + (- 10a b c + b )d e
+--R                          + 
+--R                                  2     2   3 2        2 4      3 5
+--R                            (18a c  + 2b c)d e  - 12b c d e + 8c d
+--R                       *
+--R                          f
+--R                      + 
+--R                           2   6             5          2    2   2 4       2 3 3
+--R                        - a c e  + 2a b c d e  + (- 3a c  - b c)d e  + 3b c d e
+--R                      + 
+--R                            3 4 2
+--R                        - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - a e  + 2a b d e - b d
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                      2   2         2      2 3      2 4           3    2 2 2
+--R                  ((4a d e  - 8a b d e + 4b d )f - a e  + 2a b d e  - b d e )x
+--R               *
+--R                  ROOT
+--R                                 2   3      2 2                         2  2  2
+--R                             - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                           + 
+--R                                         3                2    2         2
+--R                                 - 2a b e  + (- 12a c + 2b )d e  + 8b c d e
+--R                               + 
+--R                                     2 3
+--R                                 - 8c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                   4           3     2 2 2
+--R                             2a c e  - 2b c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                   2 2               2 2
+--R                                - a e  + 2a b d e - b d
+--R                             /
+--R                                    4   5
+--R                                  4a d f
+--R                                + 
+--R                                      4 2     3              3      2 2  2  4
+--R                                  (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                + 
+--R                                        3   3       3      2 2    2
+--R                                      2a b e  + (12a c + 2a b )d e
+--R                                    + 
+--R                                         2          3  2
+--R                                      (8a b c - 8a b )d e
+--R                                    + 
+--R                                          2 2        2      4  3
+--R                                      (24a c  - 16a b c + 4b )d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                           3     2 2  4
+--R                                      (- 2a c - a b )e
+--R                                    + 
+--R                                            2          3    3
+--R                                      (- 10a b c + 2a b )d e
+--R                                    + 
+--R                                            2 2        2     4  2 2
+--R                                      (- 22a c  + 20a b c - b )d e
+--R                                    + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                        2     5      2 2       2     4
+--R                                      2a b c e  + (8a c  - 4a b c)d e
+--R                                    + 
+--R                                                2     3   2 3
+--R                                      (- 10a b c  + 2b c)d e
+--R                                    + 
+--R                                            3     2 2  3 2       3 4      4 5
+--R                                      (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     2 2 6         2   5          3    2 2  2 4
+--R                                  - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                                + 
+--R                                      3 3 3    4 4 2
+--R                                  2b c d e  - c d e
+--R                       + 
+--R                                      2                2
+--R                         4a d f - 2a e  + 2b d e - 4c d
+--R                    /
+--R                           2   3       2 2                          2  2  2
+--R                         4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                       + 
+--R                               3            2    2         2      2 3          4
+--R                         (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                       + 
+--R                                3    2 2 2
+--R                         b c d e  - c d e
+--R              + 
+--R                                 +--------------+
+--R                     2        3  |   2
+--R                (4a d e - 4b d )\|c x  + b x + a
+--R              + 
+--R                          2 2 3        2   2         2                 2  3  2
+--R                        8a d f  + (- 2a d e  - 8a b d e + (- 16a c + 8b )d )f
+--R                      + 
+--R                                 3              2  2 2         3      2 4
+--R                        (2a b d e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                      + 
+--R                                  4         2 3     2 3 2
+--R                        - 2a c d e  + 2b c d e  - 2c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - a e  + 2a b d e - b d
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                             2       2          2        3
+--R                    (- 2a d e  + 2b d e)x - 4a d e + 4b d
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2
+--R            \|2 \|- 4d f + e
+--R         *
+--R             +------------------------------------------------------------+
+--R             |              +-----------+
+--R             |              |          2        2                        2
+--R            \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R             +----------------------------------------------------------+
+--R             |            +-----------+
+--R             |            |          2        2                        2
+--R            \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            ROOT
+--R                         2   3        2 2                           2  2  2
+--R                       8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                     + 
+--R                              3              2    2         2      2 3
+--R                       (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                     + 
+--R                               4           3     2 2 2
+--R                       - 2a c e  + 2b c d e  - 2c d e
+--R                  *
+--R                     ROOT
+--R                             2 2               2 2
+--R                          - a e  + 2a b d e - b d
+--R                       /
+--R                              4   5
+--R                            4a d f
+--R                          + 
+--R                                4 2     3              3      2 2  2  4
+--R                            (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                          + 
+--R                                  3   3       3      2 2    2
+--R                                2a b e  + (12a c + 2a b )d e
+--R                              + 
+--R                                 2          3  2        2 2        2      4  3
+--R                              (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                           *
+--R                               3
+--R                              f
+--R                          + 
+--R                                     3     2 2  4         2          3    3
+--R                                (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                              + 
+--R                                      2 2        2     4  2 2
+--R                                (- 22a c  + 20a b c - b )d e
+--R                              + 
+--R                                       2     3   3            3     2 2  4
+--R                                (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                           *
+--R                               2
+--R                              f
+--R                          + 
+--R                                  2     5      2 2       2     4
+--R                                2a b c e  + (8a c  - 4a b c)d e
+--R                              + 
+--R                                          2     3   2 3         3     2 2  3 2
+--R                                (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                              + 
+--R                                      3 4      4 5
+--R                                - 8b c d e + 4c d
+--R                           *
+--R                              f
+--R                          + 
+--R                               2 2 6         2   5          3    2 2  2 4
+--R                            - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                          + 
+--R                                3 3 3    4 4 2
+--R                            2b c d e  - c d e
+--R                 + 
+--R                                2                2
+--R                   4a d f - 2a e  + 2b d e - 4c d
+--R              /
+--R                     2   3       2 2                          2  2  2
+--R                   4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                 + 
+--R                         3            2    2         2      2 3          4
+--R                   (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                 + 
+--R                          3    2 2 2
+--R                   b c d e  - c d e
+--R         *
+--R            log
+--R                               3 2 4
+--R                           - 8a d f
+--R                         + 
+--R                              3   2     2   2        2        2  3  3
+--R                           (6a d e  + 4a b d e + (24a c - 8a b )d )f
+--R                         + 
+--R                                  3 4     2     3         2         2  2 2
+--R                               - a e  - 5a b d e  + (- 22a c + 10a b )d e
+--R                             + 
+--R                                           3  3            2     2   4
+--R                               (8a b c - 4b )d e + (- 24a c  + 8b c)d
+--R                          *
+--R                              2
+--R                             f
+--R                         + 
+--R                                2   5      2        2    4
+--R                               a b e  + (8a c - 2a b )d e
+--R                             + 
+--R                                             3  2 3         2     2   3 2
+--R                               (- 10a b c + b )d e  + (18a c  + 2b c)d e
+--R                             + 
+--R                                      2 4      3 5
+--R                               - 12b c d e + 8c d
+--R                          *
+--R                             f
+--R                         + 
+--R                              2   6             5          2    2   2 4
+--R                           - a c e  + 2a b c d e  + (- 3a c  - b c)d e
+--R                         + 
+--R                               2 3 3     3 4 2
+--R                           3b c d e  - 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - a e  + 2a b d e - b d
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2   2         2      2 3      2 4           3
+--R                           (- 4a d e  + 8a b d e - 4b d )f + a e  - 2a b d e
+--R                         + 
+--R                            2 2 2
+--R                           b d e
+--R                      *
+--R                         x
+--R                  *
+--R                     ROOT
+--R                                  2   3
+--R                                8a d f
+--R                              + 
+--R                                     2 2                           2  2  2
+--R                                (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                              + 
+--R                                            3              2    2         2
+--R                                      2a b e  + (12a c - 2b )d e  - 8b c d e
+--R                                    + 
+--R                                        2 3
+--R                                      8c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                        4           3     2 2 2
+--R                                - 2a c e  + 2b c d e  - 2c d e
+--R                           *
+--R                              ROOT
+--R                                      2 2               2 2
+--R                                   - a e  + 2a b d e - b d
+--R                                /
+--R                                       4   5
+--R                                     4a d f
+--R                                   + 
+--R                                         4 2     3              3      2 2  2  4
+--R                                     (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                   + 
+--R                                           3   3       3      2 2    2
+--R                                         2a b e  + (12a c + 2a b )d e
+--R                                       + 
+--R                                            2          3  2
+--R                                         (8a b c - 8a b )d e
+--R                                       + 
+--R                                             2 2        2      4  3
+--R                                         (24a c  - 16a b c + 4b )d
+--R                                    *
+--R                                        3
+--R                                       f
+--R                                   + 
+--R                                              3     2 2  4
+--R                                         (- 2a c - a b )e
+--R                                       + 
+--R                                               2          3    3
+--R                                         (- 10a b c + 2a b )d e
+--R                                       + 
+--R                                               2 2        2     4  2 2
+--R                                         (- 22a c  + 20a b c - b )d e
+--R                                       + 
+--R                                                2     3   3
+--R                                         (8a b c  - 8b c)d e
+--R                                       + 
+--R                                                 3     2 2  4
+--R                                         (- 16a c  + 8b c )d
+--R                                    *
+--R                                        2
+--R                                       f
+--R                                   + 
+--R                                           2     5      2 2       2     4
+--R                                         2a b c e  + (8a c  - 4a b c)d e
+--R                                       + 
+--R                                                   2     3   2 3
+--R                                         (- 10a b c  + 2b c)d e
+--R                                       + 
+--R                                             3     2 2  3 2       3 4      4 5
+--R                                       (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                    *
+--R                                       f
+--R                                   + 
+--R                                        2 2 6         2   5
+--R                                     - a c e  + 2a b c d e
+--R                                   + 
+--R                                            3    2 2  2 4       3 3 3    4 4 2
+--R                                     (- 2a c  - b c )d e  + 2b c d e  - c d e
+--R                          + 
+--R                                         2                2
+--R                            4a d f - 2a e  + 2b d e - 4c d
+--R                       /
+--R                              2   3       2 2                          2  2  2
+--R                            4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                          + 
+--R                                  3            2    2         2      2 3
+--R                            (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f
+--R                          + 
+--R                                   4          3    2 2 2
+--R                            - a c e  + b c d e  - c d e
+--R                 + 
+--R                                    +--------------+
+--R                        2        3  |   2
+--R                   (4a d e - 4b d )\|c x  + b x + a
+--R                 + 
+--R                               2 2 3      2   2         2               2  3  2
+--R                           - 8a d f  + (2a d e  + 8a b d e + (16a c - 8b )d )f
+--R                         + 
+--R                                         3                2  2 2         3
+--R                               - 2a b d e  + (- 12a c + 2b )d e  + 8b c d e
+--R                             + 
+--R                                   2 4
+--R                               - 8c d
+--R                          *
+--R                             f
+--R                         + 
+--R                                   4         2 3     2 3 2
+--R                           2a c d e  - 2b c d e  + 2c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - a e  + 2a b d e - b d
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2       2          2        3
+--R                       (- 2a d e  + 2b d e)x - 4a d e + 4b d
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R              +-----------+
+--R              |          2
+--R         (- 2\|- 4d f + e   - 2e)
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R            +-----------+
+--R            |          2
+--R         (2\|- 4d f + e   - 2e)
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R             +-----------+
+--R         +-+ |          2
+--R       2\|2 \|- 4d f + e
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 341
+
+)clear all
+
+--S 342 of 1580
+t0:=1/((a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 1580
+r0:=-f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*sqrt(2)/(sqrt(e^2-4*d*f)*sqrt(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))+f*atanh(1/2*(4*a*f-_
+   b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*sqrt(2)/(sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R       -
+--R                  +----------------------------------------------------------+
+--R                  |            +-----------+
+--R              +-+ |            |          2        2                        2
+--R            f\|2 \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            atanh
+--R                            +-----------+
+--R                            |          2
+--R                 (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R              /
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|2 \|c x  + b x + a
+--R                *
+--R                  +------------------------------------------------------------+
+--R                  |              +-----------+
+--R                  |              |          2        2                        2
+--R                 \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R       -
+--R                  +------------------------------------------------------------+
+--R                  |              +-----------+
+--R              +-+ |              |          2        2                        2
+--R            f\|2 \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            atanh
+--R                            +-----------+
+--R                            |          2
+--R                 (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R              /
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|2 \|c x  + b x + a
+--R                *
+--R                  +----------------------------------------------------------+
+--R                  |            +-----------+
+--R                  |            |          2        2                        2
+--R                 \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R        +-----------+
+--R        |          2
+--R       \|- 4d f + e
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R                      2   3        2 2                           2  2  2
+--R                    8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                  + 
+--R                           3              2    2         2      2 3           4
+--R                    (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f - 2a c e
+--R                  + 
+--R                            3     2 2 2
+--R                    2b c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                          2 2               2 2
+--R                       - b f  + 2b c e f - c e
+--R                    /
+--R                           4   5       4 2     3              3      2 2  2  4
+--R                         4a d f  + (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                       + 
+--R                               3   3       3      2 2    2      2          3  2
+--R                             2a b e  + (12a c + 2a b )d e  + (8a b c - 8a b )d e
+--R                           + 
+--R                                 2 2        2      4  3
+--R                             (24a c  - 16a b c + 4b )d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                  3     2 2  4         2          3    3
+--R                             (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                           + 
+--R                                   2 2        2     4  2 2          2     3   3
+--R                             (- 22a c  + 20a b c - b )d e  + (8a b c  - 8b c)d e
+--R                           + 
+--R                                     3     2 2  4
+--R                             (- 16a c  + 8b c )d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                               2     5      2 2       2     4
+--R                             2a b c e  + (8a c  - 4a b c)d e
+--R                           + 
+--R                                       2     3   2 3         3     2 2  3 2
+--R                             (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                           + 
+--R                                   3 4      4 5
+--R                             - 8b c d e + 4c d
+--R                        *
+--R                           f
+--R                       + 
+--R                            2 2 6         2   5          3    2 2  2 4
+--R                         - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                       + 
+--R                             3 3 3    4 4 2
+--R                         2b c d e  - c d e
+--R              + 
+--R                      2                        2
+--R                - 4a f  + (2b e + 4c d)f - 2c e
+--R           /
+--R                  2   3       2 2                          2  2  2
+--R                4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R              + 
+--R                      3            2    2         2      2 3          4
+--R                (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R              + 
+--R                       3    2 2 2
+--R                b c d e  - c d e
+--R      *
+--R         log
+--R                           3        2   2  4
+--R                        (4a d e - 8a b d )f
+--R                      + 
+--R                               3 3     2     2        2         2  2
+--R                            - a e  - 2a b d e  + (- 4a c + 12a b )d e
+--R                          + 
+--R                                         3  3
+--R                            (16a b c - 8b )d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                             2   4      2        2    3                  3  2 2
+--R                            a b e  + (5a c - 3a b )d e  + (- 20a b c + 2b )d e
+--R                          + 
+--R                                   2      2   3        2 4
+--R                            (- 4a c  + 12b c)d e - 8b c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               2   5             4        2     2   2 3
+--R                            - a c e  + 4a b c d e  + (5a c  - 3b c)d e
+--R                          + 
+--R                                  2 3 2     3 4
+--R                            - 2b c d e  + 4c d e
+--R                       *
+--R                          f
+--R                      + 
+--R                             2   5      2 2 4    3 3 3
+--R                        - a c d e  + b c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - b f  + 2b c e f - c e
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                                  3         2                    2  2
+--R                        - 4a b d f  + (a b e  + 4a c d e + 4b c d )f
+--R                      + 
+--R                                3          2     2 2       2   3
+--R                        (- a c e  - b c d e  - 4c d e)f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               2   3
+--R                             8a d f
+--R                           + 
+--R                                  2 2                           2  2  2
+--R                             (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                           + 
+--R                                    3              2    2         2      2 3
+--R                             (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                           + 
+--R                                     4           3     2 2 2
+--R                             - 2a c e  + 2b c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                   2 2               2 2
+--R                                - b f  + 2b c e f - c e
+--R                             /
+--R                                    4   5
+--R                                  4a d f
+--R                                + 
+--R                                      4 2     3              3      2 2  2  4
+--R                                  (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                + 
+--R                                        3   3       3      2 2    2
+--R                                      2a b e  + (12a c + 2a b )d e
+--R                                    + 
+--R                                         2          3  2
+--R                                      (8a b c - 8a b )d e
+--R                                    + 
+--R                                          2 2        2      4  3
+--R                                      (24a c  - 16a b c + 4b )d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                           3     2 2  4
+--R                                      (- 2a c - a b )e
+--R                                    + 
+--R                                            2          3    3
+--R                                      (- 10a b c + 2a b )d e
+--R                                    + 
+--R                                            2 2        2     4  2 2
+--R                                      (- 22a c  + 20a b c - b )d e
+--R                                    + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                        2     5      2 2       2     4
+--R                                      2a b c e  + (8a c  - 4a b c)d e
+--R                                    + 
+--R                                                2     3   2 3
+--R                                      (- 10a b c  + 2b c)d e
+--R                                    + 
+--R                                            3     2 2  3 2       3 4      4 5
+--R                                      (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     2 2 6         2   5          3    2 2  2 4
+--R                                  - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                                + 
+--R                                      3 3 3    4 4 2
+--R                                  2b c d e  - c d e
+--R                       + 
+--R                               2                        2
+--R                         - 4a f  + (2b e + 4c d)f - 2c e
+--R                    /
+--R                           2   3       2 2                          2  2  2
+--R                         4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                       + 
+--R                               3            2    2         2      2 3          4
+--R                         (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                       + 
+--R                                3    2 2 2
+--R                         b c d e  - c d e
+--R              + 
+--R                                     +--------------+
+--R                       2             |   2
+--R                (4b d f  - 4c d e f)\|c x  + b x + a
+--R              + 
+--R                            2   4      2 2                         2  2  3
+--R                        - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                      + 
+--R                                 3                2    2         2      2 3  2
+--R                        (- 2a b e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                      + 
+--R                               4           3     2 2 2
+--R                        (2a c e  - 2b c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - b f  + 2b c e f - c e
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                             2       2            2
+--R                    (- 2b e f  + 2c e f)x - 4b d f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                           2   3      2 2                         2  2  2
+--R                       - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                     + 
+--R                                3                2    2         2      2 3
+--R                       (- 2a b e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                     + 
+--R                             4           3     2 2 2
+--R                       2a c e  - 2b c d e  + 2c d e
+--R                  *
+--R                     ROOT
+--R                             2 2               2 2
+--R                          - b f  + 2b c e f - c e
+--R                       /
+--R                              4   5
+--R                            4a d f
+--R                          + 
+--R                                4 2     3              3      2 2  2  4
+--R                            (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                          + 
+--R                                  3   3       3      2 2    2
+--R                                2a b e  + (12a c + 2a b )d e
+--R                              + 
+--R                                 2          3  2        2 2        2      4  3
+--R                              (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                           *
+--R                               3
+--R                              f
+--R                          + 
+--R                                     3     2 2  4         2          3    3
+--R                                (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                              + 
+--R                                      2 2        2     4  2 2
+--R                                (- 22a c  + 20a b c - b )d e
+--R                              + 
+--R                                       2     3   3            3     2 2  4
+--R                                (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                           *
+--R                               2
+--R                              f
+--R                          + 
+--R                                  2     5      2 2       2     4
+--R                                2a b c e  + (8a c  - 4a b c)d e
+--R                              + 
+--R                                          2     3   2 3         3     2 2  3 2
+--R                                (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                              + 
+--R                                      3 4      4 5
+--R                                - 8b c d e + 4c d
+--R                           *
+--R                              f
+--R                          + 
+--R                               2 2 6         2   5          3    2 2  2 4
+--R                            - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                          + 
+--R                                3 3 3    4 4 2
+--R                            2b c d e  - c d e
+--R                 + 
+--R                         2                        2
+--R                   - 4a f  + (2b e + 4c d)f - 2c e
+--R              /
+--R                     2   3       2 2                          2  2  2
+--R                   4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                 + 
+--R                         3            2    2         2      2 3          4
+--R                   (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                 + 
+--R                          3    2 2 2
+--R                   b c d e  - c d e
+--R         *
+--R            log
+--R                              3        2   2  4
+--R                           (4a d e - 8a b d )f
+--R                         + 
+--R                                  3 3     2     2        2         2  2
+--R                               - a e  - 2a b d e  + (- 4a c + 12a b )d e
+--R                             + 
+--R                                            3  3
+--R                               (16a b c - 8b )d
+--R                          *
+--R                              3
+--R                             f
+--R                         + 
+--R                                2   4      2        2    3
+--R                               a b e  + (5a c - 3a b )d e
+--R                             + 
+--R                                              3  2 2          2      2   3
+--R                               (- 20a b c + 2b )d e  + (- 4a c  + 12b c)d e
+--R                             + 
+--R                                     2 4
+--R                               - 8b c d
+--R                          *
+--R                              2
+--R                             f
+--R                         + 
+--R                                  2   5             4        2     2   2 3
+--R                               - a c e  + 4a b c d e  + (5a c  - 3b c)d e
+--R                             + 
+--R                                     2 3 2     3 4
+--R                               - 2b c d e  + 4c d e
+--R                          *
+--R                             f
+--R                         + 
+--R                                2   5      2 2 4    3 3 3
+--R                           - a c d e  + b c d e  - c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - b f  + 2b c e f - c e
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                   3           2                    2  2
+--R                           4a b d f  + (- a b e  - 4a c d e - 4b c d )f
+--R                         + 
+--R                                 3          2     2 2       2   3
+--R                           (a c e  + b c d e  + 4c d e)f - c d e
+--R                      *
+--R                         x
+--R                  *
+--R                     ROOT
+--R                                    2   3
+--R                                - 8a d f
+--R                              + 
+--R                                   2 2                         2  2  2
+--R                                (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                              + 
+--R                                            3                2    2         2
+--R                                    - 2a b e  + (- 12a c + 2b )d e  + 8b c d e
+--R                                  + 
+--R                                        2 3
+--R                                    - 8c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                      4           3     2 2 2
+--R                                2a c e  - 2b c d e  + 2c d e
+--R                           *
+--R                              ROOT
+--R                                      2 2               2 2
+--R                                   - b f  + 2b c e f - c e
+--R                                /
+--R                                       4   5
+--R                                     4a d f
+--R                                   + 
+--R                                         4 2     3              3      2 2  2  4
+--R                                     (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                   + 
+--R                                           3   3       3      2 2    2
+--R                                         2a b e  + (12a c + 2a b )d e
+--R                                       + 
+--R                                            2          3  2
+--R                                         (8a b c - 8a b )d e
+--R                                       + 
+--R                                             2 2        2      4  3
+--R                                         (24a c  - 16a b c + 4b )d
+--R                                    *
+--R                                        3
+--R                                       f
+--R                                   + 
+--R                                              3     2 2  4
+--R                                         (- 2a c - a b )e
+--R                                       + 
+--R                                               2          3    3
+--R                                         (- 10a b c + 2a b )d e
+--R                                       + 
+--R                                               2 2        2     4  2 2
+--R                                         (- 22a c  + 20a b c - b )d e
+--R                                       + 
+--R                                                2     3   3
+--R                                         (8a b c  - 8b c)d e
+--R                                       + 
+--R                                                 3     2 2  4
+--R                                         (- 16a c  + 8b c )d
+--R                                    *
+--R                                        2
+--R                                       f
+--R                                   + 
+--R                                           2     5      2 2       2     4
+--R                                         2a b c e  + (8a c  - 4a b c)d e
+--R                                       + 
+--R                                                   2     3   2 3
+--R                                         (- 10a b c  + 2b c)d e
+--R                                       + 
+--R                                             3     2 2  3 2       3 4      4 5
+--R                                       (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                    *
+--R                                       f
+--R                                   + 
+--R                                        2 2 6         2   5
+--R                                     - a c e  + 2a b c d e
+--R                                   + 
+--R                                            3    2 2  2 4       3 3 3    4 4 2
+--R                                     (- 2a c  - b c )d e  + 2b c d e  - c d e
+--R                          + 
+--R                                  2                        2
+--R                            - 4a f  + (2b e + 4c d)f - 2c e
+--R                       /
+--R                              2   3       2 2                          2  2  2
+--R                            4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                          + 
+--R                                  3            2    2         2      2 3
+--R                            (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f
+--R                          + 
+--R                                   4          3    2 2 2
+--R                            - a c e  + b c d e  - c d e
+--R                 + 
+--R                                        +--------------+
+--R                          2             |   2
+--R                   (4b d f  - 4c d e f)\|c x  + b x + a
+--R                 + 
+--R                             2   4        2 2                           2  2  3
+--R                           8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                         + 
+--R                                  3              2    2         2      2 3  2
+--R                           (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                         + 
+--R                                    4           3     2 2 2
+--R                           (- 2a c e  + 2b c d e  - 2c d e )f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - b f  + 2b c e f - c e
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2       2            2
+--R                       (- 2b e f  + 2c e f)x - 4b d f  + 4c d e f
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R         ROOT
+--R                        2   3      2 2                         2  2  2
+--R                    - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                  + 
+--R                             3                2    2         2      2 3
+--R                    (- 2a b e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                  + 
+--R                          4           3     2 2 2
+--R                    2a c e  - 2b c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                          2 2               2 2
+--R                       - b f  + 2b c e f - c e
+--R                    /
+--R                           4   5       4 2     3              3      2 2  2  4
+--R                         4a d f  + (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                       + 
+--R                               3   3       3      2 2    2      2          3  2
+--R                             2a b e  + (12a c + 2a b )d e  + (8a b c - 8a b )d e
+--R                           + 
+--R                                 2 2        2      4  3
+--R                             (24a c  - 16a b c + 4b )d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                  3     2 2  4         2          3    3
+--R                             (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                           + 
+--R                                   2 2        2     4  2 2          2     3   3
+--R                             (- 22a c  + 20a b c - b )d e  + (8a b c  - 8b c)d e
+--R                           + 
+--R                                     3     2 2  4
+--R                             (- 16a c  + 8b c )d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                               2     5      2 2       2     4
+--R                             2a b c e  + (8a c  - 4a b c)d e
+--R                           + 
+--R                                       2     3   2 3         3     2 2  3 2
+--R                             (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                           + 
+--R                                   3 4      4 5
+--R                             - 8b c d e + 4c d
+--R                        *
+--R                           f
+--R                       + 
+--R                            2 2 6         2   5          3    2 2  2 4
+--R                         - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                       + 
+--R                             3 3 3    4 4 2
+--R                         2b c d e  - c d e
+--R              + 
+--R                      2                        2
+--R                - 4a f  + (2b e + 4c d)f - 2c e
+--R           /
+--R                  2   3       2 2                          2  2  2
+--R                4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R              + 
+--R                      3            2    2         2      2 3          4
+--R                (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R              + 
+--R                       3    2 2 2
+--R                b c d e  - c d e
+--R      *
+--R         log
+--R                             3        2   2  4
+--R                        (- 4a d e + 8a b d )f
+--R                      + 
+--R                             3 3     2     2      2         2  2
+--R                            a e  + 2a b d e  + (4a c - 12a b )d e
+--R                          + 
+--R                                           3  3
+--R                            (- 16a b c + 8b )d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                               2   4        2        2    3
+--R                            - a b e  + (- 5a c + 3a b )d e
+--R                          + 
+--R                                         3  2 2        2      2   3        2 4
+--R                            (20a b c - 2b )d e  + (4a c  - 12b c)d e + 8b c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                             2   5             4          2     2   2 3
+--R                            a c e  - 4a b c d e  + (- 5a c  + 3b c)d e
+--R                          + 
+--R                                2 3 2     3 4
+--R                            2b c d e  - 4c d e
+--R                       *
+--R                          f
+--R                      + 
+--R                           2   5      2 2 4    3 3 3
+--R                        a c d e  - b c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - b f  + 2b c e f - c e
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                                  3         2                    2  2
+--R                        - 4a b d f  + (a b e  + 4a c d e + 4b c d )f
+--R                      + 
+--R                                3          2     2 2       2   3
+--R                        (- a c e  - b c d e  - 4c d e)f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 2   3      2 2                         2  2  2
+--R                             - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                           + 
+--R                                         3                2    2         2
+--R                                 - 2a b e  + (- 12a c + 2b )d e  + 8b c d e
+--R                               + 
+--R                                     2 3
+--R                                 - 8c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                   4           3     2 2 2
+--R                             2a c e  - 2b c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                   2 2               2 2
+--R                                - b f  + 2b c e f - c e
+--R                             /
+--R                                    4   5
+--R                                  4a d f
+--R                                + 
+--R                                      4 2     3              3      2 2  2  4
+--R                                  (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                + 
+--R                                        3   3       3      2 2    2
+--R                                      2a b e  + (12a c + 2a b )d e
+--R                                    + 
+--R                                         2          3  2
+--R                                      (8a b c - 8a b )d e
+--R                                    + 
+--R                                          2 2        2      4  3
+--R                                      (24a c  - 16a b c + 4b )d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                           3     2 2  4
+--R                                      (- 2a c - a b )e
+--R                                    + 
+--R                                            2          3    3
+--R                                      (- 10a b c + 2a b )d e
+--R                                    + 
+--R                                            2 2        2     4  2 2
+--R                                      (- 22a c  + 20a b c - b )d e
+--R                                    + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                        2     5      2 2       2     4
+--R                                      2a b c e  + (8a c  - 4a b c)d e
+--R                                    + 
+--R                                                2     3   2 3
+--R                                      (- 10a b c  + 2b c)d e
+--R                                    + 
+--R                                            3     2 2  3 2       3 4      4 5
+--R                                      (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     2 2 6         2   5          3    2 2  2 4
+--R                                  - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                                + 
+--R                                      3 3 3    4 4 2
+--R                                  2b c d e  - c d e
+--R                       + 
+--R                               2                        2
+--R                         - 4a f  + (2b e + 4c d)f - 2c e
+--R                    /
+--R                           2   3       2 2                          2  2  2
+--R                         4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                       + 
+--R                               3            2    2         2      2 3          4
+--R                         (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                       + 
+--R                                3    2 2 2
+--R                         b c d e  - c d e
+--R              + 
+--R                                     +--------------+
+--R                       2             |   2
+--R                (4b d f  - 4c d e f)\|c x  + b x + a
+--R              + 
+--R                          2   4        2 2                           2  2  3
+--R                        8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                      + 
+--R                               3              2    2         2      2 3  2
+--R                        (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                      + 
+--R                                 4           3     2 2 2
+--R                        (- 2a c e  + 2b c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - b f  + 2b c e f - c e
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                             2       2            2
+--R                    (- 2b e f  + 2c e f)x - 4b d f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                         2   3        2 2                           2  2  2
+--R                       8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                     + 
+--R                              3              2    2         2      2 3
+--R                       (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                     + 
+--R                               4           3     2 2 2
+--R                       - 2a c e  + 2b c d e  - 2c d e
+--R                  *
+--R                     ROOT
+--R                             2 2               2 2
+--R                          - b f  + 2b c e f - c e
+--R                       /
+--R                              4   5
+--R                            4a d f
+--R                          + 
+--R                                4 2     3              3      2 2  2  4
+--R                            (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                          + 
+--R                                  3   3       3      2 2    2
+--R                                2a b e  + (12a c + 2a b )d e
+--R                              + 
+--R                                 2          3  2        2 2        2      4  3
+--R                              (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                           *
+--R                               3
+--R                              f
+--R                          + 
+--R                                     3     2 2  4         2          3    3
+--R                                (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                              + 
+--R                                      2 2        2     4  2 2
+--R                                (- 22a c  + 20a b c - b )d e
+--R                              + 
+--R                                       2     3   3            3     2 2  4
+--R                                (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                           *
+--R                               2
+--R                              f
+--R                          + 
+--R                                  2     5      2 2       2     4
+--R                                2a b c e  + (8a c  - 4a b c)d e
+--R                              + 
+--R                                          2     3   2 3         3     2 2  3 2
+--R                                (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                              + 
+--R                                      3 4      4 5
+--R                                - 8b c d e + 4c d
+--R                           *
+--R                              f
+--R                          + 
+--R                               2 2 6         2   5          3    2 2  2 4
+--R                            - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                          + 
+--R                                3 3 3    4 4 2
+--R                            2b c d e  - c d e
+--R                 + 
+--R                         2                        2
+--R                   - 4a f  + (2b e + 4c d)f - 2c e
+--R              /
+--R                     2   3       2 2                          2  2  2
+--R                   4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                 + 
+--R                         3            2    2         2      2 3          4
+--R                   (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                 + 
+--R                          3    2 2 2
+--R                   b c d e  - c d e
+--R         *
+--R            log
+--R                                3        2   2  4
+--R                           (- 4a d e + 8a b d )f
+--R                         + 
+--R                                3 3     2     2      2         2  2
+--R                               a e  + 2a b d e  + (4a c - 12a b )d e
+--R                             + 
+--R                                              3  3
+--R                               (- 16a b c + 8b )d
+--R                          *
+--R                              3
+--R                             f
+--R                         + 
+--R                                  2   4        2        2    3
+--R                               - a b e  + (- 5a c + 3a b )d e
+--R                             + 
+--R                                          3  2 2        2      2   3        2 4
+--R                             (20a b c - 2b )d e  + (4a c  - 12b c)d e + 8b c d
+--R                          *
+--R                              2
+--R                             f
+--R                         + 
+--R                                2   5             4          2     2   2 3
+--R                               a c e  - 4a b c d e  + (- 5a c  + 3b c)d e
+--R                             + 
+--R                                   2 3 2     3 4
+--R                               2b c d e  - 4c d e
+--R                          *
+--R                             f
+--R                         + 
+--R                              2   5      2 2 4    3 3 3
+--R                           a c d e  - b c d e  + c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - b f  + 2b c e f - c e
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                   3           2                    2  2
+--R                           4a b d f  + (- a b e  - 4a c d e - 4b c d )f
+--R                         + 
+--R                                 3          2     2 2       2   3
+--R                           (a c e  + b c d e  + 4c d e)f - c d e
+--R                      *
+--R                         x
+--R                  *
+--R                     ROOT
+--R                                  2   3
+--R                                8a d f
+--R                              + 
+--R                                     2 2                           2  2  2
+--R                                (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                              + 
+--R                                            3              2    2         2
+--R                                      2a b e  + (12a c - 2b )d e  - 8b c d e
+--R                                    + 
+--R                                        2 3
+--R                                      8c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                        4           3     2 2 2
+--R                                - 2a c e  + 2b c d e  - 2c d e
+--R                           *
+--R                              ROOT
+--R                                      2 2               2 2
+--R                                   - b f  + 2b c e f - c e
+--R                                /
+--R                                       4   5
+--R                                     4a d f
+--R                                   + 
+--R                                         4 2     3              3      2 2  2  4
+--R                                     (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                   + 
+--R                                           3   3       3      2 2    2
+--R                                         2a b e  + (12a c + 2a b )d e
+--R                                       + 
+--R                                            2          3  2
+--R                                         (8a b c - 8a b )d e
+--R                                       + 
+--R                                             2 2        2      4  3
+--R                                         (24a c  - 16a b c + 4b )d
+--R                                    *
+--R                                        3
+--R                                       f
+--R                                   + 
+--R                                              3     2 2  4
+--R                                         (- 2a c - a b )e
+--R                                       + 
+--R                                               2          3    3
+--R                                         (- 10a b c + 2a b )d e
+--R                                       + 
+--R                                               2 2        2     4  2 2
+--R                                         (- 22a c  + 20a b c - b )d e
+--R                                       + 
+--R                                                2     3   3
+--R                                         (8a b c  - 8b c)d e
+--R                                       + 
+--R                                                 3     2 2  4
+--R                                         (- 16a c  + 8b c )d
+--R                                    *
+--R                                        2
+--R                                       f
+--R                                   + 
+--R                                           2     5      2 2       2     4
+--R                                         2a b c e  + (8a c  - 4a b c)d e
+--R                                       + 
+--R                                                   2     3   2 3
+--R                                         (- 10a b c  + 2b c)d e
+--R                                       + 
+--R                                             3     2 2  3 2       3 4      4 5
+--R                                       (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                    *
+--R                                       f
+--R                                   + 
+--R                                        2 2 6         2   5
+--R                                     - a c e  + 2a b c d e
+--R                                   + 
+--R                                            3    2 2  2 4       3 3 3    4 4 2
+--R                                     (- 2a c  - b c )d e  + 2b c d e  - c d e
+--R                          + 
+--R                                  2                        2
+--R                            - 4a f  + (2b e + 4c d)f - 2c e
+--R                       /
+--R                              2   3       2 2                          2  2  2
+--R                            4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                          + 
+--R                                  3            2    2         2      2 3
+--R                            (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f
+--R                          + 
+--R                                   4          3    2 2 2
+--R                            - a c e  + b c d e  - c d e
+--R                 + 
+--R                                        +--------------+
+--R                          2             |   2
+--R                   (4b d f  - 4c d e f)\|c x  + b x + a
+--R                 + 
+--R                               2   4      2 2                         2  2  3
+--R                           - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                         + 
+--R                                         3                2    2         2
+--R                                 - 2a b e  + (- 12a c + 2b )d e  + 8b c d e
+--R                               + 
+--R                                     2 3
+--R                                 - 8c d
+--R                          *
+--R                              2
+--R                             f
+--R                         + 
+--R                                  4           3     2 2 2
+--R                           (2a c e  - 2b c d e  + 2c d e )f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - b f  + 2b c e f - c e
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2       2            2
+--R                       (- 2b e f  + 2c e f)x - 4b d f  + 4c d e f
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 344
+
+--S 345 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +-----------+
+--R          |          2
+--R         \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         ROOT
+--R                      2   3        2 2                           2  2  2
+--R                    8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                  + 
+--R                           3              2    2         2      2 3           4
+--R                    (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f - 2a c e
+--R                  + 
+--R                            3     2 2 2
+--R                    2b c d e  - 2c d e
+--R               *
+--R                  ROOT
+--R                          2 2               2 2
+--R                       - b f  + 2b c e f - c e
+--R                    /
+--R                           4   5       4 2     3              3      2 2  2  4
+--R                         4a d f  + (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                       + 
+--R                               3   3       3      2 2    2      2          3  2
+--R                             2a b e  + (12a c + 2a b )d e  + (8a b c - 8a b )d e
+--R                           + 
+--R                                 2 2        2      4  3
+--R                             (24a c  - 16a b c + 4b )d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                  3     2 2  4         2          3    3
+--R                             (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                           + 
+--R                                   2 2        2     4  2 2          2     3   3
+--R                             (- 22a c  + 20a b c - b )d e  + (8a b c  - 8b c)d e
+--R                           + 
+--R                                     3     2 2  4
+--R                             (- 16a c  + 8b c )d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                               2     5      2 2       2     4
+--R                             2a b c e  + (8a c  - 4a b c)d e
+--R                           + 
+--R                                       2     3   2 3         3     2 2  3 2
+--R                             (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                           + 
+--R                                   3 4      4 5
+--R                             - 8b c d e + 4c d
+--R                        *
+--R                           f
+--R                       + 
+--R                            2 2 6         2   5          3    2 2  2 4
+--R                         - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                       + 
+--R                             3 3 3    4 4 2
+--R                         2b c d e  - c d e
+--R              + 
+--R                      2                        2
+--R                - 4a f  + (2b e + 4c d)f - 2c e
+--R           /
+--R                  2   3       2 2                          2  2  2
+--R                4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R              + 
+--R                      3            2    2         2      2 3          4
+--R                (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R              + 
+--R                       3    2 2 2
+--R                b c d e  - c d e
+--R      *
+--R         log
+--R                           3        2   2  4
+--R                        (4a d e - 8a b d )f
+--R                      + 
+--R                               3 3     2     2        2         2  2
+--R                            - a e  - 2a b d e  + (- 4a c + 12a b )d e
+--R                          + 
+--R                                         3  3
+--R                            (16a b c - 8b )d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                             2   4      2        2    3                  3  2 2
+--R                            a b e  + (5a c - 3a b )d e  + (- 20a b c + 2b )d e
+--R                          + 
+--R                                   2      2   3        2 4
+--R                            (- 4a c  + 12b c)d e - 8b c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                               2   5             4        2     2   2 3
+--R                            - a c e  + 4a b c d e  + (5a c  - 3b c)d e
+--R                          + 
+--R                                  2 3 2     3 4
+--R                            - 2b c d e  + 4c d e
+--R                       *
+--R                          f
+--R                      + 
+--R                             2   5      2 2 4    3 3 3
+--R                        - a c d e  + b c d e  - c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - b f  + 2b c e f - c e
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                                  3         2                    2  2
+--R                        - 4a b d f  + (a b e  + 4a c d e + 4b c d )f
+--R                      + 
+--R                                3          2     2 2       2   3
+--R                        (- a c e  - b c d e  - 4c d e)f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                               2   3
+--R                             8a d f
+--R                           + 
+--R                                  2 2                           2  2  2
+--R                             (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                           + 
+--R                                    3              2    2         2      2 3
+--R                             (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                           + 
+--R                                     4           3     2 2 2
+--R                             - 2a c e  + 2b c d e  - 2c d e
+--R                        *
+--R                           ROOT
+--R                                   2 2               2 2
+--R                                - b f  + 2b c e f - c e
+--R                             /
+--R                                    4   5
+--R                                  4a d f
+--R                                + 
+--R                                      4 2     3              3      2 2  2  4
+--R                                  (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                + 
+--R                                        3   3       3      2 2    2
+--R                                      2a b e  + (12a c + 2a b )d e
+--R                                    + 
+--R                                         2          3  2
+--R                                      (8a b c - 8a b )d e
+--R                                    + 
+--R                                          2 2        2      4  3
+--R                                      (24a c  - 16a b c + 4b )d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                           3     2 2  4
+--R                                      (- 2a c - a b )e
+--R                                    + 
+--R                                            2          3    3
+--R                                      (- 10a b c + 2a b )d e
+--R                                    + 
+--R                                            2 2        2     4  2 2
+--R                                      (- 22a c  + 20a b c - b )d e
+--R                                    + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                        2     5      2 2       2     4
+--R                                      2a b c e  + (8a c  - 4a b c)d e
+--R                                    + 
+--R                                                2     3   2 3
+--R                                      (- 10a b c  + 2b c)d e
+--R                                    + 
+--R                                            3     2 2  3 2       3 4      4 5
+--R                                      (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     2 2 6         2   5          3    2 2  2 4
+--R                                  - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                                + 
+--R                                      3 3 3    4 4 2
+--R                                  2b c d e  - c d e
+--R                       + 
+--R                               2                        2
+--R                         - 4a f  + (2b e + 4c d)f - 2c e
+--R                    /
+--R                           2   3       2 2                          2  2  2
+--R                         4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                       + 
+--R                               3            2    2         2      2 3          4
+--R                         (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                       + 
+--R                                3    2 2 2
+--R                         b c d e  - c d e
+--R              + 
+--R                                     +--------------+
+--R                       2             |   2
+--R                (4b d f  - 4c d e f)\|c x  + b x + a
+--R              + 
+--R                            2   4      2 2                         2  2  3
+--R                        - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                      + 
+--R                                 3                2    2         2      2 3  2
+--R                        (- 2a b e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                      + 
+--R                               4           3     2 2 2
+--R                        (2a c e  - 2b c d e  + 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - b f  + 2b c e f - c e
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                             2       2            2
+--R                    (- 2b e f  + 2c e f)x - 4b d f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R             +-----------+
+--R             |          2
+--R            \|- 4d f + e
+--R         *
+--R            ROOT
+--R                           2   3      2 2                         2  2  2
+--R                       - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                     + 
+--R                                3                2    2         2      2 3
+--R                       (- 2a b e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                     + 
+--R                             4           3     2 2 2
+--R                       2a c e  - 2b c d e  + 2c d e
+--R                  *
+--R                     ROOT
+--R                             2 2               2 2
+--R                          - b f  + 2b c e f - c e
+--R                       /
+--R                              4   5
+--R                            4a d f
+--R                          + 
+--R                                4 2     3              3      2 2  2  4
+--R                            (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                          + 
+--R                                  3   3       3      2 2    2
+--R                                2a b e  + (12a c + 2a b )d e
+--R                              + 
+--R                                 2          3  2        2 2        2      4  3
+--R                              (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                           *
+--R                               3
+--R                              f
+--R                          + 
+--R                                     3     2 2  4         2          3    3
+--R                                (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                              + 
+--R                                      2 2        2     4  2 2
+--R                                (- 22a c  + 20a b c - b )d e
+--R                              + 
+--R                                       2     3   3            3     2 2  4
+--R                                (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                           *
+--R                               2
+--R                              f
+--R                          + 
+--R                                  2     5      2 2       2     4
+--R                                2a b c e  + (8a c  - 4a b c)d e
+--R                              + 
+--R                                          2     3   2 3         3     2 2  3 2
+--R                                (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                              + 
+--R                                      3 4      4 5
+--R                                - 8b c d e + 4c d
+--R                           *
+--R                              f
+--R                          + 
+--R                               2 2 6         2   5          3    2 2  2 4
+--R                            - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                          + 
+--R                                3 3 3    4 4 2
+--R                            2b c d e  - c d e
+--R                 + 
+--R                         2                        2
+--R                   - 4a f  + (2b e + 4c d)f - 2c e
+--R              /
+--R                     2   3       2 2                          2  2  2
+--R                   4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                 + 
+--R                         3            2    2         2      2 3          4
+--R                   (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                 + 
+--R                          3    2 2 2
+--R                   b c d e  - c d e
+--R         *
+--R             +------------------------------------------------------------+
+--R             |              +-----------+
+--R             |              |          2        2                        2
+--R            \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R             +----------------------------------------------------------+
+--R             |            +-----------+
+--R             |            |          2        2                        2
+--R            \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            log
+--R                              3        2   2  4
+--R                           (4a d e - 8a b d )f
+--R                         + 
+--R                                  3 3     2     2        2         2  2
+--R                               - a e  - 2a b d e  + (- 4a c + 12a b )d e
+--R                             + 
+--R                                            3  3
+--R                               (16a b c - 8b )d
+--R                          *
+--R                              3
+--R                             f
+--R                         + 
+--R                                2   4      2        2    3
+--R                               a b e  + (5a c - 3a b )d e
+--R                             + 
+--R                                              3  2 2          2      2   3
+--R                               (- 20a b c + 2b )d e  + (- 4a c  + 12b c)d e
+--R                             + 
+--R                                     2 4
+--R                               - 8b c d
+--R                          *
+--R                              2
+--R                             f
+--R                         + 
+--R                                  2   5             4        2     2   2 3
+--R                               - a c e  + 4a b c d e  + (5a c  - 3b c)d e
+--R                             + 
+--R                                     2 3 2     3 4
+--R                               - 2b c d e  + 4c d e
+--R                          *
+--R                             f
+--R                         + 
+--R                                2   5      2 2 4    3 3 3
+--R                           - a c d e  + b c d e  - c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - b f  + 2b c e f - c e
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                   3           2                    2  2
+--R                           4a b d f  + (- a b e  - 4a c d e - 4b c d )f
+--R                         + 
+--R                                 3          2     2 2       2   3
+--R                           (a c e  + b c d e  + 4c d e)f - c d e
+--R                      *
+--R                         x
+--R                  *
+--R                     ROOT
+--R                                    2   3
+--R                                - 8a d f
+--R                              + 
+--R                                   2 2                         2  2  2
+--R                                (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                              + 
+--R                                            3                2    2         2
+--R                                    - 2a b e  + (- 12a c + 2b )d e  + 8b c d e
+--R                                  + 
+--R                                        2 3
+--R                                    - 8c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                      4           3     2 2 2
+--R                                2a c e  - 2b c d e  + 2c d e
+--R                           *
+--R                              ROOT
+--R                                      2 2               2 2
+--R                                   - b f  + 2b c e f - c e
+--R                                /
+--R                                       4   5
+--R                                     4a d f
+--R                                   + 
+--R                                         4 2     3              3      2 2  2  4
+--R                                     (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                   + 
+--R                                           3   3       3      2 2    2
+--R                                         2a b e  + (12a c + 2a b )d e
+--R                                       + 
+--R                                            2          3  2
+--R                                         (8a b c - 8a b )d e
+--R                                       + 
+--R                                             2 2        2      4  3
+--R                                         (24a c  - 16a b c + 4b )d
+--R                                    *
+--R                                        3
+--R                                       f
+--R                                   + 
+--R                                              3     2 2  4
+--R                                         (- 2a c - a b )e
+--R                                       + 
+--R                                               2          3    3
+--R                                         (- 10a b c + 2a b )d e
+--R                                       + 
+--R                                               2 2        2     4  2 2
+--R                                         (- 22a c  + 20a b c - b )d e
+--R                                       + 
+--R                                                2     3   3
+--R                                         (8a b c  - 8b c)d e
+--R                                       + 
+--R                                                 3     2 2  4
+--R                                         (- 16a c  + 8b c )d
+--R                                    *
+--R                                        2
+--R                                       f
+--R                                   + 
+--R                                           2     5      2 2       2     4
+--R                                         2a b c e  + (8a c  - 4a b c)d e
+--R                                       + 
+--R                                                   2     3   2 3
+--R                                         (- 10a b c  + 2b c)d e
+--R                                       + 
+--R                                             3     2 2  3 2       3 4      4 5
+--R                                       (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                    *
+--R                                       f
+--R                                   + 
+--R                                        2 2 6         2   5
+--R                                     - a c e  + 2a b c d e
+--R                                   + 
+--R                                            3    2 2  2 4       3 3 3    4 4 2
+--R                                     (- 2a c  - b c )d e  + 2b c d e  - c d e
+--R                          + 
+--R                                  2                        2
+--R                            - 4a f  + (2b e + 4c d)f - 2c e
+--R                       /
+--R                              2   3       2 2                          2  2  2
+--R                            4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                          + 
+--R                                  3            2    2         2      2 3
+--R                            (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f
+--R                          + 
+--R                                   4          3    2 2 2
+--R                            - a c e  + b c d e  - c d e
+--R                 + 
+--R                                        +--------------+
+--R                          2             |   2
+--R                   (4b d f  - 4c d e f)\|c x  + b x + a
+--R                 + 
+--R                             2   4        2 2                           2  2  3
+--R                           8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                         + 
+--R                                  3              2    2         2      2 3  2
+--R                           (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                         + 
+--R                                    4           3     2 2 2
+--R                           (- 2a c e  + 2b c d e  - 2c d e )f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - b f  + 2b c e f - c e
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2       2            2
+--R                       (- 2b e f  + 2c e f)x - 4b d f  + 4c d e f
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R          +-----------+
+--R          |          2
+--R         \|- 4d f + e
+--R      *
+--R         ROOT
+--R                        2   3      2 2                         2  2  2
+--R                    - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                  + 
+--R                             3                2    2         2      2 3
+--R                    (- 2a b e  + (- 12a c + 2b )d e  + 8b c d e - 8c d )f
+--R                  + 
+--R                          4           3     2 2 2
+--R                    2a c e  - 2b c d e  + 2c d e
+--R               *
+--R                  ROOT
+--R                          2 2               2 2
+--R                       - b f  + 2b c e f - c e
+--R                    /
+--R                           4   5       4 2     3              3      2 2  2  4
+--R                         4a d f  + (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                       + 
+--R                               3   3       3      2 2    2      2          3  2
+--R                             2a b e  + (12a c + 2a b )d e  + (8a b c - 8a b )d e
+--R                           + 
+--R                                 2 2        2      4  3
+--R                             (24a c  - 16a b c + 4b )d
+--R                        *
+--R                            3
+--R                           f
+--R                       + 
+--R                                  3     2 2  4         2          3    3
+--R                             (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                           + 
+--R                                   2 2        2     4  2 2          2     3   3
+--R                             (- 22a c  + 20a b c - b )d e  + (8a b c  - 8b c)d e
+--R                           + 
+--R                                     3     2 2  4
+--R                             (- 16a c  + 8b c )d
+--R                        *
+--R                            2
+--R                           f
+--R                       + 
+--R                               2     5      2 2       2     4
+--R                             2a b c e  + (8a c  - 4a b c)d e
+--R                           + 
+--R                                       2     3   2 3         3     2 2  3 2
+--R                             (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                           + 
+--R                                   3 4      4 5
+--R                             - 8b c d e + 4c d
+--R                        *
+--R                           f
+--R                       + 
+--R                            2 2 6         2   5          3    2 2  2 4
+--R                         - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                       + 
+--R                             3 3 3    4 4 2
+--R                         2b c d e  - c d e
+--R              + 
+--R                      2                        2
+--R                - 4a f  + (2b e + 4c d)f - 2c e
+--R           /
+--R                  2   3       2 2                          2  2  2
+--R                4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R              + 
+--R                      3            2    2         2      2 3          4
+--R                (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R              + 
+--R                       3    2 2 2
+--R                b c d e  - c d e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         log
+--R                             3        2   2  4
+--R                        (- 4a d e + 8a b d )f
+--R                      + 
+--R                             3 3     2     2      2         2  2
+--R                            a e  + 2a b d e  + (4a c - 12a b )d e
+--R                          + 
+--R                                           3  3
+--R                            (- 16a b c + 8b )d
+--R                       *
+--R                           3
+--R                          f
+--R                      + 
+--R                               2   4        2        2    3
+--R                            - a b e  + (- 5a c + 3a b )d e
+--R                          + 
+--R                                         3  2 2        2      2   3        2 4
+--R                            (20a b c - 2b )d e  + (4a c  - 12b c)d e + 8b c d
+--R                       *
+--R                           2
+--R                          f
+--R                      + 
+--R                             2   5             4          2     2   2 3
+--R                            a c e  - 4a b c d e  + (- 5a c  + 3b c)d e
+--R                          + 
+--R                                2 3 2     3 4
+--R                            2b c d e  - 4c d e
+--R                       *
+--R                          f
+--R                      + 
+--R                           2   5      2 2 4    3 3 3
+--R                        a c d e  - b c d e  + c d e
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - b f  + 2b c e f - c e
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                                  3         2                    2  2
+--R                        - 4a b d f  + (a b e  + 4a c d e + 4b c d )f
+--R                      + 
+--R                                3          2     2 2       2   3
+--R                        (- a c e  - b c d e  - 4c d e)f + c d e
+--R                   *
+--R                      x
+--R               *
+--R                  ROOT
+--R                                 2   3      2 2                         2  2  2
+--R                             - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                           + 
+--R                                         3                2    2         2
+--R                                 - 2a b e  + (- 12a c + 2b )d e  + 8b c d e
+--R                               + 
+--R                                     2 3
+--R                                 - 8c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                   4           3     2 2 2
+--R                             2a c e  - 2b c d e  + 2c d e
+--R                        *
+--R                           ROOT
+--R                                   2 2               2 2
+--R                                - b f  + 2b c e f - c e
+--R                             /
+--R                                    4   5
+--R                                  4a d f
+--R                                + 
+--R                                      4 2     3              3      2 2  2  4
+--R                                  (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                + 
+--R                                        3   3       3      2 2    2
+--R                                      2a b e  + (12a c + 2a b )d e
+--R                                    + 
+--R                                         2          3  2
+--R                                      (8a b c - 8a b )d e
+--R                                    + 
+--R                                          2 2        2      4  3
+--R                                      (24a c  - 16a b c + 4b )d
+--R                                 *
+--R                                     3
+--R                                    f
+--R                                + 
+--R                                           3     2 2  4
+--R                                      (- 2a c - a b )e
+--R                                    + 
+--R                                            2          3    3
+--R                                      (- 10a b c + 2a b )d e
+--R                                    + 
+--R                                            2 2        2     4  2 2
+--R                                      (- 22a c  + 20a b c - b )d e
+--R                                    + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                                 *
+--R                                     2
+--R                                    f
+--R                                + 
+--R                                        2     5      2 2       2     4
+--R                                      2a b c e  + (8a c  - 4a b c)d e
+--R                                    + 
+--R                                                2     3   2 3
+--R                                      (- 10a b c  + 2b c)d e
+--R                                    + 
+--R                                            3     2 2  3 2       3 4      4 5
+--R                                      (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                 *
+--R                                    f
+--R                                + 
+--R                                     2 2 6         2   5          3    2 2  2 4
+--R                                  - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                                + 
+--R                                      3 3 3    4 4 2
+--R                                  2b c d e  - c d e
+--R                       + 
+--R                               2                        2
+--R                         - 4a f  + (2b e + 4c d)f - 2c e
+--R                    /
+--R                           2   3       2 2                          2  2  2
+--R                         4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                       + 
+--R                               3            2    2         2      2 3          4
+--R                         (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                       + 
+--R                                3    2 2 2
+--R                         b c d e  - c d e
+--R              + 
+--R                                     +--------------+
+--R                       2             |   2
+--R                (4b d f  - 4c d e f)\|c x  + b x + a
+--R              + 
+--R                          2   4        2 2                           2  2  3
+--R                        8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                      + 
+--R                               3              2    2         2      2 3  2
+--R                        (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                      + 
+--R                                 4           3     2 2 2
+--R                        (- 2a c e  + 2b c d e  - 2c d e )f
+--R                   *
+--R                      x
+--R                   *
+--R                      ROOT
+--R                              2 2               2 2
+--R                           - b f  + 2b c e f - c e
+--R                        /
+--R                               4   5
+--R                             4a d f
+--R                           + 
+--R                                 4 2     3              3      2 2  2  4
+--R                             (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                           + 
+--R                                   3   3       3      2 2    2
+--R                                 2a b e  + (12a c + 2a b )d e
+--R                               + 
+--R                                  2          3  2        2 2        2      4  3
+--R                               (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                            *
+--R                                3
+--R                               f
+--R                           + 
+--R                                      3     2 2  4         2          3    3
+--R                                 (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                               + 
+--R                                       2 2        2     4  2 2
+--R                                 (- 22a c  + 20a b c - b )d e
+--R                               + 
+--R                                        2     3   3            3     2 2  4
+--R                                 (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                            *
+--R                                2
+--R                               f
+--R                           + 
+--R                                   2     5      2 2       2     4
+--R                                 2a b c e  + (8a c  - 4a b c)d e
+--R                               + 
+--R                                           2     3   2 3         3     2 2  3 2
+--R                                 (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                               + 
+--R                                       3 4      4 5
+--R                                 - 8b c d e + 4c d
+--R                            *
+--R                               f
+--R                           + 
+--R                                2 2 6         2   5          3    2 2  2 4
+--R                             - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                           + 
+--R                                 3 3 3    4 4 2
+--R                             2b c d e  - c d e
+--R                  + 
+--R                             2       2            2
+--R                    (- 2b e f  + 2c e f)x - 4b d f  + 4c d e f
+--R               *
+--R                   +-+
+--R                  \|a
+--R           /
+--R              x
+--R     + 
+--R       -
+--R             +-----------+
+--R             |          2
+--R            \|- 4d f + e
+--R         *
+--R             +------------------------------------------------------------+
+--R             |              +-----------+
+--R             |              |          2        2                        2
+--R            \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R             +----------------------------------------------------------+
+--R             |            +-----------+
+--R             |            |          2        2                        2
+--R            \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            ROOT
+--R                         2   3        2 2                           2  2  2
+--R                       8a d f  + (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                     + 
+--R                              3              2    2         2      2 3
+--R                       (2a b e  + (12a c - 2b )d e  - 8b c d e + 8c d )f
+--R                     + 
+--R                               4           3     2 2 2
+--R                       - 2a c e  + 2b c d e  - 2c d e
+--R                  *
+--R                     ROOT
+--R                             2 2               2 2
+--R                          - b f  + 2b c e f - c e
+--R                       /
+--R                              4   5
+--R                            4a d f
+--R                          + 
+--R                                4 2     3              3      2 2  2  4
+--R                            (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                          + 
+--R                                  3   3       3      2 2    2
+--R                                2a b e  + (12a c + 2a b )d e
+--R                              + 
+--R                                 2          3  2        2 2        2      4  3
+--R                              (8a b c - 8a b )d e + (24a c  - 16a b c + 4b )d
+--R                           *
+--R                               3
+--R                              f
+--R                          + 
+--R                                     3     2 2  4         2          3    3
+--R                                (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                              + 
+--R                                      2 2        2     4  2 2
+--R                                (- 22a c  + 20a b c - b )d e
+--R                              + 
+--R                                       2     3   3            3     2 2  4
+--R                                (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                           *
+--R                               2
+--R                              f
+--R                          + 
+--R                                  2     5      2 2       2     4
+--R                                2a b c e  + (8a c  - 4a b c)d e
+--R                              + 
+--R                                          2     3   2 3         3     2 2  3 2
+--R                                (- 10a b c  + 2b c)d e  + (12a c  + 2b c )d e
+--R                              + 
+--R                                      3 4      4 5
+--R                                - 8b c d e + 4c d
+--R                           *
+--R                              f
+--R                          + 
+--R                               2 2 6         2   5          3    2 2  2 4
+--R                            - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                          + 
+--R                                3 3 3    4 4 2
+--R                            2b c d e  - c d e
+--R                 + 
+--R                         2                        2
+--R                   - 4a f  + (2b e + 4c d)f - 2c e
+--R              /
+--R                     2   3       2 2                          2  2  2
+--R                   4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                 + 
+--R                         3            2    2         2      2 3          4
+--R                   (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f - a c e
+--R                 + 
+--R                          3    2 2 2
+--R                   b c d e  - c d e
+--R         *
+--R            log
+--R                                3        2   2  4
+--R                           (- 4a d e + 8a b d )f
+--R                         + 
+--R                                3 3     2     2      2         2  2
+--R                               a e  + 2a b d e  + (4a c - 12a b )d e
+--R                             + 
+--R                                              3  3
+--R                               (- 16a b c + 8b )d
+--R                          *
+--R                              3
+--R                             f
+--R                         + 
+--R                                  2   4        2        2    3
+--R                               - a b e  + (- 5a c + 3a b )d e
+--R                             + 
+--R                                          3  2 2        2      2   3        2 4
+--R                             (20a b c - 2b )d e  + (4a c  - 12b c)d e + 8b c d
+--R                          *
+--R                              2
+--R                             f
+--R                         + 
+--R                                2   5             4          2     2   2 3
+--R                               a c e  - 4a b c d e  + (- 5a c  + 3b c)d e
+--R                             + 
+--R                                   2 3 2     3 4
+--R                               2b c d e  - 4c d e
+--R                          *
+--R                             f
+--R                         + 
+--R                              2   5      2 2 4    3 3 3
+--R                           a c d e  - b c d e  + c d e
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - b f  + 2b c e f - c e
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                   3           2                    2  2
+--R                           4a b d f  + (- a b e  - 4a c d e - 4b c d )f
+--R                         + 
+--R                                 3          2     2 2       2   3
+--R                           (a c e  + b c d e  + 4c d e)f - c d e
+--R                      *
+--R                         x
+--R                  *
+--R                     ROOT
+--R                                  2   3
+--R                                8a d f
+--R                              + 
+--R                                     2 2                           2  2  2
+--R                                (- 2a e  - 8a b d e + (- 16a c + 8b )d )f
+--R                              + 
+--R                                            3              2    2         2
+--R                                      2a b e  + (12a c - 2b )d e  - 8b c d e
+--R                                    + 
+--R                                        2 3
+--R                                      8c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                        4           3     2 2 2
+--R                                - 2a c e  + 2b c d e  - 2c d e
+--R                           *
+--R                              ROOT
+--R                                      2 2               2 2
+--R                                   - b f  + 2b c e f - c e
+--R                                /
+--R                                       4   5
+--R                                     4a d f
+--R                                   + 
+--R                                         4 2     3              3      2 2  2  4
+--R                                     (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                                   + 
+--R                                           3   3       3      2 2    2
+--R                                         2a b e  + (12a c + 2a b )d e
+--R                                       + 
+--R                                            2          3  2
+--R                                         (8a b c - 8a b )d e
+--R                                       + 
+--R                                             2 2        2      4  3
+--R                                         (24a c  - 16a b c + 4b )d
+--R                                    *
+--R                                        3
+--R                                       f
+--R                                   + 
+--R                                              3     2 2  4
+--R                                         (- 2a c - a b )e
+--R                                       + 
+--R                                               2          3    3
+--R                                         (- 10a b c + 2a b )d e
+--R                                       + 
+--R                                               2 2        2     4  2 2
+--R                                         (- 22a c  + 20a b c - b )d e
+--R                                       + 
+--R                                                2     3   3
+--R                                         (8a b c  - 8b c)d e
+--R                                       + 
+--R                                                 3     2 2  4
+--R                                         (- 16a c  + 8b c )d
+--R                                    *
+--R                                        2
+--R                                       f
+--R                                   + 
+--R                                           2     5      2 2       2     4
+--R                                         2a b c e  + (8a c  - 4a b c)d e
+--R                                       + 
+--R                                                   2     3   2 3
+--R                                         (- 10a b c  + 2b c)d e
+--R                                       + 
+--R                                             3     2 2  3 2       3 4      4 5
+--R                                       (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                                    *
+--R                                       f
+--R                                   + 
+--R                                        2 2 6         2   5
+--R                                     - a c e  + 2a b c d e
+--R                                   + 
+--R                                            3    2 2  2 4       3 3 3    4 4 2
+--R                                     (- 2a c  - b c )d e  + 2b c d e  - c d e
+--R                          + 
+--R                                  2                        2
+--R                            - 4a f  + (2b e + 4c d)f - 2c e
+--R                       /
+--R                              2   3       2 2                          2  2  2
+--R                            4a d f  + (- a e  - 4a b d e + (- 8a c + 4b )d )f
+--R                          + 
+--R                                  3            2    2         2      2 3
+--R                            (a b e  + (6a c - b )d e  - 4b c d e + 4c d )f
+--R                          + 
+--R                                   4          3    2 2 2
+--R                            - a c e  + b c d e  - c d e
+--R                 + 
+--R                                        +--------------+
+--R                          2             |   2
+--R                   (4b d f  - 4c d e f)\|c x  + b x + a
+--R                 + 
+--R                               2   4      2 2                         2  2  3
+--R                           - 8a d f  + (2a e  + 8a b d e + (16a c - 8b )d )f
+--R                         + 
+--R                                         3                2    2         2
+--R                                 - 2a b e  + (- 12a c + 2b )d e  + 8b c d e
+--R                               + 
+--R                                     2 3
+--R                                 - 8c d
+--R                          *
+--R                              2
+--R                             f
+--R                         + 
+--R                                  4           3     2 2 2
+--R                           (2a c e  - 2b c d e  + 2c d e )f
+--R                      *
+--R                         x
+--R                      *
+--R                         ROOT
+--R                                 2 2               2 2
+--R                              - b f  + 2b c e f - c e
+--R                           /
+--R                                  4   5
+--R                                4a d f
+--R                              + 
+--R                                    4 2     3              3      2 2  2  4
+--R                                (- a e  - 8a b d e + (- 16a c + 8a b )d )f
+--R                              + 
+--R                                      3   3       3      2 2    2
+--R                                    2a b e  + (12a c + 2a b )d e
+--R                                  + 
+--R                                       2          3  2
+--R                                    (8a b c - 8a b )d e
+--R                                  + 
+--R                                        2 2        2      4  3
+--R                                    (24a c  - 16a b c + 4b )d
+--R                               *
+--R                                   3
+--R                                  f
+--R                              + 
+--R                                         3     2 2  4         2          3    3
+--R                                    (- 2a c - a b )e  + (- 10a b c + 2a b )d e
+--R                                  + 
+--R                                          2 2        2     4  2 2
+--R                                    (- 22a c  + 20a b c - b )d e
+--R                                  + 
+--R                                           2     3   3            3     2 2  4
+--R                                    (8a b c  - 8b c)d e + (- 16a c  + 8b c )d
+--R                               *
+--R                                   2
+--R                                  f
+--R                              + 
+--R                                      2     5      2 2       2     4
+--R                                    2a b c e  + (8a c  - 4a b c)d e
+--R                                  + 
+--R                                              2     3   2 3
+--R                                    (- 10a b c  + 2b c)d e
+--R                                  + 
+--R                                          3     2 2  3 2       3 4      4 5
+--R                                    (12a c  + 2b c )d e  - 8b c d e + 4c d
+--R                               *
+--R                                  f
+--R                              + 
+--R                                   2 2 6         2   5          3    2 2  2 4
+--R                                - a c e  + 2a b c d e  + (- 2a c  - b c )d e
+--R                              + 
+--R                                    3 3 3    4 4 2
+--R                                2b c d e  - c d e
+--R                     + 
+--R                                2       2            2
+--R                       (- 2b e f  + 2c e f)x - 4b d f  + 4c d e f
+--R                  *
+--R                      +-+
+--R                     \|a
+--R              /
+--R                 x
+--R     + 
+--R                +----------------------------------------------------------+
+--R                |            +-----------+
+--R            +-+ |            |          2        2                        2
+--R         2f\|2 \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                +------------------------------------------------------------+
+--R                |              +-----------+
+--R            +-+ |              |          2        2                        2
+--R         2f\|2 \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R         +-----------+
+--R         |          2
+--R       2\|- 4d f + e
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 345
+
+--S 346 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 346
+
+)clear all
+
+--S 347 of 1580
+t0:=1/(x*(a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                          1
+--R   (1)  ------------------------------------
+--R                            +--------------+
+--R            3      2        |   2
+--R        (f x  + e x  + d x)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 1580
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(d*sqrt(a))+_
+   f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(e+sqrt(e^2-4*d*f))/(d*sqrt(2)*sqrt(e^2-_
+   4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(e-sqrt(e^2-4*d*f))/(d*sqrt(2)*sqrt(e^2-_
+   4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R              +-----------+
+--R              |          2         +-+
+--R         (- f\|- 4d f + e   + e f)\|a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R            +-----------+
+--R            |          2         +-+
+--R         (f\|- 4d f + e   + e f)\|a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2              b x + 2a
+--R            \|2 \|- 4d f + e  atanh(----------------------)
+--R                                          +--------------+
+--R                                      +-+ |   2
+--R                                    2\|a \|c x  + b x + a
+--R         *
+--R             +------------------------------------------------------------+
+--R             |              +-----------+
+--R             |              |          2        2                        2
+--R            \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R             +----------------------------------------------------------+
+--R             |            +-----------+
+--R             |            |          2        2                        2
+--R            \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R             +-----------+
+--R         +-+ |          2  +-+
+--R       d\|2 \|- 4d f + e  \|a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 348
+
+--S 349 of 1580
+--a0:=integrate(t0,x)
+--E 349
+
+--S 350 of 1580
+--m0:=a0-r0
+--E 350
+
+--S 351 of 1580
+--d0:=D(m0,x)
+--E 351
+
+)clear all
+
+--S 352 of 1580
+t0:=1/(x^2*(a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R                             +--------------+
+--R            4      3      2  |   2
+--R        (f x  + e x  + d x )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 1580
+r0:=1/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(a^(3/2)*d)+_
+   e*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(d^2*sqrt(a))-_
+   sqrt(a+b*x+c*x^2)/(a*d*x)+f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+_
+   2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(e^2-2*d*f-e*_
+   sqrt(e^2-4*d*f))/(d^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))-f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-_
+   sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f))/(d^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(f*(2*a*f-_
+   b*(e-sqrt(e^2-4*d*f)))+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                   +-----------+
+--R                   |          2           2       2     +-+
+--R         (2a e f x\|- 4d f + e   + (4a d f  - 2a e f)x)\|a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                     +-----------+
+--R                     |          2           2       2     +-+
+--R         (- 2a e f x\|- 4d f + e   + (4a d f  - 2a e f)x)\|a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                             +-----------+
+--R                         +-+ |          2              b x + 2a
+--R           (2a e + b d)x\|2 \|- 4d f + e  atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|a \|c x  + b x + a
+--R         + 
+--R                    +-----------+     +--------------+
+--R                +-+ |          2  +-+ |   2
+--R           - 2d\|2 \|- 4d f + e  \|a \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                  +-----------+
+--R           2  +-+ |          2  +-+
+--R       2a d x\|2 \|- 4d f + e  \|a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 1580
+--a0:=integrate(t0,x)
+--E 354
+
+--S 355 of 1580
+--m0:=a0-r0
+--E 355
+
+--S 356 of 1580
+--d0:=D(m0,x)
+--E 356
+
+)clear all
+
+--S 357 of 1580
+t0:=1/(x^3*(a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R                             +--------------+
+--R            5      4      3  |   2
+--R        (f x  + e x  + d x )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 1580
+r0:=-1/8*(3*b^2-4*a*c)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (a^(5/2)*d)-1/2*b*e*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (a^(3/2)*d^2)-(e^2-d*f)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (d^3*sqrt(a))-1/2*sqrt(a+b*x+c*x^2)/(a*d*x^2)+3/4*b*sqrt(a+b*x+c*x^2)/_
+   (a^2*d*x)+e*sqrt(a+b*x+c*x^2)/(a*d^2*x)+f*atanh(1/2*(4*a*f+2*x*(b*f-_
+   c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*e^3-_
+   4*d*e*f-(e^2-d*f)*(e-sqrt(e^2-4*d*f)))/(d^3*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(2*e^3-4*d*e*f-(e^2-d*f)*(e+sqrt(e^2-_
+   4*d*f)))/(d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                               +-----------+
+--R             2   2     2 2   2 |          2          2     2     2 3   2  +-+
+--R         ((8a d f  - 8a e f)x \|- 4d f + e   + (- 24a d e f  + 8a e f)x )\|a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                 +-----------+
+--R               2   2     2 2   2 |          2          2     2     2 3   2  +-+
+--R         ((- 8a d f  + 8a e f)x \|- 4d f + e   + (- 24a d e f  + 8a e f)x )\|a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                                +-----------+
+--R                2        2 2                        2  2  2 +-+ |          2
+--R             (8a d f - 8a e  - 4a b d e + (4a c - 3b )d )x \|2 \|- 4d f + e
+--R          *
+--R                          b x + 2a
+--R             atanh(----------------------)
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|a \|c x  + b x + a
+--R         + 
+--R                                           +-----------+     +--------------+
+--R                          2         2  +-+ |          2  +-+ |   2
+--R           ((8a d e + 6b d )x - 4a d )\|2 \|- 4d f + e  \|a \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                   +-----------+
+--R         2 3 2 +-+ |          2  +-+
+--R       8a d x \|2 \|- 4d f + e  \|a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 1580
+--a0:=integrate(t0,x)
+--E 359
+
+--S 360 of 1580
+--m0:=a0-r0
+--E 360
+
+-- Table construction failed in MLIFT
+--S 361 of 1580
+--d0:=D(m0,x)
+--E 361
+
+)clear all
+
+--S 362 of 1580
+t0:=x^3/((a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R      3
+--R     x
+--R  /
+--R             4               3                     2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 1580
+r0:=2*(2*a+b*x)/((b^2-4*a*c)*f*sqrt(a+b*x+c*x^2))+2*e*(b+2*c*x)/_
+   ((b^2-4*a*c)*f^2*sqrt(a+b*x+c*x^2))-2*(b^3*d*e*f+b*c*e*(c*d^2+_
+   a*(e^2-4*d*f))+2*a*c*f*(c*d^2+a*(e^2-d*f))-b^2*(c*d*e^2+a*f*(e^2-d*f))+_
+   c*(2*c^2*d^2*e+b*f*(b*d*e-a*e^2+a*d*f)+c*(2*a*e*(e^2-2*d*f)-_
+   b*d*(2*e^2-d*f)))*x)/((b^2-4*a*c)*f^2*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))*sqrt(a+b*x+c*x^2))+atanh(1/2*(4*a*f+_
+   2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(2*d*(b*d-a*e)*f+(c*d^2-b*d*e+a*(e^2-d*f))*(e-_
+   sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-_
+   2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))-atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+_
+   2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*(b*d-a*e)*f+_
+   (c*d^2-b*d*e+a*(e^2-d*f))*(e+sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-_
+   a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                    2       2          2       2  2                3
+--R               (- 4a c + a b )d f + (4a c - a b )e  + (- 4a b c + b )d e
+--R             + 
+--R                    2    2   2
+--R               (4a c  - b c)d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2        2                   3  2        2       2  3
+--R           ((- 12a c + 3a b )d e + (8a b c - 2b )d )f + (4a c - a b )e
+--R         + 
+--R                        3    2        2    2   2
+--R           (- 4a b c + b )d e  + (4a c  - b c)d e
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                  2       2            2       2  2              3
+--R               (4a c - a b )d f + (- 4a c + a b )e  + (4a b c - b )d e
+--R             + 
+--R                      2    2   2
+--R               (- 4a c  + b c)d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2        2                   3  2        2       2  3
+--R           ((- 12a c + 3a b )d e + (8a b c - 2b )d )f + (4a c - a b )e
+--R         + 
+--R                        3    2        2    2   2
+--R           (- 4a b c + b )d e  + (4a c  - b c)d e
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                2           2        2                 3         3      2
+--R           (- 2a b f + (- 4a c + 2a b )e + (6a b c - 2b )d)x - 4a f + 2a b e
+--R         + 
+--R              2        2
+--R           (4a c - 2a b )d
+--R      *
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            3     2 2  2         2         3          2 2       2     4
+--R         (4a c - a b )f  + ((- 4a b c + a b )e + (- 8a c  + 6a b c - b )d)f
+--R       + 
+--R            2 2      2   2            2    3             3    2 2  2
+--R         (4a c  - a b c)e  + (- 4a b c  + b c)d e + (4a c  - b c )d
+--R    *
+--R            +-----------+ +--------------+
+--R        +-+ |          2  |   2
+--R       \|2 \|- 4d f + e  \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 363
+
+--S 364 of 1580
+--a0:=integrate(t0,x)
+--E 364
+
+--S 365 of 1580
+--m0:=a0-r0
+--E 365
+
+--S 366 of 1580
+--d0:=D(m0,x)
+--E 366
+
+)clear all
+
+--S 367 of 1580
+t0:=x^2/((a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R      2
+--R     x
+--R  /
+--R             4               3                     2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 1580
+r0:=-2*(b+2*c*x)/((b^2-4*a*c)*f*sqrt(a+b*x+c*x^2))+2*(b^3*d*f+2*a^2*c*e*f-_
+   b^2*e*(c*d+a*f)+b*c*(c*d^2+a*(e^2-3*d*f))+c*(2*c^2*d^2+b*(b*d-a*e)*f-_
+   2*c*(b*d*e-a*e^2+a*d*f))*x)/((b^2-4*a*c)*f*(c^2*d^2+f*(b^2*d-a*b*e+_
+   a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(a+b*x+c*x^2))-f*atanh(1/2*_
+   (4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(2*d*(c*d-a*f)-(b*d-a*e)*(e-sqrt(e^2-4*d*f)))/_
+   ((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f)))+f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+_
+   sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*(c*d-a*f)-(b*d-a*e)*_
+   (e+sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-_
+   2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                                +-----------+
+--R                 2       2                3     |          2
+--R           ((- 4a c + a b )e + (4a b c - b )d)f\|- 4d f + e
+--R         + 
+--R              2        2    2
+--R           (8a c - 2a b )d f
+--R         + 
+--R                 2       2  2              3              2     2   2
+--R           ((- 4a c + a b )e  + (4a b c - b )d e + (- 8a c  + 2b c)d )f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                +-----------+
+--R               2       2                  3     |          2
+--R           ((4a c - a b )e + (- 4a b c + b )d)f\|- 4d f + e
+--R         + 
+--R              2        2    2
+--R           (8a c - 2a b )d f
+--R         + 
+--R                 2       2  2              3              2     2   2
+--R           ((- 4a c + a b )e  + (4a b c - b )d e + (- 8a c  + 2b c)d )f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R             2                        2     2          2        2
+--R         ((4a c f - 2a b c e + (- 4a c  + 2b c)d)x + 2a b f - 4a c e + 2a b c d)
+--R      *
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            3     2 2  2         2         3          2 2       2     4
+--R         (4a c - a b )f  + ((- 4a b c + a b )e + (- 8a c  + 6a b c - b )d)f
+--R       + 
+--R            2 2      2   2            2    3             3    2 2  2
+--R         (4a c  - a b c)e  + (- 4a b c  + b c)d e + (4a c  - b c )d
+--R    *
+--R            +-----------+ +--------------+
+--R        +-+ |          2  |   2
+--R       \|2 \|- 4d f + e  \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 1580
+--a0:=integrate(t0,x)
+--E 369
+
+--S 370 of 1580
+--m0:=a0-r0
+--E 370
+
+--S 371 of 1580
+--d0:=D(m0,x)
+--E 371
+
+)clear all
+
+--S 372 of 1580
+t0:=x/((a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R     x
+--R  /
+--R             4               3                     2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 372
+
+--S 373 of 1580
+r0:=2*(a*(2*c^2*d+b^2*f-c*(b*e+2*a*f))+c*(b*c*d-2*a*c*e+a*b*f)*x)/_
+   ((b^2-4*a*c)*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*_
+   sqrt(a+b*x+c*x^2))+f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-_
+   b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*(c*e-b*f)-(c*d-a*f)*_
+   (e-sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-_
+   2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))-f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+_
+   2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*(c*e-b*f)-_
+   (c*d-a*f)*(e+sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                                  +-----------+
+--R               2       2  2          2    2       |          2
+--R           ((4a c - a b )f  + (- 4a c  + b c)d f)\|- 4d f + e
+--R         + 
+--R               2       2                   3    2        2    2
+--R           ((4a c - a b )e + (- 8a b c + 2b )d)f  + (4a c  - b c)d e f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                  +-----------+
+--R                 2       2  2        2    2       |          2
+--R           ((- 4a c + a b )f  + (4a c  - b c)d f)\|- 4d f + e
+--R         + 
+--R               2       2                   3    2        2    2
+--R           ((4a c - a b )e + (- 8a b c + 2b )d)f  + (4a c  - b c)d e f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                            2        2         2        2                    2
+--R         ((- 2a b c f + 4a c e - 2b c d)x + (4a c - 2a b )f + 2a b c e - 4a c d)
+--R      *
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            3     2 2  2         2         3          2 2       2     4
+--R         (4a c - a b )f  + ((- 4a b c + a b )e + (- 8a c  + 6a b c - b )d)f
+--R       + 
+--R            2 2      2   2            2    3             3    2 2  2
+--R         (4a c  - a b c)e  + (- 4a b c  + b c)d e + (4a c  - b c )d
+--R    *
+--R            +-----------+ +--------------+
+--R        +-+ |          2  |   2
+--R       \|2 \|- 4d f + e  \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 1580
+--a0:=integrate(t0,x)
+--E 374
+
+--S 375 of 1580
+--m0:=a0-r0
+--E 375
+
+--S 376 of 1580
+--d0:=D(m0,x)
+--E 376
+
+)clear all
+
+--S 377 of 1580
+t0:=1/((a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R             4               3                     2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 1580
+r0:=2*(b^2*c*e-2*a*c^2*e-b^3*f-b*c*(c*d-3*a*f)-c*(2*c^2*d-b*c*e+b^2*f-_
+   2*a*c*f)*x)/((b^2-4*a*c)*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*_
+   (e^2-2*d*f)))*sqrt(a+b*x+c*x^2))-f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-_
+   sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f))+f*(2*a*f-b*(e+sqrt(e^2-4*d*f))))/((c^2*d^2+_
+   f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*(f*(b*e-a*f)-c*(e^2-d*f))+_
+   (c*e-b*f)*(e+sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                                  +-----------+
+--R                         3  2        2    2       |          2
+--R           ((- 4a b c + b )f  + (4a c  - b c)e f)\|- 4d f + e
+--R         + 
+--R                2        2  3               3          2     2     2
+--R           (- 8a c + 2a b )f  + ((4a b c - b )e + (8a c  - 2b c)d)f
+--R         + 
+--R                  2    2   2
+--R           (- 4a c  + b c)e f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                  +-----------+
+--R                       3  2          2    2       |          2
+--R           ((4a b c - b )f  + (- 4a c  + b c)e f)\|- 4d f + e
+--R         + 
+--R                2        2  3               3          2     2     2
+--R           (- 8a c + 2a b )f  + ((4a b c - b )e + (8a c  - 2b c)d)f
+--R         + 
+--R                  2    2   2
+--R           (- 4a c  + b c)e f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                   2     2          2      3                    3
+--R           ((- 4a c  + 2b c)f - 2b c e + 4c d)x + (- 6a b c + 2b )f
+--R         + 
+--R                2     2          2
+--R           (4a c  - 2b c)e + 2b c d
+--R      *
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            3     2 2  2         2         3          2 2       2     4
+--R         (4a c - a b )f  + ((- 4a b c + a b )e + (- 8a c  + 6a b c - b )d)f
+--R       + 
+--R            2 2      2   2            2    3             3    2 2  2
+--R         (4a c  - a b c)e  + (- 4a b c  + b c)d e + (4a c  - b c )d
+--R    *
+--R            +-----------+ +--------------+
+--R        +-+ |          2  |   2
+--R       \|2 \|- 4d f + e  \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 378
+
+--S 379 of 1580
+--a0:=integrate(t0,x)
+--E 379
+
+--S 380 of 1580
+--m0:=a0-r0
+--E 380
+
+--S 381 of 1580
+--d0:=D(m0,x)
+--E 381
+
+)clear all
+
+--S 382 of 1580
+t0:=1/(x*(a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R             5               4                     3               2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x  + a d x)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 1580
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(a^(3/2)*d)+_
+   2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*d*sqrt(a+b*x+c*x^2))+2*(b*(c^2*_
+   d*e-b*c*e^2+b*f*(b*e-a*f))-2*a*c*(f*(b*e-a*f)-c*(e^2-d*f))+c*(2*c^2*d*e+_
+   b*f*(b*e-a*f)-b*c*(e^2+d*f))*x)/((b^2-4*a*c)*d*(c^2*d^2+f*(b^2*d-a*b*e+_
+   a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(a+b*x+c*x^2))+f*atanh(1/2*(4*a*f+_
+   2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f))))*(-2*(f*(b*e^2-b*d*f-a*e*f)-c*(e^3-2*d*e*f))+(f*(b*e-a*f)-_
+   c*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/(d*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-f*atanh(1/2*(4*a*f-b*(e+_
+   sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+_
+   b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*_
+   (-2*(f*(b*e^2-b*d*f-a*e*f)-c*(e^3-2*d*e*f))+(f*(b*e-a*f)-c*(e^2-d*f))*_
+   (e+sqrt(e^2-4*d*f)))/(d*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-_
+   2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                    3     2 2  3       2         3        2 2      2     2
+--R               (- 4a c + a b )f  + ((4a b c - a b )e + (4a c  - a b c)d)f
+--R             + 
+--R                    2 2      2   2
+--R               (- 4a c  + a b c)e f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R               3     2 2        2          3    3
+--R           ((4a c - a b )e + (8a b c - 2a b )d)f
+--R         + 
+--R               2         3  2         2 2       2       2      2 2      2   3
+--R         ((- 4a b c + a b )e  + (- 12a c  + 3a b c)d e)f  + (4a c  - a b c)e f
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                  3     2 2  3         2         3          2 2      2     2
+--R               (4a c - a b )f  + ((- 4a b c + a b )e + (- 4a c  + a b c)d)f
+--R             + 
+--R                  2 2      2   2
+--R               (4a c  - a b c)e f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R               3     2 2        2          3    3
+--R           ((4a c - a b )e + (8a b c - 2a b )d)f
+--R         + 
+--R               2         3  2         2 2       2       2      2 2      2   3
+--R         ((- 4a b c + a b )e  + (- 12a c  + 3a b c)d e)f  + (4a c  - a b c)e f
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                    3     2 2  2       2         3        2 2       2     4
+--R               (- 4a c + a b )f  + ((4a b c - a b )e + (8a c  - 6a b c + b )d)f
+--R             + 
+--R                    2 2      2   2          2    3               3    2 2  2
+--R               (- 4a c  + a b c)e  + (4a b c  - b c)d e + (- 4a c  + b c )d
+--R          *
+--R                  +-----------+ +--------------+
+--R              +-+ |          2  |   2                        b x + 2a
+--R             \|2 \|- 4d f + e  \|c x  + b x + a atanh(----------------------)
+--R                                                            +--------------+
+--R                                                        +-+ |   2
+--R                                                      2\|a \|c x  + b x + a
+--R         + 
+--R                       2     3               3     2 2           3 2
+--R               ((6a b c  - 2b c)d f + (- 4a c  + 2b c )d e - 2b c d )x
+--R             + 
+--R                    2 2       2      4                2     3
+--R               (- 4a c  + 8a b c - 2b )d f + (- 6a b c  + 2b c)d e
+--R             + 
+--R                    3     2 2  2
+--R               (4a c  - 2b c )d
+--R          *
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R             \|2 \|- 4d f + e  \|a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            4     3 2    2
+--R         (4a c - a b )d f
+--R       + 
+--R               3       2 3            3 2     2 2       4  2
+--R         ((- 4a b c + a b )d e + (- 8a c  + 6a b c - a b )d )f
+--R       + 
+--R            3 2    2 2     2        2   2      3   2       2 3      2 2  3
+--R         (4a c  - a b c)d e  + (- 4a b c  + a b c)d e + (4a c  - a b c )d
+--R    *
+--R            +-----------+     +--------------+
+--R        +-+ |          2  +-+ |   2
+--R       \|2 \|- 4d f + e  \|a \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 1580
+--a0:=integrate(t0,x)
+--E 384
+
+--S 385 of 1580
+--m0:=a0-r0
+--E 385
+
+--S 386 of 1580
+--d0:=D(m0,x)
+--E 386
+
+)clear all
+
+--S 387 of 1580
+t0:=sqrt(-1+x^2)/sqrt(-1+x^4)
+--R 
+--R
+--R         +------+
+--R         | 2
+--R        \|x  - 1
+--R   (1)  ---------
+--R         +------+
+--R         | 4
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 1580
+r0:=asinh(x)*sqrt(-1+x^2)*sqrt(1+x^2)/sqrt(-1+x^4)
+--R 
+--R
+--R                 +------+ +------+
+--R                 | 2      | 2
+--R        asinh(x)\|x  - 1 \|x  + 1
+--R   (2)  --------------------------
+--R                  +------+
+--R                  | 4
+--R                 \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +------+ +------+
+--R               | 2      | 4         3
+--R              \|x  - 1 \|x  - 1  - x  + x
+--R   (3)  - log(---------------------------)
+--R                          2
+--R                         x  - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 389
+
+--S 390 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +------+ +------+
+--R      +------+     | 2      | 4         3                 +------+ +------+
+--R      | 4         \|x  - 1 \|x  - 1  - x  + x             | 2      | 2
+--R   - \|x  - 1 log(---------------------------) - asinh(x)\|x  - 1 \|x  + 1
+--R                              2
+--R                             x  - 1
+--R   ------------------------------------------------------------------------
+--R                                    +------+
+--R                                    | 4
+--R                                   \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 390
+
+--S 391 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 391
+
+)clear all
+
+--S 392 of 1580
+t0:=sqrt(1+x^2)/sqrt(-1+x^4)
+--R 
+--R
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R   (1)  ---------
+--R         +------+
+--R         | 4
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 1580
+r0:=-asin(x)*sqrt(-1+x^4)/sqrt(1-x^4),atanh(x/sqrt(-1+x^2))*sqrt(-1+x^2)*_
+   sqrt(1+x^2)/sqrt(-1+x^4)
+--R 
+--R
+--R                             +------+ +------+
+--R                             | 2      | 2               x
+--R                            \|x  - 1 \|x  + 1 atanh(---------)
+--R                   +------+                          +------+
+--R                   | 4                               | 2
+--R           asin(x)\|x  - 1                          \|x  - 1
+--R   (2)  [- ----------------,----------------------------------]
+--R               +--------+                 +------+
+--R               |   4                      | 4
+--R              \|- x  + 1                 \|x  - 1
+--R                                             Type: Tuple(Expression(Integer))
+--E 393
+
+--S 394 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +------+ +------+
+--R               | 2      | 4         3
+--R              \|x  + 1 \|x  - 1  - x  - x
+--R   (3)  - log(---------------------------)
+--R                          2
+--R                         x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 394
+
+--S 395 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                          +------+ +------+
+--R           +--------+     | 2      | 4         3                +------+
+--R           |   4         \|x  + 1 \|x  - 1  - x  - x            | 4
+--R        - \|- x  + 1 log(---------------------------) + asin(x)\|x  - 1
+--R                                     2
+--R                                    x  + 1
+--R   (4)  ----------------------------------------------------------------
+--R                                    +--------+
+--R                                    |   4
+--R                                   \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R                 +------+            +--------+ +--------+
+--R          4      | 2          2      |   4      |   2
+--R        (x  - 1)\|x  + 1  + (x  + 1)\|- x  + 1 \|- x  + 1
+--R   (5)  --------------------------------------------------
+--R              +--------+ +--------+ +------+ +------+
+--R              |   4      |   2      | 2      | 4
+--R             \|- x  + 1 \|- x  + 1 \|x  + 1 \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 1580
+t0:=(-sqrt(-1+x^2)+sqrt(1+x^2))/sqrt(-1+x^4)
+--R 
+--R
+--R         +------+    +------+
+--R         | 2         | 2
+--R        \|x  + 1  - \|x  - 1
+--R   (1)  ---------------------
+--R               +------+
+--R               | 4
+--R              \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 1580
+r0:=-asin(x)*sqrt(-1+x^4)/(sqrt(1-x^2)*sqrt(1+x^2))+asinh(x)*sqrt(-1+x^2)*_
+   sqrt(-1+x^4)/((1-x^2)*sqrt(1+x^2)),-asinh(x)*sqrt(-1+x^2)*sqrt(1+x^2)/_
+   sqrt(-1+x^4)+atanh(x/sqrt(-1+x^2))*sqrt(-1+x^2)*sqrt(1+x^2)/sqrt(-1+x^4)
+--R 
+--R
+--R   (2)
+--R                +--------+ +------+                      +------+
+--R                |   2      | 2            2              | 4
+--R    (- asinh(x)\|- x  + 1 \|x  - 1  + (- x  + 1)asin(x))\|x  - 1
+--R   [-------------------------------------------------------------,
+--R                              +--------+ +------+
+--R                       2      |   2      | 2
+--R                     (x  - 1)\|- x  + 1 \|x  + 1
+--R     +------+ +------+                            +------+ +------+
+--R     | 2      | 2               x                 | 2      | 2
+--R    \|x  - 1 \|x  + 1 atanh(---------) - asinh(x)\|x  - 1 \|x  + 1
+--R                             +------+
+--R                             | 2
+--R                            \|x  - 1
+--R    ---------------------------------------------------------------]
+--R                                +------+
+--R                                | 4
+--R                               \|x  - 1
+--R                                             Type: Tuple(Expression(Integer))
+--E 398
+
+--S 399 of 1580
+--a0:=integrate(t0,x)
+--E 399
+
+--S 400 of 1580
+--m0:=a0-r0
+--E 400
+
+--S 401 of 1580
+--d0:=D(m0,x)
+--E 401
+
+)clear all
+
+--S 402 of 1580
+t0:=x/(1-x^2)^5
+--R 
+--R
+--R                          x
+--R   (1)  - ---------------------------------
+--R           10     8      6      4     2
+--R          x   - 5x  + 10x  - 10x  + 5x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 402
+
+--S 403 of 1580
+r0:=1/8/(1-x^2)^4
+--R 
+--R
+--R                    1
+--R                    -
+--R                    8
+--R   (2)  ------------------------
+--R         8     6     4     2
+--R        x  - 4x  + 6x  - 4x  + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 403
+
+--S 404 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      1
+--R   (3)  ----------------------------
+--R          8      6      4      2
+--R        8x  - 32x  + 48x  - 32x  + 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 404
+
+--S 405 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+--S 406 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 406
+
+)clear all
+
+--S 407 of 1580
+t0:=(-1/32)/(-1+x)^5+3/64/(-1+x)^4+(-5/128)/(-1+x)^3+5/256/(-1+x)^2+_
+   (-1/32)/(1+x)^5+(-3/64)/(1+x)^4+(-5/128)/(1+x)^3+(-5/256)/(1+x)^2
+--R 
+--R
+--R                          x
+--R   (1)  - ---------------------------------
+--R           10     8      6      4     2
+--R          x   - 5x  + 10x  - 10x  + 5x  - 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 407
+
+--S 408 of 1580
+r0:=1/8/(1-x^2)^4,1/128/(1-x)^4+1/64/(1-x)^3+5/256/(1-x)^2+5/256/(1-x)+_
+   1/128/(1+x)^4+1/64/(1+x)^3+5/256/(1+x)^2+5/256/(1+x)
+--R 
+--R
+--R                     1                        1
+--R                     -                        -
+--R                     8                        8
+--R   (2)  [------------------------,------------------------]
+--R          8     6     4     2      8     6     4     2
+--R         x  - 4x  + 6x  - 4x  + 1 x  - 4x  + 6x  - 4x  + 1
+--R                         Type: Tuple(Fraction(Polynomial(Fraction(Integer))))
+--E 408
+
+--S 409 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    1
+--R                    -
+--R                    8
+--R   (3)  ------------------------
+--R         8     6     4     2
+--R        x  - 4x  + 6x  - 4x  + 1
+--R                               Type: Union(Expression(Fraction(Integer)),...)
+--E 409
+
+--S 410 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Expression(Fraction(Integer))
+--E 410
+
+--S 411 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Expression(Fraction(Integer))
+--E 411
+
+)clear all
+
+--S 412 of 1580
+t0:=(2+x)/(-1+2*x+x^2)
+--R 
+--R
+--R           x + 2
+--R   (1)  -----------
+--R         2
+--R        x  + 2x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 412
+
+--S 413 of 1580
+r0:=1/4*log(1+x+sqrt(2))*(2-sqrt(2))+1/4*log(1+x-sqrt(2))*(2+sqrt(2))
+--R 
+--R
+--R            +-+          +-+              +-+            +-+
+--R        (- \|2  + 2)log(\|2  + x + 1) + (\|2  + 2)log(- \|2  + x + 1)
+--R   (2)  -------------------------------------------------------------
+--R                                      4
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2           +-+
+--R            (x  + 2x + 3)\|2  - 4x - 4     +-+     2
+--R        log(--------------------------) + \|2 log(x  + 2x - 1)
+--R                     2
+--R                    x  + 2x - 1
+--R   (3)  ------------------------------------------------------
+--R                                   +-+
+--R                                 2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 414
+
+--S 415 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2           +-+
+--R           (x  + 2x + 3)\|2  - 4x - 4        +-+          +-+
+--R       log(--------------------------) + (- \|2  + 1)log(\|2  + x + 1)
+--R                    2
+--R                   x  + 2x - 1
+--R     + 
+--R        +-+     2                 +-+            +-+
+--R       \|2 log(x  + 2x - 1) + (- \|2  - 1)log(- \|2  + x + 1)
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 416
+
+)clear all
+
+--S 417 of 1580
+t0:=(-4+x^2)/(2-5*x+x^3)
+--R 
+--R
+--R           x + 2
+--R   (1)  -----------
+--R         2
+--R        x  + 2x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 417
+
+--S 418 of 1580
+r0:=1/4*log(1+x+sqrt(2))*(2-sqrt(2))+1/4*log(1+x-sqrt(2))*(2+sqrt(2))
+--R 
+--R
+--R            +-+          +-+              +-+            +-+
+--R        (- \|2  + 2)log(\|2  + x + 1) + (\|2  + 2)log(- \|2  + x + 1)
+--R   (2)  -------------------------------------------------------------
+--R                                      4
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2           +-+
+--R            (x  + 2x + 3)\|2  - 4x - 4     +-+     2
+--R        log(--------------------------) + \|2 log(x  + 2x - 1)
+--R                     2
+--R                    x  + 2x - 1
+--R   (3)  ------------------------------------------------------
+--R                                   +-+
+--R                                 2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 419
+
+--S 420 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2           +-+
+--R           (x  + 2x + 3)\|2  - 4x - 4        +-+          +-+
+--R       log(--------------------------) + (- \|2  + 1)log(\|2  + x + 1)
+--R                    2
+--R                   x  + 2x - 1
+--R     + 
+--R        +-+     2                 +-+            +-+
+--R       \|2 log(x  + 2x - 1) + (- \|2  - 1)log(- \|2  + x + 1)
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 420
+
+--S 421 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 421
+
+)clear all
+
+--S 422 of 1580
+t0:=(1+2*x^8)/(x*(1+x^8)^(3/2))
+--R 
+--R
+--R               8
+--R             2x  + 1
+--R   (1)  -----------------
+--R                 +------+
+--R          9      | 8
+--R        (x  + x)\|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 1580
+r0:=-1/4*atanh(sqrt(1+x^8))+(-1/4)/sqrt(1+x^8)
+--R 
+--R
+--R           +------+       +------+
+--R           | 8            | 8
+--R        - \|x  + 1 atanh(\|x  + 1 ) - 1
+--R   (2)  -------------------------------
+--R                     +------+
+--R                     | 8
+--R                   4\|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 423
+
+--S 424 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R           +------+     +------+         +------+     +------+
+--R           | 8          | 8              | 8          | 8
+--R        - \|x  + 1 log(\|x  + 1  + 1) + \|x  + 1 log(\|x  + 1  - 1) - 2
+--R   (3)  ---------------------------------------------------------------
+--R                                     +------+
+--R                                     | 8
+--R                                   8\|x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 424
+
+--S 425 of 1580
+m0:=a0-r0
+--R 
+--R
+--R               +------+             +------+                +------+
+--R               | 8                  | 8                     | 8
+--R        - log(\|x  + 1  + 1) + log(\|x  + 1  - 1) + 2atanh(\|x  + 1 )
+--R   (4)  -------------------------------------------------------------
+--R                                      8
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 1580
+t0:=(1+2*x^8)*sqrt(1+x^8)/(x+2*x^9+x^17)
+--R 
+--R
+--R                  +------+
+--R           8      | 8
+--R        (2x  + 1)\|x  + 1
+--R   (1)  ------------------
+--R            17     9
+--R           x   + 2x  + x
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 1580
+r0:=-1/4*atanh(sqrt(1+x^8))+(-1/4)/sqrt(1+x^8)
+--R 
+--R
+--R           +------+       +------+
+--R           | 8            | 8
+--R        - \|x  + 1 atanh(\|x  + 1 ) - 1
+--R   (2)  -------------------------------
+--R                     +------+
+--R                     | 8
+--R                   4\|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R           +------+     +------+         +------+     +------+
+--R           | 8          | 8              | 8          | 8
+--R        - \|x  + 1 log(\|x  + 1  + 1) + \|x  + 1 log(\|x  + 1  - 1) - 2
+--R   (3)  ---------------------------------------------------------------
+--R                                     +------+
+--R                                     | 8
+--R                                   8\|x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 429
+
+--S 430 of 1580
+m0:=a0-r0
+--R 
+--R
+--R               +------+             +------+                +------+
+--R               | 8                  | 8                     | 8
+--R        - log(\|x  + 1  + 1) + log(\|x  + 1  - 1) + 2atanh(\|x  + 1 )
+--R   (4)  -------------------------------------------------------------
+--R                                      8
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 431
+
+)clear all
+
+--S 432 of 1580
+t0:=1-9*x^2+x/sqrt(1-9*x^2)
+--R 
+--R
+--R                    +---------+
+--R             2      |    2
+--R        (- 9x  + 1)\|- 9x  + 1  + x
+--R   (1)  ---------------------------
+--R                 +---------+
+--R                 |    2
+--R                \|- 9x  + 1
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 1580
+r0:=x-3*x^3-1/9*sqrt(1-9*x^2)
+--R 
+--R
+--R           +---------+
+--R           |    2           3
+--R        - \|- 9x  + 1  - 27x  + 9x
+--R   (2)  --------------------------
+--R                     9
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    +---------+
+--R             3      |    2          3    2
+--R        (- 3x  + x)\|- 9x  + 1  + 3x  + x  - x
+--R   (3)  --------------------------------------
+--R                    +---------+
+--R                    |    2
+--R                   \|- 9x  + 1  - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 434
+
+--S 435 of 1580
+m0:=a0-r0
+--R 
+--R
+--R          1
+--R   (4)  - -
+--R          9
+--R                                                    Type: Expression(Integer)
+--E 435
+
+--S 436 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 436
+
+)clear all
+
+--S 437 of 1580
+t0:=(x+(1-9*x^2)^(3/2))/sqrt(1-9*x^2)
+--R 
+--R
+--R                    +---------+
+--R             2      |    2
+--R        (- 9x  + 1)\|- 9x  + 1  + x
+--R   (1)  ---------------------------
+--R                 +---------+
+--R                 |    2
+--R                \|- 9x  + 1
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 1580
+r0:=x-3*x^3-1/9*sqrt(1-9*x^2)
+--R 
+--R
+--R           +---------+
+--R           |    2           3
+--R        - \|- 9x  + 1  - 27x  + 9x
+--R   (2)  --------------------------
+--R                     9
+--R                                                    Type: Expression(Integer)
+--E 438
+
+--S 439 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    +---------+
+--R             3      |    2          3    2
+--R        (- 3x  + x)\|- 9x  + 1  + 3x  + x  - x
+--R   (3)  --------------------------------------
+--R                    +---------+
+--R                    |    2
+--R                   \|- 9x  + 1  - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 439
+
+--S 440 of 1580
+m0:=a0-r0
+--R 
+--R
+--R          1
+--R   (4)  - -
+--R          9
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 1580
+t0:=(x-3*sqrt(x))^(2/3)*(-3+2*sqrt(x))/sqrt(x)
+--R 
+--R
+--R                    +-----------+2
+--R           +-+     3|    +-+
+--R        (2\|x  - 3)\|- 3\|x  + x
+--R   (1)  --------------------------
+--R                    +-+
+--R                   \|x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 1580
+r0:=6/5*(x-3*sqrt(x))^(5/3)
+--R 
+--R
+--R                        +-----------+2
+--R              +-+      3|    +-+
+--R        (- 18\|x  + 6x)\|- 3\|x  + x
+--R   (2)  ------------------------------
+--R                       5
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        +-----------+2
+--R              +-+      3|    +-+
+--R        (- 18\|x  + 6x)\|- 3\|x  + x
+--R   (3)  ------------------------------
+--R                       5
+--R                                         Type: Union(Expression(Integer),...)
+--E 444
+
+--S 445 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 446
+
+)clear all
+
+--S 447 of 1580
+t0:=(9+2*x-9*sqrt(x))/(x-3*sqrt(x))^(1/3)
+--R 
+--R
+--R            +-+
+--R        - 9\|x  + 2x + 9
+--R   (1)  ----------------
+--R          +-----------+
+--R         3|    +-+
+--R         \|- 3\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 1580
+r0:=6/5*(x-3*sqrt(x))^(5/3)
+--R 
+--R
+--R                        +-----------+2
+--R              +-+      3|    +-+
+--R        (- 18\|x  + 6x)\|- 3\|x  + x
+--R   (2)  ------------------------------
+--R                       5
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        +-----------+2
+--R              +-+      3|    +-+
+--R        (- 18\|x  + 6x)\|- 3\|x  + x
+--R   (3)  ------------------------------
+--R                       5
+--R                                         Type: Union(Expression(Integer),...)
+--E 449
+
+--S 450 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+--S 451 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 451
+
+)clear all
+
+--S 452 of 1580
+t0:=2/(-1+4*x^2)
+--R 
+--R
+--R           2
+--R   (1)  -------
+--R          2
+--R        4x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 452
+
+--S 453 of 1580
+r0:=-atanh(2*x)
+--R 
+--R
+--R   (2)  - atanh(2x)
+--R                                                    Type: Expression(Integer)
+--E 453
+
+--S 454 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - log(2x + 1) + log(2x - 1)
+--R   (3)  ---------------------------
+--R                     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 454
+
+--S 455 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        - log(2x + 1) + log(2x - 1) + 2atanh(2x)
+--R   (4)  ----------------------------------------
+--R                            2
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 1580
+t0:=1/(-1+2*x)+(-1)/(1+2*x)
+--R 
+--R
+--R           2
+--R   (1)  -------
+--R          2
+--R        4x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 457
+
+--S 458 of 1580
+r0:=1/2*log(1-2*x)-1/2*log(1+2*x)
+--R 
+--R
+--R        - log(2x + 1) + log(- 2x + 1)
+--R   (2)  -----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - log(2x + 1) + log(2x - 1)
+--R   (3)  ---------------------------
+--R                     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 459
+
+--S 460 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        log(2x - 1) - log(- 2x + 1)
+--R   (4)  ---------------------------
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 461
+
+)clear all
+
+--S 462 of 1580
+t0:=1/sqrt(4-9*x^2)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         +---------+
+--R         |    2
+--R        \|- 9x  + 4
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 1580
+r0:=1/3*asin(3/2*x)
+--R 
+--R
+--R             3x
+--R        asin(--)
+--R              2
+--R   (2)  --------
+--R            3
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +---------+
+--R                 |    2
+--R                \|- 9x  + 4  - 2
+--R          2atan(----------------)
+--R                       3x
+--R   (3)  - -----------------------
+--R                     3
+--R                                         Type: Union(Expression(Integer),...)
+--E 464
+
+--S 465 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +---------+
+--R                 |    2
+--R                \|- 9x  + 4  - 2         3x
+--R        - 2atan(----------------) - asin(--)
+--R                       3x                 2
+--R   (4)  ------------------------------------
+--R                          3
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 466
+
+)clear all
+
+--S 467 of 1580
+t0:=1/(sqrt(2-3*x)*sqrt(2+3*x))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +--------+ +------+
+--R        \|- 3x + 2 \|3x + 2
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 1580
+r0:=1/3*asin(3/2*x)
+--R 
+--R
+--R             3x
+--R        asin(--)
+--R              2
+--R   (2)  --------
+--R            3
+--R                                                    Type: Expression(Integer)
+--E 468
+
+--S 469 of 1580
+--a0:=integrate(t0,x)
+--E 469
+
+--S 470 of 1580
+--m0:=a0-r0
+--E 470
+
+--S 471 of 1580
+--d0:=D(m0,x)
+--E 471
+
+)clear all
+
+--S 472 of 1580
+t0:=1/sqrt((2-3*x)*(2+3*x))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         +---------+
+--R         |    2
+--R        \|- 9x  + 4
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 1580
+r0:=1/3*asin(3/2*x)
+--R 
+--R
+--R             3x
+--R        asin(--)
+--R              2
+--R   (2)  --------
+--R            3
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +---------+
+--R                 |    2
+--R                \|- 9x  + 4  - 2
+--R          2atan(----------------)
+--R                       3x
+--R   (3)  - -----------------------
+--R                     3
+--R                                         Type: Union(Expression(Integer),...)
+--E 474
+
+--S 475 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +---------+
+--R                 |    2
+--R                \|- 9x  + 4  - 2         3x
+--R        - 2atan(----------------) - asin(--)
+--R                       3x                 2
+--R   (4)  ------------------------------------
+--R                          3
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 476
+
+)clear all
+
+--S 477 of 1580
+t0:=1/(sqrt(3-x)*sqrt(5+x))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +-------+ +-----+
+--R        \|- x + 3 \|x + 5
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 1580
+r0:=-asin(1/4*(-1-x))
+--R 
+--R
+--R             x + 1
+--R   (2)  asin(-----)
+--R               4
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 1580
+--a0:=integrate(t0,x)
+--E 479
+
+--S 480 of 1580
+--m0:=a0-r0
+--E 480
+
+--S 481 of 1580
+--d0:=D(m0,x)
+--E 481
+
+)clear all
+
+--S 482 of 1580
+t0:=1/sqrt((3-x)*(5+x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|- x  - 2x + 15
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 1580
+r0:=-asin(1/4*(-1-x))
+--R 
+--R
+--R             x + 1
+--R   (2)  asin(-----)
+--R               4
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------------+
+--R                 |   2               +--+
+--R                \|- x  - 2x + 15  - \|15
+--R   (3)  - 2atan(-------------------------)
+--R                            x
+--R                                         Type: Union(Expression(Integer),...)
+--E 484
+
+--S 485 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +--------------+
+--R                 |   2               +--+
+--R                \|- x  - 2x + 15  - \|15          x + 1
+--R   (4)  - 2atan(-------------------------) - asin(-----)
+--R                            x                       4
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 1580
+t0:=1/sqrt(15-2*x-x^2)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|- x  - 2x + 15
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 1580
+r0:=-asin(1/4*(-1-x))
+--R 
+--R
+--R             x + 1
+--R   (2)  asin(-----)
+--R               4
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------------+
+--R                 |   2               +--+
+--R                \|- x  - 2x + 15  - \|15
+--R   (3)  - 2atan(-------------------------)
+--R                            x
+--R                                         Type: Union(Expression(Integer),...)
+--E 489
+
+--S 490 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +--------------+
+--R                 |   2               +--+
+--R                \|- x  - 2x + 15  - \|15          x + 1
+--R   (4)  - 2atan(-------------------------) - asin(-----)
+--R                            x                       4
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 491
+
+)clear all
+
+--S 492 of 1580
+t0:=1/(sqrt(-3-x)*sqrt(5+x))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +-------+ +-----+
+--R        \|- x - 3 \|x + 5
+--R                                                    Type: Expression(Integer)
+--E 492
+
+--S 493 of 1580
+r0:=asin(4+x)
+--R 
+--R
+--R   (2)  asin(x + 4)
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 1580
+--a0:=integrate(t0,x)
+--E 494
+
+--S 495 of 1580
+--m0:=a0-r0
+--E 495
+
+--S 496 of 1580
+--d0:=D(m0,x)
+--E 496
+
+)clear all
+
+--S 497 of 1580
+t0:=1/sqrt((-3-x)*(5+x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|- x  - 8x - 15
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 1580
+r0:=asin(4+x)
+--R 
+--R
+--R   (2)  asin(x + 4)
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +--------------+
+--R                |   2
+--R               \|- x  - 8x - 15
+--R   (3)  - atan(-----------------)
+--R                     x + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 499
+
+--S 500 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                +--------------+
+--R                |   2
+--R               \|- x  - 8x - 15
+--R   (4)  - atan(-----------------) - asin(x + 4)
+--R                     x + 4
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 1580
+t0:=1/sqrt(-15-8*x-x^2)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|- x  - 8x - 15
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 1580
+r0:=asin(4+x)
+--R 
+--R
+--R   (2)  asin(x + 4)
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +--------------+
+--R                |   2
+--R               \|- x  - 8x - 15
+--R   (3)  - atan(-----------------)
+--R                     x + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 504
+
+--S 505 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                +--------------+
+--R                |   2
+--R               \|- x  - 8x - 15
+--R   (4)  - atan(-----------------) - asin(x + 4)
+--R                     x + 4
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 506
+
+)clear all
+
+--S 507 of 1580
+t0:=1-sqrt(x)
+--R 
+--R
+--R           +-+
+--R   (1)  - \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 1580
+r0:=x-2/3*x^(3/2)
+--R 
+--R
+--R             +-+
+--R        - 2x\|x  + 3x
+--R   (2)  -------------
+--R              3
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +-+
+--R        - 2x\|x  + 3x
+--R   (3)  -------------
+--R              3
+--R                                         Type: Union(Expression(Integer),...)
+--E 509
+
+--S 510 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+--S 511 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 511
+
+)clear all
+
+--S 512 of 1580
+t0:=(1-x)/(1+sqrt(x))
+--R 
+--R
+--R         - x + 1
+--R   (1)  --------
+--R         +-+
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 1580
+r0:=x-2/3*x^(3/2)
+--R 
+--R
+--R             +-+
+--R        - 2x\|x  + 3x
+--R   (2)  -------------
+--R              3
+--R                                                    Type: Expression(Integer)
+--E 513
+
+--S 514 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +-+
+--R        - 2x\|x  + 3x
+--R   (3)  -------------
+--R              3
+--R                                         Type: Union(Expression(Integer),...)
+--E 514
+
+--S 515 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 1580
+t0:=sqrt(1/(1-x^2))
+--R 
+--R
+--R         +--------+
+--R         |     1
+--R   (1)   |- ------
+--R         |   2
+--R        \|  x  - 1
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 1580
+r0:=asin(x)*sqrt(1/(1-x^2))*sqrt(1-x^2)
+--R 
+--R
+--R                +--------+ +--------+
+--R                |   2      |     1
+--R   (2)  asin(x)\|- x  + 1  |- ------
+--R                           |   2
+--R                          \|  x  - 1
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R                \|- x  + 1  - 1
+--R   (3)  - 2atan(---------------)
+--R                       x
+--R                                         Type: Union(Expression(Integer),...)
+--E 519
+
+--S 520 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +--------+
+--R                 |   2                     +--------+ +--------+
+--R                \|- x  + 1  - 1            |   2      |     1
+--R   (4)  - 2atan(---------------) - asin(x)\|- x  + 1  |- ------
+--R                       x                              |   2
+--R                                                     \|  x  - 1
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R           +--------+ +--------+
+--R           |   2      |     1
+--R        - \|- x  + 1  |- ------  + 1
+--R                      |   2
+--R                     \|  x  - 1
+--R   (5)  ----------------------------
+--R                  +--------+
+--R                  |   2
+--R                 \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 521
+
+)clear all
+
+--S 522 of 1580
+t0:=sqrt((1+x^2)/(1-x^4))
+--R 
+--R
+--R         +--------+
+--R         |     1
+--R   (1)   |- ------
+--R         |   2
+--R        \|  x  - 1
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 1580
+r0:=asin(x)*sqrt(1/(1-x^2))*sqrt(1-x^2)
+--R 
+--R
+--R                +--------+ +--------+
+--R                |   2      |     1
+--R   (2)  asin(x)\|- x  + 1  |- ------
+--R                           |   2
+--R                          \|  x  - 1
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R                \|- x  + 1  - 1
+--R   (3)  - 2atan(---------------)
+--R                       x
+--R                                         Type: Union(Expression(Integer),...)
+--E 524
+
+--S 525 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +--------+
+--R                 |   2                     +--------+ +--------+
+--R                \|- x  + 1  - 1            |   2      |     1
+--R   (4)  - 2atan(---------------) - asin(x)\|- x  + 1  |- ------
+--R                       x                              |   2
+--R                                                     \|  x  - 1
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R           +--------+ +--------+
+--R           |   2      |     1
+--R        - \|- x  + 1  |- ------  + 1
+--R                      |   2
+--R                     \|  x  - 1
+--R   (5)  ----------------------------
+--R                  +--------+
+--R                  |   2
+--R                 \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 526
+
+)clear all
+
+--S 527 of 1580
+t0:=sqrt(1/(-1+x^2))
+--R 
+--R
+--R         +------+
+--R         |   1
+--R   (1)   |------
+--R         | 2
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 1580
+r0:=atanh(x/sqrt(-1+x^2))*sqrt(1/(-1+x^2))*sqrt(-1+x^2)
+--R 
+--R
+--R         +------+ +------+
+--R         |   1    | 2               x
+--R   (2)   |------ \|x  - 1 atanh(---------)
+--R         | 2                     +------+
+--R        \|x  - 1                 | 2
+--R                                \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 528
+
+--S 529 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +------+
+--R               | 2
+--R   (3)  - log(\|x  - 1  - x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 529
+
+--S 530 of 1580
+m0:=a0-r0
+--R 
+--R
+--R               +------+         +------+ +------+
+--R               | 2              |   1    | 2               x
+--R   (4)  - log(\|x  - 1  - x) -  |------ \|x  - 1 atanh(---------)
+--R                                | 2                     +------+
+--R                               \|x  - 1                 | 2
+--R                                                       \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R           +------+            +------+
+--R           | 2          2      |   1
+--R        - \|x  - 1  + (x  - 1) |------
+--R                               | 2
+--R                              \|x  - 1
+--R   (5)  -------------------------------
+--R                    +------+ +------+
+--R             2      |   1    | 2
+--R           (x  - 1) |------ \|x  - 1
+--R                    | 2
+--R                   \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 531
+
+)clear all
+
+--S 532 of 1580
+t0:=sqrt((1+x^2)/(-1+x^4))
+--R 
+--R
+--R         +------+
+--R         |   1
+--R   (1)   |------
+--R         | 2
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 1580
+r0:=atanh(x/sqrt(-1+x^2))*sqrt(1/(-1+x^2))*sqrt(-1+x^2)
+--R 
+--R
+--R         +------+ +------+
+--R         |   1    | 2               x
+--R   (2)   |------ \|x  - 1 atanh(---------)
+--R         | 2                     +------+
+--R        \|x  - 1                 | 2
+--R                                \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +------+
+--R               | 2
+--R   (3)  - log(\|x  - 1  - x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 534
+
+--S 535 of 1580
+m0:=a0-r0
+--R 
+--R
+--R               +------+         +------+ +------+
+--R               | 2              |   1    | 2               x
+--R   (4)  - log(\|x  - 1  - x) -  |------ \|x  - 1 atanh(---------)
+--R                                | 2                     +------+
+--R                               \|x  - 1                 | 2
+--R                                                       \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R           +------+            +------+
+--R           | 2          2      |   1
+--R        - \|x  - 1  + (x  - 1) |------
+--R                               | 2
+--R                              \|x  - 1
+--R   (5)  -------------------------------
+--R                    +------+ +------+
+--R             2      |   1    | 2
+--R           (x  - 1) |------ \|x  - 1
+--R                    | 2
+--R                   \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 536
+
+)clear all
+
+--S 537 of 1580
+t0:=(1+x^6)/(-1+x^6)
+--R 
+--R
+--R         6
+--R        x  + 1
+--R   (1)  ------
+--R         6
+--R        x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 537
+
+--S 538 of 1580
+r0:=x-2/3*atanh(x)+1/6*log(1-x+x^2)-1/6*log(1+x+x^2)+_
+   atan((1-2*x)/sqrt(3))/sqrt(3)-atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          +-+     2             +-+     2              +-+
+--R       - \|3 log(x  + x + 1) + \|3 log(x  - x + 1) - 4\|3 atanh(x)
+--R     + 
+--R                        +-+                   +-+
+--R               (2x + 1)\|3           (2x - 1)\|3        +-+
+--R       - 6atan(------------) - 6atan(------------) + 6x\|3
+--R                     3                     3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-+     2             +-+     2              +-+
+--R       - \|3 log(x  + x + 1) + \|3 log(x  - x + 1) - 2\|3 log(x + 1)
+--R     + 
+--R                                        +-+                   +-+
+--R         +-+                   (2x + 1)\|3           (2x - 1)\|3        +-+
+--R       2\|3 log(x - 1) - 6atan(------------) - 6atan(------------) + 6x\|3
+--R                                     3                     3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 539
+
+--S 540 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        - log(x + 1) + log(x - 1) + 2atanh(x)
+--R   (4)  -------------------------------------
+--R                          3
+--R                                                    Type: Expression(Integer)
+--E 540
+
+--S 541 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 541
+
+)clear all
+
+--S 542 of 1580
+t0:=(1/x^3+x^3)/((-1)/x^3+x^3)
+--R 
+--R
+--R         6
+--R        x  + 1
+--R   (1)  ------
+--R         6
+--R        x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 542
+
+--S 543 of 1580
+r0:=x-2/3*atanh(x)+1/6*log(1-x+x^2)-1/6*log(1+x+x^2)+_
+   atan((1-2*x)/sqrt(3))/sqrt(3)-atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          +-+     2             +-+     2              +-+
+--R       - \|3 log(x  + x + 1) + \|3 log(x  - x + 1) - 4\|3 atanh(x)
+--R     + 
+--R                        +-+                   +-+
+--R               (2x + 1)\|3           (2x - 1)\|3        +-+
+--R       - 6atan(------------) - 6atan(------------) + 6x\|3
+--R                     3                     3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-+     2             +-+     2              +-+
+--R       - \|3 log(x  + x + 1) + \|3 log(x  - x + 1) - 2\|3 log(x + 1)
+--R     + 
+--R                                        +-+                   +-+
+--R         +-+                   (2x + 1)\|3           (2x - 1)\|3        +-+
+--R       2\|3 log(x - 1) - 6atan(------------) - 6atan(------------) + 6x\|3
+--R                                     3                     3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 544
+
+--S 545 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        - log(x + 1) + log(x - 1) + 2atanh(x)
+--R   (4)  -------------------------------------
+--R                          3
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 546
+
+)clear all
+
+--S 547 of 1580
+t0:=1/sqrt(1-x)
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R         +-------+
+--R        \|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 1580
+r0:=-2*sqrt(1-x)
+--R 
+--R
+--R            +-------+
+--R   (2)  - 2\|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +-------+
+--R   (3)  - 2\|- x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 549
+
+--S 550 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 551
+
+)clear all
+
+--S 552 of 1580
+t0:=sqrt(1+x)/sqrt(1-x^2)
+--R 
+--R
+--R           +-----+
+--R          \|x + 1
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 1580
+r0:=-2*sqrt(1-x)
+--R 
+--R
+--R            +-------+
+--R   (2)  - 2\|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +--------+
+--R            |   2      +-----+
+--R          2\|- x  + 1 \|x + 1
+--R   (3)  - --------------------
+--R                  x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 554
+
+--S 555 of 1580
+m0:=a0-r0
+--R 
+--R
+--R            +--------+
+--R            |   2      +-----+            +-------+
+--R        - 2\|- x  + 1 \|x + 1  + (2x + 2)\|- x + 1
+--R   (4)  -------------------------------------------
+--R                           x + 1
+--R                                                    Type: Expression(Integer)
+--E 555
+
+--S 556 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R           +--------+
+--R           |   2      +-----+           +-------+
+--R        - \|- x  + 1 \|x + 1  + (x + 1)\|- x + 1
+--R   (5)  -----------------------------------------
+--R               +--------+
+--R               |   2      +-------+ +-----+
+--R              \|- x  + 1 \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 556
+
+)clear all
+
+--S 557 of 1580
+t0:=1/sqrt(1+x)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R         +-----+
+--R        \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 1580
+r0:=2*sqrt(1+x)
+--R 
+--R
+--R          +-----+
+--R   (2)  2\|x + 1
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +-----+
+--R   (3)  2\|x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 559
+
+--S 560 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 1580
+t0:=sqrt(1-x)/sqrt(1-x^2)
+--R 
+--R
+--R          +-------+
+--R         \|- x + 1
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 1580
+r0:=2*sqrt(1+x)
+--R 
+--R
+--R          +-----+
+--R   (2)  2\|x + 1
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +--------+
+--R            |   2      +-------+
+--R        - 6\|- x  + 1 \|- x + 1  + 10x - 10
+--R   (3)  -----------------------------------
+--R                       3x - 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 564
+
+--S 565 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                               +--------+
+--R                   +-----+     |   2      +-------+
+--R        (- 6x + 6)\|x + 1  - 6\|- x  + 1 \|- x + 1  + 10x - 10
+--R   (4)  ------------------------------------------------------
+--R                                3x - 3
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R                             +--------+
+--R                  +-----+    |   2      +-------+
+--R        (- x + 1)\|x + 1  - \|- x  + 1 \|- x + 1
+--R   (5)  -----------------------------------------
+--R               +--------+
+--R               |   2      +-------+ +-----+
+--R              \|- x  + 1 \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 566
+
+)clear all
+
+--S 567 of 1580
+t0:=sqrt(1-x)
+--R 
+--R
+--R         +-------+
+--R   (1)  \|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 1580
+r0:=-2/3*(1-x)^(3/2)
+--R 
+--R
+--R                 +-------+
+--R        (2x - 2)\|- x + 1
+--R   (2)  ------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-------+
+--R        (2x - 2)\|- x + 1
+--R   (3)  ------------------
+--R                 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 569
+
+--S 570 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 571
+
+)clear all
+
+--S 572 of 1580
+t0:=sqrt(1-x^2)/sqrt(1+x)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R   (1)  -----------
+--R           +-----+
+--R          \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 1580
+r0:=-2/3*(1-x)^(3/2)
+--R 
+--R
+--R                 +-------+
+--R        (2x - 2)\|- x + 1
+--R   (2)  ------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------+
+--R                 |   2      +-----+
+--R        (8x - 8)\|- x  + 1 \|x + 1  + 17x + 17
+--R   (3)  --------------------------------------
+--R                       12x + 12
+--R                                         Type: Union(Expression(Integer),...)
+--E 574
+
+--S 575 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +--------+
+--R                 |   2      +-----+        2      +-------+
+--R        (8x - 8)\|- x  + 1 \|x + 1  + (- 8x  + 8)\|- x + 1  + 17x + 17
+--R   (4)  --------------------------------------------------------------
+--R                                   12x + 12
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R                +--------+
+--R                |   2      +-----+       2      +-------+
+--R        (x - 1)\|- x  + 1 \|x + 1  + (- x  + 1)\|- x + 1
+--R   (5)  -------------------------------------------------
+--R                   +--------+
+--R                   |   2      +-------+ +-----+
+--R                  \|- x  + 1 \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 1580
+t0:=sqrt(1+x)
+--R 
+--R
+--R         +-----+
+--R   (1)  \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 1580
+r0:=2/3*(1+x)^(3/2)
+--R 
+--R
+--R                 +-----+
+--R        (2x + 2)\|x + 1
+--R   (2)  ----------------
+--R                3
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-----+
+--R        (2x + 2)\|x + 1
+--R   (3)  ----------------
+--R                3
+--R                                         Type: Union(Expression(Integer),...)
+--E 579
+
+--S 580 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 581
+
+)clear all
+
+--S 582 of 1580
+t0:=sqrt(1-x^2)/sqrt(1-x)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R   (1)  -----------
+--R          +-------+
+--R         \|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 1580
+r0:=2/3*(1+x)^(3/2)
+--R 
+--R
+--R                 +-----+
+--R        (2x + 2)\|x + 1
+--R   (2)  ----------------
+--R                3
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +--------+
+--R                   |   2      +-------+
+--R        (- 4x - 4)\|- x  + 1 \|- x + 1  - 5x + 5
+--R   (3)  ----------------------------------------
+--R                         6x - 6
+--R                                         Type: Union(Expression(Integer),...)
+--E 584
+
+--S 585 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                                         +--------+
+--R             2      +-----+              |   2      +-------+
+--R        (- 4x  + 4)\|x + 1  + (- 4x - 4)\|- x  + 1 \|- x + 1  - 5x + 5
+--R   (4)  --------------------------------------------------------------
+--R                                    6x - 6
+--R                                                    Type: Expression(Integer)
+--E 585
+
+--S 586 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R                                       +--------+
+--R            2      +-----+             |   2      +-------+
+--R        (- x  + 1)\|x + 1  + (- x - 1)\|- x  + 1 \|- x + 1
+--R   (5)  ---------------------------------------------------
+--R                    +--------+
+--R                    |   2      +-------+ +-----+
+--R                   \|- x  + 1 \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 586
+
+)clear all
+
+--S 587 of 1580
+t0:=sqrt(2+3*x)/sqrt(1+x)
+--R 
+--R
+--R         +------+
+--R        \|3x + 2
+--R   (1)  ---------
+--R          +-----+
+--R         \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 1580
+r0:=-asinh(sqrt(2+3*x))/sqrt(3)+sqrt(1+x)*sqrt(2+3*x)
+--R 
+--R
+--R                 +------+     +-+ +-----+ +------+
+--R        - asinh(\|3x + 2 ) + \|3 \|x + 1 \|3x + 2
+--R   (2)  ------------------------------------------
+--R                            +-+
+--R                           \|3
+--R                                                    Type: Expression(Integer)
+--E 588
+
+--S 589 of 1580
+--a0:=integrate(t0,x)
+--E 589
+
+--S 590 of 1580
+--m0:=a0-r0
+--E 590
+
+--S 591 of 1580
+--d0:=D(m0,x)
+--E 591
+
+)clear all
+
+--S 592 of 1580
+t0:=sqrt(1-x)*sqrt(2+3*x)/sqrt(1-x^2)
+--R 
+--R
+--R         +-------+ +------+
+--R        \|- x + 1 \|3x + 2
+--R   (1)  -------------------
+--R             +--------+
+--R             |   2
+--R            \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 1580
+r0:=-asinh(sqrt(2+3*x))/sqrt(3)+sqrt(1+x)*sqrt(2+3*x)
+--R 
+--R
+--R                 +------+     +-+ +-----+ +------+
+--R        - asinh(\|3x + 2 ) + \|3 \|x + 1 \|3x + 2
+--R   (2)  ------------------------------------------
+--R                            +-+
+--R                           \|3
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          +--------+
+--R                          |   2      +-------+ +------+        2          +-+
+--R                 +-+    6\|- x  + 1 \|- x + 1 \|3x + 2  + (- 6x  + x + 5)\|3
+--R       (- x + 1)\|3 log(-----------------------------------------------------)
+--R                                                x - 1
+--R     + 
+--R           +--------+
+--R           |   2      +-------+ +------+
+--R       - 6\|- x  + 1 \|- x + 1 \|3x + 2
+--R  /
+--R     6x - 6
+--R                                         Type: Union(Expression(Integer),...)
+--E 594
+
+--S 595 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +--------+
+--R                      |   2      +-------+ +------+        2          +-+
+--R                    6\|- x  + 1 \|- x + 1 \|3x + 2  + (- 6x  + x + 5)\|3
+--R       (- x + 1)log(-----------------------------------------------------)
+--R                                            x - 1
+--R     + 
+--R                      +------+
+--R       (2x - 2)asinh(\|3x + 2 )
+--R     + 
+--R                                       +--------+
+--R                   +-+ +-----+     +-+ |   2      +-------+  +------+
+--R       ((- 2x + 2)\|3 \|x + 1  - 2\|3 \|- x  + 1 \|- x + 1 )\|3x + 2
+--R  /
+--R              +-+
+--R     (2x - 2)\|3
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                   3      2             +-----+
+--R               (36x  + 24x  - 36x - 24)\|x + 1
+--R             + 
+--R                                 +--------+
+--R                   2             |   2      +-------+
+--R               (36x  + 66x + 30)\|- x  + 1 \|- x + 1
+--R          *
+--R              +------+
+--R             \|3x + 2
+--R         + 
+--R                                   +--------+
+--R                 2             +-+ |   2      +-------+ +-----+
+--R           (- 36x  - 54x - 20)\|3 \|- x  + 1 \|- x + 1 \|x + 1
+--R         + 
+--R                 4      3      2             +-+
+--R           (- 36x  - 60x  + 11x  + 60x + 25)\|3
+--R      *
+--R          +------+
+--R         \|3x + 3
+--R     + 
+--R                      +--------+
+--R                  +-+ |   2      +-------+ +-----+ +------+
+--R       (- 6x - 6)\|3 \|- x  + 1 \|- x + 1 \|x + 1 \|3x + 2
+--R     + 
+--R           3      2             +-----+
+--R       (18x  + 15x  - 18x - 15)\|x + 1
+--R  /
+--R             3      2             +-+ +-----+ +------+
+--R         (12x  + 10x  - 12x - 10)\|3 \|x + 1 \|3x + 2
+--R       + 
+--R                             +--------+
+--R               2             |   2      +-------+ +-----+
+--R         (- 36x  - 60x - 24)\|- x  + 1 \|- x + 1 \|x + 1
+--R    *
+--R        +------+
+--R       \|3x + 3
+--R                                                    Type: Expression(Integer)
+--E 596
+
+)clear all
+
+--S 597 of 1580
+t0:=(1+x)^(3/2)/((1-x)^(3/2)*x)
+--R 
+--R
+--R                   +-----+
+--R         (- x - 1)\|x + 1
+--R   (1)  ------------------
+--R          2      +-------+
+--R        (x  - x)\|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 1580
+r0:=-asin(x)-2*atanh(sqrt(1-x)/sqrt(1+x))+2*(1+x)^(3/2)/sqrt(1-x)+_
+   2*sqrt(1-x)*sqrt(1+x)
+--R 
+--R
+--R                            +-------+
+--R            +-------+      \|- x + 1       +-----+           +-------+
+--R        - 2\|- x + 1 atanh(----------) + 4\|x + 1  - asin(x)\|- x + 1
+--R                             +-----+
+--R                            \|x + 1
+--R   (2)  --------------------------------------------------------------
+--R                                   +-------+
+--R                                  \|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 1580
+--a0:=integrate(t0,x)
+--E 599
+
+--S 600 of 1580
+--m0:=a0-r0
+--E 600
+
+--S 601 of 1580
+--d0:=D(m0,x)
+--E 601
+
+)clear all
+
+--S 602 of 1580
+t0:=(1+x)^3/(x*(1-x^2)^(3/2))
+--R 
+--R
+--R              2
+--R           - x  - 2x - 1
+--R   (1)  -------------------
+--R                 +--------+
+--R          2      |   2
+--R        (x  - x)\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 1580
+r0:=-asin(x)-atanh(sqrt(1-x^2))+4/sqrt(1-x^2)+4*x/sqrt(1-x^2)
+--R 
+--R
+--R           +--------+       +--------+            +--------+
+--R           |   2            |   2                 |   2
+--R        - \|- x  + 1 atanh(\|- x  + 1 ) - asin(x)\|- x  + 1  + 4x + 4
+--R   (2)  -------------------------------------------------------------
+--R                                  +--------+
+--R                                  |   2
+--R                                 \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 +--------+
+--R         +--------+              |   2
+--R         |   2                  \|- x  + 1  - 1
+--R       (\|- x  + 1  + x - 1)log(---------------)
+--R                                       x
+--R     + 
+--R                                    +--------+
+--R          +--------+                |   2
+--R          |   2                    \|- x  + 1  - 1
+--R       (2\|- x  + 1  + 2x - 2)atan(---------------) + 8x
+--R                                          x
+--R  /
+--R      +--------+
+--R      |   2
+--R     \|- x  + 1  + x - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 604
+
+--S 605 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +--------+                                    +--------+
+--R          |   2                    +--------+           |   2
+--R         \|- x  + 1  - 1           |   2               \|- x  + 1  - 1
+--R     log(---------------) + atanh(\|- x  + 1 ) + 2atan(---------------)
+--R                x                                             x
+--R   + 
+--R     asin(x) + 4
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 606
+
+)clear all
+
+--S 607 of 1580
+t0:=(1+a*x)^(3/2)/(x*(1-a*x)^(3/2))
+--R 
+--R
+--R                     +-------+
+--R         (- a x - 1)\|a x + 1
+--R   (1)  ----------------------
+--R            2      +---------+
+--R        (a x  - x)\|- a x + 1
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 1580
+r0:=-asin(a*x)-2*atanh(sqrt(1-a*x)/sqrt(1+a*x))+2*(1+a*x)^(3/2)/_
+   sqrt(1-a*x)+2*sqrt(1-a*x)*sqrt(1+a*x)
+--R 
+--R
+--R   (2)
+--R                         +---------+
+--R       +---------+      \|- a x + 1       +-------+             +---------+
+--R   - 2\|- a x + 1 atanh(------------) + 4\|a x + 1  - asin(a x)\|- a x + 1
+--R                          +-------+
+--R                         \|a x + 1
+--R   ------------------------------------------------------------------------
+--R                                  +---------+
+--R                                 \|- a x + 1
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 1580
+--a0:=integrate(t0,x)
+--E 609
+
+--S 610 of 1580
+--m0:=a0-r0
+--E 610
+
+--S 611 of 1580
+--d0:=D(m0,x)
+--E 611
+
+)clear all
+
+--S 612 of 1580
+t0:=(1+a*x)^3/(x*(1-a^2*x^2)^(3/2))
+--R 
+--R
+--R              2 2
+--R           - a x  - 2a x - 1
+--R   (1)  -----------------------
+--R                   +----------+
+--R            2      |   2 2
+--R        (a x  - x)\|- a x  + 1
+--R                                                    Type: Expression(Integer)
+--E 612
+
+--S 613 of 1580
+r0:=-asin(a*x)-atanh(sqrt(1-a^2*x^2))+4/sqrt(1-a^2*x^2)+4*a*x/sqrt(1-a^2*x^2)
+--R 
+--R
+--R   (2)
+--R      +----------+       +----------+              +----------+
+--R      |   2 2            |   2 2                   |   2 2
+--R   - \|- a x  + 1 atanh(\|- a x  + 1 ) - asin(a x)\|- a x  + 1  + 4a x + 4
+--R   -----------------------------------------------------------------------
+--R                                 +----------+
+--R                                 |   2 2
+--R                                \|- a x  + 1
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                     +----------+
+--R         +----------+                |   2 2
+--R         |   2 2                    \|- a x  + 1  - 1
+--R       (\|- a x  + 1  + a x - 1)log(-----------------)
+--R                                            x
+--R     + 
+--R                                        +----------+
+--R          +----------+                  |   2 2
+--R          |   2 2                      \|- a x  + 1  - 1
+--R       (2\|- a x  + 1  + 2a x - 2)atan(-----------------) + 8a x
+--R                                              a x
+--R  /
+--R      +----------+
+--R      |   2 2
+--R     \|- a x  + 1  + a x - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 614
+
+--S 615 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +----------+                                      +----------+
+--R          |   2 2                    +----------+           |   2 2
+--R         \|- a x  + 1  - 1           |   2 2               \|- a x  + 1  - 1
+--R     log(-----------------) + atanh(\|- a x  + 1 ) + 2atan(-----------------)
+--R                 x                                                a x
+--R   + 
+--R     asin(a x) + 4
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 616
+
+)clear all
+
+--S 617 of 1580
+t0:=1/sqrt(1-x^2)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 1580
+r0:=asin(x)
+--R 
+--R
+--R   (2)  asin(x)
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R                \|- x  + 1  - 1
+--R   (3)  - 2atan(---------------)
+--R                       x
+--R                                         Type: Union(Expression(Integer),...)
+--E 619
+
+--S 620 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R                \|- x  + 1  - 1
+--R   (4)  - 2atan(---------------) - asin(x)
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 621
+
+)clear all
+
+--S 622 of 1580
+t0:=sqrt(1+x^2)/sqrt(1-x^4)
+--R 
+--R
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 1580
+r0:=asin(x)
+--R 
+--R
+--R   (2)  asin(x)
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     3
+--R                    x  + x
+--R   (3)  atan(--------------------)
+--R              +--------+ +------+
+--R              |   4      | 2
+--R             \|- x  + 1 \|x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 624
+
+--S 625 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                     3
+--R                    x  + x
+--R   (4)  atan(--------------------) - asin(x)
+--R              +--------+ +------+
+--R              |   4      | 2
+--R             \|- x  + 1 \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R           +--------+ +------+            +--------+
+--R           |   4      | 2          2      |   2
+--R        - \|- x  + 1 \|x  + 1  + (x  + 1)\|- x  + 1
+--R   (5)  --------------------------------------------
+--R                +--------+ +--------+ +------+
+--R                |   4      |   2      | 2
+--R               \|- x  + 1 \|- x  + 1 \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 626
+
+)clear all
+
+--S 627 of 1580
+t0:=1/sqrt(1+x^2)
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 1580
+r0:=asinh(x)
+--R 
+--R
+--R   (2)  asinh(x)
+--R                                                    Type: Expression(Integer)
+--E 628
+
+--S 629 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +------+
+--R               | 2
+--R   (3)  - log(\|x  + 1  - x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 629
+
+--S 630 of 1580
+m0:=a0-r0
+--R 
+--R
+--R               +------+
+--R               | 2
+--R   (4)  - log(\|x  + 1  - x) - asinh(x)
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 631
+
+)clear all
+
+--S 632 of 1580
+t0:=sqrt(1-x^2)/sqrt(1-x^4)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 1580
+r0:=asinh(x)
+--R 
+--R
+--R   (2)  asinh(x)
+--R                                                    Type: Expression(Integer)
+--E 633
+
+--S 634 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------+ +--------+
+--R                 |   4      |   2         3
+--R              - \|- x  + 1 \|- x  + 1  - x  + x
+--R   (3)  - log(---------------------------------)
+--R                             2
+--R                            x  - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 634
+
+--S 635 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +--------+ +--------+
+--R                 |   4      |   2         3
+--R              - \|- x  + 1 \|- x  + 1  - x  + x
+--R   (4)  - log(---------------------------------) - asinh(x)
+--R                             2
+--R                            x  - 1
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R                   +------+    +--------+ +--------+
+--R            2      | 2         |   4      |   2
+--R        (- x  + 1)\|x  + 1  - \|- x  + 1 \|- x  + 1
+--R   (5)  --------------------------------------------
+--R                +--------+ +--------+ +------+
+--R                |   4      |   2      | 2
+--R               \|- x  + 1 \|- x  + 1 \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 636
+
+)clear all
+
+--S 637 of 1580
+t0:=sqrt(1-x^2)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R   (1)  \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 1580
+r0:=1/2*asin(x)+1/2*x*sqrt(1-x^2)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        x\|- x  + 1  + asin(x)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                       +--------+
+--R            +--------+                 |   2                       +--------+
+--R            |   2          2          \|- x  + 1  - 1      3       |   2
+--R       (- 4\|- x  + 1  - 2x  + 4)atan(---------------) + (x  - 2x)\|- x  + 1
+--R                                             x
+--R     + 
+--R           3
+--R       - 2x  + 2x
+--R  /
+--R       +--------+
+--R       |   2          2
+--R     4\|- x  + 1  + 2x  - 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 639
+
+--S 640 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R                \|- x  + 1  - 1
+--R        - 2atan(---------------) - asin(x)
+--R                       x
+--R   (4)  ----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 641
+
+)clear all
+
+--S 642 of 1580
+t0:=sqrt(1-x^4)/sqrt(1+x^2)
+--R 
+--R
+--R         +--------+
+--R         |   4
+--R        \|- x  + 1
+--R   (1)  -----------
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 642
+
+--S 643 of 1580
+r0:=1/2*asin(x)+1/2*x*sqrt(1-x^2)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        x\|- x  + 1  + asin(x)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             3                 +--------+ +------+
+--R          2                 x  + x             |   4      | 2
+--R        (x  + 1)atan(--------------------) + x\|- x  + 1 \|x  + 1
+--R                      +--------+ +------+
+--R                      |   4      | 2
+--R                     \|- x  + 1 \|x  + 1
+--R   (3)  ----------------------------------------------------------
+--R                                    2
+--R                                  2x  + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 644
+
+--S 645 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            3                 +--------+ +------+
+--R         2                 x  + x             |   4      | 2
+--R       (x  + 1)atan(--------------------) + x\|- x  + 1 \|x  + 1
+--R                     +--------+ +------+
+--R                     |   4      | 2
+--R                    \|- x  + 1 \|x  + 1
+--R     + 
+--R                  +--------+
+--R           3      |   2            2
+--R       (- x  - x)\|- x  + 1  + (- x  - 1)asin(x)
+--R  /
+--R       2
+--R     2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 645
+
+--S 646 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R                 +--------+ +------+              +--------+
+--R          2      |   4      | 2            4      |   2
+--R        (x  - 1)\|- x  + 1 \|x  + 1  + (- x  + 1)\|- x  + 1
+--R   (5)  ----------------------------------------------------
+--R                    +--------+ +--------+ +------+
+--R                    |   4      |   2      | 2
+--R                   \|- x  + 1 \|- x  + 1 \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 646
+
+)clear all
+
+--S 647 of 1580
+t0:=sqrt(1+x^2)
+--R 
+--R
+--R         +------+
+--R         | 2
+--R   (1)  \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 1580
+r0:=1/2*asinh(x)+1/2*x*sqrt(1+x^2)
+--R 
+--R
+--R          +------+
+--R          | 2
+--R        x\|x  + 1  + asinh(x)
+--R   (2)  ---------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +------+                +------+                    +------+
+--R             | 2          2          | 2                  3      | 2          4
+--R       (- 2x\|x  + 1  + 2x  + 1)log(\|x  + 1  - x) + (- 2x  - x)\|x  + 1  + 2x
+--R     + 
+--R         2
+--R       2x
+--R  /
+--R        +------+
+--R        | 2          2
+--R     4x\|x  + 1  - 4x  - 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 649
+
+--S 650 of 1580
+m0:=a0-r0
+--R 
+--R
+--R               +------+
+--R               | 2
+--R        - log(\|x  + 1  - x) - asinh(x)
+--R   (4)  -------------------------------
+--R                       2
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 651
+
+)clear all
+
+--S 652 of 1580
+t0:=sqrt(1-x^4)/sqrt(1-x^2)
+--R 
+--R
+--R         +--------+
+--R         |   4
+--R        \|- x  + 1
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 1580
+r0:=1/2*asinh(x)+1/2*x*sqrt(1+x^2)
+--R 
+--R
+--R          +------+
+--R          | 2
+--R        x\|x  + 1  + asinh(x)
+--R   (2)  ---------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 653
+
+--S 654 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  +--------+ +--------+
+--R                  |   4      |   2         3          +--------+ +--------+
+--R       2         \|- x  + 1 \|- x  + 1  + x  - x      |   4      |   2
+--R   (- x  + 1)log(-------------------------------) - x\|- x  + 1 \|- x  + 1
+--R                               2
+--R                              x  - 1
+--R   ------------------------------------------------------------------------
+--R                                      2
+--R                                    2x  - 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 654
+
+--S 655 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +--------+ +--------+
+--R                      |   4      |   2         3                   +------+
+--R           2         \|- x  + 1 \|- x  + 1  + x  - x        3      | 2
+--R       (- x  + 1)log(-------------------------------) + (- x  + x)\|x  + 1
+--R                                   2
+--R                                  x  - 1
+--R     + 
+--R           +--------+ +--------+
+--R           |   4      |   2            2
+--R       - x\|- x  + 1 \|- x  + 1  + (- x  + 1)asinh(x)
+--R  /
+--R       2
+--R     2x  - 2
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R                   +------+              +--------+ +--------+
+--R            4      | 2            2      |   4      |   2
+--R        (- x  + 1)\|x  + 1  + (- x  - 1)\|- x  + 1 \|- x  + 1
+--R   (5)  ------------------------------------------------------
+--R                     +--------+ +--------+ +------+
+--R                     |   4      |   2      | 2
+--R                    \|- x  + 1 \|- x  + 1 \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 656
+
+)clear all
+
+--S 657 of 1580
+t0:=(a^2*c+a^2*d*x+2*a*b*c*x^2+2*a*b*d*x^3+b^2*c*x^4+b^2*d*x^5)/(c+d*x)
+--R 
+--R
+--R         2 4         2    2
+--R   (1)  b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 657
+
+--S 658 of 1580
+r0:=a^2*x+2/3*a*b*x^3+1/5*b^2*x^5
+--R 
+--R
+--R        1  2 5   2      3    2
+--R   (2)  - b x  + - a b x  + a x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 658
+
+--S 659 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 5          3      2
+--R        3b x  + 10a b x  + 15a x
+--R   (3)  ------------------------
+--R                   15
+--R                                         Type: Union(Expression(Integer),...)
+--E 659
+
+--S 660 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 661
+
+)clear all
+
+--S 662 of 1580
+t0:=(a^2*c+a^2*d*x+2*a*b*c*x^2+2*a*b*d*x^3+b^2*c*x^4+b^2*d*x^5)/(c+d*x)^2
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R              d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 662
+
+--S 663 of 1580
+r0:=-b*c*(b*c^2+2*a*d^2)*x/d^4+1/2*b*(b*c^2+2*a*d^2)*x^2/d^3-_
+   1/3*b^2*c*x^3/d^2+1/4*b^2*x^4/d+(b*c^2+a*d^2)^2*log(c+d*x)/d^5
+--R 
+--R
+--R   (2)
+--R           2 4          2 2      2 4                  2 4 4     2   3 3
+--R       (12a d  + 24a b c d  + 12b c )log(d x + c) + 3b d x  - 4b c d x
+--R     + 
+--R               4     2 2 2  2               3      2 3
+--R       (12a b d  + 6b c d )x  + (- 24a b c d  - 12b c d)x
+--R  /
+--R        5
+--R     12d
+--R                                                    Type: Expression(Integer)
+--E 663
+
+--S 664 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 4          2 2      2 4                  2 4 4     2   3 3
+--R       (12a d  + 24a b c d  + 12b c )log(d x + c) + 3b d x  - 4b c d x
+--R     + 
+--R               4     2 2 2  2               3      2 3
+--R       (12a b d  + 6b c d )x  + (- 24a b c d  - 12b c d)x
+--R  /
+--R        5
+--R     12d
+--R                                         Type: Union(Expression(Integer),...)
+--E 664
+
+--S 665 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 666
+
+)clear all
+
+--S 667 of 1580
+t0:=(a^2*c+a^2*d*x+2*a*b*c*x^2+2*a*b*d*x^3+b^2*c*x^4+b^2*d*x^5)/(a+b*x^2)
+--R 
+--R
+--R             3        2
+--R   (1)  b d x  + b c x  + a d x + a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 667
+
+--S 668 of 1580
+r0:=a*c*x+1/2*a*d*x^2+1/3*b*c*x^3+1/4*b*d*x^4
+--R 
+--R
+--R        1      4   1      3   1      2
+--R   (2)  - b d x  + - b c x  + - a d x  + a c x
+--R        4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 668
+
+--S 669 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4         3         2
+--R        3b d x  + 4b c x  + 6a d x  + 12a c x
+--R   (3)  -------------------------------------
+--R                          12
+--R                                         Type: Union(Expression(Integer),...)
+--E 669
+
+--S 670 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 671
+
+)clear all
+
+--S 672 of 1580
+t0:=(a^2*c+a^2*d*x+2*a*b*c*x^2+2*a*b*d*x^3+b^2*c*x^4+b^2*d*x^5)/(a+b*x^2)^2
+--R 
+--R
+--R   (1)  d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 672
+
+--S 673 of 1580
+r0:=c*x+1/2*d*x^2
+--R 
+--R
+--R        1    2
+--R   (2)  - d x  + c x
+--R        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 673
+
+--S 674 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R        d x  + 2c x
+--R   (3)  -----------
+--R             2
+--R                                         Type: Union(Expression(Integer),...)
+--E 674
+
+--S 675 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 676
+
+)clear all
+
+--S 677 of 1580
+t0:=(a^2*c+a^2*d*x+2*a*b*c*x^2+2*a*b*d*x^3+b^2*c*x^4+b^2*d*x^5)/(a+b*x^2)^3
+--R 
+--R
+--R         d x + c
+--R   (1)  --------
+--R           2
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 677
+
+--S 678 of 1580
+r0:=1/2*d*log(a+b*x^2)/b+c*atan(x*sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b))
+--R 
+--R
+--R                    +-+
+--R                  x\|b              2      +-+ +-+
+--R        2b c atan(-----) + d log(b x  + a)\|a \|b
+--R                    +-+
+--R                   \|a
+--R   (2)  ------------------------------------------
+--R                           +-+ +-+
+--R                        2b\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 678
+
+--S 679 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2      +-----+
+--R            (b x  - a)\|- a b  + 2a b x             2      +-----+
+--R    b c log(---------------------------) + d log(b x  + a)\|- a b
+--R                         2
+--R                      b x  + a
+--R   [--------------------------------------------------------------,
+--R                                 +-----+
+--R                              2b\|- a b
+--R                +---+
+--R              x\|a b              2      +---+
+--R    2b c atan(-------) + d log(b x  + a)\|a b
+--R                 a
+--R    ------------------------------------------]
+--R                        +---+
+--R                     2b\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 679
+
+--S 680 of 1580
+m0a:=a0.1-r0
+--R 
+--R
+--R                         2      +-----+                              +-+
+--R          +-+ +-+    (b x  - a)\|- a b  + 2a b x       +-----+     x\|b
+--R        c\|a \|b log(---------------------------) - 2c\|- a b atan(-----)
+--R                                  2                                  +-+
+--R                               b x  + a                             \|a
+--R   (4)  -----------------------------------------------------------------
+--R                                  +-----+ +-+ +-+
+--R                                2\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 1580
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 1580
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+                  +-+
+--R          +-+ +-+     x\|a b       +---+     x\|b
+--R        c\|a \|b atan(-------) - c\|a b atan(-----)
+--R                         a                     +-+
+--R                                              \|a
+--R   (6)  -------------------------------------------
+--R                        +-+ +-+ +---+
+--R                       \|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1580
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 683
+
+)clear all
+
+--S 684 of 1580
+t0:=((a+b+c*x^2)/d)^m
+--R 
+--R
+--R            2         m
+--R         c x  + b + a
+--R   (1)  (------------)
+--R               d
+--R                                                    Type: Expression(Integer)
+--E 684
+
+--S 685 of 1580
+--r0:=x*((a+b)/d+c*x^2/d)^m*_
+--   hypergeometric(1/2,-m,3/2,-c*x^2/(a+b))/((a+b+c*x^2)/(a+b))^m
+--E 685
+
+--S 686 of 1580
+--a0:=integrate(t0,x)
+--E 686
+
+--S 687 of 1580
+--m0:=a0-r0
+--E 687
+
+--S 688 of 1580
+--d0:=D(m0,x)
+--E 688
+
+)clear all
+
+--S 689 of 1580
+t0:=1/(x-sqrt(1+x^2))
+--R 
+--R
+--R                1
+--R   (1)  - -------------
+--R           +------+
+--R           | 2
+--R          \|x  + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 1580
+r0:=-1/2*x^2-1/2*asinh(x)-1/2*x*sqrt(1+x^2)
+--R 
+--R
+--R            +------+
+--R            | 2                    2
+--R        - x\|x  + 1  - asinh(x) - x
+--R   (2)  ----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 690
+
+--S 691 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +------+                +------+          +------+
+--R            | 2          2          | 2               | 2         2
+--R        (2x\|x  + 1  - 2x  - 1)log(\|x  + 1  - x) + x\|x  + 1  - x
+--R   (3)  -----------------------------------------------------------
+--R                              +------+
+--R                              | 2          2
+--R                           4x\|x  + 1  - 4x  - 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 691
+
+--S 692 of 1580
+m0:=a0-r0
+--R 
+--R
+--R             +------+
+--R             | 2
+--R        log(\|x  + 1  - x) + asinh(x)
+--R   (4)  -----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 693
+
+)clear all
+
+--S 694 of 1580
+t0:=1/(x-sqrt(1-x^2))
+--R 
+--R
+--R                 1
+--R   (1)  - ---------------
+--R           +--------+
+--R           |   2
+--R          \|- x  + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 694
+
+--S 695 of 1580
+r0:=-1/2*asin(x)-1/2*atanh(x/sqrt(1-x^2))+1/4*log(1-2*x^2)
+--R 
+--R
+--R                      x                 2
+--R        - 2atanh(-----------) + log(- 2x  + 1) - 2asin(x)
+--R                  +--------+
+--R                  |   2
+--R                 \|- x  + 1
+--R   (2)  -------------------------------------------------
+--R                                4
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +--------+
+--R                     |   2         2
+--R             (x - 1)\|- x  + 1  - x  - x + 1
+--R       - log(-------------------------------)
+--R                             2
+--R                            x
+--R     + 
+--R                     +--------+                        +--------+
+--R                     |   2         2                   |   2
+--R           (- x - 1)\|- x  + 1  - x  + x + 1          \|- x  + 1  - 1
+--R       log(---------------------------------) + 4atan(---------------)
+--R                            2                                x
+--R                           x
+--R     + 
+--R             2
+--R       log(2x  - 1)
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 696
+
+--S 697 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +--------+
+--R                     |   2         2
+--R             (x - 1)\|- x  + 1  - x  - x + 1
+--R       - log(-------------------------------)
+--R                             2
+--R                            x
+--R     + 
+--R                     +--------+
+--R                     |   2         2
+--R           (- x - 1)\|- x  + 1  - x  + x + 1                x
+--R       log(---------------------------------) + 2atanh(-----------)
+--R                            2                           +--------+
+--R                           x                            |   2
+--R                                                       \|- x  + 1
+--R     + 
+--R              +--------+
+--R              |   2
+--R             \|- x  + 1  - 1          2                2
+--R       4atan(---------------) + log(2x  - 1) - log(- 2x  + 1) + 2asin(x)
+--R                    x
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 698
+
+)clear all
+
+--S 699 of 1580
+t0:=1/(x-sqrt(1+2*x^2))
+--R 
+--R
+--R                 1
+--R   (1)  - --------------
+--R           +-------+
+--R           |  2
+--R          \|2x  + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 699
+
+--S 700 of 1580
+r0:=atanh(x/sqrt(1+2*x^2))-1/2*log(1+x^2)-asinh(x*sqrt(2))*sqrt(2)
+--R 
+--R
+--R                    x             2          +-+        +-+
+--R        2atanh(----------) - log(x  + 1) - 2\|2 asinh(x\|2 )
+--R                +-------+
+--R                |  2
+--R               \|2x  + 1
+--R   (2)  ----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 700
+
+--S 701 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   +-------+
+--R                   |  2          2
+--R           (x - 1)\|2x  + 1  + 2x  - x + 1
+--R       log(-------------------------------)
+--R                           2
+--R                          x
+--R     + 
+--R                            +-------+
+--R                   +-+      |  2          +-+     2
+--R         +-+    (x\|2  + 1)\|2x  + 1  - x\|2  - 2x  - 1
+--R       2\|2 log(---------------------------------------)
+--R                              +-------+
+--R                              |  2
+--R                             \|2x  + 1  - 1
+--R     + 
+--R                       +-------+
+--R                       |  2          2
+--R             (- x - 1)\|2x  + 1  + 2x  + x + 1         2
+--R       - log(---------------------------------) - log(x  + 1)
+--R                              2
+--R                             x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 701
+
+--S 702 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +-------+
+--R                   |  2          2
+--R           (x - 1)\|2x  + 1  + 2x  - x + 1
+--R       log(-------------------------------)
+--R                           2
+--R                          x
+--R     + 
+--R                            +-------+
+--R                   +-+      |  2          +-+     2
+--R         +-+    (x\|2  + 1)\|2x  + 1  - x\|2  - 2x  - 1
+--R       2\|2 log(---------------------------------------)
+--R                              +-------+
+--R                              |  2
+--R                             \|2x  + 1  - 1
+--R     + 
+--R                       +-------+
+--R                       |  2          2
+--R             (- x - 1)\|2x  + 1  + 2x  + x + 1                x
+--R       - log(---------------------------------) - 2atanh(----------)
+--R                              2                           +-------+
+--R                             x                            |  2
+--R                                                         \|2x  + 1
+--R     + 
+--R         +-+        +-+
+--R       2\|2 asinh(x\|2 )
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 703
+
+)clear all
+
+--S 704 of 1580
+t0:=(2*x-x^3+x^2*sqrt(2-x^2))/(-2+2*x^2)
+--R 
+--R
+--R           +--------+
+--R         2 |   2         3
+--R        x \|- x  + 2  - x  + 2x
+--R   (1)  -----------------------
+--R                  2
+--R                2x  - 2
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 1580
+r0:=-1/4*x^2-1/2*atanh(x/sqrt(2-x^2))+1/4*log(1-x^2)+1/4*x*sqrt(2-x^2)
+--R 
+--R
+--R                                  +--------+
+--R                      x           |   2               2         2
+--R        - 2atanh(-----------) + x\|- x  + 2  + log(- x  + 1) - x
+--R                  +--------+
+--R                  |   2
+--R                 \|- x  + 2
+--R   (2)  ---------------------------------------------------------
+--R                                    4
+--R                                                    Type: Expression(Integer)
+--E 705
+
+--S 706 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  +--------+
+--R              +-+ |   2         2
+--R         (- 2\|2 \|- x  + 2  - x  + 4)
+--R      *
+--R                          +--------+
+--R                 +-+      |   2          +-+    2
+--R             (- \|2  + x)\|- x  + 2  - x\|2  - x  + 2
+--R         log(----------------------------------------)
+--R                                 2
+--R                                x
+--R     + 
+--R                                                   +--------+
+--R              +--------+                  +-+      |   2          +-+    2
+--R          +-+ |   2         2         (- \|2  - x)\|- x  + 2  + x\|2  - x  + 2
+--R       (2\|2 \|- x  + 2  + x  - 4)log(----------------------------------------)
+--R                                                          2
+--R                                                         x
+--R     + 
+--R                                              +--------+
+--R          +-+     2          2 +-+    3       |   2          2          2
+--R       (2\|2 log(x  - 1) - 2x \|2  + x  - 4x)\|- x  + 2  + (x  - 4)log(x  - 1)
+--R     + 
+--R            3       +-+    4     2
+--R       (- 2x  + 4x)\|2  - x  + 4x
+--R  /
+--R           +--------+
+--R       +-+ |   2          2
+--R     8\|2 \|- x  + 2  + 4x  - 16
+--R                                         Type: Union(Expression(Integer),...)
+--E 706
+
+--S 707 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +--------+
+--R                 +-+      |   2          +-+    2
+--R             (- \|2  + x)\|- x  + 2  - x\|2  - x  + 2
+--R       - log(----------------------------------------)
+--R                                 2
+--R                                x
+--R     + 
+--R                        +--------+
+--R               +-+      |   2          +-+    2
+--R           (- \|2  - x)\|- x  + 2  + x\|2  - x  + 2                x
+--R       log(----------------------------------------) + 2atanh(-----------)
+--R                               2                               +--------+
+--R                              x                                |   2
+--R                                                              \|- x  + 2
+--R     + 
+--R            2               2
+--R       log(x  - 1) - log(- x  + 1)
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 708
+
+)clear all
+
+--S 709 of 1580
+t0:=x*sqrt(2-x^2)/(x-sqrt(2-x^2))
+--R 
+--R
+--R              +--------+
+--R              |   2
+--R            x\|- x  + 2
+--R   (1)  - ---------------
+--R           +--------+
+--R           |   2
+--R          \|- x  + 2  - x
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 1580
+r0:=-1/4*x^2-1/2*atanh(x/sqrt(2-x^2))+1/4*log(1-x)+1/4*log(1+x)+_
+   1/4*x*sqrt(2-x^2)
+--R 
+--R
+--R                                  +--------+
+--R                      x           |   2                                     2
+--R        - 2atanh(-----------) + x\|- x  + 2  + log(x + 1) + log(- x + 1) - x
+--R                  +--------+
+--R                  |   2
+--R                 \|- x  + 2
+--R   (2)  ---------------------------------------------------------------------
+--R                                          4
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  +--------+
+--R              +-+ |   2         2
+--R         (- 2\|2 \|- x  + 2  - x  + 4)
+--R      *
+--R                          +--------+
+--R                 +-+      |   2          +-+    2
+--R             (- \|2  + x)\|- x  + 2  - x\|2  - x  + 2
+--R         log(----------------------------------------)
+--R                                 2
+--R                                x
+--R     + 
+--R                                                   +--------+
+--R              +--------+                  +-+      |   2          +-+    2
+--R          +-+ |   2         2         (- \|2  - x)\|- x  + 2  + x\|2  - x  + 2
+--R       (2\|2 \|- x  + 2  + x  - 4)log(----------------------------------------)
+--R                                                          2
+--R                                                         x
+--R     + 
+--R                                              +--------+
+--R          +-+     2          2 +-+    3       |   2          2          2
+--R       (2\|2 log(x  - 1) - 2x \|2  + x  - 4x)\|- x  + 2  + (x  - 4)log(x  - 1)
+--R     + 
+--R            3       +-+    4     2
+--R       (- 2x  + 4x)\|2  - x  + 4x
+--R  /
+--R           +--------+
+--R       +-+ |   2          2
+--R     8\|2 \|- x  + 2  + 4x  - 16
+--R                                         Type: Union(Expression(Integer),...)
+--E 711
+
+--S 712 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +--------+
+--R                 +-+      |   2          +-+    2
+--R             (- \|2  + x)\|- x  + 2  - x\|2  - x  + 2
+--R       - log(----------------------------------------)
+--R                                 2
+--R                                x
+--R     + 
+--R                        +--------+
+--R               +-+      |   2          +-+    2
+--R           (- \|2  - x)\|- x  + 2  + x\|2  - x  + 2                x
+--R       log(----------------------------------------) + 2atanh(-----------)
+--R                               2                               +--------+
+--R                              x                                |   2
+--R                                                              \|- x  + 2
+--R     + 
+--R            2
+--R       log(x  - 1) - log(x + 1) - log(- x + 1)
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 712
+
+--S 713 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 713
+
+)clear all
+
+--S 714 of 1580
+t0:=x/(-x+sqrt(2*x-x^2))
+--R 
+--R
+--R                x
+--R   (1)  ----------------
+--R         +---------+
+--R         |   2
+--R        \|- x  + 2x  - x
+--R                                                    Type: Expression(Integer)
+--E 714
+
+--S 715 of 1580
+r0:=-1/2*x+1/2*atanh(sqrt(2*x-x^2))-1/2*log(1-x)-1/2*sqrt(2*x-x^2)
+--R 
+--R
+--R               +---------+     +---------+
+--R               |   2           |   2
+--R        atanh(\|- x  + 2x ) - \|- x  + 2x  - log(- x + 1) - x
+--R   (2)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 715
+
+--S 716 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        +---------+             +---------+
+--R        |   2                   |   2               +---------+
+--R       \|- x  + 2x  + x        \|- x  + 2x  - x     |   2
+--R   log(----------------) - log(----------------) - \|- x  + 2x  - log(x - 1) - x
+--R               x                       x
+--R   -----------------------------------------------------------------------------
+--R                                         2
+--R                                         Type: Union(Expression(Integer),...)
+--E 716
+
+--S 717 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +---------+             +---------+
+--R            |   2                   |   2                     +---------+
+--R           \|- x  + 2x  + x        \|- x  + 2x  - x           |   2
+--R       log(----------------) - log(----------------) - atanh(\|- x  + 2x )
+--R                   x                       x
+--R     + 
+--R       - log(x - 1) + log(- x + 1)
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 717
+
+--S 718 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 718
+
+)clear all
+
+--S 719 of 1580
+t0:=(x+sqrt(2*x-x^2))/(2-2*x)
+--R 
+--R
+--R           +---------+
+--R           |   2
+--R        - \|- x  + 2x  - x
+--R   (1)  ------------------
+--R              2x - 2
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 1580
+r0:=-1/2*x+1/2*atanh(sqrt(2*x-x^2))-1/2*log(1-x)-1/2*sqrt(2*x-x^2)
+--R 
+--R
+--R               +---------+     +---------+
+--R               |   2           |   2
+--R        atanh(\|- x  + 2x ) - \|- x  + 2x  - log(- x + 1) - x
+--R   (2)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 720
+
+--S 721 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        +---------+             +---------+
+--R        |   2                   |   2               +---------+
+--R       \|- x  + 2x  + x        \|- x  + 2x  - x     |   2
+--R   log(----------------) - log(----------------) - \|- x  + 2x  - log(x - 1) - x
+--R               x                       x
+--R   -----------------------------------------------------------------------------
+--R                                         2
+--R                                         Type: Union(Expression(Integer),...)
+--E 721
+
+--S 722 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +---------+             +---------+
+--R            |   2                   |   2                     +---------+
+--R           \|- x  + 2x  + x        \|- x  + 2x  - x           |   2
+--R       log(----------------) - log(----------------) - atanh(\|- x  + 2x )
+--R                   x                       x
+--R     + 
+--R       - log(x - 1) + log(- x + 1)
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 722
+
+--S 723 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 723
+
+)clear all
+
+--S 724 of 1580
+t0:=(x+sqrt(2-x)*sqrt(x))/(2-2*x)
+--R 
+--R
+--R           +-------+ +-+
+--R        - \|- x + 2 \|x  - x
+--R   (1)  --------------------
+--R               2x - 2
+--R                                                    Type: Expression(Integer)
+--E 724
+
+--S 725 of 1580
+r0:=-1/2*x+1/2*atanh(sqrt(2*x-x^2))-1/2*log(1-x)-1/2*sqrt(2*x-x^2)
+--R 
+--R
+--R               +---------+     +---------+
+--R               |   2           |   2
+--R        atanh(\|- x  + 2x ) - \|- x  + 2x  - log(- x + 1) - x
+--R   (2)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-------+ +-+
+--R            - \|- x + 2 \|x  - 1     +-------+ +-+
+--R        log(--------------------) - \|- x + 2 \|x  - x
+--R                  2
+--R                 x  - 2x + 1
+--R   (3)  ----------------------------------------------
+--R                               2
+--R                                         Type: Union(Expression(Integer),...)
+--E 726
+
+--S 727 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-------+ +-+               +---------+
+--R           - \|- x + 2 \|x  - 1           |   2           +-------+ +-+
+--R       log(--------------------) - atanh(\|- x  + 2x ) - \|- x + 2 \|x
+--R                 2
+--R                x  - 2x + 1
+--R     + 
+--R        +---------+
+--R        |   2
+--R       \|- x  + 2x  + log(- x + 1)
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 727
+
+--S 728 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R       +---------+                                      +---------+
+--R       |   2          2       +-------+ +-+     2       |   2          2
+--R   (- \|- x  + 2x  - x  + 2x)\|- x + 2 \|x  + (x  - 2x)\|- x  + 2x  - x  + 2x
+--R   --------------------------------------------------------------------------
+--R                     +---------+                          +---------+
+--R                     |   2       +-------+ +-+            |   2
+--R            (2x - 2)\|- x  + 2x \|- x + 2 \|x  + (2x - 2)\|- x  + 2x
+--R                                                    Type: Expression(Integer)
+--E 728
+
+)clear all
+
+--S 729 of 1580
+t0:=sqrt(x)/(sqrt(2-x)-sqrt(x))
+--R 
+--R
+--R                  +-+
+--R                 \|x
+--R   (1)  - -----------------
+--R           +-+    +-------+
+--R          \|x  - \|- x + 2
+--R                                                    Type: Expression(Integer)
+--E 729
+
+--S 730 of 1580
+r0:=-1/2*x+1/2*atanh(sqrt(2*x-x^2))-1/2*log(1-x)-1/2*sqrt(2*x-x^2)
+--R 
+--R
+--R               +---------+     +---------+
+--R               |   2           |   2
+--R        atanh(\|- x  + 2x ) - \|- x  + 2x  - log(- x + 1) - x
+--R   (2)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 730
+
+--S 731 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-------+ +-+
+--R            - \|- x + 2 \|x  - 1     +-------+ +-+
+--R        log(--------------------) - \|- x + 2 \|x  - x
+--R                  2
+--R                 x  - 2x + 1
+--R   (3)  ----------------------------------------------
+--R                               2
+--R                                         Type: Union(Expression(Integer),...)
+--E 731
+
+--S 732 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-------+ +-+               +---------+
+--R           - \|- x + 2 \|x  - 1           |   2           +-------+ +-+
+--R       log(--------------------) - atanh(\|- x  + 2x ) - \|- x + 2 \|x
+--R                 2
+--R                x  - 2x + 1
+--R     + 
+--R        +---------+
+--R        |   2
+--R       \|- x  + 2x  + log(- x + 1)
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R       +---------+                                      +---------+
+--R       |   2          2       +-------+ +-+     2       |   2          2
+--R   (- \|- x  + 2x  - x  + 2x)\|- x + 2 \|x  + (x  - 2x)\|- x  + 2x  - x  + 2x
+--R   --------------------------------------------------------------------------
+--R                     +---------+                          +---------+
+--R                     |   2       +-------+ +-+            |   2
+--R            (2x - 2)\|- x  + 2x \|- x + 2 \|x  + (2x - 2)\|- x  + 2x
+--R                                                    Type: Expression(Integer)
+--E 733
+
+)clear all
+
+--S 734 of 1580
+t0:=(2*sqrt(3-x)+3/sqrt(1+x))^2/x
+--R 
+--R
+--R           +-------+ +-----+     2
+--R        12\|- x + 3 \|x + 1  - 4x  + 8x + 21
+--R   (1)  ------------------------------------
+--R                        2
+--R                       x  + x
+--R                                                    Type: Expression(Integer)
+--E 734
+
+--S 735 of 1580
+r0:=-4*x+12*asin(1/2*(1-x))+21*log(x)-9*log(1+x)-_
+   24*atanh(sqrt(3)*sqrt(1+x)/sqrt(3-x))*sqrt(3)
+--R 
+--R
+--R   (2)
+--R                  +-+ +-----+
+--R        +-+      \|3 \|x + 1                                     x - 1
+--R   - 24\|3 atanh(------------) - 9log(x + 1) + 21log(x) - 12asin(-----) - 4x
+--R                   +-------+                                       2
+--R                  \|- x + 3
+--R                                                    Type: Expression(Integer)
+--E 735
+
+-- integrate: implementation incomplete
+--   (residue poly has multiple non-linear factors)
+--S 736 of 1580
+--a0:=integrate(t0,x)
+--E 736
+
+--S 737 of 1580
+--m0:=a0-r0
+--E 737
+
+--S 738 of 1580
+--d0:=D(m0,x)
+--E 738
+
+)clear all
+
+--S 739 of 1580
+t0:=(-1+x+x^2)/(1+sqrt(1+x^2))
+--R 
+--R
+--R           2
+--R          x  + x - 1
+--R   (1)  -------------
+--R         +------+
+--R         | 2
+--R        \|x  + 1  + 1
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 1580
+r0:=(-1)/x-x-1/2*asinh(x)-log(1+sqrt(1+x^2))+sqrt(1+x^2)+_
+   sqrt(1+x^2)/x+1/2*x*sqrt(1+x^2)
+--R 
+--R
+--R   (2)
+--R             +------+                      +------+
+--R             | 2               2           | 2                       2
+--R   - 2x log(\|x  + 1  + 1) + (x  + 2x + 2)\|x  + 1  - x asinh(x) - 2x  - 2
+--R   -----------------------------------------------------------------------
+--R                                      2x
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +------+                  +------+
+--R             3       | 2          4     2      | 2
+--R       ((- 8x  - 2x)\|x  + 1  + 8x  + 6x )log(\|x  + 1  - x + 1)
+--R     + 
+--R                  +------+                  +------+
+--R           3      | 2          4     2      | 2
+--R       ((4x  + x)\|x  + 1  - 4x  - 3x )log(\|x  + 1  - x)
+--R     + 
+--R                   +------+                  +------+
+--R           3       | 2          4     2      | 2
+--R       ((8x  + 2x)\|x  + 1  - 8x  - 6x )log(\|x  + 1  - x - 1)
+--R     + 
+--R                                                               +------+
+--R             3                 5      4     3      2           | 2
+--R       ((- 8x  - 2x)log(x) - 4x  - 16x  - 3x  - 16x  - 4x - 2)\|x  + 1
+--R     + 
+--R          4     2            6      5     4      3     2
+--R       (8x  + 6x )log(x) + 4x  + 16x  + 5x  + 24x  + 5x  + 8x + 2
+--R  /
+--R                +------+
+--R        3       | 2          4     2
+--R     (8x  + 2x)\|x  + 1  - 8x  - 6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 741
+
+--S 742 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             +------+              +------+                 +------+
+--R             | 2                   | 2                      | 2
+--R       2log(\|x  + 1  + 1) - 2log(\|x  + 1  - x + 1) + log(\|x  + 1  - x)
+--R     + 
+--R             +------+
+--R             | 2
+--R       2log(\|x  + 1  - x - 1) - 2log(x) + asinh(x) + 2
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 743
+
+)clear all
+
+--S 744 of 1580
+t0:=(-1+x+x^2)/(1+x+sqrt(1+x^2))
+--R 
+--R
+--R             2
+--R            x  + x - 1
+--R   (1)  -----------------
+--R         +------+
+--R         | 2
+--R        \|x  + 1  + x + 1
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 1580
+r0a:=1/12*(6*x^2+2*x^3-3*asinh(x)-6*log(1+sqrt(1+x^2))+_
+   (4-3*x-2*x^2)*sqrt(1+x^2))
+--R 
+--R
+--R   (2)
+--R           +------+                         +------+
+--R           | 2                  2           | 2                      3     2
+--R   - 6log(\|x  + 1  + 1) + (- 2x  - 3x + 4)\|x  + 1  - 3asinh(x) + 2x  + 6x
+--R   -------------------------------------------------------------------------
+--R                                       12
+--R                                                    Type: Expression(Integer)
+--E 745
+
+--S 746 of 1580
+r0b:=1/2*x^2+1/6*x^3-1/6*(1+x^2)^(3/2)-1/4*asinh(x)-1/2*atanh(sqrt(1+x^2))-_
+   1/2*log(x)+1/2*sqrt(1+x^2)-1/4*x*sqrt(1+x^2)
+--R 
+--R
+--R   (3)
+--R                 +------+                     +------+
+--R                 | 2              2           | 2
+--R       - 6atanh(\|x  + 1 ) + (- 2x  - 3x + 4)\|x  + 1  - 6log(x) - 3asinh(x)
+--R     + 
+--R         3     2
+--R       2x  + 6x
+--R  /
+--R     12
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R                     +------+                   +------+
+--R              2      | 2           3            | 2
+--R       ((- 24x  - 6)\|x  + 1  + 24x  + 18x)log(\|x  + 1  - x + 1)
+--R     + 
+--R                   +------+                  +------+
+--R            2      | 2           3           | 2
+--R       ((12x  + 3)\|x  + 1  - 12x  - 9x)log(\|x  + 1  - x)
+--R     + 
+--R                   +------+                   +------+
+--R            2      | 2           3            | 2
+--R       ((24x  + 6)\|x  + 1  - 24x  - 18x)log(\|x  + 1  - x - 1)
+--R     + 
+--R                                                             +------+
+--R              2                 5      4     3      2        | 2
+--R       ((- 24x  - 6)log(x) + 16x  + 36x  - 8x  + 15x  - 12x)\|x  + 1
+--R     + 
+--R           3                   6      5      3      2
+--R       (24x  + 18x)log(x) - 16x  - 36x  - 33x  + 18x  - 3x + 4
+--R  /
+--R                 +------+
+--R         2       | 2           3
+--R     (48x  + 12)\|x  + 1  - 48x  - 36x
+--R                                         Type: Union(Expression(Integer),...)
+--E 747
+
+--S 748 of 1580
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R             +------+              +------+                 +------+
+--R             | 2                   | 2                      | 2
+--R       2log(\|x  + 1  + 1) - 2log(\|x  + 1  - x + 1) + log(\|x  + 1  - x)
+--R     + 
+--R             +------+
+--R             | 2
+--R       2log(\|x  + 1  - x - 1) - 2log(x) + asinh(x)
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 748
+
+--S 749 of 1580
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 1580
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R               +------+                 +------+              +------+
+--R               | 2                      | 2                   | 2
+--R       - 2log(\|x  + 1  - x + 1) + log(\|x  + 1  - x) + 2log(\|x  + 1  - x - 1)
+--R     + 
+--R               +------+
+--R               | 2
+--R       2atanh(\|x  + 1 ) + asinh(x)
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 750
+
+--S 751 of 1580
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 751
+
+)clear all
+
+--S 752 of 1580
+t0:=(x+2*sqrt(-1+x))/(x*sqrt(-1+x))
+--R 
+--R
+--R          +-----+
+--R        2\|x - 1  + x
+--R   (1)  -------------
+--R            +-----+
+--R          x\|x - 1
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1580
+r0:=2*log(x)+2*sqrt(-1+x)
+--R 
+--R
+--R          +-----+
+--R   (2)  2\|x - 1  + 2log(x)
+--R                                                    Type: Expression(Integer)
+--E 753
+
+--S 754 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +-----+
+--R   (3)  2\|x - 1  + 2log(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 754
+
+--S 755 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 755
+
+--S 756 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 756
+
+)clear all
+
+--S 757 of 1580
+t0:=(a+b*x^(2/3)+c*sqrt(x))^2
+--R 
+--R
+--R              +-+        3+-+2    2 3+-+        +-+    2     2
+--R   (1)  (2b c\|x  + 2a b)\|x   + b x\|x  + 2a c\|x  + c x + a
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 1580
+r0:=a^2*x+4/3*a*c*x^(3/2)+6/5*a*b*x^(5/3)+1/2*c^2*x^2+12/13*b*c*x^(13/6)+_
+   3/7*b^2*x^(7/3)
+--R 
+--R
+--R   (2)
+--R                2 6+-+            3+-+2        2 2 3+-+            +-+
+--R       2520b c x  \|x + 3276a b x \|x   + 1170b x  \|x + 3640a c x\|x
+--R     + 
+--R            2 2        2
+--R       1365c x  + 2730a x
+--R  /
+--R     2730
+--R                                                    Type: Expression(Integer)
+--E 758
+
+--S 759 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 6+-+4             6+-+3        2 2 6+-+2           2 6+-+
+--R       3276a b x \|x   + 3640a c x \|x   + 1170b x  \|x  + 2520b c x  \|x
+--R     + 
+--R            2 2        2
+--R       1365c x  + 2730a x
+--R  /
+--R     2730
+--R                                         Type: Union(Expression(Integer),...)
+--E 759
+
+--S 760 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                6+-+4            6+-+3      2 2 6+-+2           3+-+2
+--R       126a b x \|x   + 140a c x \|x   + 45b x  \|x  - 126a b x \|x
+--R     + 
+--R            2 2 3+-+           +-+
+--R       - 45b x  \|x - 140a c x\|x
+--R  /
+--R     105
+--R                                                    Type: Expression(Integer)
+--E 760
+
+--S 761 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 3+-+2          +-+3+-+    2 2 +-+ 6+-+4          +-+3+-+2 6+-+2
+--R       (- 2a c x \|x   - 2a b x\|x \|x  - b x \|x )\|x   + 2a b x\|x \|x   \|x
+--R     + 
+--R              +-+3+-+2 6+-+   2 2 +-+3+-+2
+--R       2a c x\|x \|x   \|x + b x \|x \|x
+--R  /
+--R      +-+3+-+2 6+-+4
+--R     \|x \|x   \|x
+--R                                                    Type: Expression(Integer)
+--E 761
+
+)clear all
+
+--S 762 of 1580
+t0:=(a+b*x^(2/3)+c*sqrt(x))^3
+--R 
+--R
+--R   (1)
+--R             +-+       2      2  3+-+2      2    +-+       2  3+-+
+--R     (6a b c\|x  + 3b c x + 3a b)\|x   + (3b c x\|x  + 3a b x)\|x
+--R   + 
+--R       3      2   +-+    3 2       2     3
+--R     (c x + 3a c)\|x  + b x  + 3a c x + a
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 1580
+r0:=a^3*x+2*a^2*c*x^(3/2)+9/5*a^2*b*x^(5/3)+3/2*a*c^2*x^2+_
+   36/13*a*b*c*x^(13/6)+9/7*a*b^2*x^(7/3)+2/5*c^3*x^(5/2)+_
+   9/8*b*c^2*x^(8/3)+18/17*b^2*c*x^(17/6)+1/3*b^3*x^3
+--R 
+--R
+--R   (2)
+--R              2   2 6+-+5               2 6+-+
+--R       196560b c x  \|x  + 514080a b c x  \|x
+--R     + 
+--R                 2 2          2    3+-+2            2 2 3+-+
+--R       (208845b c x  + 334152a b x)\|x   + 238680a b x  \|x
+--R     + 
+--R              3 2          2     +-+         3 3            2 2          3
+--R       (74256c x  + 371280a c x)\|x  + 61880b x  + 278460a c x  + 185640a x
+--R  /
+--R     185640
+--R                                                    Type: Expression(Integer)
+--E 763
+
+--S 764 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2   2 6+-+5            2 2          2    6+-+4
+--R       196560b c x  \|x  + (208845b c x  + 334152a b x)\|x
+--R     + 
+--R              3 2          2    6+-+3            2 2 6+-+2               2 6+-+
+--R       (74256c x  + 371280a c x)\|x   + 238680a b x  \|x  + 514080a b c x  \|x
+--R     + 
+--R             3 3            2 2          3
+--R       61880b x  + 278460a c x  + 185640a x
+--R  /
+--R     185640
+--R                                         Type: Union(Expression(Integer),...)
+--E 764
+
+--S 765 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2 2       2    6+-+4        3 2       2    6+-+3         2 2 6+-+2
+--R       (315b c x  + 504a b x)\|x   + (112c x  + 560a c x)\|x   + 360a b x  \|x
+--R     + 
+--R              2 2       2    3+-+2         2 2 3+-+         3 2       2     +-+
+--R     (- 315b c x  - 504a b x)\|x   - 360a b x  \|x + (- 112c x  - 560a c x)\|x
+--R  /
+--R     280
+--R                                                    Type: Expression(Integer)
+--E 765
+
+--S 766 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R              3 2     2    3+-+2          2 2     2     +-+3+-+       2 2 +-+
+--R         ((- c x  - 3a c x)\|x   + (- 3b c x  - 3a b x)\|x \|x  - 3a b x \|x )
+--R      *
+--R         6+-+4
+--R         \|x
+--R     + 
+--R            2 2     2     +-+3+-+2 6+-+2    3 2     2     +-+3+-+2 6+-+
+--R       (3b c x  + 3a b x)\|x \|x   \|x  + (c x  + 3a c x)\|x \|x   \|x
+--R     + 
+--R           2 2 +-+3+-+2
+--R       3a b x \|x \|x
+--R  /
+--R      +-+3+-+2 6+-+4
+--R     \|x \|x   \|x
+--R                                                    Type: Expression(Integer)
+--E 766
+
+)clear all
+
+--S 767 of 1580
+t0:=(-1+x^2)/(x^3*sqrt(a-b+b/x^2))
+--R 
+--R
+--R                2
+--R               x  - 1
+--R   (1)  --------------------
+--R           +---------------+
+--R           |          2
+--R         3 |(- b + a)x  + b
+--R        x  |---------------
+--R           |        2
+--R          \|       x
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 1580
+r0:=atanh(sqrt(a-b+b/x^2)/sqrt(a-b))/sqrt(a-b)+sqrt(a-b+b/x^2)/b
+--R 
+--R
+--R                 +---------------+
+--R                 |          2
+--R                 |(- b + a)x  + b
+--R                 |---------------                +---------------+
+--R                 |        2                      |          2
+--R                \|       x             +-------+ |(- b + a)x  + b
+--R        b atanh(------------------) + \|- b + a  |---------------
+--R                     +-------+                   |        2
+--R                    \|- b + a                   \|       x
+--R   (2)  ----------------------------------------------------------
+--R                                  +-------+
+--R                                b\|- b + a
+--R                                                    Type: Expression(Integer)
+--E 768
+
+--S 769 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          +---------------+
+--R                +-+       |          2
+--R           (b x\|b  - b x\|(- b + a)x  + b )
+--R        *
+--R           log
+--R                    +---------------+
+--R                    |          2      +-------+               +-+
+--R                  (\|(- b + a)x  + b \|- b + a  + (- b + a)x)\|b
+--R                + 
+--R                                                       +---------------+
+--R                           2      +-------+            |          2
+--R                  ((b - a)x  - b)\|- b + a  + (b - a)x\|(- b + a)x  + b
+--R             /
+--R                 +---------------+
+--R                 |          2      +-+
+--R                \|(- b + a)x  + b \|b  - b
+--R       + 
+--R          +---------------+
+--R          |          2      +-------+ +-+            2      +-------+
+--R         \|(- b + a)x  + b \|- b + a \|b  + ((b - a)x  - b)\|- b + a
+--R    /
+--R                               +---------------+
+--R           +-------+ +-+       |          2      +-------+
+--R       b x\|- b + a \|b  - b x\|(- b + a)x  + b \|- b + a
+--R     ,
+--R
+--R                            +---------------+
+--R                 +-+        |          2
+--R           (2b x\|b  - 2b x\|(- b + a)x  + b )
+--R        *
+--R                                +---------------+
+--R                 +-----+ +-+    |          2      +-----+
+--R                \|b - a \|b  - \|(- b + a)x  + b \|b - a
+--R           atan(-----------------------------------------)
+--R                                 (b - a)x
+--R       + 
+--R          +---------------+
+--R          |          2      +-----+ +-+            2      +-----+
+--R         \|(- b + a)x  + b \|b - a \|b  + ((b - a)x  - b)\|b - a
+--R    /
+--R                             +---------------+
+--R           +-----+ +-+       |          2      +-----+
+--R       b x\|b - a \|b  - b x\|(- b + a)x  + b \|b - a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 769
+
+--S 770 of 1580
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        +---------------+
+--R              +-+       |          2
+--R         (b x\|b  - b x\|(- b + a)x  + b )
+--R      *
+--R         log
+--R                  +---------------+
+--R                  |          2      +-------+               +-+
+--R                (\|(- b + a)x  + b \|- b + a  + (- b + a)x)\|b
+--R              + 
+--R                                                     +---------------+
+--R                         2      +-------+            |          2
+--R                ((b - a)x  - b)\|- b + a  + (b - a)x\|(- b + a)x  + b
+--R           /
+--R               +---------------+
+--R               |          2      +-+
+--R              \|(- b + a)x  + b \|b  - b
+--R     + 
+--R                                                 +---------------+
+--R                                                 |          2
+--R                                                 |(- b + a)x  + b
+--R                                                 |---------------
+--R                        +---------------+        |        2
+--R              +-+       |          2            \|       x
+--R       (- b x\|b  + b x\|(- b + a)x  + b )atanh(------------------)
+--R                                                     +-------+
+--R                                                    \|- b + a
+--R     + 
+--R                      +---------------+
+--R                      |          2         +---------------+
+--R            +-------+ |(- b + a)x  + b     |          2      +-------+  +-+
+--R       (- x\|- b + a  |---------------  + \|(- b + a)x  + b \|- b + a )\|b
+--R                      |        2
+--R                     \|       x
+--R     + 
+--R                                   +---------------+
+--R       +---------------+           |          2
+--R       |          2      +-------+ |(- b + a)x  + b             2      +-------+
+--R     x\|(- b + a)x  + b \|- b + a  |---------------  + ((b - a)x  - b)\|- b + a
+--R                                   |        2
+--R                                  \|       x
+--R  /
+--R                             +---------------+
+--R         +-------+ +-+       |          2      +-------+
+--R     b x\|- b + a \|b  - b x\|(- b + a)x  + b \|- b + a
+--R                                                    Type: Expression(Integer)
+--E 770
+
+--S 771 of 1580
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        2             2  7       2             2  5
+--R                   (- 5b  + 10a b - 5a )x  + (25b  - 30a b + 5a )x
+--R                 + 
+--R                         2          3      2
+--R                   (- 36b  + 20a b)x  + 16b x
+--R              *
+--R                  +---------------+
+--R                  |          2      +-------+
+--R                 \|(- b + a)x  + b \|- b + a
+--R             + 
+--R                  3        2      2      3  8
+--R               (5b  - 15a b  + 15a b - 5a )x
+--R             + 
+--R                     3        2      2      3  6       3        2      2   4
+--R               (- 25b  + 55a b  - 35a b + 5a )x  + (36b  - 56a b  + 20a b)x
+--R             + 
+--R                     3        2  2
+--R               (- 16b  + 16a b )x
+--R          *
+--R              +---------------+
+--R              |          2
+--R              |(- b + a)x  + b
+--R              |---------------
+--R              |        2
+--R             \|       x
+--R         + 
+--R                    3        2      2      3  8
+--R               (- 5b  + 15a b  - 15a b + 5a )x
+--R             + 
+--R                   3        2      2      3  6         3        2      2   4
+--R               (30b  - 65a b  + 40a b - 5a )x  + (- 61b  + 86a b  - 25a b)x
+--R             + 
+--R                   3        2  2      3
+--R               (52b  - 36a b )x  - 16b
+--R          *
+--R              +-------+
+--R             \|- b + a
+--R         + 
+--R                    3        2      2      3  7
+--R               (- 5b  + 15a b  - 15a b + 5a )x
+--R             + 
+--R                   3        2      2      3  5         3        2      2   3
+--R               (25b  - 55a b  + 35a b - 5a )x  + (- 36b  + 56a b  - 20a b)x
+--R             + 
+--R                   3        2
+--R               (16b  - 16a b )x
+--R          *
+--R              +---------------+
+--R              |          2
+--R             \|(- b + a)x  + b
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R                   3       2     2     3  9       3        2      2     3  7
+--R               (- b  + 3a b  - 3a b + a )x  + (14b  - 29a b  + 16a b - a )x
+--R             + 
+--R                     3        2      2   5       3        2  3      3
+--R               (- 41b  + 54a b  - 13a b)x  + (44b  - 28a b )x  - 16b x
+--R          *
+--R              +-------+
+--R             \|- b + a
+--R         + 
+--R                   3       2     2     3  8       3        2      2     3  6
+--R               (- b  + 3a b  - 3a b + a )x  + (13b  - 27a b  + 15a b - a )x
+--R             + 
+--R                     3        2      2   4       3        2  2
+--R               (- 28b  + 40a b  - 12a b)x  + (16b  - 16a b )x
+--R          *
+--R              +---------------+
+--R              |          2
+--R             \|(- b + a)x  + b
+--R      *
+--R          +---------------+
+--R          |          2
+--R          |(- b + a)x  + b
+--R          |---------------
+--R          |        2
+--R         \|       x
+--R     + 
+--R             3       2     2     3  8         3        2      2     3  6
+--R           (b  - 3a b  + 3a b - a )x  + (- 14b  + 29a b  - 16a b + a )x
+--R         + 
+--R               3        2      2   4         3        2  2      3
+--R           (41b  - 54a b  + 13a b)x  + (- 44b  + 28a b )x  + 16b
+--R      *
+--R          +---------------+
+--R          |          2      +-------+
+--R         \|(- b + a)x  + b \|- b + a
+--R     + 
+--R           4       3     2 2     3     4  9
+--R       (- b  + 4a b  - 6a b  + 4a b - a )x
+--R     + 
+--R           4        3      2 2      3     4  7
+--R       (14b  - 43a b  + 45a b  - 17a b + a )x
+--R     + 
+--R             4        3      2 2      3   5       4        3      2 2  3
+--R       (- 41b  + 95a b  - 67a b  + 13a b)x  + (44b  - 72a b  + 28a b )x
+--R     + 
+--R             4        3
+--R       (- 16b  + 16a b )x
+--R  /
+--R                  3        2      2      3  9         3        2      2   7
+--R               (5b  - 15a b  + 15a b - 5a )x  + (- 25b  + 50a b  - 25a b)x
+--R             + 
+--R                   3        2  5      3 3
+--R               (36b  - 36a b )x  - 16b x
+--R          *
+--R              +-------+
+--R             \|- b + a
+--R         + 
+--R                  3        2      2      3  8         3        2      2   6
+--R               (5b  - 15a b  + 15a b - 5a )x  + (- 20b  + 40a b  - 20a b)x
+--R             + 
+--R                   3        2  4
+--R               (16b  - 16a b )x
+--R          *
+--R              +---------------+
+--R              |          2
+--R             \|(- b + a)x  + b
+--R      *
+--R          +---------------+
+--R          |          2
+--R          |(- b + a)x  + b  +-+
+--R          |--------------- \|b
+--R          |        2
+--R         \|       x
+--R     + 
+--R                   3       2     2     3  9       3        2      2   7
+--R               (- b  + 3a b  - 3a b + a )x  + (13b  - 26a b  + 13a b)x
+--R             + 
+--R                     3        2  5      3 3
+--R               (- 28b  + 28a b )x  + 16b x
+--R          *
+--R              +---------------+
+--R              |          2      +-------+
+--R             \|(- b + a)x  + b \|- b + a
+--R         + 
+--R             4       3     2 2     3     4  10
+--R           (b  - 4a b  + 6a b  - 4a b + a )x
+--R         + 
+--R                 4        3      2 2      3   8       4        3      2 2  6
+--R           (- 13b  + 39a b  - 39a b  + 13a b)x  + (28b  - 56a b  + 28a b )x
+--R         + 
+--R                 4        3  4
+--R           (- 16b  + 16a b )x
+--R      *
+--R          +---------------+
+--R          |          2
+--R          |(- b + a)x  + b
+--R          |---------------
+--R          |        2
+--R         \|       x
+--R                                                    Type: Expression(Integer)
+--E 771
+
+--S 772 of 1580
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------------+
+--R                +-----+ +-+       |          2      +-----+
+--R         (- b x\|b - a \|b  + b x\|(- b + a)x  + b \|b - a )
+--R      *
+--R                +---------------+
+--R                |          2
+--R                |(- b + a)x  + b
+--R                |---------------
+--R                |        2
+--R               \|       x
+--R         atanh(------------------)
+--R                    +-------+
+--R                   \|- b + a
+--R     + 
+--R                                    +---------------+
+--R               +-------+ +-+        |          2      +-------+
+--R         (2b x\|- b + a \|b  - 2b x\|(- b + a)x  + b \|- b + a )
+--R      *
+--R                              +---------------+
+--R               +-----+ +-+    |          2      +-----+
+--R              \|b - a \|b  - \|(- b + a)x  + b \|b - a
+--R         atan(-----------------------------------------)
+--R                               (b - a)x
+--R     + 
+--R                        +---------------+
+--R                        |          2         +---------------+
+--R              +-------+ |(- b + a)x  + b     |          2      +-------+
+--R         (- x\|- b + a  |---------------  + \|(- b + a)x  + b \|- b + a )
+--R                        |        2
+--R                       \|       x
+--R      *
+--R          +-----+ +-+
+--R         \|b - a \|b
+--R     + 
+--R                                         +---------------+
+--R             +---------------+           |          2
+--R             |          2      +-------+ |(- b + a)x  + b
+--R           x\|(- b + a)x  + b \|- b + a  |---------------
+--R                                         |        2
+--R                                        \|       x
+--R         + 
+--R                    2      +-------+
+--R           ((b - a)x  - b)\|- b + a
+--R      *
+--R          +-----+
+--R         \|b - a
+--R  /
+--R                                     +---------------+
+--R         +-------+ +-----+ +-+       |          2      +-------+ +-----+
+--R     b x\|- b + a \|b - a \|b  - b x\|(- b + a)x  + b \|- b + a \|b - a
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1580
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                          +---------------+
+--R                        +---------------+ |          2
+--R                3       |          2      |(- b + a)x  + b                4
+--R           (- 2x  + 2x)\|(- b + a)x  + b  |---------------  + (- 2b + 2a)x
+--R                                          |        2
+--R                                         \|       x
+--R         + 
+--R                     2
+--R           (4b - 2a)x  - 2b
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R                                         +---------------+
+--R                                         |          2
+--R                  5            3         |(- b + a)x  + b
+--R       ((- b + a)x  + (3b - a)x  - 2b x) |---------------
+--R                                         |        2
+--R                                        \|       x
+--R     + 
+--R                                       +---------------+
+--R                4              2       |          2
+--R       ((b - a)x  + (- 3b + a)x  + 2b)\|(- b + a)x  + b
+--R  /
+--R                             +---------------+
+--R                             |          2
+--R                  5       3  |(- b + a)x  + b  +-+
+--R       ((2b - 2a)x  - 2b x ) |--------------- \|b
+--R                             |        2
+--R                            \|       x
+--R     + 
+--R                                               +---------------+
+--R                             +---------------+ |          2
+--R                  5       3  |          2      |(- b + a)x  + b
+--R       ((- b + a)x  + 2b x )\|(- b + a)x  + b  |---------------
+--R                                               |        2
+--R                                              \|       x
+--R                                                    Type: Expression(Integer)
+--E 773
+
+)clear all
+
+--S 774 of 1580
+t0:=(-1+x^2)/(x^3*sqrt(a+b*(-1+1/x^2)))
+--R 
+--R
+--R                2
+--R               x  - 1
+--R   (1)  --------------------
+--R           +---------------+
+--R           |          2
+--R         3 |(- b + a)x  + b
+--R        x  |---------------
+--R           |        2
+--R          \|       x
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 1580
+r0:=atanh(sqrt(a-b+b/x^2)/sqrt(a-b))/sqrt(a-b)+sqrt(a-b+b/x^2)/b
+--R 
+--R
+--R                 +---------------+
+--R                 |          2
+--R                 |(- b + a)x  + b
+--R                 |---------------                +---------------+
+--R                 |        2                      |          2
+--R                \|       x             +-------+ |(- b + a)x  + b
+--R        b atanh(------------------) + \|- b + a  |---------------
+--R                     +-------+                   |        2
+--R                    \|- b + a                   \|       x
+--R   (2)  ----------------------------------------------------------
+--R                                  +-------+
+--R                                b\|- b + a
+--R                                                    Type: Expression(Integer)
+--E 775
+
+--S 776 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          +---------------+
+--R                +-+       |          2
+--R           (b x\|b  - b x\|(- b + a)x  + b )
+--R        *
+--R           log
+--R                    +---------------+
+--R                    |          2      +-------+               +-+
+--R                  (\|(- b + a)x  + b \|- b + a  + (- b + a)x)\|b
+--R                + 
+--R                                                       +---------------+
+--R                           2      +-------+            |          2
+--R                  ((b - a)x  - b)\|- b + a  + (b - a)x\|(- b + a)x  + b
+--R             /
+--R                 +---------------+
+--R                 |          2      +-+
+--R                \|(- b + a)x  + b \|b  - b
+--R       + 
+--R          +---------------+
+--R          |          2      +-------+ +-+            2      +-------+
+--R         \|(- b + a)x  + b \|- b + a \|b  + ((b - a)x  - b)\|- b + a
+--R    /
+--R                               +---------------+
+--R           +-------+ +-+       |          2      +-------+
+--R       b x\|- b + a \|b  - b x\|(- b + a)x  + b \|- b + a
+--R     ,
+--R
+--R                            +---------------+
+--R                 +-+        |          2
+--R           (2b x\|b  - 2b x\|(- b + a)x  + b )
+--R        *
+--R                                +---------------+
+--R                 +-----+ +-+    |          2      +-----+
+--R                \|b - a \|b  - \|(- b + a)x  + b \|b - a
+--R           atan(-----------------------------------------)
+--R                                 (b - a)x
+--R       + 
+--R          +---------------+
+--R          |          2      +-----+ +-+            2      +-----+
+--R         \|(- b + a)x  + b \|b - a \|b  + ((b - a)x  - b)\|b - a
+--R    /
+--R                             +---------------+
+--R           +-----+ +-+       |          2      +-----+
+--R       b x\|b - a \|b  - b x\|(- b + a)x  + b \|b - a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 776
+
+--S 777 of 1580
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        +---------------+
+--R              +-+       |          2
+--R         (b x\|b  - b x\|(- b + a)x  + b )
+--R      *
+--R         log
+--R                  +---------------+
+--R                  |          2      +-------+               +-+
+--R                (\|(- b + a)x  + b \|- b + a  + (- b + a)x)\|b
+--R              + 
+--R                                                     +---------------+
+--R                         2      +-------+            |          2
+--R                ((b - a)x  - b)\|- b + a  + (b - a)x\|(- b + a)x  + b
+--R           /
+--R               +---------------+
+--R               |          2      +-+
+--R              \|(- b + a)x  + b \|b  - b
+--R     + 
+--R                                                 +---------------+
+--R                                                 |          2
+--R                                                 |(- b + a)x  + b
+--R                                                 |---------------
+--R                        +---------------+        |        2
+--R              +-+       |          2            \|       x
+--R       (- b x\|b  + b x\|(- b + a)x  + b )atanh(------------------)
+--R                                                     +-------+
+--R                                                    \|- b + a
+--R     + 
+--R                      +---------------+
+--R                      |          2         +---------------+
+--R            +-------+ |(- b + a)x  + b     |          2      +-------+  +-+
+--R       (- x\|- b + a  |---------------  + \|(- b + a)x  + b \|- b + a )\|b
+--R                      |        2
+--R                     \|       x
+--R     + 
+--R                                   +---------------+
+--R       +---------------+           |          2
+--R       |          2      +-------+ |(- b + a)x  + b             2      +-------+
+--R     x\|(- b + a)x  + b \|- b + a  |---------------  + ((b - a)x  - b)\|- b + a
+--R                                   |        2
+--R                                  \|       x
+--R  /
+--R                             +---------------+
+--R         +-------+ +-+       |          2      +-------+
+--R     b x\|- b + a \|b  - b x\|(- b + a)x  + b \|- b + a
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 1580
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        2             2  7       2             2  5
+--R                   (- 5b  + 10a b - 5a )x  + (25b  - 30a b + 5a )x
+--R                 + 
+--R                         2          3      2
+--R                   (- 36b  + 20a b)x  + 16b x
+--R              *
+--R                  +---------------+
+--R                  |          2      +-------+
+--R                 \|(- b + a)x  + b \|- b + a
+--R             + 
+--R                  3        2      2      3  8
+--R               (5b  - 15a b  + 15a b - 5a )x
+--R             + 
+--R                     3        2      2      3  6       3        2      2   4
+--R               (- 25b  + 55a b  - 35a b + 5a )x  + (36b  - 56a b  + 20a b)x
+--R             + 
+--R                     3        2  2
+--R               (- 16b  + 16a b )x
+--R          *
+--R              +---------------+
+--R              |          2
+--R              |(- b + a)x  + b
+--R              |---------------
+--R              |        2
+--R             \|       x
+--R         + 
+--R                    3        2      2      3  8
+--R               (- 5b  + 15a b  - 15a b + 5a )x
+--R             + 
+--R                   3        2      2      3  6         3        2      2   4
+--R               (30b  - 65a b  + 40a b - 5a )x  + (- 61b  + 86a b  - 25a b)x
+--R             + 
+--R                   3        2  2      3
+--R               (52b  - 36a b )x  - 16b
+--R          *
+--R              +-------+
+--R             \|- b + a
+--R         + 
+--R                    3        2      2      3  7
+--R               (- 5b  + 15a b  - 15a b + 5a )x
+--R             + 
+--R                   3        2      2      3  5         3        2      2   3
+--R               (25b  - 55a b  + 35a b - 5a )x  + (- 36b  + 56a b  - 20a b)x
+--R             + 
+--R                   3        2
+--R               (16b  - 16a b )x
+--R          *
+--R              +---------------+
+--R              |          2
+--R             \|(- b + a)x  + b
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R                   3       2     2     3  9       3        2      2     3  7
+--R               (- b  + 3a b  - 3a b + a )x  + (14b  - 29a b  + 16a b - a )x
+--R             + 
+--R                     3        2      2   5       3        2  3      3
+--R               (- 41b  + 54a b  - 13a b)x  + (44b  - 28a b )x  - 16b x
+--R          *
+--R              +-------+
+--R             \|- b + a
+--R         + 
+--R                   3       2     2     3  8       3        2      2     3  6
+--R               (- b  + 3a b  - 3a b + a )x  + (13b  - 27a b  + 15a b - a )x
+--R             + 
+--R                     3        2      2   4       3        2  2
+--R               (- 28b  + 40a b  - 12a b)x  + (16b  - 16a b )x
+--R          *
+--R              +---------------+
+--R              |          2
+--R             \|(- b + a)x  + b
+--R      *
+--R          +---------------+
+--R          |          2
+--R          |(- b + a)x  + b
+--R          |---------------
+--R          |        2
+--R         \|       x
+--R     + 
+--R             3       2     2     3  8         3        2      2     3  6
+--R           (b  - 3a b  + 3a b - a )x  + (- 14b  + 29a b  - 16a b + a )x
+--R         + 
+--R               3        2      2   4         3        2  2      3
+--R           (41b  - 54a b  + 13a b)x  + (- 44b  + 28a b )x  + 16b
+--R      *
+--R          +---------------+
+--R          |          2      +-------+
+--R         \|(- b + a)x  + b \|- b + a
+--R     + 
+--R           4       3     2 2     3     4  9
+--R       (- b  + 4a b  - 6a b  + 4a b - a )x
+--R     + 
+--R           4        3      2 2      3     4  7
+--R       (14b  - 43a b  + 45a b  - 17a b + a )x
+--R     + 
+--R             4        3      2 2      3   5       4        3      2 2  3
+--R       (- 41b  + 95a b  - 67a b  + 13a b)x  + (44b  - 72a b  + 28a b )x
+--R     + 
+--R             4        3
+--R       (- 16b  + 16a b )x
+--R  /
+--R                  3        2      2      3  9         3        2      2   7
+--R               (5b  - 15a b  + 15a b - 5a )x  + (- 25b  + 50a b  - 25a b)x
+--R             + 
+--R                   3        2  5      3 3
+--R               (36b  - 36a b )x  - 16b x
+--R          *
+--R              +-------+
+--R             \|- b + a
+--R         + 
+--R                  3        2      2      3  8         3        2      2   6
+--R               (5b  - 15a b  + 15a b - 5a )x  + (- 20b  + 40a b  - 20a b)x
+--R             + 
+--R                   3        2  4
+--R               (16b  - 16a b )x
+--R          *
+--R              +---------------+
+--R              |          2
+--R             \|(- b + a)x  + b
+--R      *
+--R          +---------------+
+--R          |          2
+--R          |(- b + a)x  + b  +-+
+--R          |--------------- \|b
+--R          |        2
+--R         \|       x
+--R     + 
+--R                   3       2     2     3  9       3        2      2   7
+--R               (- b  + 3a b  - 3a b + a )x  + (13b  - 26a b  + 13a b)x
+--R             + 
+--R                     3        2  5      3 3
+--R               (- 28b  + 28a b )x  + 16b x
+--R          *
+--R              +---------------+
+--R              |          2      +-------+
+--R             \|(- b + a)x  + b \|- b + a
+--R         + 
+--R             4       3     2 2     3     4  10
+--R           (b  - 4a b  + 6a b  - 4a b + a )x
+--R         + 
+--R                 4        3      2 2      3   8       4        3      2 2  6
+--R           (- 13b  + 39a b  - 39a b  + 13a b)x  + (28b  - 56a b  + 28a b )x
+--R         + 
+--R                 4        3  4
+--R           (- 16b  + 16a b )x
+--R      *
+--R          +---------------+
+--R          |          2
+--R          |(- b + a)x  + b
+--R          |---------------
+--R          |        2
+--R         \|       x
+--R                                                    Type: Expression(Integer)
+--E 778
+
+--S 779 of 1580
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +---------------+
+--R                +-----+ +-+       |          2      +-----+
+--R         (- b x\|b - a \|b  + b x\|(- b + a)x  + b \|b - a )
+--R      *
+--R                +---------------+
+--R                |          2
+--R                |(- b + a)x  + b
+--R                |---------------
+--R                |        2
+--R               \|       x
+--R         atanh(------------------)
+--R                    +-------+
+--R                   \|- b + a
+--R     + 
+--R                                    +---------------+
+--R               +-------+ +-+        |          2      +-------+
+--R         (2b x\|- b + a \|b  - 2b x\|(- b + a)x  + b \|- b + a )
+--R      *
+--R                              +---------------+
+--R               +-----+ +-+    |          2      +-----+
+--R              \|b - a \|b  - \|(- b + a)x  + b \|b - a
+--R         atan(-----------------------------------------)
+--R                               (b - a)x
+--R     + 
+--R                        +---------------+
+--R                        |          2         +---------------+
+--R              +-------+ |(- b + a)x  + b     |          2      +-------+
+--R         (- x\|- b + a  |---------------  + \|(- b + a)x  + b \|- b + a )
+--R                        |        2
+--R                       \|       x
+--R      *
+--R          +-----+ +-+
+--R         \|b - a \|b
+--R     + 
+--R                                         +---------------+
+--R             +---------------+           |          2
+--R             |          2      +-------+ |(- b + a)x  + b
+--R           x\|(- b + a)x  + b \|- b + a  |---------------
+--R                                         |        2
+--R                                        \|       x
+--R         + 
+--R                    2      +-------+
+--R           ((b - a)x  - b)\|- b + a
+--R      *
+--R          +-----+
+--R         \|b - a
+--R  /
+--R                                     +---------------+
+--R         +-------+ +-----+ +-+       |          2      +-------+ +-----+
+--R     b x\|- b + a \|b - a \|b  - b x\|(- b + a)x  + b \|- b + a \|b - a
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 1580
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                          +---------------+
+--R                        +---------------+ |          2
+--R                3       |          2      |(- b + a)x  + b                4
+--R           (- 2x  + 2x)\|(- b + a)x  + b  |---------------  + (- 2b + 2a)x
+--R                                          |        2
+--R                                         \|       x
+--R         + 
+--R                     2
+--R           (4b - 2a)x  - 2b
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R                                         +---------------+
+--R                                         |          2
+--R                  5            3         |(- b + a)x  + b
+--R       ((- b + a)x  + (3b - a)x  - 2b x) |---------------
+--R                                         |        2
+--R                                        \|       x
+--R     + 
+--R                                       +---------------+
+--R                4              2       |          2
+--R       ((b - a)x  + (- 3b + a)x  + 2b)\|(- b + a)x  + b
+--R  /
+--R                             +---------------+
+--R                             |          2
+--R                  5       3  |(- b + a)x  + b  +-+
+--R       ((2b - 2a)x  - 2b x ) |--------------- \|b
+--R                             |        2
+--R                            \|       x
+--R     + 
+--R                                               +---------------+
+--R                             +---------------+ |          2
+--R                  5       3  |          2      |(- b + a)x  + b
+--R       ((- b + a)x  + 2b x )\|(- b + a)x  + b  |---------------
+--R                                               |        2
+--R                                              \|       x
+--R                                                    Type: Expression(Integer)
+--E 780
+
+)clear all
+
+--S 781 of 1580
+t0:=(1+x)/((4+x^2)*sqrt(9+x^2))
+--R 
+--R
+--R              x + 1
+--R   (1)  -----------------
+--R                 +------+
+--R          2      | 2
+--R        (x  + 4)\|x  + 9
+--R                                                    Type: Expression(Integer)
+--E 781
+
+--S 782 of 1580
+r0:=1/2*atan(1/2*x*sqrt(5)/sqrt(9+x^2))/sqrt(5)-_
+   atanh(sqrt(9+x^2)/sqrt(5))/sqrt(5)
+--R 
+--R
+--R                  +------+
+--R                  | 2                   +-+
+--R                 \|x  + 9             x\|5
+--R        - 2atanh(---------) + atan(----------)
+--R                     +-+             +------+
+--R                    \|5              | 2
+--R                                   2\|x  + 9
+--R   (2)  --------------------------------------
+--R                           +-+
+--R                         2\|5
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                     4
+--R                atan(-)
+--R                     3
+--R            cos(-------)
+--R                   2
+--R         *
+--R            log
+--R                            4               4                              4  2
+--R                       atan(-)         atan(-)        +------+        atan(-)
+--R                            3               3         | 2                  3
+--R                 (2sin(-------) + 4cos(-------) - 2x)\|x  + 9  + 5sin(-------)
+--R                          2               2                              2
+--R               + 
+--R                                    4               4  2
+--R                               atan(-)         atan(-)
+--R                                    3               3
+--R                 (- 2x - 8)sin(-------) + 5cos(-------)
+--R                                  2               2
+--R               + 
+--R                                    4
+--R                               atan(-)
+--R                                    3       2
+--R                 (- 4x + 4)cos(-------) + 2x  + 13
+--R                                  2
+--R     + 
+--R                  4
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R      *
+--R         log
+--R                           4               4                              4  2
+--R                      atan(-)         atan(-)        +------+        atan(-)
+--R                           3               3         | 2                  3
+--R              (- 2sin(-------) - 4cos(-------) - 2x)\|x  + 9  + 5sin(-------)
+--R                         2               2                              2
+--R            + 
+--R                               4               4  2                    4
+--R                          atan(-)         atan(-)                 atan(-)
+--R                               3               3                       3       2
+--R              (2x + 8)sin(-------) + 5cos(-------)  + (4x - 4)cos(-------) + 2x
+--R                             2               2                       2
+--R            + 
+--R              13
+--R     + 
+--R                                         4              4
+--R                                    atan(-)        atan(-)
+--R                 4                       3              3
+--R            atan(-)            2sin(-------) - cos(-------) + 2
+--R                 3                     2              2
+--R       2sin(-------)atan(--------------------------------------------)
+--R               2                              4               4
+--R                          +------+       atan(-)         atan(-)
+--R                          | 2                 3               3
+--R                         \|x  + 9  - sin(-------) - 2cos(-------) - x
+--R                                            2               2
+--R     + 
+--R                                         4              4
+--R                                    atan(-)        atan(-)
+--R                 4                       3              3
+--R            atan(-)            2sin(-------) - cos(-------) - 2
+--R                 3                     2              2
+--R       2sin(-------)atan(--------------------------------------------)
+--R               2                              4               4
+--R                          +------+       atan(-)         atan(-)
+--R                          | 2                 3               3
+--R                         \|x  + 9  + sin(-------) + 2cos(-------) - x
+--R                                            2               2
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 783
+
+--S 784 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                         4
+--R                    atan(-)
+--R             +-+         3
+--R            \|5 cos(-------)
+--R                       2
+--R         *
+--R            log
+--R                            4               4                              4  2
+--R                       atan(-)         atan(-)        +------+        atan(-)
+--R                            3               3         | 2                  3
+--R                 (2sin(-------) + 4cos(-------) - 2x)\|x  + 9  + 5sin(-------)
+--R                          2               2                              2
+--R               + 
+--R                                    4               4  2
+--R                               atan(-)         atan(-)
+--R                                    3               3
+--R                 (- 2x - 8)sin(-------) + 5cos(-------)
+--R                                  2               2
+--R               + 
+--R                                    4
+--R                               atan(-)
+--R                                    3       2
+--R                 (- 4x + 4)cos(-------) + 2x  + 13
+--R                                  2
+--R     + 
+--R                      4
+--R                 atan(-)
+--R          +-+         3
+--R         \|5 cos(-------)
+--R                    2
+--R      *
+--R         log
+--R                           4               4                              4  2
+--R                      atan(-)         atan(-)        +------+        atan(-)
+--R                           3               3         | 2                  3
+--R              (- 2sin(-------) - 4cos(-------) - 2x)\|x  + 9  + 5sin(-------)
+--R                         2               2                              2
+--R            + 
+--R                               4               4  2                    4
+--R                          atan(-)         atan(-)                 atan(-)
+--R                               3               3                       3       2
+--R              (2x + 8)sin(-------) + 5cos(-------)  + (4x - 4)cos(-------) + 2x
+--R                             2               2                       2
+--R            + 
+--R              13
+--R     + 
+--R               +------+
+--R               | 2
+--R              \|x  + 9
+--R       4atanh(---------)
+--R                  +-+
+--R                 \|5
+--R     + 
+--R                                             4              4
+--R                                        atan(-)        atan(-)
+--R                     4                       3              3
+--R                atan(-)            2sin(-------) - cos(-------) + 2
+--R         +-+         3                     2              2
+--R       2\|5 sin(-------)atan(--------------------------------------------)
+--R                   2                              4               4
+--R                              +------+       atan(-)         atan(-)
+--R                              | 2                 3               3
+--R                             \|x  + 9  - sin(-------) - 2cos(-------) - x
+--R                                                2               2
+--R     + 
+--R                                             4              4
+--R                                        atan(-)        atan(-)
+--R                     4                       3              3
+--R                atan(-)            2sin(-------) - cos(-------) - 2
+--R         +-+         3                     2              2
+--R       2\|5 sin(-------)atan(--------------------------------------------)
+--R                   2                              4               4
+--R                              +------+       atan(-)         atan(-)
+--R                              | 2                 3               3
+--R                             \|x  + 9  + sin(-------) + 2cos(-------) - x
+--R                                                2               2
+--R     + 
+--R                    +-+
+--R                  x\|5
+--R       - 2atan(----------)
+--R                 +------+
+--R                 | 2
+--R               2\|x  + 9
+--R  /
+--R       +-+
+--R     4\|5
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                           4  12
+--R                                      atan(-)
+--R                  3                        3
+--R           (- 250x  - 1625x - 625)sin(-------)
+--R                                         2
+--R         + 
+--R                                              4           4  11
+--R                                         atan(-)     atan(-)
+--R                   3                          3           3
+--R           (- 2000x  - 13000x - 5000)cos(-------)sin(-------)
+--R                                            2           2
+--R         + 
+--R                                                   4  2
+--R                                              atan(-)
+--R                       3                           3           5       4
+--R               (- 7000x  - 45500x - 17500)cos(-------)  + 1560x  + 840x
+--R                                                 2
+--R             + 
+--R                     3         2
+--R               19110x  + 10640x  + 55230x + 24870
+--R          *
+--R                      4  10
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                                                     4  3
+--R                                                atan(-)
+--R                        3                            3
+--R               (- 16000x  - 104000x - 40000)cos(-------)
+--R                                                   2
+--R             + 
+--R                       5        4         3         2
+--R                 (5320x  + 8480x  + 66670x  + 94080x  + 206560x + 189640)
+--R              *
+--R                          4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R          *
+--R                      4  9
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                                                     4  4
+--R                                                atan(-)
+--R                        3                            3
+--R               (- 29500x  - 191750x - 73750)cos(-------)
+--R                                                   2
+--R             + 
+--R                        5         4          3          2
+--R                 (11720x  + 35080x  + 148070x  + 375180x  + 477260x + 715940)
+--R              *
+--R                          4  2
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                     7        6         5         4          3          2
+--R               - 832x  - 6016x  - 17544x  - 91064x  - 127836x  - 376104x
+--R             + 
+--R               - 312543x - 298511
+--R          *
+--R                      4  8
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                                                      4  5
+--R                                                 atan(-)
+--R                        3                             3
+--R               (- 44000x  - 286000x - 110000)cos(-------)
+--R                                                    2
+--R             + 
+--R                        5         4          3          2
+--R                 (36240x  + 79360x  + 442940x  + 858560x  + 1311920x + 1652480)
+--R              *
+--R                          4  3
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                        7         6         5          4          3           2
+--R                   5248x  - 34816x  + 67296x  - 516224x  + 132024x  - 2084864x
+--R                 + 
+--R                   - 436848x - 1656016
+--R              *
+--R                          4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R          *
+--R                      4  7
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                                                      4  6
+--R                                                 atan(-)
+--R                        3                             3
+--R               (- 53000x  - 344500x - 132500)cos(-------)
+--R                                                    2
+--R             + 
+--R                           5          4          3           2
+--R                     67160x  + 117240x  + 807210x  + 1282540x  + 2279280x
+--R                   + 
+--R                     2491320
+--R              *
+--R                          4  4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           7         6          5           4           3
+--R                   - 28544x  - 73152x  - 526688x  - 1148928x  - 3126472x
+--R                 + 
+--R                             2
+--R                   - 4974008x  - 5802456x - 4272152
+--R              *
+--R                          4  2
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                      9        8         7          6          5           4
+--R               - 4352x  + 7936x  - 79936x  + 154624x  - 438368x  + 1009328x
+--R             + 
+--R                        3           2
+--R               - 587108x  + 2408768x  + 417924x + 1166484
+--R          *
+--R                      4  6
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                                                      4  7
+--R                                                 atan(-)
+--R                        3                             3
+--R               (- 56000x  - 364000x - 140000)cos(-------)
+--R                                                    2
+--R             + 
+--R                           5          4           3           2
+--R                     92040x  + 134560x  + 1094990x  + 1487760x  + 2997320x
+--R                   + 
+--R                     2916080
+--R              *
+--R                          4  5
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           7          6          5           4           3
+--R                   - 24896x  - 110848x  - 546832x  - 1736192x  - 3889508x
+--R                 + 
+--R                             2
+--R                   - 7401312x  - 8477904x - 6132608
+--R              *
+--R                          4  3
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                         9        8          7          6           5
+--R                   18176x  + 3072x  + 426048x  + 130048x  + 3536544x
+--R                 + 
+--R                           4            3           2
+--R                   1465536x  + 11850404x  + 5322816x  + 12129248x + 3528208
+--R              *
+--R                          4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R          *
+--R                      4  5
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                                                      4  8
+--R                                                 atan(-)
+--R                        3                             3
+--R               (- 48250x  - 313625x - 120625)cos(-------)
+--R                                                    2
+--R             + 
+--R                          5          4           3           2
+--R                   120440x  + 119160x  + 1420890x  + 1361860x  + 3769020x
+--R                 + 
+--R                   2761380
+--R              *
+--R                          4  6
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           7          6           5           4           3
+--R                   - 67040x  - 209920x  - 1293880x  - 3229280x  - 7956470x
+--R                 + 
+--R                              2
+--R                   - 13170080x  - 15038460x - 9347620
+--R              *
+--R                          4  4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           9         8          7          6          5
+--R                   - 16640x  + 15360x  - 173760x  + 412160x  + 675360x
+--R                 + 
+--R                           4            3            2
+--R                   3499200x  + 10184500x  + 10136400x  + 19038040x + 5575880
+--R              *
+--R                          4  2
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                      11         10          9          8           7
+--R               - 4608x   + 10240x   - 125952x  + 220288x  - 1293664x
+--R             + 
+--R                       6           5           4            3           2
+--R               1578240x  - 6089552x  + 4079456x  - 12526466x  + 2280976x
+--R             + 
+--R               - 8048263x - 504895
+--R          *
+--R                      4  4
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                                                     4  9
+--R                                                atan(-)
+--R                        3                            3
+--R               (- 34000x  - 221000x - 85000)cos(-------)
+--R                                                   2
+--R             + 
+--R                        5         4           3          2
+--R                 (96640x  + 64960x  + 1127840x  + 776160x  + 2885120x + 1633280)
+--R              *
+--R                          4  7
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           7          6           5           4           3
+--R                   - 97344x  - 233472x  - 1682448x  - 3516288x  - 8775012x
+--R                 + 
+--R                              2
+--R                   - 13803968x  - 13066656x - 8533712
+--R              *
+--R                          4  5
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                         9          8          7           6           5
+--R                   24320x  + 194560x  + 735040x  + 3891200x  + 7593440x
+--R                 + 
+--R                            4            3            2
+--R                   24871040x  + 30772660x  + 52547840x  + 37773840x + 18274560
+--R              *
+--R                          4  3
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                         11          9         8           7           6
+--R                   14336x   + 310784x  - 70656x  + 2131328x  - 1310720x
+--R                 + 
+--R                           5           4           3            2
+--R                   3822784x  - 7692032x  - 7508248x  - 14713472x  - 16175624x
+--R                 + 
+--R                   - 4407080
+--R              *
+--R                          4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R          *
+--R                      4  3
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                                                     4  10
+--R                                                atan(-)
+--R                        3                            3
+--R               (- 22000x  - 143000x - 55000)cos(-------)
+--R                                                   2
+--R             + 
+--R                        5         4          3          2
+--R                 (78480x  + 22720x  + 916880x  + 323620x  + 2333090x + 788210)
+--R              *
+--R                          4  8
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           7         6           5           4           3
+--R                   - 98624x  - 89792x  - 1571248x  - 1363488x  - 7087412x
+--R                 + 
+--R                             2
+--R                   - 5410168x  - 7742076x - 3150092
+--R              *
+--R                          4  6
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                         9          8           7           6           5
+--R                   51840x  + 147840x  + 1140960x  + 2885440x  + 8421840x
+--R                 + 
+--R                            4            3            2
+--R                   17856600x  + 23315950x  + 35763900x  + 18444160x + 10553720
+--R              *
+--R                          4  4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                          11         10          9           8           7
+--R                   - 8192x   - 87040x   - 301568x  - 2170368x  - 3955456x
+--R                 + 
+--R                              6            5            4            3
+--R                   - 19237120x  - 22912768x  - 70974336x  - 56537904x
+--R                 + 
+--R                              2
+--R                   - 93839656x  - 43036332x - 20034060
+--R              *
+--R                          4  2
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                      13        12         11         10          9          8
+--R               - 2048x   + 2048x   - 66048x   + 69632x   - 807424x  + 886656x
+--R             + 
+--R                         7           6            5            4            3
+--R               - 4591584x  + 5203584x  - 11761304x  + 13745320x  - 10125506x
+--R             + 
+--R                        2
+--R               12906736x  + 274014x + 1663974
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                                                   4  11
+--R                                              atan(-)
+--R                       3                           3
+--R               (- 8000x  - 52000x - 20000)cos(-------)
+--R                                                 2
+--R             + 
+--R                        5        4          3         2
+--R                 (35520x  + 1280x  + 409120x  + 52880x  + 993160x + 180040)
+--R              *
+--R                          4  9
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           7         6          5          4           3
+--R                   - 63488x  - 15104x  - 990976x  - 275456x  - 4329344x
+--R                 + 
+--R                             2
+--R                   - 1451616x  - 4324512x - 1494304
+--R              *
+--R                          4  7
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                         9         8           7          6           5
+--R                   53376x  + 26112x  + 1051488x  + 520448x  + 6617424x
+--R                 + 
+--R                           4            3           2
+--R                   3496416x  + 13687574x  + 8504496x  + 4214408x + 3806608
+--R              *
+--R                          4  5
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           11         10          9          8           7
+--R                   - 19456x   - 20480x   - 486144x  - 528384x  - 4294208x
+--R                 + 
+--R                             6            5            4            3
+--R                   - 4956160x  - 15549344x  - 19962368x  - 18999052x
+--R                 + 
+--R                              2
+--R                   - 30117728x  - 1524656x - 7929920
+--R              *
+--R                          4  3
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                        13        12         11          10           9
+--R                   2048x   + 8192x   + 81408x   + 278528x   + 1224704x
+--R                 + 
+--R                           8           7            6            5            4
+--R                   3597824x  + 8797984x  + 21838336x  + 30836344x  + 61598880x
+--R                 + 
+--R                            3            2
+--R                   46859806x  + 66084544x  + 20681856x + 12131496
+--R              *
+--R                          4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                                               4  12
+--R                                          atan(-)
+--R                   3                           3
+--R           (- 4000x  - 26000x - 10000)cos(-------)
+--R                                             2
+--R         + 
+--R                    5         4          3          2
+--R             (15040x  - 13440x  + 174240x  - 120240x  + 421320x - 172920)
+--R          *
+--R                      4  10
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       7         6          5          4           3           2
+--R               - 23712x  + 38144x  - 389904x  + 525176x  - 1856826x  + 1816536x
+--R             + 
+--R               - 2205513x + 886399
+--R          *
+--R                      4  8
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     9         8          7          6           5           4
+--R               20352x  - 38016x  + 449056x  - 700224x  + 3364208x  - 3977288x
+--R             + 
+--R                       3           2
+--R               9497218x  - 6814828x  + 7085556x - 1134084
+--R          *
+--R                      4  6
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                      11         10          9          8           7
+--R               - 9728x   + 15360x   - 272512x  + 366848x  - 2797344x
+--R             + 
+--R                       6            5           4            3            2
+--R               3042560x  - 12570512x  + 9981056x  - 22441766x  + 10070776x
+--R             + 
+--R               - 9473518x + 344330
+--R          *
+--R                      4  4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                    13        12         11         10          9          8
+--R               2048x   - 2048x   + 71168x   - 64512x   + 943104x  - 750976x
+--R             + 
+--R                       7           6            5           4            3
+--R               5898144x  - 3897024x  + 17186104x  - 8320520x  + 18727606x
+--R             + 
+--R                         2
+--R               - 4304636x  + 2296476x + 906516
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                  13        12         11         10          9          8
+--R           - 2048x   - 2048x   - 63488x   - 63488x   - 756480x  - 756480x
+--R         + 
+--R                     7           6            5            4            3
+--R           - 4293632x  - 4293632x  - 11533640x  - 11533640x  - 12131496x
+--R         + 
+--R                      2
+--R           - 12131496x  - 2313441x - 2313441
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 9
+--R     + 
+--R                                       4  12
+--R                                  atan(-)
+--R            4        2                 3
+--R       (250x  + 3250x  + 9000)sin(-------)
+--R                                     2
+--R     + 
+--R                                          4           4  11
+--R                                     atan(-)     atan(-)
+--R             4         2                  3           3
+--R       (2000x  + 26000x  + 72000)cos(-------)sin(-------)
+--R                                        2           2
+--R     + 
+--R                                               4  2
+--R                                          atan(-)
+--R                 4         2                   3           6       5         4
+--R           (7000x  + 91000x  + 252000)cos(-------)  - 1560x  - 840x  - 26130x
+--R                                             2
+--R         + 
+--R                   3          2
+--R           - 14420x  - 126210x  - 61740x - 156600
+--R      *
+--R                  4  10
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                 4  3
+--R                                            atan(-)
+--R                  4          2                   3
+--R           (16000x  + 208000x  + 576000)cos(-------)
+--R                                               2
+--R         + 
+--R                      6        5         4          3          2
+--R               - 5320x  - 8480x  - 90610x  - 132240x  - 458370x  - 503280x
+--R             + 
+--R               - 664200
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R      *
+--R                  4  9
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                  4  4
+--R                                             atan(-)
+--R                  4          2                    3
+--R           (29500x  + 383500x  + 1062000)cos(-------)
+--R                                                2
+--R         + 
+--R                       6         5          4          3           2
+--R               - 11720x  - 35080x  - 200810x  - 533040x  - 1039770x  - 1955880x
+--R             + 
+--R               - 1636200
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R               8        7         6          5          4          3          2
+--R           832x  + 6016x  + 21288x  + 118136x  + 198360x  + 724980x  + 748288x
+--R         + 
+--R           1341468x + 727632
+--R      *
+--R                  4  8
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                  4  5
+--R                                             atan(-)
+--R                  4          2                    3
+--R           (44000x  + 572000x  + 1584000)cos(-------)
+--R                                                2
+--R         + 
+--R                       6         5          4           3           2
+--R               - 36240x  - 79360x  - 606020x  - 1215680x  - 2954340x  - 4512960x
+--R             + 
+--R               - 3920400
+--R          *
+--R                      4  3
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                      8         7         6          5          4           3
+--R               - 5248x  + 34816x  - 90912x  + 672896x  - 381720x  + 4055360x
+--R             + 
+--R                      2
+--R               286568x  + 7374528x + 1655712
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R      *
+--R                  4  7
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                  4  6
+--R                                             atan(-)
+--R                  4          2                    3
+--R           (53000x  + 689000x  + 1908000)cos(-------)
+--R                                                2
+--R         + 
+--R                       6          5           4           3           2
+--R               - 67160x  - 117240x  - 1109430x  - 1810120x  - 5234310x
+--R             + 
+--R               - 6794640x - 6204600
+--R          *
+--R                      4  4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     8         7          6           5           4           3
+--R               28544x  + 73152x  + 655136x  + 1478112x  + 5207560x  + 9403520x
+--R             + 
+--R                        2
+--R               15841096x  + 18232416x + 11074464
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                10        9         8          7          6           5
+--R           4352x   - 7936x  + 99520x  - 190336x  + 754016x  - 1624784x
+--R         + 
+--R                   4           3          2
+--R           1948700x  - 5746760x  + 312492x  - 6800184x - 1324080
+--R      *
+--R                  4  6
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                  4  7
+--R                                             atan(-)
+--R                  4          2                    3
+--R           (56000x  + 728000x  + 2016000)cos(-------)
+--R                                                2
+--R         + 
+--R                       6          5           4           3           2
+--R               - 92040x  - 134560x  - 1509170x  - 2093280x  - 6973890x
+--R             + 
+--R               - 7940160x - 7619400
+--R          *
+--R                      4  5
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     8          7          6           5           4
+--R               24896x  + 110848x  + 658864x  + 2235008x  + 6098180x
+--R             + 
+--R                        3            2
+--R               14091840x  + 21562564x  + 26599104x + 17079696
+--R          *
+--R                      4  3
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       10        9          8          7           6           5
+--R               - 18176x   - 3072x  - 507840x  - 143872x  - 5269728x  - 2019648x
+--R             + 
+--R                          4            3            2
+--R               - 24279260x  - 10740960x  - 44401996x  - 17804448x - 15966000
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R      *
+--R                  4  5
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                  4  8
+--R                                             atan(-)
+--R                  4          2                    3
+--R           (48250x  + 627250x  + 1737000)cos(-------)
+--R                                                2
+--R         + 
+--R                        6          5           4           3           2
+--R               - 120440x  - 119160x  - 1962870x  - 1898080x  - 8894790x
+--R             + 
+--R               - 7430760x - 8861400
+--R          *
+--R                      4  6
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     8          7           6           5            4
+--R               67040x  + 209920x  + 1595560x  + 4173920x  + 13100150x
+--R             + 
+--R                        3            2
+--R               25576400x  + 40737110x  + 45131760x + 28835640
+--R          *
+--R                      4  4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     10         9          8          7         6           5
+--R               16640x   - 15360x  + 248640x  - 481280x  - 61920x  - 5198400x
+--R             + 
+--R                          4            3            2
+--R               - 14224780x  - 22409520x  - 54385340x  - 30691440x - 31152240
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                12         11          10          9           8           7
+--R           4608x   - 10240x   + 146688x   - 266368x  + 1813792x  - 2465856x
+--R         + 
+--R                    6           5            4            3            2
+--R           10845728x  - 9417680x  + 31388810x  - 12071320x  + 36863010x
+--R         + 
+--R           - 440136x + 8419464
+--R      *
+--R                  4  4
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                  4  9
+--R                                             atan(-)
+--R                  4          2                    3
+--R           (34000x  + 442000x  + 1224000)cos(-------)
+--R                                                2
+--R         + 
+--R                       6         5           4           3           2
+--R               - 96640x  - 64960x  - 1562720x  - 1068480x  - 6918240x
+--R             + 
+--R               - 4354560x - 6134400
+--R          *
+--R                      4  7
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     8          7           6           5            4
+--R               97344x  + 233472x  + 2120496x  + 4566912x  + 15360420x
+--R             + 
+--R                        3            2
+--R               27263360x  + 39876196x  + 45651456x + 21859344
+--R          *
+--R                      4  5
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       10          9          8           7            6
+--R               - 24320x   - 194560x  - 844480x  - 4766720x  - 10654880x
+--R             + 
+--R                          5            4             3             2
+--R               - 40411520x  - 58608940x  - 133933760x  - 126655260x
+--R             + 
+--R               - 130501440x - 55419120
+--R          *
+--R                      4  3
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       12          10         9           8           7
+--R               - 14336x   - 375296x   + 70656x  - 3384704x  + 1628672x
+--R             + 
+--R                          6            5           4            3            2
+--R               - 10920256x  + 12874880x  + 1399480x  + 39275840x  + 48061080x
+--R             + 
+--R               34345152x + 23252832
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R      *
+--R                  4  3
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                 4  10
+--R                                            atan(-)
+--R                  4          2                   3
+--R           (22000x  + 286000x  + 792000)cos(-------)
+--R                                               2
+--R         + 
+--R                       6         5           4          3           2
+--R               - 78480x  - 22720x  - 1270040x  - 425860x  - 5614680x  - 1992420x
+--R             + 
+--R               - 4870800
+--R          *
+--R                      4  8
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     8         7           6           5            4
+--R               98624x  + 89792x  + 2015056x  + 1767552x  + 13159460x
+--R             + 
+--R                        3            2
+--R               10636720x  + 28187716x  + 18017136x + 9676944
+--R          *
+--R                      4  6
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       10          9           8           7            6
+--R               - 51840x   - 147840x  - 1374240x  - 3550720x  - 13031280x
+--R             + 
+--R                          5            4            3            2
+--R               - 29344200x  - 52023970x  - 93639480x  - 76842410x  - 84371760x
+--R             + 
+--R               - 22154760
+--R          *
+--R                      4  4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                    12         11          10           9           8
+--R               8192x   + 87040x   + 338432x   + 2562048x  + 5229568x
+--R             + 
+--R                        7            6             5             4             3
+--R               28122496x  + 38032192x  + 139532160x  + 131237040x  + 295028320x
+--R             + 
+--R                         2
+--R               181617840x  + 184477536x + 49139136
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                14        13         12         11           10           9
+--R           2048x   - 2048x   + 75264x   - 78848x   + 1083904x   - 1179264x
+--R         + 
+--R                   8           7            6            5            4
+--R           7649568x  - 8581824x  + 26732696x  - 30831784x  + 39729206x
+--R         + 
+--R                      3            2
+--R           - 47933476x  + 12799638x  - 20529756x - 2956824
+--R      *
+--R                  4  2
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                4  11
+--R                                           atan(-)
+--R                 4          2                   3
+--R           (8000x  + 104000x  + 288000)cos(-------)
+--R                                              2
+--R         + 
+--R                       6        5          4         3           2
+--R               - 35520x  - 1280x  - 568960x  - 58640x  - 2440320x  - 424080x
+--R             + 
+--R               - 1771200
+--R          *
+--R                      4  9
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     8         7           6          5           4           3
+--R               63488x  + 15104x  + 1276672x  + 343424x  + 8145920x  + 2538240x
+--R             + 
+--R                        2
+--R               16673792x  + 6037632x + 4393728
+--R          *
+--R                      4  7
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       10         9           8          7            6
+--R               - 53376x   - 26112x  - 1291680x  - 637952x  - 10808688x
+--R             + 
+--R                         5            4            3            2
+--R               - 5574048x  - 35251610x  - 20158560x  - 33065506x  - 23675328x
+--R             + 
+--R               1170360
+--R          *
+--R                      4  5
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     12         11          10          9           8
+--R               19456x   + 20480x   + 573696x   + 620544x  + 6284864x
+--R             + 
+--R                       7            6            5            4            3
+--R               7126528x  + 30837536x  + 37848320x  + 62655820x  + 88592960x
+--R             + 
+--R                        2
+--R               32050620x  + 64795968x - 4635792
+--R          *
+--R                      4  3
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                      14        13         12          11           10
+--R               - 2048x   - 8192x   - 90624x   - 315392x   - 1570304x
+--R             + 
+--R                         9            8            7            6             5
+--R               - 4768256x  - 13578208x  - 35581696x  - 61211416x  - 134034336x
+--R             + 
+--R                         4             3             2
+--R             - 134787106x  - 227935504x  - 115435458x  - 119184624x - 16755336
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R      *
+--R                  4
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                           4  12
+--R                                      atan(-)
+--R             4         2                   3
+--R       (4000x  + 52000x  + 144000)cos(-------)
+--R                                         2
+--R     + 
+--R                   6         5          4          3           2
+--R           - 15040x  + 13440x  - 241920x  + 180720x  - 1040640x  + 537840x
+--R         + 
+--R           - 734400
+--R      *
+--R                  4  10
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R     + 
+--R                 8         7          6          5           4           3
+--R           23712x  - 38144x  + 496608x  - 696824x  + 3371310x  - 3793620x
+--R         + 
+--R                   2
+--R           7697158x  - 5506812x + 2651112
+--R      *
+--R                  4  8
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R     + 
+--R                   10         9          8          7           6           5
+--R           - 20352x   + 38016x  - 540640x  + 871296x  - 5178896x  + 6743384x
+--R         + 
+--R                      4            3            2
+--R           - 21016750x  + 19354960x  - 31007622x  + 13732344x - 6753240
+--R      *
+--R                  4  6
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R     + 
+--R                12         11          10          9           8           7
+--R           9728x   - 15360x   + 316288x   - 435968x  + 3925152x  - 4537856x
+--R         + 
+--R                    6            5            4            3            2
+--R           22842608x  - 20658080x  + 60609110x  - 36957520x  + 56500110x
+--R         + 
+--R           - 14016816x + 5134104
+--R      *
+--R                  4  4
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R     + 
+--R                  14        13         12         11           10           9
+--R           - 2048x   + 2048x   - 80384x   + 73728x   - 1242624x   + 1020544x
+--R         + 
+--R                     8           7            6            5            4
+--R           - 9514848x  + 6716544x  - 36896536x  + 20667944x  - 64383706x
+--R         + 
+--R                    3            2
+--R           23278976x  - 32177178x  + 1152216x + 2956824
+--R      *
+--R                  4  2
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R     + 
+--R            14        13         12         11           10           9
+--R       2048x   + 2048x   + 72704x   + 72704x   + 1021440x   + 1021440x
+--R     + 
+--R               8           7            6            5            4            3
+--R       7148288x  + 7148288x  + 25563416x  + 25563416x  + 42062436x  + 42062436x
+--R     + 
+--R                2
+--R       22066668x  + 22066668x
+--R  /
+--R                                                                          4  10
+--R                                                                     atan(-)
+--R                 5        4         3         2                           3
+--R           (1900x  + 1600x  + 24700x  + 20800x  + 68400x + 57600)sin(-------)
+--R                                                                        2
+--R         + 
+--R                   5         4         3          2
+--R             (6800x  + 15200x  + 88400x  + 197600x  + 244800x + 547200)
+--R          *
+--R                      4           4  9
+--R                 atan(-)     atan(-)
+--R                      3           3
+--R             cos(-------)sin(-------)
+--R                    2           2
+--R         + 
+--R                        5         4          3          2
+--R                 (17800x  + 59200x  + 231400x  + 769600x  + 640800x + 2131200)
+--R              *
+--R                          4  2
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                     7         6         5          4          3          2
+--R               - 888x  - 11264x  - 22612x  - 173312x  - 175852x  - 754944x
+--R             + 
+--R               - 398448x - 967680
+--R          *
+--R                      4  8
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                           5          4          3           2
+--R                     57600x  + 126400x  + 748800x  + 1643200x  + 2073600x
+--R                   + 
+--R                     4550400
+--R              *
+--R                          4  3
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                        7         6        5          4          3           2
+--R                   2432x  - 59904x  + 8768x  - 924032x  - 209472x  - 4045184x
+--R                 + 
+--R                   - 822528x - 5230080
+--R              *
+--R                          4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R          *
+--R                      4  7
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                          5          4           3           2
+--R                   108400x  + 177600x  + 1409200x  + 2308800x  + 3902400x
+--R                 + 
+--R                   6393600
+--R              *
+--R                          4  4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           7          6           5           4           3
+--R                   - 53696x  - 127488x  - 1039904x  - 1957504x  - 6377184x
+--R                 + 
+--R                             2
+--R                   - 8491648x  - 12306816x - 10805760
+--R              *
+--R                          4  2
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                      9         8         7          6          5           4
+--R               - 4480x  + 14336x  - 71168x  + 297472x  - 268232x  + 2066304x
+--R             + 
+--R                      3           2
+--R               329048x  + 5375872x  + 2200032x + 3810816
+--R          *
+--R                      4  6
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                          5          4           3           2
+--R                   149600x  + 194400x  + 1944800x  + 2527200x  + 5385600x
+--R                 + 
+--R                   6998400
+--R              *
+--R                          4  5
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           7          6           5           4           3
+--R                   - 62464x  - 232192x  - 1313536x  - 3475136x  - 8768256x
+--R                 + 
+--R                              2
+--R                   - 14295232x  - 18054144x - 16439040
+--R              *
+--R                          4  3
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                         9         8          7          6           5
+--R                   33280x  + 13312x  + 850944x  + 317184x  + 7687776x
+--R                 + 
+--R                           4            3           2
+--R                   2552128x  + 28731616x  + 7778624x  + 37862784x + 7172352
+--R              *
+--R                          4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R          *
+--R                      4  5
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                          5          4           3           2
+--R                   190600x  + 158400x  + 2477800x  + 2059200x  + 6861600x
+--R                 + 
+--R                   5702400
+--R              *
+--R                          4  6
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                            7          6           5           4            3
+--R                   - 147360x  - 430080x  - 2730640x  - 6320640x  - 15899440x
+--R                 + 
+--R                              2
+--R                   - 24967680x  - 29338560x - 26265600
+--R              *
+--R                          4  4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           9          8         7           6           5
+--R                   - 19200x  + 143360x  - 52480x  + 2821120x  + 3236080x
+--R                 + 
+--R                            4            3            2
+--R                   18346240x  + 24837680x  + 44069120x  + 49129920x + 26588160
+--R              *
+--R                          4  2
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                      11         10          9          8           7
+--R               - 8064x   + 16384x   - 247488x  + 356352x  - 2872048x
+--R             + 
+--R                       6            5           4            3           2
+--R               2666496x  - 15540456x  + 7890688x  - 38543192x  + 7158528x
+--R             + 
+--R               - 34237152x - 1410048
+--R          *
+--R                      4  4
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                            5         4           3          2
+--R                     153600x  + 70400x  + 1996800x  + 915200x  + 5529600x
+--R                   + 
+--R                     2534400
+--R              *
+--R                          4  7
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                            7          6           5           4            3
+--R                   - 224896x  - 389888x  - 3719104x  - 5677504x  - 18437184x
+--R                 + 
+--R                              2
+--R                   - 21952448x  - 28636416x - 21922560
+--R              *
+--R                          4  5
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                          9          8           7           6            5
+--R                   102400x  + 476160x  + 2411520x  + 9189120x  + 20020480x
+--R                 + 
+--R                            4            3             2
+--R                   58117440x  + 68660480x  + 133811520x  + 82437120x + 71573760
+--R              *
+--R                          4  3
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                         11         10          9           8           7
+--R                   27648x   - 73728x   + 585216x  - 1849344x  + 4017536x
+--R                 + 
+--R                              6           5            4           3
+--R                   - 16934912x  + 8334912x  - 68414336x  - 8876096x
+--R                 + 
+--R                               2
+--R                   - 113452416x  - 33244416x - 45080064
+--R              *
+--R                          4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R          *
+--R                      4  3
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                         5         4           3          2
+--R                 (117700x  + 12800x  + 1530100x  + 166400x  + 4237200x + 460800)
+--R              *
+--R                          4  8
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                            7         6           5          4            3
+--R                   - 197216x  - 66048x  - 3122384x  - 953984x  - 14361264x
+--R                 + 
+--R                             2
+--R                   - 3617408x  - 20108736x - 3432960
+--R              *
+--R                          4  6
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                          9          8           7           6            5
+--R                   172800x  + 240640x  + 3524480x  + 4609280x  + 24304720x
+--R                 + 
+--R                            4            3            2
+--R                   28852160x  + 65106320x  + 65490880x  + 52879680x + 33719040
+--R              *
+--R                          4  4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           11          10           9           8            7
+--R                   - 62976x   - 221184x   - 1691392x  - 5363712x  - 17034432x
+--R                 + 
+--R                              6            5             4             3
+--R                   - 47102976x  - 79245984x  - 180563328x  - 166627168x
+--R                 + 
+--R                               2
+--R                   - 279427968x  - 120267648x - 96671232
+--R              *
+--R                          4  2
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                      13         12          11          10           9
+--R               - 5120x   + 16384x   - 160768x   + 503808x   - 1968704x
+--R             + 
+--R                       8            7            6            5            4
+--R               5999616x  - 11816576x  + 34620928x  - 35604388x  + 98164800x
+--R             + 
+--R                          3             2
+--R               - 48076820x  + 118387008x  - 18564624x + 31539456
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                        5         4          3          2
+--R                 (54800x  - 12800x  + 712400x  - 166400x  + 1972800x - 460800)
+--R              *
+--R                          4  9
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                            7         6           5          4           3
+--R                   - 116992x  + 52224x  - 1902208x  + 718592x  - 9168768x
+--R                 + 
+--R                           2
+--R                   2395904x  - 13727232x + 1428480
+--R              *
+--R                          4  7
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                          9         8           7           6            5
+--R                   125440x  - 76288x  + 2540544x  - 1416576x  + 17305056x
+--R                 + 
+--R                             4            3            2
+--R                   - 8460832x  + 45253216x  - 17785376x  + 34614144x - 6899328
+--R              *
+--R                          4  5
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                           11         10           9          8            7
+--R                   - 73728x   + 12288x   - 1867776x  + 236544x  - 17437696x
+--R                 + 
+--R                           6            5           4             3           2
+--R                   1382912x  - 73289472x  + 1804736x  - 133201664x  - 4785984x
+--R                 + 
+--R                   - 73534464x - 7485696
+--R              *
+--R                          4  3
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R             + 
+--R                         13         12          11          10           9
+--R                   20480x   + 24576x   + 667648x   + 755712x   + 8583424x
+--R                 + 
+--R                           8            7            6             5
+--R                   8999424x  + 55010816x  + 51931392x  + 182024848x
+--R                 + 
+--R                           4             3             2
+--R                 147247200x  + 285532240x  + 177580512x  + 152852544x + 47309184
+--R              *
+--R                          4
+--R                     atan(-)
+--R                          3
+--R                 cos(-------)
+--R                        2
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             sin(-------)
+--R                    2
+--R         + 
+--R                    5         4          3          2
+--R             (19600x  - 25600x  + 254800x  - 332800x  + 705600x - 921600)
+--R          *
+--R                      4  10
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       7         6          5           4           3
+--R               - 35208x  + 75776x  - 633292x  + 1131008x  - 3550132x
+--R             + 
+--R                       2
+--R               4624896x  - 6321168x + 5253120
+--R          *
+--R                      4  8
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     9         8          7           6           5            4
+--R               37760x  - 91136x  + 899968x  - 1783552x  + 7578472x  - 11505984x
+--R             + 
+--R                        3            2
+--R               26439752x  - 27287872x  + 32434848x - 15872256
+--R          *
+--R                      4  6
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       11         10          9           8           7
+--R               - 25344x   + 57344x   - 728448x  + 1431552x  - 7904608x
+--R             + 
+--R                        6            5            4            3            2
+--R               13034496x  - 39898416x  + 52297088x  - 91822352x  + 85984128x
+--R             + 
+--R               - 74279232x + 33633792
+--R          *
+--R                      4  4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     13         12          11          10           9
+--R               10240x   - 16384x   + 339968x   - 503808x   + 4468864x
+--R             + 
+--R                         8            7            6             5            4
+--R               - 5999616x  + 29441536x  - 34620928x  + 100914248x  - 98164800x
+--R             + 
+--R                         3             2
+--R               166072360x  - 118387008x  + 96074784x - 31539456
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                  15         13           11            9            7
+--R           - 2048x   - 80896x   - 1312256x   - 11234048x  - 54156568x
+--R         + 
+--R                       5             3
+--R           - 144316100x  - 190316412x  - 88266672x
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 9
+--R     + 
+--R                                        4  12
+--R                                   atan(-)
+--R            4        2                  3
+--R       (625x  + 8125x  + 22500)sin(-------)
+--R                                      2
+--R     + 
+--R                                           4           4  11
+--R                                      atan(-)     atan(-)
+--R             4         2                   3           3
+--R       (5000x  + 65000x  + 180000)cos(-------)sin(-------)
+--R                                         2           2
+--R     + 
+--R                                                 4  2
+--R                                            atan(-)
+--R                  4          2                   3           6        5
+--R           (17500x  + 227500x  + 630000)cos(-------)  - 1900x  - 1600x
+--R                                               2
+--R         + 
+--R                   4         3          2
+--R           - 34450x  - 20800x  - 195150x  - 57600x - 351000
+--R      *
+--R                  4  10
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                  4  3
+--R                                             atan(-)
+--R                  4          2                    3
+--R           (40000x  + 520000x  + 1440000)cos(-------)
+--R                                                2
+--R         + 
+--R                      6         5          4          3          2
+--R               - 6800x  - 15200x  - 125400x  - 197600x  - 725800x  - 547200x
+--R             + 
+--R               - 1332000
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R      *
+--R                  4  9
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                  4  4
+--R                                             atan(-)
+--R                  4          2                    3
+--R           (73750x  + 958750x  + 2655000)cos(-------)
+--R                                                2
+--R         + 
+--R                       6         5          4          3           2
+--R               - 17800x  - 59200x  - 315900x  - 769600x  - 1739300x  - 2131200x
+--R             + 
+--R               - 3042000
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R               8         7         6          5          4           3
+--R           888x  + 11264x  + 26608x  + 224000x  + 269991x  + 1413888x
+--R         + 
+--R                   2
+--R           1090787x  + 2792448x + 1518876
+--R      *
+--R                  4  8
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                    4  5
+--R                                               atan(-)
+--R                   4           2                    3
+--R           (110000x  + 1430000x  + 3960000)cos(-------)
+--R                                                  2
+--R         + 
+--R                       6          5          4           3           2
+--R               - 57600x  - 126400x  - 972800x  - 1643200x  - 4985600x
+--R             + 
+--R               - 4550400x - 8064000
+--R          *
+--R                      4  3
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                      8         7         6           5          4           3
+--R               - 2432x  + 59904x  - 19712x  + 1193600x  + 202576x  + 7549568x
+--R             + 
+--R                       2
+--R               2188432x  + 14934528x + 4873536
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R      *
+--R                  4  7
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                    4  6
+--R                                               atan(-)
+--R                   4           2                    3
+--R           (132500x  + 1722500x  + 4770000)cos(-------)
+--R                                                  2
+--R         + 
+--R                        6          5           4           3           2
+--R               - 108400x  - 177600x  - 1790200x  - 2308800x  - 8855400x
+--R             + 
+--R               - 6393600x - 13716000
+--R          *
+--R                      4  4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     8          7           6           5            4
+--R               53696x  + 127488x  + 1281536x  + 2531200x  + 10526072x
+--R             + 
+--R                        3            2
+--R               15949696x  + 34105304x  + 31458816x + 36276192
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                10         9         8          7          6           5
+--R           4480x   - 14336x  + 91328x  - 361984x  + 543128x  - 3259776x
+--R         + 
+--R                  4            3           2
+--R           360772x  - 12310912x  - 4371780x  - 16584192x - 7291728
+--R      *
+--R                  4  6
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                    4  7
+--R                                               atan(-)
+--R                   4           2                    3
+--R           (140000x  + 1820000x  + 5040000)cos(-------)
+--R                                                  2
+--R         + 
+--R                        6          5           4           3            2
+--R               - 149600x  - 194400x  - 2438800x  - 2527200x  - 11807600x
+--R             + 
+--R               - 6998400x - 17784000
+--R          *
+--R                      4  5
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     8          7           6           5            4
+--R               62464x  + 232192x  + 1594624x  + 4520000x  + 14056448x
+--R             + 
+--R                        3            2
+--R               27878464x  + 49415936x  + 54054144x + 58825728
+--R          *
+--R                      4  3
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       10         9           8          7            6
+--R               - 33280x   - 13312x  - 1000704x  - 377088x  - 11180064x
+--R             + 
+--R                         5            4            3             2
+--R               - 3844672x  - 56231216x  - 16614464x  - 119730640x  - 25668864x
+--R             + 
+--R               - 72645696
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R      *
+--R                  4  5
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                    4  8
+--R                                               atan(-)
+--R                   4           2                    3
+--R           (120625x  + 1568125x  + 4342500)cos(-------)
+--R                                                  2
+--R         + 
+--R                        6          5           4           3            2
+--R               - 190600x  - 158400x  - 3094300x  - 2059200x  - 14876100x
+--R             + 
+--R               - 5702400x - 22194000
+--R          *
+--R                      4  6
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                      8          7           6           5            4
+--R               147360x  + 430080x  + 3393760x  + 8256000x  + 26754020x
+--R             + 
+--R                        3            2
+--R               50127360x  + 82253140x  + 95938560x + 80424720
+--R          *
+--R                      4  4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     10          9          8           7           6
+--R               19200x   - 143360x  + 138880x  - 3466240x  - 3194320x
+--R             + 
+--R                          5            4             3             2
+--R               - 29589760x  - 39057880x  - 104433920x  - 130596200x
+--R             + 
+--R               - 129438720x - 117787680
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                12         11          10          9           8           7
+--R           8064x   - 16384x   + 283776x   - 430080x  + 3904096x  - 4104192x
+--R         + 
+--R                    6            5            4            3             2
+--R           26326272x  - 17028352x  + 88605471x  - 27705600x  + 130823539x
+--R         + 
+--R           - 7713792x + 48595932
+--R      *
+--R                  4  4
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                   4  9
+--R                                              atan(-)
+--R                  4           2                    3
+--R           (85000x  + 1105000x  + 3060000)cos(-------)
+--R                                                 2
+--R         + 
+--R                        6         5           4          3            2
+--R               - 153600x  - 70400x  - 2460800x  - 915200x  - 11561600x
+--R             + 
+--R               - 2534400x - 16704000
+--R          *
+--R                      4  7
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                      8          7           6           5            4
+--R               224896x  + 389888x  + 4731136x  + 7432000x  + 33077072x
+--R             + 
+--R                        3            2
+--R               44760896x  + 84354704x  + 85084416x + 53404992
+--R          *
+--R                      4  5
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                        10          9           8            7            6
+--R               - 102400x   - 476160x  - 2872320x  - 11331840x  - 29835520x
+--R             + 
+--R                          5             4             3             2
+--R               - 94647360x  - 138970880x  - 323718720x  - 272140800x
+--R             + 
+--R               - 383857920x - 144046080
+--R          *
+--R                      4  3
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       12         11          10           9           8
+--R               - 27648x   + 73728x   - 709632x   + 2181120x  - 6371072x
+--R             + 
+--R                        7            6             5           4             3
+--R               24510464x  - 21748224x  + 129256064x  - 7529432x  + 315216000x
+--R             + 
+--R                        2
+--R               79981832x  + 278567424x + 66089376
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R      *
+--R                  4  3
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                  4  10
+--R                                             atan(-)
+--R                  4          2                    3
+--R           (55000x  + 715000x  + 1980000)cos(-------)
+--R                                                2
+--R         + 
+--R                        6         5           4          3           2
+--R               - 117700x  - 12800x  - 1909350x  - 166400x  - 9167450x  - 460800x
+--R             + 
+--R               - 13653000
+--R          *
+--R                      4  8
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                      8         7           6           5            4
+--R               197216x  + 66048x  + 4009856x  + 1251200x  + 26619212x
+--R             + 
+--R                       3            2
+--R               7481216x  + 61428284x  + 14132736x + 25949232
+--R          *
+--R                      4  6
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                        10          9           8           7            6
+--R               - 172800x   - 240640x  - 4302080x  - 5692160x  - 38415280x
+--R             + 
+--R                          5             4             3             2
+--R               - 47157440x  - 146593720x  - 159436480x  - 216065000x
+--R             + 
+--R               - 185921280x - 52953120
+--R          *
+--R                      4  4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     12          11           10           9            8
+--R               62976x   + 221184x   + 1974784x   + 6359040x  + 24008064x
+--R             + 
+--R                        7             6             5             4
+--R               69000192x  + 141644928x  + 348296832x  + 411690604x
+--R             + 
+--R                         3             2
+--R               802742400x  + 512018556x  + 652810752x + 144464688
+--R          *
+--R                      4  2
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                14         13          12          11           10           9
+--R           5120x   - 16384x   + 183808x   - 577536x   + 2640320x   - 8100864x
+--R         + 
+--R                    8            7            6             5             4
+--R           19281248x  - 57264640x  + 74858644x  - 211968576x  + 145416590x
+--R         + 
+--R                       3             2
+--R           - 380282688x  + 112019058x  - 245037312x + 11060712
+--R      *
+--R                  4  2
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                                 4  11
+--R                                            atan(-)
+--R                  4          2                   3
+--R           (20000x  + 260000x  + 720000)cos(-------)
+--R                                               2
+--R         + 
+--R                       6         5          4          3           2
+--R               - 54800x  + 12800x  - 869400x  + 166400x  - 4013800x  + 460800x
+--R             + 
+--R               - 5652000
+--R          *
+--R                      4  9
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                      8         7           6          5            4
+--R               116992x  - 52224x  + 2428672x  - 953600x  + 16637344x
+--R             + 
+--R                         3            2
+--R               - 5451008x  + 40799008x  - 9888768x + 22483584
+--R          *
+--R                      4  7
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                        10         9           8           7            6
+--R               - 125440x   + 76288x  - 3105024x  + 1759872x  - 27467424x
+--R             + 
+--R                        5             4            3             2
+--R               14063008x  - 103060976x  + 44955296x  - 146329360x  + 47915136x
+--R             + 
+--R               - 27821376
+--R          *
+--R                      4  5
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                     12         11           10          9            8
+--R               73728x   - 12288x   + 2199552x   - 291840x  + 25096192x
+--R             + 
+--R                         7             6           5             4           3
+--R               - 2322944x  + 136207104x  - 6192704x  + 352660672x  + 3038400x
+--R             + 
+--R                         2
+--R               365559488x  + 24696576x + 62648064
+--R          *
+--R                      4  3
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R         + 
+--R                       14         13          12          11            10
+--R               - 20480x   - 24576x   - 759808x   - 866304x   - 11380480x
+--R             + 
+--R                          9            8            7             6
+--R               - 12151296x  - 87809408x  - 85896960x  - 367837264x
+--R             + 
+--R                           5             4             3             2
+--R               - 317952864x  - 800698360x  - 570424032x  - 756173448x
+--R             + 
+--R               - 367555968x - 152878752
+--R          *
+--R                      4
+--R                 atan(-)
+--R                      3
+--R             cos(-------)
+--R                    2
+--R      *
+--R                  4
+--R             atan(-)
+--R                  3
+--R         sin(-------)
+--R                2
+--R     + 
+--R                                             4  12
+--R                                        atan(-)
+--R              4          2                   3
+--R       (10000x  + 130000x  + 360000)cos(-------)
+--R                                           2
+--R     + 
+--R                   6         5          4          3           2
+--R           - 19600x  + 25600x  - 323800x  + 332800x  - 1602600x  + 921600x
+--R         + 
+--R           - 2484000
+--R      *
+--R                  4  10
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R     + 
+--R                 8         7          6           5           4           3
+--R           35208x  - 75776x  + 791728x  - 1472000x  + 6065481x  - 9057792x
+--R         + 
+--R                    2
+--R           17948717x  - 17528832x + 16404516
+--R      *
+--R                  4  8
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R     + 
+--R                   10         9           8           7            6
+--R           - 37760x   + 91136x  - 1069888x  + 2193664x  - 11246008x
+--R         + 
+--R                    5            4            3             2
+--R           18609216x  - 53138852x  + 65084992x  - 106009980x  + 79656192x
+--R         + 
+--R           - 58337712
+--R      *
+--R                  4  6
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R     + 
+--R                 12         11          10           9            8            7
+--R           25344x   - 57344x   + 842496x   - 1689600x  + 10926016x  - 18895872x
+--R         + 
+--R                    6            5             4             3             2
+--R           69248352x  - 99070592x  + 218029686x  - 239875200x  + 297901534x
+--R         + 
+--R           - 209889792x + 96872472
+--R      *
+--R                  4  4
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R     + 
+--R                   14         13          12          11           10
+--R           - 10240x   + 16384x   - 386048x   + 577536x   - 5895040x
+--R         + 
+--R                   9            8            7             6             5
+--R           8100864x  - 46575808x  + 57264640x  - 201019304x  + 211968576x
+--R         + 
+--R                       4             3             2
+--R           - 455107180x  + 380282688x  - 455111028x  + 245037312x - 103598352
+--R      *
+--R                  4  2
+--R             atan(-)
+--R                  3
+--R         cos(-------)
+--R                2
+--R     + 
+--R            16         14           12            10            8             6
+--R       2048x   + 90112x   + 1655552x   + 16413440x   + 94584136x  + 316639568x
+--R     + 
+--R                 4             2
+--R       575233929x  + 466808589x  + 83283876
+--R                                                    Type: Expression(Integer)
+--E 785
+
+)clear all
+
+--S 786 of 1580
+t0:=x*(1+sqrt(1-x^2))
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R   (1)  x\|- x  + 1  + x
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 1580
+r0:=1/2*x^2-1/3*(1-x^2)^(3/2)
+--R 
+--R
+--R                  +--------+
+--R           2      |   2          2
+--R        (2x  - 2)\|- x  + 1  + 3x
+--R   (2)  --------------------------
+--R                     6
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------+
+--R               4 |   2          6     4
+--R           - 3x \|- x  + 1  - 2x  + 3x
+--R   (3)  ---------------------------------
+--R                   +--------+
+--R           2       |   2           2
+--R        (6x  - 24)\|- x  + 1  - 18x  + 24
+--R                                         Type: Union(Expression(Integer),...)
+--E 788
+
+--S 789 of 1580
+m0:=a0-r0
+--R 
+--R
+--R          1
+--R   (4)  - -
+--R          3
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 790
+
+)clear all
+
+--S 791 of 1580
+t0:=x*(1+sqrt(1-x)*sqrt(1+x))
+--R 
+--R
+--R          +-------+ +-----+
+--R   (1)  x\|- x + 1 \|x + 1  + x
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 1580
+r0:=1/2*x^2-1/3*(1-x^2)^(3/2)
+--R 
+--R
+--R                  +--------+
+--R           2      |   2          2
+--R        (2x  - 2)\|- x  + 1  + 3x
+--R   (2)  --------------------------
+--R                     6
+--R                                                    Type: Expression(Integer)
+--E 792
+
+--S 793 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2      +-------+ +-----+     2
+--R        (2x  - 2)\|- x + 1 \|x + 1  + 3x
+--R   (3)  ---------------------------------
+--R                        6
+--R                                         Type: Union(Expression(Integer),...)
+--E 793
+
+--S 794 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                                                +--------+
+--R          2      +-------+ +-----+       2      |   2
+--R        (x  - 1)\|- x + 1 \|x + 1  + (- x  + 1)\|- x  + 1
+--R   (4)  --------------------------------------------------
+--R                                 3
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R                                                +--------+
+--R          3      +-------+ +-----+       3      |   2
+--R        (x  - x)\|- x + 1 \|x + 1  + (- x  + x)\|- x  + 1
+--R   (5)  --------------------------------------------------
+--R                    +--------+
+--R                    |   2      +-------+ +-----+
+--R                   \|- x  + 1 \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 795
+
+)clear all
+
+--S 796 of 1580
+t0:=x*(1+1/(sqrt(2+x)*sqrt(3+x)))
+--R 
+--R
+--R          +-----+ +-----+
+--R        x\|x + 2 \|x + 3  + x
+--R   (1)  ---------------------
+--R            +-----+ +-----+
+--R           \|x + 2 \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 1580
+r0:=1/2*x^2-5*asinh(sqrt(2+x))+sqrt(2+x)*sqrt(3+x)
+--R 
+--R
+--R                   +-----+      +-----+ +-----+    2
+--R        - 10asinh(\|x + 2 ) + 2\|x + 2 \|x + 3  + x
+--R   (2)  --------------------------------------------
+--R                              2
+--R                                                    Type: Expression(Integer)
+--E 797
+
+--S 798 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-----+ +-----+               +-----+ +-----+    2
+--R        - 5log(2\|x + 2 \|x + 3  + 2x + 5) + 2\|x + 2 \|x + 3  + x
+--R   (3)  -----------------------------------------------------------
+--R                                     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 798
+
+--S 799 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                 +-----+ +-----+                      +-----+
+--R        - 5log(2\|x + 2 \|x + 3  + 2x + 5) + 10asinh(\|x + 2 )
+--R   (4)  ------------------------------------------------------
+--R                                   2
+--R                                                    Type: Expression(Integer)
+--E 799
+
+--S 800 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 800
+
+)clear all
+
+--S 801 of 1580
+t0:=(x-sqrt(x^6))/(x*(1-x^4))
+--R 
+--R
+--R         +--+
+--R         | 6
+--R        \|x   - x
+--R   (1)  ---------
+--R           5
+--R          x  - x
+--R                                                    Type: Expression(Integer)
+--E 801
+
+--S 802 of 1580
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(x^6)/x^3-_
+   1/2*atanh(x)*sqrt(x^6)/x^3
+--R 
+--R
+--R                               +--+
+--R                               | 6     3            3
+--R        (- atanh(x) + atan(x))\|x   + x atanh(x) + x atan(x)
+--R   (2)  ----------------------------------------------------
+--R                                   3
+--R                                 2x
+--R                                                    Type: Expression(Integer)
+--E 802
+
+--S 803 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  atan(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 803
+
+--S 804 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                             +--+
+--R                             | 6     3            3
+--R        (atanh(x) - atan(x))\|x   - x atanh(x) + x atan(x)
+--R   (4)  --------------------------------------------------
+--R                                  3
+--R                                2x
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R            +--+
+--R          2 | 6     5
+--R         x \|x   - x
+--R   (5)  -------------
+--R                 +--+
+--R          4      | 6
+--R        (x  - 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 805
+
+)clear all
+
+--S 806 of 1580
+t0:=(1-sqrt(x^6)/x)/(1-x^4)
+--R 
+--R
+--R         +--+
+--R         | 6
+--R        \|x   - x
+--R   (1)  ---------
+--R           5
+--R          x  - x
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 1580
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(x^6)/x^3-_
+   1/2*atanh(x)*sqrt(x^6)/x^3
+--R 
+--R
+--R                               +--+
+--R                               | 6     3            3
+--R        (- atanh(x) + atan(x))\|x   + x atanh(x) + x atan(x)
+--R   (2)  ----------------------------------------------------
+--R                                   3
+--R                                 2x
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  atan(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 808
+
+--S 809 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                             +--+
+--R                             | 6     3            3
+--R        (atanh(x) - atan(x))\|x   - x atanh(x) + x atan(x)
+--R   (4)  --------------------------------------------------
+--R                                  3
+--R                                2x
+--R                                                    Type: Expression(Integer)
+--E 809
+
+--S 810 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R            +--+
+--R          2 | 6     5
+--R         x \|x   - x
+--R   (5)  -------------
+--R                 +--+
+--R          4      | 6
+--R        (x  - 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 810
+
+)clear all
+
+--S 811 of 1580
+t0:=(x-sqrt(x^6))/(x-x^5)
+--R 
+--R
+--R         +--+
+--R         | 6
+--R        \|x   - x
+--R   (1)  ---------
+--R           5
+--R          x  - x
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 1580
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(x^6)/x^3-_
+   1/2*atanh(x)*sqrt(x^6)/x^3
+--R 
+--R
+--R                               +--+
+--R                               | 6     3            3
+--R        (- atanh(x) + atan(x))\|x   + x atanh(x) + x atan(x)
+--R   (2)  ----------------------------------------------------
+--R                                   3
+--R                                 2x
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  atan(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 813
+
+--S 814 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                             +--+
+--R                             | 6     3            3
+--R        (atanh(x) - atan(x))\|x   - x atanh(x) + x atan(x)
+--R   (4)  --------------------------------------------------
+--R                                  3
+--R                                2x
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R            +--+
+--R          2 | 6     5
+--R         x \|x   - x
+--R   (5)  -------------
+--R                 +--+
+--R          4      | 6
+--R        (x  - 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 815
+
+)clear all
+
+--S 816 of 1580
+t0:=x/(x+sqrt(x^6))
+--R 
+--R
+--R            x
+--R   (1)  ---------
+--R         +--+
+--R         | 6
+--R        \|x   + x
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 1580
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(x^6)/x^3-_
+   1/2*atanh(x)*sqrt(x^6)/x^3
+--R 
+--R
+--R                               +--+
+--R                               | 6     3            3
+--R        (- atanh(x) + atan(x))\|x   + x atanh(x) + x atan(x)
+--R   (2)  ----------------------------------------------------
+--R                                   3
+--R                                 2x
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  atan(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 818
+
+--S 819 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                             +--+
+--R                             | 6     3            3
+--R        (atanh(x) - atan(x))\|x   - x atanh(x) + x atan(x)
+--R   (4)  --------------------------------------------------
+--R                                  3
+--R                                2x
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R            +--+
+--R          2 | 6     5
+--R         x \|x   - x
+--R   (5)  -------------
+--R                 +--+
+--R          4      | 6
+--R        (x  - 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 820
+
+)clear all
+
+--S 821 of 1580
+t0:=(sqrt(x)-sqrt(x^3))/(x-x^3)
+--R 
+--R
+--R         +--+
+--R         | 3     +-+
+--R        \|x   - \|x
+--R   (1)  ------------
+--R            3
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 1580
+r0:=atan(sqrt(x))+atanh(sqrt(x))+atan(sqrt(x))*sqrt(x^3)/x^(3/2)-_
+   atanh(sqrt(x))*sqrt(x^3)/x^(3/2)
+--R 
+--R
+--R            +--+                         +--+
+--R            | 3      +-+        +-+      | 3      +-+       +-+
+--R        (- \|x   + x\|x )atanh(\|x ) + (\|x   + x\|x )atan(\|x )
+--R   (2)  --------------------------------------------------------
+--R                                    +-+
+--R                                  x\|x
+--R                                                    Type: Expression(Integer)
+--E 822
+
+--S 823 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+
+--R   (3)  2atan(\|x )
+--R                                         Type: Union(Expression(Integer),...)
+--E 823
+
+--S 824 of 1580
+m0:=a0-r0
+--R 
+--R
+--R          +--+                           +--+
+--R          | 3      +-+        +-+        | 3      +-+       +-+
+--R        (\|x   - x\|x )atanh(\|x ) + (- \|x   + x\|x )atan(\|x )
+--R   (4)  --------------------------------------------------------
+--R                                    +-+
+--R                                  x\|x
+--R                                                    Type: Expression(Integer)
+--E 824
+
+--S 825 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R           +--+
+--R           | 3     2 +-+
+--R         x\|x   - x \|x
+--R   (5)  -----------------
+--R                     +--+
+--R          2      +-+ | 3
+--R        (x  - 1)\|x \|x
+--R                                                    Type: Expression(Integer)
+--E 825
+
+)clear all
+
+--S 826 of 1580
+t0:=1/(sqrt(x)+sqrt(x^3))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         +--+
+--R         | 3     +-+
+--R        \|x   + \|x
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 1580
+r0:=atan(sqrt(x))+atanh(sqrt(x))+atan(sqrt(x))*sqrt(x^3)/x^(3/2)-_
+   atanh(sqrt(x))*sqrt(x^3)/x^(3/2)
+--R 
+--R
+--R            +--+                         +--+
+--R            | 3      +-+        +-+      | 3      +-+       +-+
+--R        (- \|x   + x\|x )atanh(\|x ) + (\|x   + x\|x )atan(\|x )
+--R   (2)  --------------------------------------------------------
+--R                                    +-+
+--R                                  x\|x
+--R                                                    Type: Expression(Integer)
+--E 827
+
+--S 828 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+
+--R   (3)  2atan(\|x )
+--R                                         Type: Union(Expression(Integer),...)
+--E 828
+
+--S 829 of 1580
+m0:=a0-r0
+--R 
+--R
+--R          +--+                           +--+
+--R          | 3      +-+        +-+        | 3      +-+       +-+
+--R        (\|x   - x\|x )atanh(\|x ) + (- \|x   + x\|x )atan(\|x )
+--R   (4)  --------------------------------------------------------
+--R                                    +-+
+--R                                  x\|x
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R           +--+
+--R           | 3     2 +-+
+--R         x\|x   - x \|x
+--R   (5)  -----------------
+--R                     +--+
+--R          2      +-+ | 3
+--R        (x  - 1)\|x \|x
+--R                                                    Type: Expression(Integer)
+--E 830
+
+)clear all
+
+--S 831 of 1580
+t0:=1/(sqrt(-1+x)+sqrt((-1+x)^3))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R         +-----------------+
+--R         | 3     2              +-----+
+--R        \|x  - 3x  + 3x - 1  + \|x - 1
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 1580
+r0:=atan(sqrt(-1+x))+atanh(sqrt(-1+x))+atan(sqrt(-1+x))*_
+   sqrt((-1+x)^3)/(-1+x)^(3/2)-atanh(sqrt(-1+x))*sqrt((-1+x)^3)/(-1+x)^(3/2)
+--R 
+--R
+--R   (2)
+--R           +-----------------+
+--R           | 3     2                     +-----+        +-----+
+--R       (- \|x  - 3x  + 3x - 1  + (x - 1)\|x - 1 )atanh(\|x - 1 )
+--R     + 
+--R         +-----------------+
+--R         | 3     2                     +-----+       +-----+
+--R       (\|x  - 3x  + 3x - 1  + (x - 1)\|x - 1 )atan(\|x - 1 )
+--R  /
+--R             +-----+
+--R     (x - 1)\|x - 1
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-----+
+--R   (3)  2atan(\|x - 1 )
+--R                                         Type: Union(Expression(Integer),...)
+--E 833
+
+--S 834 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         +-----------------+
+--R         | 3     2                       +-----+        +-----+
+--R       (\|x  - 3x  + 3x - 1  + (- x + 1)\|x - 1 )atanh(\|x - 1 )
+--R     + 
+--R           +-----------------+
+--R           | 3     2                     +-----+       +-----+
+--R       (- \|x  - 3x  + 3x - 1  + (x - 1)\|x - 1 )atan(\|x - 1 )
+--R  /
+--R             +-----+
+--R     (x - 1)\|x - 1
+--R                                                    Type: Expression(Integer)
+--E 834
+
+--S 835 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R                +-----------------+
+--R                | 3     2                 2           +-----+
+--R        (x - 1)\|x  - 3x  + 3x - 1  + (- x  + 2x - 1)\|x - 1
+--R   (5)  -----------------------------------------------------
+--R                                  +-----------------+
+--R                  2       +-----+ | 3     2
+--R                (x  - 2x)\|x - 1 \|x  - 3x  + 3x - 1
+--R                                                    Type: Expression(Integer)
+--E 835
+
+)clear all
+
+--S 836 of 1580
+t0:=(-5-4*x-3*sqrt(1-x^2))/((4+5*x)^2*sqrt(1-x^2))
+--R 
+--R
+--R               +--------+
+--R               |   2
+--R           - 3\|- x  + 1  - 4x - 5
+--R   (1)  ----------------------------
+--R                          +--------+
+--R            2             |   2
+--R        (25x  + 40x + 16)\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 1580
+r0:=3/5/(4+5*x)+sqrt(1-x^2)/(4+5*x)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        5\|- x  + 1  + 3
+--R   (2)  ----------------
+--R            25x + 20
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +--------+
+--R                   |   2           2
+--R        (25x + 12)\|- x  + 1  - 20x  - 25x - 12
+--R   (3)  ---------------------------------------
+--R                       +--------+
+--R                       |   2
+--R           (100x + 80)\|- x  + 1  - 100x - 80
+--R                                         Type: Union(Expression(Integer),...)
+--E 838
+
+--S 839 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        1
+--R   (4)  -
+--R        4
+--R                                                    Type: Expression(Integer)
+--E 839
+
+--S 840 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 840
+
+)clear all
+
+--S 841 of 1580
+t0:=(-1+sqrt(1-x^2))/((2+x-2*sqrt(1-x^2))^2*sqrt(1-x^2))
+--R 
+--R
+--R                          +--------+
+--R                          |   2
+--R                       - \|- x  + 1  + 1
+--R   (1)  ----------------------------------------------
+--R                       +--------+
+--R           2           |   2          3     2
+--R        (3x  - 4x - 8)\|- x  + 1  - 4x  - 8x  + 4x + 8
+--R                                                    Type: Expression(Integer)
+--E 841
+
+--S 842 of 1580
+r0:=3/5/(4+5*x)+sqrt(1-x^2)/(4+5*x)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        5\|- x  + 1  + 3
+--R   (2)  ----------------
+--R            25x + 20
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +--------+
+--R                   |   2           2
+--R        (25x + 12)\|- x  + 1  - 20x  - 25x - 12
+--R   (3)  ---------------------------------------
+--R                       +--------+
+--R                       |   2
+--R           (100x + 80)\|- x  + 1  - 100x - 80
+--R                                         Type: Union(Expression(Integer),...)
+--E 843
+
+--S 844 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        1
+--R   (4)  -
+--R        4
+--R                                                    Type: Expression(Integer)
+--E 844
+
+--S 845 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 845
+
+)clear all
+
+--S 846 of 1580
+t0:=1/(3*(1-x^2)+(-5-4*x)*sqrt(1-x^2))
+--R 
+--R
+--R                        1
+--R   (1)  - -----------------------------
+--R                   +--------+
+--R                   |   2          2
+--R          (4x + 5)\|- x  + 1  + 3x  - 3
+--R                                                    Type: Expression(Integer)
+--E 846
+
+--S 847 of 1580
+r0:=3/5/(4+5*x)+sqrt(1-x^2)/(4+5*x)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        5\|- x  + 1  + 3
+--R   (2)  ----------------
+--R            25x + 20
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +--------+
+--R                   |   2           2
+--R        (25x + 12)\|- x  + 1  - 20x  - 25x - 12
+--R   (3)  ---------------------------------------
+--R                       +--------+
+--R                       |   2
+--R           (100x + 80)\|- x  + 1  - 100x - 80
+--R                                         Type: Union(Expression(Integer),...)
+--E 848
+
+--S 849 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        1
+--R   (4)  -
+--R        4
+--R                                                    Type: Expression(Integer)
+--E 849
+
+--S 850 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 850
+
+)clear all
+
+--S 851 of 1580
+t0:=(a+b*x^(-1+n))/(c*x+d*x^n)
+--R 
+--R
+--R           n - 1
+--R        b x      + a
+--R   (1)  ------------
+--R            n
+--R         d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 1580
+r0:=b*log(x)/d-(b*c-a*d)*log(d+c*x^(1-n))/(c*d*(1-n))
+--R 
+--R
+--R                            - n + 1
+--R        (- a d + b c)log(c x        + d) + (b c n - b c)log(x)
+--R   (2)  ------------------------------------------------------
+--R                              c d n - c d
+--R                                                    Type: Expression(Integer)
+--E 852
+
+--S 853 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             n log(x)
+--R        (- a d + b c)log(d %e         + c x) + (a d n - b c)log(x)
+--R   (3)  ----------------------------------------------------------
+--R                                c d n - c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 853
+
+--S 854 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                            n log(x)                            - n + 1
+--R       (- a d + b c)log(d %e         + c x) + (a d - b c)log(c x        + d)
+--R     + 
+--R       (a d - b c)n log(x)
+--R  /
+--R     c d n - c d
+--R                                                    Type: Expression(Integer)
+--E 854
+
+--S 855 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R             2          - n  n log(x)               2  - n + 1
+--R       (- a d  + b c d)x   %e         + (a c d - b c )x
+--R     + 
+--R                     2    - n      2
+--R       (- a c d + b c )x x    + a d  - b c d
+--R  /
+--R         2 - n + 1    3   n log(x)    2     - n + 1      2
+--R     (c d x        + d )%e         + c d x x        + c d x
+--R                                                    Type: Expression(Integer)
+--E 855
+
+)clear all
+
+--S 856 of 1580
+t0:=1/((8+12*x+5*x^2)*sqrt(-7+2*x+5*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                        +------------+
+--R           2            |  2
+--R        (5x  + 12x + 8)\|5x  + 2x - 7
+--R                                                    Type: Expression(Integer)
+--E 856
+
+--S 857 of 1580
+r0:=(-1/20+1/10*%i)*atan((1/50+1/100*%i)*(-164-8*%i+(-100-40*%i)*x)/_
+   sqrt(-7+2*x+5*x^2))+(-1/10+1/20*%i)*atanh((1/100+1/50*%i)*_
+   (-164+8*%i+(-100+40*%i)*x)/sqrt(-7+2*x+5*x^2))
+--R 
+--R
+--R   (2)
+--R                        9   8        9   16
+--R                       (- + - %i)x + - + -- %i
+--R       1    1           5   5        5    5
+--R     (-- - -- %i)atanh(-----------------------)
+--R      10   20               +------------+
+--R                            |  2
+--R                           \|5x  + 2x - 7
+--R   + 
+--R                       8   9        16   9
+--R                      (- + - %i)x + -- + - %i
+--R       1    1          5   5         5   5
+--R     (-- - -- %i)atan(-----------------------)
+--R      20   10              +------------+
+--R                           |  2
+--R                          \|5x  + 2x - 7
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 857
+
+--S 858 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +------------+
+--R                    |  2                2
+--R           (5x + 5)\|5x  + 2x - 7  + 15x  + 26x + 9
+--R       log(----------------------------------------)
+--R                               2
+--R                              x
+--R     + 
+--R                        +------------+
+--R                        |  2                2
+--R             (- 5x - 5)\|5x  + 2x - 7  + 15x  + 26x + 9
+--R       - log(------------------------------------------)
+--R                                  2
+--R                                 x
+--R     + 
+--R                +------------+                      +------------+
+--R                |  2                                |  2
+--R              5\|5x  + 2x - 7  - x + 7            5\|5x  + 2x - 7  + x - 7
+--R       atan(---------------------------) - atan(---------------------------)
+--R              +------------+                      +------------+
+--R              |  2                                |  2
+--R            5\|5x  + 2x - 7  - 17x - 25         5\|5x  + 2x - 7  + 17x + 25
+--R  /
+--R     20
+--R                                         Type: Union(Expression(Integer),...)
+--E 858
+
+--S 859 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +------------+
+--R                     |  2                2
+--R      1     (5x + 5)\|5x  + 2x - 7  + 15x  + 26x + 9
+--R     -- log(----------------------------------------)
+--R     20                         2
+--R                               x
+--R   + 
+--R                         +------------+
+--R                         |  2                2
+--R        1     (- 5x - 5)\|5x  + 2x - 7  + 15x  + 26x + 9
+--R     - -- log(------------------------------------------)
+--R       20                          2
+--R                                  x
+--R   + 
+--R                          9   8        9   16
+--R                         (- + - %i)x + - + -- %i
+--R         1    1           5   5        5    5
+--R     (- -- + -- %i)atanh(-----------------------)
+--R        10   20               +------------+
+--R                              |  2
+--R                             \|5x  + 2x - 7
+--R   + 
+--R               +------------+                        +------------+
+--R               |  2             1     7              |  2             1     7
+--R              \|5x  + 2x - 7  - - x + -             \|5x  + 2x - 7  + - x - -
+--R      1                         5     5     1                         5     5
+--R     -- atan(--------------------------) - -- atan(--------------------------)
+--R     20       +------------+               20       +------------+
+--R              |  2             17                   |  2             17
+--R             \|5x  + 2x - 7  - -- x - 5            \|5x  + 2x - 7  + -- x + 5
+--R                                5                                     5
+--R   + 
+--R                         8   9        16   9
+--R                        (- + - %i)x + -- + - %i
+--R         1    1          5   5         5   5
+--R     (- -- + -- %i)atan(-----------------------)
+--R        20   10              +------------+
+--R                             |  2
+--R                            \|5x  + 2x - 7
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 859
+
+--S 860 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 860
+
+)clear all
+
+--S 861 of 1580
+t0:=(-x+2*x^3+4*x^5)/(3+2*x^2+x^4)^2
+--R 
+--R
+--R                 5     3
+--R               4x  + 2x  - x
+--R   (1)  --------------------------
+--R         8     6      4      2
+--R        x  + 4x  + 10x  + 12x  + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 861
+
+--S 862 of 1580
+r0:=1/8*(5-7*x^2)/(3+2*x^2+x^4)+9/8*atan((1+x^2)/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                2      +-+
+--R           4      2           (x  + 1)\|2          2      +-+
+--R        (9x  + 18x  + 27)atan(------------) + (- 7x  + 5)\|2
+--R                                    2
+--R   (2)  -----------------------------------------------------
+--R                           4      2       +-+
+--R                        (8x  + 16x  + 24)\|2
+--R                                                    Type: Expression(Integer)
+--E 862
+
+--S 863 of 1580
+r0b:=-2*x^2/(3+2*x^2+x^4)+1/8*(5+9*x^2)/(3+2*x^2+x^4)+_
+   9/8*atan((1+x^2)/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                2      +-+
+--R           4      2           (x  + 1)\|2          2      +-+
+--R        (9x  + 18x  + 27)atan(------------) + (- 7x  + 5)\|2
+--R                                    2
+--R   (3)  -----------------------------------------------------
+--R                           4      2       +-+
+--R                        (8x  + 16x  + 24)\|2
+--R                                                    Type: Expression(Integer)
+--E 863
+
+--S 864 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                2      +-+
+--R           4      2           (x  + 1)\|2          2      +-+
+--R        (9x  + 18x  + 27)atan(------------) + (- 7x  + 5)\|2
+--R                                    2
+--R   (4)  -----------------------------------------------------
+--R                           4      2       +-+
+--R                        (8x  + 16x  + 24)\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 864
+
+--S 865 of 1580
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R                               2      +-+
+--R          4      2           (x  + 1)\|2
+--R       (9x  + 18x  + 27)atan(------------)
+--R                                   2
+--R     + 
+--R                4                 2              +-+
+--R       (- 8r0a x  + (- 16r0a - 7)x  - 24r0a + 5)\|2
+--R  /
+--R        4      2       +-+
+--R     (8x  + 16x  + 24)\|2
+--R                                                    Type: Expression(Integer)
+--E 865
+
+--S 866 of 1580
+d0a:=D(m0a,x)
+--R 
+--R
+--R                 5     3
+--R               4x  + 2x  - x
+--R   (6)  --------------------------
+--R         8     6      4      2
+--R        x  + 4x  + 10x  + 12x  + 9
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 1580
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 1580
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 868
+
+)clear all
+
+--S 869 of 1580
+t0:=(x+x^5)/(1+2*x^2+2*x^4)^3
+--R 
+--R
+--R                            5
+--R                           x  + x
+--R   (1)  -------------------------------------------
+--R          12      10      8      6      4     2
+--R        8x   + 24x   + 36x  + 32x  + 18x  + 6x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 869
+
+--S 870 of 1580
+r0:=1/16*(3+4*x^2)/(1+2*x^2+2*x^4)^2+1/2*(1+2*x^2)/(1+2*x^2+2*x^4)+_
+   atan(1+2*x^2)
+--R 
+--R
+--R   (2)
+--R       8       6       4      2             2           6      4      2
+--R   (64x  + 128x  + 128x  + 64x  + 16)atan(2x  + 1) + 32x  + 48x  + 36x  + 11
+--R   -------------------------------------------------------------------------
+--R                           8       6       4      2
+--R                        64x  + 128x  + 128x  + 64x  + 16
+--R                                                    Type: Expression(Integer)
+--E 870
+
+--S 871 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       8       6       4      2             2           6      4      2
+--R   (64x  + 128x  + 128x  + 64x  + 16)atan(2x  + 1) + 32x  + 48x  + 36x  + 11
+--R   -------------------------------------------------------------------------
+--R                           8       6       4      2
+--R                        64x  + 128x  + 128x  + 64x  + 16
+--R                                         Type: Union(Expression(Integer),...)
+--E 871
+
+--S 872 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 873
+
+)clear all
+
+--S 874 of 1580
+t0:=(a+b*x+c*x^2)/(d+e*x^2+f*x^4)
+--R 
+--R
+--R            2
+--R         c x  + b x + a
+--R   (1)  ---------------
+--R           4      2
+--R        f x  + e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 874
+
+--S 875 of 1580
+r0:=-b*atanh((e+2*f*x^2)/sqrt(e^2-4*d*f))/sqrt(e^2-4*d*f)+atan(x*sqrt(2)*_
+   sqrt(f)/sqrt(e-sqrt(e^2-4*d*f)))*(c+(-c*e+2*a*f)/sqrt(e^2-4*d*f))/_
+   (sqrt(2)*sqrt(f)*sqrt(e-sqrt(e^2-4*d*f)))+atan(x*sqrt(2)*sqrt(f)/_
+   sqrt(e+sqrt(e^2-4*d*f)))*(c+(c*e-2*a*f)/sqrt(e^2-4*d*f))/(sqrt(2)*_
+   sqrt(f)*sqrt(e+sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2                | |          2
+--R         (c\|- 4d f + e   + 2a f - c e)\|\|- 4d f + e   + e
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|f
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4d f + e   + e
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2                |   |          2
+--R         (c\|- 4d f + e   - 2a f + c e)\|- \|- 4d f + e   + e
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|f
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4d f + e   + e
+--R     + 
+--R       -
+--R                                           +--------------------+
+--R                                  2        |   +-----------+
+--R              +-+ +-+         2f x  + e    |   |          2
+--R            b\|2 \|f atanh(--------------)\|- \|- 4d f + e   + e
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4d f + e
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4d f + e   + e
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4d f + e  \|f \|- \|- 4d f + e   + e \|\|- 4d f + e   + e
+--R                                                    Type: Expression(Integer)
+--E 875
+
+--S 876 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           ROOT
+--R                        2 2       2       2        2 2       2
+--R                  (- 12d f  + 3d e f)%%HF1  + (- 8d f  + 2d e f)%%HF0 %%HF1
+--R                + 
+--R                        2 2       2       2     2                2        2
+--R                  (- 12d f  + 3d e f)%%HF0  + (a e + (- 4a c - 2b )d)f + c d e
+--R             /
+--R                  2 2      2
+--R                4d f  - d e f
+--R         + 
+--R           - %%HF1 - %%HF0
+--R      *
+--R         log
+--R                              3 3           2          2  4  4
+--R                          (64a d e + (- 128a c + 256a b )d )f
+--R                        + 
+--R                                   3 2 3       2          2  3 2        2 4
+--R                              - 32a d e  + (64a c - 128a b )d e  - 64a c d e
+--R                            + 
+--R                                  3 5
+--R                              128c d
+--R                         *
+--R                             3
+--R                            f
+--R                        + 
+--R                                3   5        2         2  2 4        2 3 3
+--R                              4a d e  + (- 8a c + 16a b )d e  + 32a c d e
+--R                            + 
+--R                                   3 4 2
+--R                              - 64c d e
+--R                         *
+--R                             2
+--R                            f
+--R                        + 
+--R                                 2 2 5     3 3 4
+--R                          (- 4a c d e  + 8c d e )f
+--R                     *
+--R                        %%HF0
+--R                    + 
+--R                           3   3 4
+--R                      - 32a b d f
+--R                    + 
+--R                           2           3  3              2      3   4  3
+--R                      ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                    + 
+--R                            3     4         2          3  2 3      3   3 2
+--R                          2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                        + 
+--R                               3 4
+--R                          32b c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 4       3 3 3
+--R                      (6a b c d e  - 8b c d e )f
+--R                 *
+--R                    %%HF1
+--R                + 
+--R                           3   3 4
+--R                      - 32a b d f
+--R                    + 
+--R                           2           3  3              2      3   4  3
+--R                      ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                    + 
+--R                            3     4         2          3  2 3      3   3 2
+--R                          2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                        + 
+--R                               3 4
+--R                          32b c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 4       3 3 3
+--R                      (6a b c d e  - 8b c d e )f
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                    5 2 4
+--R                  8a d f
+--R                + 
+--R                       5   2         4      3 2  2        2 2         4  3  3
+--R                  (- 2a d e  + (- 12a c - 4a b )d e + (24a b c - 16a b )d )f
+--R                + 
+--R                         4     3 2    3      3 2     2 2        4  2 2
+--R                      (3a c + a b )d e  + (4a c  - 6a b c + 4a b )d e
+--R                    + 
+--R                         2 3        2 2  3           4     2 3  4
+--R                      (8a c  - 12a b c )d e + (- 8a c  + 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                         3 2   4        2 3       2 2  2 3
+--R                      - a c d e  + (- 2a c  + 3a b c )d e
+--R                    + 
+--R                             4     2 3  3 2     5 4
+--R                      (- 2a c  - 2b c )d e  + 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                     4 2 4    5 3 3
+--R                  a c d e  - c d e
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12d f  + 3d e f)%%HF1  + (- 8d f  + 2d e f)%%HF0 %%HF1
+--R                     + 
+--R                             2 2       2       2     2                2
+--R                       (- 12d f  + 3d e f)%%HF0  + (a e + (- 4a c - 2b )d)f
+--R                     + 
+--R                        2
+--R                       c d e
+--R                  /
+--R                       2 2      2
+--R                     4d f  - d e f
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64a d e + (- 128a c + 256a b )d )f
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32a d e  + (64a c - 128a b )d e  - 64a c d e
+--R                          + 
+--R                                3 5
+--R                            128c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4a d e  + (- 8a c + 16a b )d e  + 32a c d e
+--R                          + 
+--R                                 3 4 2
+--R                            - 64c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4a c d e  + 8c d e )f
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                       3   3 4
+--R                  - 32a b d f
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                      + 
+--R                             3 4
+--R                        32b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6a b c d e  - 8b c d e )f
+--R             *
+--R                     2
+--R                %%HF1
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64a d e + (- 128a c + 256a b )d )f
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32a d e  + (64a c - 128a b )d e  - 64a c d e
+--R                          + 
+--R                                3 5
+--R                            128c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4a d e  + (- 8a c + 16a b )d e  + 32a c d e
+--R                          + 
+--R                                 3 4 2
+--R                            - 64c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4a c d e  + 8c d e )f
+--R                 *
+--R                         2
+--R                    %%HF0
+--R                + 
+--R                      5 2 4
+--R                  - 8a d f
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2a d e  + (12a c + 4a b )d e + (- 24a b c + 16a b )d )f
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3a c - a b )d e  + (- 4a c  + 6a b c - 4a b )d e
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8a c  + 12a b c )d e + (8a c  - 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      a c d e  + (2a c  - 3a b c )d e  + (2a c  + 2b c )d e
+--R                    + 
+--R                          5 4
+--R                      - 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - a c d e  + c d e
+--R             *
+--R                %%HF1
+--R            + 
+--R                       3   3 4
+--R                  - 32a b d f
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                      + 
+--R                             3 4
+--R                        32b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6a b c d e  - 8b c d e )f
+--R             *
+--R                     2
+--R                %%HF0
+--R            + 
+--R                      5 2 4
+--R                  - 8a d f
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2a d e  + (12a c + 4a b )d e + (- 24a b c + 16a b )d )f
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3a c - a b )d e  + (- 4a c  + 6a b c - 4a b )d e
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8a c  + 12a b c )d e + (8a c  - 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      a c d e  + (2a c  - 3a b c )d e  + (2a c  + 2b c )d e
+--R                    + 
+--R                          5 4
+--R                      - 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - a c d e  + c d e
+--R             *
+--R                %%HF0
+--R            + 
+--R                    6   4
+--R                  4a d f
+--R                + 
+--R                         6 2        5      4 2
+--R                      - a e  + (- 4a c - 8a b )d e
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4a c  + 32a b c - 16a b )d
+--R                 *
+--R                     3
+--R                    f
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      a c e  + (a c  + 8a b c)d e
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8a c  - 48a b c  + 16a b c)d e
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4a c  + 32a b c  - 16b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2a c d e  + (a c  + 8a b c )d e  + (- 4a c  - 8b c )d e
+--R                    + 
+--R                        6 4
+--R                      4c d
+--R                 *
+--R                    f
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  a c d e  - c d e
+--R             *
+--R                x
+--R            + 
+--R                 5              4        3 3  2  3
+--R              (4a b d e + (- 12a b c + 4a b )d )f
+--R            + 
+--R                       4       3 3    2       3   2       5  2
+--R                  (- 7a b c - a b )d e  + (28a b c  - 4a b )d e
+--R                + 
+--R                        2   3       3 2     5   3
+--R                  (- 16a b c  - 4a b c  + 8b c)d
+--R             *
+--R                 2
+--R                f
+--R            + 
+--R                 3   2   3         2   3      3 2  2 2          4 3        5 4
+--R              (3a b c d e  + (- 16a b c  + a b c )d e  + 16a b c d e - 4b c d )f
+--R            + 
+--R                   4 2 3      5 3 2
+--R              a b c d e  - b c d e
+--R     + 
+--R           -
+--R              ROOT
+--R                           2 2       2       2        2 2       2
+--R                     (- 12d f  + 3d e f)%%HF1  + (- 8d f  + 2d e f)%%HF0 %%HF1
+--R                   + 
+--R                         2 2       2       2     2                2        2
+--R                   (- 12d f  + 3d e f)%%HF0  + (a e + (- 4a c - 2b )d)f + c d e
+--R                /
+--R                     2 2      2
+--R                   4d f  - d e f
+--R         + 
+--R           - %%HF1 - %%HF0
+--R      *
+--R         log
+--R                                3 3         2          2  4  4
+--R                          (- 64a d e + (128a c - 256a b )d )f
+--R                        + 
+--R                                 3 2 3         2          2  3 2        2 4
+--R                              32a d e  + (- 64a c + 128a b )d e  + 64a c d e
+--R                            + 
+--R                                    3 5
+--R                              - 128c d
+--R                         *
+--R                             3
+--R                            f
+--R                        + 
+--R                                  3   5      2         2  2 4        2 3 3
+--R                              - 4a d e  + (8a c - 16a b )d e  - 32a c d e
+--R                            + 
+--R                                 3 4 2
+--R                              64c d e
+--R                         *
+--R                             2
+--R                            f
+--R                        + 
+--R                               2 2 5     3 3 4
+--R                          (4a c d e  - 8c d e )f
+--R                     *
+--R                        %%HF0
+--R                    + 
+--R                         3   3 4
+--R                      32a b d f
+--R                    + 
+--R                             2           3  3            2      3   4  3
+--R                      ((- 96a b c + 32a b )d e + (96a b c  - 64b c)d )f
+--R                    + 
+--R                              3     4       2          3  2 3      3   3 2
+--R                          - 2a b d e  + (24a b c - 8a b )d e  + 16b c d e
+--R                        + 
+--R                                 3 4
+--R                          - 32b c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                               2 2 4       3 3 3
+--R                      (- 6a b c d e  + 8b c d e )f
+--R                 *
+--R                    %%HF1
+--R                + 
+--R                         3   3 4
+--R                      32a b d f
+--R                    + 
+--R                             2           3  3            2      3   4  3
+--R                      ((- 96a b c + 32a b )d e + (96a b c  - 64b c)d )f
+--R                    + 
+--R                              3     4       2          3  2 3      3   3 2
+--R                          - 2a b d e  + (24a b c - 8a b )d e  + 16b c d e
+--R                        + 
+--R                                 3 4
+--R                          - 32b c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                               2 2 4       3 3 3
+--R                      (- 6a b c d e  + 8b c d e )f
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                      5 2 4
+--R                  - 8a d f
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2a d e  + (12a c + 4a b )d e + (- 24a b c + 16a b )d )f
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3a c - a b )d e  + (- 4a c  + 6a b c - 4a b )d e
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8a c  + 12a b c )d e + (8a c  - 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      a c d e  + (2a c  - 3a b c )d e  + (2a c  + 2b c )d e
+--R                    + 
+--R                          5 4
+--R                      - 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - a c d e  + c d e
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12d f  + 3d e f)%%HF1  + (- 8d f  + 2d e f)%%HF0 %%HF1
+--R                     + 
+--R                             2 2       2       2     2                2
+--R                       (- 12d f  + 3d e f)%%HF0  + (a e + (- 4a c - 2b )d)f
+--R                     + 
+--R                        2
+--R                       c d e
+--R                  /
+--R                       2 2      2
+--R                     4d f  - d e f
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64a d e + (- 128a c + 256a b )d )f
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32a d e  + (64a c - 128a b )d e  - 64a c d e
+--R                          + 
+--R                                3 5
+--R                            128c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4a d e  + (- 8a c + 16a b )d e  + 32a c d e
+--R                          + 
+--R                                 3 4 2
+--R                            - 64c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4a c d e  + 8c d e )f
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                       3   3 4
+--R                  - 32a b d f
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                      + 
+--R                             3 4
+--R                        32b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6a b c d e  - 8b c d e )f
+--R             *
+--R                     2
+--R                %%HF1
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64a d e + (- 128a c + 256a b )d )f
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32a d e  + (64a c - 128a b )d e  - 64a c d e
+--R                          + 
+--R                                3 5
+--R                            128c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4a d e  + (- 8a c + 16a b )d e  + 32a c d e
+--R                          + 
+--R                                 3 4 2
+--R                            - 64c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4a c d e  + 8c d e )f
+--R                 *
+--R                         2
+--R                    %%HF0
+--R                + 
+--R                      5 2 4
+--R                  - 8a d f
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2a d e  + (12a c + 4a b )d e + (- 24a b c + 16a b )d )f
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3a c - a b )d e  + (- 4a c  + 6a b c - 4a b )d e
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8a c  + 12a b c )d e + (8a c  - 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      a c d e  + (2a c  - 3a b c )d e  + (2a c  + 2b c )d e
+--R                    + 
+--R                          5 4
+--R                      - 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - a c d e  + c d e
+--R             *
+--R                %%HF1
+--R            + 
+--R                       3   3 4
+--R                  - 32a b d f
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                      + 
+--R                             3 4
+--R                        32b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6a b c d e  - 8b c d e )f
+--R             *
+--R                     2
+--R                %%HF0
+--R            + 
+--R                      5 2 4
+--R                  - 8a d f
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2a d e  + (12a c + 4a b )d e + (- 24a b c + 16a b )d )f
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3a c - a b )d e  + (- 4a c  + 6a b c - 4a b )d e
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8a c  + 12a b c )d e + (8a c  - 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      a c d e  + (2a c  - 3a b c )d e  + (2a c  + 2b c )d e
+--R                    + 
+--R                          5 4
+--R                      - 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - a c d e  + c d e
+--R             *
+--R                %%HF0
+--R            + 
+--R                    6   4
+--R                  4a d f
+--R                + 
+--R                         6 2        5      4 2
+--R                      - a e  + (- 4a c - 8a b )d e
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4a c  + 32a b c - 16a b )d
+--R                 *
+--R                     3
+--R                    f
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      a c e  + (a c  + 8a b c)d e
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8a c  - 48a b c  + 16a b c)d e
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4a c  + 32a b c  - 16b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2a c d e  + (a c  + 8a b c )d e  + (- 4a c  - 8b c )d e
+--R                    + 
+--R                        6 4
+--R                      4c d
+--R                 *
+--R                    f
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  a c d e  - c d e
+--R             *
+--R                x
+--R            + 
+--R                 5              4        3 3  2  3
+--R              (4a b d e + (- 12a b c + 4a b )d )f
+--R            + 
+--R                       4       3 3    2       3   2       5  2
+--R                  (- 7a b c - a b )d e  + (28a b c  - 4a b )d e
+--R                + 
+--R                        2   3       3 2     5   3
+--R                  (- 16a b c  - 4a b c  + 8b c)d
+--R             *
+--R                 2
+--R                f
+--R            + 
+--R                 3   2   3         2   3      3 2  2 2          4 3        5 4
+--R              (3a b c d e  + (- 16a b c  + a b c )d e  + 16a b c d e - 4b c d )f
+--R            + 
+--R                   4 2 3      5 3 2
+--R              a b c d e  - b c d e
+--R     + 
+--R         2%%HF1
+--R      *
+--R         log
+--R                             3 3         2          2  4  4
+--R                      (- 128a d e + (256a c - 512a b )d )f
+--R                    + 
+--R                             3 2 3          2          2  3 2         2 4
+--R                          64a d e  + (- 128a c + 256a b )d e  + 128a c d e
+--R                        + 
+--R                                3 5
+--R                          - 256c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5       2         2  2 4        2 3 3
+--R                          - 8a d e  + (16a c - 32a b )d e  - 64a c d e
+--R                        + 
+--R                              3 4 2
+--R                          128c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                           2 2 5      3 3 4
+--R                      (8a c d e  - 16c d e )f
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                     3   3 4
+--R                  64a b d f
+--R                + 
+--R                          2           3  3             2       3   4  3
+--R                  ((- 192a b c + 64a b )d e + (192a b c  - 128b c)d )f
+--R                + 
+--R                          3     4       2           3  2 3      3   3 2
+--R                      - 4a b d e  + (48a b c - 16a b )d e  + 32b c d e
+--R                    + 
+--R                             3 4
+--R                      - 64b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                            2 2 4        3 3 3
+--R                  (- 12a b c d e  + 16b c d e )f
+--R             *
+--R                     2
+--R                %%HF1
+--R            + 
+--R                             3 3         2          2  4  4
+--R                      (- 128a d e + (256a c - 512a b )d )f
+--R                    + 
+--R                             3 2 3          2          2  3 2         2 4
+--R                          64a d e  + (- 128a c + 256a b )d e  + 128a c d e
+--R                        + 
+--R                                3 5
+--R                          - 256c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5       2         2  2 4        2 3 3
+--R                          - 8a d e  + (16a c - 32a b )d e  - 64a c d e
+--R                        + 
+--R                              3 4 2
+--R                          128c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                           2 2 5      3 3 4
+--R                      (8a c d e  - 16c d e )f
+--R                 *
+--R                         2
+--R                    %%HF0
+--R                + 
+--R                     5 2 4
+--R                  16a d f
+--R                + 
+--R                       5   2         4      3 2  2        2 2         4  3  3
+--R                  (- 4a d e  + (- 24a c - 8a b )d e + (48a b c - 32a b )d )f
+--R                + 
+--R                         4      3 2    3      3 2      2 2        4  2 2
+--R                      (6a c + 2a b )d e  + (8a c  - 12a b c + 8a b )d e
+--R                    + 
+--R                          2 3        2 2  3            4      2 3  4
+--R                      (16a c  - 24a b c )d e + (- 16a c  + 16b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3 2   4        2 3       2 2  2 3
+--R                      - 2a c d e  + (- 4a c  + 6a b c )d e
+--R                    + 
+--R                             4     2 3  3 2     5 4
+--R                      (- 4a c  - 4b c )d e  + 8c d e
+--R                 *
+--R                    f
+--R                + 
+--R                      4 2 4     5 3 3
+--R                  2a c d e  - 2c d e
+--R             *
+--R                %%HF1
+--R            + 
+--R                         3 3         2          2  4  4
+--R                  (- 128a d e + (256a c - 512a b )d )f
+--R                + 
+--R                      3 2 3          2          2  3 2         2 4        3 5  3
+--R                  (64a d e  + (- 128a c + 256a b )d e  + 128a c d e - 256c d )f
+--R                + 
+--R                       3   5       2         2  2 4        2 3 3       3 4 2  2
+--R                  (- 8a d e  + (16a c - 32a b )d e  - 64a c d e  + 128c d e )f
+--R                + 
+--R                       2 2 5      3 3 4
+--R                  (8a c d e  - 16c d e )f
+--R             *
+--R                     3
+--R                %%HF0
+--R            + 
+--R                        5   2         4       3 2  2
+--R                      8a d e  + (- 48a c + 16a b )d e
+--R                    + 
+--R                          3 2      2 2         4  3
+--R                      (64a c  - 96a b c - 64a b )d
+--R                 *
+--R                     3
+--R                    f
+--R                + 
+--R                          5 4       4      3 2    3
+--R                      - 2a e  + (12a c - 4a b )d e
+--R                    + 
+--R                            3 2      2 2         4  2 2       2 3        2 2  3
+--R                      (- 16a c  + 24a b c + 16a b )d e  + (32a c  + 48a b c )d e
+--R                    + 
+--R                              4      2 3  4
+--R                      (- 64a c  - 32b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                        2 3        2 2  2 3        4     2 3  3 2      5 4
+--R                  ((- 8a c  - 12a b c )d e  + (8a c  + 8b c )d e  + 16c d e)f
+--R                + 
+--R                      4 2 4     5 3 3
+--R                  2a c d e  - 4c d e
+--R             *
+--R                %%HF0
+--R            + 
+--R                    6   4
+--R                  4a d f
+--R                + 
+--R                         6 2        5      4 2
+--R                      - a e  + (- 4a c - 8a b )d e
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4a c  + 32a b c - 16a b )d
+--R                 *
+--R                     3
+--R                    f
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      a c e  + (a c  + 8a b c)d e
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8a c  - 48a b c  + 16a b c)d e
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4a c  + 32a b c  - 16b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2a c d e  + (a c  + 8a b c )d e  + (- 4a c  - 8b c )d e
+--R                    + 
+--R                        6 4
+--R                      4c d
+--R                 *
+--R                    f
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  a c d e  - c d e
+--R             *
+--R                x
+--R            + 
+--R                 4         3 3  2 3
+--R              (4a b c + 12a b )d f
+--R            + 
+--R                     5   3      4        3 3    2         3   2       5  2
+--R                  - a b e  + (9a b c - 3a b )d e  + (- 36a b c  + 4a b )d e
+--R                + 
+--R                      2   3        3 2     5   3
+--R                  (32a b c  - 12a b c  - 8b c)d
+--R             *
+--R                 2
+--R                f
+--R            + 
+--R                  3   2   3       2   3       3 2  2 2          4 3        5 4
+--R              (- a b c d e  + (12a b c  + 3a b c )d e  - 12a b c d e - 4b c d )f
+--R            + 
+--R                      4 2 3       5 3 2
+--R              - 2a b c d e  + 3b c d e
+--R     + 
+--R         2%%HF0
+--R      *
+--R         log
+--R                       3 3           2          2  4  4
+--R                  (128a d e + (- 256a c + 512a b )d )f
+--R                + 
+--R                        3 2 3        2          2  3 2         2 4        3 5  3
+--R                  (- 64a d e  + (128a c - 256a b )d e  - 128a c d e + 256c d )f
+--R                + 
+--R                     3   5         2         2  2 4        2 3 3       3 4 2  2
+--R                  (8a d e  + (- 16a c + 32a b )d e  + 64a c d e  - 128c d e )f
+--R                + 
+--R                         2 2 5      3 3 4
+--R                  (- 8a c d e  + 16c d e )f
+--R             *
+--R                     3
+--R                %%HF0
+--R            + 
+--R                     3   3 4
+--R                  64a b d f
+--R                + 
+--R                          2           3  3             2       3   4  3
+--R                  ((- 192a b c + 64a b )d e + (192a b c  - 128b c)d )f
+--R                + 
+--R                          3     4       2           3  2 3      3   3 2
+--R                      - 4a b d e  + (48a b c - 16a b )d e  + 32b c d e
+--R                    + 
+--R                             3 4
+--R                      - 64b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                            2 2 4        3 3 3
+--R                  (- 12a b c d e  + 16b c d e )f
+--R             *
+--R                     2
+--R                %%HF0
+--R            + 
+--R                     5 2 4
+--R                  16a d f
+--R                + 
+--R                           5   2       4       3 2  2
+--R                      - 12a d e  + (24a c - 24a b )d e
+--R                    + 
+--R                            3 2       2 2         4  3
+--R                      (- 64a c  + 144a b c + 32a b )d
+--R                 *
+--R                     3
+--R                    f
+--R                + 
+--R                        5 4        4      3 2    3
+--R                      2a e  + (- 6a c + 6a b )d e
+--R                    + 
+--R                          3 2      2 2        4  2 2         2 3        2 2  3
+--R                      (24a c  - 36a b c - 8a b )d e  + (- 16a c  - 72a b c )d e
+--R                    + 
+--R                            4      2 3  4
+--R                      (48a c  + 48b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3 2   4      2 3        2 2  2 3
+--R                      - 2a c d e  + (4a c  + 18a b c )d e
+--R                    + 
+--R                              4      2 3  3 2     5 4
+--R                      (- 12a c  - 12b c )d e  - 8c d e
+--R                 *
+--R                    f
+--R                + 
+--R                    5 3 3
+--R                  2c d e
+--R             *
+--R                %%HF0
+--R            + 
+--R                    6   4
+--R                  4a d f
+--R                + 
+--R                         6 2        5      4 2
+--R                      - a e  + (- 4a c - 8a b )d e
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4a c  + 32a b c - 16a b )d
+--R                 *
+--R                     3
+--R                    f
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      a c e  + (a c  + 8a b c)d e
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8a c  - 48a b c  + 16a b c)d e
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4a c  + 32a b c  - 16b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2a c d e  + (a c  + 8a b c )d e  + (- 4a c  - 8b c )d e
+--R                    + 
+--R                        6 4
+--R                      4c d
+--R                 *
+--R                    f
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  a c d e  - c d e
+--R             *
+--R                x
+--R            + 
+--R                   5            4         3 3  2  3
+--R              (- 8a b d e + (20a b c - 20a b )d )f
+--R            + 
+--R                   5   3      4        3 3    2         3   2       5  2
+--R                  a b e  + (5a b c + 5a b )d e  + (- 20a b c  + 4a b )d e
+--R                + 
+--R                        3 2     5   3
+--R                  (20a b c  - 8b c)d
+--R             *
+--R                 2
+--R                f
+--R            + 
+--R                      3   2   3       2   3       3 2  2 2          4 3
+--R                  - 5a b c d e  + (20a b c  - 5a b c )d e  - 20a b c d e
+--R                + 
+--R                       5 4
+--R                  12b c d
+--R             *
+--R                f
+--R            + 
+--R                   5 3 2
+--R              - b c d e
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 876
+
+--S 877 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    +--------------------+ +------------------+
+--R                  +-----------+     |   +-----------+      | +-----------+
+--R              +-+ |          2  +-+ |   |          2       | |          2
+--R             \|2 \|- 4d f + e  \|f \|- \|- 4d f + e   + e \|\|- 4d f + e   + e
+--R          *
+--R             ROOT
+--R                          2 2       2       2        2 2       2
+--R                    (- 12d f  + 3d e f)%%HF1  + (- 8d f  + 2d e f)%%HF0 %%HF1
+--R                  + 
+--R                        2 2       2       2     2                2        2
+--R                  (- 12d f  + 3d e f)%%HF0  + (a e + (- 4a c - 2b )d)f + c d e
+--R               /
+--R                    2 2      2
+--R                  4d f  - d e f
+--R         + 
+--R           -
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R                 +-+ |          2  +-+ |   |          2
+--R                \|2 \|- 4d f + e  \|f \|- \|- 4d f + e   + e
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4d f + e   + e %%HF1
+--R         + 
+--R           -
+--R                                            +--------------------+
+--R                     +-----------+          |   +-----------+
+--R                 +-+ |          2  +-+      |   |          2
+--R                \|2 \|- 4d f + e  \|f %%HF0\|- \|- 4d f + e   + e
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4d f + e   + e
+--R      *
+--R         log
+--R                              3 3           2          2  4  4
+--R                          (64a d e + (- 128a c + 256a b )d )f
+--R                        + 
+--R                                   3 2 3       2          2  3 2        2 4
+--R                              - 32a d e  + (64a c - 128a b )d e  - 64a c d e
+--R                            + 
+--R                                  3 5
+--R                              128c d
+--R                         *
+--R                             3
+--R                            f
+--R                        + 
+--R                                3   5        2         2  2 4        2 3 3
+--R                              4a d e  + (- 8a c + 16a b )d e  + 32a c d e
+--R                            + 
+--R                                   3 4 2
+--R                              - 64c d e
+--R                         *
+--R                             2
+--R                            f
+--R                        + 
+--R                                 2 2 5     3 3 4
+--R                          (- 4a c d e  + 8c d e )f
+--R                     *
+--R                        %%HF0
+--R                    + 
+--R                           3   3 4
+--R                      - 32a b d f
+--R                    + 
+--R                           2           3  3              2      3   4  3
+--R                      ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                    + 
+--R                            3     4         2          3  2 3      3   3 2
+--R                          2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                        + 
+--R                               3 4
+--R                          32b c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 4       3 3 3
+--R                      (6a b c d e  - 8b c d e )f
+--R                 *
+--R                    %%HF1
+--R                + 
+--R                           3   3 4
+--R                      - 32a b d f
+--R                    + 
+--R                           2           3  3              2      3   4  3
+--R                      ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                    + 
+--R                            3     4         2          3  2 3      3   3 2
+--R                          2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                        + 
+--R                               3 4
+--R                          32b c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 4       3 3 3
+--R                      (6a b c d e  - 8b c d e )f
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                    5 2 4
+--R                  8a d f
+--R                + 
+--R                       5   2         4      3 2  2        2 2         4  3  3
+--R                  (- 2a d e  + (- 12a c - 4a b )d e + (24a b c - 16a b )d )f
+--R                + 
+--R                         4     3 2    3      3 2     2 2        4  2 2
+--R                      (3a c + a b )d e  + (4a c  - 6a b c + 4a b )d e
+--R                    + 
+--R                         2 3        2 2  3           4     2 3  4
+--R                      (8a c  - 12a b c )d e + (- 8a c  + 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                         3 2   4        2 3       2 2  2 3
+--R                      - a c d e  + (- 2a c  + 3a b c )d e
+--R                    + 
+--R                             4     2 3  3 2     5 4
+--R                      (- 2a c  - 2b c )d e  + 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                     4 2 4    5 3 3
+--R                  a c d e  - c d e
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12d f  + 3d e f)%%HF1  + (- 8d f  + 2d e f)%%HF0 %%HF1
+--R                     + 
+--R                             2 2       2       2     2                2
+--R                       (- 12d f  + 3d e f)%%HF0  + (a e + (- 4a c - 2b )d)f
+--R                     + 
+--R                        2
+--R                       c d e
+--R                  /
+--R                       2 2      2
+--R                     4d f  - d e f
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64a d e + (- 128a c + 256a b )d )f
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32a d e  + (64a c - 128a b )d e  - 64a c d e
+--R                          + 
+--R                                3 5
+--R                            128c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4a d e  + (- 8a c + 16a b )d e  + 32a c d e
+--R                          + 
+--R                                 3 4 2
+--R                            - 64c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4a c d e  + 8c d e )f
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                       3   3 4
+--R                  - 32a b d f
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                      + 
+--R                             3 4
+--R                        32b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6a b c d e  - 8b c d e )f
+--R             *
+--R                     2
+--R                %%HF1
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64a d e + (- 128a c + 256a b )d )f
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32a d e  + (64a c - 128a b )d e  - 64a c d e
+--R                          + 
+--R                                3 5
+--R                            128c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4a d e  + (- 8a c + 16a b )d e  + 32a c d e
+--R                          + 
+--R                                 3 4 2
+--R                            - 64c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4a c d e  + 8c d e )f
+--R                 *
+--R                         2
+--R                    %%HF0
+--R                + 
+--R                      5 2 4
+--R                  - 8a d f
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2a d e  + (12a c + 4a b )d e + (- 24a b c + 16a b )d )f
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3a c - a b )d e  + (- 4a c  + 6a b c - 4a b )d e
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8a c  + 12a b c )d e + (8a c  - 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      a c d e  + (2a c  - 3a b c )d e  + (2a c  + 2b c )d e
+--R                    + 
+--R                          5 4
+--R                      - 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - a c d e  + c d e
+--R             *
+--R                %%HF1
+--R            + 
+--R                       3   3 4
+--R                  - 32a b d f
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                      + 
+--R                             3 4
+--R                        32b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6a b c d e  - 8b c d e )f
+--R             *
+--R                     2
+--R                %%HF0
+--R            + 
+--R                      5 2 4
+--R                  - 8a d f
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2a d e  + (12a c + 4a b )d e + (- 24a b c + 16a b )d )f
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3a c - a b )d e  + (- 4a c  + 6a b c - 4a b )d e
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8a c  + 12a b c )d e + (8a c  - 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      a c d e  + (2a c  - 3a b c )d e  + (2a c  + 2b c )d e
+--R                    + 
+--R                          5 4
+--R                      - 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - a c d e  + c d e
+--R             *
+--R                %%HF0
+--R            + 
+--R                    6   4
+--R                  4a d f
+--R                + 
+--R                         6 2        5      4 2
+--R                      - a e  + (- 4a c - 8a b )d e
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4a c  + 32a b c - 16a b )d
+--R                 *
+--R                     3
+--R                    f
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      a c e  + (a c  + 8a b c)d e
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8a c  - 48a b c  + 16a b c)d e
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4a c  + 32a b c  - 16b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2a c d e  + (a c  + 8a b c )d e  + (- 4a c  - 8b c )d e
+--R                    + 
+--R                        6 4
+--R                      4c d
+--R                 *
+--R                    f
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  a c d e  - c d e
+--R             *
+--R                x
+--R            + 
+--R                 5              4        3 3  2  3
+--R              (4a b d e + (- 12a b c + 4a b )d )f
+--R            + 
+--R                       4       3 3    2       3   2       5  2
+--R                  (- 7a b c - a b )d e  + (28a b c  - 4a b )d e
+--R                + 
+--R                        2   3       3 2     5   3
+--R                  (- 16a b c  - 4a b c  + 8b c)d
+--R             *
+--R                 2
+--R                f
+--R            + 
+--R                 3   2   3         2   3      3 2  2 2          4 3        5 4
+--R              (3a b c d e  + (- 16a b c  + a b c )d e  + 16a b c d e - 4b c d )f
+--R            + 
+--R                   4 2 3      5 3 2
+--R              a b c d e  - b c d e
+--R     + 
+--R           -
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R                 +-+ |          2  +-+ |   |          2
+--R                \|2 \|- 4d f + e  \|f \|- \|- 4d f + e   + e
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4d f + e   + e
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12d f  + 3d e f)%%HF1  + (- 8d f  + 2d e f)%%HF0 %%HF1
+--R                     + 
+--R                             2 2       2       2     2                2
+--R                       (- 12d f  + 3d e f)%%HF0  + (a e + (- 4a c - 2b )d)f
+--R                     + 
+--R                        2
+--R                       c d e
+--R                  /
+--R                       2 2      2
+--R                     4d f  - d e f
+--R         + 
+--R           -
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R                 +-+ |          2  +-+ |   |          2
+--R                \|2 \|- 4d f + e  \|f \|- \|- 4d f + e   + e
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4d f + e   + e %%HF1
+--R         + 
+--R           -
+--R                                            +--------------------+
+--R                     +-----------+          |   +-----------+
+--R                 +-+ |          2  +-+      |   |          2
+--R                \|2 \|- 4d f + e  \|f %%HF0\|- \|- 4d f + e   + e
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4d f + e   + e
+--R      *
+--R         log
+--R                                3 3         2          2  4  4
+--R                          (- 64a d e + (128a c - 256a b )d )f
+--R                        + 
+--R                                 3 2 3         2          2  3 2        2 4
+--R                              32a d e  + (- 64a c + 128a b )d e  + 64a c d e
+--R                            + 
+--R                                    3 5
+--R                              - 128c d
+--R                         *
+--R                             3
+--R                            f
+--R                        + 
+--R                                  3   5      2         2  2 4        2 3 3
+--R                              - 4a d e  + (8a c - 16a b )d e  - 32a c d e
+--R                            + 
+--R                                 3 4 2
+--R                              64c d e
+--R                         *
+--R                             2
+--R                            f
+--R                        + 
+--R                               2 2 5     3 3 4
+--R                          (4a c d e  - 8c d e )f
+--R                     *
+--R                        %%HF0
+--R                    + 
+--R                         3   3 4
+--R                      32a b d f
+--R                    + 
+--R                             2           3  3            2      3   4  3
+--R                      ((- 96a b c + 32a b )d e + (96a b c  - 64b c)d )f
+--R                    + 
+--R                              3     4       2          3  2 3      3   3 2
+--R                          - 2a b d e  + (24a b c - 8a b )d e  + 16b c d e
+--R                        + 
+--R                                 3 4
+--R                          - 32b c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                               2 2 4       3 3 3
+--R                      (- 6a b c d e  + 8b c d e )f
+--R                 *
+--R                    %%HF1
+--R                + 
+--R                         3   3 4
+--R                      32a b d f
+--R                    + 
+--R                             2           3  3            2      3   4  3
+--R                      ((- 96a b c + 32a b )d e + (96a b c  - 64b c)d )f
+--R                    + 
+--R                              3     4       2          3  2 3      3   3 2
+--R                          - 2a b d e  + (24a b c - 8a b )d e  + 16b c d e
+--R                        + 
+--R                                 3 4
+--R                          - 32b c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                               2 2 4       3 3 3
+--R                      (- 6a b c d e  + 8b c d e )f
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                      5 2 4
+--R                  - 8a d f
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2a d e  + (12a c + 4a b )d e + (- 24a b c + 16a b )d )f
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3a c - a b )d e  + (- 4a c  + 6a b c - 4a b )d e
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8a c  + 12a b c )d e + (8a c  - 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      a c d e  + (2a c  - 3a b c )d e  + (2a c  + 2b c )d e
+--R                    + 
+--R                          5 4
+--R                      - 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - a c d e  + c d e
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12d f  + 3d e f)%%HF1  + (- 8d f  + 2d e f)%%HF0 %%HF1
+--R                     + 
+--R                             2 2       2       2     2                2
+--R                       (- 12d f  + 3d e f)%%HF0  + (a e + (- 4a c - 2b )d)f
+--R                     + 
+--R                        2
+--R                       c d e
+--R                  /
+--R                       2 2      2
+--R                     4d f  - d e f
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64a d e + (- 128a c + 256a b )d )f
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32a d e  + (64a c - 128a b )d e  - 64a c d e
+--R                          + 
+--R                                3 5
+--R                            128c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4a d e  + (- 8a c + 16a b )d e  + 32a c d e
+--R                          + 
+--R                                 3 4 2
+--R                            - 64c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4a c d e  + 8c d e )f
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                       3   3 4
+--R                  - 32a b d f
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                      + 
+--R                             3 4
+--R                        32b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6a b c d e  - 8b c d e )f
+--R             *
+--R                     2
+--R                %%HF1
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64a d e + (- 128a c + 256a b )d )f
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32a d e  + (64a c - 128a b )d e  - 64a c d e
+--R                          + 
+--R                                3 5
+--R                            128c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4a d e  + (- 8a c + 16a b )d e  + 32a c d e
+--R                          + 
+--R                                 3 4 2
+--R                            - 64c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4a c d e  + 8c d e )f
+--R                 *
+--R                         2
+--R                    %%HF0
+--R                + 
+--R                      5 2 4
+--R                  - 8a d f
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2a d e  + (12a c + 4a b )d e + (- 24a b c + 16a b )d )f
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3a c - a b )d e  + (- 4a c  + 6a b c - 4a b )d e
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8a c  + 12a b c )d e + (8a c  - 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      a c d e  + (2a c  - 3a b c )d e  + (2a c  + 2b c )d e
+--R                    + 
+--R                          5 4
+--R                      - 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - a c d e  + c d e
+--R             *
+--R                %%HF1
+--R            + 
+--R                       3   3 4
+--R                  - 32a b d f
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96a b c - 32a b )d e + (- 96a b c  + 64b c)d )f
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2a b d e  + (- 24a b c + 8a b )d e  - 16b c d e
+--R                      + 
+--R                             3 4
+--R                        32b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6a b c d e  - 8b c d e )f
+--R             *
+--R                     2
+--R                %%HF0
+--R            + 
+--R                      5 2 4
+--R                  - 8a d f
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2a d e  + (12a c + 4a b )d e + (- 24a b c + 16a b )d )f
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3a c - a b )d e  + (- 4a c  + 6a b c - 4a b )d e
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8a c  + 12a b c )d e + (8a c  - 8b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      a c d e  + (2a c  - 3a b c )d e  + (2a c  + 2b c )d e
+--R                    + 
+--R                          5 4
+--R                      - 4c d e
+--R                 *
+--R                    f
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - a c d e  + c d e
+--R             *
+--R                %%HF0
+--R            + 
+--R                    6   4
+--R                  4a d f
+--R                + 
+--R                         6 2        5      4 2
+--R                      - a e  + (- 4a c - 8a b )d e
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4a c  + 32a b c - 16a b )d
+--R                 *
+--R                     3
+--R                    f
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      a c e  + (a c  + 8a b c)d e
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8a c  - 48a b c  + 16a b c)d e
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4a c  + 32a b c  - 16b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2a c d e  + (a c  + 8a b c )d e  + (- 4a c  - 8b c )d e
+--R                    + 
+--R                        6 4
+--R                      4c d
+--R                 *
+--R                    f
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  a c d e  - c d e
+--R             *
+--R                x
+--R            + 
+--R                 5              4        3 3  2  3
+--R              (4a b d e + (- 12a b c + 4a b )d )f
+--R            + 
+--R                       4       3 3    2       3   2       5  2
+--R                  (- 7a b c - a b )d e  + (28a b c  - 4a b )d e
+--R                + 
+--R                        2   3       3 2     5   3
+--R                  (- 16a b c  - 4a b c  + 8b c)d
+--R             *
+--R                 2
+--R                f
+--R            + 
+--R                 3   2   3         2   3      3 2  2 2          4 3        5 4
+--R              (3a b c d e  + (- 16a b c  + a b c )d e  + 16a b c d e - 4b c d )f
+--R            + 
+--R                   4 2 3      5 3 2
+--R              a b c d e  - b c d e
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R         2\|2 \|- 4d f + e  \|f \|- \|- 4d f + e   + e \|\|- 4d f + e   + e
+--R      *
+--R         %%HF1
+--R      *
+--R         log
+--R                             3 3         2          2  4  4
+--R                      (- 128a d e + (256a c - 512a b )d )f
+--R                    + 
+--R                             3 2 3          2          2  3 2         2 4
+--R                          64a d e  + (- 128a c + 256a b )d e  + 128a c d e
+--R                        + 
+--R                                3 5
+--R                          - 256c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5       2         2  2 4        2 3 3
+--R                          - 8a d e  + (16a c - 32a b )d e  - 64a c d e
+--R                        + 
+--R                              3 4 2
+--R                          128c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                           2 2 5      3 3 4
+--R                      (8a c d e  - 16c d e )f
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                     3   3 4
+--R                  64a b d f
+--R                + 
+--R                          2           3  3             2       3   4  3
+--R                  ((- 192a b c + 64a b )d e + (192a b c  - 128b c)d )f
+--R                + 
+--R                          3     4       2           3  2 3      3   3 2
+--R                      - 4a b d e  + (48a b c - 16a b )d e  + 32b c d e
+--R                    + 
+--R                             3 4
+--R                      - 64b c d e
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                            2 2 4        3 3 3
+--R                  (- 12a b c d e  + 16b c d e )f
+--R             *
+--R                     2
+--R                %%HF1
+--R            + 
+--R                             3 3         2          2  4  4
+--R                      (- 128a d e + (256a c - 512a b )d )f
+--R                    + 
+--R                             3 2 3          2          2  3 2         2 4
+--R                          64a d e  + (- 128a c + 256a b )d e  + 128a c d e
+--R                        + 
+--R                                3 5
+--R                          - 256c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                              3   5       2         2  2 4        2 3 3
+--R                          - 8a d e  + (16a c - 32a b )d e  - 64a c d e
+--R                        + 
+--R                              3 4 2
+--R                          128c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                           2 2 5      3 3 4
+--R                      (8a c d e  - 16c d e )f
+--R                 *
+--R                         2
+--R                    %%HF0
+--R                + 
+--R                     5 2 4
+--R                  16a d f
+--R                + 
+--R                       5   2         4      3 2  2        2 2         4  3  3
+--R                  (- 4a d e  + (- 24a c - 8a b )d e + (48a b c - 32a b )d )f
+--R                + 
+--R                         4      3 2    3      3 2      2 2        4  2 2
+--R                      (6a c + 2a b )d e  + (8a c  - 12a b c + 8a b )d e
+--R                    + 
+--R                          2 3        2 2  3            4      2 3  4
+--R                      (16a c  - 24a b c )d e + (- 16a c  + 16b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3 2   4        2 3       2 2  2 3
+--R                      - 2a c d e  + (- 4a c  + 6a b c )d e
+--R                    + 
+--R                             4     2 3  3 2     5 4
+--R                      (- 4a c  - 4b c )d e  + 8c d e
+--R                 *
+--R                    f
+--R                + 
+--R                      4 2 4     5 3 3
+--R                  2a c d e  - 2c d e
+--R             *
+--R                %%HF1
+--R            + 
+--R                         3 3         2          2  4  4
+--R                  (- 128a d e + (256a c - 512a b )d )f
+--R                + 
+--R                      3 2 3          2          2  3 2         2 4        3 5  3
+--R                  (64a d e  + (- 128a c + 256a b )d e  + 128a c d e - 256c d )f
+--R                + 
+--R                       3   5       2         2  2 4        2 3 3       3 4 2  2
+--R                  (- 8a d e  + (16a c - 32a b )d e  - 64a c d e  + 128c d e )f
+--R                + 
+--R                       2 2 5      3 3 4
+--R                  (8a c d e  - 16c d e )f
+--R             *
+--R                     3
+--R                %%HF0
+--R            + 
+--R                        5   2         4       3 2  2
+--R                      8a d e  + (- 48a c + 16a b )d e
+--R                    + 
+--R                          3 2      2 2         4  3
+--R                      (64a c  - 96a b c - 64a b )d
+--R                 *
+--R                     3
+--R                    f
+--R                + 
+--R                          5 4       4      3 2    3
+--R                      - 2a e  + (12a c - 4a b )d e
+--R                    + 
+--R                            3 2      2 2         4  2 2       2 3        2 2  3
+--R                      (- 16a c  + 24a b c + 16a b )d e  + (32a c  + 48a b c )d e
+--R                    + 
+--R                              4      2 3  4
+--R                      (- 64a c  - 32b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                        2 3        2 2  2 3        4     2 3  3 2      5 4
+--R                  ((- 8a c  - 12a b c )d e  + (8a c  + 8b c )d e  + 16c d e)f
+--R                + 
+--R                      4 2 4     5 3 3
+--R                  2a c d e  - 4c d e
+--R             *
+--R                %%HF0
+--R            + 
+--R                    6   4
+--R                  4a d f
+--R                + 
+--R                         6 2        5      4 2
+--R                      - a e  + (- 4a c - 8a b )d e
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4a c  + 32a b c - 16a b )d
+--R                 *
+--R                     3
+--R                    f
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      a c e  + (a c  + 8a b c)d e
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8a c  - 48a b c  + 16a b c)d e
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4a c  + 32a b c  - 16b c )d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2a c d e  + (a c  + 8a b c )d e  + (- 4a c  - 8b c )d e
+--R                    + 
+--R                        6 4
+--R                      4c d
+--R                 *
+--R                    f
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  a c d e  - c d e
+--R             *
+--R                x
+--R            + 
+--R                 4         3 3  2 3
+--R              (4a b c + 12a b )d f
+--R            + 
+--R                     5   3      4        3 3    2         3   2       5  2
+--R                  - a b e  + (9a b c - 3a b )d e  + (- 36a b c  + 4a b )d e
+--R                + 
+--R                      2   3        3 2     5   3
+--R                  (32a b c  - 12a b c  - 8b c)d
+--R             *
+--R                 2
+--R                f
+--R            + 
+--R                  3   2   3       2   3       3 2  2 2          4 3        5 4
+--R              (- a b c d e  + (12a b c  + 3a b c )d e  - 12a b c d e - 4b c d )f
+--R            + 
+--R                      4 2 3       5 3 2
+--R              - 2a b c d e  + 3b c d e
+--R     + 
+--R                                            +------------------+
+--R               +-----------+                | +-----------+
+--R               |          2                 | |          2
+--R         (- 2c\|- 4d f + e   - 4a f + 2c e)\|\|- 4d f + e   + e
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|f
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4d f + e   + e
+--R     + 
+--R                                            +--------------------+
+--R               +-----------+                |   +-----------+
+--R               |          2                 |   |          2
+--R         (- 2c\|- 4d f + e   + 4a f - 2c e)\|- \|- 4d f + e   + e
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|f
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4d f + e   + e
+--R     + 
+--R                   +-----------+
+--R               +-+ |          2  +-+
+--R             2\|2 \|- 4d f + e  \|f %%HF0
+--R          *
+--R             log
+--R                           3 3           2          2  4  4
+--R                      (128a d e + (- 256a c + 512a b )d )f
+--R                    + 
+--R                               3 2 3        2          2  3 2         2 4
+--R                          - 64a d e  + (128a c - 256a b )d e  - 128a c d e
+--R                        + 
+--R                              3 5
+--R                          256c d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                            3   5         2         2  2 4        2 3 3
+--R                          8a d e  + (- 16a c + 32a b )d e  + 64a c d e
+--R                        + 
+--R                                3 4 2
+--R                          - 128c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                             2 2 5      3 3 4
+--R                      (- 8a c d e  + 16c d e )f
+--R                 *
+--R                         3
+--R                    %%HF0
+--R                + 
+--R                         3   3 4
+--R                      64a b d f
+--R                    + 
+--R                              2           3  3             2       3   4  3
+--R                      ((- 192a b c + 64a b )d e + (192a b c  - 128b c)d )f
+--R                    + 
+--R                              3     4       2           3  2 3      3   3 2
+--R                          - 4a b d e  + (48a b c - 16a b )d e  + 32b c d e
+--R                        + 
+--R                                 3 4
+--R                          - 64b c d e
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                                2 2 4        3 3 3
+--R                      (- 12a b c d e  + 16b c d e )f
+--R                 *
+--R                         2
+--R                    %%HF0
+--R                + 
+--R                         5 2 4
+--R                      16a d f
+--R                    + 
+--R                               5   2       4       3 2  2
+--R                          - 12a d e  + (24a c - 24a b )d e
+--R                        + 
+--R                                3 2       2 2         4  3
+--R                          (- 64a c  + 144a b c + 32a b )d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                            5 4        4      3 2    3
+--R                          2a e  + (- 6a c + 6a b )d e
+--R                        + 
+--R                              3 2      2 2        4  2 2
+--R                          (24a c  - 36a b c - 8a b )d e
+--R                        + 
+--R                                2 3        2 2  3          4      2 3  4
+--R                          (- 16a c  - 72a b c )d e + (48a c  + 48b c )d
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                              3 2   4      2 3        2 2  2 3
+--R                          - 2a c d e  + (4a c  + 18a b c )d e
+--R                        + 
+--R                                  4      2 3  3 2     5 4
+--R                          (- 12a c  - 12b c )d e  - 8c d e
+--R                     *
+--R                        f
+--R                    + 
+--R                        5 3 3
+--R                      2c d e
+--R                 *
+--R                    %%HF0
+--R                + 
+--R                        6   4
+--R                      4a d f
+--R                    + 
+--R                             6 2        5      4 2
+--R                          - a e  + (- 4a c - 8a b )d e
+--R                        + 
+--R                               4 2      3 2       2 4  2
+--R                          (- 4a c  + 32a b c - 16a b )d
+--R                     *
+--R                         3
+--R                        f
+--R                    + 
+--R                           5   3     4 2     3 2     2
+--R                          a c e  + (a c  + 8a b c)d e
+--R                        + 
+--R                             3 3      2 2 2        4   2
+--R                          (8a c  - 48a b c  + 16a b c)d e
+--R                        + 
+--R                               2 4        2 3      4 2  3
+--R                          (- 4a c  + 32a b c  - 16b c )d
+--R                     *
+--R                         2
+--R                        f
+--R                    + 
+--R                              3 3   3     2 4       2 3  2 2
+--R                          - 2a c d e  + (a c  + 8a b c )d e
+--R                        + 
+--R                                 5     2 4  3      6 4
+--R                          (- 4a c  - 8b c )d e + 4c d
+--R                     *
+--R                        f
+--R                    + 
+--R                         5 2 3    6 3 2
+--R                      a c d e  - c d e
+--R                 *
+--R                    x
+--R                + 
+--R                       5            4         3 3  2  3
+--R                  (- 8a b d e + (20a b c - 20a b )d )f
+--R                + 
+--R                       5   3      4        3 3    2         3   2       5  2
+--R                      a b e  + (5a b c + 5a b )d e  + (- 20a b c  + 4a b )d e
+--R                    + 
+--R                            3 2     5   3
+--R                      (20a b c  - 8b c)d
+--R                 *
+--R                     2
+--R                    f
+--R                + 
+--R                          3   2   3       2   3       3 2  2 2          4 3
+--R                      - 5a b c d e  + (20a b c  - 5a b c )d e  - 20a b c d e
+--R                    + 
+--R                           5 4
+--R                      12b c d
+--R                 *
+--R                    f
+--R                + 
+--R                       5 3 2
+--R                  - b c d e
+--R         + 
+--R                                  2
+--R              +-+ +-+         2f x  + e
+--R           2b\|2 \|f atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4d f + e
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4d f + e   + e \|\|- 4d f + e   + e
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     2\|2 \|- 4d f + e  \|f \|- \|- 4d f + e   + e \|\|- 4d f + e   + e
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--(1 . failed) cannot be coerced to mode (SparseUnivariatePolynomial (Integer))
+--S 878 of 1580
+--d0:=D(m0,x)
+--E 878
+
+)clear all
+
+--S 879 of 1580
+t0:=(d+e*x)^2/(a+b*x^2+c*x^4)
+--R 
+--R
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R   (1)  ------------------
+--R             4      2
+--R          c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 879
+
+--S 880 of 1580
+r0:=-2*d*e*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)+_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(e^2+(2*c*d^2-b*e^2)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(e^2+(-2*c*d^2+b*e^2)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                           +------------------+
+--R             +-----------+                 | +-----------+
+--R           2 |          2       2       2  | |          2
+--R         (e \|- 4a c + b   - b e  + 2c d )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                           +--------------------+
+--R             +-----------+                 |   +-----------+
+--R           2 |          2       2       2  |   |          2
+--R         (e \|- 4a c + b   + b e  - 2c d )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                                              +--------------------+
+--R                                     2        |   +-----------+
+--R                 +-+ +-+         2c x  + b    |   |          2
+--R            2d e\|2 \|c atanh(--------------)\|- \|- 4a c + b   + b
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 880
+
+--S 881 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           ROOT
+--R                        2 2       2       2        2 2       2
+--R                  (- 12a c  + 3a b c)%%HG1  + (- 8a c  + 2a b c)%%HG0 %%HG1
+--R                + 
+--R                        2 2       2       2        4          2 2        4
+--R                  (- 12a c  + 3a b c)%%HG0  + a b e  - 12a c d e  + b c d
+--R             /
+--R                  2 2      2
+--R                4a c  - a b c
+--R         + 
+--R           - %%HG1 - %%HG0
+--R      *
+--R         log
+--R                               5 3      4 2 2     3 4   6
+--R                          (128a c  - 64a b c  + 8a b c)e
+--R                        + 
+--R                                4   3      3 3 2     2 5   2 4
+--R                          (- 64a b c  + 32a b c  - 4a b c)d e
+--R                        + 
+--R                               4 4       3 2 3      2 4 2  4 2
+--R                          (896a c  - 448a b c  + 56a b c )d e
+--R                        + 
+--R                              3   4      2 3 3       5 2  6
+--R                          (64a b c  - 32a b c  + 4a b c )d
+--R                     *
+--R                        %%HG0
+--R                    + 
+--R                          4   2      3 3     7
+--R                      (64a b c  - 16a b c)d e
+--R                    + 
+--R                           4 3       3 2 2      2 4   3 5
+--R                      (320a c  - 128a b c  + 12a b c)d e
+--R                    + 
+--R                            3   3      2 3 2  5 3         3 4       4 2  7
+--R                      (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R                 *
+--R                    %%HG1
+--R                + 
+--R                          4   2      3 3     7
+--R                      (64a b c  - 16a b c)d e
+--R                    + 
+--R                           4 3       3 2 2      2 4   3 5
+--R                      (320a c  - 128a b c  + 12a b c)d e
+--R                    + 
+--R                            3   3      2 3 2  5 3         3 4       4 2  7
+--R                      (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                     4       3 3  10       4 2      3 2     2 4  2 8
+--R                  (4a b c - a b )e   + (24a c  - 10a b c + a b )d e
+--R                + 
+--R                        3   2      2 3   4 6
+--R                  (- 40a b c  + 10a b c)d e
+--R                + 
+--R                         3 3      2 2 2      4   6 4
+--R                  (- 160a c  + 44a b c  - a b c)d e
+--R                + 
+--R                        2   3       3 2  8 2      2 4       2 3  10
+--R                  (- 28a b c  + 7a b c )d e  + (8a c  - 2a b c )d
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12a c  + 3a b c)%%HG1  + (- 8a c  + 2a b c)%%HG0 %%HG1
+--R                     + 
+--R                             2 2       2       2        4          2 2        4
+--R                       (- 12a c  + 3a b c)%%HG0  + a b e  - 12a c d e  + b c d
+--R                  /
+--R                       2 2      2
+--R                     4a c  - a b c
+--R            + 
+--R                           5 3      4 2 2     3 4   6
+--R                      (128a c  - 64a b c  + 8a b c)e
+--R                    + 
+--R                            4   3      3 3 2     2 5   2 4
+--R                      (- 64a b c  + 32a b c  - 4a b c)d e
+--R                    + 
+--R                           4 4       3 2 3      2 4 2  4 2
+--R                      (896a c  - 448a b c  + 56a b c )d e
+--R                    + 
+--R                          3   4      2 3 3       5 2  6
+--R                      (64a b c  - 32a b c  + 4a b c )d
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                      4   2      3 3     7        4 3       3 2 2      2 4   3 5
+--R                  (64a b c  - 16a b c)d e  + (320a c  - 128a b c  + 12a b c)d e
+--R                + 
+--R                        3   3      2 3 2  5 3         3 4       4 2  7
+--R                  (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R             *
+--R                     2
+--R                %%HG1
+--R            + 
+--R                           5 3      4 2 2     3 4   6
+--R                      (128a c  - 64a b c  + 8a b c)e
+--R                    + 
+--R                            4   3      3 3 2     2 5   2 4
+--R                      (- 64a b c  + 32a b c  - 4a b c)d e
+--R                    + 
+--R                           4 4       3 2 3      2 4 2  4 2
+--R                      (896a c  - 448a b c  + 56a b c )d e
+--R                    + 
+--R                          3   4      2 3 3       5 2  6
+--R                      (64a b c  - 32a b c  + 4a b c )d
+--R                 *
+--R                         2
+--R                    %%HG0
+--R                + 
+--R                       4       3 3  10         4 2      3 2     2 4  2 8
+--R                  (- 4a b c + a b )e   + (- 24a c  + 10a b c - a b )d e
+--R                + 
+--R                      3   2      2 3   4 6        3 3      2 2 2      4   6 4
+--R                  (40a b c  - 10a b c)d e  + (160a c  - 44a b c  + a b c)d e
+--R                + 
+--R                      2   3       3 2  8 2        2 4       2 3  10
+--R                  (28a b c  - 7a b c )d e  + (- 8a c  + 2a b c )d
+--R             *
+--R                %%HG1
+--R            + 
+--R                      4   2      3 3     7        4 3       3 2 2      2 4   3 5
+--R                  (64a b c  - 16a b c)d e  + (320a c  - 128a b c  + 12a b c)d e
+--R                + 
+--R                        3   3      2 3 2  5 3         3 4       4 2  7
+--R                  (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R             *
+--R                     2
+--R                %%HG0
+--R            + 
+--R                       4       3 3  10         4 2      3 2     2 4  2 8
+--R                  (- 4a b c + a b )e   + (- 24a c  + 10a b c - a b )d e
+--R                + 
+--R                      3   2      2 3   4 6        3 3      2 2 2      4   6 4
+--R                  (40a b c  - 10a b c)d e  + (160a c  - 44a b c  + a b c)d e
+--R                + 
+--R                      2   3       3 2  8 2        2 4       2 3  10
+--R                  (28a b c  - 7a b c )d e  + (- 8a c  + 2a b c )d
+--R             *
+--R                %%HG0
+--R            + 
+--R                     4     3 2  12         3       2 3  2 10
+--R                  (4a c - a b )e   + (- 36a b c + a b )d e
+--R                + 
+--R                         3 2      2 2   4 8       2   2       3   6 6
+--R                  (- 132a c  + 33a b c)d e  + (72a b c  - 2a b c)d e
+--R                + 
+--R                         2 3        2 2  8 4             3    3 2  10 2
+--R                  (- 132a c  + 33a b c )d e  + (- 36a b c  + b c )d  e
+--R                + 
+--R                       4    2 3  12
+--R                  (4a c  - b c )d
+--R             *
+--R                x
+--R            + 
+--R                   4      3 2    11       3        2 3  3 9
+--R              (- 8a c - 2a b )d e   + (32a b c + 2a b )d e
+--R            + 
+--R                   3 2      2 2   5 7         2   2       3   7 5
+--R              (192a c  - 24a b c)d e  + (- 72a b c  + 6a b c)d e
+--R            + 
+--R                 2 3        2 2  9 3         3 11
+--R              (8a c  - 22a b c )d e  + 8a b c d  e
+--R     + 
+--R           -
+--R              ROOT
+--R                           2 2       2       2        2 2       2
+--R                     (- 12a c  + 3a b c)%%HG1  + (- 8a c  + 2a b c)%%HG0 %%HG1
+--R                   + 
+--R                           2 2       2       2        4          2 2        4
+--R                     (- 12a c  + 3a b c)%%HG0  + a b e  - 12a c d e  + b c d
+--R                /
+--R                     2 2      2
+--R                   4a c  - a b c
+--R         + 
+--R           - %%HG1 - %%HG0
+--R      *
+--R         log
+--R                                 5 3      4 2 2     3 4   6
+--R                          (- 128a c  + 64a b c  - 8a b c)e
+--R                        + 
+--R                              4   3      3 3 2     2 5   2 4
+--R                          (64a b c  - 32a b c  + 4a b c)d e
+--R                        + 
+--R                                 4 4       3 2 3      2 4 2  4 2
+--R                          (- 896a c  + 448a b c  - 56a b c )d e
+--R                        + 
+--R                                3   4      2 3 3       5 2  6
+--R                          (- 64a b c  + 32a b c  - 4a b c )d
+--R                     *
+--R                        %%HG0
+--R                    + 
+--R                            4   2      3 3     7
+--R                      (- 64a b c  + 16a b c)d e
+--R                    + 
+--R                             4 3       3 2 2      2 4   3 5
+--R                      (- 320a c  + 128a b c  - 12a b c)d e
+--R                    + 
+--R                          3   3      2 3 2  5 3       3 4       4 2  7
+--R                      (64a b c  - 16a b c )d e  + (64a c  - 4a b c )d e
+--R                 *
+--R                    %%HG1
+--R                + 
+--R                            4   2      3 3     7
+--R                      (- 64a b c  + 16a b c)d e
+--R                    + 
+--R                             4 3       3 2 2      2 4   3 5
+--R                      (- 320a c  + 128a b c  - 12a b c)d e
+--R                    + 
+--R                          3   3      2 3 2  5 3       3 4       4 2  7
+--R                      (64a b c  - 16a b c )d e  + (64a c  - 4a b c )d e
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                       4       3 3  10         4 2      3 2     2 4  2 8
+--R                  (- 4a b c + a b )e   + (- 24a c  + 10a b c - a b )d e
+--R                + 
+--R                      3   2      2 3   4 6        3 3      2 2 2      4   6 4
+--R                  (40a b c  - 10a b c)d e  + (160a c  - 44a b c  + a b c)d e
+--R                + 
+--R                      2   3       3 2  8 2        2 4       2 3  10
+--R                  (28a b c  - 7a b c )d e  + (- 8a c  + 2a b c )d
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12a c  + 3a b c)%%HG1  + (- 8a c  + 2a b c)%%HG0 %%HG1
+--R                     + 
+--R                             2 2       2       2        4          2 2        4
+--R                       (- 12a c  + 3a b c)%%HG0  + a b e  - 12a c d e  + b c d
+--R                  /
+--R                       2 2      2
+--R                     4a c  - a b c
+--R            + 
+--R                           5 3      4 2 2     3 4   6
+--R                      (128a c  - 64a b c  + 8a b c)e
+--R                    + 
+--R                            4   3      3 3 2     2 5   2 4
+--R                      (- 64a b c  + 32a b c  - 4a b c)d e
+--R                    + 
+--R                           4 4       3 2 3      2 4 2  4 2
+--R                      (896a c  - 448a b c  + 56a b c )d e
+--R                    + 
+--R                          3   4      2 3 3       5 2  6
+--R                      (64a b c  - 32a b c  + 4a b c )d
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                      4   2      3 3     7        4 3       3 2 2      2 4   3 5
+--R                  (64a b c  - 16a b c)d e  + (320a c  - 128a b c  + 12a b c)d e
+--R                + 
+--R                        3   3      2 3 2  5 3         3 4       4 2  7
+--R                  (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R             *
+--R                     2
+--R                %%HG1
+--R            + 
+--R                           5 3      4 2 2     3 4   6
+--R                      (128a c  - 64a b c  + 8a b c)e
+--R                    + 
+--R                            4   3      3 3 2     2 5   2 4
+--R                      (- 64a b c  + 32a b c  - 4a b c)d e
+--R                    + 
+--R                           4 4       3 2 3      2 4 2  4 2
+--R                      (896a c  - 448a b c  + 56a b c )d e
+--R                    + 
+--R                          3   4      2 3 3       5 2  6
+--R                      (64a b c  - 32a b c  + 4a b c )d
+--R                 *
+--R                         2
+--R                    %%HG0
+--R                + 
+--R                       4       3 3  10         4 2      3 2     2 4  2 8
+--R                  (- 4a b c + a b )e   + (- 24a c  + 10a b c - a b )d e
+--R                + 
+--R                      3   2      2 3   4 6        3 3      2 2 2      4   6 4
+--R                  (40a b c  - 10a b c)d e  + (160a c  - 44a b c  + a b c)d e
+--R                + 
+--R                      2   3       3 2  8 2        2 4       2 3  10
+--R                  (28a b c  - 7a b c )d e  + (- 8a c  + 2a b c )d
+--R             *
+--R                %%HG1
+--R            + 
+--R                      4   2      3 3     7        4 3       3 2 2      2 4   3 5
+--R                  (64a b c  - 16a b c)d e  + (320a c  - 128a b c  + 12a b c)d e
+--R                + 
+--R                        3   3      2 3 2  5 3         3 4       4 2  7
+--R                  (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R             *
+--R                     2
+--R                %%HG0
+--R            + 
+--R                       4       3 3  10         4 2      3 2     2 4  2 8
+--R                  (- 4a b c + a b )e   + (- 24a c  + 10a b c - a b )d e
+--R                + 
+--R                      3   2      2 3   4 6        3 3      2 2 2      4   6 4
+--R                  (40a b c  - 10a b c)d e  + (160a c  - 44a b c  + a b c)d e
+--R                + 
+--R                      2   3       3 2  8 2        2 4       2 3  10
+--R                  (28a b c  - 7a b c )d e  + (- 8a c  + 2a b c )d
+--R             *
+--R                %%HG0
+--R            + 
+--R                     4     3 2  12         3       2 3  2 10
+--R                  (4a c - a b )e   + (- 36a b c + a b )d e
+--R                + 
+--R                         3 2      2 2   4 8       2   2       3   6 6
+--R                  (- 132a c  + 33a b c)d e  + (72a b c  - 2a b c)d e
+--R                + 
+--R                         2 3        2 2  8 4             3    3 2  10 2
+--R                  (- 132a c  + 33a b c )d e  + (- 36a b c  + b c )d  e
+--R                + 
+--R                       4    2 3  12
+--R                  (4a c  - b c )d
+--R             *
+--R                x
+--R            + 
+--R                   4      3 2    11       3        2 3  3 9
+--R              (- 8a c - 2a b )d e   + (32a b c + 2a b )d e
+--R            + 
+--R                   3 2      2 2   5 7         2   2       3   7 5
+--R              (192a c  - 24a b c)d e  + (- 72a b c  + 6a b c)d e
+--R            + 
+--R                 2 3        2 2  9 3         3 11
+--R              (8a c  - 22a b c )d e  + 8a b c d  e
+--R     + 
+--R         2%%HG1
+--R      *
+--R         log
+--R                             5 3       4 2 2      3 4   6
+--R                      (- 256a c  + 128a b c  - 16a b c)e
+--R                    + 
+--R                           4   3      3 3 2     2 5   2 4
+--R                      (128a b c  - 64a b c  + 8a b c)d e
+--R                    + 
+--R                              4 4       3 2 3       2 4 2  4 2
+--R                      (- 1792a c  + 896a b c  - 112a b c )d e
+--R                    + 
+--R                             3   4      2 3 3       5 2  6
+--R                      (- 128a b c  + 64a b c  - 8a b c )d
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                         4   2      3 3     7
+--R                  (- 128a b c  + 32a b c)d e
+--R                + 
+--R                         4 3       3 2 2      2 4   3 5
+--R                  (- 640a c  + 256a b c  - 24a b c)d e
+--R                + 
+--R                       3   3      2 3 2  5 3        3 4       4 2  7
+--R                  (128a b c  - 32a b c )d e  + (128a c  - 8a b c )d e
+--R             *
+--R                     2
+--R                %%HG1
+--R            + 
+--R                             5 3       4 2 2      3 4   6
+--R                      (- 256a c  + 128a b c  - 16a b c)e
+--R                    + 
+--R                           4   3      3 3 2     2 5   2 4
+--R                      (128a b c  - 64a b c  + 8a b c)d e
+--R                    + 
+--R                              4 4       3 2 3       2 4 2  4 2
+--R                      (- 1792a c  + 896a b c  - 112a b c )d e
+--R                    + 
+--R                             3   4      2 3 3       5 2  6
+--R                      (- 128a b c  + 64a b c  - 8a b c )d
+--R                 *
+--R                         2
+--R                    %%HG0
+--R                + 
+--R                     4        3 3  10       4 2      3 2      2 4  2 8
+--R                  (8a b c - 2a b )e   + (48a c  - 20a b c + 2a b )d e
+--R                + 
+--R                        3   2      2 3   4 6
+--R                  (- 80a b c  + 20a b c)d e
+--R                + 
+--R                         3 3      2 2 2       4   6 4
+--R                  (- 320a c  + 88a b c  - 2a b c)d e
+--R                + 
+--R                        2   3        3 2  8 2       2 4       2 3  10
+--R                  (- 56a b c  + 14a b c )d e  + (16a c  - 4a b c )d
+--R             *
+--R                %%HG1
+--R            + 
+--R                         5 3       4 2 2      3 4   6
+--R                  (- 256a c  + 128a b c  - 16a b c)e
+--R                + 
+--R                       4   3      3 3 2     2 5   2 4
+--R                  (128a b c  - 64a b c  + 8a b c)d e
+--R                + 
+--R                          4 4       3 2 3       2 4 2  4 2
+--R                  (- 1792a c  + 896a b c  - 112a b c )d e
+--R                + 
+--R                         3   4      2 3 3       5 2  6
+--R                  (- 128a b c  + 64a b c  - 8a b c )d
+--R             *
+--R                     3
+--R                %%HG0
+--R            + 
+--R                      4        3 3  10          4 2      3 2      2 4  2 8
+--R                  (16a b c - 4a b )e   + (- 192a c  + 40a b c + 2a b )d e
+--R                + 
+--R                       3   2      2 3   4 6           3 3       2 2 2  6 4
+--R                  (224a b c  - 56a b c)d e  + (- 1344a c  + 336a b c )d e
+--R                + 
+--R                      2   3       3 2  8 2        2 3     4 2  10
+--R                  (16a b c  - 4a b c )d e  + (8a b c  - 2b c )d
+--R             *
+--R                %%HG0
+--R            + 
+--R                     4     3 2  12         3       2 3  2 10
+--R                  (4a c - a b )e   + (- 36a b c + a b )d e
+--R                + 
+--R                         3 2      2 2   4 8       2   2       3   6 6
+--R                  (- 132a c  + 33a b c)d e  + (72a b c  - 2a b c)d e
+--R                + 
+--R                         2 3        2 2  8 4             3    3 2  10 2
+--R                  (- 132a c  + 33a b c )d e  + (- 36a b c  + b c )d  e
+--R                + 
+--R                       4    2 3  12
+--R                  (4a c  - b c )d
+--R             *
+--R                x
+--R            + 
+--R                   4      3 2    11         3        2 3  3 9
+--R              (- 8a c + 6a b )d e   + (- 24a b c - 4a b )d e
+--R            + 
+--R                     3 2      2 2   5 7       2   2       3   7 5
+--R              (- 288a c  + 48a b c)d e  + (56a b c  - 2a b c)d e
+--R            + 
+--R                   2 3       2 2  9 3     3 2 11
+--R              (104a c  - 6a b c )d e  - 2b c d  e
+--R     + 
+--R         2%%HG0
+--R      *
+--R         log
+--R                       5 3       4 2 2      3 4   6
+--R                  (256a c  - 128a b c  + 16a b c)e
+--R                + 
+--R                         4   3      3 3 2     2 5   2 4
+--R                  (- 128a b c  + 64a b c  - 8a b c)d e
+--R                + 
+--R                        4 4       3 2 3       2 4 2  4 2
+--R                  (1792a c  - 896a b c  + 112a b c )d e
+--R                + 
+--R                       3   4      2 3 3       5 2  6
+--R                  (128a b c  - 64a b c  + 8a b c )d
+--R             *
+--R                     3
+--R                %%HG0
+--R            + 
+--R                         4   2      3 3     7
+--R                  (- 128a b c  + 32a b c)d e
+--R                + 
+--R                         4 3       3 2 2      2 4   3 5
+--R                  (- 640a c  + 256a b c  - 24a b c)d e
+--R                + 
+--R                       3   3      2 3 2  5 3        3 4       4 2  7
+--R                  (128a b c  - 32a b c )d e  + (128a c  - 8a b c )d e
+--R             *
+--R                     2
+--R                %%HG0
+--R            + 
+--R                       4        3 3  10        4 2      3 2   2 8
+--R                  (- 8a b c + 2a b )e   + (240a c  - 60a b c)d e
+--R                + 
+--R                         3   2      2 3   4 6
+--R                  (- 304a b c  + 76a b c)d e
+--R                + 
+--R                        3 3       2 2 2       4   6 4
+--R                  (1024a c  - 248a b c  - 2a b c)d e
+--R                + 
+--R                        2   3        3 2  8 2       2 4        2 3     4 2  10
+--R                  (- 72a b c  + 18a b c )d e  + (16a c  - 12a b c  + 2b c )d
+--R             *
+--R                %%HG0
+--R            + 
+--R                     4     3 2  12         3       2 3  2 10
+--R                  (4a c - a b )e   + (- 36a b c + a b )d e
+--R                + 
+--R                         3 2      2 2   4 8       2   2       3   6 6
+--R                  (- 132a c  + 33a b c)d e  + (72a b c  - 2a b c)d e
+--R                + 
+--R                         2 3        2 2  8 4             3    3 2  10 2
+--R                  (- 132a c  + 33a b c )d e  + (- 36a b c  + b c )d  e
+--R                + 
+--R                       4    2 3  12
+--R                  (4a c  - b c )d
+--R             *
+--R                x
+--R            + 
+--R                  4      3 2    11      3     3 9      3 2 5 7
+--R              (24a c - 2a b )d e   - 40a b c d e  - 96a c d e
+--R            + 
+--R                  2   2        3   7 5          2 3        2 2  9 3
+--R              (88a b c  - 10a b c)d e  + (- 120a c  + 50a b c )d e
+--R            + 
+--R                        3     3 2  11
+--R              (- 16a b c  + 2b c )d  e
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 881
+
+--S 882 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    +--------------------+ +------------------+
+--R                  +-----------+     |   +-----------+      | +-----------+
+--R              +-+ |          2  +-+ |   |          2       | |          2
+--R             \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R          *
+--R             ROOT
+--R                          2 2       2       2        2 2       2
+--R                    (- 12a c  + 3a b c)%%HG1  + (- 8a c  + 2a b c)%%HG0 %%HG1
+--R                  + 
+--R                          2 2       2       2        4          2 2        4
+--R                    (- 12a c  + 3a b c)%%HG0  + a b e  - 12a c d e  + b c d
+--R               /
+--R                    2 2      2
+--R                  4a c  - a b c
+--R         + 
+--R           -
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R                 +-+ |          2  +-+ |   |          2
+--R                \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b %%HG1
+--R         + 
+--R           -
+--R                                            +--------------------+
+--R                     +-----------+          |   +-----------+
+--R                 +-+ |          2  +-+      |   |          2
+--R                \|2 \|- 4a c + b  \|c %%HG0\|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                               5 3      4 2 2     3 4   6
+--R                          (128a c  - 64a b c  + 8a b c)e
+--R                        + 
+--R                                4   3      3 3 2     2 5   2 4
+--R                          (- 64a b c  + 32a b c  - 4a b c)d e
+--R                        + 
+--R                               4 4       3 2 3      2 4 2  4 2
+--R                          (896a c  - 448a b c  + 56a b c )d e
+--R                        + 
+--R                              3   4      2 3 3       5 2  6
+--R                          (64a b c  - 32a b c  + 4a b c )d
+--R                     *
+--R                        %%HG0
+--R                    + 
+--R                          4   2      3 3     7
+--R                      (64a b c  - 16a b c)d e
+--R                    + 
+--R                           4 3       3 2 2      2 4   3 5
+--R                      (320a c  - 128a b c  + 12a b c)d e
+--R                    + 
+--R                            3   3      2 3 2  5 3         3 4       4 2  7
+--R                      (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R                 *
+--R                    %%HG1
+--R                + 
+--R                          4   2      3 3     7
+--R                      (64a b c  - 16a b c)d e
+--R                    + 
+--R                           4 3       3 2 2      2 4   3 5
+--R                      (320a c  - 128a b c  + 12a b c)d e
+--R                    + 
+--R                            3   3      2 3 2  5 3         3 4       4 2  7
+--R                      (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                     4       3 3  10       4 2      3 2     2 4  2 8
+--R                  (4a b c - a b )e   + (24a c  - 10a b c + a b )d e
+--R                + 
+--R                        3   2      2 3   4 6
+--R                  (- 40a b c  + 10a b c)d e
+--R                + 
+--R                         3 3      2 2 2      4   6 4
+--R                  (- 160a c  + 44a b c  - a b c)d e
+--R                + 
+--R                        2   3       3 2  8 2      2 4       2 3  10
+--R                  (- 28a b c  + 7a b c )d e  + (8a c  - 2a b c )d
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12a c  + 3a b c)%%HG1  + (- 8a c  + 2a b c)%%HG0 %%HG1
+--R                     + 
+--R                             2 2       2       2        4          2 2        4
+--R                       (- 12a c  + 3a b c)%%HG0  + a b e  - 12a c d e  + b c d
+--R                  /
+--R                       2 2      2
+--R                     4a c  - a b c
+--R            + 
+--R                           5 3      4 2 2     3 4   6
+--R                      (128a c  - 64a b c  + 8a b c)e
+--R                    + 
+--R                            4   3      3 3 2     2 5   2 4
+--R                      (- 64a b c  + 32a b c  - 4a b c)d e
+--R                    + 
+--R                           4 4       3 2 3      2 4 2  4 2
+--R                      (896a c  - 448a b c  + 56a b c )d e
+--R                    + 
+--R                          3   4      2 3 3       5 2  6
+--R                      (64a b c  - 32a b c  + 4a b c )d
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                      4   2      3 3     7        4 3       3 2 2      2 4   3 5
+--R                  (64a b c  - 16a b c)d e  + (320a c  - 128a b c  + 12a b c)d e
+--R                + 
+--R                        3   3      2 3 2  5 3         3 4       4 2  7
+--R                  (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R             *
+--R                     2
+--R                %%HG1
+--R            + 
+--R                           5 3      4 2 2     3 4   6
+--R                      (128a c  - 64a b c  + 8a b c)e
+--R                    + 
+--R                            4   3      3 3 2     2 5   2 4
+--R                      (- 64a b c  + 32a b c  - 4a b c)d e
+--R                    + 
+--R                           4 4       3 2 3      2 4 2  4 2
+--R                      (896a c  - 448a b c  + 56a b c )d e
+--R                    + 
+--R                          3   4      2 3 3       5 2  6
+--R                      (64a b c  - 32a b c  + 4a b c )d
+--R                 *
+--R                         2
+--R                    %%HG0
+--R                + 
+--R                       4       3 3  10         4 2      3 2     2 4  2 8
+--R                  (- 4a b c + a b )e   + (- 24a c  + 10a b c - a b )d e
+--R                + 
+--R                      3   2      2 3   4 6        3 3      2 2 2      4   6 4
+--R                  (40a b c  - 10a b c)d e  + (160a c  - 44a b c  + a b c)d e
+--R                + 
+--R                      2   3       3 2  8 2        2 4       2 3  10
+--R                  (28a b c  - 7a b c )d e  + (- 8a c  + 2a b c )d
+--R             *
+--R                %%HG1
+--R            + 
+--R                      4   2      3 3     7        4 3       3 2 2      2 4   3 5
+--R                  (64a b c  - 16a b c)d e  + (320a c  - 128a b c  + 12a b c)d e
+--R                + 
+--R                        3   3      2 3 2  5 3         3 4       4 2  7
+--R                  (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R             *
+--R                     2
+--R                %%HG0
+--R            + 
+--R                       4       3 3  10         4 2      3 2     2 4  2 8
+--R                  (- 4a b c + a b )e   + (- 24a c  + 10a b c - a b )d e
+--R                + 
+--R                      3   2      2 3   4 6        3 3      2 2 2      4   6 4
+--R                  (40a b c  - 10a b c)d e  + (160a c  - 44a b c  + a b c)d e
+--R                + 
+--R                      2   3       3 2  8 2        2 4       2 3  10
+--R                  (28a b c  - 7a b c )d e  + (- 8a c  + 2a b c )d
+--R             *
+--R                %%HG0
+--R            + 
+--R                     4     3 2  12         3       2 3  2 10
+--R                  (4a c - a b )e   + (- 36a b c + a b )d e
+--R                + 
+--R                         3 2      2 2   4 8       2   2       3   6 6
+--R                  (- 132a c  + 33a b c)d e  + (72a b c  - 2a b c)d e
+--R                + 
+--R                         2 3        2 2  8 4             3    3 2  10 2
+--R                  (- 132a c  + 33a b c )d e  + (- 36a b c  + b c )d  e
+--R                + 
+--R                       4    2 3  12
+--R                  (4a c  - b c )d
+--R             *
+--R                x
+--R            + 
+--R                   4      3 2    11       3        2 3  3 9
+--R              (- 8a c - 2a b )d e   + (32a b c + 2a b )d e
+--R            + 
+--R                   3 2      2 2   5 7         2   2       3   7 5
+--R              (192a c  - 24a b c)d e  + (- 72a b c  + 6a b c)d e
+--R            + 
+--R                 2 3        2 2  9 3         3 11
+--R              (8a c  - 22a b c )d e  + 8a b c d  e
+--R     + 
+--R           -
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R                 +-+ |          2  +-+ |   |          2
+--R                \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12a c  + 3a b c)%%HG1  + (- 8a c  + 2a b c)%%HG0 %%HG1
+--R                     + 
+--R                             2 2       2       2        4          2 2        4
+--R                       (- 12a c  + 3a b c)%%HG0  + a b e  - 12a c d e  + b c d
+--R                  /
+--R                       2 2      2
+--R                     4a c  - a b c
+--R         + 
+--R           -
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R                 +-+ |          2  +-+ |   |          2
+--R                \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b %%HG1
+--R         + 
+--R           -
+--R                                            +--------------------+
+--R                     +-----------+          |   +-----------+
+--R                 +-+ |          2  +-+      |   |          2
+--R                \|2 \|- 4a c + b  \|c %%HG0\|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                 5 3      4 2 2     3 4   6
+--R                          (- 128a c  + 64a b c  - 8a b c)e
+--R                        + 
+--R                              4   3      3 3 2     2 5   2 4
+--R                          (64a b c  - 32a b c  + 4a b c)d e
+--R                        + 
+--R                                 4 4       3 2 3      2 4 2  4 2
+--R                          (- 896a c  + 448a b c  - 56a b c )d e
+--R                        + 
+--R                                3   4      2 3 3       5 2  6
+--R                          (- 64a b c  + 32a b c  - 4a b c )d
+--R                     *
+--R                        %%HG0
+--R                    + 
+--R                            4   2      3 3     7
+--R                      (- 64a b c  + 16a b c)d e
+--R                    + 
+--R                             4 3       3 2 2      2 4   3 5
+--R                      (- 320a c  + 128a b c  - 12a b c)d e
+--R                    + 
+--R                          3   3      2 3 2  5 3       3 4       4 2  7
+--R                      (64a b c  - 16a b c )d e  + (64a c  - 4a b c )d e
+--R                 *
+--R                    %%HG1
+--R                + 
+--R                            4   2      3 3     7
+--R                      (- 64a b c  + 16a b c)d e
+--R                    + 
+--R                             4 3       3 2 2      2 4   3 5
+--R                      (- 320a c  + 128a b c  - 12a b c)d e
+--R                    + 
+--R                          3   3      2 3 2  5 3       3 4       4 2  7
+--R                      (64a b c  - 16a b c )d e  + (64a c  - 4a b c )d e
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                       4       3 3  10         4 2      3 2     2 4  2 8
+--R                  (- 4a b c + a b )e   + (- 24a c  + 10a b c - a b )d e
+--R                + 
+--R                      3   2      2 3   4 6        3 3      2 2 2      4   6 4
+--R                  (40a b c  - 10a b c)d e  + (160a c  - 44a b c  + a b c)d e
+--R                + 
+--R                      2   3       3 2  8 2        2 4       2 3  10
+--R                  (28a b c  - 7a b c )d e  + (- 8a c  + 2a b c )d
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12a c  + 3a b c)%%HG1  + (- 8a c  + 2a b c)%%HG0 %%HG1
+--R                     + 
+--R                             2 2       2       2        4          2 2        4
+--R                       (- 12a c  + 3a b c)%%HG0  + a b e  - 12a c d e  + b c d
+--R                  /
+--R                       2 2      2
+--R                     4a c  - a b c
+--R            + 
+--R                           5 3      4 2 2     3 4   6
+--R                      (128a c  - 64a b c  + 8a b c)e
+--R                    + 
+--R                            4   3      3 3 2     2 5   2 4
+--R                      (- 64a b c  + 32a b c  - 4a b c)d e
+--R                    + 
+--R                           4 4       3 2 3      2 4 2  4 2
+--R                      (896a c  - 448a b c  + 56a b c )d e
+--R                    + 
+--R                          3   4      2 3 3       5 2  6
+--R                      (64a b c  - 32a b c  + 4a b c )d
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                      4   2      3 3     7        4 3       3 2 2      2 4   3 5
+--R                  (64a b c  - 16a b c)d e  + (320a c  - 128a b c  + 12a b c)d e
+--R                + 
+--R                        3   3      2 3 2  5 3         3 4       4 2  7
+--R                  (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R             *
+--R                     2
+--R                %%HG1
+--R            + 
+--R                           5 3      4 2 2     3 4   6
+--R                      (128a c  - 64a b c  + 8a b c)e
+--R                    + 
+--R                            4   3      3 3 2     2 5   2 4
+--R                      (- 64a b c  + 32a b c  - 4a b c)d e
+--R                    + 
+--R                           4 4       3 2 3      2 4 2  4 2
+--R                      (896a c  - 448a b c  + 56a b c )d e
+--R                    + 
+--R                          3   4      2 3 3       5 2  6
+--R                      (64a b c  - 32a b c  + 4a b c )d
+--R                 *
+--R                         2
+--R                    %%HG0
+--R                + 
+--R                       4       3 3  10         4 2      3 2     2 4  2 8
+--R                  (- 4a b c + a b )e   + (- 24a c  + 10a b c - a b )d e
+--R                + 
+--R                      3   2      2 3   4 6        3 3      2 2 2      4   6 4
+--R                  (40a b c  - 10a b c)d e  + (160a c  - 44a b c  + a b c)d e
+--R                + 
+--R                      2   3       3 2  8 2        2 4       2 3  10
+--R                  (28a b c  - 7a b c )d e  + (- 8a c  + 2a b c )d
+--R             *
+--R                %%HG1
+--R            + 
+--R                      4   2      3 3     7        4 3       3 2 2      2 4   3 5
+--R                  (64a b c  - 16a b c)d e  + (320a c  - 128a b c  + 12a b c)d e
+--R                + 
+--R                        3   3      2 3 2  5 3         3 4       4 2  7
+--R                  (- 64a b c  + 16a b c )d e  + (- 64a c  + 4a b c )d e
+--R             *
+--R                     2
+--R                %%HG0
+--R            + 
+--R                       4       3 3  10         4 2      3 2     2 4  2 8
+--R                  (- 4a b c + a b )e   + (- 24a c  + 10a b c - a b )d e
+--R                + 
+--R                      3   2      2 3   4 6        3 3      2 2 2      4   6 4
+--R                  (40a b c  - 10a b c)d e  + (160a c  - 44a b c  + a b c)d e
+--R                + 
+--R                      2   3       3 2  8 2        2 4       2 3  10
+--R                  (28a b c  - 7a b c )d e  + (- 8a c  + 2a b c )d
+--R             *
+--R                %%HG0
+--R            + 
+--R                     4     3 2  12         3       2 3  2 10
+--R                  (4a c - a b )e   + (- 36a b c + a b )d e
+--R                + 
+--R                         3 2      2 2   4 8       2   2       3   6 6
+--R                  (- 132a c  + 33a b c)d e  + (72a b c  - 2a b c)d e
+--R                + 
+--R                         2 3        2 2  8 4             3    3 2  10 2
+--R                  (- 132a c  + 33a b c )d e  + (- 36a b c  + b c )d  e
+--R                + 
+--R                       4    2 3  12
+--R                  (4a c  - b c )d
+--R             *
+--R                x
+--R            + 
+--R                   4      3 2    11       3        2 3  3 9
+--R              (- 8a c - 2a b )d e   + (32a b c + 2a b )d e
+--R            + 
+--R                   3 2      2 2   5 7         2   2       3   7 5
+--R              (192a c  - 24a b c)d e  + (- 72a b c  + 6a b c)d e
+--R            + 
+--R                 2 3        2 2  9 3         3 11
+--R              (8a c  - 22a b c )d e  + 8a b c d  e
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R         2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         %%HG1
+--R      *
+--R         log
+--R                             5 3       4 2 2      3 4   6
+--R                      (- 256a c  + 128a b c  - 16a b c)e
+--R                    + 
+--R                           4   3      3 3 2     2 5   2 4
+--R                      (128a b c  - 64a b c  + 8a b c)d e
+--R                    + 
+--R                              4 4       3 2 3       2 4 2  4 2
+--R                      (- 1792a c  + 896a b c  - 112a b c )d e
+--R                    + 
+--R                             3   4      2 3 3       5 2  6
+--R                      (- 128a b c  + 64a b c  - 8a b c )d
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                         4   2      3 3     7
+--R                  (- 128a b c  + 32a b c)d e
+--R                + 
+--R                         4 3       3 2 2      2 4   3 5
+--R                  (- 640a c  + 256a b c  - 24a b c)d e
+--R                + 
+--R                       3   3      2 3 2  5 3        3 4       4 2  7
+--R                  (128a b c  - 32a b c )d e  + (128a c  - 8a b c )d e
+--R             *
+--R                     2
+--R                %%HG1
+--R            + 
+--R                             5 3       4 2 2      3 4   6
+--R                      (- 256a c  + 128a b c  - 16a b c)e
+--R                    + 
+--R                           4   3      3 3 2     2 5   2 4
+--R                      (128a b c  - 64a b c  + 8a b c)d e
+--R                    + 
+--R                              4 4       3 2 3       2 4 2  4 2
+--R                      (- 1792a c  + 896a b c  - 112a b c )d e
+--R                    + 
+--R                             3   4      2 3 3       5 2  6
+--R                      (- 128a b c  + 64a b c  - 8a b c )d
+--R                 *
+--R                         2
+--R                    %%HG0
+--R                + 
+--R                     4        3 3  10       4 2      3 2      2 4  2 8
+--R                  (8a b c - 2a b )e   + (48a c  - 20a b c + 2a b )d e
+--R                + 
+--R                        3   2      2 3   4 6
+--R                  (- 80a b c  + 20a b c)d e
+--R                + 
+--R                         3 3      2 2 2       4   6 4
+--R                  (- 320a c  + 88a b c  - 2a b c)d e
+--R                + 
+--R                        2   3        3 2  8 2       2 4       2 3  10
+--R                  (- 56a b c  + 14a b c )d e  + (16a c  - 4a b c )d
+--R             *
+--R                %%HG1
+--R            + 
+--R                         5 3       4 2 2      3 4   6
+--R                  (- 256a c  + 128a b c  - 16a b c)e
+--R                + 
+--R                       4   3      3 3 2     2 5   2 4
+--R                  (128a b c  - 64a b c  + 8a b c)d e
+--R                + 
+--R                          4 4       3 2 3       2 4 2  4 2
+--R                  (- 1792a c  + 896a b c  - 112a b c )d e
+--R                + 
+--R                         3   4      2 3 3       5 2  6
+--R                  (- 128a b c  + 64a b c  - 8a b c )d
+--R             *
+--R                     3
+--R                %%HG0
+--R            + 
+--R                      4        3 3  10          4 2      3 2      2 4  2 8
+--R                  (16a b c - 4a b )e   + (- 192a c  + 40a b c + 2a b )d e
+--R                + 
+--R                       3   2      2 3   4 6           3 3       2 2 2  6 4
+--R                  (224a b c  - 56a b c)d e  + (- 1344a c  + 336a b c )d e
+--R                + 
+--R                      2   3       3 2  8 2        2 3     4 2  10
+--R                  (16a b c  - 4a b c )d e  + (8a b c  - 2b c )d
+--R             *
+--R                %%HG0
+--R            + 
+--R                     4     3 2  12         3       2 3  2 10
+--R                  (4a c - a b )e   + (- 36a b c + a b )d e
+--R                + 
+--R                         3 2      2 2   4 8       2   2       3   6 6
+--R                  (- 132a c  + 33a b c)d e  + (72a b c  - 2a b c)d e
+--R                + 
+--R                         2 3        2 2  8 4             3    3 2  10 2
+--R                  (- 132a c  + 33a b c )d e  + (- 36a b c  + b c )d  e
+--R                + 
+--R                       4    2 3  12
+--R                  (4a c  - b c )d
+--R             *
+--R                x
+--R            + 
+--R                   4      3 2    11         3        2 3  3 9
+--R              (- 8a c + 6a b )d e   + (- 24a b c - 4a b )d e
+--R            + 
+--R                     3 2      2 2   5 7       2   2       3   7 5
+--R              (- 288a c  + 48a b c)d e  + (56a b c  - 2a b c)d e
+--R            + 
+--R                   2 3       2 2  9 3     3 2 11
+--R              (104a c  - 6a b c )d e  - 2b c d  e
+--R     + 
+--R                                               +------------------+
+--R                +-----------+                  | +-----------+
+--R              2 |          2        2       2  | |          2
+--R         (- 2e \|- 4a c + b   + 2b e  - 4c d )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                               +--------------------+
+--R                +-----------+                  |   +-----------+
+--R              2 |          2        2       2  |   |          2
+--R         (- 2e \|- 4a c + b   - 2b e  + 4c d )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                   +-----------+
+--R               +-+ |          2  +-+
+--R             2\|2 \|- 4a c + b  \|c %%HG0
+--R          *
+--R             log
+--R                           5 3       4 2 2      3 4   6
+--R                      (256a c  - 128a b c  + 16a b c)e
+--R                    + 
+--R                             4   3      3 3 2     2 5   2 4
+--R                      (- 128a b c  + 64a b c  - 8a b c)d e
+--R                    + 
+--R                            4 4       3 2 3       2 4 2  4 2
+--R                      (1792a c  - 896a b c  + 112a b c )d e
+--R                    + 
+--R                           3   4      2 3 3       5 2  6
+--R                      (128a b c  - 64a b c  + 8a b c )d
+--R                 *
+--R                         3
+--R                    %%HG0
+--R                + 
+--R                             4   2      3 3     7
+--R                      (- 128a b c  + 32a b c)d e
+--R                    + 
+--R                             4 3       3 2 2      2 4   3 5
+--R                      (- 640a c  + 256a b c  - 24a b c)d e
+--R                    + 
+--R                           3   3      2 3 2  5 3        3 4       4 2  7
+--R                      (128a b c  - 32a b c )d e  + (128a c  - 8a b c )d e
+--R                 *
+--R                         2
+--R                    %%HG0
+--R                + 
+--R                           4        3 3  10        4 2      3 2   2 8
+--R                      (- 8a b c + 2a b )e   + (240a c  - 60a b c)d e
+--R                    + 
+--R                             3   2      2 3   4 6
+--R                      (- 304a b c  + 76a b c)d e
+--R                    + 
+--R                            3 3       2 2 2       4   6 4
+--R                      (1024a c  - 248a b c  - 2a b c)d e
+--R                    + 
+--R                          2   3        3 2  8 2       2 4        2 3     4 2  10
+--R                    (- 72a b c  + 18a b c )d e  + (16a c  - 12a b c  + 2b c )d
+--R                 *
+--R                    %%HG0
+--R                + 
+--R                         4     3 2  12         3       2 3  2 10
+--R                      (4a c - a b )e   + (- 36a b c + a b )d e
+--R                    + 
+--R                             3 2      2 2   4 8       2   2       3   6 6
+--R                      (- 132a c  + 33a b c)d e  + (72a b c  - 2a b c)d e
+--R                    + 
+--R                             2 3        2 2  8 4             3    3 2  10 2
+--R                      (- 132a c  + 33a b c )d e  + (- 36a b c  + b c )d  e
+--R                    + 
+--R                           4    2 3  12
+--R                      (4a c  - b c )d
+--R                 *
+--R                    x
+--R                + 
+--R                      4      3 2    11      3     3 9      3 2 5 7
+--R                  (24a c - 2a b )d e   - 40a b c d e  - 96a c d e
+--R                + 
+--R                      2   2        3   7 5          2 3        2 2  9 3
+--R                  (88a b c  - 10a b c)d e  + (- 120a c  + 50a b c )d e
+--R                + 
+--R                            3     3 2  11
+--R                  (- 16a b c  + 2b c )d  e
+--R         + 
+--R                                    2
+--R                +-+ +-+         2c x  + b
+--R           4d e\|2 \|c atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 883
+
+)clear all
+
+--S 884 of 1580
+t0:=sqrt(1+2*x^2)/(1+sqrt(1+2*x^2))
+--R 
+--R
+--R           +-------+
+--R           |  2
+--R          \|2x  + 1
+--R   (1)  --------------
+--R         +-------+
+--R         |  2
+--R        \|2x  + 1  + 1
+--R                                                    Type: Expression(Integer)
+--E 884
+
+--S 885 of 1580
+r0:=(-1/2)/x+x-asinh(x*sqrt(2))/sqrt(2)+1/2*sqrt(1+2*x^2)/x
+--R 
+--R
+--R             +-------+
+--R         +-+ |  2                   +-+       2      +-+
+--R        \|2 \|2x  + 1  - 2x asinh(x\|2 ) + (2x  - 1)\|2
+--R   (2)  ------------------------------------------------
+--R                                +-+
+--R                             2x\|2
+--R                                                    Type: Expression(Integer)
+--E 885
+
+--S 886 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                +-------+
+--R              +-------+                +-+      |  2          +-+     2
+--R          +-+ |  2          +-+     (x\|2  + 1)\|2x  + 1  - x\|2  - 2x  - 1
+--R       (x\|2 \|2x  + 1  - x\|2 )log(---------------------------------------)
+--R                                                  +-------+
+--R                                                  |  2
+--R                                                 \|2x  + 1  - 1
+--R     + 
+--R                 +-------+
+--R          2      |  2
+--R       (2x  - 2)\|2x  + 1  + 2
+--R  /
+--R        +-------+
+--R        |  2
+--R     2x\|2x  + 1  - 2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 886
+
+--S 887 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                        +-------+
+--R               +-+      |  2          +-+     2
+--R            (x\|2  + 1)\|2x  + 1  - x\|2  - 2x  - 1            +-+
+--R        log(---------------------------------------) + asinh(x\|2 )
+--R                          +-------+
+--R                          |  2
+--R                         \|2x  + 1  - 1
+--R   (4)  -----------------------------------------------------------
+--R                                     +-+
+--R                                    \|2
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 888
+
+)clear all
+
+--S 889 of 1580
+t0:=sqrt(-1+4*x^2)/(x+sqrt(-1+4*x^2))
+--R 
+--R
+--R           +-------+
+--R           |  2
+--R          \|4x  - 1
+--R   (1)  --------------
+--R         +-------+
+--R         |  2
+--R        \|4x  - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 889
+
+--S 890 of 1580
+r0:=4/3*x-1/3*atanh(x*sqrt(3))/sqrt(3)+1/3*atanh(sqrt(3)*_
+   sqrt(-1+4*x^2))/sqrt(3)-1/3*sqrt(-1+4*x^2)
+--R 
+--R
+--R                   +-------+         +-------+
+--R               +-+ |  2          +-+ |  2                +-+       +-+
+--R        atanh(\|3 \|4x  - 1 ) - \|3 \|4x  - 1  - atanh(x\|3 ) + 4x\|3
+--R   (2)  --------------------------------------------------------------
+--R                                       +-+
+--R                                     3\|3
+--R                                                    Type: Expression(Integer)
+--E 890
+
+--S 891 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-------+
+--R           |  2
+--R         (\|4x  - 1  - 2x)
+--R      *
+--R         log
+--R                                             +-------+
+--R                     3       +-+      2      |  2              4      2      +-+
+--R                ((24x  - 4x)\|3  - 24x  + 3)\|4x  - 1  + (- 48x  + 14x  - 1)\|3
+--R              + 
+--R                   3
+--R                48x  - 12x
+--R           /
+--R                          +-------+
+--R                  3       |  2           4      2
+--R              (12x  - 4x)\|4x  - 1  - 24x  + 11x  - 1
+--R     + 
+--R               2      +-+                  +-------+
+--R            (3x  + 1)\|3  - 6x        +-+  |  2
+--R       (log(------------------) + 12x\|3 )\|4x  - 1
+--R                    2
+--R                  3x  - 1
+--R     + 
+--R                   2      +-+
+--R                (3x  + 1)\|3  - 6x          2      +-+
+--R       - 2x log(------------------) + (- 24x  + 2)\|3
+--R                        2
+--R                      3x  - 1
+--R  /
+--R           +-------+
+--R       +-+ |  2            +-+
+--R     6\|3 \|4x  - 1  - 12x\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 891
+
+--S 892 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                           +-------+
+--R                   3       +-+      2      |  2              4      2      +-+
+--R              ((24x  - 4x)\|3  - 24x  + 3)\|4x  - 1  + (- 48x  + 14x  - 1)\|3
+--R            + 
+--R                 3
+--R              48x  - 12x
+--R         /
+--R                        +-------+
+--R                3       |  2           4      2
+--R            (12x  - 4x)\|4x  - 1  - 24x  + 11x  - 1
+--R     + 
+--R                     +-------+           2      +-+
+--R                 +-+ |  2             (3x  + 1)\|3  - 6x             +-+
+--R       - 2atanh(\|3 \|4x  - 1 ) + log(------------------) + 2atanh(x\|3 )
+--R                                              2
+--R                                            3x  - 1
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 892
+
+--S 893 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 893
+
+)clear all
+
+--S 894 of 1580
+t0:=x^2/((a+b*x)*(c+d*x))
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R             2
+--R        b d x  + (a d + b c)x + a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 894
+
+--S 895 of 1580
+r0:=x/(b*d)+a^2*log(a+b*x)/(b^2*(b*c-a*d))-c^2*log(c+d*x)/(d^2*(b*c-a*d))
+--R 
+--R
+--R         2 2                2 2                     2    2
+--R        b c log(d x + c) - a d log(b x + a) + (a b d  - b c d)x
+--R   (2)  -------------------------------------------------------
+--R                               2 3    3   2
+--R                            a b d  - b c d
+--R                                                    Type: Expression(Integer)
+--E 895
+
+--S 896 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2 2                2 2                     2    2
+--R        b c log(d x + c) - a d log(b x + a) + (a b d  - b c d)x
+--R   (3)  -------------------------------------------------------
+--R                               2 3    3   2
+--R                            a b d  - b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 896
+
+--S 897 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 897
+
+--S 898 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 898
+
+)clear all
+
+--S 899 of 1580
+t0:=x^2/((c+d*x)*(a+b*x^2))
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R             3        2
+--R        b d x  + b c x  + a d x + a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 899
+
+--S 900 of 1580
+r0:=c^2*log(c+d*x)/(d*(b*c^2+a*d^2))+1/2*a*d*log(a+b*x^2)/(b*(b*c^2+a*d^2))-_
+   c*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/((b*c^2+a*d^2)*sqrt(b))
+--R 
+--R
+--R                           +-+
+--R                 +-+     x\|b         2       2            2              +-+
+--R        - 2b c d\|a atan(-----) + (a d log(b x  + a) + 2b c log(d x + c))\|b
+--R                           +-+
+--R                          \|a
+--R   (2)  ---------------------------------------------------------------------
+--R                                       3     2 2   +-+
+--R                                (2a b d  + 2b c d)\|b
+--R                                                    Type: Expression(Integer)
+--E 900
+
+--S 901 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               +---+
+--R                               |  a       2
+--R               +---+    - 2b x |- -  + b x  - a
+--R               |  a           \|  b                   2       2
+--R         b c d |- - log(-----------------------) + a d log(b x  + a)
+--R              \|  b                2
+--R                                b x  + a
+--R       + 
+--R             2
+--R         2b c log(d x + c)
+--R    /
+--R             3     2 2
+--R       2a b d  + 2b c d
+--R     ,
+--R                    +-+
+--R                    |a
+--R           +-+      |-
+--R           |a      \|b        2       2            2
+--R    2b c d |- atan(----) + a d log(b x  + a) + 2b c log(d x + c)
+--R          \|b        x
+--R    ------------------------------------------------------------]
+--R                                3     2 2
+--R                          2a b d  + 2b c d
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 901
+
+--S 902 of 1580
+m0a:=a0.1-r0
+--R 
+--R
+--R                              +---+
+--R                              |  a       2
+--R          +---+        - 2b x |- -  + b x  - a                 +-+
+--R          |  a  +-+          \|  b                   +-+     x\|b
+--R        c |- - \|b log(-----------------------) + 2c\|a atan(-----)
+--R         \|  b                    2                            +-+
+--R                               b x  + a                       \|a
+--R   (4)  -----------------------------------------------------------
+--R                                 2       2  +-+
+--R                            (2a d  + 2b c )\|b
+--R                                                    Type: Expression(Integer)
+--E 902
+
+--S 903 of 1580
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 903
+
+--S 904 of 1580
+m0b:=a0.2-r0
+--R 
+--R
+--R                                          +-+
+--R                                          |a
+--R                    +-+      +-+          |-
+--R          +-+     x\|b       |a  +-+     \|b
+--R        c\|a atan(-----) + c |- \|b atan(----)
+--R                    +-+     \|b            x
+--R                   \|a
+--R   (6)  --------------------------------------
+--R                       2      2  +-+
+--R                   (a d  + b c )\|b
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 1580
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 905
+
+)clear all
+
+--S 906 of 1580
+t0:=x^2/((c+d*x)*(a+b*x^3))
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R             4        3
+--R        b d x  + b c x  + a d x + a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 906
+
+--S 907 of 1580
+r0:=1/3*a^(1/3)*d*(b^(1/3)*c+a^(1/3)*d)*log(a^(1/3)+b^(1/3)*x)/(b^(2/3)*_
+   (b*c^3-a*d^3))-c^2*log(c+d*x)/(b*c^3-a*d^3)-1/6*a^(1/3)*d*(b^(1/3)*c+_
+   a^(1/3)*d)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(b^(2/3)*(b*c^3-_
+   a*d^3))+1/3*c^2*log(a+b*x^3)/(b*c^3-a*d^3)-a^(1/3)*d*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(b^(2/3)*(b^(2/3)*c^2+a^(1/3)*b^(1/3)*_
+   c*d+a^(2/3)*d^2)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              4      3   +-+3+-+3+-+2       2 2 +-+3+-+2 3+-+          3 +-+
+--R         ((a d  + b c d)\|3 \|a \|b   + 2b c d \|3 \|a   \|b + 2a b c d \|3 )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                    4       3   +-+3+-+3+-+2       2 2 +-+3+-+2 3+-+
+--R             (- 2a d  - 2b c d)\|3 \|a \|b   - 4b c d \|3 \|a   \|b
+--R           + 
+--R                       3 +-+
+--R             - 4a b c d \|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                                       3+-+   3+-+
+--R            4       3  3+-+3+-+2     2x\|b  - \|a
+--R       (6a d  - 6b c d)\|a \|b  atan(-------------)
+--R                                         +-+3+-+
+--R                                        \|3 \|a
+--R     + 
+--R              3  +-+       3            3  +-+             3+-+3+-+2
+--R       (- 2b c d\|3 log(b x  + a) + 6b c d\|3 log(d x + c))\|a \|b
+--R     + 
+--R              2 2 +-+       3            2 2 +-+             3+-+2 3+-+
+--R       (- 2b c d \|3 log(b x  + a) + 6b c d \|3 log(d x + c))\|a   \|b
+--R     + 
+--R           2 4 +-+       3          2 4 +-+
+--R       - 2b c \|3 log(b x  + a) + 6b c \|3 log(d x + c)
+--R  /
+--R                4     2 4   +-+3+-+3+-+2          5     2 3 2  +-+3+-+2 3+-+
+--R       (6a b c d  - 6b c d)\|3 \|a \|b   + (6a b d  - 6b c d )\|3 \|a   \|b
+--R     + 
+--R            2 2 3     3 5  +-+
+--R       (6a b c d  - 6b c )\|3
+--R                                                    Type: Expression(Integer)
+--E 907
+
+--S 908 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   3      3
+--R             (- a d  + b c )
+--R          *
+--R             ROOT
+--R                         2   6        2 3 3     3 6      2
+--R                    (- 9a b d  + 18a b c d  - 9b c )%%HH0
+--R                  + 
+--R                             2 3     2 5               3      4
+--R                    (- 6a b c d  + 6b c )%%HH0 + 4a c d  - b c
+--R               /
+--R                    2   6       2 3 3     3 6
+--R                  3a b d  - 6a b c d  + 3b c
+--R         + 
+--R                 3      3          2
+--R           (- a d  + b c )%%HH0 - c
+--R      *
+--R         log
+--R                       3     2 3
+--R                (9a b d  - 9b c )%%HH0
+--R             *
+--R                ROOT
+--R                            2   6        2 3 3     3 6      2
+--R                       (- 9a b d  + 18a b c d  - 9b c )%%HH0
+--R                     + 
+--R                                2 3     2 5               3      4
+--R                       (- 6a b c d  + 6b c )%%HH0 + 4a c d  - b c
+--R                  /
+--R                       2   6       2 3 3     3 6
+--R                     3a b d  - 6a b c d  + 3b c
+--R            + 
+--R                       3     2 3      2       2
+--R              (- 9a b d  + 9b c )%%HH0  - 9b c %%HH0 + 2d x + 2c
+--R     + 
+--R                 3      3
+--R             (a d  - b c )
+--R          *
+--R             ROOT
+--R                         2   6        2 3 3     3 6      2
+--R                    (- 9a b d  + 18a b c d  - 9b c )%%HH0
+--R                  + 
+--R                             2 3     2 5               3      4
+--R                    (- 6a b c d  + 6b c )%%HH0 + 4a c d  - b c
+--R               /
+--R                    2   6       2 3 3     3 6
+--R                  3a b d  - 6a b c d  + 3b c
+--R         + 
+--R                 3      3          2
+--R           (- a d  + b c )%%HH0 - c
+--R      *
+--R         log
+--R                         3     2 3
+--R                (- 9a b d  + 9b c )%%HH0
+--R             *
+--R                ROOT
+--R                            2   6        2 3 3     3 6      2
+--R                       (- 9a b d  + 18a b c d  - 9b c )%%HH0
+--R                     + 
+--R                                2 3     2 5               3      4
+--R                       (- 6a b c d  + 6b c )%%HH0 + 4a c d  - b c
+--R                  /
+--R                       2   6       2 3 3     3 6
+--R                     3a b d  - 6a b c d  + 3b c
+--R            + 
+--R                       3     2 3      2       2
+--R              (- 9a b d  + 9b c )%%HH0  - 9b c %%HH0 + 2d x + 2c
+--R     + 
+--R            3       3                  3     2 3      2       2
+--R       (2a d  - 2b c )%%HH0 log((9a b d  - 9b c )%%HH0  + 9b c %%HH0 + d x - 2c)
+--R     + 
+--R         2
+--R       2c log(d x + c)
+--R  /
+--R         3       3
+--R     2a d  - 2b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 908
+
+--S 909 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          4     2 4   +-+3+-+3+-+2
+--R               (- 3a b c d  + 3b c d)\|3 \|a \|b
+--R             + 
+--R                        5     2 3 2  +-+3+-+2 3+-+         2 2 3     3 5  +-+
+--R               (- 3a b d  + 3b c d )\|3 \|a   \|b + (- 3a b c d  + 3b c )\|3
+--R          *
+--R             ROOT
+--R                         2   6        2 3 3     3 6      2
+--R                    (- 9a b d  + 18a b c d  - 9b c )%%HH0
+--R                  + 
+--R                             2 3     2 5               3      4
+--R                    (- 6a b c d  + 6b c )%%HH0 + 4a c d  - b c
+--R               /
+--R                    2   6       2 3 3     3 6
+--R                  3a b d  - 6a b c d  + 3b c
+--R         + 
+--R                          4     2 4   +-+3+-+3+-+2
+--R               (- 3a b c d  + 3b c d)\|3 \|a \|b
+--R             + 
+--R                        5     2 3 2  +-+3+-+2 3+-+         2 2 3     3 5  +-+
+--R               (- 3a b d  + 3b c d )\|3 \|a   \|b + (- 3a b c d  + 3b c )\|3
+--R          *
+--R             %%HH0
+--R         + 
+--R                 3  +-+3+-+3+-+2       2 2 +-+3+-+2 3+-+    2 4 +-+
+--R           - 3b c d\|3 \|a \|b   - 3b c d \|3 \|a   \|b - 3b c \|3
+--R      *
+--R         log
+--R                       3     2 3
+--R                (9a b d  - 9b c )%%HH0
+--R             *
+--R                ROOT
+--R                            2   6        2 3 3     3 6      2
+--R                       (- 9a b d  + 18a b c d  - 9b c )%%HH0
+--R                     + 
+--R                                2 3     2 5               3      4
+--R                       (- 6a b c d  + 6b c )%%HH0 + 4a c d  - b c
+--R                  /
+--R                       2   6       2 3 3     3 6
+--R                     3a b d  - 6a b c d  + 3b c
+--R            + 
+--R                       3     2 3      2       2
+--R              (- 9a b d  + 9b c )%%HH0  - 9b c %%HH0 + 2d x + 2c
+--R     + 
+--R                        4     2 4   +-+3+-+3+-+2
+--R               (3a b c d  - 3b c d)\|3 \|a \|b
+--R             + 
+--R                      5     2 3 2  +-+3+-+2 3+-+       2 2 3     3 5  +-+
+--R               (3a b d  - 3b c d )\|3 \|a   \|b + (3a b c d  - 3b c )\|3
+--R          *
+--R             ROOT
+--R                         2   6        2 3 3     3 6      2
+--R                    (- 9a b d  + 18a b c d  - 9b c )%%HH0
+--R                  + 
+--R                             2 3     2 5               3      4
+--R                    (- 6a b c d  + 6b c )%%HH0 + 4a c d  - b c
+--R               /
+--R                    2   6       2 3 3     3 6
+--R                  3a b d  - 6a b c d  + 3b c
+--R         + 
+--R                          4     2 4   +-+3+-+3+-+2
+--R               (- 3a b c d  + 3b c d)\|3 \|a \|b
+--R             + 
+--R                        5     2 3 2  +-+3+-+2 3+-+         2 2 3     3 5  +-+
+--R               (- 3a b d  + 3b c d )\|3 \|a   \|b + (- 3a b c d  + 3b c )\|3
+--R          *
+--R             %%HH0
+--R         + 
+--R                 3  +-+3+-+3+-+2       2 2 +-+3+-+2 3+-+    2 4 +-+
+--R           - 3b c d\|3 \|a \|b   - 3b c d \|3 \|a   \|b - 3b c \|3
+--R      *
+--R         log
+--R                         3     2 3
+--R                (- 9a b d  + 9b c )%%HH0
+--R             *
+--R                ROOT
+--R                            2   6        2 3 3     3 6      2
+--R                       (- 9a b d  + 18a b c d  - 9b c )%%HH0
+--R                     + 
+--R                                2 3     2 5               3      4
+--R                       (- 6a b c d  + 6b c )%%HH0 + 4a c d  - b c
+--R                  /
+--R                       2   6       2 3 3     3 6
+--R                     3a b d  - 6a b c d  + 3b c
+--R            + 
+--R                       3     2 3      2       2
+--R              (- 9a b d  + 9b c )%%HH0  - 9b c %%HH0 + 2d x + 2c
+--R     + 
+--R                    4     2 4   +-+3+-+3+-+2          5     2 3 2  +-+3+-+2 3+-+
+--R           (6a b c d  - 6b c d)\|3 \|a \|b   + (6a b d  - 6b c d )\|3 \|a   \|b
+--R         + 
+--R                2 2 3     3 5  +-+
+--R           (6a b c d  - 6b c )\|3
+--R      *
+--R                          3     2 3      2       2
+--R         %%HH0 log((9a b d  - 9b c )%%HH0  + 9b c %%HH0 + d x - 2c)
+--R     + 
+--R                4      3   +-+3+-+3+-+2       2 2 +-+3+-+2 3+-+          3 +-+
+--R         ((- a d  - b c d)\|3 \|a \|b   - 2b c d \|3 \|a   \|b - 2a b c d \|3 )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               4       3   +-+3+-+3+-+2       2 2 +-+3+-+2 3+-+          3 +-+
+--R         ((2a d  + 2b c d)\|3 \|a \|b   + 4b c d \|3 \|a   \|b + 4a b c d \|3 )
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                                         3+-+   3+-+
+--R              4       3  3+-+3+-+2     2x\|b  - \|a
+--R       (- 6a d  + 6b c d)\|a \|b  atan(-------------)
+--R                                           +-+3+-+
+--R                                          \|3 \|a
+--R     + 
+--R           3  +-+       3     3+-+3+-+2       2 2 +-+       3     3+-+2 3+-+
+--R       2b c d\|3 log(b x  + a)\|a \|b   + 2b c d \|3 log(b x  + a)\|a   \|b
+--R     + 
+--R         2 4 +-+       3
+--R       2b c \|3 log(b x  + a)
+--R  /
+--R                4     2 4   +-+3+-+3+-+2          5     2 3 2  +-+3+-+2 3+-+
+--R       (6a b c d  - 6b c d)\|3 \|a \|b   + (6a b d  - 6b c d )\|3 \|a   \|b
+--R     + 
+--R            2 2 3     3 5  +-+
+--R       (6a b c d  - 6b c )\|3
+--R                                                    Type: Expression(Integer)
+--E 909
+
+--S 910 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 910
+
+)clear all
+
+--S 911 of 1580
+t0:=x^2/((c+d*x)*(a+b*x^4))
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R             5        4
+--R        b d x  + b c x  + a d x + a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 911
+
+--S 912 of 1580
+r0:=c^2*d*log(c+d*x)/(b*c^4+a*d^4)-1/4*c^2*d*log(a+b*x^4)/(b*c^4+a*d^4)+_
+   1/2*d^3*atan(x^2*sqrt(b)/sqrt(a))*sqrt(a)/((b*c^4+a*d^4)*sqrt(b))-_
+   1/2*c*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(-d^2*sqrt(a)+c^2*sqrt(b))/_
+   (a^(1/4)*b^(1/4)*(b*c^4+a*d^4)*sqrt(2))+1/2*c*atan(1+b^(1/4)*x*_
+   sqrt(2)/a^(1/4))*(-d^2*sqrt(a)+c^2*sqrt(b))/(a^(1/4)*b^(1/4)*_
+   (b*c^4+a*d^4)*sqrt(2))+1/4*c*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+_
+   x^2*sqrt(b))*(d^2*sqrt(a)+c^2*sqrt(b))/(a^(1/4)*b^(1/4)*(b*c^4+a*d^4)*_
+   sqrt(2))-1/4*c*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*_
+   (d^2*sqrt(a)+c^2*sqrt(b))/(a^(1/4)*b^(1/4)*(b*c^4+a*d^4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2 +-+ +-+      3       +-+4+-+4+-+    2 +-+    +-+
+--R       (- c d \|a \|b  - b c )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R           2 +-+ +-+      3         +-+4+-+4+-+    2 +-+    +-+
+--R       (c d \|a \|b  + b c )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                       +-+4+-+   4+-+
+--R              2 +-+ +-+       3      x\|2 \|b  + \|a
+--R       (- 2c d \|a \|b  + 2b c )atan(----------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                       +-+4+-+   4+-+
+--R              2 +-+ +-+       3      x\|2 \|b  - \|a
+--R       (- 2c d \|a \|b  + 2b c )atan(----------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                2 +-+
+--R         3 +-+ +-+4+-+4+-+     x \|b
+--R       2d \|2 \|a \|a \|b atan(------)
+--R                                 +-+
+--R                                \|a
+--R     + 
+--R           2  +-+       4          2  +-+             4+-+ +-+4+-+
+--R       (- c d\|2 log(b x  + a) + 4c d\|2 log(d x + c))\|a \|b \|b
+--R  /
+--R          4       4  +-+4+-+ +-+4+-+
+--R     (4a d  + 4b c )\|2 \|a \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 912
+
+--S 913 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 4      4
+--R             (a d  + b c )
+--R          *
+--R             ROOT
+--R                         2   8        2 4 4     3 8      2
+--R                    (- 6a b d  - 12a b c d  - 6b c )%%HI1
+--R                  + 
+--R                               2   8       2 4 4     3 8               2 5
+--R                          (- 4a b d  - 8a b c d  - 4b c )%%HI0 - 4a b c d
+--R                        + 
+--R                              2 6
+--R                          - 4b c d
+--R                   *
+--R                      %%HI1
+--R                  + 
+--R                         2   8        2 4 4     3 8      2
+--R                    (- 6a b d  - 12a b c d  - 6b c )%%HI0
+--R                  + 
+--R                             2 5     2 6             6      4 2
+--R                    (- 4a b c d  - 4b c d)%%HI0 - a d  + b c d
+--R               /
+--R                    2   8       2 4 4     3 8
+--R                  2a b d  + 4a b c d  + 2b c
+--R         + 
+--R                 4      4               4      4          2
+--R           (- a d  - b c )%%HI1 + (- a d  - b c )%%HI0 - c d
+--R      *
+--R         log
+--R                          3   8      2 2 4 4        3 8           2   2 5
+--R                      (64a b d  + 32a b c d  - 32a b c )%%HI0 - 8a b c d
+--R                    + 
+--R                            2 6
+--R                      - 8a b c d
+--R                 *
+--R                    %%HI1
+--R                + 
+--R                       2   2 5       2 6            2 6         4 2
+--R                  (- 8a b c d  - 8a b c d)%%HI0 - 4a d  - 4a b c d
+--R             *
+--R                ROOT
+--R                            2   8        2 4 4     3 8      2
+--R                       (- 6a b d  - 12a b c d  - 6b c )%%HI1
+--R                     + 
+--R                                2   8       2 4 4     3 8               2 5
+--R                           (- 4a b d  - 8a b c d  - 4b c )%%HI0 - 4a b c d
+--R                         + 
+--R                               2 6
+--R                           - 4b c d
+--R                      *
+--R                         %%HI1
+--R                     + 
+--R                            2   8        2 4 4     3 8      2
+--R                       (- 6a b d  - 12a b c d  - 6b c )%%HI0
+--R                     + 
+--R                                2 5     2 6             6      4 2
+--R                       (- 4a b c d  - 4b c d)%%HI0 - a d  + b c d
+--R                  /
+--R                       2   8       2 4 4     3 8
+--R                     2a b d  + 4a b c d  + 2b c
+--R            + 
+--R                     3   8      2 2 4 4        3 8           2   2 5       2 6
+--R                ((64a b d  + 32a b c d  - 32a b c )%%HI0 - 8a b c d  - 8a b c d)
+--R             *
+--R                     2
+--R                %%HI1
+--R            + 
+--R                      3   8      2 2 4 4        3 8      2
+--R                  (64a b d  + 32a b c d  - 32a b c )%%HI0
+--R                + 
+--R                      2   2 5        2 6            2 6         4 2
+--R                  (64a b c d  - 32a b c d)%%HI0 + 4a d  - 4a b c d
+--R             *
+--R                %%HI1
+--R            + 
+--R                   2   2 5       2 6       2      2 6         4 2
+--R              (- 8a b c d  - 8a b c d)%%HI0  + (4a d  - 4a b c d )%%HI0
+--R            + 
+--R                     4      5        2 3
+--R              (4a c d  - b c )x + a c d
+--R     + 
+--R                   4      4
+--R             (- a d  - b c )
+--R          *
+--R             ROOT
+--R                         2   8        2 4 4     3 8      2
+--R                    (- 6a b d  - 12a b c d  - 6b c )%%HI1
+--R                  + 
+--R                               2   8       2 4 4     3 8               2 5
+--R                          (- 4a b d  - 8a b c d  - 4b c )%%HI0 - 4a b c d
+--R                        + 
+--R                              2 6
+--R                          - 4b c d
+--R                   *
+--R                      %%HI1
+--R                  + 
+--R                         2   8        2 4 4     3 8      2
+--R                    (- 6a b d  - 12a b c d  - 6b c )%%HI0
+--R                  + 
+--R                             2 5     2 6             6      4 2
+--R                    (- 4a b c d  - 4b c d)%%HI0 - a d  + b c d
+--R               /
+--R                    2   8       2 4 4     3 8
+--R                  2a b d  + 4a b c d  + 2b c
+--R         + 
+--R                 4      4               4      4          2
+--R           (- a d  - b c )%%HI1 + (- a d  - b c )%%HI0 - c d
+--R      *
+--R         log
+--R                            3   8      2 2 4 4        3 8           2   2 5
+--R                      (- 64a b d  - 32a b c d  + 32a b c )%%HI0 + 8a b c d
+--R                    + 
+--R                          2 6
+--R                      8a b c d
+--R                 *
+--R                    %%HI1
+--R                + 
+--R                     2   2 5       2 6            2 6         4 2
+--R                  (8a b c d  + 8a b c d)%%HI0 + 4a d  + 4a b c d
+--R             *
+--R                ROOT
+--R                            2   8        2 4 4     3 8      2
+--R                       (- 6a b d  - 12a b c d  - 6b c )%%HI1
+--R                     + 
+--R                                2   8       2 4 4     3 8               2 5
+--R                           (- 4a b d  - 8a b c d  - 4b c )%%HI0 - 4a b c d
+--R                         + 
+--R                               2 6
+--R                           - 4b c d
+--R                      *
+--R                         %%HI1
+--R                     + 
+--R                            2   8        2 4 4     3 8      2
+--R                       (- 6a b d  - 12a b c d  - 6b c )%%HI0
+--R                     + 
+--R                                2 5     2 6             6      4 2
+--R                       (- 4a b c d  - 4b c d)%%HI0 - a d  + b c d
+--R                  /
+--R                       2   8       2 4 4     3 8
+--R                     2a b d  + 4a b c d  + 2b c
+--R            + 
+--R                     3   8      2 2 4 4        3 8           2   2 5       2 6
+--R                ((64a b d  + 32a b c d  - 32a b c )%%HI0 - 8a b c d  - 8a b c d)
+--R             *
+--R                     2
+--R                %%HI1
+--R            + 
+--R                      3   8      2 2 4 4        3 8      2
+--R                  (64a b d  + 32a b c d  - 32a b c )%%HI0
+--R                + 
+--R                      2   2 5        2 6            2 6         4 2
+--R                  (64a b c d  - 32a b c d)%%HI0 + 4a d  - 4a b c d
+--R             *
+--R                %%HI1
+--R            + 
+--R                   2   2 5       2 6       2      2 6         4 2
+--R              (- 8a b c d  - 8a b c d)%%HI0  + (4a d  - 4a b c d )%%HI0
+--R            + 
+--R                     4      5        2 3
+--R              (4a c d  - b c )x + a c d
+--R     + 
+--R              4       4
+--R         (2a d  + 2b c )%%HI1
+--R      *
+--R         log
+--R                         3   8      2 2 4 4        3 8            2   2 5
+--R                  (- 128a b d  - 64a b c d  + 64a b c )%%HI0 + 16a b c d
+--R                + 
+--R                       2 6
+--R                  16a b c d
+--R             *
+--R                     2
+--R                %%HI1
+--R            + 
+--R                         3   8      2 2 4 4        3 8      2
+--R                  (- 128a b d  - 64a b c d  + 64a b c )%%HI0
+--R                + 
+--R                         2   2 5        2 6            2 6         4 2
+--R                  (- 128a b c d  + 64a b c d)%%HI0 - 8a d  + 8a b c d
+--R             *
+--R                %%HI1
+--R            + 
+--R                     3   8      2 2 4 4        3 8      3
+--R              (- 128a b d  - 64a b c d  + 64a b c )%%HI0
+--R            + 
+--R                     2   2 5        2 6       2         2 6         4 2
+--R              (- 128a b c d  + 64a b c d)%%HI0  + (- 16a d  + 8a b c d )%%HI0
+--R            + 
+--R                     4      5        2 3
+--R              (4a c d  - b c )x - a c d
+--R     + 
+--R              4       4
+--R         (2a d  + 2b c )%%HI0
+--R      *
+--R         log
+--R                   3   8      2 2 4 4        3 8      3
+--R              (128a b d  + 64a b c d  - 64a b c )%%HI0
+--R            + 
+--R                   2   2 5        2 6       2     2 6               4      5
+--R              (144a b c d  - 48a b c d)%%HI0  + 8a d %%HI0 + (4a c d  - b c )x
+--R            + 
+--R                   2 3
+--R              - a c d
+--R     + 
+--R         2
+--R       2c d log(d x + c)
+--R  /
+--R         4       4
+--R     2a d  + 2b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 913
+
+--S 914 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  4       4  +-+4+-+ +-+4+-+
+--R             (2a d  + 2b c )\|2 \|a \|b \|b
+--R          *
+--R             ROOT
+--R                         2   8        2 4 4     3 8      2
+--R                    (- 6a b d  - 12a b c d  - 6b c )%%HI1
+--R                  + 
+--R                               2   8       2 4 4     3 8               2 5
+--R                          (- 4a b d  - 8a b c d  - 4b c )%%HI0 - 4a b c d
+--R                        + 
+--R                              2 6
+--R                          - 4b c d
+--R                   *
+--R                      %%HI1
+--R                  + 
+--R                         2   8        2 4 4     3 8      2
+--R                    (- 6a b d  - 12a b c d  - 6b c )%%HI0
+--R                  + 
+--R                             2 5     2 6             6      4 2
+--R                    (- 4a b c d  - 4b c d)%%HI0 - a d  + b c d
+--R               /
+--R                    2   8       2 4 4     3 8
+--R                  2a b d  + 4a b c d  + 2b c
+--R         + 
+--R                  4       4  +-+4+-+ +-+4+-+
+--R           (- 2a d  - 2b c )\|2 \|a \|b \|b %%HI1
+--R         + 
+--R                  4       4  +-+4+-+ +-+4+-+          2  +-+4+-+ +-+4+-+
+--R           (- 2a d  - 2b c )\|2 \|a \|b \|b %%HI0 - 2c d\|2 \|a \|b \|b
+--R      *
+--R         log
+--R                          3   8      2 2 4 4        3 8           2   2 5
+--R                      (64a b d  + 32a b c d  - 32a b c )%%HI0 - 8a b c d
+--R                    + 
+--R                            2 6
+--R                      - 8a b c d
+--R                 *
+--R                    %%HI1
+--R                + 
+--R                       2   2 5       2 6            2 6         4 2
+--R                  (- 8a b c d  - 8a b c d)%%HI0 - 4a d  - 4a b c d
+--R             *
+--R                ROOT
+--R                            2   8        2 4 4     3 8      2
+--R                       (- 6a b d  - 12a b c d  - 6b c )%%HI1
+--R                     + 
+--R                                2   8       2 4 4     3 8               2 5
+--R                           (- 4a b d  - 8a b c d  - 4b c )%%HI0 - 4a b c d
+--R                         + 
+--R                               2 6
+--R                           - 4b c d
+--R                      *
+--R                         %%HI1
+--R                     + 
+--R                            2   8        2 4 4     3 8      2
+--R                       (- 6a b d  - 12a b c d  - 6b c )%%HI0
+--R                     + 
+--R                                2 5     2 6             6      4 2
+--R                       (- 4a b c d  - 4b c d)%%HI0 - a d  + b c d
+--R                  /
+--R                       2   8       2 4 4     3 8
+--R                     2a b d  + 4a b c d  + 2b c
+--R            + 
+--R                     3   8      2 2 4 4        3 8           2   2 5       2 6
+--R                ((64a b d  + 32a b c d  - 32a b c )%%HI0 - 8a b c d  - 8a b c d)
+--R             *
+--R                     2
+--R                %%HI1
+--R            + 
+--R                      3   8      2 2 4 4        3 8      2
+--R                  (64a b d  + 32a b c d  - 32a b c )%%HI0
+--R                + 
+--R                      2   2 5        2 6            2 6         4 2
+--R                  (64a b c d  - 32a b c d)%%HI0 + 4a d  - 4a b c d
+--R             *
+--R                %%HI1
+--R            + 
+--R                   2   2 5       2 6       2      2 6         4 2
+--R              (- 8a b c d  - 8a b c d)%%HI0  + (4a d  - 4a b c d )%%HI0
+--R            + 
+--R                     4      5        2 3
+--R              (4a c d  - b c )x + a c d
+--R     + 
+--R                    4       4  +-+4+-+ +-+4+-+
+--R             (- 2a d  - 2b c )\|2 \|a \|b \|b
+--R          *
+--R             ROOT
+--R                         2   8        2 4 4     3 8      2
+--R                    (- 6a b d  - 12a b c d  - 6b c )%%HI1
+--R                  + 
+--R                               2   8       2 4 4     3 8               2 5
+--R                          (- 4a b d  - 8a b c d  - 4b c )%%HI0 - 4a b c d
+--R                        + 
+--R                              2 6
+--R                          - 4b c d
+--R                   *
+--R                      %%HI1
+--R                  + 
+--R                         2   8        2 4 4     3 8      2
+--R                    (- 6a b d  - 12a b c d  - 6b c )%%HI0
+--R                  + 
+--R                             2 5     2 6             6      4 2
+--R                    (- 4a b c d  - 4b c d)%%HI0 - a d  + b c d
+--R               /
+--R                    2   8       2 4 4     3 8
+--R                  2a b d  + 4a b c d  + 2b c
+--R         + 
+--R                  4       4  +-+4+-+ +-+4+-+
+--R           (- 2a d  - 2b c )\|2 \|a \|b \|b %%HI1
+--R         + 
+--R                  4       4  +-+4+-+ +-+4+-+          2  +-+4+-+ +-+4+-+
+--R           (- 2a d  - 2b c )\|2 \|a \|b \|b %%HI0 - 2c d\|2 \|a \|b \|b
+--R      *
+--R         log
+--R                            3   8      2 2 4 4        3 8           2   2 5
+--R                      (- 64a b d  - 32a b c d  + 32a b c )%%HI0 + 8a b c d
+--R                    + 
+--R                          2 6
+--R                      8a b c d
+--R                 *
+--R                    %%HI1
+--R                + 
+--R                     2   2 5       2 6            2 6         4 2
+--R                  (8a b c d  + 8a b c d)%%HI0 + 4a d  + 4a b c d
+--R             *
+--R                ROOT
+--R                            2   8        2 4 4     3 8      2
+--R                       (- 6a b d  - 12a b c d  - 6b c )%%HI1
+--R                     + 
+--R                                2   8       2 4 4     3 8               2 5
+--R                           (- 4a b d  - 8a b c d  - 4b c )%%HI0 - 4a b c d
+--R                         + 
+--R                               2 6
+--R                           - 4b c d
+--R                      *
+--R                         %%HI1
+--R                     + 
+--R                            2   8        2 4 4     3 8      2
+--R                       (- 6a b d  - 12a b c d  - 6b c )%%HI0
+--R                     + 
+--R                                2 5     2 6             6      4 2
+--R                       (- 4a b c d  - 4b c d)%%HI0 - a d  + b c d
+--R                  /
+--R                       2   8       2 4 4     3 8
+--R                     2a b d  + 4a b c d  + 2b c
+--R            + 
+--R                     3   8      2 2 4 4        3 8           2   2 5       2 6
+--R                ((64a b d  + 32a b c d  - 32a b c )%%HI0 - 8a b c d  - 8a b c d)
+--R             *
+--R                     2
+--R                %%HI1
+--R            + 
+--R                      3   8      2 2 4 4        3 8      2
+--R                  (64a b d  + 32a b c d  - 32a b c )%%HI0
+--R                + 
+--R                      2   2 5        2 6            2 6         4 2
+--R                  (64a b c d  - 32a b c d)%%HI0 + 4a d  - 4a b c d
+--R             *
+--R                %%HI1
+--R            + 
+--R                   2   2 5       2 6       2      2 6         4 2
+--R              (- 8a b c d  - 8a b c d)%%HI0  + (4a d  - 4a b c d )%%HI0
+--R            + 
+--R                     4      5        2 3
+--R              (4a c d  - b c )x + a c d
+--R     + 
+--R              4       4  +-+4+-+ +-+4+-+
+--R         (4a d  + 4b c )\|2 \|a \|b \|b %%HI1
+--R      *
+--R         log
+--R                         3   8      2 2 4 4        3 8            2   2 5
+--R                  (- 128a b d  - 64a b c d  + 64a b c )%%HI0 + 16a b c d
+--R                + 
+--R                       2 6
+--R                  16a b c d
+--R             *
+--R                     2
+--R                %%HI1
+--R            + 
+--R                         3   8      2 2 4 4        3 8      2
+--R                  (- 128a b d  - 64a b c d  + 64a b c )%%HI0
+--R                + 
+--R                         2   2 5        2 6            2 6         4 2
+--R                  (- 128a b c d  + 64a b c d)%%HI0 - 8a d  + 8a b c d
+--R             *
+--R                %%HI1
+--R            + 
+--R                     3   8      2 2 4 4        3 8      3
+--R              (- 128a b d  - 64a b c d  + 64a b c )%%HI0
+--R            + 
+--R                     2   2 5        2 6       2         2 6         4 2
+--R              (- 128a b c d  + 64a b c d)%%HI0  + (- 16a d  + 8a b c d )%%HI0
+--R            + 
+--R                     4      5        2 3
+--R              (4a c d  - b c )x - a c d
+--R     + 
+--R              4       4  +-+4+-+ +-+4+-+
+--R         (4a d  + 4b c )\|2 \|a \|b \|b %%HI0
+--R      *
+--R         log
+--R                   3   8      2 2 4 4        3 8      3
+--R              (128a b d  + 64a b c d  - 64a b c )%%HI0
+--R            + 
+--R                   2   2 5        2 6       2     2 6               4      5
+--R              (144a b c d  - 48a b c d)%%HI0  + 8a d %%HI0 + (4a c d  - b c )x
+--R            + 
+--R                   2 3
+--R              - a c d
+--R     + 
+--R           2 +-+ +-+      3       +-+4+-+4+-+    2 +-+    +-+
+--R       (c d \|a \|b  + b c )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R             2 +-+ +-+      3         +-+4+-+4+-+    2 +-+    +-+
+--R       (- c d \|a \|b  - b c )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R            2 +-+ +-+       3      x\|2 \|b  + \|a
+--R       (2c d \|a \|b  - 2b c )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R            2 +-+ +-+       3      x\|2 \|b  - \|a
+--R       (2c d \|a \|b  - 2b c )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                  2 +-+
+--R           3 +-+ +-+4+-+4+-+     x \|b      2  +-+       4     4+-+ +-+4+-+
+--R       - 2d \|2 \|a \|a \|b atan(------) + c d\|2 log(b x  + a)\|a \|b \|b
+--R                                   +-+
+--R                                  \|a
+--R  /
+--R          4       4  +-+4+-+ +-+4+-+
+--R     (4a d  + 4b c )\|2 \|a \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 914
+
+--S 915 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       2 6       3 4         2 2      3  +-+4+-+2        3 4
+--R               (- b c d x  + 5b c x  - 5a c d x  + a c )\|a \|a   + a b c x
+--R             + 
+--R                 2   2 2    2 3
+--R               2a c d x  - a c
+--R          *
+--R              +-+
+--R             \|b
+--R         + 
+--R             2 3 6          2 4        3 2    2   2 4+-+2
+--R           (b c x  - a b c d x  + a b c x  - a c d )\|a
+--R         + 
+--R                     2 4         3 2    2   2  +-+
+--R           (- a b c d x  - 2a b c x  + a c d )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R           2 3 6           2 4        3 2 4+-+2 +-+
+--R       (- b c x  + 2a b c d x  + a b c x )\|a  \|b
+--R     + 
+--R         2   2 6     2 3 4          2 2  +-+4+-+2       2 3 4     2     2 2
+--R       (b c d x  - 2b c x  - a b c d x )\|a \|a   - 4a b c x  + 4a b c d x
+--R  /
+--R                   4     2 4  6      2 4         4  2  +-+4+-+2 +-+
+--R           ((4a b d  + 4b c )x  + (4a d  + 4a b c )x )\|a \|a  \|b
+--R         + 
+--R                 2 4     3 4  8      2   4       2 4  4     3 4     2   4 4+-+2
+--R           ((2a b d  + 2b c )x  + (4a b d  + 4a b c )x  + 2a d  + 2a b c )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R            2 2 4       3 4  6        3   4     2 2 4  2
+--R       (- 4a b d  - 4a b c )x  + (- 4a b d  - 4a b c )x
+--R                                                    Type: Expression(Integer)
+--E 915
+
+)clear all
+
+--S 916 of 1580
+t0:=x/((1-x)*(1+x)^2)
+--R 
+--R
+--R                 x
+--R   (1)  - ---------------
+--R           3    2
+--R          x  + x  - x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 916
+
+--S 917 of 1580
+r0:=1/2/(1+x)+1/2*atanh(x)
+--R 
+--R
+--R        (x + 1)atanh(x) + 1
+--R   (2)  -------------------
+--R               2x + 2
+--R                                                    Type: Expression(Integer)
+--E 917
+
+--S 918 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (x + 1)log(x + 1) + (- x - 1)log(x - 1) + 2
+--R   (3)  -------------------------------------------
+--R                           4x + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 918
+
+--S 919 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        log(x + 1) - log(x - 1) - 2atanh(x)
+--R   (4)  -----------------------------------
+--R                         4
+--R                                                    Type: Expression(Integer)
+--E 919
+
+--S 920 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 920
+
+)clear all
+
+--S 921 of 1580
+t0:=x^2/((1-x^2)*(1+x^2)^2)
+--R 
+--R
+--R                  2
+--R                 x
+--R   (1)  - ----------------
+--R           6    4    2
+--R          x  + x  - x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 921
+
+--S 922 of 1580
+r0:=-1/4*x/(1+x^2)+1/4*atanh(x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atanh(x) - x
+--R   (2)  --------------------
+--R                 2
+--R               4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2                      2
+--R        (x  + 1)log(x + 1) + (- x  - 1)log(x - 1) - 2x
+--R   (3)  ----------------------------------------------
+--R                              2
+--R                            8x  + 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 923
+
+--S 924 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        log(x + 1) - log(x - 1) - 2atanh(x)
+--R   (4)  -----------------------------------
+--R                         8
+--R                                                    Type: Expression(Integer)
+--E 924
+
+--S 925 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 925
+
+)clear all
+
+--S 926 of 1580
+t0:=x^3/((1-x^3)*(1+x^3)^2)
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  - ----------------
+--R           9    6    3
+--R          x  + x  - x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 926
+
+--S 927 of 1580
+r0:=-1/6*x/(1+x^3)+1/6*atanh(x)-1/9*log(1+x)+1/72*log(1-x+x^2)+_
+   1/24*log(1+x+x^2)+1/12*atan((1-2*x)/sqrt(3))/sqrt(3)+_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3),1/18/(1+x)+1/18*(-1-x)/(1-x+x^2)-_
+   1/12*log(1-x)-1/36*log(1+x)+1/72*log(1-x+x^2)+1/24*log(1+x+x^2)+_
+   1/12*atan((1-2*x)/sqrt(3))/sqrt(3)+1/4*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R   [
+--R            3      +-+     2              3      +-+     2
+--R         (3x  + 3)\|3 log(x  + x + 1) + (x  + 1)\|3 log(x  - x + 1)
+--R       + 
+--R              3      +-+                 3       +-+
+--R         (- 8x  - 8)\|3 log(x + 1) + (12x  + 12)\|3 atanh(x)
+--R       + 
+--R                                +-+                             +-+
+--R           3           (2x + 1)\|3          3          (2x - 1)\|3         +-+
+--R       (18x  + 18)atan(------------) + (- 6x  - 6)atan(------------) - 12x\|3
+--R                             3                               3
+--R    /
+--R           3       +-+
+--R       (72x  + 72)\|3
+--R     ,
+--R
+--R            3      +-+     2              3      +-+     2
+--R         (3x  + 3)\|3 log(x  + x + 1) + (x  + 1)\|3 log(x  - x + 1)
+--R       + 
+--R              3      +-+                  3      +-+
+--R         (- 2x  - 2)\|3 log(x + 1) + (- 6x  - 6)\|3 log(- x + 1)
+--R       + 
+--R                                +-+                             +-+
+--R           3           (2x + 1)\|3          3          (2x - 1)\|3         +-+
+--R       (18x  + 18)atan(------------) + (- 6x  - 6)atan(------------) - 12x\|3
+--R                             3                               3
+--R    /
+--R           3       +-+
+--R       (72x  + 72)\|3
+--R     ]
+--R                                             Type: Tuple(Expression(Integer))
+--E 927
+
+--S 928 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3      +-+     2              3      +-+     2
+--R       (3x  + 3)\|3 log(x  + x + 1) + (x  + 1)\|3 log(x  - x + 1)
+--R     + 
+--R            3      +-+                  3      +-+
+--R       (- 2x  - 2)\|3 log(x + 1) + (- 6x  - 6)\|3 log(x - 1)
+--R     + 
+--R                                +-+                             +-+
+--R           3           (2x + 1)\|3          3          (2x - 1)\|3         +-+
+--R       (18x  + 18)atan(------------) + (- 6x  - 6)atan(------------) - 12x\|3
+--R                             3                               3
+--R  /
+--R         3       +-+
+--R     (72x  + 72)\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 928
+
+--S 929 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        log(x + 1) - log(x - 1) - 2atanh(x)
+--R   (4)  -----------------------------------
+--R                         12
+--R                                                    Type: Expression(Integer)
+--E 929
+
+--S 930 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 930
+
+)clear all
+
+--S 931 of 1580
+t0:=(9+x+3*x^2+x^3)/((1+x^2)*(3+x^2))
+--R 
+--R
+--R         3     2
+--R        x  + 3x  + x + 9
+--R   (1)  ----------------
+--R           4     2
+--R          x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 931
+
+--S 932 of 1580
+r0:=3*atan(x)+1/2*log(3+x^2)
+--R 
+--R
+--R             2
+--R        log(x  + 3) + 6atan(x)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 932
+
+--S 933 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R        log(x  + 3) + 6atan(x)
+--R   (3)  ----------------------
+--R                   2
+--R                                         Type: Union(Expression(Integer),...)
+--E 933
+
+--S 934 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 934
+
+--S 935 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 935
+
+)clear all
+
+--S 936 of 1580
+t0:=(3+x+x^2+x^3)/((1+x^2)*(3+x^2))
+--R 
+--R
+--R         3    2
+--R        x  + x  + x + 3
+--R   (1)  ---------------
+--R           4     2
+--R          x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 936
+
+--S 937 of 1580
+r0:=atan(x)+1/2*log(3+x^2)
+--R 
+--R
+--R             2
+--R        log(x  + 3) + 2atan(x)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 937
+
+--S 938 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R        log(x  + 3) + 2atan(x)
+--R   (3)  ----------------------
+--R                   2
+--R                                         Type: Union(Expression(Integer),...)
+--E 938
+
+--S 939 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 939
+
+--S 940 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 940
+
+)clear all
+
+--S 941 of 1580
+t0:=(-4+6*x-x^2+3*x^3)/((1+x^2)*(2+x^2))
+--R 
+--R
+--R          3    2
+--R        3x  - x  + 6x - 4
+--R   (1)  -----------------
+--R            4     2
+--R           x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 941
+
+--S 942 of 1580
+r0:=-3*atan(x)+3/2*log(1+x^2)+atan(x/sqrt(2))*sqrt(2)
+--R 
+--R
+--R                                   +-+
+--R              2          +-+     x\|2
+--R        3log(x  + 1) + 2\|2 atan(-----) - 6atan(x)
+--R                                   2
+--R   (2)  ------------------------------------------
+--R                             2
+--R                                                    Type: Expression(Integer)
+--E 942
+
+--S 943 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                  +-+
+--R              2          +-+     \|2
+--R        3log(x  + 1) - 2\|2 atan(----) - 6atan(x)
+--R                                   x
+--R   (3)  -----------------------------------------
+--R                            2
+--R                                         Type: Union(Expression(Integer),...)
+--E 943
+
+--S 944 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                     +-+              +-+
+--R           +-+     x\|2      +-+     \|2
+--R   (4)  - \|2 atan(-----) - \|2 atan(----)
+--R                     2                 x
+--R                                                    Type: Expression(Integer)
+--E 944
+
+--S 945 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 945
+
+)clear all
+
+--S 946 of 1580
+t0:=(1-3*x^4)/((-2+x)*(1+x^2)^2)
+--R 
+--R
+--R                      4
+--R                  - 3x  + 1
+--R   (1)  ----------------------------
+--R         5     4     3     2
+--R        x  - 2x  + 2x  - 4x  + x - 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 946
+
+--S 947 of 1580
+r0:=1/5*(-1+2*x)/(1+x^2)-46/25*atan(x)-47/25*log(2-x)-14/25*log(1+x^2)
+--R 
+--R
+--R   (2)
+--R             2           2              2
+--R       (- 14x  - 14)log(x  + 1) + (- 47x  - 47)log(- x + 2)
+--R     + 
+--R             2
+--R       (- 46x  - 46)atan(x) + 10x - 5
+--R  /
+--R        2
+--R     25x  + 25
+--R                                                    Type: Expression(Integer)
+--E 947
+
+--S 948 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2           2              2                         2
+--R       (- 14x  - 14)log(x  + 1) + (- 47x  - 47)log(x - 2) + (- 46x  - 46)atan(x)
+--R     + 
+--R       10x - 5
+--R  /
+--R        2
+--R     25x  + 25
+--R                                         Type: Union(Expression(Integer),...)
+--E 948
+
+--S 949 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        - 47log(x - 2) + 47log(- x + 2)
+--R   (4)  -------------------------------
+--R                       25
+--R                                                    Type: Expression(Integer)
+--E 949
+
+--S 950 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 950
+
+)clear all
+
+--S 951 of 1580
+t0:=(-9-9*x+2*x^2)/(-9*x+x^3)
+--R 
+--R
+--R          2
+--R        2x  - 9x - 9
+--R   (1)  ------------
+--R            3
+--R           x  - 9x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 951
+
+--S 952 of 1580
+r0:=-log(3-x)+log(x)+2*log(3+x)
+--R 
+--R
+--R   (2)  2log(x + 3) + log(x) - log(- x + 3)
+--R                                                    Type: Expression(Integer)
+--E 952
+
+--S 953 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  2log(x + 3) + log(x) - log(x - 3)
+--R                                         Type: Union(Expression(Integer),...)
+--E 953
+
+--S 954 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  - log(x - 3) + log(- x + 3)
+--R                                                    Type: Expression(Integer)
+--E 954
+
+--S 955 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 955
+
+)clear all
+
+--S 956 of 1580
+t0:=(1+2*x^2+x^5)/(-x+x^3)
+--R 
+--R
+--R         5     2
+--R        x  + 2x  + 1
+--R   (1)  ------------
+--R            3
+--R           x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 956
+
+--S 957 of 1580
+r0:=x+1/3*x^3+2*log(1-x)-log(x)+log(1+x)
+--R 
+--R
+--R                                                 3
+--R        3log(x + 1) - 3log(x) + 6log(- x + 1) + x  + 3x
+--R   (2)  -----------------------------------------------
+--R                               3
+--R                                                    Type: Expression(Integer)
+--E 957
+
+--S 958 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                               3
+--R        3log(x + 1) - 3log(x) + 6log(x - 1) + x  + 3x
+--R   (3)  ---------------------------------------------
+--R                              3
+--R                                         Type: Union(Expression(Integer),...)
+--E 958
+
+--S 959 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  2log(x - 1) - 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 959
+
+--S 960 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 960
+
+)clear all
+
+--S 961 of 1580
+t0:=(3+2*x^2)/((-1+x)^2*x)
+--R 
+--R
+--R             2
+--R           2x  + 3
+--R   (1)  ------------
+--R         3     2
+--R        x  - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 961
+
+--S 962 of 1580
+r0:=5/(1-x)-log(1-x)+3*log(x)
+--R 
+--R
+--R        (3x - 3)log(x) + (- x + 1)log(- x + 1) - 5
+--R   (2)  ------------------------------------------
+--R                           x - 1
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (3x - 3)log(x) + (- x + 1)log(x - 1) - 5
+--R   (3)  ----------------------------------------
+--R                          x - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 963
+
+--S 964 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  - log(x - 1) + log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 964
+
+--S 965 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 965
+
+)clear all
+
+--S 966 of 1580
+t0:=(-1+2*x^2)/((-1+4*x)*(1+x^2))
+--R 
+--R
+--R               2
+--R             2x  - 1
+--R   (1)  -----------------
+--R          3    2
+--R        4x  - x  + 4x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 966
+
+--S 967 of 1580
+r0:=3/17*atan(x)-7/34*log(1-4*x)+6/17*log(1+x^2)
+--R 
+--R
+--R               2
+--R        12log(x  + 1) - 7log(- 4x + 1) + 6atan(x)
+--R   (2)  -----------------------------------------
+--R                            34
+--R                                                    Type: Expression(Integer)
+--E 967
+
+--S 968 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R        12log(x  + 1) - 7log(4x - 1) + 6atan(x)
+--R   (3)  ---------------------------------------
+--R                           34
+--R                                         Type: Union(Expression(Integer),...)
+--E 968
+
+--S 969 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        - 7log(4x - 1) + 7log(- 4x + 1)
+--R   (4)  -------------------------------
+--R                       34
+--R                                                    Type: Expression(Integer)
+--E 969
+
+--S 970 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 970
+
+)clear all
+
+--S 971 of 1580
+t0:=(-3+2*x-3*x^2+x^3)/(1+x^2)
+--R 
+--R
+--R         3     2
+--R        x  - 3x  + 2x - 3
+--R   (1)  -----------------
+--R               2
+--R              x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 971
+
+--S 972 of 1580
+r0:=-3*x+1/2*x^2+1/2*log(1+x^2)
+--R 
+--R
+--R             2         2
+--R        log(x  + 1) + x  - 6x
+--R   (2)  ---------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 972
+
+--S 973 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2         2
+--R        log(x  + 1) + x  - 6x
+--R   (3)  ---------------------
+--R                  2
+--R                                         Type: Union(Expression(Integer),...)
+--E 973
+
+--S 974 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 974
+
+--S 975 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 975
+
+)clear all
+
+--S 976 of 1580
+t0:=(x+10*x^2+6*x^3+x^4)/(10+6*x+x^2)
+--R 
+--R
+--R         4     3      2
+--R        x  + 6x  + 10x  + x
+--R   (1)  -------------------
+--R             2
+--R            x  + 6x + 10
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 976
+
+--S 977 of 1580
+r0:=1/3*x^3-3*atan(3+x)+1/2*log(10+6*x+x^2)
+--R 
+--R
+--R              2                                3
+--R        3log(x  + 6x + 10) - 18atan(x + 3) + 2x
+--R   (2)  ----------------------------------------
+--R                            6
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                                3
+--R        3log(x  + 6x + 10) - 18atan(x + 3) + 2x
+--R   (3)  ----------------------------------------
+--R                            6
+--R                                         Type: Union(Expression(Integer),...)
+--E 978
+
+--S 979 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 979
+
+--S 980 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 980
+
+)clear all
+
+--S 981 of 1580
+t0:=1/(-18+27*x-7*x^2-3*x^3+x^4)
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R         4     3     2
+--R        x  - 3x  - 7x  + 27x - 18
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 981
+
+--S 982 of 1580
+r0:=1/8*log(1-x)-1/5*log(2-x)+1/12*log(3-x)-1/120*log(3+x)
+--R 
+--R
+--R        - log(x + 3) + 10log(- x + 3) - 24log(- x + 2) + 15log(- x + 1)
+--R   (2)  ---------------------------------------------------------------
+--R                                      120
+--R                                                    Type: Expression(Integer)
+--E 982
+
+--S 983 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - log(x + 3) + 15log(x - 1) - 24log(x - 2) + 10log(x - 3)
+--R   (3)  ---------------------------------------------------------
+--R                                   120
+--R                                         Type: Union(Expression(Integer),...)
+--E 983
+
+--S 984 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       15log(x - 1) - 24log(x - 2) + 10log(x - 3) - 10log(- x + 3)
+--R     + 
+--R       24log(- x + 2) - 15log(- x + 1)
+--R  /
+--R     120
+--R                                                    Type: Expression(Integer)
+--E 984
+
+--S 985 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 985
+
+)clear all
+
+--S 986 of 1580
+t0:=(1+x^3)/(-2+x)
+--R 
+--R
+--R         3
+--R        x  + 1
+--R   (1)  ------
+--R         x - 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 986
+
+--S 987 of 1580
+r0:=4*x+x^2+1/3*x^3+9*log(2-x)
+--R 
+--R
+--R                          3     2
+--R        27log(- x + 2) + x  + 3x  + 12x
+--R   (2)  -------------------------------
+--R                       3
+--R                                                    Type: Expression(Integer)
+--E 987
+
+--S 988 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        3     2
+--R        27log(x - 2) + x  + 3x  + 12x
+--R   (3)  -----------------------------
+--R                      3
+--R                                         Type: Union(Expression(Integer),...)
+--E 988
+
+--S 989 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  9log(x - 2) - 9log(- x + 2)
+--R                                                    Type: Expression(Integer)
+--E 989
+
+--S 990 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 990
+
+)clear all
+
+--S 991 of 1580
+t0:=x/(2-3*x+x^3)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         3
+--R        x  - 3x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 991
+
+--S 992 of 1580
+r0:=1/3/(1-x)+2/9*log(1-x)-2/9*log(2+x)
+--R 
+--R
+--R        (- 2x + 2)log(x + 2) + (2x - 2)log(- x + 1) - 3
+--R   (2)  -----------------------------------------------
+--R                             9x - 9
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (- 2x + 2)log(x + 2) + (2x - 2)log(x - 1) - 3
+--R   (3)  ---------------------------------------------
+--R                            9x - 9
+--R                                         Type: Union(Expression(Integer),...)
+--E 993
+
+--S 994 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        2log(x - 1) - 2log(- x + 1)
+--R   (4)  ---------------------------
+--R                     9
+--R                                                    Type: Expression(Integer)
+--E 994
+
+--S 995 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 995
+
+)clear all
+
+--S 996 of 1580
+t0:=(-6+2*x+x^4)/(-2*x+x^2+x^3)
+--R 
+--R
+--R          4
+--R         x  + 2x - 6
+--R   (1)  ------------
+--R         3    2
+--R        x  + x  - 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 996
+
+--S 997 of 1580
+r0:=-x+1/2*x^2-log(1-x)+3*log(x)+log(2+x)
+--R 
+--R
+--R                                                 2
+--R        2log(x + 2) + 6log(x) - 2log(- x + 1) + x  - 2x
+--R   (2)  -----------------------------------------------
+--R                               2
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                               2
+--R        2log(x + 2) + 6log(x) - 2log(x - 1) + x  - 2x
+--R   (3)  ---------------------------------------------
+--R                              2
+--R                                         Type: Union(Expression(Integer),...)
+--E 998
+
+--S 999 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  - log(x - 1) + log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 999
+
+--S 1000 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+)clear all
+
+--S 1001 of 1580
+t0:=(7+8*x^3)/((1+x)*(1+2*x)^3)
+--R 
+--R
+--R                    3
+--R                  8x  + 7
+--R   (1)  --------------------------
+--R          4      3      2
+--R        8x  + 20x  + 18x  + 7x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1001
+
+--S 1002 of 1580
+r0:=(-3)/(1+2*x)^2+3/(1+2*x)+log(1+x)
+--R 
+--R
+--R           2
+--R        (4x  + 4x + 1)log(x + 1) + 6x
+--R   (2)  -----------------------------
+--R                   2
+--R                 4x  + 4x + 1
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+--S 1003 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R        (4x  + 4x + 1)log(x + 1) + 6x
+--R   (3)  -----------------------------
+--R                   2
+--R                 4x  + 4x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 1003
+
+--S 1004 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1004
+
+--S 1005 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1005
+
+)clear all
+
+--S 1006 of 1580
+t0:=(1+x^4)/(x*(1+x^2)^2)
+--R 
+--R
+--R            4
+--R           x  + 1
+--R   (1)  ------------
+--R         5     3
+--R        x  + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1006
+
+--S 1007 of 1580
+r0:=1/(1+x^2)+log(x)
+--R 
+--R
+--R          2
+--R        (x  + 1)log(x) + 1
+--R   (2)  ------------------
+--R               2
+--R              x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1007
+
+--S 1008 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2
+--R        (x  + 1)log(x) + 1
+--R   (3)  ------------------
+--R               2
+--R              x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 1008
+
+--S 1009 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1009
+
+--S 1010 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1010
+
+)clear all
+
+--S 1011 of 1580
+t0:=(1-x^3)/(x*(1+x^2))
+--R 
+--R
+--R           3
+--R        - x  + 1
+--R   (1)  --------
+--R          3
+--R         x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1011
+
+--S 1012 of 1580
+r0:=-x+atan(x)+log(x)-1/2*log(1+x^2)
+--R 
+--R
+--R               2
+--R        - log(x  + 1) + 2log(x) + 2atan(x) - 2x
+--R   (2)  ---------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 1012
+
+--S 1013 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R        - log(x  + 1) + 2log(x) + 2atan(x) - 2x
+--R   (3)  ---------------------------------------
+--R                           2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1013
+
+--S 1014 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1014
+
+--S 1015 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1015
+
+)clear all
+
+--S 1016 of 1580
+t0:=(3*x-4*x^2+3*x^3)/(1+x^2)
+--R 
+--R
+--R          3     2
+--R        3x  - 4x  + 3x
+--R   (1)  --------------
+--R             2
+--R            x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1016
+
+--S 1017 of 1580
+r0:=-4*x+3/2*x^2+4*atan(x)
+--R 
+--R
+--R                     2
+--R        8atan(x) + 3x  - 8x
+--R   (2)  -------------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 1017
+
+--S 1018 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     2
+--R        8atan(x) + 3x  - 8x
+--R   (3)  -------------------
+--R                 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1018
+
+--S 1019 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1019
+
+--S 1020 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1020
+
+)clear all
+
+--S 1021 of 1580
+t0:=(5+3*x)/(1-x-x^2+x^3)
+--R 
+--R
+--R             3x + 5
+--R   (1)  ---------------
+--R         3    2
+--R        x  - x  - x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1021
+
+--S 1022 of 1580
+r0:=4/(1-x)+atanh(x)
+--R 
+--R
+--R        (x - 1)atanh(x) - 4
+--R   (2)  -------------------
+--R               x - 1
+--R                                                    Type: Expression(Integer)
+--E 1022
+
+--S 1023 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (x - 1)log(x + 1) + (- x + 1)log(x - 1) - 8
+--R   (3)  -------------------------------------------
+--R                           2x - 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1023
+
+--S 1024 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        log(x + 1) - log(x - 1) - 2atanh(x)
+--R   (4)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 1024
+
+--S 1025 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1025
+
+)clear all
+
+--S 1026 of 1580
+t0:=(-1-x-x^3+x^4)/(-x^2+x^3)
+--R 
+--R
+--R         4    3
+--R        x  - x  - x - 1
+--R   (1)  ---------------
+--R             3    2
+--R            x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1026
+
+--S 1027 of 1580
+r0:=(-1)/x+1/2*x^2-2*log(1-x)+2*log(x)
+--R 
+--R
+--R                                       3
+--R        4x log(x) - 4x log(- x + 1) + x  - 2
+--R   (2)  ------------------------------------
+--R                         2x
+--R                                                    Type: Expression(Integer)
+--E 1027
+
+--S 1028 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                     3
+--R        4x log(x) - 4x log(x - 1) + x  - 2
+--R   (3)  ----------------------------------
+--R                        2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1028
+
+--S 1029 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  - 2log(x - 1) + 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1029
+
+--S 1030 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1030
+
+)clear all
+
+--S 1031 of 1580
+t0:=(2+x+x^2+x^3)/(2+3*x^2+x^4)
+--R 
+--R
+--R         3    2
+--R        x  + x  + x + 2
+--R   (1)  ---------------
+--R           4     2
+--R          x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1031
+
+--S 1032 of 1580
+r0:=atan(x)+1/2*log(2+x^2)
+--R 
+--R
+--R             2
+--R        log(x  + 2) + 2atan(x)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 1032
+
+--S 1033 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R        log(x  + 2) + 2atan(x)
+--R   (3)  ----------------------
+--R                   2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1033
+
+--S 1034 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1034
+
+--S 1035 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1035
+
+)clear all
+
+--S 1036 of 1580
+t0:=(-4+8*x-4*x^2+4*x^3-x^4+x^5)/(2+x^2)^3
+--R 
+--R
+--R         5    4     3     2
+--R        x  - x  + 4x  - 4x  + 8x - 4
+--R   (1)  ----------------------------
+--R              6     4      2
+--R             x  + 6x  + 12x  + 8
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1036
+
+--S 1037 of 1580
+r0:=(-1)/(2+x^2)^2+1/2*log(2+x^2)-atan(x/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                                                +-+
+--R          4     2      +-+     2             4     2          x\|2       +-+
+--R        (x  + 4x  + 4)\|2 log(x  + 2) + (- 2x  - 8x  - 8)atan(-----) - 2\|2
+--R                                                                2
+--R   (2)  --------------------------------------------------------------------
+--R                                    4     2      +-+
+--R                                 (2x  + 8x  + 8)\|2
+--R                                                    Type: Expression(Integer)
+--E 1037
+
+--S 1038 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                                +-+
+--R          4     2      +-+     2             4     2          x\|2       +-+
+--R        (x  + 4x  + 4)\|2 log(x  + 2) + (- 2x  - 8x  - 8)atan(-----) - 2\|2
+--R                                                                2
+--R   (3)  --------------------------------------------------------------------
+--R                                    4     2      +-+
+--R                                 (2x  + 8x  + 8)\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1038
+
+--S 1039 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1039
+
+--S 1040 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1040
+
+)clear all
+
+--S 1041 of 1580
+t0:=(-1-3*x+x^2)/(-2*x+x^2+x^3)
+--R 
+--R
+--R          2
+--R         x  - 3x - 1
+--R   (1)  ------------
+--R         3    2
+--R        x  + x  - 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1041
+
+--S 1042 of 1580
+r0:=-log(1-x)+1/2*log(x)+3/2*log(2+x)
+--R 
+--R
+--R        3log(x + 2) + log(x) - 2log(- x + 1)
+--R   (2)  ------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 1042
+
+--S 1043 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        3log(x + 2) + log(x) - 2log(x - 1)
+--R   (3)  ----------------------------------
+--R                         2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1043
+
+--S 1044 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  - log(x - 1) + log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1044
+
+--S 1045 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1045
+
+)clear all
+
+--S 1046 of 1580
+t0:=(3-x+3*x^2-2*x^3+x^4)/(3*x-2*x^2+x^3)
+--R 
+--R
+--R         4     3     2
+--R        x  - 2x  + 3x  - x + 3
+--R   (1)  ----------------------
+--R              3     2
+--R             x  - 2x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1046
+
+--S 1047 of 1580
+r0:=1/2*x^2+log(x)-1/2*log(3-2*x+x^2)
+--R 
+--R
+--R               2                        2
+--R        - log(x  - 2x + 3) + 2log(x) + x
+--R   (2)  ---------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 1047
+
+--S 1048 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2                        2
+--R        - log(x  - 2x + 3) + 2log(x) + x
+--R   (3)  ---------------------------------
+--R                        2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1048
+
+--S 1049 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1049
+
+--S 1050 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1050
+
+)clear all
+
+--S 1051 of 1580
+t0:=(-1+x+x^3)/(1+x^2)^2
+--R 
+--R
+--R          3
+--R         x  + x - 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1051
+
+--S 1052 of 1580
+r0:=-1/2*x/(1+x^2)-1/2*atan(x)+1/2*log(1+x^2)
+--R 
+--R
+--R          2          2            2
+--R        (x  + 1)log(x  + 1) + (- x  - 1)atan(x) - x
+--R   (2)  -------------------------------------------
+--R                            2
+--R                          2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 1052
+
+--S 1053 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2          2            2
+--R        (x  + 1)log(x  + 1) + (- x  - 1)atan(x) - x
+--R   (3)  -------------------------------------------
+--R                            2
+--R                          2x  + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1053
+
+--S 1054 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1054
+
+--S 1055 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1055
+
+)clear all
+
+--S 1056 of 1580
+t0:=(1+2*x-x^2+8*x^3+x^4)/((x+x^2)*(1+x^3))
+--R 
+--R
+--R         4     3    2
+--R        x  + 8x  - x  + 2x + 1
+--R   (1)  ----------------------
+--R            5    4    2
+--R           x  + x  + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1056
+
+--S 1057 of 1580
+r0:=(-3)/(1+x)+log(x)-2*log(1+x)+log(1-x+x^2)-2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R               +-+     2                       +-+                     +-+
+--R       (x + 1)\|3 log(x  - x + 1) + (- 2x - 2)\|3 log(x + 1) + (x + 1)\|3 log(x)
+--R     + 
+--R                             +-+
+--R                    (2x - 1)\|3       +-+
+--R       (2x + 2)atan(------------) - 3\|3
+--R                          3
+--R  /
+--R             +-+
+--R     (x + 1)\|3
+--R                                                    Type: Expression(Integer)
+--E 1057
+
+--S 1058 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +-+     2                       +-+                     +-+
+--R       (x + 1)\|3 log(x  - x + 1) + (- 2x - 2)\|3 log(x + 1) + (x + 1)\|3 log(x)
+--R     + 
+--R                             +-+
+--R                    (2x - 1)\|3       +-+
+--R       (2x + 2)atan(------------) - 3\|3
+--R                          3
+--R  /
+--R             +-+
+--R     (x + 1)\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1058
+
+--S 1059 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1059
+
+--S 1060 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1060
+
+)clear all
+
+--S 1061 of 1580
+t0:=(15-5*x+x^2+x^3)/((5+x^2)*(3+2*x+x^2))
+--R 
+--R
+--R             3    2
+--R            x  + x  - 5x + 15
+--R   (1)  -------------------------
+--R         4     3     2
+--R        x  + 2x  + 8x  + 10x + 15
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1061
+
+--S 1062 of 1580
+r0:=1/2*log(3+2*x+x^2)+5*atan((1+x)/sqrt(2))/sqrt(2)-atan(x/sqrt(5))*sqrt(5)
+--R 
+--R
+--R                                               +-+                   +-+
+--R         +-+     2               +-+ +-+     x\|5            (x + 1)\|2
+--R        \|2 log(x  + 2x + 3) - 2\|2 \|5 atan(-----) + 10atan(-----------)
+--R                                               5                  2
+--R   (2)  -----------------------------------------------------------------
+--R                                        +-+
+--R                                      2\|2
+--R                                                    Type: Expression(Integer)
+--E 1062
+
+--S 1063 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                              +-+                   +-+
+--R         +-+     2               +-+ +-+     \|5            (x + 1)\|2
+--R        \|2 log(x  + 2x + 3) + 2\|2 \|5 atan(----) + 10atan(-----------)
+--R                                               x                 2
+--R   (3)  ----------------------------------------------------------------
+--R                                        +-+
+--R                                      2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1063
+
+--S 1064 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                   +-+              +-+
+--R         +-+     x\|5      +-+     \|5
+--R   (4)  \|5 atan(-----) + \|5 atan(----)
+--R                   5                 x
+--R                                                    Type: Expression(Integer)
+--E 1064
+
+--S 1065 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1065
+
+)clear all
+
+--S 1066 of 1580
+t0:=(-3+25*x+23*x^2+32*x^3+15*x^4+7*x^5+x^6)/((1+x^2)^2*(2+x+x^2)^2)
+--R 
+--R
+--R               6     5      4      3      2
+--R              x  + 7x  + 15x  + 32x  + 23x  + 25x - 3
+--R   (1)  --------------------------------------------------
+--R         8     7     6     5      4      3      2
+--R        x  + 2x  + 7x  + 8x  + 15x  + 10x  + 13x  + 4x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1066
+
+--S 1067 of 1580
+r0:=(-3)/(1+x^2)+1/(2+x+x^2)+log(1+x^2)-log(2+x+x^2)
+--R 
+--R
+--R   (2)
+--R           4    3     2              2
+--R       (- x  - x  - 3x  - x - 2)log(x  + x + 2)
+--R     + 
+--R         4    3     2              2          2
+--R       (x  + x  + 3x  + x + 2)log(x  + 1) - 2x  - 3x - 5
+--R  /
+--R      4    3     2
+--R     x  + x  + 3x  + x + 2
+--R                                                    Type: Expression(Integer)
+--E 1067
+
+--S 1068 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4    3     2              2
+--R       (- x  - x  - 3x  - x - 2)log(x  + x + 2)
+--R     + 
+--R         4    3     2              2          2
+--R       (x  + x  + 3x  + x + 2)log(x  + 1) - 2x  - 3x - 5
+--R  /
+--R      4    3     2
+--R     x  + x  + 3x  + x + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1068
+
+--S 1069 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1069
+
+--S 1070 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1070
+
+)clear all
+
+--S 1071 of 1580
+t0:=1/((1+x^2)*(4+x^2))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1071
+
+--S 1072 of 1580
+r0:=-1/6*atan(1/2*x)+1/3*atan(x)
+--R 
+--R
+--R                        x
+--R        2atan(x) - atan(-)
+--R                        2
+--R   (2)  ------------------
+--R                 6
+--R                                                    Type: Expression(Integer)
+--E 1072
+
+--S 1073 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        x
+--R        2atan(x) - atan(-)
+--R                        2
+--R   (3)  ------------------
+--R                 6
+--R                                         Type: Union(Expression(Integer),...)
+--E 1073
+
+--S 1074 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1074
+
+--S 1075 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1075
+
+)clear all
+
+--S 1076 of 1580
+t0:=(a+b*x^3)/(1+x^2)
+--R 
+--R
+--R           3
+--R        b x  + a
+--R   (1)  --------
+--R          2
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1076
+
+--S 1077 of 1580
+r0:=1/2*b*x^2+a*atan(x)-1/2*b*log(1+x^2)
+--R 
+--R
+--R                 2                        2
+--R        - b log(x  + 1) + 2a atan(x) + b x
+--R   (2)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 1077
+
+--S 1078 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 2                        2
+--R        - b log(x  + 1) + 2a atan(x) + b x
+--R   (3)  -----------------------------------
+--R                         2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1078
+
+--S 1079 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1079
+
+--S 1080 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1080
+
+)clear all
+
+--S 1081 of 1580
+t0:=(x+x^2)/((4+x)*(-4+x^2))
+--R 
+--R
+--R               2
+--R              x  + x
+--R   (1)  ------------------
+--R         3     2
+--R        x  + 4x  - 4x - 16
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1081
+
+--S 1082 of 1580
+r0:=-1/2*atanh(1/2*x)+log(4+x)
+--R 
+--R
+--R                            x
+--R        2log(x + 4) - atanh(-)
+--R                            2
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 1082
+
+--S 1083 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        4log(x + 4) - log(x + 2) + log(x - 2)
+--R   (3)  -------------------------------------
+--R                          4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1083
+
+--S 1084 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                                           x
+--R        - log(x + 2) + log(x - 2) + 2atanh(-)
+--R                                           2
+--R   (4)  -------------------------------------
+--R                          4
+--R                                                    Type: Expression(Integer)
+--E 1084
+
+--S 1085 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1085
+
+)clear all
+
+--S 1086 of 1580
+t0:=(4+x^2)/((1+x^2)*(2+x^2))
+--R 
+--R
+--R            2
+--R           x  + 4
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1086
+
+--S 1087 of 1580
+r0:=3*atan(x)-atan(x/sqrt(2))*sqrt(2)
+--R 
+--R
+--R                     +-+
+--R           +-+     x\|2
+--R   (2)  - \|2 atan(-----) + 3atan(x)
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 1087
+
+--S 1088 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +-+
+--R         +-+     \|2
+--R   (3)  \|2 atan(----) + 3atan(x)
+--R                   x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1088
+
+--S 1089 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                   +-+              +-+
+--R         +-+     x\|2      +-+     \|2
+--R   (4)  \|2 atan(-----) + \|2 atan(----)
+--R                   2                 x
+--R                                                    Type: Expression(Integer)
+--E 1089
+
+--S 1090 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1090
+
+)clear all
+
+--S 1091 of 1580
+t0:=(5-4*x+3*x^2+x^4)/((-1+x)^2*(1+x^2))
+--R 
+--R
+--R            4     2
+--R           x  + 3x  - 4x + 5
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  - 2x  + 2x  - 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1091
+
+--S 1092 of 1580
+r0:=5/2/(1-x)+x+2*atan(x)+1/2*log(1-x)+3/4*log(1+x^2)
+--R 
+--R
+--R   (2)
+--R                2                                                   2
+--R   (3x - 3)log(x  + 1) + (2x - 2)log(- x + 1) + (8x - 8)atan(x) + 4x  - 4x - 10
+--R   ----------------------------------------------------------------------------
+--R                                      4x - 4
+--R                                                    Type: Expression(Integer)
+--E 1092
+
+--S 1093 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2                                                 2
+--R   (3x - 3)log(x  + 1) + (2x - 2)log(x - 1) + (8x - 8)atan(x) + 4x  - 4x - 10
+--R   --------------------------------------------------------------------------
+--R                                     4x - 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1093
+
+--S 1094 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        log(x - 1) - log(- x + 1)
+--R   (4)  -------------------------
+--R                    2
+--R                                                    Type: Expression(Integer)
+--E 1094
+
+--S 1095 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1095
+
+)clear all
+
+--S 1096 of 1580
+t0:=(1+x^4)/(2+x^2)
+--R 
+--R
+--R         4
+--R        x  + 1
+--R   (1)  ------
+--R         2
+--R        x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1096
+
+--S 1097 of 1580
+r0:=-2*x+1/3*x^3+5*atan(x/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                 +-+
+--R               x\|2       3       +-+
+--R        15atan(-----) + (x  - 6x)\|2
+--R                 2
+--R   (2)  -----------------------------
+--R                      +-+
+--R                    3\|2
+--R                                                    Type: Expression(Integer)
+--E 1097
+
+--S 1098 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-+
+--R               x\|2       3       +-+
+--R        15atan(-----) + (x  - 6x)\|2
+--R                 2
+--R   (3)  -----------------------------
+--R                      +-+
+--R                    3\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1098
+
+--S 1099 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1099
+
+--S 1100 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1100
+
+)clear all
+
+--S 1101 of 1580
+t0:=(2+2*x+x^4)/(x^4+x^5)
+--R 
+--R
+--R         4
+--R        x  + 2x + 2
+--R   (1)  -----------
+--R           5    4
+--R          x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1101
+
+--S 1102 of 1580
+r0:=(-2/3)/x^3+log(1+x)
+--R 
+--R
+--R          3
+--R        3x log(x + 1) - 2
+--R   (2)  -----------------
+--R                 3
+--R               3x
+--R                                                    Type: Expression(Integer)
+--E 1102
+
+--S 1103 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3
+--R        3x log(x + 1) - 2
+--R   (3)  -----------------
+--R                 3
+--R               3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1103
+
+--S 1104 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1104
+
+--S 1105 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1105
+
+)clear all
+
+--S 1106 of 1580
+t0:=(-1-5*x+2*x^2)/(2-x-2*x^2+x^3)
+--R 
+--R
+--R            2
+--R          2x  - 5x - 1
+--R   (1)  ----------------
+--R         3     2
+--R        x  - 2x  - x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1106
+
+--S 1107 of 1580
+r0:=2*log(1-x)-log(2-x)+log(1+x)
+--R 
+--R
+--R   (2)  log(x + 1) - log(- x + 2) + 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1107
+
+--S 1108 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  log(x + 1) + 2log(x - 1) - log(x - 2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 1108
+
+--S 1109 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  2log(x - 1) - log(x - 2) + log(- x + 2) - 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1109
+
+--S 1110 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1110
+
+)clear all
+
+--S 1111 of 1580
+t0:=(2+x+x^3)/(1+2*x^2+x^4)
+--R 
+--R
+--R          3
+--R         x  + x + 2
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1111
+
+--S 1112 of 1580
+r0:=x/(1+x^2)+atan(x)+1/2*log(1+x^2)
+--R 
+--R
+--R          2          2           2
+--R        (x  + 1)log(x  + 1) + (2x  + 2)atan(x) + 2x
+--R   (2)  -------------------------------------------
+--R                            2
+--R                          2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 1112
+
+--S 1113 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2          2           2
+--R        (x  + 1)log(x  + 1) + (2x  + 2)atan(x) + 2x
+--R   (3)  -------------------------------------------
+--R                            2
+--R                          2x  + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1113
+
+--S 1114 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1114
+
+--S 1115 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1115
+
+)clear all
+
+--S 1116 of 1580
+t0:=(1+2*x+x^2+x^3)/(1+2*x^2+x^4)
+--R 
+--R
+--R         3    2
+--R        x  + x  + 2x + 1
+--R   (1)  ----------------
+--R           4     2
+--R          x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1116
+
+--S 1117 of 1580
+r0:=(-1/2)/(1+x^2)+atan(x)+1/2*log(1+x^2)
+--R 
+--R
+--R          2          2           2
+--R        (x  + 1)log(x  + 1) + (2x  + 2)atan(x) - 1
+--R   (2)  ------------------------------------------
+--R                            2
+--R                          2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 1117
+
+--S 1118 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2          2           2
+--R        (x  + 1)log(x  + 1) + (2x  + 2)atan(x) - 1
+--R   (3)  ------------------------------------------
+--R                            2
+--R                          2x  + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1118
+
+--S 1119 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1119
+
+--S 1120 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1120
+
+)clear all
+
+--S 1121 of 1580
+t0:=(3+4*x)/((1+x^2)*(2+x^2))
+--R 
+--R
+--R           4x + 3
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1121
+
+--S 1122 of 1580
+r0:=3*atan(x)+2*log(1+x^2)-2*log(2+x^2)-3*atan(x/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                                        +-+
+--R            +-+     2          +-+     2              x\|2       +-+
+--R        - 2\|2 log(x  + 2) + 2\|2 log(x  + 1) - 3atan(-----) + 3\|2 atan(x)
+--R                                                        2
+--R   (2)  -------------------------------------------------------------------
+--R                                         +-+
+--R                                        \|2
+--R                                                    Type: Expression(Integer)
+--E 1122
+
+--S 1123 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        +-+
+--R            +-+     2          +-+     2              x\|2       +-+
+--R        - 2\|2 log(x  + 2) + 2\|2 log(x  + 1) - 3atan(-----) + 3\|2 atan(x)
+--R                                                        2
+--R   (3)  -------------------------------------------------------------------
+--R                                         +-+
+--R                                        \|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1123
+
+--S 1124 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1124
+
+--S 1125 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1125
+
+)clear all
+
+--S 1126 of 1580
+t0:=(2+x)/((1+x^2)*(4+x^2))
+--R 
+--R
+--R            x + 2
+--R   (1)  ------------
+--R         4     2
+--R        x  + 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1126
+
+--S 1127 of 1580
+r0:=-1/3*atan(1/2*x)+2/3*atan(x)+1/6*log(1+x^2)-1/6*log(4+x^2)
+--R 
+--R
+--R               2             2                         x
+--R        - log(x  + 4) + log(x  + 1) + 4atan(x) - 2atan(-)
+--R                                                       2
+--R   (2)  -------------------------------------------------
+--R                                6
+--R                                                    Type: Expression(Integer)
+--E 1127
+
+--S 1128 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2             2                         x
+--R        - log(x  + 4) + log(x  + 1) + 4atan(x) - 2atan(-)
+--R                                                       2
+--R   (3)  -------------------------------------------------
+--R                                6
+--R                                         Type: Union(Expression(Integer),...)
+--E 1128
+
+--S 1129 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1129
+
+--S 1130 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1130
+
+)clear all
+
+--S 1131 of 1580
+t0:=(2-x+x^3)/(-7-6*x+x^2)
+--R 
+--R
+--R          3
+--R         x  - x + 2
+--R   (1)  -----------
+--R         2
+--R        x  - 6x - 7
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1131
+
+--S 1132 of 1580
+r0:=6*x+1/2*x^2+169/4*log(7-x)-1/4*log(1+x)
+--R 
+--R
+--R                                           2
+--R        - log(x + 1) + 169log(- x + 7) + 2x  + 24x
+--R   (2)  ------------------------------------------
+--R                             4
+--R                                                    Type: Expression(Integer)
+--E 1132
+
+--S 1133 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                         2
+--R        - log(x + 1) + 169log(x - 7) + 2x  + 24x
+--R   (3)  ----------------------------------------
+--R                            4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1133
+
+--S 1134 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        169log(x - 7) - 169log(- x + 7)
+--R   (4)  -------------------------------
+--R                       4
+--R                                                    Type: Expression(Integer)
+--E 1134
+
+--S 1135 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1135
+
+)clear all
+
+--S 1136 of 1580
+t0:=(-1+x^5)/(-1+x^2)
+--R 
+--R
+--R         4    3    2
+--R        x  + x  + x  + x + 1
+--R   (1)  --------------------
+--R                x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1136
+
+--S 1137 of 1580
+r0:=1/2*x^2+1/4*x^4+log(1+x)
+--R 
+--R
+--R                       4     2
+--R        4log(x + 1) + x  + 2x
+--R   (2)  ----------------------
+--R                   4
+--R                                                    Type: Expression(Integer)
+--E 1137
+
+--S 1138 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       4     2
+--R        4log(x + 1) + x  + 2x
+--R   (3)  ----------------------
+--R                   4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1138
+
+--S 1139 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1139
+
+--S 1140 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1140
+
+)clear all
+
+--S 1141 of 1580
+t0:=(5+2*x-x^2+x^3)/(1+x+x^2)
+--R 
+--R
+--R         3    2
+--R        x  - x  + 2x + 5
+--R   (1)  ----------------
+--R            2
+--R           x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1141
+
+--S 1142 of 1580
+r0:=-2*x+1/2*x^2+3/2*log(1+x+x^2)+11*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                               +-+
+--R          +-+     2                   (2x + 1)\|3       2       +-+
+--R        3\|3 log(x  + x + 1) + 22atan(------------) + (x  - 4x)\|3
+--R                                            3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   2\|3
+--R                                                    Type: Expression(Integer)
+--E 1142
+
+--S 1143 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                               +-+
+--R          +-+     2                   (2x + 1)\|3       2       +-+
+--R        3\|3 log(x  + x + 1) + 22atan(------------) + (x  - 4x)\|3
+--R                                            3
+--R   (3)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1143
+
+--S 1144 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1144
+
+--S 1145 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1145
+
+)clear all
+
+--S 1146 of 1580
+t0:=(-3+x-2*x^3+x^4)/(10-8*x+2*x^2)
+--R 
+--R
+--R         4     3
+--R        x  - 2x  + x - 3
+--R   (1)  ----------------
+--R            2
+--R          2x  - 8x + 10
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1146
+
+--S 1147 of 1580
+r0:=3/2*x+1/2*x^2+1/6*x^3+6*atan(2-x)+3/4*log(5-4*x+x^2)
+--R 
+--R
+--R              2                               3     2
+--R        9log(x  - 4x + 5) - 72atan(x - 2) + 2x  + 6x  + 18x
+--R   (2)  ---------------------------------------------------
+--R                                 12
+--R                                                    Type: Expression(Integer)
+--E 1147
+
+--S 1148 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                               3     2
+--R        9log(x  - 4x + 5) - 72atan(x - 2) + 2x  + 6x  + 18x
+--R   (3)  ---------------------------------------------------
+--R                                 12
+--R                                         Type: Union(Expression(Integer),...)
+--E 1148
+
+--S 1149 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1149
+
+--S 1150 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1150
+
+)clear all
+
+--S 1151 of 1580
+t0:=(1+2*x+3*x^2+x^3)/((-3+x)*(-2+x)*(-1+x))
+--R 
+--R
+--R          3     2
+--R         x  + 3x  + 2x + 1
+--R   (1)  ------------------
+--R         3     2
+--R        x  - 6x  + 11x - 6
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1151
+
+--S 1152 of 1580
+r0:=x+7/2*log(1-x)-25*log(2-x)+61/2*log(3-x)
+--R 
+--R
+--R        61log(- x + 3) - 50log(- x + 2) + 7log(- x + 1) + 2x
+--R   (2)  ----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 1152
+
+--S 1153 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        7log(x - 1) - 50log(x - 2) + 61log(x - 3) + 2x
+--R   (3)  ----------------------------------------------
+--R                               2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1153
+
+--S 1154 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       7log(x - 1) - 50log(x - 2) + 61log(x - 3) - 61log(- x + 3)
+--R     + 
+--R       50log(- x + 2) - 7log(- x + 1)
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 1154
+
+--S 1155 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1155
+
+)clear all
+
+--S 1156 of 1580
+t0:=(2-7*x+x^2-x^3+x^4)/(-24-14*x+x^2+x^3)
+--R 
+--R
+--R         4    3    2
+--R        x  - x  + x  - 7x + 2
+--R   (1)  ---------------------
+--R           3    2
+--R          x  + x  - 14x - 24
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1156
+
+--S 1157 of 1580
+r0:=-2*x+1/2*x^2+13/3*log(4-x)-22/3*log(2+x)+20*log(3+x)
+--R 
+--R
+--R                                                          2
+--R        120log(x + 3) - 44log(x + 2) + 26log(- x + 4) + 3x  - 12x
+--R   (2)  ---------------------------------------------------------
+--R                                    6
+--R                                                    Type: Expression(Integer)
+--E 1157
+
+--S 1158 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        2
+--R        120log(x + 3) - 44log(x + 2) + 26log(x - 4) + 3x  - 12x
+--R   (3)  -------------------------------------------------------
+--R                                   6
+--R                                         Type: Union(Expression(Integer),...)
+--E 1158
+
+--S 1159 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        13log(x - 4) - 13log(- x + 4)
+--R   (4)  -----------------------------
+--R                      3
+--R                                                    Type: Expression(Integer)
+--E 1159
+
+--S 1160 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1160
+
+)clear all
+
+--S 1161 of 1580
+t0:=(2+x^2)/((-1+x)^2*x*(1+x))
+--R 
+--R
+--R              2
+--R             x  + 2
+--R   (1)  ----------------
+--R         4    3    2
+--R        x  - x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1161
+
+--S 1162 of 1580
+r0:=3/2/(1-x)-5/4*log(1-x)+2*log(x)-3/4*log(1+x)
+--R 
+--R
+--R        (- 3x + 3)log(x + 1) + (8x - 8)log(x) + (- 5x + 5)log(- x + 1) - 6
+--R   (2)  ------------------------------------------------------------------
+--R                                      4x - 4
+--R                                                    Type: Expression(Integer)
+--E 1162
+
+--S 1163 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (- 3x + 3)log(x + 1) + (8x - 8)log(x) + (- 5x + 5)log(x - 1) - 6
+--R   (3)  ----------------------------------------------------------------
+--R                                     4x - 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1163
+
+--S 1164 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        - 5log(x - 1) + 5log(- x + 1)
+--R   (4)  -----------------------------
+--R                      4
+--R                                                    Type: Expression(Integer)
+--E 1164
+
+--S 1165 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1165
+
+)clear all
+
+--S 1166 of 1580
+t0:=(3+x^2+x^3)/(2+x^2)^2
+--R 
+--R
+--R          3    2
+--R         x  + x  + 3
+--R   (1)  ------------
+--R         4     2
+--R        x  + 4x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1166
+
+--S 1167 of 1580
+r0:=1/4*(4+x)/(2+x^2)+1/2*log(2+x^2)+5/4*atan(x/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                                    +-+
+--R           2      +-+     2           2           x\|2             +-+
+--R        (2x  + 4)\|2 log(x  + 2) + (5x  + 10)atan(-----) + (x + 4)\|2
+--R                                                    2
+--R   (2)  --------------------------------------------------------------
+--R                                    2      +-+
+--R                                 (4x  + 8)\|2
+--R                                                    Type: Expression(Integer)
+--E 1167
+
+--S 1168 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                    +-+
+--R           2      +-+     2           2           x\|2             +-+
+--R        (2x  + 4)\|2 log(x  + 2) + (5x  + 10)atan(-----) + (x + 4)\|2
+--R                                                    2
+--R   (3)  --------------------------------------------------------------
+--R                                    2      +-+
+--R                                 (4x  + 8)\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1168
+
+--S 1169 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1169
+
+--S 1170 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1170
+
+)clear all
+
+--S 1171 of 1580
+t0:=(-35+70*x-4*x^2+2*x^3)/((26-10*x+x^2)*(17-2*x+x^2))
+--R 
+--R
+--R               3     2
+--R             2x  - 4x  + 70x - 35
+--R   (1)  -----------------------------
+--R         4      3      2
+--R        x  - 12x  + 63x  - 222x + 442
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1171
+
+--S 1172 of 1580
+r0:=-15033/1025*atan(5-x)+4607/4100*atan(1/4-1/4*x)+_
+   1003/1025*log(26-10*x+x^2)+22/1025*log(17-2*x+x^2)
+--R 
+--R
+--R   (2)
+--R              2                       2
+--R       88log(x  - 2x + 17) + 4012log(x  - 10x + 26) + 60132atan(x - 5)
+--R     + 
+--R                  x - 1
+--R       - 4607atan(-----)
+--R                    4
+--R  /
+--R     4100
+--R                                                    Type: Expression(Integer)
+--E 1172
+
+--S 1173 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2                       2
+--R       88log(x  - 2x + 17) + 4012log(x  - 10x + 26) + 60132atan(x - 5)
+--R     + 
+--R                  x - 1
+--R       - 4607atan(-----)
+--R                    4
+--R  /
+--R     4100
+--R                                         Type: Union(Expression(Integer),...)
+--E 1173
+
+--S 1174 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1174
+
+--S 1175 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1175
+
+)clear all
+
+--S 1176 of 1580
+t0:=(2+x^2)/((-5+x)*(-3+x)*(4+x))
+--R 
+--R
+--R                2
+--R               x  + 2
+--R   (1)  -------------------
+--R         3     2
+--R        x  - 4x  - 17x + 60
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1176
+
+--S 1177 of 1580
+r0:=-11/14*log(3-x)+3/2*log(5-x)+2/7*log(4+x)
+--R 
+--R
+--R        4log(x + 4) + 21log(- x + 5) - 11log(- x + 3)
+--R   (2)  ---------------------------------------------
+--R                              14
+--R                                                    Type: Expression(Integer)
+--E 1177
+
+--S 1178 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        4log(x + 4) - 11log(x - 3) + 21log(x - 5)
+--R   (3)  -----------------------------------------
+--R                            14
+--R                                         Type: Union(Expression(Integer),...)
+--E 1178
+
+--S 1179 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        - 11log(x - 3) + 21log(x - 5) - 21log(- x + 5) + 11log(- x + 3)
+--R   (4)  ---------------------------------------------------------------
+--R                                       14
+--R                                                    Type: Expression(Integer)
+--E 1179
+
+--S 1180 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1180
+
+)clear all
+
+--S 1181 of 1580
+t0:=x^4/((-1+x)*(2+x^2))
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ----------------
+--R         3    2
+--R        x  - x  + 2x - 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1181
+
+--S 1182 of 1580
+r0:=x+1/2*x^2+1/3*log(1-x)-2/3*log(2+x^2)-2/3*atan(x/sqrt(2))*sqrt(2)
+--R 
+--R
+--R                                                     +-+
+--R                2                          +-+     x\|2       2
+--R        - 4log(x  + 2) + 2log(- x + 1) - 4\|2 atan(-----) + 3x  + 6x
+--R                                                     2
+--R   (2)  ------------------------------------------------------------
+--R                                      6
+--R                                                    Type: Expression(Integer)
+--E 1182
+
+--S 1183 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                  +-+
+--R                2                        +-+     \|2       2
+--R        - 4log(x  + 2) + 2log(x - 1) + 4\|2 atan(----) + 3x  + 6x
+--R                                                   x
+--R   (3)  ---------------------------------------------------------
+--R                                    6
+--R                                         Type: Union(Expression(Integer),...)
+--E 1183
+
+--S 1184 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                                                +-+               +-+
+--R                                      +-+     x\|2       +-+     \|2
+--R        log(x - 1) - log(- x + 1) + 2\|2 atan(-----) + 2\|2 atan(----)
+--R                                                2                  x
+--R   (4)  --------------------------------------------------------------
+--R                                       3
+--R                                                    Type: Expression(Integer)
+--E 1184
+
+--S 1185 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1185
+
+)clear all
+
+--S 1186 of 1580
+t0:=(-1+7*x+2*x^2)/(-1-x+x^2+x^3)
+--R 
+--R
+--R            2
+--R          2x  + 7x - 1
+--R   (1)  ---------------
+--R         3    2
+--R        x  + x  - x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1186
+
+--S 1187 of 1580
+r0:=(-3)/(1+x)+2*log(1-x)
+--R 
+--R
+--R        (2x + 2)log(- x + 1) - 3
+--R   (2)  ------------------------
+--R                  x + 1
+--R                                                    Type: Expression(Integer)
+--E 1187
+
+--S 1188 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (2x + 2)log(x - 1) - 3
+--R   (3)  ----------------------
+--R                 x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 1188
+
+--S 1189 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  2log(x - 1) - 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1189
+
+--S 1190 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1190
+
+)clear all
+
+--S 1191 of 1580
+t0:=(1+2*x)/(-1+3*x-3*x^2+x^3)
+--R 
+--R
+--R              2x + 1
+--R   (1)  -----------------
+--R         3     2
+--R        x  - 3x  + 3x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1191
+
+--S 1192 of 1580
+r0:=-1/6*(1+2*x)^2/(1-x)^2
+--R 
+--R
+--R          2  2   2     1
+--R        - - x  - - x - -
+--R          3      3     6
+--R   (2)  ----------------
+--R            2
+--R           x  - 2x + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1192
+
+--S 1193 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          - 4x + 1
+--R   (3)  ------------
+--R          2
+--R        2x  - 4x + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1193
+
+--S 1194 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        2
+--R   (4)  -
+--R        3
+--R                                                    Type: Expression(Integer)
+--E 1194
+
+--S 1195 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1195
+
+)clear all
+
+--S 1196 of 1580
+t0:=(5-5*x+7*x^2+x^3)/((-1+x)^2*(1+x)^3)
+--R 
+--R
+--R              3     2
+--R             x  + 7x  - 5x + 5
+--R   (1)  ---------------------------
+--R         5    4     3     2
+--R        x  + x  - 2x  - 2x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1196
+
+--S 1197 of 1580
+r0:=1/(1-x)+(-2)/(1+x)^2
+--R 
+--R
+--R            2
+--R         - x  - 4x + 1
+--R   (2)  ---------------
+--R         3    2
+--R        x  + x  - x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1197
+
+--S 1198 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2
+--R         - x  - 4x + 1
+--R   (3)  ---------------
+--R         3    2
+--R        x  + x  - x - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 1198
+
+--S 1199 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1199
+
+--S 1200 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1200
+
+)clear all
+
+--S 1201 of 1580
+t0:=(1+3*x+3*x^2)/(1+2*x+2*x^2+x^3)
+--R 
+--R
+--R             2
+--R           3x  + 3x + 1
+--R   (1)  -----------------
+--R         3     2
+--R        x  + 2x  + 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1201
+
+--S 1202 of 1580
+r0:=log(1+x)+log(1+x+x^2)-2*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                              +-+
+--R         +-+     2             +-+                   (2x + 1)\|3
+--R        \|3 log(x  + x + 1) + \|3 log(x + 1) - 2atan(------------)
+--R                                                           3
+--R   (2)  ----------------------------------------------------------
+--R                                    +-+
+--R                                   \|3
+--R                                                    Type: Expression(Integer)
+--E 1202
+
+--S 1203 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                              +-+
+--R         +-+     2             +-+                   (2x + 1)\|3
+--R        \|3 log(x  + x + 1) + \|3 log(x + 1) - 2atan(------------)
+--R                                                           3
+--R   (3)  ----------------------------------------------------------
+--R                                    +-+
+--R                                   \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1203
+
+--S 1204 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1204
+
+--S 1205 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1205
+
+)clear all
+
+--S 1206 of 1580
+t0:=(-1+2*x+x^2)/(-2*x+3*x^2+2*x^3)
+--R 
+--R
+--R           2
+--R          x  + 2x - 1
+--R   (1)  --------------
+--R          3     2
+--R        2x  + 3x  - 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1206
+
+--S 1207 of 1580
+r0:=1/10*log(1-2*x)+1/2*log(x)-1/10*log(2+x)
+--R 
+--R
+--R        - log(x + 2) + 5log(x) + log(- 2x + 1)
+--R   (2)  --------------------------------------
+--R                          10
+--R                                                    Type: Expression(Integer)
+--E 1207
+
+--S 1208 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(2x - 1) - log(x + 2) + 5log(x)
+--R   (3)  ----------------------------------
+--R                        10
+--R                                         Type: Union(Expression(Integer),...)
+--E 1208
+
+--S 1209 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        log(2x - 1) - log(- 2x + 1)
+--R   (4)  ---------------------------
+--R                     10
+--R                                                    Type: Expression(Integer)
+--E 1209
+
+--S 1210 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1210
+
+)clear all
+
+--S 1211 of 1580
+t0:=(1+4*x-2*x^2+x^4)/(1-x-x^2+x^3)
+--R 
+--R
+--R         4     2
+--R        x  - 2x  + 4x + 1
+--R   (1)  -----------------
+--R          3    2
+--R         x  - x  - x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1211
+
+--S 1212 of 1580
+r0:=2/(1-x)+x+1/2*x^2-2*atanh(x)
+--R 
+--R
+--R                              3    2
+--R        (- 4x + 4)atanh(x) + x  + x  - 2x - 4
+--R   (2)  -------------------------------------
+--R                        2x - 2
+--R                                                    Type: Expression(Integer)
+--E 1212
+
+--S 1213 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                     3    2
+--R        (- 2x + 2)log(x + 1) + (2x - 2)log(x - 1) + x  + x  - 2x - 4
+--R   (3)  ------------------------------------------------------------
+--R                                   2x - 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1213
+
+--S 1214 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  - log(x + 1) + log(x - 1) + 2atanh(x)
+--R                                                    Type: Expression(Integer)
+--E 1214
+
+--S 1215 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1215
+
+)clear all
+
+--S 1216 of 1580
+t0:=(4-x+2*x^2)/(4*x+x^3)
+--R 
+--R
+--R          2
+--R        2x  - x + 4
+--R   (1)  -----------
+--R           3
+--R          x  + 4x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1216
+
+--S 1217 of 1580
+r0:=-1/2*atan(1/2*x)+log(x)+1/2*log(4+x^2)
+--R 
+--R
+--R             2                       x
+--R        log(x  + 4) + 2log(x) - atan(-)
+--R                                     2
+--R   (2)  -------------------------------
+--R                       2
+--R                                                    Type: Expression(Integer)
+--E 1217
+
+--S 1218 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2                       x
+--R        log(x  + 4) + 2log(x) - atan(-)
+--R                                     2
+--R   (3)  -------------------------------
+--R                       2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1218
+
+--S 1219 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1219
+
+--S 1220 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1220
+
+)clear all
+
+--S 1221 of 1580
+t0:=(1+x^2+x^3)/((-1+x)*x*(1+x^2)^3*(1+x+x^2))
+--R 
+--R
+--R                        3    2
+--R                       x  + x  + 1
+--R   (1)  -----------------------------------------
+--R         10     8    7     6     5    4     3
+--R        x   + 3x  - x  + 3x  - 3x  + x  - 3x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1221
+
+--S 1222 of 1580
+r0:=1/8*(1+x)/(1+x^2)^2-3/8*(1-x)/(1+x^2)+3/16*x/(1+x^2)+_
+   7/16*atan(x)+1/8*log(1-x)-log(x)+15/16*log(1+x^2)-_
+   1/2*log(1+x+x^2)-atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R            4      2      +-+     2                4      2       +-+     2
+--R       (- 8x  - 16x  - 8)\|3 log(x  + x + 1) + (15x  + 30x  + 15)\|3 log(x  + 1)
+--R     + 
+--R             4      2       +-+            4     2      +-+
+--R       (- 16x  - 32x  - 16)\|3 log(x) + (2x  + 4x  + 2)\|3 log(- x + 1)
+--R     + 
+--R                                         +-+
+--R             4      2           (2x + 1)\|3        4      2      +-+
+--R       (- 16x  - 32x  - 16)atan(------------) + (7x  + 14x  + 7)\|3 atan(x)
+--R                                      3
+--R     + 
+--R          3     2            +-+
+--R       (9x  - 6x  + 11x - 4)\|3
+--R  /
+--R         4      2       +-+
+--R     (16x  + 32x  + 16)\|3
+--R                                                    Type: Expression(Integer)
+--E 1222
+
+--S 1223 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4      2      +-+     2                4      2       +-+     2
+--R       (- 8x  - 16x  - 8)\|3 log(x  + x + 1) + (15x  + 30x  + 15)\|3 log(x  + 1)
+--R     + 
+--R             4      2       +-+            4     2      +-+
+--R       (- 16x  - 32x  - 16)\|3 log(x) + (2x  + 4x  + 2)\|3 log(x - 1)
+--R     + 
+--R                                         +-+
+--R             4      2           (2x + 1)\|3        4      2      +-+
+--R       (- 16x  - 32x  - 16)atan(------------) + (7x  + 14x  + 7)\|3 atan(x)
+--R                                      3
+--R     + 
+--R          3     2            +-+
+--R       (9x  - 6x  + 11x - 4)\|3
+--R  /
+--R         4      2       +-+
+--R     (16x  + 32x  + 16)\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1223
+
+--S 1224 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        log(x - 1) - log(- x + 1)
+--R   (4)  -------------------------
+--R                    8
+--R                                                    Type: Expression(Integer)
+--E 1224
+
+--S 1225 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1225
+
+)clear all
+
+--S 1226 of 1580
+t0:=(1-3*x+2*x^2-x^3)/(1+x^2)^2
+--R 
+--R
+--R           3     2
+--R        - x  + 2x  - 3x + 1
+--R   (1)  -------------------
+--R             4     2
+--R            x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1226
+
+--S 1227 of 1580
+r0:=1/2*(2-x)/(1+x^2)+3/2*atan(x)-1/2*log(1+x^2)
+--R 
+--R
+--R            2          2           2
+--R        (- x  - 1)log(x  + 1) + (3x  + 3)atan(x) - x + 2
+--R   (2)  ------------------------------------------------
+--R                               2
+--R                             2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 1227
+
+--S 1228 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2          2           2
+--R        (- x  - 1)log(x  + 1) + (3x  + 3)atan(x) - x + 2
+--R   (3)  ------------------------------------------------
+--R                               2
+--R                             2x  + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1228
+
+--S 1229 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1229
+
+--S 1230 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1230
+
+)clear all
+
+--S 1231 of 1580
+t0:=(1-3*x+2*x^2-x^3)/(x*(1+x^2)^2)
+--R 
+--R
+--R           3     2
+--R        - x  + 2x  - 3x + 1
+--R   (1)  -------------------
+--R             5     3
+--R            x  + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1231
+
+--S 1232 of 1580
+r0:=1/2*(-1-2*x)/(1+x^2)-2*atan(x)+log(x)-1/2*log(1+x^2)
+--R 
+--R
+--R            2          2           2                   2
+--R        (- x  - 1)log(x  + 1) + (2x  + 2)log(x) + (- 4x  - 4)atan(x) - 2x - 1
+--R   (2)  ---------------------------------------------------------------------
+--R                                         2
+--R                                       2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 1232
+
+--S 1233 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2          2           2                   2
+--R        (- x  - 1)log(x  + 1) + (2x  + 2)log(x) + (- 4x  - 4)atan(x) - 2x - 1
+--R   (3)  ---------------------------------------------------------------------
+--R                                         2
+--R                                       2x  + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1233
+
+--S 1234 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1234
+
+--S 1235 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1235
+
+)clear all
+
+--S 1236 of 1580
+t0:=(1-x-x^2+x^3+x^4)/(-x+x^3)
+--R 
+--R
+--R         4    3    2
+--R        x  + x  - x  - x + 1
+--R   (1)  --------------------
+--R                3
+--R               x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1236
+
+--S 1237 of 1580
+r0:=x+1/2*x^2-log(x)+1/2*log(1-x^2)
+--R 
+--R
+--R                           2         2
+--R        - 2log(x) + log(- x  + 1) + x  + 2x
+--R   (2)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 1237
+
+--S 1238 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2                   2
+--R        log(x  - 1) - 2log(x) + x  + 2x
+--R   (3)  -------------------------------
+--R                       2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1238
+
+--S 1239 of 1580
+m0:=a0-r0
+--R 
+--R
+--R             2               2
+--R        log(x  - 1) - log(- x  + 1)
+--R   (4)  ---------------------------
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 1239
+
+--S 1240 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1240
+
+)clear all
+
+--S 1241 of 1580
+t0:=(2-4*x^2+x^3)/((1+x^2)*(2+x^2))
+--R 
+--R
+--R         3     2
+--R        x  - 4x  + 2
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1241
+
+--S 1242 of 1580
+r0:=6*atan(x)-1/2*log(1+x^2)+log(2+x^2)-5*atan(x/sqrt(2))*sqrt(2)
+--R 
+--R
+--R                                                  +-+
+--R              2             2           +-+     x\|2
+--R        2log(x  + 2) - log(x  + 1) - 10\|2 atan(-----) + 12atan(x)
+--R                                                  2
+--R   (2)  ----------------------------------------------------------
+--R                                     2
+--R                                                    Type: Expression(Integer)
+--E 1242
+
+--S 1243 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                 +-+
+--R              2             2           +-+     \|2
+--R        2log(x  + 2) - log(x  + 1) + 10\|2 atan(----) + 12atan(x)
+--R                                                  x
+--R   (3)  ---------------------------------------------------------
+--R                                    2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1243
+
+--S 1244 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                    +-+               +-+
+--R          +-+     x\|2       +-+     \|2
+--R   (4)  5\|2 atan(-----) + 5\|2 atan(----)
+--R                    2                  x
+--R                                                    Type: Expression(Integer)
+--E 1244
+
+--S 1245 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1245
+
+)clear all
+
+--S 1246 of 1580
+t0:=(1+x^2+x^4)/((1+x^2)*(4+x^2)^2)
+--R 
+--R
+--R              4    2
+--R             x  + x  + 1
+--R   (1)  --------------------
+--R         6     4      2
+--R        x  + 9x  + 24x  + 16
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1246
+
+--S 1247 of 1580
+r0:=-13/24*x/(4+x^2)+25/144*atan(1/2*x)+1/9*atan(x)
+--R 
+--R
+--R            2                    2            x
+--R        (16x  + 64)atan(x) + (25x  + 100)atan(-) - 78x
+--R                                              2
+--R   (2)  ----------------------------------------------
+--R                              2
+--R                          144x  + 576
+--R                                                    Type: Expression(Integer)
+--E 1247
+
+--S 1248 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2                    2            x
+--R        (16x  + 64)atan(x) + (25x  + 100)atan(-) - 78x
+--R                                              2
+--R   (3)  ----------------------------------------------
+--R                              2
+--R                          144x  + 576
+--R                                         Type: Union(Expression(Integer),...)
+--E 1248
+
+--S 1249 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1249
+
+--S 1250 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1250
+
+)clear all
+
+--S 1251 of 1580
+t0:=(1+x^2+x^3)/(2*x^2+x^3+x^4)
+--R 
+--R
+--R          3    2
+--R         x  + x  + 1
+--R   (1)  -------------
+--R         4    3     2
+--R        x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1251
+
+--S 1252 of 1580
+r0:=(-1/2)/x-1/4*log(x)+5/8*log(2+x+x^2)+1/4*atan((1+2*x)/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                                                                +-+
+--R           +-+     2               +-+                 (2x + 1)\|7       +-+
+--R        5x\|7 log(x  + x + 2) - 2x\|7 log(x) + 2x atan(------------) - 4\|7
+--R                                                             7
+--R   (2)  --------------------------------------------------------------------
+--R                                          +-+
+--R                                       8x\|7
+--R                                                    Type: Expression(Integer)
+--E 1252
+
+--S 1253 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                                +-+
+--R           +-+     2               +-+                 (2x + 1)\|7       +-+
+--R        5x\|7 log(x  + x + 2) - 2x\|7 log(x) + 2x atan(------------) - 4\|7
+--R                                                             7
+--R   (3)  --------------------------------------------------------------------
+--R                                          +-+
+--R                                       8x\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 1253
+
+--S 1254 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1254
+
+--S 1255 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1255
+
+)clear all
+
+--S 1256 of 1580
+t0:=(1-12*x+x^2+x^3)/(-12+x+x^2)
+--R 
+--R
+--R         3    2
+--R        x  + x  - 12x + 1
+--R   (1)  -----------------
+--R            2
+--R           x  + x - 12
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1256
+
+--S 1257 of 1580
+r0:=1/2*x^2-2/7*atanh(1/7*(1+2*x)),1/2*x^2+1/7*log(3-x)-1/7*log(4+x)
+--R 
+--R
+--R                  2x + 1      2
+--R         - 4atanh(------) + 7x                                    2
+--R                     7          - 2log(x + 4) + 2log(- x + 3) + 7x
+--R   (2)  [----------------------,-----------------------------------]
+--R                   14                            14
+--R                                             Type: Tuple(Expression(Integer))
+--E 1257
+
+--S 1258 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        2
+--R        - 2log(x + 4) + 2log(x - 3) + 7x
+--R   (3)  ---------------------------------
+--R                        14
+--R                                         Type: Union(Expression(Integer),...)
+--E 1258
+
+--S 1259 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                                           2x + 1
+--R        - log(x + 4) + log(x - 3) + 2atanh(------)
+--R                                              7
+--R   (4)  ------------------------------------------
+--R                             7
+--R                                                    Type: Expression(Integer)
+--E 1259
+
+--S 1260 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1260
+
+)clear all
+
+--S 1261 of 1580
+t0:=(-3+5*x+6*x^2)/(-3*x+2*x^2+x^3)
+--R 
+--R
+--R           2
+--R         6x  + 5x - 3
+--R   (1)  -------------
+--R         3     2
+--R        x  + 2x  - 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1261
+
+--S 1262 of 1580
+r0:=2*log(1-x)+log(x)+3*log(3+x)
+--R 
+--R
+--R   (2)  3log(x + 3) + log(x) + 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1262
+
+--S 1263 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  3log(x + 3) + log(x) + 2log(x - 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 1263
+
+--S 1264 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  2log(x - 1) - 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1264
+
+--S 1265 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1265
+
+)clear all
+
+--S 1266 of 1580
+t0:=(-2+3*x+5*x^2)/(2*x^2+x^3)
+--R 
+--R
+--R          2
+--R        5x  + 3x - 2
+--R   (1)  ------------
+--R           3     2
+--R          x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1266
+
+--S 1267 of 1580
+r0:=1/x+2*log(x)+3*log(2+x)
+--R 
+--R
+--R        3x log(x + 2) + 2x log(x) + 1
+--R   (2)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 1267
+
+--S 1268 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        3x log(x + 2) + 2x log(x) + 1
+--R   (3)  -----------------------------
+--R                      x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1268
+
+--S 1269 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1269
+
+--S 1270 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1270
+
+)clear all
+
+--S 1271 of 1580
+t0:=(18-2*x-4*x^2)/(-6+x+4*x^2+x^3)
+--R 
+--R
+--R             2
+--R         - 4x  - 2x + 18
+--R   (1)  ----------------
+--R         3     2
+--R        x  + 4x  + x - 6
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1271
+
+--S 1272 of 1580
+r0:=log(1-x)-2*log(2+x)-3*log(3+x)
+--R 
+--R
+--R   (2)  - 3log(x + 3) - 2log(x + 2) + log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1272
+
+--S 1273 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  - 3log(x + 3) - 2log(x + 2) + log(x - 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 1273
+
+--S 1274 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  log(x - 1) - log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1274
+
+--S 1275 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1275
+
+)clear all
+
+--S 1276 of 1580
+t0:=(1+x-2*x^2+x^3)/(4+5*x^2+x^4)
+--R 
+--R
+--R         3     2
+--R        x  - 2x  + x + 1
+--R   (1)  ----------------
+--R           4     2
+--R          x  + 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1276
+
+--S 1277 of 1580
+r0:=-3/2*atan(1/2*x)+atan(x)+1/2*log(4+x^2)
+--R 
+--R
+--R             2                         x
+--R        log(x  + 4) + 2atan(x) - 3atan(-)
+--R                                       2
+--R   (2)  ---------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 1277
+
+--S 1278 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2                         x
+--R        log(x  + 4) + 2atan(x) - 3atan(-)
+--R                                       2
+--R   (3)  ---------------------------------
+--R                        2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1278
+
+--S 1279 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1279
+
+--S 1280 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1280
+
+)clear all
+
+--S 1281 of 1580
+t0:=(-32+5*x-27*x^2+4*x^3)/(-70-299*x-286*x^2+50*x^3-13*x^4+30*x^5)
+--R 
+--R
+--R                   3      2
+--R                 4x  - 27x  + 5x - 32
+--R   (1)  --------------------------------------
+--R           5      4      3       2
+--R        30x  - 13x  + 50x  - 286x  - 299x - 70
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1281
+
+--S 1282 of 1580
+r0:=-3146/80155*log(7-3*x)-334/323*log(1+2*x)+4822/4879*log(2+5*x)+_
+   11049/260015*log(5+x+x^2)+3988/13685*atan((1+2*x)/sqrt(19))/sqrt(19)
+--R 
+--R
+--R   (2)
+--R              +--+     2                     +--+
+--R       453009\|19 log(x  + x + 5) + 10536070\|19 log(5x + 2)
+--R     + 
+--R                  +--+                     +--+
+--R       - 11023670\|19 log(2x + 1) - 418418\|19 log(- 3x + 7)
+--R     + 
+--R                            +--+
+--R                   (2x + 1)\|19
+--R       3106652atan(-------------)
+--R                         19
+--R  /
+--R              +--+
+--R     10660615\|19
+--R                                                    Type: Expression(Integer)
+--E 1282
+
+--S 1283 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +--+     2                     +--+
+--R       453009\|19 log(x  + x + 5) + 10536070\|19 log(5x + 2)
+--R     + 
+--R                +--+                       +--+
+--R       - 418418\|19 log(3x - 7) - 11023670\|19 log(2x + 1)
+--R     + 
+--R                            +--+
+--R                   (2x + 1)\|19
+--R       3106652atan(-------------)
+--R                         19
+--R  /
+--R              +--+
+--R     10660615\|19
+--R                                         Type: Union(Expression(Integer),...)
+--E 1283
+
+--S 1284 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        - 3146log(3x - 7) + 3146log(- 3x + 7)
+--R   (4)  -------------------------------------
+--R                        80155
+--R                                                    Type: Expression(Integer)
+--E 1284
+
+--S 1285 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1285
+
+)clear all
+
+--S 1286 of 1580
+t0:=(8-13*x^2-7*x^3+12*x^5)/(4-20*x+41*x^2-80*x^3+116*x^4-80*x^5+100*x^6)
+--R 
+--R
+--R                       5     3      2
+--R                    12x  - 7x  - 13x  + 8
+--R   (1)  --------------------------------------------
+--R            6      5       4      3      2
+--R        100x  - 80x  + 116x  - 80x  + 41x  - 20x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1286
+
+--S 1287 of 1580
+r0:=5828/9075/(2-5*x)+1/1452*(-313-502*x)/(1+2*x^2)-_
+   59096/99825*log(2-5*x)+2843/7986*log(1+2*x^2)+503/7986*atan(x*sqrt(2))/_
+   sqrt(2),5828/9075/(2-5*x)+1/1452*(-313-502*x)/(1+2*x^2)-_
+   59096/99825*log(2-5*x)+2843/7986*log(1+2*x^2)-_
+   251/726*atan(x*sqrt(2))/sqrt(2)+272/1331*atan(x*sqrt(2))*sqrt(2)
+--R 
+--R
+--R   (2)
+--R   [
+--R                  3          2                     +-+      2
+--R         (1421500x  - 568600x  + 710750x - 284300)\|2 log(2x  + 1)
+--R       + 
+--R                    3          2                      +-+
+--R         (- 2363840x  + 945536x  - 1181920x + 472768)\|2 log(- 5x + 2)
+--R       + 
+--R                 3          2                          +-+
+--R         (251500x  - 100600x  + 125750x - 50300)atan(x\|2 )
+--R       + 
+--R                    2                    +-+
+--R         (- 1203114x  - 154275x - 84282)\|2
+--R    /
+--R                3           2                      +-+
+--R       (3993000x  - 1597200x  + 1996500x - 798600)\|2
+--R     ,
+--R
+--R                  3          2                     +-+      2
+--R         (1421500x  - 568600x  + 710750x - 284300)\|2 log(2x  + 1)
+--R       + 
+--R                    3          2                      +-+
+--R         (- 2363840x  + 945536x  - 1181920x + 472768)\|2 log(- 5x + 2)
+--R       + 
+--R                 3          2                          +-+
+--R         (251500x  - 100600x  + 125750x - 50300)atan(x\|2 )
+--R       + 
+--R                    2                    +-+
+--R         (- 1203114x  - 154275x - 84282)\|2
+--R    /
+--R                3           2                      +-+
+--R       (3993000x  - 1597200x  + 1996500x - 798600)\|2
+--R     ]
+--R                                             Type: Tuple(Expression(Integer))
+--E 1287
+
+--S 1288 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3          2                     +-+      2
+--R       (1421500x  - 568600x  + 710750x - 284300)\|2 log(2x  + 1)
+--R     + 
+--R                  3          2                      +-+
+--R       (- 2363840x  + 945536x  - 1181920x + 472768)\|2 log(5x - 2)
+--R     + 
+--R               3          2                          +-+
+--R       (251500x  - 100600x  + 125750x - 50300)atan(x\|2 )
+--R     + 
+--R                  2                    +-+
+--R       (- 1203114x  - 154275x - 84282)\|2
+--R  /
+--R              3           2                      +-+
+--R     (3993000x  - 1597200x  + 1996500x - 798600)\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1288
+
+--S 1289 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        - 59096log(5x - 2) + 59096log(- 5x + 2)
+--R   (4)  ---------------------------------------
+--R                         99825
+--R                                                    Type: Expression(Integer)
+--E 1289
+
+--S 1290 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1290
+
+)clear all
+
+--S 1291 of 1580
+t0:=(9+x^4)/(x^2*(9+x^2))
+--R 
+--R
+--R          4
+--R         x  + 9
+--R   (1)  --------
+--R         4     2
+--R        x  + 9x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1291
+
+--S 1292 of 1580
+r0:=(-1)/x+x-10/3*atan(1/3*x)
+--R 
+--R
+--R                   x      2
+--R        - 10x atan(-) + 3x  - 3
+--R                   3
+--R   (2)  -----------------------
+--R                   3x
+--R                                                    Type: Expression(Integer)
+--E 1292
+
+--S 1293 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   x      2
+--R        - 10x atan(-) + 3x  - 3
+--R                   3
+--R   (3)  -----------------------
+--R                   3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1293
+
+--S 1294 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1294
+
+--S 1295 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1295
+
+)clear all
+
+--S 1296 of 1580
+t0:=(2*x+x^4)/(1+x^2)
+--R 
+--R
+--R         4
+--R        x  + 2x
+--R   (1)  -------
+--R          2
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1296
+
+--S 1297 of 1580
+r0:=-x+1/3*x^3+atan(x)+log(1+x^2)
+--R 
+--R
+--R              2                    3
+--R        3log(x  + 1) + 3atan(x) + x  - 3x
+--R   (2)  ---------------------------------
+--R                        3
+--R                                                    Type: Expression(Integer)
+--E 1297
+
+--S 1298 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                    3
+--R        3log(x  + 1) + 3atan(x) + x  - 3x
+--R   (3)  ---------------------------------
+--R                        3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1298
+
+--S 1299 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1299
+
+--S 1300 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1300
+
+)clear all
+
+--S 1301 of 1580
+t0:=(-x+x^3)/((-1+x)^2*(1+x^2))
+--R 
+--R
+--R              2
+--R             x  + x
+--R   (1)  ---------------
+--R         3    2
+--R        x  - x  + x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1301
+
+--S 1302 of 1580
+r0:=atan(x)+log(1-x)
+--R 
+--R
+--R   (2)  log(- x + 1) + atan(x)
+--R                                                    Type: Expression(Integer)
+--E 1302
+
+--S 1303 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  log(x - 1) + atan(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 1303
+
+--S 1304 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  log(x - 1) - log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1304
+
+--S 1305 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1305
+
+)clear all
+
+--S 1306 of 1580
+t0:=(2+5*x+3*x^2+2*x^3)/(1+x+x^2)
+--R 
+--R
+--R          3     2
+--R        2x  + 3x  + 5x + 2
+--R   (1)  ------------------
+--R             2
+--R            x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1306
+
+--S 1307 of 1580
+r0:=x+x^2+log(1+x+x^2)
+--R 
+--R
+--R             2             2
+--R   (2)  log(x  + x + 1) + x  + x
+--R                                                    Type: Expression(Integer)
+--E 1307
+
+--S 1308 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2             2
+--R   (3)  log(x  + x + 1) + x  + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1308
+
+--S 1309 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1309
+
+--S 1310 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1310
+
+)clear all
+
+--S 1311 of 1580
+t0:=(3-4*x-5*x^2+3*x^3)/(x^3*(-1+x+x^2))
+--R 
+--R
+--R          3     2
+--R        3x  - 5x  - 4x + 3
+--R   (1)  ------------------
+--R            5    4    3
+--R           x  + x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1311
+
+--S 1312 of 1580
+r0:=3/2/x^2+(-1)/x+3*log(x)-1/10*log(1+2*x-sqrt(5))*(15-sqrt(5))-_
+   1/10*log(1+2*x+sqrt(5))*(15+sqrt(5))
+--R 
+--R
+--R   (2)
+--R           2 +-+      2      +-+                2
+--R       (- x \|5  - 15x )log(\|5  + 2x + 1) + 30x log(x)
+--R     + 
+--R         2 +-+      2        +-+
+--R       (x \|5  - 15x )log(- \|5  + 2x + 1) - 10x + 15
+--R  /
+--R        2
+--R     10x
+--R                                                    Type: Expression(Integer)
+--E 1312
+
+--S 1313 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2           +-+
+--R        2    (2x  + 2x + 3)\|5  - 10x - 5      2 +-+     2
+--R       x log(----------------------------) - 3x \|5 log(x  + x - 1)
+--R                       2
+--R                      x  + x - 1
+--R     + 
+--R         2 +-+                    +-+
+--R       6x \|5 log(x) + (- 2x + 3)\|5
+--R  /
+--R       2 +-+
+--R     2x \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 1313
+
+--S 1314 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2           +-+
+--R           (2x  + 2x + 3)\|5  - 10x - 5       +-+          +-+
+--R       log(----------------------------) + (3\|5  + 1)log(\|5  + 2x + 1)
+--R                     2
+--R                    x  + x - 1
+--R     + 
+--R           +-+     2               +-+            +-+
+--R       - 3\|5 log(x  + x - 1) + (3\|5  - 1)log(- \|5  + 2x + 1)
+--R  /
+--R       +-+
+--R     2\|5
+--R                                                    Type: Expression(Integer)
+--E 1314
+
+--S 1315 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1315
+
+)clear all
+
+--S 1316 of 1580
+t0:=(4+8*x+5*x^2+2*x^3)/(2+2*x+x^2)^2
+--R 
+--R
+--R             3     2
+--R           2x  + 5x  + 8x + 4
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  + 4x  + 8x  + 8x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1316
+
+--S 1317 of 1580
+r0:=(-1)/(2+2*x+x^2)-atan(1+x)+log(2+2*x+x^2)
+--R 
+--R
+--R          2               2                 2
+--R        (x  + 2x + 2)log(x  + 2x + 2) + (- x  - 2x - 2)atan(x + 1) - 1
+--R   (2)  --------------------------------------------------------------
+--R                                   2
+--R                                  x  + 2x + 2
+--R                                                    Type: Expression(Integer)
+--E 1317
+
+--S 1318 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2               2                 2
+--R        (x  + 2x + 2)log(x  + 2x + 2) + (- x  - 2x - 2)atan(x + 1) - 1
+--R   (3)  --------------------------------------------------------------
+--R                                   2
+--R                                  x  + 2x + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1318
+
+--S 1319 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1319
+
+--S 1320 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1320
+
+)clear all
+
+--S 1321 of 1580
+t0:=(-1+x)^4*x^4/(1+x^2)
+--R 
+--R
+--R         8     7     6     5    4
+--R        x  - 4x  + 6x  - 4x  + x
+--R   (1)  -------------------------
+--R                   2
+--R                  x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1321
+
+--S 1322 of 1580
+r0:=4*x-4/3*x^3+x^5-2/3*x^6+1/7*x^7-4*atan(x)
+--R 
+--R
+--R                        7      6      5      3
+--R        - 84atan(x) + 3x  - 14x  + 21x  - 28x  + 84x
+--R   (2)  --------------------------------------------
+--R                             21
+--R                                                    Type: Expression(Integer)
+--E 1322
+
+--S 1323 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        7      6      5      3
+--R        - 84atan(x) + 3x  - 14x  + 21x  - 28x  + 84x
+--R   (3)  --------------------------------------------
+--R                             21
+--R                                         Type: Union(Expression(Integer),...)
+--E 1323
+
+--S 1324 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1324
+
+--S 1325 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1325
+
+)clear all
+
+--S 1326 of 1580
+t0:=(-20*x+4*x^2)/(9-10*x^2+x^4)
+--R 
+--R
+--R            2
+--R          4x  - 20x
+--R   (1)  -------------
+--R         4      2
+--R        x  - 10x  + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1326
+
+--S 1327 of 1580
+r0:=log(1-x)-1/2*log(3-x)+3/2*log(1+x)-2*log(3+x)
+--R 
+--R
+--R        - 4log(x + 3) + 3log(x + 1) - log(- x + 3) + 2log(- x + 1)
+--R   (2)  ----------------------------------------------------------
+--R                                     2
+--R                                                    Type: Expression(Integer)
+--E 1327
+
+--S 1328 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 4log(x + 3) + 3log(x + 1) + 2log(x - 1) - log(x - 3)
+--R   (3)  ------------------------------------------------------
+--R                                   2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1328
+
+--S 1329 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        2log(x - 1) - log(x - 3) + log(- x + 3) - 2log(- x + 1)
+--R   (4)  -------------------------------------------------------
+--R                                   2
+--R                                                    Type: Expression(Integer)
+--E 1329
+
+--S 1330 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1330
+
+)clear all
+
+--S 1331 of 1580
+t0:=(-1+x+4*x^3)/((-1+x)*x^2*(1+x^2))
+--R 
+--R
+--R             3
+--R           4x  + x - 1
+--R   (1)  -----------------
+--R         5    4    3    2
+--R        x  - x  + x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1331
+
+--S 1332 of 1580
+r0:=(-1)/x+atan(x)+2*log(1-x)-log(1+x^2)
+--R 
+--R
+--R                 2
+--R        - x log(x  + 1) + 2x log(- x + 1) + x atan(x) - 1
+--R   (2)  -------------------------------------------------
+--R                                x
+--R                                                    Type: Expression(Integer)
+--E 1332
+
+--S 1333 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 2
+--R        - x log(x  + 1) + 2x log(x - 1) + x atan(x) - 1
+--R   (3)  -----------------------------------------------
+--R                               x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1333
+
+--S 1334 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  2log(x - 1) - 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1334
+
+--S 1335 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1335
+
+)clear all
+
+--S 1336 of 1580
+t0:=(1-3*x+2*x^2-4*x^3+x^4)/(1+x^2)^3
+--R 
+--R
+--R         4     3     2
+--R        x  - 4x  + 2x  - 3x + 1
+--R   (1)  -----------------------
+--R            6     4     2
+--R           x  + 3x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1336
+
+--S 1337 of 1580
+r0:=(-1/4)/(1+x^2)^2+2/(1+x^2)+atan(x),1/4*(7-4*x)/(1+x^2)^2+2*x^2/(1+x^2)^2-_
+   x^3/(1+x^2)^2+x/(1+x^2)+atan(x)
+--R 
+--R
+--R            4     2                 2        4     2                 2
+--R         (4x  + 8x  + 4)atan(x) + 8x  + 7 (4x  + 8x  + 4)atan(x) + 8x  + 7
+--R   (2)  [--------------------------------,--------------------------------]
+--R                     4     2                          4     2
+--R                   4x  + 8x  + 4                    4x  + 8x  + 4
+--R                                             Type: Tuple(Expression(Integer))
+--E 1337
+
+--S 1338 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4     2                 2
+--R        (4x  + 8x  + 4)atan(x) + 8x  + 7
+--R   (3)  --------------------------------
+--R                    4     2
+--R                  4x  + 8x  + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1338
+
+--S 1339 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1339
+
+--S 1340 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1340
+
+)clear all
+
+--S 1341 of 1580
+t0:=(1-3*x+2*x^2-4*x^3+x^4)/(1+3*x^2+3*x^4+x^6)
+--R 
+--R
+--R         4     3     2
+--R        x  - 4x  + 2x  - 3x + 1
+--R   (1)  -----------------------
+--R            6     4     2
+--R           x  + 3x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1341
+
+--S 1342 of 1580
+r0:=(-1/4)/(1+x^2)^2+2/(1+x^2)+atan(x),1/4*(7-4*x)/(1+x^2)^2+2*x^2/(1+x^2)^2-_
+   x^3/(1+x^2)^2+x/(1+x^2)+atan(x)
+--R 
+--R
+--R            4     2                 2        4     2                 2
+--R         (4x  + 8x  + 4)atan(x) + 8x  + 7 (4x  + 8x  + 4)atan(x) + 8x  + 7
+--R   (2)  [--------------------------------,--------------------------------]
+--R                     4     2                          4     2
+--R                   4x  + 8x  + 4                    4x  + 8x  + 4
+--R                                             Type: Tuple(Expression(Integer))
+--E 1342
+
+--S 1343 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4     2                 2
+--R        (4x  + 8x  + 4)atan(x) + 8x  + 7
+--R   (3)  --------------------------------
+--R                    4     2
+--R                  4x  + 8x  + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1343
+
+--S 1344 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1344
+
+--S 1345 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1345
+
+)clear all
+
+--S 1346 of 1580
+t0:=(1+x+2*x^2+2*x^3)/(x^2+x^3+x^4)
+--R 
+--R
+--R          3     2
+--R        2x  + 2x  + x + 1
+--R   (1)  -----------------
+--R            4    3    2
+--R           x  + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1346
+
+--S 1347 of 1580
+r0:=(-1)/x+log(1+x+x^2)
+--R 
+--R
+--R               2
+--R        x log(x  + x + 1) - 1
+--R   (2)  ---------------------
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 1347
+
+--S 1348 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R        x log(x  + x + 1) - 1
+--R   (3)  ---------------------
+--R                  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1348
+
+--S 1349 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1349
+
+--S 1350 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1350
+
+)clear all
+
+--S 1351 of 1580
+t0:=1/((4-4*x+x^2)*(5-4*x+x^2))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R         4     3      2
+--R        x  - 8x  + 25x  - 36x + 20
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1351
+
+--S 1352 of 1580
+r0:=1/(2-x)+atan(2-x)
+--R 
+--R
+--R        (- x + 2)atan(x - 2) - 1
+--R   (2)  ------------------------
+--R                  x - 2
+--R                                                    Type: Expression(Integer)
+--E 1352
+
+--S 1353 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (- x + 2)atan(x - 2) - 1
+--R   (3)  ------------------------
+--R                  x - 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1353
+
+--S 1354 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1354
+
+--S 1355 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1355
+
+)clear all
+
+--S 1356 of 1580
+t0:=(-3+x+x^2)/((-3+x)*x^2)
+--R 
+--R
+--R         2
+--R        x  + x - 3
+--R   (1)  ----------
+--R          3     2
+--R         x  - 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1356
+
+--S 1357 of 1580
+r0:=(-1)/x+log(3-x)
+--R 
+--R
+--R        x log(- x + 3) - 1
+--R   (2)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 1357
+
+--S 1358 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        x log(x - 3) - 1
+--R   (3)  ----------------
+--R                x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1358
+
+--S 1359 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  log(x - 3) - log(- x + 3)
+--R                                                    Type: Expression(Integer)
+--E 1359
+
+--S 1360 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1360
+
+)clear all
+
+--S 1361 of 1580
+t0:=(1+x+4*x^2)/(x+4*x^3)
+--R 
+--R
+--R          2
+--R        4x  + x + 1
+--R   (1)  -----------
+--R            3
+--R          4x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1361
+
+--S 1362 of 1580
+r0:=1/2*atan(2*x)+log(x)
+--R 
+--R
+--R        2log(x) + atan(2x)
+--R   (2)  ------------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 1362
+
+--S 1363 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        2log(x) + atan(2x)
+--R   (3)  ------------------
+--R                 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1363
+
+--S 1364 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1364
+
+--S 1365 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1365
+
+)clear all
+
+--S 1366 of 1580
+t0:=(1-x+3*x^2)/(-x^2+x^3)
+--R 
+--R
+--R          2
+--R        3x  - x + 1
+--R   (1)  -----------
+--R           3    2
+--R          x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1366
+
+--S 1367 of 1580
+r0:=1/x+3*log(1-x)
+--R 
+--R
+--R        3x log(- x + 1) + 1
+--R   (2)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 1367
+
+--S 1368 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        3x log(x - 1) + 1
+--R   (3)  -----------------
+--R                x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1368
+
+--S 1369 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  3log(x - 1) - 3log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1369
+
+--S 1370 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1370
+
+)clear all
+
+--S 1371 of 1580
+t0:=(4+3*x+x^2)/(x+x^2)
+--R 
+--R
+--R         2
+--R        x  + 3x + 4
+--R   (1)  -----------
+--R            2
+--R           x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1371
+
+--S 1372 of 1580
+r0:=x+4*log(x)-2*log(1+x)
+--R 
+--R
+--R   (2)  - 2log(x + 1) + 4log(x) + x
+--R                                                    Type: Expression(Integer)
+--E 1372
+
+--S 1373 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  - 2log(x + 1) + 4log(x) + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1373
+
+--S 1374 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1374
+
+--S 1375 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1375
+
+)clear all
+
+--S 1376 of 1580
+t0:=(4+x+3*x^2)/(x+x^3)
+--R 
+--R
+--R          2
+--R        3x  + x + 4
+--R   (1)  -----------
+--R            3
+--R           x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1376
+
+--S 1377 of 1580
+r0:=atan(x)+4*log(x)-1/2*log(1+x^2)
+--R 
+--R
+--R               2
+--R        - log(x  + 1) + 8log(x) + 2atan(x)
+--R   (2)  ----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 1377
+
+--S 1378 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R        - log(x  + 1) + 8log(x) + 2atan(x)
+--R   (3)  ----------------------------------
+--R                         2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1378
+
+--S 1379 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1379
+
+--S 1380 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1380
+
+)clear all
+
+--S 1381 of 1580
+t0:=(7-4*x+8*x^2)/((1+4*x)*(1+x^2))
+--R 
+--R
+--R             2
+--R           8x  - 4x + 7
+--R   (1)  -----------------
+--R          3    2
+--R        4x  + x  + 4x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1381
+
+--S 1382 of 1580
+r0:=-atan(x)+2*log(1+4*x)
+--R 
+--R
+--R   (2)  2log(4x + 1) - atan(x)
+--R                                                    Type: Expression(Integer)
+--E 1382
+
+--S 1383 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  2log(4x + 1) - atan(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 1383
+
+--S 1384 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1384
+
+--S 1385 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1385
+
+)clear all
+
+--S 1386 of 1580
+t0:=x^2/((-1+x)*(1+2*x+x^2))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R         3    2
+--R        x  + x  - x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1386
+
+--S 1387 of 1580
+r0:=1/2/(1+x)+1/4*log(1-x)+3/4*log(1+x)
+--R 
+--R
+--R        (3x + 3)log(x + 1) + (x + 1)log(- x + 1) + 2
+--R   (2)  --------------------------------------------
+--R                           4x + 4
+--R                                                    Type: Expression(Integer)
+--E 1387
+
+--S 1388 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (3x + 3)log(x + 1) + (x + 1)log(x - 1) + 2
+--R   (3)  ------------------------------------------
+--R                          4x + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1388
+
+--S 1389 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        log(x - 1) - log(- x + 1)
+--R   (4)  -------------------------
+--R                    4
+--R                                                    Type: Expression(Integer)
+--E 1389
+
+--S 1390 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1390
+
+)clear all
+
+--S 1391 of 1580
+t0:=(-4+3*x+x^2)/((-1+2*x)^2*(3+2*x))
+--R 
+--R
+--R             2
+--R            x  + 3x - 4
+--R   (1)  -------------------
+--R          3     2
+--R        8x  + 4x  - 10x + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1391
+
+--S 1392 of 1580
+r0:=(-9/32)/(1-2*x)+41/128*log(1-2*x)-25/128*log(3+2*x)
+--R 
+--R
+--R        (- 50x + 25)log(2x + 3) + (82x - 41)log(- 2x + 1) + 36
+--R   (2)  ------------------------------------------------------
+--R                              256x - 128
+--R                                                    Type: Expression(Integer)
+--E 1392
+
+--S 1393 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (- 50x + 25)log(2x + 3) + (82x - 41)log(2x - 1) + 36
+--R   (3)  ----------------------------------------------------
+--R                             256x - 128
+--R                                         Type: Union(Expression(Integer),...)
+--E 1393
+
+--S 1394 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        41log(2x - 1) - 41log(- 2x + 1)
+--R   (4)  -------------------------------
+--R                      128
+--R                                                    Type: Expression(Integer)
+--E 1394
+
+--S 1395 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1395
+
+)clear all
+
+--S 1396 of 1580
+t0:=(5-4*x+3*x^2)/((-1+x)*(1+x^2))
+--R 
+--R
+--R            2
+--R          3x  - 4x + 5
+--R   (1)  ---------------
+--R         3    2
+--R        x  - x  + x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1396
+
+--S 1397 of 1580
+r0:=-3*atan(x)+2*log(1-x)+1/2*log(1+x^2)
+--R 
+--R
+--R             2
+--R        log(x  + 1) + 4log(- x + 1) - 6atan(x)
+--R   (2)  --------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 1397
+
+--S 1398 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R        log(x  + 1) + 4log(x - 1) - 6atan(x)
+--R   (3)  ------------------------------------
+--R                          2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1398
+
+--S 1399 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  2log(x - 1) - 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1399
+
+--S 1400 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1400
+
+)clear all
+
+--S 1401 of 1580
+t0:=(-1-2*x+x^2)/((-1+x)^2*(1+x^2))
+--R 
+--R
+--R               2
+--R              x  - 2x - 1
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  - 2x  + 2x  - 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1401
+
+--S 1402 of 1580
+r0:=1/(-1+x)+atan(x)+log(1-x)-1/2*log(1+x^2)
+--R 
+--R
+--R                      2
+--R        (- x + 1)log(x  + 1) + (2x - 2)log(- x + 1) + (2x - 2)atan(x) + 2
+--R   (2)  -----------------------------------------------------------------
+--R                                      2x - 2
+--R                                                    Type: Expression(Integer)
+--E 1402
+
+--S 1403 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      2
+--R        (- x + 1)log(x  + 1) + (2x - 2)log(x - 1) + (2x - 2)atan(x) + 2
+--R   (3)  ---------------------------------------------------------------
+--R                                     2x - 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1403
+
+--S 1404 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  log(x - 1) - log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1404
+
+--S 1405 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1405
+
+)clear all
+
+--S 1406 of 1580
+t0:=(5+x^3)/((10-6*x+x^2)*(1/2-x+x^2))
+--R 
+--R
+--R                   3
+--R                  x  + 5
+--R   (1)  --------------------------
+--R         4     3   33  2
+--R        x  - 7x  + -- x  - 13x + 5
+--R                    2
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 1406
+
+--S 1407 of 1580
+r0:=-261/221*atan(1-2*x)-1026/221*atan(3-x)+56/221*log(10-6*x+x^2)+_
+   109/442*log(1-2*x+2*x^2)
+--R 
+--R
+--R   (2)
+--R                2                     2
+--R       109log(2x  - 2x + 1) + 112log(x  - 6x + 10) + 522atan(2x - 1)
+--R     + 
+--R       2052atan(x - 3)
+--R  /
+--R     442
+--R                                                    Type: Expression(Integer)
+--E 1407
+
+--S 1408 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     109      2       1     56      2              261
+--R     --- log(x  - x + -) + --- log(x  - 6x + 10) + --- atan(2x - 1)
+--R     442              2    221                     221
+--R   + 
+--R     1026
+--R     ---- atan(x - 3)
+--R      221
+--R                               Type: Union(Expression(Fraction(Integer)),...)
+--E 1408
+
+--S 1409 of 1580
+m0:=a0-r0
+--R 
+--R
+--R          109       2             109      2       1
+--R   (4)  - --- log(2x  - 2x + 1) + --- log(x  - x + -)
+--R          442                     442              2
+--R                                          Type: Expression(Fraction(Integer))
+--E 1409
+
+--S 1410 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Expression(Fraction(Integer))
+--E 1410
+
+)clear all
+
+--S 1411 of 1580
+t0:=(4+3*x+x^2)/((-3+x)*(-2+x)*(-1+x))
+--R 
+--R
+--R             2
+--R            x  + 3x + 4
+--R   (1)  ------------------
+--R         3     2
+--R        x  - 6x  + 11x - 6
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1411
+
+--S 1412 of 1580
+r0:=4*log(1-x)-14*log(2-x)+11*log(3-x)
+--R 
+--R
+--R   (2)  11log(- x + 3) - 14log(- x + 2) + 4log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1412
+
+--S 1413 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  4log(x - 1) - 14log(x - 2) + 11log(x - 3)
+--R                                         Type: Union(Expression(Integer),...)
+--E 1413
+
+--S 1414 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R     4log(x - 1) - 14log(x - 2) + 11log(x - 3) - 11log(- x + 3) + 14log(- x + 2)
+--R   + 
+--R     - 4log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1414
+
+--S 1415 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1415
+
+)clear all
+
+--S 1416 of 1580
+t0:=(1+16*x)/((5+x)^2*(-3+2*x)*(1+x+x^2))
+--R 
+--R
+--R                      16x + 1
+--R   (1)  -----------------------------------
+--R          5      4      3      2
+--R        2x  + 19x  + 39x  - 38x  - 55x - 75
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1416
+
+--S 1417 of 1580
+r0:=(-79/273)/(5+x)+200/3211*log(3-2*x)+2731/24843*log(5+x)-_
+   481/5586*log(1+x+x^2)+451/2793*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                           +-+     2                               +-+
+--R       (- 81289x - 406445)\|3 log(x  + x + 1) + (103778x + 518890)\|3 log(x + 5)
+--R     + 
+--R                                                                            +-+
+--R                         +-+                                       (2x + 1)\|3
+--R       (58800x + 294000)\|3 log(- 2x + 3) + (152438x + 762190)atan(------------)
+--R                                                                         3
+--R     + 
+--R                +-+
+--R       - 273182\|3
+--R  /
+--R                         +-+
+--R     (944034x + 4720170)\|3
+--R                                                    Type: Expression(Integer)
+--E 1417
+
+--S 1418 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                           +-+     2                              +-+
+--R       (- 81289x - 406445)\|3 log(x  + x + 1) + (58800x + 294000)\|3 log(2x - 3)
+--R     + 
+--R                                                                          +-+
+--R                          +-+                                    (2x + 1)\|3
+--R       (103778x + 518890)\|3 log(x + 5) + (152438x + 762190)atan(------------)
+--R                                                                       3
+--R     + 
+--R                +-+
+--R       - 273182\|3
+--R  /
+--R                         +-+
+--R     (944034x + 4720170)\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1418
+
+--S 1419 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        200log(2x - 3) - 200log(- 2x + 3)
+--R   (4)  ---------------------------------
+--R                       3211
+--R                                                    Type: Expression(Integer)
+--E 1419
+
+--S 1420 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1420
+
+)clear all
+
+--S 1421 of 1580
+t0:=(-1+x^3)/(1+x+x^2)
+--R 
+--R
+--R   (1)  x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1421
+
+--S 1422 of 1580
+r0:=-x+1/2*x^2
+--R 
+--R
+--R        1  2
+--R   (2)  - x  - x
+--R        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1422
+
+--S 1423 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2
+--R        x  - 2x
+--R   (3)  -------
+--R           2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1423
+
+--S 1424 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1424
+
+--S 1425 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1425
+
+)clear all
+
+--S 1426 of 1580
+t0:=(-3+x^3)/(-7-6*x+x^2)
+--R 
+--R
+--R            3
+--R           x  - 3
+--R   (1)  -----------
+--R         2
+--R        x  - 6x - 7
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1426
+
+--S 1427 of 1580
+r0:=6*x+1/2*x^2+85/2*log(7-x)+1/2*log(1+x)
+--R 
+--R
+--R                                       2
+--R        log(x + 1) + 85log(- x + 7) + x  + 12x
+--R   (2)  --------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 1427
+
+--S 1428 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                     2
+--R        log(x + 1) + 85log(x - 7) + x  + 12x
+--R   (3)  ------------------------------------
+--R                          2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1428
+
+--S 1429 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        85log(x - 7) - 85log(- x + 7)
+--R   (4)  -----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 1429
+
+--S 1430 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1430
+
+)clear all
+
+--S 1431 of 1580
+t0:=(1+x^3)/(13+4*x+x^2)^2
+--R 
+--R
+--R                    3
+--R                   x  + 1
+--R   (1)  ----------------------------
+--R         4     3      2
+--R        x  + 8x  + 42x  + 104x + 169
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1431
+
+--S 1432 of 1580
+r0:=1/18*(67+47*x)/(13+4*x+x^2)-61/54*atan(2/3+1/3*x)+1/2*log(13+4*x+x^2)
+--R 
+--R
+--R   (2)
+--R           2                   2                    2                   x + 2
+--R       (27x  + 108x + 351)log(x  + 4x + 13) + (- 61x  - 244x - 793)atan(-----)
+--R                                                                          3
+--R     + 
+--R       141x + 201
+--R  /
+--R        2
+--R     54x  + 216x + 702
+--R                                                    Type: Expression(Integer)
+--E 1432
+
+--S 1433 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2                   2                    2                   x + 2
+--R       (27x  + 108x + 351)log(x  + 4x + 13) + (- 61x  - 244x - 793)atan(-----)
+--R                                                                          3
+--R     + 
+--R       141x + 201
+--R  /
+--R        2
+--R     54x  + 216x + 702
+--R                                         Type: Union(Expression(Integer),...)
+--E 1433
+
+--S 1434 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1434
+
+--S 1435 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1435
+
+)clear all
+
+--S 1436 of 1580
+t0:=(-32+36*x-42*x^2+21*x^3-10*x^4+3*x^5)/(x*(1+x^2)*(4+x^2)^2)
+--R 
+--R
+--R          5      4      3      2
+--R        3x  - 10x  + 21x  - 42x  + 36x - 32
+--R   (1)  -----------------------------------
+--R                7     5      3
+--R               x  + 9x  + 24x  + 16x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1436
+
+--S 1437 of 1580
+r0:=1/(4+x^2)+1/2*atan(1/2*x)+2*atan(x)-2*log(x)+log(4+x^2)
+--R 
+--R
+--R   (2)
+--R          2          2             2                  2
+--R       (2x  + 8)log(x  + 4) + (- 4x  - 16)log(x) + (4x  + 16)atan(x)
+--R     + 
+--R         2          x
+--R       (x  + 4)atan(-) + 2
+--R                    2
+--R  /
+--R       2
+--R     2x  + 8
+--R                                                    Type: Expression(Integer)
+--E 1437
+
+--S 1438 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2          2             2                  2
+--R       (2x  + 8)log(x  + 4) + (- 4x  - 16)log(x) + (4x  + 16)atan(x)
+--R     + 
+--R         2          x
+--R       (x  + 4)atan(-) + 2
+--R                    2
+--R  /
+--R       2
+--R     2x  + 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1438
+
+--S 1439 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1439
+
+--S 1440 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1440
+
+)clear all
+
+--S 1441 of 1580
+t0:=(-1+x^4+7*x^5+x^9)/(-7+6*x^4+x^8)
+--R 
+--R
+--R         9     5    4
+--R        x  + 7x  + x  - 1
+--R   (1)  -----------------
+--R            8     4
+--R           x  + 6x  - 7
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1441
+
+--S 1442 of 1580
+r0:=1/2*x^2+1/4*log(1-x^2)-1/4*log(1+x^2)-1/2*atan(1-x*sqrt(2)/7^(1/4))/_
+   (7^(3/4)*sqrt(2))+1/2*atan(1+x*sqrt(2)/7^(1/4))/(7^(3/4)*sqrt(2))-_
+   1/4*log(x^2-7^(1/4)*x*sqrt(2)+sqrt(7))/(7^(3/4)*sqrt(2))+_
+   1/4*log(x^2+7^(1/4)*x*sqrt(2)+sqrt(7))/(7^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             +-+4+-+    +-+    2     +-+4+-+3     2
+--R       log(x\|2 \|7  + \|7  + x ) - \|2 \|7  log(x  + 1)
+--R     + 
+--R        +-+4+-+3       2                +-+4+-+    +-+    2
+--R       \|2 \|7  log(- x  + 1) - log(- x\|2 \|7  + \|7  + x )
+--R     + 
+--R               +-+4+-+3                +-+4+-+3
+--R             x\|2 \|7   + 7          x\|2 \|7   - 7      2 +-+4+-+3
+--R       2atan(--------------) + 2atan(--------------) + 2x \|2 \|7
+--R                    7                       7
+--R  /
+--R       +-+4+-+3
+--R     4\|2 \|7
+--R                                                    Type: Expression(Integer)
+--E 1442
+
+--S 1443 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2 4+---+2     +-+4+---+              2 4+---+2     +-+4+---+
+--R       log(x  \|343  + 7x\|2 \|343  + 49) - log(x  \|343  - 7x\|2 \|343  + 49)
+--R     + 
+--R          +-+4+---+     2         +-+4+---+     2                     7
+--R       - \|2 \|343 log(x  + 1) + \|2 \|343 log(x  - 1) - 2atan(---------------)
+--R                                                                 +-+4+---+
+--R                                                               x\|2 \|343  - 7
+--R     + 
+--R                      7             2 +-+4+---+
+--R       - 2atan(---------------) + 2x \|2 \|343
+--R                 +-+4+---+
+--R               x\|2 \|343  + 7
+--R  /
+--R       +-+4+---+
+--R     4\|2 \|343
+--R                                         Type: Union(Expression(Integer),...)
+--E 1443
+
+--S 1444 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       4+-+3     2 4+---+2     +-+4+---+
+--R       \|7  log(x  \|343  + 7x\|2 \|343  + 49)
+--R     + 
+--R         4+-+3     2 4+---+2     +-+4+---+
+--R       - \|7  log(x  \|343  - 7x\|2 \|343  + 49)
+--R     + 
+--R         4+---+      +-+4+-+    +-+    2     +-+4+-+3 4+---+     2
+--R       - \|343 log(x\|2 \|7  + \|7  + x ) + \|2 \|7   \|343 log(x  - 1)
+--R     + 
+--R          +-+4+-+3 4+---+       2       4+---+        +-+4+-+    +-+    2
+--R       - \|2 \|7   \|343 log(- x  + 1 + \|343 log(- x\|2 \|7  + \|7  + x )
+--R     + 
+--R                       +-+4+-+3                      +-+4+-+3
+--R          4+---+     x\|2 \|7   + 7     4+---+     x\|2 \|7   - 7
+--R       - 2\|343 atan(--------------) - 2\|343 atan(--------------)
+--R                            7                             7
+--R     + 
+--R          4+-+3            7            4+-+3            7
+--R       - 2\|7  atan(---------------) - 2\|7  atan(---------------)
+--R                      +-+4+---+                     +-+4+---+
+--R                    x\|2 \|343  - 7               x\|2 \|343  + 7
+--R  /
+--R       +-+4+-+3 4+---+
+--R     4\|2 \|7   \|343
+--R                                                    Type: Expression(Integer)
+--E 1444
+
+--S 1445 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R               2 +-+     4     4+-+2        4      +-+      2
+--R            (2x \|7  + 3x  + 7)\|7   + (- 3x  - 7)\|7  - 14x
+--R   (5)  --------------------------------------------------------
+--R            6      2  +-+     8      4      4+-+2      6       2
+--R        ((4x  + 28x )\|7  + 2x  + 28x  + 98)\|7   - 28x  - 196x
+--R                                                    Type: Expression(Integer)
+--E 1445
+
+)clear all
+
+--S 1446 of 1580
+t0:=(1+x^3+x^6)/(x+x^5)
+--R 
+--R
+--R         6    3
+--R        x  + x  + 1
+--R   (1)  -----------
+--R            5
+--R           x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1446
+
+--S 1447 of 1580
+r0:=1/2*x^2-1/2*atan(x^2)+log(x)-1/4*log(1+x^4)-_
+   1/2*atan(1-x*sqrt(2))/sqrt(2)+1/2*atan(1+x*sqrt(2))/sqrt(2)+_
+   1/4*log(1+x^2-x*sqrt(2))/sqrt(2)-1/4*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R               +-+    2         +-+     4          +-+
+--R       - log(x\|2  + x  + 1) - \|2 log(x  + 1) + 4\|2 log(x)
+--R     + 
+--R               +-+    2                +-+                +-+
+--R       log(- x\|2  + x  + 1) + 2atan(x\|2  + 1) + 2atan(x\|2  - 1)
+--R     + 
+--R           +-+      2      2 +-+
+--R       - 2\|2 atan(x ) + 2x \|2
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 1447
+
+--S 1448 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +------------------------------------------------------+
+--R              |        2                               2
+--R           - \|- 3%%HQ1  + (- 2%%HQ0 - 2)%%HQ1 - 3%%HQ0  - 2%%HQ0 - 1  - %%HQ1
+--R         + 
+--R           - %%HQ0 - 1
+--R      *
+--R         log
+--R                ((32%%HQ0 - 8)%%HQ1 - 8%%HQ0 - 4)
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        2                               2
+--R                \|- 3%%HQ1  + (- 2%%HQ0 - 2)%%HQ1 - 3%%HQ0  - 2%%HQ0 - 1
+--R            + 
+--R                                  2             2                             2
+--R              (- 32%%HQ0 + 8)%%HQ1  + (- 32%%HQ0  - 32%%HQ0 + 4)%%HQ1 + 8%%HQ0
+--R            + 
+--R              4%%HQ0 + 3x + 3
+--R     + 
+--R            +------------------------------------------------------+
+--R            |        2                               2
+--R           \|- 3%%HQ1  + (- 2%%HQ0 - 2)%%HQ1 - 3%%HQ0  - 2%%HQ0 - 1  - %%HQ1
+--R         + 
+--R           - %%HQ0 - 1
+--R      *
+--R         log
+--R                ((- 32%%HQ0 + 8)%%HQ1 + 8%%HQ0 + 4)
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        2                               2
+--R                \|- 3%%HQ1  + (- 2%%HQ0 - 2)%%HQ1 - 3%%HQ0  - 2%%HQ0 - 1
+--R            + 
+--R                                  2             2                             2
+--R              (- 32%%HQ0 + 8)%%HQ1  + (- 32%%HQ0  - 32%%HQ0 + 4)%%HQ1 + 8%%HQ0
+--R            + 
+--R              4%%HQ0 + 3x + 3
+--R     + 
+--R         2%%HQ1
+--R      *
+--R         log
+--R                                 2           2                              3
+--R              (64%%HQ0 - 16)%%HQ1  + (64%%HQ0  + 64%%HQ0 - 8)%%HQ1 + 64%%HQ0
+--R            + 
+--R                     2
+--R              64%%HQ0  + 32%%HQ0 + 3x - 1
+--R     + 
+--R                           3          2                                  2
+--R       2%%HQ0 log(- 64%%HQ0  - 80%%HQ0  - 40%%HQ0 + 3x - 5) + 2log(x) + x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1448
+
+--S 1449 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +------------------------------------------------------+
+--R               +-+ |        2                               2
+--R           - 2\|2 \|- 3%%HQ1  + (- 2%%HQ0 - 2)%%HQ1 - 3%%HQ0  - 2%%HQ0 - 1
+--R         + 
+--R               +-+          +-+          +-+
+--R           - 2\|2 %%HQ1 - 2\|2 %%HQ0 - 2\|2
+--R      *
+--R         log
+--R                ((32%%HQ0 - 8)%%HQ1 - 8%%HQ0 - 4)
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        2                               2
+--R                \|- 3%%HQ1  + (- 2%%HQ0 - 2)%%HQ1 - 3%%HQ0  - 2%%HQ0 - 1
+--R            + 
+--R                                  2             2                             2
+--R              (- 32%%HQ0 + 8)%%HQ1  + (- 32%%HQ0  - 32%%HQ0 + 4)%%HQ1 + 8%%HQ0
+--R            + 
+--R              4%%HQ0 + 3x + 3
+--R     + 
+--R                 +------------------------------------------------------+
+--R             +-+ |        2                               2
+--R           2\|2 \|- 3%%HQ1  + (- 2%%HQ0 - 2)%%HQ1 - 3%%HQ0  - 2%%HQ0 - 1
+--R         + 
+--R               +-+          +-+          +-+
+--R           - 2\|2 %%HQ1 - 2\|2 %%HQ0 - 2\|2
+--R      *
+--R         log
+--R                ((- 32%%HQ0 + 8)%%HQ1 + 8%%HQ0 + 4)
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        2                               2
+--R                \|- 3%%HQ1  + (- 2%%HQ0 - 2)%%HQ1 - 3%%HQ0  - 2%%HQ0 - 1
+--R            + 
+--R                                  2             2                             2
+--R              (- 32%%HQ0 + 8)%%HQ1  + (- 32%%HQ0  - 32%%HQ0 + 4)%%HQ1 + 8%%HQ0
+--R            + 
+--R              4%%HQ0 + 3x + 3
+--R     + 
+--R           +-+
+--R         4\|2 %%HQ1
+--R      *
+--R         log
+--R                                 2           2                              3
+--R              (64%%HQ0 - 16)%%HQ1  + (64%%HQ0  + 64%%HQ0 - 8)%%HQ1 + 64%%HQ0
+--R            + 
+--R                     2
+--R              64%%HQ0  + 32%%HQ0 + 3x - 1
+--R     + 
+--R         +-+                   3          2
+--R       4\|2 %%HQ0 log(- 64%%HQ0  - 80%%HQ0  - 40%%HQ0 + 3x - 5)
+--R     + 
+--R             +-+    2         +-+     4                +-+    2
+--R       log(x\|2  + x  + 1) + \|2 log(x  + 1) - log(- x\|2  + x  + 1)
+--R     + 
+--R                 +-+                +-+          +-+      2
+--R       - 2atan(x\|2  + 1) - 2atan(x\|2  - 1) + 2\|2 atan(x )
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 1449
+
+--S 1450 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1450
+
+)clear all
+
+--S 1451 of 1580
+t0:=(1+x^2)/(-x+x^2)
+--R 
+--R
+--R         2
+--R        x  + 1
+--R   (1)  ------
+--R         2
+--R        x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1451
+
+--S 1452 of 1580
+r0:=x+2*log(1-x)-log(x)
+--R 
+--R
+--R   (2)  - log(x) + 2log(- x + 1) + x
+--R                                                    Type: Expression(Integer)
+--E 1452
+
+--S 1453 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  - log(x) + 2log(x - 1) + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1453
+
+--S 1454 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  2log(x - 1) - 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1454
+
+--S 1455 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1455
+
+)clear all
+
+--S 1456 of 1580
+t0:=(1+x^3)/(-x+x^3)
+--R 
+--R
+--R         2
+--R        x  - x + 1
+--R   (1)  ----------
+--R           2
+--R          x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1456
+
+--S 1457 of 1580
+r0:=x+log(1-x)-log(x)
+--R 
+--R
+--R   (2)  - log(x) + log(- x + 1) + x
+--R                                                    Type: Expression(Integer)
+--E 1457
+
+--S 1458 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  - log(x) + log(x - 1) + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1458
+
+--S 1459 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  log(x - 1) - log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1459
+
+--S 1460 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1460
+
+)clear all
+
+--S 1461 of 1580
+t0:=(1+x^3)/(-x^2+x^3)
+--R 
+--R
+--R          3
+--R         x  + 1
+--R   (1)  -------
+--R         3    2
+--R        x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1461
+
+--S 1462 of 1580
+r0:=1/x+x+2*log(1-x)-log(x)
+--R 
+--R
+--R                                        2
+--R        - x log(x) + 2x log(- x + 1) + x  + 1
+--R   (2)  -------------------------------------
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 1462
+
+--S 1463 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                      2
+--R        - x log(x) + 2x log(x - 1) + x  + 1
+--R   (3)  -----------------------------------
+--R                         x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1463
+
+--S 1464 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  2log(x - 1) - 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 1464
+
+--S 1465 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1465
+
+)clear all
+
+--S 1466 of 1580
+t0:=(-1+x^5)/(-x+x^3)
+--R 
+--R
+--R         4    3    2
+--R        x  + x  + x  + x + 1
+--R   (1)  --------------------
+--R                2
+--R               x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1466
+
+--S 1467 of 1580
+r0:=x+1/3*x^3+log(x)-log(1+x)
+--R 
+--R
+--R                                   3
+--R        - 3log(x + 1) + 3log(x) + x  + 3x
+--R   (2)  ---------------------------------
+--R                        3
+--R                                                    Type: Expression(Integer)
+--E 1467
+
+--S 1468 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   3
+--R        - 3log(x + 1) + 3log(x) + x  + 3x
+--R   (3)  ---------------------------------
+--R                        3
+--R                                         Type: Union(Expression(Integer),...)
+--E 1468
+
+--S 1469 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1469
+
+--S 1470 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1470
+
+)clear all
+
+--S 1471 of 1580
+t0:=(1+x^4)/(x^3+x^5)
+--R 
+--R
+--R          4
+--R         x  + 1
+--R   (1)  -------
+--R         5    3
+--R        x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1471
+
+--S 1472 of 1580
+r0:=(-1/2)/x^2-log(x)+log(1+x^2)
+--R 
+--R
+--R          2     2          2
+--R        2x log(x  + 1) - 2x log(x) - 1
+--R   (2)  ------------------------------
+--R                        2
+--R                      2x
+--R                                                    Type: Expression(Integer)
+--E 1472
+
+--S 1473 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2     2          2
+--R        2x log(x  + 1) - 2x log(x) - 1
+--R   (3)  ------------------------------
+--R                        2
+--R                      2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1473
+
+--S 1474 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1474
+
+--S 1475 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1475
+
+)clear all
+
+--S 1476 of 1580
+t0:=(1+x^2)/(x+2*x^2+x^3)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         3     2
+--R        x  + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1476
+
+--S 1477 of 1580
+r0:=2/(1+x)+log(x)
+--R 
+--R
+--R        (x + 1)log(x) + 2
+--R   (2)  -----------------
+--R              x + 1
+--R                                                    Type: Expression(Integer)
+--E 1477
+
+--S 1478 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (x + 1)log(x) + 2
+--R   (3)  -----------------
+--R              x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 1478
+
+--S 1479 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1479
+
+--S 1480 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1480
+
+)clear all
+
+--S 1481 of 1580
+t0:=(1+x^5)/(-10*x-3*x^2+x^3)
+--R 
+--R
+--R             5
+--R            x  + 1
+--R   (1)  --------------
+--R         3     2
+--R        x  - 3x  - 10x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1481
+
+--S 1482 of 1580
+r0:=19*x+3/2*x^2+1/3*x^3+3126/35*log(5-x)-1/10*log(x)-31/14*log(2+x)
+--R 
+--R
+--R                                                            3       2
+--R        - 465log(x + 2) - 21log(x) + 18756log(- x + 5) + 70x  + 315x  + 3990x
+--R   (2)  ---------------------------------------------------------------------
+--R                                         210
+--R                                                    Type: Expression(Integer)
+--E 1482
+
+--S 1483 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                          3       2
+--R        - 465log(x + 2) - 21log(x) + 18756log(x - 5) + 70x  + 315x  + 3990x
+--R   (3)  -------------------------------------------------------------------
+--R                                        210
+--R                                         Type: Union(Expression(Integer),...)
+--E 1483
+
+--S 1484 of 1580
+m0:=a0-r0
+--R 
+--R
+--R        3126log(x - 5) - 3126log(- x + 5)
+--R   (4)  ---------------------------------
+--R                        35
+--R                                                    Type: Expression(Integer)
+--E 1484
+
+--S 1485 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1485
+
+)clear all
+
+--S 1486 of 1580
+t0:=(15-5*x+x^2+x^3)/((5+x^2)*(3+2*x+x^2))
+--R 
+--R
+--R             3    2
+--R            x  + x  - 5x + 15
+--R   (1)  -------------------------
+--R         4     3     2
+--R        x  + 2x  + 8x  + 10x + 15
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1486
+
+--S 1487 of 1580
+r0:=1/2*log(3+2*x+x^2)+5*atan((1+x)/sqrt(2))/sqrt(2)-atan(x/sqrt(5))*sqrt(5)
+--R 
+--R
+--R                                               +-+                   +-+
+--R         +-+     2               +-+ +-+     x\|5            (x + 1)\|2
+--R        \|2 log(x  + 2x + 3) - 2\|2 \|5 atan(-----) + 10atan(-----------)
+--R                                               5                  2
+--R   (2)  -----------------------------------------------------------------
+--R                                        +-+
+--R                                      2\|2
+--R                                                    Type: Expression(Integer)
+--E 1487
+
+--S 1488 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                              +-+                   +-+
+--R         +-+     2               +-+ +-+     \|5            (x + 1)\|2
+--R        \|2 log(x  + 2x + 3) + 2\|2 \|5 atan(----) + 10atan(-----------)
+--R                                               x                 2
+--R   (3)  ----------------------------------------------------------------
+--R                                        +-+
+--R                                      2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1488
+
+--S 1489 of 1580
+m0:=a0-r0
+--R 
+--R
+--R                   +-+              +-+
+--R         +-+     x\|5      +-+     \|5
+--R   (4)  \|5 atan(-----) + \|5 atan(----)
+--R                   5                 x
+--R                                                    Type: Expression(Integer)
+--E 1489
+
+--S 1490 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1490
+
+)clear all
+
+--S 1491 of 1580
+t0:=1/((1+x^2)*(3+10*x/(1+x^2)))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R          2
+--R        3x  + 10x + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1491
+
+--S 1492 of 1580
+r0:=-1/8*log(3+x)+1/8*log(1+3*x)
+--R 
+--R
+--R        log(3x + 1) - log(x + 3)
+--R   (2)  ------------------------
+--R                    8
+--R                                                    Type: Expression(Integer)
+--E 1492
+
+--S 1493 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(3x + 1) - log(x + 3)
+--R   (3)  ------------------------
+--R                    8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1493
+
+--S 1494 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1494
+
+--S 1495 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1495
+
+)clear all
+
+--S 1496 of 1580
+t0:=x^3/(13+2/x+15*x)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1496
+
+--S 1497 of 1580
+r0:=139/3375*x-13/450*x^2+1/45*x^3-16/567*log(2+3*x)+1/4375*log(1+5*x)
+--R 
+--R
+--R                                                  3         2
+--R        162log(5x + 1) - 20000log(3x + 2) + 15750x  - 20475x  + 29190x
+--R   (2)  --------------------------------------------------------------
+--R                                    708750
+--R                                                    Type: Expression(Integer)
+--E 1497
+
+--S 1498 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                  3         2
+--R        162log(5x + 1) - 20000log(3x + 2) + 15750x  - 20475x  + 29190x
+--R   (3)  --------------------------------------------------------------
+--R                                    708750
+--R                                         Type: Union(Expression(Integer),...)
+--E 1498
+
+--S 1499 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1499
+
+--S 1500 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1500
+
+)clear all
+
+--S 1501 of 1580
+t0:=x^2/(13+2/x+15*x)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1501
+
+--S 1502 of 1580
+r0:=-13/225*x+1/30*x^2+8/189*log(2+3*x)-1/875*log(1+5*x)
+--R 
+--R
+--R                                                 2
+--R        - 54log(5x + 1) + 2000log(3x + 2) + 1575x  - 2730x
+--R   (2)  --------------------------------------------------
+--R                               47250
+--R                                                    Type: Expression(Integer)
+--E 1502
+
+--S 1503 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                 2
+--R        - 54log(5x + 1) + 2000log(3x + 2) + 1575x  - 2730x
+--R   (3)  --------------------------------------------------
+--R                               47250
+--R                                         Type: Union(Expression(Integer),...)
+--E 1503
+
+--S 1504 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1504
+
+--S 1505 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1505
+
+)clear all
+
+--S 1506 of 1580
+t0:=x/(13+2/x+15*x)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1506
+
+--S 1507 of 1580
+r0:=1/15*x-4/63*log(2+3*x)+1/175*log(1+5*x)
+--R 
+--R
+--R        9log(5x + 1) - 100log(3x + 2) + 105x
+--R   (2)  ------------------------------------
+--R                        1575
+--R                                                    Type: Expression(Integer)
+--E 1507
+
+--S 1508 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        9log(5x + 1) - 100log(3x + 2) + 105x
+--R   (3)  ------------------------------------
+--R                        1575
+--R                                         Type: Union(Expression(Integer),...)
+--E 1508
+
+--S 1509 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1509
+
+--S 1510 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1510
+
+)clear all
+
+--S 1511 of 1580
+t0:=1/(13+2/x+15*x)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1511
+
+--S 1512 of 1580
+r0:=2/21*log(2+3*x)-1/35*log(1+5*x)
+--R 
+--R
+--R        - 3log(5x + 1) + 10log(3x + 2)
+--R   (2)  ------------------------------
+--R                      105
+--R                                                    Type: Expression(Integer)
+--E 1512
+
+--S 1513 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 3log(5x + 1) + 10log(3x + 2)
+--R   (3)  ------------------------------
+--R                      105
+--R                                         Type: Union(Expression(Integer),...)
+--E 1513
+
+--S 1514 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1514
+
+--S 1515 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1515
+
+)clear all
+
+--S 1516 of 1580
+t0:=1/(x*(13+2/x+15*x))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1516
+
+--S 1517 of 1580
+r0:=-1/7*log(2+3*x)+1/7*log(1+5*x)
+--R 
+--R
+--R        log(5x + 1) - log(3x + 2)
+--R   (2)  -------------------------
+--R                    7
+--R                                                    Type: Expression(Integer)
+--E 1517
+
+--S 1518 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(5x + 1) - log(3x + 2)
+--R   (3)  -------------------------
+--R                    7
+--R                                         Type: Union(Expression(Integer),...)
+--E 1518
+
+--S 1519 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1519
+
+--S 1520 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1520
+
+)clear all
+
+--S 1521 of 1580
+t0:=1/(x^2*(13+2/x+15*x))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           3      2
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1521
+
+--S 1522 of 1580
+r0:=1/2*log(x)+3/14*log(2+3*x)-5/7*log(1+5*x)
+--R 
+--R
+--R        - 10log(5x + 1) + 3log(3x + 2) + 7log(x)
+--R   (2)  ----------------------------------------
+--R                           14
+--R                                                    Type: Expression(Integer)
+--E 1522
+
+--S 1523 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 10log(5x + 1) + 3log(3x + 2) + 7log(x)
+--R   (3)  ----------------------------------------
+--R                           14
+--R                                         Type: Union(Expression(Integer),...)
+--E 1523
+
+--S 1524 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1524
+
+--S 1525 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1525
+
+)clear all
+
+--S 1526 of 1580
+t0:=1/(x^3*(13+2/x+15*x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           4      3     2
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1526
+
+--S 1527 of 1580
+r0:=(-1/2)/x-13/4*log(x)-9/28*log(2+3*x)+25/7*log(1+5*x)
+--R 
+--R
+--R        100x log(5x + 1) - 9x log(3x + 2) - 91x log(x) - 14
+--R   (2)  ---------------------------------------------------
+--R                                28x
+--R                                                    Type: Expression(Integer)
+--E 1527
+
+--S 1528 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R        100x log(5x + 1) - 9x log(3x + 2) - 91x log(x) - 14
+--R   (3)  ---------------------------------------------------
+--R                                28x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1528
+
+--S 1529 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1529
+
+--S 1530 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1530
+
+)clear all
+
+--S 1531 of 1580
+t0:=1/(x^4*(13+2/x+15*x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           5      4     3
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1531
+
+--S 1532 of 1580
+r0:=(-1/4)/x^2+13/4/x+139/8*log(x)+27/56*log(2+3*x)-125/7*log(1+5*x)
+--R 
+--R
+--R               2                 2                  2
+--R        - 1000x log(5x + 1) + 27x log(3x + 2) + 973x log(x) + 182x - 14
+--R   (2)  ---------------------------------------------------------------
+--R                                         2
+--R                                      56x
+--R                                                    Type: Expression(Integer)
+--E 1532
+
+--S 1533 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2                 2                  2
+--R        - 1000x log(5x + 1) + 27x log(3x + 2) + 973x log(x) + 182x - 14
+--R   (3)  ---------------------------------------------------------------
+--R                                         2
+--R                                      56x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1533
+
+--S 1534 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1534
+
+--S 1535 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1535
+
+)clear all
+
+--S 1536 of 1580
+t0:=1/(x^5*(13+2/x+15*x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           6      5     4
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1536
+
+--S 1537 of 1580
+r0:=(-1/6)/x^3+13/8/x^2+(-139/8)/x-1417/16*log(x)-81/112*log(2+3*x)+_
+   625/7*log(1+5*x)
+--R 
+--R
+--R   (2)
+--R         3                  3                    3              2
+--R   30000x log(5x + 1) - 243x log(3x + 2) - 29757x log(x) - 5838x  + 546x - 56
+--R   --------------------------------------------------------------------------
+--R                                          3
+--R                                      336x
+--R                                                    Type: Expression(Integer)
+--E 1537
+
+--S 1538 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3                  3                    3              2
+--R   30000x log(5x + 1) - 243x log(3x + 2) - 29757x log(x) - 5838x  + 546x - 56
+--R   --------------------------------------------------------------------------
+--R                                          3
+--R                                      336x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1538
+
+--S 1539 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1539
+
+--S 1540 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1540
+
+)clear all
+
+--S 1541 of 1580
+t0:=(1-x^2)/(a+b*(1-x^2)^4)
+--R 
+--R
+--R                         2
+--R                      - x  + 1
+--R   (1)  ------------------------------------
+--R           8       6       4       2
+--R        b x  - 4b x  + 6b x  - 4b x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1541
+
+--S 1542 of 1580
+r0:=1/4*atan(b^(1/8)*x/sqrt(%i*(-a)^(1/4)-b^(1/4)))/(b^(3/8)*sqrt(-a)*_
+   sqrt(%i*(-a)^(1/4)-b^(1/4)))-1/4*atan(b^(1/8)*x/sqrt((-a)^(1/4)-_
+   b^(1/4)))/(b^(3/8)*sqrt(-a)*sqrt((-a)^(1/4)-b^(1/4)))-_
+   1/4*atanh(b^(1/8)*x/sqrt(%i*(-a)^(1/4)+b^(1/4)))/(b^(3/8)*sqrt(-a)*_
+   sqrt(%i*(-a)^(1/4)+b^(1/4)))+1/4*atanh(b^(1/8)*x/sqrt((-a)^(1/4)+_
+   b^(1/4)))/(b^(3/8)*sqrt(-a)*sqrt((-a)^(1/4)+b^(1/4)))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +-----------------+ +---------------+ +-------------+
+--R             |  4+-+     4+---+  |  4+-+   4+---+  |4+-+   4+---+
+--R            \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + \|- a
+--R         *
+--R                          8+-+
+--R                         x\|b
+--R            atanh(------------------)
+--R                   +---------------+
+--R                   |4+-+     4+---+
+--R                  \|\|b  + %i\|- a
+--R     + 
+--R          +-----------------+ +---------------+ +---------------+
+--R          |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R                      8+-+
+--R                     x\|b
+--R         atanh(----------------)
+--R                +-------------+
+--R                |4+-+   4+---+
+--R               \|\|b  + \|- a
+--R     + 
+--R          +---------------+ +---------------+ +-------------+
+--R          |  4+-+   4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R         \|- \|b  + \|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R      *
+--R                       8+-+
+--R                      x\|b
+--R         atan(--------------------)
+--R               +-----------------+
+--R               |  4+-+     4+---+
+--R              \|- \|b  + %i\|- a
+--R     + 
+--R       -
+--R             +-----------------+ +---------------+ +-------------+
+--R             |  4+-+     4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R            \|- \|b  + %i\|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R         *
+--R                         8+-+
+--R                        x\|b
+--R            atan(------------------)
+--R                  +---------------+
+--R                  |  4+-+   4+---+
+--R                 \|- \|b  + \|- a
+--R  /
+--R                    +-----------------+ +---------------+ +---------------+
+--R         +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R       4\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R    *
+--R        +-------------+
+--R        |4+-+   4+---+
+--R       \|\|b  + \|- a
+--R                                           Type: Expression(Complex(Integer))
+--E 1542
+
+--S 1543 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R                              2
+--R                  (16a b + 16a )
+--R               *
+--R                  ROOT
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                       + 
+--R                                     2 3        3 2        4               2
+--R                             (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                           + 
+--R                                  2
+--R                             - 64a b
+--R                        *
+--R                           %%HR1
+--R                       + 
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                       + 
+--R                                 2      2
+--R                         (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                    /
+--R                           2 3        3 2       4
+--R                       512a b  + 1024a b  + 512a b
+--R              + 
+--R                              2                       2
+--R                (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R           /
+--R                       2
+--R              8a b + 8a
+--R      *
+--R         log
+--R                                     3 4           4 3               2 3
+--R                            (1572864a b  + 1572864a b )%%HR0 + 16384a b
+--R                          + 
+--R                                  3 2
+--R                            16384a b
+--R                     *
+--R                        %%HR1
+--R                    + 
+--R                             2 3         3 2               2       2
+--R                      (16384a b  + 16384a b )%%HR0 + 128a b  + 128a b
+--R                 *
+--R                    ROOT
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                         + 
+--R                                       2 3        3 2        4               2
+--R                               (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                             + 
+--R                                    2
+--R                               - 64a b
+--R                          *
+--R                             %%HR1
+--R                         + 
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                         + 
+--R                                   2      2
+--R                           (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                      /
+--R                             2 3        3 2       4
+--R                         512a b  + 1024a b  + 512a b
+--R                + 
+--R                              3 4           4 3               2 3         3 2
+--R                    ((1572864a b  + 1572864a b )%%HR0 + 16384a b  + 16384a b )
+--R                 *
+--R                         2
+--R                    %%HR1
+--R                + 
+--R                               3 4           4 3      2         2 3
+--R                      (1572864a b  + 1572864a b )%%HR0  + 98304a b %%HR0
+--R                    + 
+--R                            2       2
+--R                      896a b  - 128a b
+--R                 *
+--R                    %%HR1
+--R                + 
+--R                         2 3         3 2      2          2       2
+--R                  (16384a b  + 16384a b )%%HR0  + (896a b  - 128a b)%%HR0 + 8b
+--R             *
+--R                ROOT
+--R                                     2
+--R                         (16a b + 16a )
+--R                      *
+--R                         ROOT
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                              + 
+--R                                            2 3        3 2        4
+--R                                    (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                  + 
+--R                                           2      2
+--R                                    - 64a b  - 64a b
+--R                               *
+--R                                  %%HR1
+--R                              + 
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                              + 
+--R                                        2      2
+--R                                (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                           /
+--R                                  2 3        3 2       4
+--R                              512a b  + 1024a b  + 512a b
+--R                     + 
+--R                                     2                       2
+--R                       (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R                  /
+--R                              2
+--R                     8a b + 8a
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                                   2
+--R                     (- 16a b - 16a )
+--R                  *
+--R                     ROOT
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                          + 
+--R                                        2 3        3 2        4               2
+--R                                (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                              + 
+--R                                     2
+--R                                - 64a b
+--R                           *
+--R                              %%HR1
+--R                          + 
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                          + 
+--R                                    2      2
+--R                            (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                       /
+--R                              2 3        3 2       4
+--R                          512a b  + 1024a b  + 512a b
+--R                 + 
+--R                                 2                       2
+--R                   (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R              /
+--R                          2
+--R                 8a b + 8a
+--R         *
+--R            log
+--R                                      3 4           4 3               2 3
+--R                             (1572864a b  + 1572864a b )%%HR0 + 16384a b
+--R                           + 
+--R                                   3 2
+--R                             16384a b
+--R                        *
+--R                           %%HR1
+--R                       + 
+--R                                2 3         3 2               2       2
+--R                         (16384a b  + 16384a b )%%HR0 + 128a b  + 128a b
+--R                    *
+--R                       ROOT
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                            + 
+--R                                          2 3        3 2        4
+--R                                  (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                + 
+--R                                         2      2
+--R                                  - 64a b  - 64a b
+--R                             *
+--R                                %%HR1
+--R                            + 
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                            + 
+--R                                      2      2
+--R                              (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                         /
+--R                                2 3        3 2       4
+--R                            512a b  + 1024a b  + 512a b
+--R                   + 
+--R                                    3 4           4 3               2 3
+--R                         (- 1572864a b  - 1572864a b )%%HR0 - 16384a b
+--R                       + 
+--R                                 3 2
+--R                         - 16384a b
+--R                    *
+--R                            2
+--R                       %%HR1
+--R                   + 
+--R                                    3 4           4 3      2         2 3
+--R                         (- 1572864a b  - 1572864a b )%%HR0  - 98304a b %%HR0
+--R                       + 
+--R                                 2       2
+--R                         - 896a b  + 128a b
+--R                    *
+--R                       %%HR1
+--R                   + 
+--R                              2 3         3 2      2            2       2
+--R                     (- 16384a b  - 16384a b )%%HR0  + (- 896a b  + 128a b)%%HR0
+--R                   + 
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                          2
+--R                            (- 16a b - 16a )
+--R                         *
+--R                            ROOT
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                                 + 
+--R                                               2 3        3 2        4
+--R                                       (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                     + 
+--R                                              2      2
+--R                                       - 64a b  - 64a b
+--R                                  *
+--R                                     %%HR1
+--R                                 + 
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                                 + 
+--R                                           2      2
+--R                                   (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                              /
+--R                                     2 3        3 2       4
+--R                                 512a b  + 1024a b  + 512a b
+--R                        + 
+--R                                        2                       2
+--R                          (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R                     /
+--R                                 2
+--R                        8a b + 8a
+--R               + 
+--R                 x
+--R     + 
+--R         ROOT
+--R                                2
+--R                  (- 16a b - 16a )
+--R               *
+--R                  ROOT
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                       + 
+--R                                     2 3        3 2        4               2
+--R                             (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                           + 
+--R                                  2
+--R                             - 64a b
+--R                        *
+--R                           %%HR1
+--R                       + 
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                       + 
+--R                                 2      2
+--R                         (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                    /
+--R                           2 3        3 2       4
+--R                       512a b  + 1024a b  + 512a b
+--R              + 
+--R                              2                       2
+--R                (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R           /
+--R                       2
+--R              8a b + 8a
+--R      *
+--R         log
+--R                                     3 4           4 3               2 3
+--R                          (- 1572864a b  - 1572864a b )%%HR0 - 16384a b
+--R                        + 
+--R                                  3 2
+--R                          - 16384a b
+--R                     *
+--R                        %%HR1
+--R                    + 
+--R                               2 3         3 2               2       2
+--R                      (- 16384a b  - 16384a b )%%HR0 - 128a b  - 128a b
+--R                 *
+--R                    ROOT
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                         + 
+--R                                       2 3        3 2        4               2
+--R                               (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                             + 
+--R                                    2
+--R                               - 64a b
+--R                          *
+--R                             %%HR1
+--R                         + 
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                         + 
+--R                                   2      2
+--R                           (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                      /
+--R                             2 3        3 2       4
+--R                         512a b  + 1024a b  + 512a b
+--R                + 
+--R                              3 4           4 3               2 3         3 2
+--R                    ((1572864a b  + 1572864a b )%%HR0 + 16384a b  + 16384a b )
+--R                 *
+--R                         2
+--R                    %%HR1
+--R                + 
+--R                               3 4           4 3      2         2 3
+--R                      (1572864a b  + 1572864a b )%%HR0  + 98304a b %%HR0
+--R                    + 
+--R                            2       2
+--R                      896a b  - 128a b
+--R                 *
+--R                    %%HR1
+--R                + 
+--R                         2 3         3 2      2          2       2
+--R                  (16384a b  + 16384a b )%%HR0  + (896a b  - 128a b)%%HR0 + 8b
+--R             *
+--R                ROOT
+--R                                       2
+--R                         (- 16a b - 16a )
+--R                      *
+--R                         ROOT
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                              + 
+--R                                            2 3        3 2        4
+--R                                    (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                  + 
+--R                                           2      2
+--R                                    - 64a b  - 64a b
+--R                               *
+--R                                  %%HR1
+--R                              + 
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                              + 
+--R                                        2      2
+--R                                (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                           /
+--R                                  2 3        3 2       4
+--R                              512a b  + 1024a b  + 512a b
+--R                     + 
+--R                                     2                       2
+--R                       (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R                  /
+--R                              2
+--R                     8a b + 8a
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                                 2
+--R                     (16a b + 16a )
+--R                  *
+--R                     ROOT
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                          + 
+--R                                        2 3        3 2        4               2
+--R                                (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                              + 
+--R                                     2
+--R                                - 64a b
+--R                           *
+--R                              %%HR1
+--R                          + 
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                          + 
+--R                                    2      2
+--R                            (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                       /
+--R                              2 3        3 2       4
+--R                          512a b  + 1024a b  + 512a b
+--R                 + 
+--R                                 2                       2
+--R                   (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R              /
+--R                          2
+--R                 8a b + 8a
+--R         *
+--R            log
+--R                                        3 4           4 3               2 3
+--R                             (- 1572864a b  - 1572864a b )%%HR0 - 16384a b
+--R                           + 
+--R                                     3 2
+--R                             - 16384a b
+--R                        *
+--R                           %%HR1
+--R                       + 
+--R                                  2 3         3 2               2       2
+--R                         (- 16384a b  - 16384a b )%%HR0 - 128a b  - 128a b
+--R                    *
+--R                       ROOT
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                            + 
+--R                                          2 3        3 2        4
+--R                                  (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                + 
+--R                                         2      2
+--R                                  - 64a b  - 64a b
+--R                             *
+--R                                %%HR1
+--R                            + 
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                            + 
+--R                                      2      2
+--R                              (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                         /
+--R                                2 3        3 2       4
+--R                            512a b  + 1024a b  + 512a b
+--R                   + 
+--R                                    3 4           4 3               2 3
+--R                         (- 1572864a b  - 1572864a b )%%HR0 - 16384a b
+--R                       + 
+--R                                 3 2
+--R                         - 16384a b
+--R                    *
+--R                            2
+--R                       %%HR1
+--R                   + 
+--R                                    3 4           4 3      2         2 3
+--R                         (- 1572864a b  - 1572864a b )%%HR0  - 98304a b %%HR0
+--R                       + 
+--R                                 2       2
+--R                         - 896a b  + 128a b
+--R                    *
+--R                       %%HR1
+--R                   + 
+--R                              2 3         3 2      2            2       2
+--R                     (- 16384a b  - 16384a b )%%HR0  + (- 896a b  + 128a b)%%HR0
+--R                   + 
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                        2
+--R                            (16a b + 16a )
+--R                         *
+--R                            ROOT
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                                 + 
+--R                                               2 3        3 2        4
+--R                                       (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                     + 
+--R                                              2      2
+--R                                       - 64a b  - 64a b
+--R                                  *
+--R                                     %%HR1
+--R                                 + 
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                                 + 
+--R                                           2      2
+--R                                   (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                              /
+--R                                     2 3        3 2       4
+--R                                 512a b  + 1024a b  + 512a b
+--R                        + 
+--R                                        2                       2
+--R                          (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R                     /
+--R                                 2
+--R                        8a b + 8a
+--R               + 
+--R                 x
+--R     + 
+--R       -
+--R             +------+
+--R            \|4%%HR1
+--R         *
+--R            log
+--R                                    3 4           4 3               2 3
+--R                           (3145728a b  + 3145728a b )%%HR0 + 32768a b
+--R                         + 
+--R                                 3 2
+--R                           32768a b
+--R                    *
+--R                            2
+--R                       %%HR1
+--R                   + 
+--R                                  3 4           4 3      2          2 3
+--R                         (3145728a b  + 3145728a b )%%HR0  + 196608a b %%HR0
+--R                       + 
+--R                                2       2
+--R                         1792a b  - 256a b
+--R                    *
+--R                       %%HR1
+--R                   + 
+--R                              3 4           4 3      3          2 3     2
+--R                     (3145728a b  + 3145728a b )%%HR0  + 196608a b %%HR0
+--R                   + 
+--R                            2
+--R                     4608a b %%HR0 + 32b
+--R                *
+--R                    +------+
+--R                   \|4%%HR1
+--R               + 
+--R                 x
+--R     + 
+--R          +------+
+--R         \|4%%HR1
+--R      *
+--R         log
+--R                                3 4           4 3               2 3         3 2
+--R                    ((- 3145728a b  - 3145728a b )%%HR0 - 32768a b  - 32768a b )
+--R                 *
+--R                         2
+--R                    %%HR1
+--R                + 
+--R                                 3 4           4 3      2          2 3
+--R                      (- 3145728a b  - 3145728a b )%%HR0  - 196608a b %%HR0
+--R                    + 
+--R                               2       2
+--R                      - 1792a b  + 256a b
+--R                 *
+--R                    %%HR1
+--R                + 
+--R                             3 4           4 3      3          2 3     2
+--R                  (- 3145728a b  - 3145728a b )%%HR0  - 196608a b %%HR0
+--R                + 
+--R                           2
+--R                  - 4608a b %%HR0 - 32b
+--R             *
+--R                 +------+
+--R                \|4%%HR1
+--R            + 
+--R              x
+--R     + 
+--R          +------+
+--R         \|4%%HR0
+--R      *
+--R         log
+--R                           3 4           4 3      3
+--R                  (3145728a b  + 3145728a b )%%HR0
+--R                + 
+--R                        2 3         3 2      2           2       2
+--R                (163840a b  - 32768a b )%%HR0  + (2816a b  + 256a b)%%HR0 + 16b
+--R             *
+--R                 +------+
+--R                \|4%%HR0
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +------+
+--R            \|4%%HR0
+--R         *
+--R            log
+--R                                3 4           4 3      3
+--R                     (- 3145728a b  - 3145728a b )%%HR0
+--R                   + 
+--R                               2 3         3 2      2
+--R                     (- 163840a b  + 32768a b )%%HR0
+--R                   + 
+--R                               2       2
+--R                     (- 2816a b  - 256a b)%%HR0 - 16b
+--R                *
+--R                    +------+
+--R                   \|4%%HR0
+--R               + 
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1543
+
+--S 1544 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +-----------------+ +---------------+ +---------------+
+--R           +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R          +-------------+
+--R          |4+-+   4+---+
+--R         \|\|b  + \|- a
+--R      *
+--R         ROOT
+--R                              2
+--R                  (16a b + 16a )
+--R               *
+--R                  ROOT
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                       + 
+--R                                     2 3        3 2        4               2
+--R                             (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                           + 
+--R                                  2
+--R                             - 64a b
+--R                        *
+--R                           %%HR1
+--R                       + 
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                       + 
+--R                                 2      2
+--R                         (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                    /
+--R                           2 3        3 2       4
+--R                       512a b  + 1024a b  + 512a b
+--R              + 
+--R                              2                       2
+--R                (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R           /
+--R                       2
+--R              8a b + 8a
+--R      *
+--R         log
+--R                                     3 4           4 3               2 3
+--R                            (1572864a b  + 1572864a b )%%HR0 + 16384a b
+--R                          + 
+--R                                  3 2
+--R                            16384a b
+--R                     *
+--R                        %%HR1
+--R                    + 
+--R                             2 3         3 2               2       2
+--R                      (16384a b  + 16384a b )%%HR0 + 128a b  + 128a b
+--R                 *
+--R                    ROOT
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                         + 
+--R                                       2 3        3 2        4               2
+--R                               (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                             + 
+--R                                    2
+--R                               - 64a b
+--R                          *
+--R                             %%HR1
+--R                         + 
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                         + 
+--R                                   2      2
+--R                           (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                      /
+--R                             2 3        3 2       4
+--R                         512a b  + 1024a b  + 512a b
+--R                + 
+--R                              3 4           4 3               2 3         3 2
+--R                    ((1572864a b  + 1572864a b )%%HR0 + 16384a b  + 16384a b )
+--R                 *
+--R                         2
+--R                    %%HR1
+--R                + 
+--R                               3 4           4 3      2         2 3
+--R                      (1572864a b  + 1572864a b )%%HR0  + 98304a b %%HR0
+--R                    + 
+--R                            2       2
+--R                      896a b  - 128a b
+--R                 *
+--R                    %%HR1
+--R                + 
+--R                         2 3         3 2      2          2       2
+--R                  (16384a b  + 16384a b )%%HR0  + (896a b  - 128a b)%%HR0 + 8b
+--R             *
+--R                ROOT
+--R                                     2
+--R                         (16a b + 16a )
+--R                      *
+--R                         ROOT
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                              + 
+--R                                            2 3        3 2        4
+--R                                    (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                  + 
+--R                                           2      2
+--R                                    - 64a b  - 64a b
+--R                               *
+--R                                  %%HR1
+--R                              + 
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                              + 
+--R                                        2      2
+--R                                (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                           /
+--R                                  2 3        3 2       4
+--R                              512a b  + 1024a b  + 512a b
+--R                     + 
+--R                                     2                       2
+--R                       (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R                  /
+--R                              2
+--R                     8a b + 8a
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                         +-----------------+ +---------------+ +---------------+
+--R              +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R            2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R         *
+--R             +-------------+
+--R             |4+-+   4+---+
+--R            \|\|b  + \|- a
+--R         *
+--R            ROOT
+--R                                   2
+--R                     (- 16a b - 16a )
+--R                  *
+--R                     ROOT
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                          + 
+--R                                        2 3        3 2        4               2
+--R                                (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                              + 
+--R                                     2
+--R                                - 64a b
+--R                           *
+--R                              %%HR1
+--R                          + 
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                          + 
+--R                                    2      2
+--R                            (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                       /
+--R                              2 3        3 2       4
+--R                          512a b  + 1024a b  + 512a b
+--R                 + 
+--R                                 2                       2
+--R                   (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R              /
+--R                          2
+--R                 8a b + 8a
+--R         *
+--R            log
+--R                                      3 4           4 3               2 3
+--R                             (1572864a b  + 1572864a b )%%HR0 + 16384a b
+--R                           + 
+--R                                   3 2
+--R                             16384a b
+--R                        *
+--R                           %%HR1
+--R                       + 
+--R                                2 3         3 2               2       2
+--R                         (16384a b  + 16384a b )%%HR0 + 128a b  + 128a b
+--R                    *
+--R                       ROOT
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                            + 
+--R                                          2 3        3 2        4
+--R                                  (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                + 
+--R                                         2      2
+--R                                  - 64a b  - 64a b
+--R                             *
+--R                                %%HR1
+--R                            + 
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                            + 
+--R                                      2      2
+--R                              (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                         /
+--R                                2 3        3 2       4
+--R                            512a b  + 1024a b  + 512a b
+--R                   + 
+--R                                    3 4           4 3               2 3
+--R                         (- 1572864a b  - 1572864a b )%%HR0 - 16384a b
+--R                       + 
+--R                                 3 2
+--R                         - 16384a b
+--R                    *
+--R                            2
+--R                       %%HR1
+--R                   + 
+--R                                    3 4           4 3      2         2 3
+--R                         (- 1572864a b  - 1572864a b )%%HR0  - 98304a b %%HR0
+--R                       + 
+--R                                 2       2
+--R                         - 896a b  + 128a b
+--R                    *
+--R                       %%HR1
+--R                   + 
+--R                              2 3         3 2      2            2       2
+--R                     (- 16384a b  - 16384a b )%%HR0  + (- 896a b  + 128a b)%%HR0
+--R                   + 
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                          2
+--R                            (- 16a b - 16a )
+--R                         *
+--R                            ROOT
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                                 + 
+--R                                               2 3        3 2        4
+--R                                       (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                     + 
+--R                                              2      2
+--R                                       - 64a b  - 64a b
+--R                                  *
+--R                                     %%HR1
+--R                                 + 
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                                 + 
+--R                                           2      2
+--R                                   (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                              /
+--R                                     2 3        3 2       4
+--R                                 512a b  + 1024a b  + 512a b
+--R                        + 
+--R                                        2                       2
+--R                          (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R                     /
+--R                                 2
+--R                        8a b + 8a
+--R               + 
+--R                 x
+--R     + 
+--R                      +-----------------+ +---------------+ +---------------+
+--R           +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R          +-------------+
+--R          |4+-+   4+---+
+--R         \|\|b  + \|- a
+--R      *
+--R         ROOT
+--R                                2
+--R                  (- 16a b - 16a )
+--R               *
+--R                  ROOT
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                       + 
+--R                                     2 3        3 2        4               2
+--R                             (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                           + 
+--R                                  2
+--R                             - 64a b
+--R                        *
+--R                           %%HR1
+--R                       + 
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                       + 
+--R                                 2      2
+--R                         (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                    /
+--R                           2 3        3 2       4
+--R                       512a b  + 1024a b  + 512a b
+--R              + 
+--R                              2                       2
+--R                (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R           /
+--R                       2
+--R              8a b + 8a
+--R      *
+--R         log
+--R                                     3 4           4 3               2 3
+--R                          (- 1572864a b  - 1572864a b )%%HR0 - 16384a b
+--R                        + 
+--R                                  3 2
+--R                          - 16384a b
+--R                     *
+--R                        %%HR1
+--R                    + 
+--R                               2 3         3 2               2       2
+--R                      (- 16384a b  - 16384a b )%%HR0 - 128a b  - 128a b
+--R                 *
+--R                    ROOT
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                         + 
+--R                                       2 3        3 2        4               2
+--R                               (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                             + 
+--R                                    2
+--R                               - 64a b
+--R                          *
+--R                             %%HR1
+--R                         + 
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                         + 
+--R                                   2      2
+--R                           (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                      /
+--R                             2 3        3 2       4
+--R                         512a b  + 1024a b  + 512a b
+--R                + 
+--R                              3 4           4 3               2 3         3 2
+--R                    ((1572864a b  + 1572864a b )%%HR0 + 16384a b  + 16384a b )
+--R                 *
+--R                         2
+--R                    %%HR1
+--R                + 
+--R                               3 4           4 3      2         2 3
+--R                      (1572864a b  + 1572864a b )%%HR0  + 98304a b %%HR0
+--R                    + 
+--R                            2       2
+--R                      896a b  - 128a b
+--R                 *
+--R                    %%HR1
+--R                + 
+--R                         2 3         3 2      2          2       2
+--R                  (16384a b  + 16384a b )%%HR0  + (896a b  - 128a b)%%HR0 + 8b
+--R             *
+--R                ROOT
+--R                                       2
+--R                         (- 16a b - 16a )
+--R                      *
+--R                         ROOT
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                              + 
+--R                                            2 3        3 2        4
+--R                                    (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                  + 
+--R                                           2      2
+--R                                    - 64a b  - 64a b
+--R                               *
+--R                                  %%HR1
+--R                              + 
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                              + 
+--R                                        2      2
+--R                                (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                           /
+--R                                  2 3        3 2       4
+--R                              512a b  + 1024a b  + 512a b
+--R                     + 
+--R                                     2                       2
+--R                       (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R                  /
+--R                              2
+--R                     8a b + 8a
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                         +-----------------+ +---------------+ +---------------+
+--R              +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R            2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R         *
+--R             +-------------+
+--R             |4+-+   4+---+
+--R            \|\|b  + \|- a
+--R         *
+--R            ROOT
+--R                                 2
+--R                     (16a b + 16a )
+--R                  *
+--R                     ROOT
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                          + 
+--R                                        2 3        3 2        4               2
+--R                                (- 1024a b  - 2048a b  - 1024a b)%%HR0 - 64a b
+--R                              + 
+--R                                     2
+--R                                - 64a b
+--R                           *
+--R                              %%HR1
+--R                          + 
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                          + 
+--R                                    2      2
+--R                            (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                       /
+--R                              2 3        3 2       4
+--R                          512a b  + 1024a b  + 512a b
+--R                 + 
+--R                                 2                       2
+--R                   (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R              /
+--R                          2
+--R                 8a b + 8a
+--R         *
+--R            log
+--R                                        3 4           4 3               2 3
+--R                             (- 1572864a b  - 1572864a b )%%HR0 - 16384a b
+--R                           + 
+--R                                     3 2
+--R                             - 16384a b
+--R                        *
+--R                           %%HR1
+--R                       + 
+--R                                  2 3         3 2               2       2
+--R                         (- 16384a b  - 16384a b )%%HR0 - 128a b  - 128a b
+--R                    *
+--R                       ROOT
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                            + 
+--R                                          2 3        3 2        4
+--R                                  (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                + 
+--R                                         2      2
+--R                                  - 64a b  - 64a b
+--R                             *
+--R                                %%HR1
+--R                            + 
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                            + 
+--R                                      2      2
+--R                              (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                         /
+--R                                2 3        3 2       4
+--R                            512a b  + 1024a b  + 512a b
+--R                   + 
+--R                                    3 4           4 3               2 3
+--R                         (- 1572864a b  - 1572864a b )%%HR0 - 16384a b
+--R                       + 
+--R                                 3 2
+--R                         - 16384a b
+--R                    *
+--R                            2
+--R                       %%HR1
+--R                   + 
+--R                                    3 4           4 3      2         2 3
+--R                         (- 1572864a b  - 1572864a b )%%HR0  - 98304a b %%HR0
+--R                       + 
+--R                                 2       2
+--R                         - 896a b  + 128a b
+--R                    *
+--R                       %%HR1
+--R                   + 
+--R                              2 3         3 2      2            2       2
+--R                     (- 16384a b  - 16384a b )%%HR0  + (- 896a b  + 128a b)%%HR0
+--R                   + 
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                        2
+--R                            (16a b + 16a )
+--R                         *
+--R                            ROOT
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HR1
+--R                                 + 
+--R                                               2 3        3 2        4
+--R                                       (- 1024a b  - 2048a b  - 1024a b)%%HR0
+--R                                     + 
+--R                                              2      2
+--R                                       - 64a b  - 64a b
+--R                                  *
+--R                                     %%HR1
+--R                                 + 
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HR0
+--R                                 + 
+--R                                           2      2
+--R                                   (- 64a b  - 64a b)%%HR0 - b - 3a
+--R                              /
+--R                                     2 3        3 2       4
+--R                                 512a b  + 1024a b  + 512a b
+--R                        + 
+--R                                        2                       2
+--R                          (- 16a b - 16a )%%HR1 + (- 16a b - 16a )%%HR0 - 1
+--R                     /
+--R                                 2
+--R                        8a b + 8a
+--R               + 
+--R                 x
+--R     + 
+--R       -
+--R                         +-----------------+ +---------------+ +---------------+
+--R              +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R            2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R         *
+--R             +-------------+
+--R             |4+-+   4+---+  +------+
+--R            \|\|b  + \|- a  \|4%%HR1
+--R         *
+--R            log
+--R                                    3 4           4 3               2 3
+--R                           (3145728a b  + 3145728a b )%%HR0 + 32768a b
+--R                         + 
+--R                                 3 2
+--R                           32768a b
+--R                    *
+--R                            2
+--R                       %%HR1
+--R                   + 
+--R                                  3 4           4 3      2          2 3
+--R                         (3145728a b  + 3145728a b )%%HR0  + 196608a b %%HR0
+--R                       + 
+--R                                2       2
+--R                         1792a b  - 256a b
+--R                    *
+--R                       %%HR1
+--R                   + 
+--R                              3 4           4 3      3          2 3     2
+--R                     (3145728a b  + 3145728a b )%%HR0  + 196608a b %%HR0
+--R                   + 
+--R                            2
+--R                     4608a b %%HR0 + 32b
+--R                *
+--R                    +------+
+--R                   \|4%%HR1
+--R               + 
+--R                 x
+--R     + 
+--R                      +-----------------+ +---------------+ +---------------+
+--R           +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R          +-------------+
+--R          |4+-+   4+---+  +------+
+--R         \|\|b  + \|- a  \|4%%HR1
+--R      *
+--R         log
+--R                                3 4           4 3               2 3         3 2
+--R                    ((- 3145728a b  - 3145728a b )%%HR0 - 32768a b  - 32768a b )
+--R                 *
+--R                         2
+--R                    %%HR1
+--R                + 
+--R                                 3 4           4 3      2          2 3
+--R                      (- 3145728a b  - 3145728a b )%%HR0  - 196608a b %%HR0
+--R                    + 
+--R                               2       2
+--R                      - 1792a b  + 256a b
+--R                 *
+--R                    %%HR1
+--R                + 
+--R                             3 4           4 3      3          2 3     2
+--R                  (- 3145728a b  - 3145728a b )%%HR0  - 196608a b %%HR0
+--R                + 
+--R                           2
+--R                  - 4608a b %%HR0 - 32b
+--R             *
+--R                 +------+
+--R                \|4%%HR1
+--R            + 
+--R              x
+--R     + 
+--R                      +-----------------+ +---------------+ +---------------+
+--R           +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R          +-------------+
+--R          |4+-+   4+---+  +------+
+--R         \|\|b  + \|- a  \|4%%HR0
+--R      *
+--R         log
+--R                           3 4           4 3      3
+--R                  (3145728a b  + 3145728a b )%%HR0
+--R                + 
+--R                        2 3         3 2      2           2       2
+--R                (163840a b  - 32768a b )%%HR0  + (2816a b  + 256a b)%%HR0 + 16b
+--R             *
+--R                 +------+
+--R                \|4%%HR0
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                         +-----------------+ +---------------+ +---------------+
+--R              +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R            2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R         *
+--R             +-------------+
+--R             |4+-+   4+---+  +------+
+--R            \|\|b  + \|- a  \|4%%HR0
+--R         *
+--R            log
+--R                                3 4           4 3      3
+--R                     (- 3145728a b  - 3145728a b )%%HR0
+--R                   + 
+--R                               2 3         3 2      2
+--R                     (- 163840a b  + 32768a b )%%HR0
+--R                   + 
+--R                               2       2
+--R                     (- 2816a b  - 256a b)%%HR0 - 16b
+--R                *
+--R                    +------+
+--R                   \|4%%HR0
+--R               + 
+--R                 x
+--R     + 
+--R          +-----------------+ +---------------+ +-------------+
+--R          |  4+-+     4+---+  |  4+-+   4+---+  |4+-+   4+---+
+--R         \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + \|- a
+--R      *
+--R                       8+-+
+--R                      x\|b
+--R         atanh(------------------)
+--R                +---------------+
+--R                |4+-+     4+---+
+--R               \|\|b  + %i\|- a
+--R     + 
+--R       -
+--R             +-----------------+ +---------------+ +---------------+
+--R             |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R            \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R         *
+--R                         8+-+
+--R                        x\|b
+--R            atanh(----------------)
+--R                   +-------------+
+--R                   |4+-+   4+---+
+--R                  \|\|b  + \|- a
+--R     + 
+--R       -
+--R             +---------------+ +---------------+ +-------------+
+--R             |  4+-+   4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R            \|- \|b  + \|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R         *
+--R                          8+-+
+--R                         x\|b
+--R            atan(--------------------)
+--R                  +-----------------+
+--R                  |  4+-+     4+---+
+--R                 \|- \|b  + %i\|- a
+--R     + 
+--R          +-----------------+ +---------------+ +-------------+
+--R          |  4+-+     4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R         \|- \|b  + %i\|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R      *
+--R                      8+-+
+--R                     x\|b
+--R         atan(------------------)
+--R               +---------------+
+--R               |  4+-+   4+---+
+--R              \|- \|b  + \|- a
+--R  /
+--R                    +-----------------+ +---------------+ +---------------+
+--R         +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R       4\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R    *
+--R        +-------------+
+--R        |4+-+   4+---+
+--R       \|\|b  + \|- a
+--R                                           Type: Expression(Complex(Integer))
+--E 1544
+
+--S 1545 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 10       8       6       4             2  +---+4+---+2
+--R           (- b x   + 4b x  - 6b x  + 4b x  + (- b - a)x )\|- a \|- a
+--R         + 
+--R                  10        8             2  2          2
+--R           - a b x   + a b x  + (- a b - a )x  + a b + a
+--R      *
+--R         8+-+6
+--R         \|b
+--R     + 
+--R                 8       6       4       2          +---+4+---+2         8
+--R             (b x  - 4b x  + 6b x  - 4b x  + b + a)\|- a \|- a   + 4a b x
+--R           + 
+--R                     6
+--R             - 4a b x
+--R      *
+--R         4+-+8+-+4
+--R         \|b \|b
+--R     + 
+--R                6         4 4+-+2 8+-+2         4         2 4+-+3
+--R       (- 6a b x  + 6a b x )\|b   \|b  + (4a b x  - 4a b x )\|b
+--R  /
+--R              2 16       2 14       2 12       2 10        2     2   8
+--R           a b x   - 4a b x   + 6a b x   - 4a b x   + (2a b  + 2a b)x
+--R         + 
+--R                  2     2   6        2     2   4          2     2   2      2
+--R           (- 4a b  - 4a b)x  + (6a b  + 6a b)x  + (- 4a b  - 4a b)x  + a b
+--R         + 
+--R             2     3
+--R           2a b + a
+--R      *
+--R         8+-+6
+--R         \|b
+--R     + 
+--R                2 14        2 12        2 10        2 8          2     2   6
+--R         (- 4a b x   + 16a b x   - 24a b x   + 16a b x  + (- 4a b  - 4a b)x )
+--R      *
+--R         4+-+8+-+4
+--R         \|b \|b
+--R     + 
+--R            2 12        2 10        2 8        2 6        2     2   4 4+-+2 8+-+2
+--R       (6a b x   - 24a b x   + 36a b x  - 24a b x  + (6a b  + 6a b)x )\|b   \|b
+--R     + 
+--R              2 10        2 8        2 6        2 4          2     2   2 4+-+3
+--R       (- 4a b x   + 16a b x  - 24a b x  + 16a b x  + (- 4a b  - 4a b)x )\|b
+--R                                           Type: Expression(Complex(Integer))
+--E 1545
+
+)clear all
+
+--S 1546 of 1580
+t0:=(1-x^2)/(a+b*(-1+x^2)^4)
+--R 
+--R
+--R                         2
+--R                      - x  + 1
+--R   (1)  ------------------------------------
+--R           8       6       4       2
+--R        b x  - 4b x  + 6b x  - 4b x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1546
+
+--S 1547 of 1580
+r0:=1/4*atan(b^(1/8)*x/sqrt(%i*(-a)^(1/4)-b^(1/4)))/(b^(3/8)*sqrt(-a)*_
+   sqrt(%i*(-a)^(1/4)-b^(1/4)))-1/4*atan(b^(1/8)*x/sqrt((-a)^(1/4)-_
+   b^(1/4)))/(b^(3/8)*sqrt(-a)*sqrt((-a)^(1/4)-b^(1/4)))-_
+   1/4*atanh(b^(1/8)*x/sqrt(%i*(-a)^(1/4)+b^(1/4)))/(b^(3/8)*sqrt(-a)*_
+   sqrt(%i*(-a)^(1/4)+b^(1/4)))+1/4*atanh(b^(1/8)*x/sqrt((-a)^(1/4)+_
+   b^(1/4)))/(b^(3/8)*sqrt(-a)*sqrt((-a)^(1/4)+b^(1/4)))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +-----------------+ +---------------+ +-------------+
+--R             |  4+-+     4+---+  |  4+-+   4+---+  |4+-+   4+---+
+--R            \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + \|- a
+--R         *
+--R                          8+-+
+--R                         x\|b
+--R            atanh(------------------)
+--R                   +---------------+
+--R                   |4+-+     4+---+
+--R                  \|\|b  + %i\|- a
+--R     + 
+--R          +-----------------+ +---------------+ +---------------+
+--R          |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R                      8+-+
+--R                     x\|b
+--R         atanh(----------------)
+--R                +-------------+
+--R                |4+-+   4+---+
+--R               \|\|b  + \|- a
+--R     + 
+--R          +---------------+ +---------------+ +-------------+
+--R          |  4+-+   4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R         \|- \|b  + \|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R      *
+--R                       8+-+
+--R                      x\|b
+--R         atan(--------------------)
+--R               +-----------------+
+--R               |  4+-+     4+---+
+--R              \|- \|b  + %i\|- a
+--R     + 
+--R       -
+--R             +-----------------+ +---------------+ +-------------+
+--R             |  4+-+     4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R            \|- \|b  + %i\|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R         *
+--R                         8+-+
+--R                        x\|b
+--R            atan(------------------)
+--R                  +---------------+
+--R                  |  4+-+   4+---+
+--R                 \|- \|b  + \|- a
+--R  /
+--R                    +-----------------+ +---------------+ +---------------+
+--R         +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R       4\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R    *
+--R        +-------------+
+--R        |4+-+   4+---+
+--R       \|\|b  + \|- a
+--R                                           Type: Expression(Complex(Integer))
+--E 1547
+
+--S 1548 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         ROOT
+--R                              2
+--R                  (16a b + 16a )
+--R               *
+--R                  ROOT
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                       + 
+--R                                     2 3        3 2        4               2
+--R                             (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                           + 
+--R                                  2
+--R                             - 64a b
+--R                        *
+--R                           %%HS1
+--R                       + 
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                       + 
+--R                                 2      2
+--R                         (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                    /
+--R                           2 3        3 2       4
+--R                       512a b  + 1024a b  + 512a b
+--R              + 
+--R                              2                       2
+--R                (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R           /
+--R                       2
+--R              8a b + 8a
+--R      *
+--R         log
+--R                                     3 4           4 3               2 3
+--R                            (1572864a b  + 1572864a b )%%HS0 + 16384a b
+--R                          + 
+--R                                  3 2
+--R                            16384a b
+--R                     *
+--R                        %%HS1
+--R                    + 
+--R                             2 3         3 2               2       2
+--R                      (16384a b  + 16384a b )%%HS0 + 128a b  + 128a b
+--R                 *
+--R                    ROOT
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                         + 
+--R                                       2 3        3 2        4               2
+--R                               (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                             + 
+--R                                    2
+--R                               - 64a b
+--R                          *
+--R                             %%HS1
+--R                         + 
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                         + 
+--R                                   2      2
+--R                           (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                      /
+--R                             2 3        3 2       4
+--R                         512a b  + 1024a b  + 512a b
+--R                + 
+--R                              3 4           4 3               2 3         3 2
+--R                    ((1572864a b  + 1572864a b )%%HS0 + 16384a b  + 16384a b )
+--R                 *
+--R                         2
+--R                    %%HS1
+--R                + 
+--R                               3 4           4 3      2         2 3
+--R                      (1572864a b  + 1572864a b )%%HS0  + 98304a b %%HS0
+--R                    + 
+--R                            2       2
+--R                      896a b  - 128a b
+--R                 *
+--R                    %%HS1
+--R                + 
+--R                         2 3         3 2      2          2       2
+--R                  (16384a b  + 16384a b )%%HS0  + (896a b  - 128a b)%%HS0 + 8b
+--R             *
+--R                ROOT
+--R                                     2
+--R                         (16a b + 16a )
+--R                      *
+--R                         ROOT
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                              + 
+--R                                            2 3        3 2        4
+--R                                    (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                  + 
+--R                                           2      2
+--R                                    - 64a b  - 64a b
+--R                               *
+--R                                  %%HS1
+--R                              + 
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                              + 
+--R                                        2      2
+--R                                (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                           /
+--R                                  2 3        3 2       4
+--R                              512a b  + 1024a b  + 512a b
+--R                     + 
+--R                                     2                       2
+--R                       (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R                  /
+--R                              2
+--R                     8a b + 8a
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                                   2
+--R                     (- 16a b - 16a )
+--R                  *
+--R                     ROOT
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                          + 
+--R                                        2 3        3 2        4               2
+--R                                (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                              + 
+--R                                     2
+--R                                - 64a b
+--R                           *
+--R                              %%HS1
+--R                          + 
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                          + 
+--R                                    2      2
+--R                            (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                       /
+--R                              2 3        3 2       4
+--R                          512a b  + 1024a b  + 512a b
+--R                 + 
+--R                                 2                       2
+--R                   (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R              /
+--R                          2
+--R                 8a b + 8a
+--R         *
+--R            log
+--R                                      3 4           4 3               2 3
+--R                             (1572864a b  + 1572864a b )%%HS0 + 16384a b
+--R                           + 
+--R                                   3 2
+--R                             16384a b
+--R                        *
+--R                           %%HS1
+--R                       + 
+--R                                2 3         3 2               2       2
+--R                         (16384a b  + 16384a b )%%HS0 + 128a b  + 128a b
+--R                    *
+--R                       ROOT
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                            + 
+--R                                          2 3        3 2        4
+--R                                  (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                + 
+--R                                         2      2
+--R                                  - 64a b  - 64a b
+--R                             *
+--R                                %%HS1
+--R                            + 
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                            + 
+--R                                      2      2
+--R                              (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                         /
+--R                                2 3        3 2       4
+--R                            512a b  + 1024a b  + 512a b
+--R                   + 
+--R                                    3 4           4 3               2 3
+--R                         (- 1572864a b  - 1572864a b )%%HS0 - 16384a b
+--R                       + 
+--R                                 3 2
+--R                         - 16384a b
+--R                    *
+--R                            2
+--R                       %%HS1
+--R                   + 
+--R                                    3 4           4 3      2         2 3
+--R                         (- 1572864a b  - 1572864a b )%%HS0  - 98304a b %%HS0
+--R                       + 
+--R                                 2       2
+--R                         - 896a b  + 128a b
+--R                    *
+--R                       %%HS1
+--R                   + 
+--R                              2 3         3 2      2            2       2
+--R                     (- 16384a b  - 16384a b )%%HS0  + (- 896a b  + 128a b)%%HS0
+--R                   + 
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                          2
+--R                            (- 16a b - 16a )
+--R                         *
+--R                            ROOT
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                                 + 
+--R                                               2 3        3 2        4
+--R                                       (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                     + 
+--R                                              2      2
+--R                                       - 64a b  - 64a b
+--R                                  *
+--R                                     %%HS1
+--R                                 + 
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                                 + 
+--R                                           2      2
+--R                                   (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                              /
+--R                                     2 3        3 2       4
+--R                                 512a b  + 1024a b  + 512a b
+--R                        + 
+--R                                        2                       2
+--R                          (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R                     /
+--R                                 2
+--R                        8a b + 8a
+--R               + 
+--R                 x
+--R     + 
+--R         ROOT
+--R                                2
+--R                  (- 16a b - 16a )
+--R               *
+--R                  ROOT
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                       + 
+--R                                     2 3        3 2        4               2
+--R                             (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                           + 
+--R                                  2
+--R                             - 64a b
+--R                        *
+--R                           %%HS1
+--R                       + 
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                       + 
+--R                                 2      2
+--R                         (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                    /
+--R                           2 3        3 2       4
+--R                       512a b  + 1024a b  + 512a b
+--R              + 
+--R                              2                       2
+--R                (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R           /
+--R                       2
+--R              8a b + 8a
+--R      *
+--R         log
+--R                                     3 4           4 3               2 3
+--R                          (- 1572864a b  - 1572864a b )%%HS0 - 16384a b
+--R                        + 
+--R                                  3 2
+--R                          - 16384a b
+--R                     *
+--R                        %%HS1
+--R                    + 
+--R                               2 3         3 2               2       2
+--R                      (- 16384a b  - 16384a b )%%HS0 - 128a b  - 128a b
+--R                 *
+--R                    ROOT
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                         + 
+--R                                       2 3        3 2        4               2
+--R                               (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                             + 
+--R                                    2
+--R                               - 64a b
+--R                          *
+--R                             %%HS1
+--R                         + 
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                         + 
+--R                                   2      2
+--R                           (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                      /
+--R                             2 3        3 2       4
+--R                         512a b  + 1024a b  + 512a b
+--R                + 
+--R                              3 4           4 3               2 3         3 2
+--R                    ((1572864a b  + 1572864a b )%%HS0 + 16384a b  + 16384a b )
+--R                 *
+--R                         2
+--R                    %%HS1
+--R                + 
+--R                               3 4           4 3      2         2 3
+--R                      (1572864a b  + 1572864a b )%%HS0  + 98304a b %%HS0
+--R                    + 
+--R                            2       2
+--R                      896a b  - 128a b
+--R                 *
+--R                    %%HS1
+--R                + 
+--R                         2 3         3 2      2          2       2
+--R                  (16384a b  + 16384a b )%%HS0  + (896a b  - 128a b)%%HS0 + 8b
+--R             *
+--R                ROOT
+--R                                       2
+--R                         (- 16a b - 16a )
+--R                      *
+--R                         ROOT
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                              + 
+--R                                            2 3        3 2        4
+--R                                    (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                  + 
+--R                                           2      2
+--R                                    - 64a b  - 64a b
+--R                               *
+--R                                  %%HS1
+--R                              + 
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                              + 
+--R                                        2      2
+--R                                (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                           /
+--R                                  2 3        3 2       4
+--R                              512a b  + 1024a b  + 512a b
+--R                     + 
+--R                                     2                       2
+--R                       (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R                  /
+--R                              2
+--R                     8a b + 8a
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R            ROOT
+--R                                 2
+--R                     (16a b + 16a )
+--R                  *
+--R                     ROOT
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                          + 
+--R                                        2 3        3 2        4               2
+--R                                (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                              + 
+--R                                     2
+--R                                - 64a b
+--R                           *
+--R                              %%HS1
+--R                          + 
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                          + 
+--R                                    2      2
+--R                            (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                       /
+--R                              2 3        3 2       4
+--R                          512a b  + 1024a b  + 512a b
+--R                 + 
+--R                                 2                       2
+--R                   (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R              /
+--R                          2
+--R                 8a b + 8a
+--R         *
+--R            log
+--R                                        3 4           4 3               2 3
+--R                             (- 1572864a b  - 1572864a b )%%HS0 - 16384a b
+--R                           + 
+--R                                     3 2
+--R                             - 16384a b
+--R                        *
+--R                           %%HS1
+--R                       + 
+--R                                  2 3         3 2               2       2
+--R                         (- 16384a b  - 16384a b )%%HS0 - 128a b  - 128a b
+--R                    *
+--R                       ROOT
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                            + 
+--R                                          2 3        3 2        4
+--R                                  (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                + 
+--R                                         2      2
+--R                                  - 64a b  - 64a b
+--R                             *
+--R                                %%HS1
+--R                            + 
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                            + 
+--R                                      2      2
+--R                              (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                         /
+--R                                2 3        3 2       4
+--R                            512a b  + 1024a b  + 512a b
+--R                   + 
+--R                                    3 4           4 3               2 3
+--R                         (- 1572864a b  - 1572864a b )%%HS0 - 16384a b
+--R                       + 
+--R                                 3 2
+--R                         - 16384a b
+--R                    *
+--R                            2
+--R                       %%HS1
+--R                   + 
+--R                                    3 4           4 3      2         2 3
+--R                         (- 1572864a b  - 1572864a b )%%HS0  - 98304a b %%HS0
+--R                       + 
+--R                                 2       2
+--R                         - 896a b  + 128a b
+--R                    *
+--R                       %%HS1
+--R                   + 
+--R                              2 3         3 2      2            2       2
+--R                     (- 16384a b  - 16384a b )%%HS0  + (- 896a b  + 128a b)%%HS0
+--R                   + 
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                        2
+--R                            (16a b + 16a )
+--R                         *
+--R                            ROOT
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                                 + 
+--R                                               2 3        3 2        4
+--R                                       (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                     + 
+--R                                              2      2
+--R                                       - 64a b  - 64a b
+--R                                  *
+--R                                     %%HS1
+--R                                 + 
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                                 + 
+--R                                           2      2
+--R                                   (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                              /
+--R                                     2 3        3 2       4
+--R                                 512a b  + 1024a b  + 512a b
+--R                        + 
+--R                                        2                       2
+--R                          (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R                     /
+--R                                 2
+--R                        8a b + 8a
+--R               + 
+--R                 x
+--R     + 
+--R       -
+--R             +------+
+--R            \|4%%HS1
+--R         *
+--R            log
+--R                                    3 4           4 3               2 3
+--R                           (3145728a b  + 3145728a b )%%HS0 + 32768a b
+--R                         + 
+--R                                 3 2
+--R                           32768a b
+--R                    *
+--R                            2
+--R                       %%HS1
+--R                   + 
+--R                                  3 4           4 3      2          2 3
+--R                         (3145728a b  + 3145728a b )%%HS0  + 196608a b %%HS0
+--R                       + 
+--R                                2       2
+--R                         1792a b  - 256a b
+--R                    *
+--R                       %%HS1
+--R                   + 
+--R                              3 4           4 3      3          2 3     2
+--R                     (3145728a b  + 3145728a b )%%HS0  + 196608a b %%HS0
+--R                   + 
+--R                            2
+--R                     4608a b %%HS0 + 32b
+--R                *
+--R                    +------+
+--R                   \|4%%HS1
+--R               + 
+--R                 x
+--R     + 
+--R          +------+
+--R         \|4%%HS1
+--R      *
+--R         log
+--R                                3 4           4 3               2 3         3 2
+--R                    ((- 3145728a b  - 3145728a b )%%HS0 - 32768a b  - 32768a b )
+--R                 *
+--R                         2
+--R                    %%HS1
+--R                + 
+--R                                 3 4           4 3      2          2 3
+--R                      (- 3145728a b  - 3145728a b )%%HS0  - 196608a b %%HS0
+--R                    + 
+--R                               2       2
+--R                      - 1792a b  + 256a b
+--R                 *
+--R                    %%HS1
+--R                + 
+--R                             3 4           4 3      3          2 3     2
+--R                  (- 3145728a b  - 3145728a b )%%HS0  - 196608a b %%HS0
+--R                + 
+--R                           2
+--R                  - 4608a b %%HS0 - 32b
+--R             *
+--R                 +------+
+--R                \|4%%HS1
+--R            + 
+--R              x
+--R     + 
+--R          +------+
+--R         \|4%%HS0
+--R      *
+--R         log
+--R                           3 4           4 3      3
+--R                  (3145728a b  + 3145728a b )%%HS0
+--R                + 
+--R                        2 3         3 2      2           2       2
+--R                (163840a b  - 32768a b )%%HS0  + (2816a b  + 256a b)%%HS0 + 16b
+--R             *
+--R                 +------+
+--R                \|4%%HS0
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R             +------+
+--R            \|4%%HS0
+--R         *
+--R            log
+--R                                3 4           4 3      3
+--R                     (- 3145728a b  - 3145728a b )%%HS0
+--R                   + 
+--R                               2 3         3 2      2
+--R                     (- 163840a b  + 32768a b )%%HS0
+--R                   + 
+--R                               2       2
+--R                     (- 2816a b  - 256a b)%%HS0 - 16b
+--R                *
+--R                    +------+
+--R                   \|4%%HS0
+--R               + 
+--R                 x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1548
+
+--S 1549 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +-----------------+ +---------------+ +---------------+
+--R           +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R          +-------------+
+--R          |4+-+   4+---+
+--R         \|\|b  + \|- a
+--R      *
+--R         ROOT
+--R                              2
+--R                  (16a b + 16a )
+--R               *
+--R                  ROOT
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                       + 
+--R                                     2 3        3 2        4               2
+--R                             (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                           + 
+--R                                  2
+--R                             - 64a b
+--R                        *
+--R                           %%HS1
+--R                       + 
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                       + 
+--R                                 2      2
+--R                         (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                    /
+--R                           2 3        3 2       4
+--R                       512a b  + 1024a b  + 512a b
+--R              + 
+--R                              2                       2
+--R                (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R           /
+--R                       2
+--R              8a b + 8a
+--R      *
+--R         log
+--R                                     3 4           4 3               2 3
+--R                            (1572864a b  + 1572864a b )%%HS0 + 16384a b
+--R                          + 
+--R                                  3 2
+--R                            16384a b
+--R                     *
+--R                        %%HS1
+--R                    + 
+--R                             2 3         3 2               2       2
+--R                      (16384a b  + 16384a b )%%HS0 + 128a b  + 128a b
+--R                 *
+--R                    ROOT
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                         + 
+--R                                       2 3        3 2        4               2
+--R                               (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                             + 
+--R                                    2
+--R                               - 64a b
+--R                          *
+--R                             %%HS1
+--R                         + 
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                         + 
+--R                                   2      2
+--R                           (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                      /
+--R                             2 3        3 2       4
+--R                         512a b  + 1024a b  + 512a b
+--R                + 
+--R                              3 4           4 3               2 3         3 2
+--R                    ((1572864a b  + 1572864a b )%%HS0 + 16384a b  + 16384a b )
+--R                 *
+--R                         2
+--R                    %%HS1
+--R                + 
+--R                               3 4           4 3      2         2 3
+--R                      (1572864a b  + 1572864a b )%%HS0  + 98304a b %%HS0
+--R                    + 
+--R                            2       2
+--R                      896a b  - 128a b
+--R                 *
+--R                    %%HS1
+--R                + 
+--R                         2 3         3 2      2          2       2
+--R                  (16384a b  + 16384a b )%%HS0  + (896a b  - 128a b)%%HS0 + 8b
+--R             *
+--R                ROOT
+--R                                     2
+--R                         (16a b + 16a )
+--R                      *
+--R                         ROOT
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                              + 
+--R                                            2 3        3 2        4
+--R                                    (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                  + 
+--R                                           2      2
+--R                                    - 64a b  - 64a b
+--R                               *
+--R                                  %%HS1
+--R                              + 
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                              + 
+--R                                        2      2
+--R                                (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                           /
+--R                                  2 3        3 2       4
+--R                              512a b  + 1024a b  + 512a b
+--R                     + 
+--R                                     2                       2
+--R                       (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R                  /
+--R                              2
+--R                     8a b + 8a
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                         +-----------------+ +---------------+ +---------------+
+--R              +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R            2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R         *
+--R             +-------------+
+--R             |4+-+   4+---+
+--R            \|\|b  + \|- a
+--R         *
+--R            ROOT
+--R                                   2
+--R                     (- 16a b - 16a )
+--R                  *
+--R                     ROOT
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                          + 
+--R                                        2 3        3 2        4               2
+--R                                (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                              + 
+--R                                     2
+--R                                - 64a b
+--R                           *
+--R                              %%HS1
+--R                          + 
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                          + 
+--R                                    2      2
+--R                            (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                       /
+--R                              2 3        3 2       4
+--R                          512a b  + 1024a b  + 512a b
+--R                 + 
+--R                                 2                       2
+--R                   (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R              /
+--R                          2
+--R                 8a b + 8a
+--R         *
+--R            log
+--R                                      3 4           4 3               2 3
+--R                             (1572864a b  + 1572864a b )%%HS0 + 16384a b
+--R                           + 
+--R                                   3 2
+--R                             16384a b
+--R                        *
+--R                           %%HS1
+--R                       + 
+--R                                2 3         3 2               2       2
+--R                         (16384a b  + 16384a b )%%HS0 + 128a b  + 128a b
+--R                    *
+--R                       ROOT
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                            + 
+--R                                          2 3        3 2        4
+--R                                  (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                + 
+--R                                         2      2
+--R                                  - 64a b  - 64a b
+--R                             *
+--R                                %%HS1
+--R                            + 
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                            + 
+--R                                      2      2
+--R                              (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                         /
+--R                                2 3        3 2       4
+--R                            512a b  + 1024a b  + 512a b
+--R                   + 
+--R                                    3 4           4 3               2 3
+--R                         (- 1572864a b  - 1572864a b )%%HS0 - 16384a b
+--R                       + 
+--R                                 3 2
+--R                         - 16384a b
+--R                    *
+--R                            2
+--R                       %%HS1
+--R                   + 
+--R                                    3 4           4 3      2         2 3
+--R                         (- 1572864a b  - 1572864a b )%%HS0  - 98304a b %%HS0
+--R                       + 
+--R                                 2       2
+--R                         - 896a b  + 128a b
+--R                    *
+--R                       %%HS1
+--R                   + 
+--R                              2 3         3 2      2            2       2
+--R                     (- 16384a b  - 16384a b )%%HS0  + (- 896a b  + 128a b)%%HS0
+--R                   + 
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                          2
+--R                            (- 16a b - 16a )
+--R                         *
+--R                            ROOT
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                                 + 
+--R                                               2 3        3 2        4
+--R                                       (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                     + 
+--R                                              2      2
+--R                                       - 64a b  - 64a b
+--R                                  *
+--R                                     %%HS1
+--R                                 + 
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                                 + 
+--R                                           2      2
+--R                                   (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                              /
+--R                                     2 3        3 2       4
+--R                                 512a b  + 1024a b  + 512a b
+--R                        + 
+--R                                        2                       2
+--R                          (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R                     /
+--R                                 2
+--R                        8a b + 8a
+--R               + 
+--R                 x
+--R     + 
+--R                      +-----------------+ +---------------+ +---------------+
+--R           +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R          +-------------+
+--R          |4+-+   4+---+
+--R         \|\|b  + \|- a
+--R      *
+--R         ROOT
+--R                                2
+--R                  (- 16a b - 16a )
+--R               *
+--R                  ROOT
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                       + 
+--R                                     2 3        3 2        4               2
+--R                             (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                           + 
+--R                                  2
+--R                             - 64a b
+--R                        *
+--R                           %%HS1
+--R                       + 
+--R                                 2 3        3 2        4       2
+--R                         (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                       + 
+--R                                 2      2
+--R                         (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                    /
+--R                           2 3        3 2       4
+--R                       512a b  + 1024a b  + 512a b
+--R              + 
+--R                              2                       2
+--R                (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R           /
+--R                       2
+--R              8a b + 8a
+--R      *
+--R         log
+--R                                     3 4           4 3               2 3
+--R                          (- 1572864a b  - 1572864a b )%%HS0 - 16384a b
+--R                        + 
+--R                                  3 2
+--R                          - 16384a b
+--R                     *
+--R                        %%HS1
+--R                    + 
+--R                               2 3         3 2               2       2
+--R                      (- 16384a b  - 16384a b )%%HS0 - 128a b  - 128a b
+--R                 *
+--R                    ROOT
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                         + 
+--R                                       2 3        3 2        4               2
+--R                               (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                             + 
+--R                                    2
+--R                               - 64a b
+--R                          *
+--R                             %%HS1
+--R                         + 
+--R                                   2 3        3 2        4       2
+--R                           (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                         + 
+--R                                   2      2
+--R                           (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                      /
+--R                             2 3        3 2       4
+--R                         512a b  + 1024a b  + 512a b
+--R                + 
+--R                              3 4           4 3               2 3         3 2
+--R                    ((1572864a b  + 1572864a b )%%HS0 + 16384a b  + 16384a b )
+--R                 *
+--R                         2
+--R                    %%HS1
+--R                + 
+--R                               3 4           4 3      2         2 3
+--R                      (1572864a b  + 1572864a b )%%HS0  + 98304a b %%HS0
+--R                    + 
+--R                            2       2
+--R                      896a b  - 128a b
+--R                 *
+--R                    %%HS1
+--R                + 
+--R                         2 3         3 2      2          2       2
+--R                  (16384a b  + 16384a b )%%HS0  + (896a b  - 128a b)%%HS0 + 8b
+--R             *
+--R                ROOT
+--R                                       2
+--R                         (- 16a b - 16a )
+--R                      *
+--R                         ROOT
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                              + 
+--R                                            2 3        3 2        4
+--R                                    (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                  + 
+--R                                           2      2
+--R                                    - 64a b  - 64a b
+--R                               *
+--R                                  %%HS1
+--R                              + 
+--R                                        2 3        3 2        4       2
+--R                                (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                              + 
+--R                                        2      2
+--R                                (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                           /
+--R                                  2 3        3 2       4
+--R                              512a b  + 1024a b  + 512a b
+--R                     + 
+--R                                     2                       2
+--R                       (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R                  /
+--R                              2
+--R                     8a b + 8a
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                         +-----------------+ +---------------+ +---------------+
+--R              +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R            2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R         *
+--R             +-------------+
+--R             |4+-+   4+---+
+--R            \|\|b  + \|- a
+--R         *
+--R            ROOT
+--R                                 2
+--R                     (16a b + 16a )
+--R                  *
+--R                     ROOT
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                          + 
+--R                                        2 3        3 2        4               2
+--R                                (- 1024a b  - 2048a b  - 1024a b)%%HS0 - 64a b
+--R                              + 
+--R                                     2
+--R                                - 64a b
+--R                           *
+--R                              %%HS1
+--R                          + 
+--R                                    2 3        3 2        4       2
+--R                            (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                          + 
+--R                                    2      2
+--R                            (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                       /
+--R                              2 3        3 2       4
+--R                          512a b  + 1024a b  + 512a b
+--R                 + 
+--R                                 2                       2
+--R                   (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R              /
+--R                          2
+--R                 8a b + 8a
+--R         *
+--R            log
+--R                                        3 4           4 3               2 3
+--R                             (- 1572864a b  - 1572864a b )%%HS0 - 16384a b
+--R                           + 
+--R                                     3 2
+--R                             - 16384a b
+--R                        *
+--R                           %%HS1
+--R                       + 
+--R                                  2 3         3 2               2       2
+--R                         (- 16384a b  - 16384a b )%%HS0 - 128a b  - 128a b
+--R                    *
+--R                       ROOT
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                            + 
+--R                                          2 3        3 2        4
+--R                                  (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                + 
+--R                                         2      2
+--R                                  - 64a b  - 64a b
+--R                             *
+--R                                %%HS1
+--R                            + 
+--R                                      2 3        3 2        4       2
+--R                              (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                            + 
+--R                                      2      2
+--R                              (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                         /
+--R                                2 3        3 2       4
+--R                            512a b  + 1024a b  + 512a b
+--R                   + 
+--R                                    3 4           4 3               2 3
+--R                         (- 1572864a b  - 1572864a b )%%HS0 - 16384a b
+--R                       + 
+--R                                 3 2
+--R                         - 16384a b
+--R                    *
+--R                            2
+--R                       %%HS1
+--R                   + 
+--R                                    3 4           4 3      2         2 3
+--R                         (- 1572864a b  - 1572864a b )%%HS0  - 98304a b %%HS0
+--R                       + 
+--R                                 2       2
+--R                         - 896a b  + 128a b
+--R                    *
+--R                       %%HS1
+--R                   + 
+--R                              2 3         3 2      2            2       2
+--R                     (- 16384a b  - 16384a b )%%HS0  + (- 896a b  + 128a b)%%HS0
+--R                   + 
+--R                     - 8b
+--R                *
+--R                   ROOT
+--R                                        2
+--R                            (16a b + 16a )
+--R                         *
+--R                            ROOT
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HS1
+--R                                 + 
+--R                                               2 3        3 2        4
+--R                                       (- 1024a b  - 2048a b  - 1024a b)%%HS0
+--R                                     + 
+--R                                              2      2
+--R                                       - 64a b  - 64a b
+--R                                  *
+--R                                     %%HS1
+--R                                 + 
+--R                                           2 3        3 2        4       2
+--R                                   (- 1536a b  - 3072a b  - 1536a b)%%HS0
+--R                                 + 
+--R                                           2      2
+--R                                   (- 64a b  - 64a b)%%HS0 - b - 3a
+--R                              /
+--R                                     2 3        3 2       4
+--R                                 512a b  + 1024a b  + 512a b
+--R                        + 
+--R                                        2                       2
+--R                          (- 16a b - 16a )%%HS1 + (- 16a b - 16a )%%HS0 - 1
+--R                     /
+--R                                 2
+--R                        8a b + 8a
+--R               + 
+--R                 x
+--R     + 
+--R       -
+--R                         +-----------------+ +---------------+ +---------------+
+--R              +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R            2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R         *
+--R             +-------------+
+--R             |4+-+   4+---+  +------+
+--R            \|\|b  + \|- a  \|4%%HS1
+--R         *
+--R            log
+--R                                    3 4           4 3               2 3
+--R                           (3145728a b  + 3145728a b )%%HS0 + 32768a b
+--R                         + 
+--R                                 3 2
+--R                           32768a b
+--R                    *
+--R                            2
+--R                       %%HS1
+--R                   + 
+--R                                  3 4           4 3      2          2 3
+--R                         (3145728a b  + 3145728a b )%%HS0  + 196608a b %%HS0
+--R                       + 
+--R                                2       2
+--R                         1792a b  - 256a b
+--R                    *
+--R                       %%HS1
+--R                   + 
+--R                              3 4           4 3      3          2 3     2
+--R                     (3145728a b  + 3145728a b )%%HS0  + 196608a b %%HS0
+--R                   + 
+--R                            2
+--R                     4608a b %%HS0 + 32b
+--R                *
+--R                    +------+
+--R                   \|4%%HS1
+--R               + 
+--R                 x
+--R     + 
+--R                      +-----------------+ +---------------+ +---------------+
+--R           +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R          +-------------+
+--R          |4+-+   4+---+  +------+
+--R         \|\|b  + \|- a  \|4%%HS1
+--R      *
+--R         log
+--R                                3 4           4 3               2 3         3 2
+--R                    ((- 3145728a b  - 3145728a b )%%HS0 - 32768a b  - 32768a b )
+--R                 *
+--R                         2
+--R                    %%HS1
+--R                + 
+--R                                 3 4           4 3      2          2 3
+--R                      (- 3145728a b  - 3145728a b )%%HS0  - 196608a b %%HS0
+--R                    + 
+--R                               2       2
+--R                      - 1792a b  + 256a b
+--R                 *
+--R                    %%HS1
+--R                + 
+--R                             3 4           4 3      3          2 3     2
+--R                  (- 3145728a b  - 3145728a b )%%HS0  - 196608a b %%HS0
+--R                + 
+--R                           2
+--R                  - 4608a b %%HS0 - 32b
+--R             *
+--R                 +------+
+--R                \|4%%HS1
+--R            + 
+--R              x
+--R     + 
+--R                      +-----------------+ +---------------+ +---------------+
+--R           +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R          +-------------+
+--R          |4+-+   4+---+  +------+
+--R         \|\|b  + \|- a  \|4%%HS0
+--R      *
+--R         log
+--R                           3 4           4 3      3
+--R                  (3145728a b  + 3145728a b )%%HS0
+--R                + 
+--R                        2 3         3 2      2           2       2
+--R                (163840a b  - 32768a b )%%HS0  + (2816a b  + 256a b)%%HS0 + 16b
+--R             *
+--R                 +------+
+--R                \|4%%HS0
+--R            + 
+--R              x
+--R     + 
+--R       -
+--R                         +-----------------+ +---------------+ +---------------+
+--R              +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R            2\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R         *
+--R             +-------------+
+--R             |4+-+   4+---+  +------+
+--R            \|\|b  + \|- a  \|4%%HS0
+--R         *
+--R            log
+--R                                3 4           4 3      3
+--R                     (- 3145728a b  - 3145728a b )%%HS0
+--R                   + 
+--R                               2 3         3 2      2
+--R                     (- 163840a b  + 32768a b )%%HS0
+--R                   + 
+--R                               2       2
+--R                     (- 2816a b  - 256a b)%%HS0 - 16b
+--R                *
+--R                    +------+
+--R                   \|4%%HS0
+--R               + 
+--R                 x
+--R     + 
+--R          +-----------------+ +---------------+ +-------------+
+--R          |  4+-+     4+---+  |  4+-+   4+---+  |4+-+   4+---+
+--R         \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + \|- a
+--R      *
+--R                       8+-+
+--R                      x\|b
+--R         atanh(------------------)
+--R                +---------------+
+--R                |4+-+     4+---+
+--R               \|\|b  + %i\|- a
+--R     + 
+--R       -
+--R             +-----------------+ +---------------+ +---------------+
+--R             |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R            \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R         *
+--R                         8+-+
+--R                        x\|b
+--R            atanh(----------------)
+--R                   +-------------+
+--R                   |4+-+   4+---+
+--R                  \|\|b  + \|- a
+--R     + 
+--R       -
+--R             +---------------+ +---------------+ +-------------+
+--R             |  4+-+   4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R            \|- \|b  + \|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R         *
+--R                          8+-+
+--R                         x\|b
+--R            atan(--------------------)
+--R                  +-----------------+
+--R                  |  4+-+     4+---+
+--R                 \|- \|b  + %i\|- a
+--R     + 
+--R          +-----------------+ +---------------+ +-------------+
+--R          |  4+-+     4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R         \|- \|b  + %i\|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R      *
+--R                      8+-+
+--R                     x\|b
+--R         atan(------------------)
+--R               +---------------+
+--R               |  4+-+   4+---+
+--R              \|- \|b  + \|- a
+--R  /
+--R                    +-----------------+ +---------------+ +---------------+
+--R         +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R       4\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R    *
+--R        +-------------+
+--R        |4+-+   4+---+
+--R       \|\|b  + \|- a
+--R                                           Type: Expression(Complex(Integer))
+--E 1549
+
+--S 1550 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 10       8       6       4             2  +---+4+---+2
+--R           (- b x   + 4b x  - 6b x  + 4b x  + (- b - a)x )\|- a \|- a
+--R         + 
+--R                  10        8             2  2          2
+--R           - a b x   + a b x  + (- a b - a )x  + a b + a
+--R      *
+--R         8+-+6
+--R         \|b
+--R     + 
+--R                 8       6       4       2          +---+4+---+2         8
+--R             (b x  - 4b x  + 6b x  - 4b x  + b + a)\|- a \|- a   + 4a b x
+--R           + 
+--R                     6
+--R             - 4a b x
+--R      *
+--R         4+-+8+-+4
+--R         \|b \|b
+--R     + 
+--R                6         4 4+-+2 8+-+2         4         2 4+-+3
+--R       (- 6a b x  + 6a b x )\|b   \|b  + (4a b x  - 4a b x )\|b
+--R  /
+--R              2 16       2 14       2 12       2 10        2     2   8
+--R           a b x   - 4a b x   + 6a b x   - 4a b x   + (2a b  + 2a b)x
+--R         + 
+--R                  2     2   6        2     2   4          2     2   2      2
+--R           (- 4a b  - 4a b)x  + (6a b  + 6a b)x  + (- 4a b  - 4a b)x  + a b
+--R         + 
+--R             2     3
+--R           2a b + a
+--R      *
+--R         8+-+6
+--R         \|b
+--R     + 
+--R                2 14        2 12        2 10        2 8          2     2   6
+--R         (- 4a b x   + 16a b x   - 24a b x   + 16a b x  + (- 4a b  - 4a b)x )
+--R      *
+--R         4+-+8+-+4
+--R         \|b \|b
+--R     + 
+--R            2 12        2 10        2 8        2 6        2     2   4 4+-+2 8+-+2
+--R       (6a b x   - 24a b x   + 36a b x  - 24a b x  + (6a b  + 6a b)x )\|b   \|b
+--R     + 
+--R              2 10        2 8        2 6        2 4          2     2   2 4+-+3
+--R       (- 4a b x   + 16a b x  - 24a b x  + 16a b x  + (- 4a b  - 4a b)x )\|b
+--R                                           Type: Expression(Complex(Integer))
+--E 1550
+
+)clear all
+
+--S 1551 of 1580
+t0:=(-1+4*x^5)/(1+x+x^5)^2
+--R 
+--R
+--R                     5
+--R                   4x  - 1
+--R   (1)  -----------------------------
+--R         10     6     5    2
+--R        x   + 2x  + 2x  + x  + 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1551
+
+--S 1552 of 1580
+r0:=-x/(1+x+x^5)
+--R 
+--R
+--R               x
+--R   (2)  - ----------
+--R           5
+--R          x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1552
+
+--S 1553 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               x
+--R   (3)  - ----------
+--R           5
+--R          x  + x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 1553
+
+--S 1554 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1554
+
+--S 1555 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1555
+
+)clear all
+
+--S 1556 of 1580
+t0:=(b*c-a*d-2*a*e*x-b*e*x^2-3*a*f*x^2-2*b*f*x^3)/(c+d*x+e*x^2+f*x^3)^2
+--R 
+--R
+--R   (1)
+--R             3                  2
+--R     - 2b f x  + (- 3a f - b e)x  - 2a e x - a d + b c
+--R  /
+--R        2 6         5            2  4                 3            2  2
+--R       f x  + 2e f x  + (2d f + e )x  + (2c f + 2d e)x  + (2c e + d )x  + 2c d x
+--R     + 
+--R        2
+--R       c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1556
+
+--S 1557 of 1580
+r0:=a/(c+d*x+e*x^2+f*x^3)+b*x/(c+d*x+e*x^2+f*x^3)
+--R 
+--R
+--R               b x + a
+--R   (2)  ---------------------
+--R           3      2
+--R        f x  + e x  + d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1557
+
+--S 1558 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               b x + a
+--R   (3)  ---------------------
+--R           3      2
+--R        f x  + e x  + d x + c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1558
+
+--S 1559 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1559
+
+--S 1560 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1560
+
+)clear all
+
+--S 1561 of 1580
+t0:=(9-40*x-18*x^2+174*x^4+24*x^5+26*x^6-39*x^8)/(3+2*x^2+x^4)^3
+--R 
+--R
+--R             8      6      5       4      2
+--R        - 39x  + 26x  + 24x  + 174x  - 18x  - 40x + 9
+--R   (1)  ---------------------------------------------
+--R          12     10      8      6      4      2
+--R         x   + 6x   + 21x  + 44x  + 63x  + 54x  + 27
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1561
+
+--S 1562 of 1580
+r0:=2/(3+2*x^2+x^4)^2+3*x/(3+2*x^2+x^4)^2-4*x^2/(3+2*x^2+x^4)^2+_
+   13*x^5/(3+2*x^2+x^4)^2
+--R 
+--R
+--R               5     2
+--R            13x  - 4x  + 3x + 2
+--R   (2)  --------------------------
+--R         8     6      4      2
+--R        x  + 4x  + 10x  + 12x  + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1562
+
+--S 1563 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R               5     2
+--R            13x  - 4x  + 3x + 2
+--R   (3)  --------------------------
+--R         8     6      4      2
+--R        x  + 4x  + 10x  + 12x  + 9
+--R                                         Type: Union(Expression(Integer),...)
+--E 1563
+
+--S 1564 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1564
+
+--S 1565 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1565
+
+)clear all
+
+--S 1566 of 1580
+t0:=(-15+36*x-5*x^2-12*x^3+34*x^4-140*x^5-15*x^6-8*x^7+30*x^9)/(3+x+x^4)^4
+--R 
+--R
+--R   (1)
+--R        9     7      6       5      4      3     2
+--R     30x  - 8x  - 15x  - 140x  + 34x  - 12x  - 5x  + 36x - 15
+--R  /
+--R        16     13      12     10      9      8     7      6       5       4
+--R       x   + 4x   + 12x   + 6x   + 36x  + 54x  + 4x  + 36x  + 108x  + 109x
+--R     + 
+--R          3      2
+--R       12x  + 54x  + 108x + 81
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1566
+
+--S 1567 of 1580
+r0:=2/(3+x+x^4)^3-3*x/(3+x+x^4)^3+5*x^2/(3+x+x^4)^3+x^4/(3+x+x^4)^3-_
+   5*x^6/(3+x+x^4)^3
+--R 
+--R
+--R                            6    4     2
+--R                        - 5x  + x  + 5x  - 3x + 2
+--R   (2)  ---------------------------------------------------------
+--R         12     9     8     6      5      4    3     2
+--R        x   + 3x  + 9x  + 3x  + 18x  + 27x  + x  + 9x  + 27x + 27
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1567
+
+--S 1568 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            6    4     2
+--R                        - 5x  + x  + 5x  - 3x + 2
+--R   (3)  ---------------------------------------------------------
+--R         12     9     8     6      5      4    3     2
+--R        x   + 3x  + 9x  + 3x  + 18x  + 27x  + x  + 9x  + 27x + 27
+--R                                         Type: Union(Expression(Integer),...)
+--E 1568
+
+--S 1569 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1569
+
+--S 1570 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1570
+
+)clear all
+
+--S 1571 of 1580
+t0:=3*(-47+228*x+120*x^2+19*x^3)/(3+x+x^4)^4+_
+   (42-320*x-75*x^2-8*x^3)/(3+x+x^4)^3+30*x/(3+x+x^4)^2
+--R 
+--R
+--R   (1)
+--R        9     7      6       5      4      3     2
+--R     30x  - 8x  - 15x  - 140x  + 34x  - 12x  - 5x  + 36x - 15
+--R  /
+--R        16     13      12     10      9      8     7      6       5       4
+--R       x   + 4x   + 12x   + 6x   + 36x  + 54x  + 4x  + 36x  + 108x  + 109x
+--R     + 
+--R          3      2
+--R       12x  + 54x  + 108x + 81
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1571
+
+--S 1572 of 1580
+r0:=(2-3*x+5*x^2+x^4-5*x^6)/(3+x+x^4)^3
+--R 
+--R
+--R                            6    4     2
+--R                        - 5x  + x  + 5x  - 3x + 2
+--R   (2)  ---------------------------------------------------------
+--R         12     9     8     6      5      4    3     2
+--R        x   + 3x  + 9x  + 3x  + 18x  + 27x  + x  + 9x  + 27x + 27
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1572
+
+--S 1573 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            6    4     2
+--R                        - 5x  + x  + 5x  - 3x + 2
+--R   (3)  ---------------------------------------------------------
+--R         12     9     8     6      5      4    3     2
+--R        x   + 3x  + 9x  + 3x  + 18x  + 27x  + x  + 9x  + 27x + 27
+--R                                         Type: Union(Expression(Integer),...)
+--E 1573
+
+--S 1574 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1574
+
+--S 1575 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1575
+
+)clear all
+
+--S 1576 of 1580
+t0:=(-3+10*x+4*x^3-30*x^5)/(3+x+x^4)^3-3*(1+4*x^3)*_
+   (2-3*x+5*x^2+x^4-5*x^6)/(3+x+x^4)^4
+--R 
+--R
+--R   (1)
+--R        9     7      6       5      4      3     2
+--R     30x  - 8x  - 15x  - 140x  + 34x  - 12x  - 5x  + 36x - 15
+--R  /
+--R        16     13      12     10      9      8     7      6       5       4
+--R       x   + 4x   + 12x   + 6x   + 36x  + 54x  + 4x  + 36x  + 108x  + 109x
+--R     + 
+--R          3      2
+--R       12x  + 54x  + 108x + 81
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1576
+
+--S 1577 of 1580
+r0:=(2-3*x+5*x^2+x^4-5*x^6)/(3+x+x^4)^3
+--R 
+--R
+--R                            6    4     2
+--R                        - 5x  + x  + 5x  - 3x + 2
+--R   (2)  ---------------------------------------------------------
+--R         12     9     8     6      5      4    3     2
+--R        x   + 3x  + 9x  + 3x  + 18x  + 27x  + x  + 9x  + 27x + 27
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1577
+
+--S 1578 of 1580
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            6    4     2
+--R                        - 5x  + x  + 5x  - 3x + 2
+--R   (3)  ---------------------------------------------------------
+--R         12     9     8     6      5      4    3     2
+--R        x   + 3x  + 9x  + 3x  + 18x  + 27x  + x  + 9x  + 27x + 27
+--R                                         Type: Union(Expression(Integer),...)
+--E 1578
+
+--S 1579 of 1580
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1579
+
+--S 1580 of 1580
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1580
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich20a.input.pamphlet b/src/input/rich20a.input.pamphlet
new file mode 100644
index 0000000..abb46fb
--- /dev/null
+++ b/src/input/rich20a.input.pamphlet
@@ -0,0 +1,15124 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich20a.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|y'[x] f[y[x]]|
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich20a.output
+)spool rich20a.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 619
+t0:=(b+2*c*x+3*d*x^2)*(a+b*x+c*x^2+d*x^3)^n
+--R 
+--R
+--R             2                3      2           n
+--R   (1)  (3d x  + 2c x + b)(d x  + c x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 619
+r0:=(a+b*x+c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2           n + 1
+--R        (d x  + c x  + b x + a)
+--R   (2)  ----------------------------
+--R                    n + 1
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                          3      2
+--R            3      2             n log(d x  + c x  + b x + a)
+--R        (d x  + c x  + b x + a)%e
+--R   (3)  -----------------------------------------------------
+--R                                n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         3      2
+--R           3      2             n log(d x  + c x  + b x + a)
+--R       (d x  + c x  + b x + a)%e
+--R     + 
+--R             3      2           n + 1
+--R       - (d x  + c x  + b x + a)
+--R  /
+--R     n + 1
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                  3      2
+--R          2              n log(d x  + c x  + b x + a)
+--R     (3d x  + 2c x + b)%e
+--R   + 
+--R            2                3      2           n
+--R     (- 3d x  - 2c x - b)(d x  + c x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 619
+t0:=(b+2*c*x+3*d*x^2)*(b*x+c*x^2+d*x^3)^n
+--R 
+--R
+--R             2                3      2       n
+--R   (1)  (3d x  + 2c x + b)(d x  + c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 619
+r0:=(b*x+c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2       n + 1
+--R        (d x  + c x  + b x)
+--R   (2)  ------------------------
+--R                  n + 1
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                      3      2
+--R            3      2         n log(d x  + c x  + b x)
+--R        (d x  + c x  + b x)%e
+--R   (3)  ---------------------------------------------
+--R                            n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 3      2
+--R       3      2         n log(d x  + c x  + b x)       3      2       n + 1
+--R   (d x  + c x  + b x)%e                         - (d x  + c x  + b x)
+--R   ------------------------------------------------------------------------
+--R                                     n + 1
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                  3      2
+--R          2              n log(d x  + c x  + b x)
+--R     (3d x  + 2c x + b)%e
+--R   + 
+--R            2                3      2       n
+--R     (- 3d x  - 2c x - b)(d x  + c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 619
+t0:=x^n*(b+c*x+d*x^2)^n*(b+2*c*x+3*d*x^2)
+--R 
+--R
+--R             2             n    2           n
+--R   (1)  (3d x  + 2c x + b)x (d x  + c x + b)
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 619
+r0:=x^(1+n)*(b+c*x+d*x^2)^(1+n)/(1+n)
+--R 
+--R
+--R         n + 1    2           n + 1
+--R        x     (d x  + c x + b)
+--R   (2)  ---------------------------
+--R                   n + 1
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                2
+--R            3      2         n log(x)  n log(d x  + c x + b)
+--R        (d x  + c x  + b x)%e        %e
+--R   (3)  ----------------------------------------------------
+--R                                n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 13
+
+--S 14 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               2
+--R           3      2         n log(x)  n log(d x  + c x + b)
+--R       (d x  + c x  + b x)%e        %e
+--R     + 
+--R          n + 1    2           n + 1
+--R       - x     (d x  + c x + b)
+--R  /
+--R     n + 1
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                            2
+--R          2              n log(x)  n log(d x  + c x + b)
+--R     (3d x  + 2c x + b)%e        %e
+--R   + 
+--R        n    2           n + 1                n + 1    2           n
+--R     - x (d x  + c x + b)      + (- 2d x - c)x     (d x  + c x + b)
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 619
+t0:=(b+3*d*x^2)*(a+b*x+d*x^3)^n
+--R 
+--R
+--R             2         3           n
+--R   (1)  (3d x  + b)(d x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 619
+r0:=(a+b*x+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3           n + 1
+--R        (d x  + b x + a)
+--R   (2)  ---------------------
+--R                n + 1
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   3
+--R            3             n log(d x  + b x + a)
+--R        (d x  + b x + a)%e
+--R   (3)  ---------------------------------------
+--R                         n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                   3
+--R            3             n log(d x  + b x + a)       3           n + 1
+--R        (d x  + b x + a)%e                      - (d x  + b x + a)
+--R   (4)  ---------------------------------------------------------------
+--R                                     n + 1
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R                              3
+--R             2       n log(d x  + b x + a)          2         3           n
+--R   (5)  (3d x  + b)%e                      + (- 3d x  - b)(d x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 619
+t0:=(b+3*d*x^2)*(b*x+d*x^3)^n
+--R 
+--R
+--R             2         3       n
+--R   (1)  (3d x  + b)(d x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 619
+r0:=(b*x+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3       n + 1
+--R        (d x  + b x)
+--R   (2)  -----------------
+--R              n + 1
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               3
+--R            3         n log(d x  + b x)
+--R        (d x  + b x)%e
+--R   (3)  -------------------------------
+--R                     n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 23
+
+--S 24 of 619
+m0:=a0-r0
+--R 
+--R
+--R                               3
+--R            3         n log(d x  + b x)       3       n + 1
+--R        (d x  + b x)%e                  - (d x  + b x)
+--R   (4)  ---------------------------------------------------
+--R                               n + 1
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R                              3
+--R             2       n log(d x  + b x)          2         3       n
+--R   (5)  (3d x  + b)%e                  + (- 3d x  - b)(d x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 25
+
+)clear all
+
+--S 26 of 619
+t0:=x^n*(b+d*x^2)^n*(b+3*d*x^2)
+--R 
+--R
+--R             2      n    2     n
+--R   (1)  (3d x  + b)x (d x  + b)
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 619
+r0:=x^(1+n)*(b+d*x^2)^(1+n)/(1+n)
+--R 
+--R
+--R         n + 1    2     n + 1
+--R        x     (d x  + b)
+--R   (2)  ---------------------
+--R                n + 1
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                         2
+--R            3         n log(x)  n log(d x  + b)
+--R        (d x  + b x)%e        %e
+--R   (3)  ---------------------------------------
+--R                         n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 28
+
+--S 29 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                         2
+--R            3         n log(x)  n log(d x  + b)    n + 1    2     n + 1
+--R        (d x  + b x)%e        %e                - x     (d x  + b)
+--R   (4)  ---------------------------------------------------------------
+--R                                     n + 1
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                     2
+--R          2       n log(x)  n log(d x  + b)    n    2     n + 1
+--R     (3d x  + b)%e        %e                - x (d x  + b)
+--R   + 
+--R             n + 1    2     n
+--R     - 2d x x     (d x  + b)
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 619
+t0:=(2*c*x+3*d*x^2)*(a+c*x^2+d*x^3)^n
+--R 
+--R
+--R             2            3      2     n
+--R   (1)  (3d x  + 2c x)(d x  + c x  + a)
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 619
+r0:=(a+c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2     n + 1
+--R        (d x  + c x  + a)
+--R   (2)  ----------------------
+--R                 n + 1
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                    3      2
+--R            3      2       n log(d x  + c x  + a)
+--R        (d x  + c x  + a)%e
+--R   (3)  -----------------------------------------
+--R                          n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 33
+
+--S 34 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                    3      2
+--R            3      2       n log(d x  + c x  + a)       3      2     n + 1
+--R        (d x  + c x  + a)%e                       - (d x  + c x  + a)
+--R   (4)  ------------------------------------------------------------------
+--R                                       n + 1
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                            3      2
+--R        2          n log(d x  + c x  + a)          2            3      2     n
+--R   (3d x  + 2c x)%e                       + (- 3d x  - 2c x)(d x  + c x  + a)
+--R                                                    Type: Expression(Integer)
+--E 35
+
+)clear all
+
+--S 36 of 619
+t0:=(2*c*x+3*d*x^2)*(c*x^2+d*x^3)^n
+--R 
+--R
+--R             2            3      2 n
+--R   (1)  (3d x  + 2c x)(d x  + c x )
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 619
+r0:=(c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2 n + 1
+--R        (d x  + c x )
+--R   (2)  ------------------
+--R               n + 1
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                3      2
+--R            3      2   n log(d x  + c x )
+--R        (d x  + c x )%e
+--R   (3)  ---------------------------------
+--R                      n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 38
+
+--S 39 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                3      2
+--R            3      2   n log(d x  + c x )       3      2 n + 1
+--R        (d x  + c x )%e                   - (d x  + c x )
+--R   (4)  ------------------------------------------------------
+--R                                 n + 1
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R                                 3      2
+--R             2          n log(d x  + c x )          2            3      2 n
+--R   (5)  (3d x  + 2c x)%e                   + (- 3d x  - 2c x)(d x  + c x )
+--R                                                    Type: Expression(Integer)
+--E 40
+
+)clear all
+
+--S 41 of 619
+t0:=x^n*(c*x+d*x^2)^n*(2*c*x+3*d*x^2)
+--R 
+--R
+--R             2         n    2       n
+--R   (1)  (3d x  + 2c x)x (d x  + c x)
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 619
+r0:=x^(1+n)*(c*x+d*x^2)^(1+n)/(1+n)
+--R 
+--R
+--R         n + 1    2       n + 1
+--R        x     (d x  + c x)
+--R   (2)  -----------------------
+--R                 n + 1
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                          2
+--R            3      2   n log(x)  n log(d x  + c x)
+--R        (d x  + c x )%e        %e
+--R   (3)  ------------------------------------------
+--R                           n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 43
+
+--S 44 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                          2
+--R            3      2   n log(x)  n log(d x  + c x)    n + 1    2       n + 1
+--R        (d x  + c x )%e        %e                  - x     (d x  + c x)
+--R   (4)  --------------------------------------------------------------------
+--R                                        n + 1
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                        2
+--R          2          n log(x)  n log(d x  + c x)    n    2       n + 1
+--R     (3d x  + 2c x)%e        %e                  - x (d x  + c x)
+--R   + 
+--R                  n + 1    2       n
+--R     (- 2d x - c)x     (d x  + c x)
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 619
+t0:=x^(2*n)*(c+d*x)^n*(2*c*x+3*d*x^2)
+--R 
+--R
+--R             2         2n         n
+--R   (1)  (3d x  + 2c x)x  (d x + c)
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 619
+r0:=x^(2*(1+n))*(c+d*x)^(1+n)/(1+n)
+--R 
+--R
+--R         2n + 2         n + 1
+--R        x      (d x + c)
+--R   (2)  ---------------------
+--R                n + 1
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3      2   2n log(x)  n log(d x + c)
+--R        (d x  + c x )%e         %e
+--R   (3)  ----------------------------------------
+--R                          n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 619
+m0:=a0-r0
+--R 
+--R
+--R            3      2   2n log(x)  n log(d x + c)    2n + 2         n + 1
+--R        (d x  + c x )%e         %e               - x      (d x + c)
+--R   (4)  ----------------------------------------------------------------
+--R                                      n + 1
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R          2          2n log(x)  n log(d x + c)     2n + 1         n + 1
+--R     (3d x  + 2c x)%e         %e               - 2x      (d x + c)
+--R   + 
+--R          2n + 2         n
+--R     - d x      (d x + c)
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 619
+t0:=x*(2*c+3*d*x)*(a+c*x^2+d*x^3)^n
+--R 
+--R
+--R             2            3      2     n
+--R   (1)  (3d x  + 2c x)(d x  + c x  + a)
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 619
+r0:=(a+c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2     n + 1
+--R        (d x  + c x  + a)
+--R   (2)  ----------------------
+--R                 n + 1
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                    3      2
+--R            3      2       n log(d x  + c x  + a)
+--R        (d x  + c x  + a)%e
+--R   (3)  -----------------------------------------
+--R                          n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 53
+
+--S 54 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                    3      2
+--R            3      2       n log(d x  + c x  + a)       3      2     n + 1
+--R        (d x  + c x  + a)%e                       - (d x  + c x  + a)
+--R   (4)  ------------------------------------------------------------------
+--R                                       n + 1
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                            3      2
+--R        2          n log(d x  + c x  + a)          2            3      2     n
+--R   (3d x  + 2c x)%e                       + (- 3d x  - 2c x)(d x  + c x  + a)
+--R                                                    Type: Expression(Integer)
+--E 55
+
+)clear all
+
+--S 56 of 619
+t0:=x*(2*c+3*d*x)*(c*x^2+d*x^3)^n
+--R 
+--R
+--R             2            3      2 n
+--R   (1)  (3d x  + 2c x)(d x  + c x )
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 619
+r0:=(c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2 n + 1
+--R        (d x  + c x )
+--R   (2)  ------------------
+--R               n + 1
+--R                                                    Type: Expression(Integer)
+--E 57
+
+--S 58 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                3      2
+--R            3      2   n log(d x  + c x )
+--R        (d x  + c x )%e
+--R   (3)  ---------------------------------
+--R                      n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 58
+
+--S 59 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                3      2
+--R            3      2   n log(d x  + c x )       3      2 n + 1
+--R        (d x  + c x )%e                   - (d x  + c x )
+--R   (4)  ------------------------------------------------------
+--R                                 n + 1
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R                                 3      2
+--R             2          n log(d x  + c x )          2            3      2 n
+--R   (5)  (3d x  + 2c x)%e                   + (- 3d x  - 2c x)(d x  + c x )
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 619
+t0:=(b+2*c*x+3*d*x^2)*(a+b*x+c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22         7      2 6  21
+--R     3d x   + 23c d x   + (22b d  + 77c d )x
+--R   + 
+--R           7           6       3 5  20
+--R     (21a d  + 147b c d  + 147c d )x
+--R   + 
+--R                   2  6         2 5       4 4  19
+--R     ((140a c + 70b )d  + 420b c d  + 175c d )x
+--R   + 
+--R              6          2       2   5         3 4       5 3  18
+--R     (133a b d  + (399a c  + 399b c)d  + 665b c d  + 133c d )x
+--R   + 
+--R            2 6                   3  5          3       2 2  4         4 3
+--R         63a d  + (756a b c + 126b )d  + (630a c  + 945b c )d  + 630b c d
+--R       + 
+--R            6 2
+--R         63c d
+--R    *
+--R        17
+--R       x
+--R   + 
+--R              2          2  5             2       3   4          4        2 3  3
+--R         (357a c + 357a b )d  + (1785a b c  + 595b c)d  + (595a c  + 1190b c )d
+--R       + 
+--R               5 2      7
+--R         357b c d  + 17c d
+--R    *
+--R        16
+--R       x
+--R   + 
+--R             2   5        2 2          2        4  4             3        3 2  3
+--R         336a b d  + (840a c  + 1680a b c + 140b )d  + (2240a b c  + 1120b c )d
+--R       + 
+--R                5       2 4  2         6      8
+--R         (336a c  + 840b c )d  + 112b c d + 2c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R             3 5         2            3  4         2 3          2 2       4   3
+--R         105a d  + (1575a b c + 525a b )d  + (1050a c  + 3150a b c  + 525b c)d
+--R       + 
+--R                   4        3 3  2          6       2 5          7
+--R         (1575a b c  + 1050b c )d  + (105a c  + 315b c )d + 15b c
+--R    *
+--R        14
+--R       x
+--R   + 
+--R              3        2 2  4         2   2          3       5  3
+--R         (490a c + 735a b )d  + (2940a b c  + 1960a b c + 98b )d
+--R       + 
+--R              2 4          2 3       4 2  2            5       3 4          7
+--R         (735a c  + 2940a b c  + 735b c )d  + (588a b c  + 490b c )d + 14a c
+--R       + 
+--R            2 6
+--R         49b c
+--R    *
+--R        13
+--R       x
+--R   + 
+--R             3   4        3 2        2 2          4  3
+--R         455a b d  + (910a c  + 2730a b c + 455a b )d
+--R       + 
+--R               2   3          3 2       5   2
+--R         (2730a b c  + 2730a b c  + 273b c)d
+--R       + 
+--R              2 5          2 4       4 3            6      3 5
+--R         (273a c  + 1365a b c  + 455b c )d + 91a b c  + 91b c
+--R    *
+--R        12
+--R       x
+--R   + 
+--R             4 4         3          2 3  3
+--R         105a d  + (1680a b c + 840a b )d
+--R       + 
+--R              3 3        2 2 2          4       6  2
+--R         (840a c  + 3780a b c  + 1260a b c + 42b )d
+--R       + 
+--R               2   4          3 3       5 2        2 6         2 5       4 4
+--R         (1260a b c  + 1680a b c  + 252b c )d + 42a c  + 252a b c  + 105b c
+--R    *
+--R        11
+--R       x
+--R   + 
+--R              4        3 2  3         3   2        2 3          5  2
+--R         (385a c + 770a b )d  + (2310a b c  + 2310a b c + 231a b )d
+--R       + 
+--R              3 4        2 2 3          4 2      6          2   5         3 4
+--R         (385a c  + 2310a b c  + 1155a b c  + 77b c)d + 231a b c  + 385a b c
+--R       + 
+--R            5 3
+--R         77b c
+--R    *
+--R        10
+--R       x
+--R   + 
+--R             4   3        4 2        3 2        2 4  2
+--R         350a b d  + (525a c  + 2100a b c + 525a b )d
+--R       + 
+--R               3   3        2 3 2         5       7        3 5       2 2 4
+--R         (1400a b c  + 2100a b c  + 420a b c + 10b )d + 70a c  + 525a b c
+--R       + 
+--R               4 3      6 2
+--R         350a b c  + 35b c
+--R    *
+--R        9
+--R       x
+--R   + 
+--R            5 3        4          3 3  2
+--R         63a d  + (945a b c + 630a b )d
+--R       + 
+--R              4 3        3 2 2       2 4         6         3   4       2 3 3
+--R         (315a c  + 1890a b c  + 945a b c + 63a b )d + 315a b c  + 630a b c
+--R       + 
+--R               5 2     7
+--R         189a b c  + 9b c
+--R    *
+--R        8
+--R       x
+--R   + 
+--R              5        4 2  2        4   2        3 3        2 5        4 4
+--R         (168a c + 420a b )d  + (840a b c  + 1120a b c + 168a b )d + 70a c
+--R       + 
+--R             3 2 3       2 4 2        6     8
+--R         560a b c  + 420a b c  + 56a b c + b
+--R    *
+--R        7
+--R       x
+--R   + 
+--R             5   2        5 2       4 2        3 4         4   3       3 3 2
+--R         147a b d  + (147a c  + 735a b c + 245a b )d + 245a b c  + 490a b c
+--R       + 
+--R             2 5        7
+--R         147a b c + 7a b
+--R    *
+--R        6
+--R       x
+--R   + 
+--R         6 2        5          4 3        5 3       4 2 2       3 4       2 6  5
+--R     (21a d  + (252a b c + 210a b )d + 42a c  + 315a b c  + 210a b c + 21a b )x
+--R   + 
+--R          6        5 2         5   2       4 3       3 5  4
+--R     ((35a c + 105a b )d + 105a b c  + 175a b c + 35a b )x
+--R   + 
+--R         6         6 2      5 2       4 4  3      7       6         5 3  2
+--R     (28a b d + 14a c  + 84a b c + 35a b )x  + (3a d + 21a b c + 21a b )x
+--R   + 
+--R        7      6 2      7
+--R     (2a c + 7a b )x + a b
+--R                                                    Type: Polynomial(Integer)
+--E 61
+
+--S 62 of 619
+r0:=1/8*(a+b*x+c*x^2+d*x^3)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23       7   7  2 6  22       7         6     3 5  21
+--R     - d x   + c d x   + (b d  + - c d )x   + (a d  + 7b c d  + 7c d )x
+--R     8                           2
+--R   + 
+--R              7  2  6        2 5   35  4 4  20
+--R     ((7a c + - b )d  + 21b c d  + -- c d )x
+--R              2                     4
+--R   + 
+--R            6         2      2   5        3 4     5 3  19
+--R     (7a b d  + (21a c  + 21b c)d  + 35b c d  + 7c d )x
+--R   + 
+--R      7  2 6                3  5         3   105  2 2  4        4 3   7  6 2  18
+--R     (- a d  + (42a b c + 7b )d  + (35a c  + --- b c )d  + 35b c d  + - c d )x
+--R      2                                       2                       2
+--R   + 
+--R             2         2  5            2      3   4         4      2 3  3
+--R         (21a c + 21a b )d  + (105a b c  + 35b c)d  + (35a c  + 70b c )d
+--R       + 
+--R              5 2    7
+--R         21b c d  + c d
+--R    *
+--R        17
+--R       x
+--R   + 
+--R            2   5    105  2 2         2    35  4  4            3      3 2  3
+--R         21a b d  + (--- a c  + 105a b c + -- b )d  + (140a b c  + 70b c )d
+--R                      2                     4
+--R       + 
+--R               5   105  2 4  2       6    1  8
+--R         (21a c  + --- b c )d  + 7b c d + - c
+--R                    2                     8
+--R    *
+--R        16
+--R       x
+--R   + 
+--R           3 5        2           3  4       2 3         2 2      4   3
+--R         7a d  + (105a b c + 35a b )d  + (70a c  + 210a b c  + 35b c)d
+--R       + 
+--R                  4      3 3  2        6      2 5        7
+--R         (105a b c  + 70b c )d  + (7a c  + 21b c )d + b c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R             3    105  2 2  4        2   2         3      5  3
+--R         (35a c + --- a b )d  + (210a b c  + 140a b c + 7b )d
+--R                   2
+--R       + 
+--R          105  2 4         2 3   105  4 2  2           5      3 4        7
+--R         (--- a c  + 210a b c  + --- b c )d  + (42a b c  + 35b c )d + a c
+--R           2                      2
+--R       + 
+--R         7  2 6
+--R         - b c
+--R         2
+--R    *
+--R        14
+--R       x
+--R   + 
+--R            3   4       3 2       2 2         4  3
+--R         35a b d  + (70a c  + 210a b c + 35a b )d
+--R       + 
+--R              2   3         3 2      5   2       2 5         2 4      4 3
+--R         (210a b c  + 210a b c  + 21b c)d  + (21a c  + 105a b c  + 35b c )d
+--R       + 
+--R               6     3 5
+--R         7a b c  + 7b c
+--R    *
+--R        13
+--R       x
+--R   + 
+--R         35  4 4        3         2 3  3
+--R         -- a d  + (140a b c + 70a b )d
+--R          4
+--R       + 
+--R             3 3       2 2 2         4    7  6  2
+--R         (70a c  + 315a b c  + 105a b c + - b )d
+--R                                          2
+--R       + 
+--R              2   4         3 3      5 2     7  2 6        2 5   35  4 4
+--R         (105a b c  + 140a b c  + 21b c )d + - a c  + 21a b c  + -- b c
+--R                                             2                    4
+--R    *
+--R        12
+--R       x
+--R   + 
+--R             4       3 2  3        3   2       2 3         5  2
+--R         (35a c + 70a b )d  + (210a b c  + 210a b c + 21a b )d
+--R       + 
+--R             3 4       2 2 3         4 2     6         2   5        3 4     5 3
+--R         (35a c  + 210a b c  + 105a b c  + 7b c)d + 21a b c  + 35a b c  + 7b c
+--R    *
+--R        11
+--R       x
+--R   + 
+--R            4   3    105  4 2       3 2    105  2 4  2
+--R         35a b d  + (--- a c  + 210a b c + --- a b )d
+--R                      2                     2
+--R       + 
+--R              3   3       2 3 2        5     7       3 5   105  2 2 4        4 3
+--R         (140a b c  + 210a b c  + 42a b c + b )d + 7a c  + --- a b c  + 35a b c
+--R                                                            2
+--R       + 
+--R         7  6 2
+--R         - b c
+--R         2
+--R    *
+--R        10
+--R       x
+--R   + 
+--R           5 3        4         3 3  2
+--R         7a d  + (105a b c + 70a b )d
+--R       + 
+--R             4 3       3 2 2       2 4        6        3   4      2 3 3
+--R         (35a c  + 210a b c  + 105a b c + 7a b )d + 35a b c  + 70a b c
+--R       + 
+--R              5 2    7
+--R         21a b c  + b c
+--R    *
+--R        9
+--R       x
+--R   + 
+--R             5    105  4 2  2        4   2       3 3       2 5     35  4 4
+--R         (21a c + --- a b )d  + (105a b c  + 140a b c + 21a b )d + -- a c
+--R                   2                                                4
+--R       + 
+--R            3 2 3   105  2 4 2       6    1  8
+--R         70a b c  + --- a b c  + 7a b c + - b
+--R                     2                    8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R            5   2       5 2       4 2       3 4        4   3      3 3 2
+--R         21a b d  + (21a c  + 105a b c + 35a b )d + 35a b c  + 70a b c
+--R       + 
+--R            2 5       7
+--R         21a b c + a b
+--R    *
+--R        7
+--R       x
+--R   + 
+--R      7  6 2       5         4 3       5 3   105  4 2 2      3 4    7  2 6  6
+--R     (- a d  + (42a b c + 35a b )d + 7a c  + --- a b c  + 35a b c + - a b )x
+--R      2                                       2                     2
+--R   + 
+--R         6       5 2        5   2      4 3      3 5  5
+--R     ((7a c + 21a b )d + 21a b c  + 35a b c + 7a b )x
+--R   + 
+--R        6      7  6 2      5 2    35  4 4  4     7      6        5 3  3
+--R     (7a b d + - a c  + 21a b c + -- a b )x  + (a d + 7a b c + 7a b )x
+--R               2                   4
+--R   + 
+--R       7    7  6 2  2    7      1  8
+--R     (a c + - a b )x  + a b x + - a
+--R            2                   8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 62
+
+--S 63 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23       7   7  2 6  22       7         6     3 5  21
+--R     - d x   + c d x   + (b d  + - c d )x   + (a d  + 7b c d  + 7c d )x
+--R     8                           2
+--R   + 
+--R              7  2  6        2 5   35  4 4  20
+--R     ((7a c + - b )d  + 21b c d  + -- c d )x
+--R              2                     4
+--R   + 
+--R            6         2      2   5        3 4     5 3  19
+--R     (7a b d  + (21a c  + 21b c)d  + 35b c d  + 7c d )x
+--R   + 
+--R      7  2 6                3  5         3   105  2 2  4        4 3   7  6 2  18
+--R     (- a d  + (42a b c + 7b )d  + (35a c  + --- b c )d  + 35b c d  + - c d )x
+--R      2                                       2                       2
+--R   + 
+--R             2         2  5            2      3   4         4      2 3  3
+--R         (21a c + 21a b )d  + (105a b c  + 35b c)d  + (35a c  + 70b c )d
+--R       + 
+--R              5 2    7
+--R         21b c d  + c d
+--R    *
+--R        17
+--R       x
+--R   + 
+--R            2   5    105  2 2         2    35  4  4            3      3 2  3
+--R         21a b d  + (--- a c  + 105a b c + -- b )d  + (140a b c  + 70b c )d
+--R                      2                     4
+--R       + 
+--R               5   105  2 4  2       6    1  8
+--R         (21a c  + --- b c )d  + 7b c d + - c
+--R                    2                     8
+--R    *
+--R        16
+--R       x
+--R   + 
+--R           3 5        2           3  4       2 3         2 2      4   3
+--R         7a d  + (105a b c + 35a b )d  + (70a c  + 210a b c  + 35b c)d
+--R       + 
+--R                  4      3 3  2        6      2 5        7
+--R         (105a b c  + 70b c )d  + (7a c  + 21b c )d + b c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R             3    105  2 2  4        2   2         3      5  3
+--R         (35a c + --- a b )d  + (210a b c  + 140a b c + 7b )d
+--R                   2
+--R       + 
+--R          105  2 4         2 3   105  4 2  2           5      3 4        7
+--R         (--- a c  + 210a b c  + --- b c )d  + (42a b c  + 35b c )d + a c
+--R           2                      2
+--R       + 
+--R         7  2 6
+--R         - b c
+--R         2
+--R    *
+--R        14
+--R       x
+--R   + 
+--R            3   4       3 2       2 2         4  3
+--R         35a b d  + (70a c  + 210a b c + 35a b )d
+--R       + 
+--R              2   3         3 2      5   2       2 5         2 4      4 3
+--R         (210a b c  + 210a b c  + 21b c)d  + (21a c  + 105a b c  + 35b c )d
+--R       + 
+--R               6     3 5
+--R         7a b c  + 7b c
+--R    *
+--R        13
+--R       x
+--R   + 
+--R         35  4 4        3         2 3  3
+--R         -- a d  + (140a b c + 70a b )d
+--R          4
+--R       + 
+--R             3 3       2 2 2         4    7  6  2
+--R         (70a c  + 315a b c  + 105a b c + - b )d
+--R                                          2
+--R       + 
+--R              2   4         3 3      5 2     7  2 6        2 5   35  4 4
+--R         (105a b c  + 140a b c  + 21b c )d + - a c  + 21a b c  + -- b c
+--R                                             2                    4
+--R    *
+--R        12
+--R       x
+--R   + 
+--R             4       3 2  3        3   2       2 3         5  2
+--R         (35a c + 70a b )d  + (210a b c  + 210a b c + 21a b )d
+--R       + 
+--R             3 4       2 2 3         4 2     6         2   5        3 4     5 3
+--R         (35a c  + 210a b c  + 105a b c  + 7b c)d + 21a b c  + 35a b c  + 7b c
+--R    *
+--R        11
+--R       x
+--R   + 
+--R            4   3    105  4 2       3 2    105  2 4  2
+--R         35a b d  + (--- a c  + 210a b c + --- a b )d
+--R                      2                     2
+--R       + 
+--R              3   3       2 3 2        5     7       3 5   105  2 2 4        4 3
+--R         (140a b c  + 210a b c  + 42a b c + b )d + 7a c  + --- a b c  + 35a b c
+--R                                                            2
+--R       + 
+--R         7  6 2
+--R         - b c
+--R         2
+--R    *
+--R        10
+--R       x
+--R   + 
+--R           5 3        4         3 3  2
+--R         7a d  + (105a b c + 70a b )d
+--R       + 
+--R             4 3       3 2 2       2 4        6        3   4      2 3 3
+--R         (35a c  + 210a b c  + 105a b c + 7a b )d + 35a b c  + 70a b c
+--R       + 
+--R              5 2    7
+--R         21a b c  + b c
+--R    *
+--R        9
+--R       x
+--R   + 
+--R             5    105  4 2  2        4   2       3 3       2 5     35  4 4
+--R         (21a c + --- a b )d  + (105a b c  + 140a b c + 21a b )d + -- a c
+--R                   2                                                4
+--R       + 
+--R            3 2 3   105  2 4 2       6    1  8
+--R         70a b c  + --- a b c  + 7a b c + - b
+--R                     2                    8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R            5   2       5 2       4 2       3 4        4   3      3 3 2
+--R         21a b d  + (21a c  + 105a b c + 35a b )d + 35a b c  + 70a b c
+--R       + 
+--R            2 5       7
+--R         21a b c + a b
+--R    *
+--R        7
+--R       x
+--R   + 
+--R      7  6 2       5         4 3       5 3   105  4 2 2      3 4    7  2 6  6
+--R     (- a d  + (42a b c + 35a b )d + 7a c  + --- a b c  + 35a b c + - a b )x
+--R      2                                       2                     2
+--R   + 
+--R         6       5 2        5   2      4 3      3 5  5
+--R     ((7a c + 21a b )d + 21a b c  + 35a b c + 7a b )x
+--R   + 
+--R        6      7  6 2      5 2    35  4 4  4     7      6        5 3  3
+--R     (7a b d + - a c  + 21a b c + -- a b )x  + (a d + 7a b c + 7a b )x
+--R               2                   4
+--R   + 
+--R       7    7  6 2  2    7
+--R     (a c + - a b )x  + a b x
+--R            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 63
+
+--S 64 of 619
+m0:=a0-r0
+--R 
+--R
+--R          1  8
+--R   (4)  - - a
+--R          8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 64
+
+--S 65 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 65
+
+)clear all
+
+--S 66 of 619
+t0:=(b+2*c*x+3*d*x^2)*(b*x+c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22         7      2 6  21            6       3 5  20
+--R     3d x   + 23c d x   + (22b d  + 77c d )x   + (147b c d  + 147c d )x
+--R   + 
+--R         2 6         2 5       4 4  19        2   5         3 4       5 3  18
+--R     (70b d  + 420b c d  + 175c d )x   + (399b c d  + 665b c d  + 133c d )x
+--R   + 
+--R          3 5       2 2 4         4 3      6 2  17
+--R     (126b d  + 945b c d  + 630b c d  + 63c d )x
+--R   + 
+--R          3   4        2 3 3         5 2      7   16
+--R     (595b c d  + 1190b c d  + 357b c d  + 17c d)x
+--R   + 
+--R          4 4        3 2 3       2 4 2         6      8  15
+--R     (140b d  + 1120b c d  + 840b c d  + 112b c d + 2c )x
+--R   + 
+--R          4   3        3 3 2       2 5         7  14
+--R     (525b c d  + 1050b c d  + 315b c d + 15b c )x
+--R   + 
+--R         5 3       4 2 2       3 4       2 6  13
+--R     (98b d  + 735b c d  + 490b c d + 49b c )x
+--R   + 
+--R          5   2       4 3       3 5  12       6 2       5 2        4 4  11
+--R     (273b c d  + 455b c d + 91b c )x   + (42b d  + 252b c d + 105b c )x
+--R   + 
+--R         6         5 3  10       7       6 2  9     7   8    8 7
+--R     (77b c d + 77b c )x   + (10b d + 35b c )x  + 9b c x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 66
+
+--S 67 of 619
+r0:=1/8*(b*x+c*x^2+d*x^3)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23       7   7  2 6  22          6     3 5  21
+--R     - d x   + c d x   + (b d  + - c d )x   + (7b c d  + 7c d )x
+--R     8                           2
+--R   + 
+--R      7  2 6        2 5   35  4 4  20       2   5        3 4     5 3  19
+--R     (- b d  + 21b c d  + -- c d )x   + (21b c d  + 35b c d  + 7c d )x
+--R      2                    4
+--R   + 
+--R        3 5   105  2 2 4        4 3   7  6 2  18
+--R     (7b d  + --- b c d  + 35b c d  + - c d )x
+--R               2                      2
+--R   + 
+--R         3   4      2 3 3        5 2    7   17
+--R     (35b c d  + 70b c d  + 21b c d  + c d)x
+--R   + 
+--R      35  4 4      3 2 3   105  2 4 2       6    1  8  16
+--R     (-- b d  + 70b c d  + --- b c d  + 7b c d + - c )x
+--R       4                    2                    8
+--R   + 
+--R         4   3      3 3 2      2 5       7  15
+--R     (35b c d  + 70b c d  + 21b c d + b c )x
+--R   + 
+--R        5 3   105  4 2 2      3 4    7  2 6  14
+--R     (7b d  + --- b c d  + 35b c d + - b c )x
+--R               2                     2
+--R   + 
+--R         5   2      4 3      3 5  13    7  6 2      5 2    35  4 4  12
+--R     (21b c d  + 35b c d + 7b c )x   + (- b d  + 21b c d + -- b c )x
+--R                                        2                   4
+--R   + 
+--R        6        5 3  11     7    7  6 2  10    7   9   1  8 8
+--R     (7b c d + 7b c )x   + (b d + - b c )x   + b c x  + - b x
+--R                                  2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 67
+
+--S 68 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23       7   7  2 6  22          6     3 5  21
+--R     - d x   + c d x   + (b d  + - c d )x   + (7b c d  + 7c d )x
+--R     8                           2
+--R   + 
+--R      7  2 6        2 5   35  4 4  20       2   5        3 4     5 3  19
+--R     (- b d  + 21b c d  + -- c d )x   + (21b c d  + 35b c d  + 7c d )x
+--R      2                    4
+--R   + 
+--R        3 5   105  2 2 4        4 3   7  6 2  18
+--R     (7b d  + --- b c d  + 35b c d  + - c d )x
+--R               2                      2
+--R   + 
+--R         3   4      2 3 3        5 2    7   17
+--R     (35b c d  + 70b c d  + 21b c d  + c d)x
+--R   + 
+--R      35  4 4      3 2 3   105  2 4 2       6    1  8  16
+--R     (-- b d  + 70b c d  + --- b c d  + 7b c d + - c )x
+--R       4                    2                    8
+--R   + 
+--R         4   3      3 3 2      2 5       7  15
+--R     (35b c d  + 70b c d  + 21b c d + b c )x
+--R   + 
+--R        5 3   105  4 2 2      3 4    7  2 6  14
+--R     (7b d  + --- b c d  + 35b c d + - b c )x
+--R               2                     2
+--R   + 
+--R         5   2      4 3      3 5  13    7  6 2      5 2    35  4 4  12
+--R     (21b c d  + 35b c d + 7b c )x   + (- b d  + 21b c d + -- b c )x
+--R                                        2                   4
+--R   + 
+--R        6        5 3  11     7    7  6 2  10    7   9   1  8 8
+--R     (7b c d + 7b c )x   + (b d + - b c )x   + b c x  + - b x
+--R                                  2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 68
+
+--S 69 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 69
+
+--S 70 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 70
+
+)clear all
+
+--S 71 of 619
+t0:=x^7*(b+c*x+d*x^2)^7*(b+2*c*x+3*d*x^2)
+--R 
+--R
+--R   (1)
+--R       8 23        7 22         7      2 6  21            6       3 5  20
+--R     3d x   + 23c d x   + (22b d  + 77c d )x   + (147b c d  + 147c d )x
+--R   + 
+--R         2 6         2 5       4 4  19        2   5         3 4       5 3  18
+--R     (70b d  + 420b c d  + 175c d )x   + (399b c d  + 665b c d  + 133c d )x
+--R   + 
+--R          3 5       2 2 4         4 3      6 2  17
+--R     (126b d  + 945b c d  + 630b c d  + 63c d )x
+--R   + 
+--R          3   4        2 3 3         5 2      7   16
+--R     (595b c d  + 1190b c d  + 357b c d  + 17c d)x
+--R   + 
+--R          4 4        3 2 3       2 4 2         6      8  15
+--R     (140b d  + 1120b c d  + 840b c d  + 112b c d + 2c )x
+--R   + 
+--R          4   3        3 3 2       2 5         7  14
+--R     (525b c d  + 1050b c d  + 315b c d + 15b c )x
+--R   + 
+--R         5 3       4 2 2       3 4       2 6  13
+--R     (98b d  + 735b c d  + 490b c d + 49b c )x
+--R   + 
+--R          5   2       4 3       3 5  12       6 2       5 2        4 4  11
+--R     (273b c d  + 455b c d + 91b c )x   + (42b d  + 252b c d + 105b c )x
+--R   + 
+--R         6         5 3  10       7       6 2  9     7   8    8 7
+--R     (77b c d + 77b c )x   + (10b d + 35b c )x  + 9b c x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 71
+
+--S 72 of 619
+r0:=1/8*x^8*(b+c*x+d*x^2)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23       7   7  2 6  22          6     3 5  21
+--R     - d x   + c d x   + (b d  + - c d )x   + (7b c d  + 7c d )x
+--R     8                           2
+--R   + 
+--R      7  2 6        2 5   35  4 4  20       2   5        3 4     5 3  19
+--R     (- b d  + 21b c d  + -- c d )x   + (21b c d  + 35b c d  + 7c d )x
+--R      2                    4
+--R   + 
+--R        3 5   105  2 2 4        4 3   7  6 2  18
+--R     (7b d  + --- b c d  + 35b c d  + - c d )x
+--R               2                      2
+--R   + 
+--R         3   4      2 3 3        5 2    7   17
+--R     (35b c d  + 70b c d  + 21b c d  + c d)x
+--R   + 
+--R      35  4 4      3 2 3   105  2 4 2       6    1  8  16
+--R     (-- b d  + 70b c d  + --- b c d  + 7b c d + - c )x
+--R       4                    2                    8
+--R   + 
+--R         4   3      3 3 2      2 5       7  15
+--R     (35b c d  + 70b c d  + 21b c d + b c )x
+--R   + 
+--R        5 3   105  4 2 2      3 4    7  2 6  14
+--R     (7b d  + --- b c d  + 35b c d + - b c )x
+--R               2                     2
+--R   + 
+--R         5   2      4 3      3 5  13    7  6 2      5 2    35  4 4  12
+--R     (21b c d  + 35b c d + 7b c )x   + (- b d  + 21b c d + -- b c )x
+--R                                        2                   4
+--R   + 
+--R        6        5 3  11     7    7  6 2  10    7   9   1  8 8
+--R     (7b c d + 7b c )x   + (b d + - b c )x   + b c x  + - b x
+--R                                  2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 72
+
+--S 73 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23       7   7  2 6  22          6     3 5  21
+--R     - d x   + c d x   + (b d  + - c d )x   + (7b c d  + 7c d )x
+--R     8                           2
+--R   + 
+--R      7  2 6        2 5   35  4 4  20       2   5        3 4     5 3  19
+--R     (- b d  + 21b c d  + -- c d )x   + (21b c d  + 35b c d  + 7c d )x
+--R      2                    4
+--R   + 
+--R        3 5   105  2 2 4        4 3   7  6 2  18
+--R     (7b d  + --- b c d  + 35b c d  + - c d )x
+--R               2                      2
+--R   + 
+--R         3   4      2 3 3        5 2    7   17
+--R     (35b c d  + 70b c d  + 21b c d  + c d)x
+--R   + 
+--R      35  4 4      3 2 3   105  2 4 2       6    1  8  16
+--R     (-- b d  + 70b c d  + --- b c d  + 7b c d + - c )x
+--R       4                    2                    8
+--R   + 
+--R         4   3      3 3 2      2 5       7  15
+--R     (35b c d  + 70b c d  + 21b c d + b c )x
+--R   + 
+--R        5 3   105  4 2 2      3 4    7  2 6  14
+--R     (7b d  + --- b c d  + 35b c d + - b c )x
+--R               2                     2
+--R   + 
+--R         5   2      4 3      3 5  13    7  6 2      5 2    35  4 4  12
+--R     (21b c d  + 35b c d + 7b c )x   + (- b d  + 21b c d + -- b c )x
+--R                                        2                   4
+--R   + 
+--R        6        5 3  11     7    7  6 2  10    7   9   1  8 8
+--R     (7b c d + 7b c )x   + (b d + - b c )x   + b c x  + - b x
+--R                                  2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 73
+
+--S 74 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 74
+
+--S 75 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 75
+
+)clear all
+
+--S 76 of 619
+t0:=(b+3*d*x^2)*(a+b*x+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 21        7 20      2 6 19           6 18
+--R     3d x   + 22b d x   + 21a d x   + 70b d x   + 133a b d x
+--R   + 
+--R         2 6       3 5  17         2 5 16        2   5       4 4  15
+--R     (63a d  + 126b d )x   + 357a b d x   + (336a b d  + 140b d )x
+--R   + 
+--R          3 5         3 4  14        2 2 4      5 3  13
+--R     (105a d  + 525a b d )x   + (735a b d  + 98b d )x
+--R   + 
+--R          3   4         4 3  12        4 4       2 3 3      6 2  11
+--R     (455a b d  + 455a b d )x   + (105a d  + 840a b d  + 42b d )x
+--R   + 
+--R          3 2 3         5 2  10        4   3       2 4 2      7   9
+--R     (770a b d  + 231a b d )x   + (350a b d  + 525a b d  + 10b d)x
+--R   + 
+--R         5 3       3 3 2        6   8        4 2 2       2 5     8  7
+--R     (63a d  + 630a b d  + 63a b d)x  + (420a b d  + 168a b d + b )x
+--R   + 
+--R          5   2       3 4        7  6       6 2       4 3       2 6  5
+--R     (147a b d  + 245a b d + 7a b )x  + (21a d  + 210a b d + 21a b )x
+--R   + 
+--R          5 2       3 5  4       6         4 4  3      7       5 3  2     6 2
+--R     (105a b d + 35a b )x  + (28a b d + 35a b )x  + (3a d + 21a b )x  + 7a b x
+--R   + 
+--R      7
+--R     a b
+--R                                                    Type: Polynomial(Integer)
+--E 76
+
+--S 77 of 619
+r0:=1/8*(a+b*x+d*x^3)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 22      7 21   7  2 6 20         6 19    7  2 6     3 5  18
+--R     - d x   + b d x   + a d x   + - b d x   + 7a b d x   + (- a d  + 7b d )x
+--R     8                             2                         2
+--R   + 
+--R          2 5 17       2   5   35  4 4  16      3 5        3 4  15
+--R     21a b d x   + (21a b d  + -- b d )x   + (7a d  + 35a b d )x
+--R                                4
+--R   + 
+--R      105  2 2 4     5 3  14       3   4        4 3  13
+--R     (--- a b d  + 7b d )x   + (35a b d  + 35a b d )x
+--R       2
+--R   + 
+--R      35  4 4      2 3 3   7  6 2  12       3 2 3        5 2  11
+--R     (-- a d  + 70a b d  + - b d )x   + (70a b d  + 21a b d )x
+--R       4                   2
+--R   + 
+--R         4   3   105  2 4 2    7   10      5 3      3 3 2       6   9
+--R     (35a b d  + --- a b d  + b d)x   + (7a d  + 70a b d  + 7a b d)x
+--R                  2
+--R   + 
+--R      105  4 2 2      2 5    1  8  8       5   2      3 4       7  7
+--R     (--- a b d  + 21a b d + - b )x  + (21a b d  + 35a b d + a b )x
+--R       2                     8
+--R   + 
+--R      7  6 2      4 3    7  2 6  6       5 2      3 5  5      6      35  4 4  4
+--R     (- a d  + 35a b d + - a b )x  + (21a b d + 7a b )x  + (7a b d + -- a b )x
+--R      2                  2                                            4
+--R   + 
+--R       7      5 3  3   7  6 2 2    7      1  8
+--R     (a d + 7a b )x  + - a b x  + a b x + - a
+--R                       2                  8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 77
+
+--S 78 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 22      7 21   7  2 6 20         6 19    7  2 6     3 5  18
+--R     - d x   + b d x   + a d x   + - b d x   + 7a b d x   + (- a d  + 7b d )x
+--R     8                             2                         2
+--R   + 
+--R          2 5 17       2   5   35  4 4  16      3 5        3 4  15
+--R     21a b d x   + (21a b d  + -- b d )x   + (7a d  + 35a b d )x
+--R                                4
+--R   + 
+--R      105  2 2 4     5 3  14       3   4        4 3  13
+--R     (--- a b d  + 7b d )x   + (35a b d  + 35a b d )x
+--R       2
+--R   + 
+--R      35  4 4      2 3 3   7  6 2  12       3 2 3        5 2  11
+--R     (-- a d  + 70a b d  + - b d )x   + (70a b d  + 21a b d )x
+--R       4                   2
+--R   + 
+--R         4   3   105  2 4 2    7   10      5 3      3 3 2       6   9
+--R     (35a b d  + --- a b d  + b d)x   + (7a d  + 70a b d  + 7a b d)x
+--R                  2
+--R   + 
+--R      105  4 2 2      2 5    1  8  8       5   2      3 4       7  7
+--R     (--- a b d  + 21a b d + - b )x  + (21a b d  + 35a b d + a b )x
+--R       2                     8
+--R   + 
+--R      7  6 2      4 3    7  2 6  6       5 2      3 5  5      6      35  4 4  4
+--R     (- a d  + 35a b d + - a b )x  + (21a b d + 7a b )x  + (7a b d + -- a b )x
+--R      2                  2                                            4
+--R   + 
+--R       7      5 3  3   7  6 2 2    7
+--R     (a d + 7a b )x  + - a b x  + a b x
+--R                       2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 78
+
+--S 79 of 619
+m0:=a0-r0
+--R 
+--R
+--R          1  8
+--R   (4)  - - a
+--R          8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 79
+
+--S 80 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 80
+
+)clear all
+
+--S 81 of 619
+t0:=x^7*(b+d*x^2)^7*(b+3*d*x^2)
+--R 
+--R
+--R   (1)
+--R       8 23        7 21      2 6 19       3 5 17       4 4 15      5 3 13
+--R     3d x   + 22b d x   + 70b d x   + 126b d x   + 140b d x   + 98b d x
+--R   + 
+--R        6 2 11      7   9    8 7
+--R     42b d x   + 10b d x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 81
+
+--S 82 of 619
+r0:=1/8*x^8*(b+d*x^2)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 22   7  2 6 20     3 5 18   35  4 4 16     5 3 14
+--R     - d x   + b d x   + - b d x   + 7b d x   + -- b d x   + 7b d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 12    7   10   1  8 8
+--R     - b d x   + b d x   + - b x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 82
+
+--S 83 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 22   7  2 6 20     3 5 18   35  4 4 16     5 3 14
+--R     - d x   + b d x   + - b d x   + 7b d x   + -- b d x   + 7b d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 12    7   10   1  8 8
+--R     - b d x   + b d x   + - b x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 83
+
+--S 84 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 84
+
+--S 85 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 85
+
+)clear all
+
+--S 86 of 619
+t0:=(b+3*d*x^2)*(b*x+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 21      2 6 19       3 5 17       4 4 15      5 3 13
+--R     3d x   + 22b d x   + 70b d x   + 126b d x   + 140b d x   + 98b d x
+--R   + 
+--R        6 2 11      7   9    8 7
+--R     42b d x   + 10b d x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 86
+
+--S 87 of 619
+r0:=1/8*x^8*(b+d*x^2)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 22   7  2 6 20     3 5 18   35  4 4 16     5 3 14
+--R     - d x   + b d x   + - b d x   + 7b d x   + -- b d x   + 7b d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 12    7   10   1  8 8
+--R     - b d x   + b d x   + - b x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 87
+
+--S 88 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 22   7  2 6 20     3 5 18   35  4 4 16     5 3 14
+--R     - d x   + b d x   + - b d x   + 7b d x   + -- b d x   + 7b d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 12    7   10   1  8 8
+--R     - b d x   + b d x   + - b x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 88
+
+--S 89 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 89
+
+--S 90 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 90
+
+)clear all
+
+--S 91 of 619
+t0:=(2*c*x+3*d*x^2)*(a+c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21         7       3 5  20
+--R     3d x   + 23c d x   + 77c d x   + (21a d  + 147c d )x
+--R   + 
+--R              6       4 4  19          2 5       5 3  18
+--R     (140a c d  + 175c d )x   + (399a c d  + 133c d )x
+--R   + 
+--R         2 6         3 4      6 2  17        2   5         4 3      7   16
+--R     (63a d  + 630a c d  + 63c d )x   + (357a c d  + 595a c d  + 17c d)x
+--R   + 
+--R          2 2 4         5 2     8  15        3 5        2 3 3         6   14
+--R     (840a c d  + 336a c d  + 2c )x   + (105a d  + 1050a c d  + 105a c d)x
+--R   + 
+--R          3   4       2 4 2        7  13        3 2 3       2 5   12
+--R     (490a c d  + 735a c d  + 14a c )x   + (910a c d  + 273a c d)x
+--R   + 
+--R          4 4       3 3 2      2 6  11        4   3       3 4   10
+--R     (105a d  + 840a c d  + 42a c )x   + (385a c d  + 385a c d)x
+--R   + 
+--R          4 2 2      3 5  9       5 3       4 3   8        5   2      4 4  7
+--R     (525a c d  + 70a c )x  + (63a d  + 315a c d)x  + (168a c d  + 70a c )x
+--R   + 
+--R       5 2   6       6 2      5 3  5      6     4      6 2 3     7   2     7
+--R   147a c d x  + (21a d  + 42a c )x  + 35a c d x  + 14a c x  + 3a d x  + 2a c x
+--R                                                    Type: Polynomial(Integer)
+--E 91
+
+--S 92 of 619
+r0:=1/8*(a+c*x^2+d*x^3)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22       7     3 5  21          6   35  4 4  20
+--R     - d x   + c d x   + - c d x   + (a d  + 7c d )x   + (7a c d  + -- c d )x
+--R     8                   2                                           4
+--R   + 
+--R           2 5     5 3  19    7  2 6        3 4   7  6 2  18
+--R     (21a c d  + 7c d )x   + (- a d  + 35a c d  + - c d )x
+--R                              2                   2
+--R   + 
+--R         2   5        4 3    7   17    105  2 2 4        5 2   1  8  16
+--R     (21a c d  + 35a c d  + c d)x   + (--- a c d  + 21a c d  + - c )x
+--R                                        2                      8
+--R   + 
+--R        3 5      2 3 3       6   15       3   4   105  2 4 2      7  14
+--R     (7a d  + 70a c d  + 7a c d)x   + (35a c d  + --- a c d  + a c )x
+--R                                                   2
+--R   + 
+--R         3 2 3      2 5   13    35  4 4      3 3 2   7  2 6  12
+--R     (70a c d  + 21a c d)x   + (-- a d  + 70a c d  + - a c )x
+--R                                 4                   2
+--R   + 
+--R         4   3      3 4   11    105  4 2 2     3 5  10      5 3      4 3   9
+--R     (35a c d  + 35a c d)x   + (--- a c d  + 7a c )x   + (7a d  + 35a c d)x
+--R                                 2
+--R   + 
+--R         5   2   35  4 4  8      5 2   7    7  6 2     5 3  6     6     5
+--R     (21a c d  + -- a c )x  + 21a c d x  + (- a d  + 7a c )x  + 7a c d x
+--R                  4                         2
+--R   + 
+--R     7  6 2 4    7   3    7   2   1  8
+--R     - a c x  + a d x  + a c x  + - a
+--R     2                            8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 92
+
+--S 93 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23   7  2 6 22       7     3 5  21          6   35  4 4  20
+--R     - d x   + c d x   + - c d x   + (a d  + 7c d )x   + (7a c d  + -- c d )x
+--R     8                   2                                           4
+--R   + 
+--R           2 5     5 3  19    7  2 6        3 4   7  6 2  18
+--R     (21a c d  + 7c d )x   + (- a d  + 35a c d  + - c d )x
+--R                              2                   2
+--R   + 
+--R         2   5        4 3    7   17    105  2 2 4        5 2   1  8  16
+--R     (21a c d  + 35a c d  + c d)x   + (--- a c d  + 21a c d  + - c )x
+--R                                        2                      8
+--R   + 
+--R        3 5      2 3 3       6   15       3   4   105  2 4 2      7  14
+--R     (7a d  + 70a c d  + 7a c d)x   + (35a c d  + --- a c d  + a c )x
+--R                                                   2
+--R   + 
+--R         3 2 3      2 5   13    35  4 4      3 3 2   7  2 6  12
+--R     (70a c d  + 21a c d)x   + (-- a d  + 70a c d  + - a c )x
+--R                                 4                   2
+--R   + 
+--R         4   3      3 4   11    105  4 2 2     3 5  10      5 3      4 3   9
+--R     (35a c d  + 35a c d)x   + (--- a c d  + 7a c )x   + (7a d  + 35a c d)x
+--R                                 2
+--R   + 
+--R         5   2   35  4 4  8      5 2   7    7  6 2     5 3  6     6     5
+--R     (21a c d  + -- a c )x  + 21a c d x  + (- a d  + 7a c )x  + 7a c d x
+--R                  4                         2
+--R   + 
+--R     7  6 2 4    7   3    7   2
+--R     - a c x  + a d x  + a c x
+--R     2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 93
+
+--S 94 of 619
+m0:=a0-r0
+--R 
+--R
+--R          1  8
+--R   (4)  - - a
+--R          8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 94
+
+--S 95 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 95
+
+)clear all
+
+--S 96 of 619
+t0:=(2*c*x+3*d*x^2)*(c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 96
+
+--S 97 of 619
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 97
+
+--S 98 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 98
+
+--S 99 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 99
+
+--S 100 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 100
+
+)clear all
+
+--S 101 of 619
+t0:=x^7*(c*x+d*x^2)^7*(2*c*x+3*d*x^2)
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 101
+
+--S 102 of 619
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 102
+
+--S 103 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 103
+
+--S 104 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 104
+
+--S 105 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 105
+
+)clear all
+
+--S 106 of 619
+t0:=x^14*(c+d*x)^7*(2*c*x+3*d*x^2)
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 106
+
+--S 107 of 619
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 107
+
+--S 108 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 108
+
+--S 109 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 109
+
+--S 110 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 110
+
+)clear all
+
+--S 111 of 619
+t0:=x*(2*c+3*d*x)*(a+c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21         7       3 5  20
+--R     3d x   + 23c d x   + 77c d x   + (21a d  + 147c d )x
+--R   + 
+--R              6       4 4  19          2 5       5 3  18
+--R     (140a c d  + 175c d )x   + (399a c d  + 133c d )x
+--R   + 
+--R         2 6         3 4      6 2  17        2   5         4 3      7   16
+--R     (63a d  + 630a c d  + 63c d )x   + (357a c d  + 595a c d  + 17c d)x
+--R   + 
+--R          2 2 4         5 2     8  15        3 5        2 3 3         6   14
+--R     (840a c d  + 336a c d  + 2c )x   + (105a d  + 1050a c d  + 105a c d)x
+--R   + 
+--R          3   4       2 4 2        7  13        3 2 3       2 5   12
+--R     (490a c d  + 735a c d  + 14a c )x   + (910a c d  + 273a c d)x
+--R   + 
+--R          4 4       3 3 2      2 6  11        4   3       3 4   10
+--R     (105a d  + 840a c d  + 42a c )x   + (385a c d  + 385a c d)x
+--R   + 
+--R          4 2 2      3 5  9       5 3       4 3   8        5   2      4 4  7
+--R     (525a c d  + 70a c )x  + (63a d  + 315a c d)x  + (168a c d  + 70a c )x
+--R   + 
+--R       5 2   6       6 2      5 3  5      6     4      6 2 3     7   2     7
+--R   147a c d x  + (21a d  + 42a c )x  + 35a c d x  + 14a c x  + 3a d x  + 2a c x
+--R                                                    Type: Polynomial(Integer)
+--E 111
+
+--S 112 of 619
+r0:=1/8*(a+c*x^2+d*x^3)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22       7     3 5  21          6   35  4 4  20
+--R     - d x   + c d x   + - c d x   + (a d  + 7c d )x   + (7a c d  + -- c d )x
+--R     8                   2                                           4
+--R   + 
+--R           2 5     5 3  19    7  2 6        3 4   7  6 2  18
+--R     (21a c d  + 7c d )x   + (- a d  + 35a c d  + - c d )x
+--R                              2                   2
+--R   + 
+--R         2   5        4 3    7   17    105  2 2 4        5 2   1  8  16
+--R     (21a c d  + 35a c d  + c d)x   + (--- a c d  + 21a c d  + - c )x
+--R                                        2                      8
+--R   + 
+--R        3 5      2 3 3       6   15       3   4   105  2 4 2      7  14
+--R     (7a d  + 70a c d  + 7a c d)x   + (35a c d  + --- a c d  + a c )x
+--R                                                   2
+--R   + 
+--R         3 2 3      2 5   13    35  4 4      3 3 2   7  2 6  12
+--R     (70a c d  + 21a c d)x   + (-- a d  + 70a c d  + - a c )x
+--R                                 4                   2
+--R   + 
+--R         4   3      3 4   11    105  4 2 2     3 5  10      5 3      4 3   9
+--R     (35a c d  + 35a c d)x   + (--- a c d  + 7a c )x   + (7a d  + 35a c d)x
+--R                                 2
+--R   + 
+--R         5   2   35  4 4  8      5 2   7    7  6 2     5 3  6     6     5
+--R     (21a c d  + -- a c )x  + 21a c d x  + (- a d  + 7a c )x  + 7a c d x
+--R                  4                         2
+--R   + 
+--R     7  6 2 4    7   3    7   2   1  8
+--R     - a c x  + a d x  + a c x  + - a
+--R     2                            8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 112
+
+--S 113 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23   7  2 6 22       7     3 5  21          6   35  4 4  20
+--R     - d x   + c d x   + - c d x   + (a d  + 7c d )x   + (7a c d  + -- c d )x
+--R     8                   2                                           4
+--R   + 
+--R           2 5     5 3  19    7  2 6        3 4   7  6 2  18
+--R     (21a c d  + 7c d )x   + (- a d  + 35a c d  + - c d )x
+--R                              2                   2
+--R   + 
+--R         2   5        4 3    7   17    105  2 2 4        5 2   1  8  16
+--R     (21a c d  + 35a c d  + c d)x   + (--- a c d  + 21a c d  + - c )x
+--R                                        2                      8
+--R   + 
+--R        3 5      2 3 3       6   15       3   4   105  2 4 2      7  14
+--R     (7a d  + 70a c d  + 7a c d)x   + (35a c d  + --- a c d  + a c )x
+--R                                                   2
+--R   + 
+--R         3 2 3      2 5   13    35  4 4      3 3 2   7  2 6  12
+--R     (70a c d  + 21a c d)x   + (-- a d  + 70a c d  + - a c )x
+--R                                 4                   2
+--R   + 
+--R         4   3      3 4   11    105  4 2 2     3 5  10      5 3      4 3   9
+--R     (35a c d  + 35a c d)x   + (--- a c d  + 7a c )x   + (7a d  + 35a c d)x
+--R                                 2
+--R   + 
+--R         5   2   35  4 4  8      5 2   7    7  6 2     5 3  6     6     5
+--R     (21a c d  + -- a c )x  + 21a c d x  + (- a d  + 7a c )x  + 7a c d x
+--R                  4                         2
+--R   + 
+--R     7  6 2 4    7   3    7   2
+--R     - a c x  + a d x  + a c x
+--R     2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 113
+
+--S 114 of 619
+m0:=a0-r0
+--R 
+--R
+--R          1  8
+--R   (4)  - - a
+--R          8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 114
+
+--S 115 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 115
+
+)clear all
+
+--S 116 of 619
+t0:=x*(2*c+3*d*x)*(c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 116
+
+--S 117 of 619
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 117
+
+--S 118 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 118
+
+--S 119 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 119
+
+--S 120 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 120
+
+)clear all
+
+--S 121 of 619
+t0:=x^8*(2*c+3*d*x)*(c*x+d*x^2)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 121
+
+--S 122 of 619
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 122
+
+--S 123 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 123
+
+--S 124 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 124
+
+--S 125 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 125
+
+)clear all
+
+--S 126 of 619
+t0:=x^15*(c+d*x)^7*(2*c+3*d*x)
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 126
+
+--S 127 of 619
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 127
+
+--S 128 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 128
+
+--S 129 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 129
+
+--S 130 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 130
+
+)clear all
+
+--S 131 of 619
+t0:=(a+b*x)*(1+(a*x+1/2*b*x^2)^4)
+--R 
+--R
+--R         1  5 9    9    4 8     2 3 7   7  3 2 6     4   5    5 4
+--R   (1)  -- b x  + -- a b x  + 2a b x  + - a b x  + 3a b x  + a x  + b x + a
+--R        16        16                    2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 131
+
+--S 132 of 619
+r0:=a*x+1/2*b*x^2+1/5*(a*x+1/2*b*x^2)^5
+--R 
+--R
+--R   (2)
+--R      1   5 10    1    4 9   1  2 3 8   1  3 2 7   1  4   6   1  5 5   1    2
+--R     --- b x   + -- a b x  + - a b x  + - a b x  + - a b x  + - a x  + - b x
+--R     160         16          4          2          2          5        2
+--R   + 
+--R     a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 132
+
+--S 133 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1   5 10    1    4 9   1  2 3 8   1  3 2 7   1  4   6   1  5 5   1    2
+--R     --- b x   + -- a b x  + - a b x  + - a b x  + - a b x  + - a x  + - b x
+--R     160         16          4          2          2          5        2
+--R   + 
+--R     a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 133
+
+--S 134 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 134
+
+--S 135 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 135
+
+)clear all
+
+--S 136 of 619
+t0:=(a+b*x)*(1+(c+a*x+1/2*b*x^2)^4)
+--R 
+--R
+--R   (1)
+--R      1  5 9    9    4 8    1  4      2 3  7    7    3    7  3 2  6
+--R     -- b x  + -- a b x  + (- b c + 2a b )x  + (- a b c + - a b )x
+--R     16        16           2                   2         2
+--R   + 
+--R      3  3 2     2 2      4   5    15    2 2      3       5  4
+--R     (- b c  + 9a b c + 3a b)x  + (-- a b c  + 10a b c + a )x
+--R      2                             2
+--R   + 
+--R        2 3      2   2     4   3          3     3 2  2       4     2 3
+--R     (2b c  + 12a b c  + 4a c)x  + (6a b c  + 6a c )x  + (b c  + 4a c  + b)x
+--R   + 
+--R        4
+--R     a c  + a
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 136
+
+--S 137 of 619
+r0:=a*x+1/2*b*x^2+1/5*(c+a*x+1/2*b*x^2)^5
+--R 
+--R
+--R   (2)
+--R      1   5 10    1    4 9     1  4    1  2 3  8    1    3    1  3 2  7
+--R     --- b x   + -- a b x  + (-- b c + - a b )x  + (- a b c + - a b )x
+--R     160         16           16       4            2         2
+--R   + 
+--R      1  3 2   3  2 2    1  4   6    3    2 2     3      1  5  5
+--R     (- b c  + - a b c + - a b)x  + (- a b c  + 2a b c + - a )x
+--R      4        2         2           2                   5
+--R   + 
+--R      1  2 3     2   2    4   4          3     3 2  3    1    4     2 3   1    2
+--R     (- b c  + 3a b c  + a c)x  + (2a b c  + 2a c )x  + (- b c  + 2a c  + - b)x
+--R      2                                                  2                2
+--R   + 
+--R         4         1  5
+--R     (a c  + a)x + - c
+--R                   5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 137
+
+--S 138 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1   5 10    1    4 9     1  4    1  2 3  8    1    3    1  3 2  7
+--R     --- b x   + -- a b x  + (-- b c + - a b )x  + (- a b c + - a b )x
+--R     160         16           16       4            2         2
+--R   + 
+--R      1  3 2   3  2 2    1  4   6    3    2 2     3      1  5  5
+--R     (- b c  + - a b c + - a b)x  + (- a b c  + 2a b c + - a )x
+--R      4        2         2           2                   5
+--R   + 
+--R      1  2 3     2   2    4   4          3     3 2  3    1    4     2 3   1    2
+--R     (- b c  + 3a b c  + a c)x  + (2a b c  + 2a c )x  + (- b c  + 2a c  + - b)x
+--R      2                                                  2                2
+--R   + 
+--R         4
+--R     (a c  + a)x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 138
+
+--S 139 of 619
+m0:=a0-r0
+--R 
+--R
+--R          1  5
+--R   (4)  - - c
+--R          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 139
+
+--S 140 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 140
+
+)clear all
+
+--S 141 of 619
+t0:=(a+b*x)*(1+(a*x+1/2*b*x^2)^n)
+--R 
+--R
+--R                     2        n
+--R                  b x  + 2a x
+--R   (1)  (b x + a)(-----------)  + b x + a
+--R                       2
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 619
+r0:=a*x+1/2*b*x^2+(a*x+1/2*b*x^2)^(1+n)/(1+n)
+--R 
+--R
+--R             2        n + 1
+--R          b x  + 2a x                   2
+--R        2(-----------)      + (b n + b)x  + (2a n + 2a)x
+--R               2
+--R   (2)  ------------------------------------------------
+--R                             2n + 2
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                2
+--R                             b x  + 2a x
+--R                       n log(-----------)
+--R            2                     2                   2
+--R        (b x  + 2a x)%e                   + (b n + b)x  + (2a n + 2a)x
+--R   (3)  --------------------------------------------------------------
+--R                                    2n + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 143
+
+--S 144 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                2
+--R                             b x  + 2a x
+--R                       n log(-----------)        2        n + 1
+--R            2                     2           b x  + 2a x
+--R        (b x  + 2a x)%e                   - 2(-----------)
+--R                                                   2
+--R   (4)  -------------------------------------------------------
+--R                                 2n + 2
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R                            2
+--R                         b x  + 2a x
+--R                   n log(-----------)                  2        n
+--R                              2                     b x  + 2a x
+--R   (5)  (b x + a)%e                   + (- b x - a)(-----------)
+--R                                                         2
+--R                                                    Type: Expression(Integer)
+--E 145
+
+)clear all
+
+--S 146 of 619
+t0:=(a+b*x)*(1+(c+a*x+1/2*b*x^2)^n)
+--R 
+--R
+--R                     2             n
+--R                  b x  + 2a x + 2c
+--R   (1)  (b x + a)(----------------)  + b x + a
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 619
+r0:=a*x+1/2*b*x^2+(c+a*x+1/2*b*x^2)^(1+n)/(1+n)
+--R 
+--R
+--R             2             n + 1
+--R          b x  + 2a x + 2c                   2
+--R        2(----------------)      + (b n + b)x  + (2a n + 2a)x
+--R                  2
+--R   (2)  -----------------------------------------------------
+--R                                2n + 2
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                2
+--R                             b x  + 2a x + 2c
+--R                       n log(----------------)
+--R       2                             2                     2
+--R   (b x  + 2a x + 2c)%e                        + (b n + b)x  + (2a n + 2a)x
+--R   ------------------------------------------------------------------------
+--R                                    2n + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 148
+
+--S 149 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                     2
+--R                                  b x  + 2a x + 2c
+--R                            n log(----------------)        2             n + 1
+--R            2                             2             b x  + 2a x + 2c
+--R        (b x  + 2a x + 2c)%e                        - 2(----------------)
+--R                                                                2
+--R   (4)  ----------------------------------------------------------------------
+--R                                        2n + 2
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R                            2
+--R                         b x  + 2a x + 2c
+--R                   n log(----------------)                  2             n
+--R                                 2                       b x  + 2a x + 2c
+--R   (5)  (b x + a)%e                        + (- b x - a)(----------------)
+--R                                                                 2
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 619
+t0:=(a+c*x^2)*(1+(a*x+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    16    5 15   35  2 4 13   40  3 3 11   25  4 2 9   8  5   7
+--R     --- c x   + --- a c x   + -- a c x   + -- a c x   + -- a c x  + - a c x
+--R     243         243           81           27            9          3
+--R   + 
+--R      6 5      2
+--R     a x  + c x  + a
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 151
+
+--S 152 of 619
+r0:=a*x+1/3*c*x^3+1/6*(a*x+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 16    5   2 4 14   10  3 3 12    5  4 2 10   1  5   8
+--R     ---- c x   + --- a c x   + --- a c x   + -- a c x   + -- a c x   + - a c x
+--R     4374         243           162           81           18           3
+--R   + 
+--R     1  6 6   1    3
+--R     - a x  + - c x  + a x
+--R     6        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 152
+
+--S 153 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       1   6 18    1     5 16    5   2 4 14   10  3 3 12    5  4 2 10   1  5   8
+--R     ---- c x   + --- a c x   + --- a c x   + -- a c x   + -- a c x   + - a c x
+--R     4374         243           162           81           18           3
+--R   + 
+--R     1  6 6   1    3
+--R     - a x  + - c x  + a x
+--R     6        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 153
+
+--S 154 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 154
+
+--S 155 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 155
+
+)clear all
+
+--S 156 of 619
+t0:=(a+c*x^2)*(1+(d+a*x+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    16    5 15    5  5   14   35  2 4 13   65    4   12
+--R     --- c x   + --- a c x   + -- c d x   + -- a c x   + -- a c d x
+--R     243         243           81           81           81
+--R   + 
+--R      10  4 2   40  3 3  11   110  2 3   10    100    3 2   25  4 2  9
+--R     (-- c d  + -- a c )x   + --- a c d x   + (--- a c d  + -- a c )x
+--R      27        27             27               27           9
+--R   + 
+--R      10  3 3      3 2   8    40  2 2 2   8  5   7    70    2 3   35  4     6
+--R     (-- c d  + 10a c d)x  + (-- a c d  + - a c)x  + (-- a c d  + -- a c d)x
+--R       9                       3          3            9           3
+--R   + 
+--R      5  2 4      3   2    6  5    50  2   3     5   4    20      4      4 2  3
+--R     (- c d  + 20a c d  + a )x  + (-- a c d  + 5a d)x  + (-- a c d  + 10a d )x
+--R      3                             3                      3
+--R   + 
+--R         5      3 3      2     2 4       5
+--R     (c d  + 10a d  + c)x  + 5a d x + a d  + a
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 156
+
+--S 157 of 619
+r0:=a*x+1/3*c*x^3+1/6*(d+a*x+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 16    1   5   15    5   2 4 14    5    4   13
+--R     ---- c x   + --- a c x   + --- c d x   + --- a c x   + -- a c d x
+--R     4374         243           243           162           81
+--R   + 
+--R       5   4 2   10  3 3  12   10  2 3   11    10    3 2    5  4 2  10
+--R     (--- c d  + -- a c )x   + -- a c d x   + (-- a c d  + -- a c )x
+--R      162        81            27              27          18
+--R   + 
+--R      10  3 3   10  3 2   9    5  2 2 2   1  5   8    10    2 3   5  4     7
+--R     (-- c d  + -- a c d)x  + (- a c d  + - a c)x  + (-- a c d  + - a c d)x
+--R      81         9             3          3            9          3
+--R   + 
+--R       5  2 4   10  3   2   1  6  6    10  2   3    5   5
+--R     (-- c d  + -- a c d  + - a )x  + (-- a c d  + a d)x
+--R      18         3          6           3
+--R   + 
+--R      5      4   5  4 2  4    1    5   10  3 3   1    3   5  2 4 2       5
+--R     (- a c d  + - a d )x  + (- c d  + -- a d  + - c)x  + - a d x  + (a d  + a)x
+--R      3          2            3         3        3        2
+--R   + 
+--R     1  6
+--R     - d
+--R     6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 157
+
+--S 158 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       1   6 18    1     5 16    1   5   15    5   2 4 14    5    4   13
+--R     ---- c x   + --- a c x   + --- c d x   + --- a c x   + -- a c d x
+--R     4374         243           243           162           81
+--R   + 
+--R       5   4 2   10  3 3  12   10  2 3   11    10    3 2    5  4 2  10
+--R     (--- c d  + -- a c )x   + -- a c d x   + (-- a c d  + -- a c )x
+--R      162        81            27              27          18
+--R   + 
+--R      10  3 3   10  3 2   9    5  2 2 2   1  5   8    10    2 3   5  4     7
+--R     (-- c d  + -- a c d)x  + (- a c d  + - a c)x  + (-- a c d  + - a c d)x
+--R      81         9             3          3            9          3
+--R   + 
+--R       5  2 4   10  3   2   1  6  6    10  2   3    5   5
+--R     (-- c d  + -- a c d  + - a )x  + (-- a c d  + a d)x
+--R      18         3          6           3
+--R   + 
+--R    5      4   5  4 2  4    1    5   10  3 3   1    3   5  2 4 2       5
+--R   (- a c d  + - a d )x  + (- c d  + -- a d  + - c)x  + - a d x  + (a d  + a)x
+--R    3          2            3         3        3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 158
+
+--S 159 of 619
+m0:=a0-r0
+--R 
+--R
+--R          1  6
+--R   (4)  - - d
+--R          6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 159
+
+--S 160 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 160
+
+)clear all
+
+--S 161 of 619
+t0:=(b*x+c*x^2)*(1+(1/2*b*x^2+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    17    5 16   10  2 4 15    25  3 3 14    35  4 2 13
+--R     --- c x   + --- b c x   + -- b c x   + --- b c x   + --- b c x
+--R     243         486           81           108           144
+--R   + 
+--R     13  5   12    1  6 11      2
+--R     -- b c x   + -- b x   + c x  + b x
+--R     96           32
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 161
+
+--S 162 of 619
+r0:=1/2*b*x^2+1/3*c*x^3+1/6*(1/2*b*x^2+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 17    5   2 4 16    5   3 3 15    5   4 2 14
+--R     ---- c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R     4374         486           648           324           288
+--R   + 
+--R      1  5   13    1   6 12   1    3   1    2
+--R     -- b c x   + --- b x   + - c x  + - b x
+--R     96           384         3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 162
+
+--S 163 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       1   6 18    1     5 17    5   2 4 16    5   3 3 15    5   4 2 14
+--R     ---- c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R     4374         486           648           324           288
+--R   + 
+--R      1  5   13    1   6 12   1    3   1    2
+--R     -- b c x   + --- b x   + - c x  + - b x
+--R     96           384         3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 163
+
+--S 164 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 164
+
+--S 165 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 165
+
+)clear all
+
+--S 166 of 619
+t0:=(b*x+c*x^2)*(1+(d+1/2*b*x^2+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    17    5 16   10  2 4 15     5  5     25  3 3  14
+--R     --- c x   + --- b c x   + -- b c x   + (-- c d + --- b c )x
+--R     243         486           81            81       108
+--R   + 
+--R      35    4     35  4 2  13    65  2 3    13  5   12
+--R     (-- b c d + --- b c )x   + (-- b c d + -- b c)x
+--R      81         144             54         96
+--R   + 
+--R      10  4 2   5  3 2     1  6  11    55    3 2   55  4     10
+--R     (-- c d  + - b c d + -- b )x   + (-- b c d  + -- b c d)x
+--R      27        3         32           27          48
+--R   + 
+--R      25  2 2 2    5  5   9    10  3 3   15  3   2  8    40    2 3   5  4 2  7
+--R     (-- b c d  + -- b d)x  + (-- c d  + -- b c d )x  + (-- b c d  + - b d )x
+--R       6          16            9         4               9          4
+--R   + 
+--R     35  2   3 6    5  2 4   5  3 3  5   25      4 4   5  2 4 3       5      2
+--R     -- b c d x  + (- c d  + - b d )x  + -- b c d x  + - b d x  + (c d  + c)x
+--R      6             3        2            6            2
+--R   + 
+--R         5
+--R     (b d  + b)x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 166
+
+--S 167 of 619
+r0:=1/2*b*x^2+1/3*c*x^3+1/6*(d+1/2*b*x^2+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 17    5   2 4 16     1   5     5   3 3  15
+--R     ---- c x   + --- b c x   + --- b c x   + (--- c d + --- b c )x
+--R     4374         486           648            243       324
+--R   + 
+--R       5     4     5   4 2  14     5  2 3     1  5   13
+--R     (--- b c d + --- b c )x   + (-- b c d + -- b c)x
+--R      162         288             54         96
+--R   + 
+--R       5   4 2    5  3 2     1   6  12     5    3 2    5  4     11
+--R     (--- c d  + -- b c d + --- b )x   + (-- b c d  + -- b c d)x
+--R      162        36         384           27          48
+--R   + 
+--R       5  2 2 2    1  5   10    10  3 3    5  3   2  9    5    2 3    5  4 2  8
+--R     (-- b c d  + -- b d)x   + (-- c d  + -- b c d )x  + (- b c d  + -- b d )x
+--R      12          32            81        12              9          32
+--R   + 
+--R     5  2   3 7     5  2 4    5  3 3  6   5      4 5   5  2 4 4
+--R     - b c d x  + (-- c d  + -- b d )x  + - b c d x  + - b d x
+--R     6             18        12           6            8
+--R   + 
+--R      1    5   1    3    1    5   1    2   1  6
+--R     (- c d  + - c)x  + (- b d  + - b)x  + - d
+--R      3        3         2        2        6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 167
+
+--S 168 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       1   6 18    1     5 17    5   2 4 16     1   5     5   3 3  15
+--R     ---- c x   + --- b c x   + --- b c x   + (--- c d + --- b c )x
+--R     4374         486           648            243       324
+--R   + 
+--R       5     4     5   4 2  14     5  2 3     1  5   13
+--R     (--- b c d + --- b c )x   + (-- b c d + -- b c)x
+--R      162         288             54         96
+--R   + 
+--R       5   4 2    5  3 2     1   6  12     5    3 2    5  4     11
+--R     (--- c d  + -- b c d + --- b )x   + (-- b c d  + -- b c d)x
+--R      162        36         384           27          48
+--R   + 
+--R       5  2 2 2    1  5   10    10  3 3    5  3   2  9    5    2 3    5  4 2  8
+--R     (-- b c d  + -- b d)x   + (-- c d  + -- b c d )x  + (- b c d  + -- b d )x
+--R      12          32            81        12              9          32
+--R   + 
+--R     5  2   3 7     5  2 4    5  3 3  6   5      4 5   5  2 4 4
+--R     - b c d x  + (-- c d  + -- b d )x  + - b c d x  + - b d x
+--R     6             18        12           6            8
+--R   + 
+--R      1    5   1    3    1    5   1    2
+--R     (- c d  + - c)x  + (- b d  + - b)x
+--R      3        3         2        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 168
+
+--S 169 of 619
+m0:=a0-r0
+--R 
+--R
+--R          1  6
+--R   (4)  - - d
+--R          6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 169
+
+--S 170 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 170
+
+)clear all
+
+--S 171 of 619
+t0:=(a+b*x+c*x^2)*(1+(a*x+1/2*b*x^2+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    17    5 16     16    5   10  2 4  15
+--R     --- c x   + --- b c x   + (--- a c  + -- b c )x
+--R     243         486            243        81
+--R   + 
+--R      25      4    25  3 3  14    35  2 4   35    2 3    35  4 2  13
+--R     (-- a b c  + --- b c )x   + (-- a c  + -- a b c  + --- b c )x
+--R      54          108             81        27          144
+--R   + 
+--R      65  2   3   65    3 2   13  5   12
+--R     (-- a b c  + -- a b c  + -- b c)x
+--R      27          36          96
+--R   + 
+--R      40  3 3     2 2 2   5    4     1  6  11
+--R     (-- a c  + 5a b c  + - a b c + -- b )x
+--R      27                  4         32
+--R   + 
+--R      55  3   2   55  2 3    11    5  10    25  4 2   25  3 2    25  2 4  9
+--R     (-- a b c  + -- a b c + -- a b )x   + (-- a c  + -- a b c + -- a b )x
+--R       9          12         32              9         3         16
+--R   + 
+--R    15  4      15  3 3  8    8  5      4 2  7   7  5   6    6 5      2
+--R   (-- a b c + -- a b )x  + (- a c + 5a b )x  + - a b x  + a x  + c x  + b x + a
+--R     2          4            3                  2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 171
+
+--S 172 of 619
+r0:=a*x+1/2*b*x^2+1/3*c*x^3+1/6*(a*x+1/2*b*x^2+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 17     1     5    5   2 4  16
+--R     ---- c x   + --- b c x   + (--- a c  + --- b c )x
+--R     4374         486            243        648
+--R   + 
+--R       5       4    5   3 3  15     5   2 4    5    2 3    5   4 2  14
+--R     (--- a b c  + --- b c )x   + (--- a c  + -- a b c  + --- b c )x
+--R      162          324             162        54          288
+--R   + 
+--R       5  2   3    5    3 2    1  5   13
+--R     (-- a b c  + -- a b c  + -- b c)x
+--R      27          36          96
+--R   + 
+--R      10  3 3    5  2 2 2    5    4     1   6  12
+--R     (-- a c  + -- a b c  + -- a b c + --- b )x
+--R      81        12          48         384
+--R   + 
+--R      5  3   2    5  2 3     1    5  11     5  4 2   5  3 2     5  2 4  10
+--R     (- a b c  + -- a b c + -- a b )x   + (-- a c  + - a b c + -- a b )x
+--R      9          12         32             18        6         32
+--R   + 
+--R      5  4       5  3 3  9    1  5    5  4 2  8   1  5   7   1  6 6   1    3
+--R     (- a b c + -- a b )x  + (- a c + - a b )x  + - a b x  + - a x  + - c x
+--R      6         12            3       8           2          6        3
+--R   + 
+--R     1    2
+--R     - b x  + a x
+--R     2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 172
+
+--S 173 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       1   6 18    1     5 17     1     5    5   2 4  16
+--R     ---- c x   + --- b c x   + (--- a c  + --- b c )x
+--R     4374         486            243        648
+--R   + 
+--R       5       4    5   3 3  15     5   2 4    5    2 3    5   4 2  14
+--R     (--- a b c  + --- b c )x   + (--- a c  + -- a b c  + --- b c )x
+--R      162          324             162        54          288
+--R   + 
+--R       5  2   3    5    3 2    1  5   13
+--R     (-- a b c  + -- a b c  + -- b c)x
+--R      27          36          96
+--R   + 
+--R      10  3 3    5  2 2 2    5    4     1   6  12
+--R     (-- a c  + -- a b c  + -- a b c + --- b )x
+--R      81        12          48         384
+--R   + 
+--R      5  3   2    5  2 3     1    5  11     5  4 2   5  3 2     5  2 4  10
+--R     (- a b c  + -- a b c + -- a b )x   + (-- a c  + - a b c + -- a b )x
+--R      9          12         32             18        6         32
+--R   + 
+--R      5  4       5  3 3  9    1  5    5  4 2  8   1  5   7   1  6 6   1    3
+--R     (- a b c + -- a b )x  + (- a c + - a b )x  + - a b x  + - a x  + - c x
+--R      6         12            3       8           2          6        3
+--R   + 
+--R     1    2
+--R     - b x  + a x
+--R     2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 173
+
+--S 174 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 174
+
+--S 175 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 175
+
+)clear all
+
+--S 176 of 619
+t0:=(a+b*x+c*x^2)*(1+(d+a*x+1/2*b*x^2+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    17    5 16     16    5   10  2 4  15
+--R     --- c x   + --- b c x   + (--- a c  + -- b c )x
+--R     243         486            243        81
+--R   + 
+--R       5  5    25      4    25  3 3  14
+--R     (-- c d + -- a b c  + --- b c )x
+--R      81       54          108
+--R   + 
+--R      35    4    35  2 4   35    2 3    35  4 2  13
+--R     (-- b c d + -- a c  + -- a b c  + --- b c )x
+--R      81         81        27          144
+--R   + 
+--R       65    4   65  2 3     65  2   3   65    3 2   13  5   12
+--R     ((-- a c  + -- b c )d + -- a b c  + -- a b c  + -- b c)x
+--R       81        54          27          36          96
+--R   + 
+--R      10  4 2    40      3   5  3 2     40  3 3     2 2 2   5    4     1  6  11
+--R     (-- c d  + (-- a b c  + - b c )d + -- a c  + 5a b c  + - a b c + -- b )x
+--R      27          9          3          27                  4         32
+--R   + 
+--R         55    3 2    110  2 3   55    2 2   55  4      55  3   2   55  2 3
+--R         -- b c d  + (--- a c  + -- a b c  + -- b c)d + -- a b c  + -- a b c
+--R         27            27         6          48          9          12
+--R       + 
+--R         11    5
+--R         -- a b
+--R         32
+--R    *
+--R        10
+--R       x
+--R   + 
+--R          100    3   25  2 2  2    50  2   2   25    3     5  5     25  4 2
+--R         (--- a c  + -- b c )d  + (-- a b c  + -- a b c + -- b )d + -- a c
+--R           27         6             3           3         16         9
+--R       + 
+--R         25  3 2    25  2 4
+--R         -- a b c + -- a b
+--R          3         16
+--R    *
+--R        9
+--R       x
+--R   + 
+--R         10  3 3           2   15  3   2       3 2   45  2 2    45    4
+--R         -- c d  + (15a b c  + -- b c)d  + (10a c  + -- a b c + -- a b )d
+--R          9                     4                     2         16
+--R       + 
+--R         15  4      15  3 3
+--R         -- a b c + -- a b
+--R          2          4
+--R    *
+--R        8
+--R       x
+--R   + 
+--R         40    2 3    40  2 2        2    5  4  2    80  3         2 3     8  5
+--R         -- b c d  + (-- a c  + 20a b c + - b )d  + (-- a b c + 10a b )d + - a c
+--R          9            3                  4           3                    3
+--R       + 
+--R           4 2
+--R         5a b
+--R    *
+--R        7
+--R       x
+--R   + 
+--R          70    2   35  2   3       2      35    3  2    35  4    35  3 2
+--R         (-- a c  + -- b c)d  + (35a b c + -- a b )d  + (-- a c + -- a b )d
+--R           9         6                      4             3        2
+--R       + 
+--R         7  5
+--R         - a b
+--R         2
+--R    *
+--R        6
+--R       x
+--R   + 
+--R      5  2 4              5  3  3       3    45  2 2  2      4       6  5
+--R     (- c d  + (20a b c + - b )d  + (20a c + -- a b )d  + 15a b d + a )x
+--R      3                   2                   2
+--R   + 
+--R      25      4    50  2    25    2  3      3   2     5   4
+--R     (-- b c d  + (-- a c + -- a b )d  + 25a b d  + 5a d)x
+--R       6            3        2
+--R   + 
+--R       20       5  2  4      2   3      4 2  3
+--R     ((-- a c + - b )d  + 20a b d  + 10a d )x
+--R        3       2
+--R   + 
+--R         5   15      4      3 3      2       5     2 4            5
+--R     (c d  + -- a b d  + 10a d  + c)x  + (b d  + 5a d  + b)x + a d  + a
+--R              2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 176
+
+--S 177 of 619
+r0:=a*x+1/2*b*x^2+1/3*c*x^3+1/6*(d+a*x+1/2*b*x^2+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 17     1     5    5   2 4  16
+--R     ---- c x   + --- b c x   + (--- a c  + --- b c )x
+--R     4374         486            243        648
+--R   + 
+--R       1   5     5       4    5   3 3  15
+--R     (--- c d + --- a b c  + --- b c )x
+--R      243       162          324
+--R   + 
+--R       5     4     5   2 4    5    2 3    5   4 2  14
+--R     (--- b c d + --- a c  + -- a b c  + --- b c )x
+--R      162         162        54          288
+--R   + 
+--R        5    4    5  2 3      5  2   3    5    3 2    1  5   13
+--R     ((-- a c  + -- b c )d + -- a b c  + -- a b c  + -- b c)x
+--R       81        54          27          36          96
+--R   + 
+--R          5   4 2    10      3    5  3 2     10  3 3    5  2 2 2    5    4
+--R         --- c d  + (-- a b c  + -- b c )d + -- a c  + -- a b c  + -- a b c
+--R         162         27          36          81        12          48
+--R       + 
+--R          1   6
+--R         --- b
+--R         384
+--R    *
+--R        12
+--R       x
+--R   + 
+--R          5    3 2    10  2 3   5    2 2    5  4      5  3   2    5  2 3
+--R         -- b c d  + (-- a c  + - a b c  + -- b c)d + - a b c  + -- a b c
+--R         27           27        6          48         9          12
+--R       + 
+--R          1    5
+--R         -- a b
+--R         32
+--R    *
+--R        11
+--R       x
+--R   + 
+--R          10    3    5  2 2  2    5  2   2   5    3     1  5      5  4 2
+--R         (-- a c  + -- b c )d  + (- a b c  + - a b c + -- b )d + -- a c
+--R          27        12            3          6         32        18
+--R       + 
+--R         5  3 2     5  2 4
+--R         - a b c + -- a b
+--R         6         32
+--R    *
+--R        10
+--R       x
+--R   + 
+--R         10  3 3    5      2    5  3   2    10  3 2   5  2 2     5    4
+--R         -- c d  + (- a b c  + -- b c)d  + (-- a c  + - a b c + -- a b )d
+--R         81         3          12            9        2         16
+--R       + 
+--R         5  4       5  3 3
+--R         - a b c + -- a b
+--R         6         12
+--R    *
+--R        9
+--R       x
+--R   + 
+--R         5    2 3    5  2 2   5    2     5  4  2    10  3      5  2 3     1  5
+--R         - b c d  + (- a c  + - a b c + -- b )d  + (-- a b c + - a b )d + - a c
+--R         9           3        2         32           3         4          3
+--R       + 
+--R         5  4 2
+--R         - a b
+--R         8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R       10    2   5  2   3      2      5    3  2    5  4    5  3 2     1  5   7
+--R     ((-- a c  + - b c)d  + (5a b c + - a b )d  + (- a c + - a b )d + - a b)x
+--R        9        6                    4            3       2          2
+--R   + 
+--R       5  2 4    10          5  3  3    10  3    15  2 2  2   5  4      1  6  6
+--R     (-- c d  + (-- a b c + -- b )d  + (-- a c + -- a b )d  + - a b d + - a )x
+--R      18          3         12           3        4           2         6
+--R   + 
+--R      5      4    10  2    5    2  3     3   2    5   5
+--R     (- b c d  + (-- a c + - a b )d  + 5a b d  + a d)x
+--R      6            3       2
+--R   + 
+--R       5       5  2  4     2   3   5  4 2  4
+--R     ((- a c + - b )d  + 5a b d  + - a d )x
+--R       3       8                   2
+--R   + 
+--R      1    5   5      4   10  3 3   1    3    1    5   5  2 4   1    2
+--R     (- c d  + - a b d  + -- a d  + - c)x  + (- b d  + - a d  + - b)x
+--R      3        2           3        3         2        2        2
+--R   + 
+--R         5         1  6
+--R     (a d  + a)x + - d
+--R                   6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 177
+
+--S 178 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       1   6 18    1     5 17     1     5    5   2 4  16
+--R     ---- c x   + --- b c x   + (--- a c  + --- b c )x
+--R     4374         486            243        648
+--R   + 
+--R       1   5     5       4    5   3 3  15
+--R     (--- c d + --- a b c  + --- b c )x
+--R      243       162          324
+--R   + 
+--R       5     4     5   2 4    5    2 3    5   4 2  14
+--R     (--- b c d + --- a c  + -- a b c  + --- b c )x
+--R      162         162        54          288
+--R   + 
+--R        5    4    5  2 3      5  2   3    5    3 2    1  5   13
+--R     ((-- a c  + -- b c )d + -- a b c  + -- a b c  + -- b c)x
+--R       81        54          27          36          96
+--R   + 
+--R          5   4 2    10      3    5  3 2     10  3 3    5  2 2 2    5    4
+--R         --- c d  + (-- a b c  + -- b c )d + -- a c  + -- a b c  + -- a b c
+--R         162         27          36          81        12          48
+--R       + 
+--R          1   6
+--R         --- b
+--R         384
+--R    *
+--R        12
+--R       x
+--R   + 
+--R          5    3 2    10  2 3   5    2 2    5  4      5  3   2    5  2 3
+--R         -- b c d  + (-- a c  + - a b c  + -- b c)d + - a b c  + -- a b c
+--R         27           27        6          48         9          12
+--R       + 
+--R          1    5
+--R         -- a b
+--R         32
+--R    *
+--R        11
+--R       x
+--R   + 
+--R          10    3    5  2 2  2    5  2   2   5    3     1  5      5  4 2
+--R         (-- a c  + -- b c )d  + (- a b c  + - a b c + -- b )d + -- a c
+--R          27        12            3          6         32        18
+--R       + 
+--R         5  3 2     5  2 4
+--R         - a b c + -- a b
+--R         6         32
+--R    *
+--R        10
+--R       x
+--R   + 
+--R         10  3 3    5      2    5  3   2    10  3 2   5  2 2     5    4
+--R         -- c d  + (- a b c  + -- b c)d  + (-- a c  + - a b c + -- a b )d
+--R         81         3          12            9        2         16
+--R       + 
+--R         5  4       5  3 3
+--R         - a b c + -- a b
+--R         6         12
+--R    *
+--R        9
+--R       x
+--R   + 
+--R         5    2 3    5  2 2   5    2     5  4  2    10  3      5  2 3     1  5
+--R         - b c d  + (- a c  + - a b c + -- b )d  + (-- a b c + - a b )d + - a c
+--R         9           3        2         32           3         4          3
+--R       + 
+--R         5  4 2
+--R         - a b
+--R         8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R       10    2   5  2   3      2      5    3  2    5  4    5  3 2     1  5   7
+--R     ((-- a c  + - b c)d  + (5a b c + - a b )d  + (- a c + - a b )d + - a b)x
+--R        9        6                    4            3       2          2
+--R   + 
+--R       5  2 4    10          5  3  3    10  3    15  2 2  2   5  4      1  6  6
+--R     (-- c d  + (-- a b c + -- b )d  + (-- a c + -- a b )d  + - a b d + - a )x
+--R      18          3         12           3        4           2         6
+--R   + 
+--R      5      4    10  2    5    2  3     3   2    5   5
+--R     (- b c d  + (-- a c + - a b )d  + 5a b d  + a d)x
+--R      6            3       2
+--R   + 
+--R       5       5  2  4     2   3   5  4 2  4
+--R     ((- a c + - b )d  + 5a b d  + - a d )x
+--R       3       8                   2
+--R   + 
+--R      1    5   5      4   10  3 3   1    3    1    5   5  2 4   1    2
+--R     (- c d  + - a b d  + -- a d  + - c)x  + (- b d  + - a d  + - b)x
+--R      3        2           3        3         2        2        2
+--R   + 
+--R         5
+--R     (a d  + a)x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 178
+
+--S 179 of 619
+m0:=a0-r0
+--R 
+--R
+--R          1  6
+--R   (4)  - - d
+--R          6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 179
+
+--S 180 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 180
+
+)clear all
+
+--S 181 of 619
+t0:=(a+c*x^2)*(1+(a*x+1/3*c*x^3)^n)
+--R 
+--R
+--R                      3        n
+--R            2      c x  + 3a x        2
+--R   (1)  (c x  + a)(-----------)  + c x  + a
+--R                        3
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 619
+r0:=a*x+1/3*c*x^3+(a*x+1/3*c*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R             3        n + 1
+--R          c x  + 3a x                   3
+--R        3(-----------)      + (c n + c)x  + (3a n + 3a)x
+--R               3
+--R   (2)  ------------------------------------------------
+--R                             3n + 3
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                3
+--R                             c x  + 3a x
+--R                       n log(-----------)
+--R            3                     3                   3
+--R        (c x  + 3a x)%e                   + (c n + c)x  + (3a n + 3a)x
+--R   (3)  --------------------------------------------------------------
+--R                                    3n + 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 183
+
+--S 184 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                3
+--R                             c x  + 3a x
+--R                       n log(-----------)        3        n + 1
+--R            3                     3           c x  + 3a x
+--R        (c x  + 3a x)%e                   - 3(-----------)
+--R                                                   3
+--R   (4)  -------------------------------------------------------
+--R                                 3n + 3
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R                             3
+--R                          c x  + 3a x
+--R                    n log(-----------)                   3        n
+--R            2                  3               2      c x  + 3a x
+--R   (5)  (c x  + a)%e                   + (- c x  - a)(-----------)
+--R                                                           3
+--R                                                    Type: Expression(Integer)
+--E 185
+
+)clear all
+
+--S 186 of 619
+t0:=(b*x+c*x^2)*(1+(1/2*b*x^2+1/3*c*x^3)^n)
+--R 
+--R
+--R                         3       2 n
+--R            2        2c x  + 3b x         2
+--R   (1)  (c x  + b x)(-------------)  + c x  + b x
+--R                           6
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 619
+r0:=1/2*b*x^2+1/3*c*x^3+(1/2*b*x^2+1/3*c*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R              3       2 n + 1
+--R          2c x  + 3b x                      3               2
+--R        6(-------------)      + (2c n + 2c)x  + (3b n + 3b)x
+--R                6
+--R   (2)  -----------------------------------------------------
+--R                                6n + 6
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   3       2
+--R                               2c x  + 3b x
+--R                         n log(-------------)
+--R             3       2               6                      3               2
+--R        (2c x  + 3b x )%e                     + (2c n + 2c)x  + (3b n + 3b)x
+--R   (3)  ---------------------------------------------------------------------
+--R                                        6n + 6
+--R                                         Type: Union(Expression(Integer),...)
+--E 188
+
+--S 189 of 619
+m0:=a0-r0
+--R 
+--R
+--R                                   3       2
+--R                               2c x  + 3b x
+--R                         n log(-------------)         3       2 n + 1
+--R             3       2               6            2c x  + 3b x
+--R        (2c x  + 3b x )%e                     - 6(-------------)
+--R                                                        6
+--R   (4)  -------------------------------------------------------------
+--R                                    6n + 6
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R                                3       2
+--R                            2c x  + 3b x
+--R                      n log(-------------)                      3       2 n
+--R            2                     6                2        2c x  + 3b x
+--R   (5)  (c x  + b x)%e                     + (- c x  - b x)(-------------)
+--R                                                                  6
+--R                                                    Type: Expression(Integer)
+--E 190
+
+)clear all
+
+--S 191 of 619
+t0:=(a+b*x+c*x^2)*(1+(a*x+1/2*b*x^2+1/3*c*x^3)^n)
+--R 
+--R
+--R                             3       2        n
+--R            2            2c x  + 3b x  + 6a x        2
+--R   (1)  (c x  + b x + a)(--------------------)  + c x  + b x + a
+--R                                   6
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 619
+r0:=a*x+1/2*b*x^2+1/3*c*x^3+(a*x+1/2*b*x^2+1/3*c*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R   (2)
+--R         3       2        n + 1
+--R     2c x  + 3b x  + 6a x                     3               2
+--R   6(--------------------)      + (2c n + 2c)x  + (3b n + 3b)x  + (6a n + 6a)x
+--R               6
+--R   ---------------------------------------------------------------------------
+--R                                      6n + 6
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         3       2
+--R                                     2c x  + 3b x  + 6a x
+--R                               n log(--------------------)
+--R            3       2                          6                         3
+--R       (2c x  + 3b x  + 6a x)%e                            + (2c n + 2c)x
+--R     + 
+--R                   2
+--R       (3b n + 3b)x  + (6a n + 6a)x
+--R  /
+--R     6n + 6
+--R                                         Type: Union(Expression(Integer),...)
+--E 193
+
+--S 194 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         3       2
+--R                                     2c x  + 3b x  + 6a x
+--R                               n log(--------------------)
+--R            3       2                          6
+--R       (2c x  + 3b x  + 6a x)%e
+--R     + 
+--R               3       2        n + 1
+--R           2c x  + 3b x  + 6a x
+--R       - 6(--------------------)
+--R                     6
+--R  /
+--R     6n + 6
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                 3       2
+--R                             2c x  + 3b x  + 6a x
+--R                       n log(--------------------)
+--R         2                             6
+--R     (c x  + b x + a)%e
+--R   + 
+--R                            3       2        n
+--R           2            2c x  + 3b x  + 6a x
+--R     (- c x  - b x - a)(--------------------)
+--R                                  6
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 619
+t0:=(b+2*c*x)*(b*x+c*x^2)^13
+--R 
+--R
+--R   (1)
+--R       14 27        13 26       2 12 25       3 11 24        4 10 23
+--R     2c  x   + 27b c  x   + 169b c  x   + 650b c  x   + 1716b c  x
+--R   + 
+--R          5 9 22        6 8 21        7 7 20        8 6 19        9 5 18
+--R     3289b c x   + 4719b c x   + 5148b c x   + 4290b c x   + 2717b c x
+--R   + 
+--R          10 4 17       11 3 16       12 2 15      13   14    14 13
+--R     1287b  c x   + 442b  c x   + 104b  c x   + 15b  c x   + b  x
+--R                                                    Type: Polynomial(Integer)
+--E 196
+
+--S 197 of 619
+r0:=1/14*x^14*(b+c*x)^14
+--R 
+--R
+--R   (2)
+--R      1  14 28      13 27   13  2 12 26      3 11 25   143  4 10 24       5 9 23
+--R     -- c  x   + b c  x   + -- b c  x   + 26b c  x   + --- b c  x   + 143b c x
+--R     14                      2                          2
+--R   + 
+--R     429  6 8 22   1716  7 7 21   429  8 6 20       9 5 19   143  10 4 18
+--R     --- b c x   + ---- b c x   + --- b c x   + 143b c x   + --- b  c x
+--R      2              7             2                          2
+--R   + 
+--R        11 3 17   13  12 2 16    13   15    1  14 14
+--R     26b  c x   + -- b  c x   + b  c x   + -- b  x
+--R                   2                       14
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 197
+
+--S 198 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 28      13 27   13  2 12 26      3 11 25   143  4 10 24       5 9 23
+--R     -- c  x   + b c  x   + -- b c  x   + 26b c  x   + --- b c  x   + 143b c x
+--R     14                      2                          2
+--R   + 
+--R     429  6 8 22   1716  7 7 21   429  8 6 20       9 5 19   143  10 4 18
+--R     --- b c x   + ---- b c x   + --- b c x   + 143b c x   + --- b  c x
+--R      2              7             2                          2
+--R   + 
+--R        11 3 17   13  12 2 16    13   15    1  14 14
+--R     26b  c x   + -- b  c x   + b  c x   + -- b  x
+--R                   2                       14
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 198
+
+--S 199 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 199
+
+--S 200 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 200
+
+)clear all
+
+--S 201 of 619
+t0:=x^14*(b+2*c*x^2)*(b*x+c*x^3)^13
+--R 
+--R
+--R   (1)
+--R       14 55        13 53       2 12 51       3 11 49        4 10 47
+--R     2c  x   + 27b c  x   + 169b c  x   + 650b c  x   + 1716b c  x
+--R   + 
+--R          5 9 45        6 8 43        7 7 41        8 6 39        9 5 37
+--R     3289b c x   + 4719b c x   + 5148b c x   + 4290b c x   + 2717b c x
+--R   + 
+--R          10 4 35       11 3 33       12 2 31      13   29    14 27
+--R     1287b  c x   + 442b  c x   + 104b  c x   + 15b  c x   + b  x
+--R                                                    Type: Polynomial(Integer)
+--E 201
+
+--S 202 of 619
+r0:=1/28*x^28*(b+c*x^2)^14
+--R 
+--R
+--R   (2)
+--R      1  14 56   1    13 54   13  2 12 52      3 11 50   143  4 10 48
+--R     -- c  x   + - b c  x   + -- b c  x   + 13b c  x   + --- b c  x
+--R     28          2             4                          4
+--R   + 
+--R     143  5 9 46   429  6 8 44   858  7 7 42   429  8 6 40   143  9 5 38
+--R     --- b c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R      2             4             7             4             2
+--R   + 
+--R     143  10 4 36      11 3 34   13  12 2 32   1  13   30    1  14 28
+--R     --- b  c x   + 13b  c x   + -- b  c x   + - b  c x   + -- b  x
+--R      4                           4            2            28
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 202
+
+--S 203 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 56   1    13 54   13  2 12 52      3 11 50   143  4 10 48
+--R     -- c  x   + - b c  x   + -- b c  x   + 13b c  x   + --- b c  x
+--R     28          2             4                          4
+--R   + 
+--R     143  5 9 46   429  6 8 44   858  7 7 42   429  8 6 40   143  9 5 38
+--R     --- b c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R      2             4             7             4             2
+--R   + 
+--R     143  10 4 36      11 3 34   13  12 2 32   1  13   30    1  14 28
+--R     --- b  c x   + 13b  c x   + -- b  c x   + - b  c x   + -- b  x
+--R      4                           4            2            28
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 203
+
+--S 204 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 204
+
+--S 205 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 205
+
+)clear all
+
+--S 206 of 619
+t0:=x^28*(b+2*c*x^3)*(b*x+c*x^4)^13
+--R 
+--R
+--R   (1)
+--R       14 83        13 80       2 12 77       3 11 74        4 10 71
+--R     2c  x   + 27b c  x   + 169b c  x   + 650b c  x   + 1716b c  x
+--R   + 
+--R          5 9 68        6 8 65        7 7 62        8 6 59        9 5 56
+--R     3289b c x   + 4719b c x   + 5148b c x   + 4290b c x   + 2717b c x
+--R   + 
+--R          10 4 53       11 3 50       12 2 47      13   44    14 41
+--R     1287b  c x   + 442b  c x   + 104b  c x   + 15b  c x   + b  x
+--R                                                    Type: Polynomial(Integer)
+--E 206
+
+--S 207 of 619
+r0:=1/42*x^42*(b+c*x^3)^14
+--R 
+--R
+--R   (2)
+--R      1  14 84   1    13 81   13  2 12 78   26  3 11 75   143  4 10 72
+--R     -- c  x   + - b c  x   + -- b c  x   + -- b c  x   + --- b c  x
+--R     42          3             6             3             6
+--R   + 
+--R     143  5 9 69   143  6 8 66   572  7 7 63   143  8 6 60   143  9 5 57
+--R     --- b c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R      3             2             7             2             3
+--R   + 
+--R     143  10 4 54   26  11 3 51   13  12 2 48   1  13   45    1  14 42
+--R     --- b  c x   + -- b  c x   + -- b  c x   + - b  c x   + -- b  x
+--R      6              3             6            3            42
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 207
+
+--S 208 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  14 84   1    13 81   13  2 12 78   26  3 11 75   143  4 10 72
+--R     -- c  x   + - b c  x   + -- b c  x   + -- b c  x   + --- b c  x
+--R     42          3             6             3             6
+--R   + 
+--R     143  5 9 69   143  6 8 66   572  7 7 63   143  8 6 60   143  9 5 57
+--R     --- b c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R      3             2             7             2             3
+--R   + 
+--R     143  10 4 54   26  11 3 51   13  12 2 48   1  13   45    1  14 42
+--R     --- b  c x   + -- b  c x   + -- b  c x   + - b  c x   + -- b  x
+--R      6              3             6            3            42
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 208
+
+--S 209 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 209
+
+--S 210 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 210
+
+)clear all
+
+--S 211 of 619
+t0:=x^(14*(-1+n))*(b+2*c*x^n)*(b*x+c*x^(1+n))^13
+--R 
+--R
+--R   (1)
+--R          14 n      13   n + 1 13         13   n      2 12    n + 1 12
+--R       (2c  x  + b c  )(x     )   + (26b c  x x  + 13b c  x)(x     )
+--R     + 
+--R            2 12 2 n      3 11 2   n + 1 11
+--R       (156b c  x x  + 78b c  x )(x     )
+--R     + 
+--R            3 11 3 n       4 10 3   n + 1 10
+--R       (572b c  x x  + 286b c  x )(x     )
+--R     + 
+--R             4 10 4 n       5 9 4   n + 1 9
+--R       (1430b c  x x  + 715b c x )(x     )
+--R     + 
+--R             5 9 5 n        6 8 5   n + 1 8
+--R       (2574b c x x  + 1287b c x )(x     )
+--R     + 
+--R             6 8 6 n        7 7 6   n + 1 7
+--R       (3432b c x x  + 1716b c x )(x     )
+--R     + 
+--R             7 7 7 n        8 6 7   n + 1 6
+--R       (3432b c x x  + 1716b c x )(x     )
+--R     + 
+--R             8 6 8 n        9 5 8   n + 1 5
+--R       (2574b c x x  + 1287b c x )(x     )
+--R     + 
+--R             9 5 9 n       10 4 9   n + 1 4
+--R       (1430b c x x  + 715b  c x )(x     )
+--R     + 
+--R            10 4 10 n       11 3 10   n + 1 3
+--R       (572b  c x  x  + 286b  c x  )(x     )
+--R     + 
+--R            11 3 11 n      12 2 11   n + 1 2       12 2 12 n      13   12  n + 1
+--R       (156b  c x  x  + 78b  c x  )(x     )  + (26b  c x  x  + 13b  c x  )x
+--R     + 
+--R         13   13 n    14 13
+--R       2b  c x  x  + b  x
+--R  *
+--R      14n - 14
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 619
+r0:=1/14*x^(14*n)*(b+c*x^n)^14/n
+--R 
+--R
+--R   (2)
+--R          14  n 14        13  n 13      2 12  n 12       3 11  n 11
+--R         c  (x )   + 14b c  (x )   + 91b c  (x )   + 364b c  (x )
+--R       + 
+--R              4 10  n 10        5 9  n 9        6 8  n 8        7 7  n 7
+--R         1001b c  (x )   + 2002b c (x )  + 3003b c (x )  + 3432b c (x )
+--R       + 
+--R              8 6  n 6        9 5  n 5        10 4  n 4       11 3  n 3
+--R         3003b c (x )  + 2002b c (x )  + 1001b  c (x )  + 364b  c (x )
+--R       + 
+--R            12 2  n 2      13   n    14
+--R         91b  c (x )  + 14b  c x  + b
+--R    *
+--R        14n
+--R       x
+--R  /
+--R     14n
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        14   (n + 1)log(x) 28        13     (n + 1)log(x) 27
+--R       c  (%e             )   + 14b c  x (%e             )
+--R     + 
+--R          2 12 2   (n + 1)log(x) 26       3 11 3   (n + 1)log(x) 25
+--R       91b c  x (%e             )   + 364b c  x (%e             )
+--R     + 
+--R            4 10 4   (n + 1)log(x) 24        5 9 5   (n + 1)log(x) 23
+--R       1001b c  x (%e             )   + 2002b c x (%e             )
+--R     + 
+--R            6 8 6   (n + 1)log(x) 22        7 7 7   (n + 1)log(x) 21
+--R       3003b c x (%e             )   + 3432b c x (%e             )
+--R     + 
+--R            8 6 8   (n + 1)log(x) 20        9 5 9   (n + 1)log(x) 19
+--R       3003b c x (%e             )   + 2002b c x (%e             )
+--R     + 
+--R            10 4 10   (n + 1)log(x) 18       11 3 11   (n + 1)log(x) 17
+--R       1001b  c x  (%e             )   + 364b  c x  (%e             )
+--R     + 
+--R          12 2 12   (n + 1)log(x) 16      13   13   (n + 1)log(x) 15
+--R       91b  c x  (%e             )   + 14b  c x  (%e             )
+--R     + 
+--R        14 14   (n + 1)log(x) 14
+--R       b  x  (%e             )
+--R  /
+--R          28
+--R     14n x
+--R                                         Type: Union(Expression(Integer),...)
+--E 213
+
+--S 214 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        14   (n + 1)log(x) 28        13     (n + 1)log(x) 27
+--R       c  (%e             )   + 14b c  x (%e             )
+--R     + 
+--R          2 12 2   (n + 1)log(x) 26       3 11 3   (n + 1)log(x) 25
+--R       91b c  x (%e             )   + 364b c  x (%e             )
+--R     + 
+--R            4 10 4   (n + 1)log(x) 24        5 9 5   (n + 1)log(x) 23
+--R       1001b c  x (%e             )   + 2002b c x (%e             )
+--R     + 
+--R            6 8 6   (n + 1)log(x) 22        7 7 7   (n + 1)log(x) 21
+--R       3003b c x (%e             )   + 3432b c x (%e             )
+--R     + 
+--R            8 6 8   (n + 1)log(x) 20        9 5 9   (n + 1)log(x) 19
+--R       3003b c x (%e             )   + 2002b c x (%e             )
+--R     + 
+--R            10 4 10   (n + 1)log(x) 18       11 3 11   (n + 1)log(x) 17
+--R       1001b  c x  (%e             )   + 364b  c x  (%e             )
+--R     + 
+--R          12 2 12   (n + 1)log(x) 16      13   13   (n + 1)log(x) 15
+--R       91b  c x  (%e             )   + 14b  c x  (%e             )
+--R     + 
+--R        14 14   (n + 1)log(x) 14
+--R       b  x  (%e             )
+--R     + 
+--R              14 28  n 14        13 28  n 13      2 12 28  n 12
+--R           - c  x  (x )   - 14b c  x  (x )   - 91b c  x  (x )
+--R         + 
+--R                 3 11 28  n 11        4 10 28  n 10        5 9 28  n 9
+--R           - 364b c  x  (x )   - 1001b c  x  (x )   - 2002b c x  (x )
+--R         + 
+--R                  6 8 28  n 8        7 7 28  n 7        8 6 28  n 6
+--R           - 3003b c x  (x )  - 3432b c x  (x )  - 3003b c x  (x )
+--R         + 
+--R                  9 5 28  n 5        10 4 28  n 4       11 3 28  n 3
+--R           - 2002b c x  (x )  - 1001b  c x  (x )  - 364b  c x  (x )
+--R         + 
+--R                12 2 28  n 2      13   28 n    14 28
+--R           - 91b  c x  (x )  - 14b  c x  x  - b  x
+--R      *
+--R          14n
+--R         x
+--R  /
+--R          28
+--R     14n x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         14   (n + 1)log(x) 28        13     (n + 1)log(x) 27
+--R       2c  (%e             )   + 27b c  x (%e             )
+--R     + 
+--R           2 12 2   (n + 1)log(x) 26       3 11 3   (n + 1)log(x) 25
+--R       169b c  x (%e             )   + 650b c  x (%e             )
+--R     + 
+--R            4 10 4   (n + 1)log(x) 24        5 9 5   (n + 1)log(x) 23
+--R       1716b c  x (%e             )   + 3289b c x (%e             )
+--R     + 
+--R            6 8 6   (n + 1)log(x) 22        7 7 7   (n + 1)log(x) 21
+--R       4719b c x (%e             )   + 5148b c x (%e             )
+--R     + 
+--R            8 6 8   (n + 1)log(x) 20        9 5 9   (n + 1)log(x) 19
+--R       4290b c x (%e             )   + 2717b c x (%e             )
+--R     + 
+--R            10 4 10   (n + 1)log(x) 18       11 3 11   (n + 1)log(x) 17
+--R       1287b  c x  (%e             )   + 442b  c x  (%e             )
+--R     + 
+--R           12 2 12   (n + 1)log(x) 16      13   13   (n + 1)log(x) 15
+--R       104b  c x  (%e             )   + 15b  c x  (%e             )
+--R     + 
+--R        14 14   (n + 1)log(x) 14
+--R       b  x  (%e             )
+--R     + 
+--R              14 29 n - 1  n 13        13 29 n - 1  n 12
+--R           - c  x  x     (x )   - 13b c  x  x     (x )
+--R         + 
+--R                2 12 29 n - 1  n 11       3 11 29 n - 1  n 10
+--R           - 78b c  x  x     (x )   - 286b c  x  x     (x )
+--R         + 
+--R                 4 10 29 n - 1  n 9        5 9 29 n - 1  n 8
+--R           - 715b c  x  x     (x )  - 1287b c x  x     (x )
+--R         + 
+--R                  6 8 29 n - 1  n 7        7 7 29 n - 1  n 6
+--R           - 1716b c x  x     (x )  - 1716b c x  x     (x )
+--R         + 
+--R                  8 6 29 n - 1  n 5       9 5 29 n - 1  n 4
+--R           - 1287b c x  x     (x )  - 715b c x  x     (x )
+--R         + 
+--R                 10 4 29 n - 1  n 3      11 3 29 n - 1  n 2      12 2 29 n - 1 n
+--R           - 286b  c x  x     (x )  - 78b  c x  x     (x )  - 13b  c x  x     x
+--R         + 
+--R              13   29 n - 1
+--R           - b  c x  x
+--R      *
+--R          14n
+--R         x
+--R     + 
+--R              14 29  n 14        13 29  n 13      2 12 29  n 12
+--R           - c  x  (x )   - 14b c  x  (x )   - 91b c  x  (x )
+--R         + 
+--R                 3 11 29  n 11        4 10 29  n 10        5 9 29  n 9
+--R           - 364b c  x  (x )   - 1001b c  x  (x )   - 2002b c x  (x )
+--R         + 
+--R                  6 8 29  n 8        7 7 29  n 7        8 6 29  n 6
+--R           - 3003b c x  (x )  - 3432b c x  (x )  - 3003b c x  (x )
+--R         + 
+--R                  9 5 29  n 5        10 4 29  n 4       11 3 29  n 3
+--R           - 2002b c x  (x )  - 1001b  c x  (x )  - 364b  c x  (x )
+--R         + 
+--R                12 2 29  n 2      13   29 n    14 29
+--R           - 91b  c x  (x )  - 14b  c x  x  - b  x
+--R      *
+--R          14n - 1
+--R         x
+--R  /
+--R      29
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 215
+
+)clear all
+
+--S 216 of 619
+t0:=(b+2*c*x)/(b*x+c*x^2)
+--R 
+--R
+--R         2c x + b
+--R   (1)  ----------
+--R           2
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 216
+
+--S 217 of 619
+r0:=log(x)+log(b+c*x)
+--R 
+--R
+--R   (2)  log(c x + b) + log(x)
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R   (3)  log(c x  + b x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 218
+
+--S 219 of 619
+m0:=a0-r0
+--R 
+--R
+--R               2
+--R   (4)  log(c x  + b x) - log(c x + b) - log(x)
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 220
+
+)clear all
+
+--S 221 of 619
+t0:=(b+2*c*x^2)/(b*x+c*x^3)
+--R 
+--R
+--R             2
+--R         2c x  + b
+--R   (1)  ----------
+--R           3
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 221
+
+--S 222 of 619
+r0:=log(x)+1/2*log(b+c*x^2)
+--R 
+--R
+--R               2
+--R        log(c x  + b) + 2log(x)
+--R   (2)  -----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R        log(c x  + b) + 2log(x)
+--R   (3)  -----------------------
+--R                   2
+--R                                         Type: Union(Expression(Integer),...)
+--E 223
+
+--S 224 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 619
+t0:=(b+2*c*x^3)/(b*x+c*x^4)
+--R 
+--R
+--R             3
+--R         2c x  + b
+--R   (1)  ----------
+--R           4
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 226
+
+--S 227 of 619
+r0:=log(x)+1/3*log(b+c*x^3)
+--R 
+--R
+--R               3
+--R        log(c x  + b) + 3log(x)
+--R   (2)  -----------------------
+--R                   3
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3
+--R        log(c x  + b) + 3log(x)
+--R   (3)  -----------------------
+--R                   3
+--R                                         Type: Union(Expression(Integer),...)
+--E 228
+
+--S 229 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 230
+
+)clear all
+
+--S 231 of 619
+t0:=(b+2*c*x^n)/(b*x+c*x^(1+n))
+--R 
+--R
+--R               n
+--R           2c x  + b
+--R   (1)  --------------
+--R           n + 1
+--R        c x      + b x
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 619
+r0:=log(x)+log(b+c*x^n)/n
+--R 
+--R
+--R               n
+--R        log(c x  + b) + n log(x)
+--R   (2)  ------------------------
+--R                    n
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                (n + 1)log(x)
+--R        log(c %e              + b x) + (n - 1)log(x)
+--R   (3)  --------------------------------------------
+--R                              n
+--R                                         Type: Union(Expression(Integer),...)
+--E 233
+
+--S 234 of 619
+m0:=a0-r0
+--R 
+--R
+--R                (n + 1)log(x)                 n
+--R        log(c %e              + b x) - log(c x  + b) - log(x)
+--R   (4)  -----------------------------------------------------
+--R                                  n
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R          2 n    2   n - 1         (n + 1)log(x)        2 n - 1
+--R        (c x  - c x x      + b c)%e              - b c x x
+--R   (5)  -------------------------------------------------------
+--R             2   n           (n + 1)log(x)        2 n    2 2
+--R           (c x x  + b c x)%e              + b c x x  + b x
+--R                                                    Type: Expression(Integer)
+--E 235
+
+)clear all
+
+--S 236 of 619
+t0:=(b+2*c*x)/(b*x+c*x^2)^8
+--R 
+--R
+--R   (1)
+--R     2c x + b
+--R  /
+--R        8 16       7 15      2 6 14      3 5 13      4 4 12      5 3 11
+--R       c x   + 8b c x   + 28b c x   + 56b c x   + 70b c x   + 56b c x
+--R     + 
+--R          6 2 10     7   9    8 8
+--R       28b c x   + 8b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 236
+
+--S 237 of 619
+r0:=(-1/7)/(x^7*(b+c*x)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R        1
+--R        -
+--R        7
+--R     /
+--R           7 14       6 13      2 5 12      3 4 11      4 3 10      5 2 9
+--R          c x   + 7b c x   + 21b c x   + 35b c x   + 35b c x   + 21b c x
+--R        + 
+--R            6   8    7 7
+--R          7b c x  + b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 237
+
+--S 238 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R            7 14        6 13       2 5 12       3 4 11       4 3 10       5 2 9
+--R          7c x   + 49b c x   + 147b c x   + 245b c x   + 245b c x   + 147b c x
+--R        + 
+--R             6   8     7 7
+--R          49b c x  + 7b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 238
+
+--S 239 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 619
+t0:=(b+2*c*x^2)/(x^7*(b*x+c*x^3)^8)
+--R 
+--R
+--R   (1)
+--R         2
+--R     2c x  + b
+--R  /
+--R        8 31       7 29      2 6 27      3 5 25      4 4 23      5 3 21
+--R       c x   + 8b c x   + 28b c x   + 56b c x   + 70b c x   + 56b c x
+--R     + 
+--R          6 2 19     7   17    8 15
+--R       28b c x   + 8b c x   + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 241
+
+--S 242 of 619
+r0:=(-1/14)/(x^14*(b+c*x^2)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R         1
+--R        --
+--R        14
+--R     /
+--R           7 28       6 26      2 5 24      3 4 22      4 3 20      5 2 18
+--R          c x   + 7b c x   + 21b c x   + 35b c x   + 35b c x   + 21b c x
+--R        + 
+--R            6   16    7 14
+--R          7b c x   + b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 242
+
+--S 243 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R             7 28        6 26       2 5 24       3 4 22       4 3 20
+--R          14c x   + 98b c x   + 294b c x   + 490b c x   + 490b c x
+--R        + 
+--R              5 2 18      6   16      7 14
+--R          294b c x   + 98b c x   + 14b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 243
+
+--S 244 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 245
+
+)clear all
+
+--S 246 of 619
+t0:=(b+2*c*x^3)/(x^14*(b*x+c*x^4)^8)
+--R 
+--R
+--R   (1)
+--R         3
+--R     2c x  + b
+--R  /
+--R        8 46       7 43      2 6 40      3 5 37      4 4 34      5 3 31
+--R       c x   + 8b c x   + 28b c x   + 56b c x   + 70b c x   + 56b c x
+--R     + 
+--R          6 2 28     7   25    8 22
+--R       28b c x   + 8b c x   + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 246
+
+--S 247 of 619
+r0:=(-1/21)/(x^21*(b+c*x^3)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R         1
+--R        --
+--R        21
+--R     /
+--R           7 42       6 39      2 5 36      3 4 33      4 3 30      5 2 27
+--R          c x   + 7b c x   + 21b c x   + 35b c x   + 35b c x   + 21b c x
+--R        + 
+--R            6   24    7 21
+--R          7b c x   + b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 247
+
+--S 248 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R             7 42         6 39       2 5 36       3 4 33       4 3 30
+--R          21c x   + 147b c x   + 441b c x   + 735b c x   + 735b c x
+--R        + 
+--R              5 2 27       6   24      7 21
+--R          441b c x   + 147b c x   + 21b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 248
+
+--S 249 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+--S 250 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 250
+
+)clear all
+
+--S 251 of 619
+t0:=(b+2*c*x^n)/(x^(7*(-1+n))*(b*x+c*x^(1+n))^8)
+--R 
+--R
+--R   (1)
+--R         n
+--R     2c x  + b
+--R  /
+--R          8  n + 1 8       7    n + 1 7      2 6 2  n + 1 6      3 5 3  n + 1 5
+--R         c (x     )  + 8b c x (x     )  + 28b c x (x     )  + 56b c x (x     )
+--R       + 
+--R            4 4 4  n + 1 4      5 3 5  n + 1 3      6 2 6  n + 1 2
+--R         70b c x (x     )  + 56b c x (x     )  + 28b c x (x     )
+--R       + 
+--R           7   7 n + 1    8 8
+--R         8b c x x      + b x
+--R    *
+--R        7n - 7
+--R       x
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 619
+r0:=(-1/7)/(n*x^(7*n)*(b+c*x^n)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R        1
+--R     /
+--R              7    n 7        6    n 6       2 5    n 5       3 4    n 4
+--R            7c n (x )  + 49b c n (x )  + 147b c n (x )  + 245b c n (x )
+--R          + 
+--R                4 3    n 3       5 2    n 2      6     n     7
+--R            245b c n (x )  + 147b c n (x )  + 49b c n x  + 7b n
+--R       *
+--R           7n
+--R          x
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R         14
+--R        x
+--R     /
+--R            7     (n + 1)log(x) 14        6       (n + 1)log(x) 13
+--R          7c n (%e             )   + 49b c n x (%e             )
+--R        + 
+--R              2 5   2   (n + 1)log(x) 12       3 4   3   (n + 1)log(x) 11
+--R          147b c n x (%e             )   + 245b c n x (%e             )
+--R        + 
+--R              4 3   4   (n + 1)log(x) 10       5 2   5   (n + 1)log(x) 9
+--R          245b c n x (%e             )   + 147b c n x (%e             )
+--R        + 
+--R             6     6   (n + 1)log(x) 8     7   7   (n + 1)log(x) 7
+--R          49b c n x (%e             )  + 7b n x (%e             )
+--R                                         Type: Union(Expression(Integer),...)
+--E 253
+
+--S 254 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        7   (n + 1)log(x) 14       6     (n + 1)log(x) 13
+--R       c (%e             )   + 7b c x (%e             )
+--R     + 
+--R          2 5 2   (n + 1)log(x) 12      3 4 3   (n + 1)log(x) 11
+--R       21b c x (%e             )   + 35b c x (%e             )
+--R     + 
+--R          4 3 4   (n + 1)log(x) 10      5 2 5   (n + 1)log(x) 9
+--R       35b c x (%e             )   + 21b c x (%e             )
+--R     + 
+--R         6   6   (n + 1)log(x) 8    7 7   (n + 1)log(x) 7
+--R       7b c x (%e             )  + b x (%e             )
+--R     + 
+--R              7 14  n 7       6 14  n 6      2 5 14  n 5      3 4 14  n 4
+--R           - c x  (x )  - 7b c x  (x )  - 21b c x  (x )  - 35b c x  (x )
+--R         + 
+--R                4 3 14  n 3      5 2 14  n 2     6   14 n    7 14
+--R           - 35b c x  (x )  - 21b c x  (x )  - 7b c x  x  - b x
+--R      *
+--R          7n
+--R         x
+--R  /
+--R             14    n 7        13    n 6       2 12    n 5       3 11    n 4
+--R           7c  n (x )  + 49b c  n (x )  + 147b c  n (x )  + 245b c  n (x )
+--R         + 
+--R               4 10    n 3       5 9    n 2      6 8   n     7 7
+--R           245b c  n (x )  + 147b c n (x )  + 49b c n x  + 7b c n
+--R      *
+--R          7n   (n + 1)log(x) 14
+--R         x  (%e             )
+--R     + 
+--R                13      n 7       2 12      n 6        3 11      n 5
+--R           49b c  n x (x )  + 343b c  n x (x )  + 1029b c  n x (x )
+--R         + 
+--R                4 10      n 4        5 9      n 3        6 8      n 2
+--R           1715b c  n x (x )  + 1715b c n x (x )  + 1029b c n x (x )
+--R         + 
+--R               7 7     n      8 6
+--R           343b c n x x  + 49b c n x
+--R      *
+--R          7n   (n + 1)log(x) 13
+--R         x  (%e             )
+--R     + 
+--R               2 12   2  n 7        3 11   2  n 6        4 10   2  n 5
+--R           147b c  n x (x )  + 1029b c  n x (x )  + 3087b c  n x (x )
+--R         + 
+--R                5 9   2  n 4        6 8   2  n 3        7 7   2  n 2
+--R           5145b c n x (x )  + 5145b c n x (x )  + 3087b c n x (x )
+--R         + 
+--R                8 6   2 n       9 5   2
+--R           1029b c n x x  + 147b c n x
+--R      *
+--R          7n   (n + 1)log(x) 12
+--R         x  (%e             )
+--R     + 
+--R               3 11   3  n 7        4 10   3  n 6        5 9   3  n 5
+--R           245b c  n x (x )  + 1715b c  n x (x )  + 5145b c n x (x )
+--R         + 
+--R                6 8   3  n 4        7 7   3  n 3        8 6   3  n 2
+--R           8575b c n x (x )  + 8575b c n x (x )  + 5145b c n x (x )
+--R         + 
+--R                9 5   3 n       10 4   3
+--R           1715b c n x x  + 245b  c n x
+--R      *
+--R          7n   (n + 1)log(x) 11
+--R         x  (%e             )
+--R     + 
+--R               4 10   4  n 7        5 9   4  n 6        6 8   4  n 5
+--R           245b c  n x (x )  + 1715b c n x (x )  + 5145b c n x (x )
+--R         + 
+--R                7 7   4  n 4        8 6   4  n 3        9 5   4  n 2
+--R           8575b c n x (x )  + 8575b c n x (x )  + 5145b c n x (x )
+--R         + 
+--R                10 4   4 n       11 3   4
+--R           1715b  c n x x  + 245b  c n x
+--R      *
+--R          7n   (n + 1)log(x) 10
+--R         x  (%e             )
+--R     + 
+--R               5 9   5  n 7        6 8   5  n 6        7 7   5  n 5
+--R           147b c n x (x )  + 1029b c n x (x )  + 3087b c n x (x )
+--R         + 
+--R                8 6   5  n 4        9 5   5  n 3        10 4   5  n 2
+--R           5145b c n x (x )  + 5145b c n x (x )  + 3087b  c n x (x )
+--R         + 
+--R                11 3   5 n       12 2   5
+--R           1029b  c n x x  + 147b  c n x
+--R      *
+--R          7n   (n + 1)log(x) 9
+--R         x  (%e             )
+--R     + 
+--R              6 8   6  n 7       7 7   6  n 6        8 6   6  n 5
+--R           49b c n x (x )  + 343b c n x (x )  + 1029b c n x (x )
+--R         + 
+--R                9 5   6  n 4        10 4   6  n 3        11 3   6  n 2
+--R           1715b c n x (x )  + 1715b  c n x (x )  + 1029b  c n x (x )
+--R         + 
+--R               12 2   6 n      13     6
+--R           343b  c n x x  + 49b  c n x
+--R      *
+--R          7n   (n + 1)log(x) 8
+--R         x  (%e             )
+--R     + 
+--R             7 7   7  n 7      8 6   7  n 6       9 5   7  n 5
+--R           7b c n x (x )  + 49b c n x (x )  + 147b c n x (x )
+--R         + 
+--R               10 4   7  n 4       11 3   7  n 3       12 2   7  n 2
+--R           245b  c n x (x )  + 245b  c n x (x )  + 147b  c n x (x )
+--R         + 
+--R              13     7 n     14   7
+--R           49b  c n x x  + 7b  n x
+--R      *
+--R          7n   (n + 1)log(x) 7
+--R         x  (%e             )
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           9 n - 1 7n       9 n      8  7n - 1    (n + 1)log(x) 15
+--R       (- c x     x   + (- c x  - b c )x      )(%e             )
+--R     + 
+--R              8   n - 1 7n          8   n     2 7   7n - 1    (n + 1)log(x) 14
+--R       (- 8b c x x     x   + (- 8b c x x  - 8b c x)x      )(%e             )
+--R     + 
+--R               2 7 2 n - 1 7n         2 7 2 n      3 6 2  7n - 1
+--R         (- 28b c x x     x   + (- 28b c x x  - 28b c x )x      )
+--R      *
+--R            (n + 1)log(x) 13
+--R         (%e             )
+--R     + 
+--R               3 6 3 n - 1 7n         3 6 3 n      4 5 3  7n - 1
+--R         (- 56b c x x     x   + (- 56b c x x  - 56b c x )x      )
+--R      *
+--R            (n + 1)log(x) 12
+--R         (%e             )
+--R     + 
+--R               4 5 4 n - 1 7n         4 5 4 n      5 4 4  7n - 1
+--R         (- 70b c x x     x   + (- 70b c x x  - 70b c x )x      )
+--R      *
+--R            (n + 1)log(x) 11
+--R         (%e             )
+--R     + 
+--R               5 4 5 n - 1 7n         5 4 5 n      6 3 5  7n - 1
+--R         (- 56b c x x     x   + (- 56b c x x  - 56b c x )x      )
+--R      *
+--R            (n + 1)log(x) 10
+--R         (%e             )
+--R     + 
+--R               6 3 6 n - 1 7n         6 3 6 n      7 2 6  7n - 1
+--R         (- 28b c x x     x   + (- 28b c x x  - 28b c x )x      )
+--R      *
+--R            (n + 1)log(x) 9
+--R         (%e             )
+--R     + 
+--R            7 2 7 n - 1 7n        7 2 7 n     8   7  7n - 1    (n + 1)log(x) 8
+--R       (- 8b c x x     x   + (- 8b c x x  - 8b c x )x      )(%e             )
+--R     + 
+--R           8   8 n - 1 7n       8   8 n    9 8  7n - 1    (n + 1)log(x) 7
+--R       (- b c x x     x   + (- b c x x  - b x )x      )(%e             )
+--R     + 
+--R             9 13  n 8        8 13  n 7      2 7 13  n 6       3 6 13  n 5
+--R           2c x  (x )  + 16b c x  (x )  + 56b c x  (x )  + 112b c x  (x )
+--R         + 
+--R               4 5 13  n 4       5 4 13  n 3      6 3 13  n 2      7 2 13 n
+--R           140b c x  (x )  + 112b c x  (x )  + 56b c x  (x )  + 16b c x  x
+--R         + 
+--R             8   13
+--R           2b c x
+--R      *
+--R           7n 2  (n + 1)log(x)
+--R         (x  ) %e
+--R     + 
+--R              8 14  n 8     2 7 14  n 7      3 6 14  n 6      4 5 14  n 5
+--R           b c x  (x )  + 8b c x  (x )  + 28b c x  (x )  + 56b c x  (x )
+--R         + 
+--R            5 4 14  n 4      6 3 14  n 3      7 2 14  n 2     8   14 n    9 14
+--R         70b c x  (x )  + 56b c x  (x )  + 28b c x  (x )  + 8b c x  x  + b x
+--R      *
+--R           7n 2
+--R         (x  )
+--R  /
+--R            16  n 8       15  n 7      2 14  n 6      3 13  n 5      4 12  n 4
+--R           c  (x )  + 8b c  (x )  + 28b c  (x )  + 56b c  (x )  + 70b c  (x )
+--R         + 
+--R              5 11  n 3      6 10  n 2     7 9 n    8 8
+--R           56b c  (x )  + 28b c  (x )  + 8b c x  + b c
+--R      *
+--R           7n 2   (n + 1)log(x) 15
+--R         (x  ) (%e             )
+--R     + 
+--R               15    n 8      2 14    n 7       3 13    n 6       4 12    n 5
+--R           8b c  x (x )  + 64b c  x (x )  + 224b c  x (x )  + 448b c  x (x )
+--R         + 
+--R               5 11    n 4       6 10    n 3       7 9    n 2      8 8   n
+--R           560b c  x (x )  + 448b c  x (x )  + 224b c x (x )  + 64b c x x
+--R         + 
+--R             9 7
+--R           8b c x
+--R      *
+--R           7n 2   (n + 1)log(x) 14
+--R         (x  ) (%e             )
+--R     + 
+--R              2 14 2  n 8       3 13 2  n 7       4 12 2  n 6        5 11 2  n 5
+--R           28b c  x (x )  + 224b c  x (x )  + 784b c  x (x )  + 1568b c  x (x )
+--R         + 
+--R                6 10 2  n 4        7 9 2  n 3       8 8 2  n 2       9 7 2 n
+--R           1960b c  x (x )  + 1568b c x (x )  + 784b c x (x )  + 224b c x x
+--R         + 
+--R              10 6 2
+--R           28b  c x
+--R      *
+--R           7n 2   (n + 1)log(x) 13
+--R         (x  ) (%e             )
+--R     + 
+--R              3 13 3  n 8       4 12 3  n 7        5 11 3  n 6
+--R           56b c  x (x )  + 448b c  x (x )  + 1568b c  x (x )
+--R         + 
+--R                6 10 3  n 5        7 9 3  n 4        8 8 3  n 3
+--R           3136b c  x (x )  + 3920b c x (x )  + 3136b c x (x )
+--R         + 
+--R                9 7 3  n 2       10 6 3 n      11 5 3
+--R           1568b c x (x )  + 448b  c x x  + 56b  c x
+--R      *
+--R           7n 2   (n + 1)log(x) 12
+--R         (x  ) (%e             )
+--R     + 
+--R              4 12 4  n 8       5 11 4  n 7        6 10 4  n 6        7 9 4  n 5
+--R           70b c  x (x )  + 560b c  x (x )  + 1960b c  x (x )  + 3920b c x (x )
+--R         + 
+--R                8 8 4  n 4        9 7 4  n 3        10 6 4  n 2       11 5 4 n
+--R           4900b c x (x )  + 3920b c x (x )  + 1960b  c x (x )  + 560b  c x x
+--R         + 
+--R              12 4 4
+--R           70b  c x
+--R      *
+--R           7n 2   (n + 1)log(x) 11
+--R         (x  ) (%e             )
+--R     + 
+--R              5 11 5  n 8       6 10 5  n 7        7 9 5  n 6        8 8 5  n 5
+--R           56b c  x (x )  + 448b c  x (x )  + 1568b c x (x )  + 3136b c x (x )
+--R         + 
+--R                9 7 5  n 4        10 6 5  n 3        11 5 5  n 2       12 4 5 n
+--R           3920b c x (x )  + 3136b  c x (x )  + 1568b  c x (x )  + 448b  c x x
+--R         + 
+--R              13 3 5
+--R           56b  c x
+--R      *
+--R           7n 2   (n + 1)log(x) 10
+--R         (x  ) (%e             )
+--R     + 
+--R              6 10 6  n 8       7 9 6  n 7       8 8 6  n 6        9 7 6  n 5
+--R           28b c  x (x )  + 224b c x (x )  + 784b c x (x )  + 1568b c x (x )
+--R         + 
+--R                10 6 6  n 4        11 5 6  n 3       12 4 6  n 2       13 3 6 n
+--R           1960b  c x (x )  + 1568b  c x (x )  + 784b  c x (x )  + 224b  c x x
+--R         + 
+--R              14 2 6
+--R           28b  c x
+--R      *
+--R           7n 2   (n + 1)log(x) 9
+--R         (x  ) (%e             )
+--R     + 
+--R             7 9 7  n 8      8 8 7  n 7       9 7 7  n 6       10 6 7  n 5
+--R           8b c x (x )  + 64b c x (x )  + 224b c x (x )  + 448b  c x (x )
+--R         + 
+--R               11 5 7  n 4       12 4 7  n 3       13 3 7  n 2      14 2 7 n
+--R           560b  c x (x )  + 448b  c x (x )  + 224b  c x (x )  + 64b  c x x
+--R         + 
+--R             15   7
+--R           8b  c x
+--R      *
+--R           7n 2   (n + 1)log(x) 8
+--R         (x  ) (%e             )
+--R     + 
+--R            8 8 8  n 8     9 7 8  n 7      10 6 8  n 6      11 5 8  n 5
+--R           b c x (x )  + 8b c x (x )  + 28b  c x (x )  + 56b  c x (x )
+--R         + 
+--R            12 4 8  n 4      13 3 8  n 3      14 2 8  n 2     15   8 n    16 8
+--R         70b  c x (x )  + 56b  c x (x )  + 28b  c x (x )  + 8b  c x x  + b  x
+--R      *
+--R           7n 2   (n + 1)log(x) 7
+--R         (x  ) (%e             )
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 619
+t0:=(b+2*c*x)*(b*x+c*x^2)^p
+--R 
+--R
+--R                      2       p
+--R   (1)  (2c x + b)(c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 619
+r0:=(b*x+c*x^2)^(1+p)/(1+p)
+--R 
+--R
+--R            2       p + 1
+--R        (c x  + b x)
+--R   (2)  -----------------
+--R              p + 1
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               2
+--R            2         p log(c x  + b x)
+--R        (c x  + b x)%e
+--R   (3)  -------------------------------
+--R                     p + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 258
+
+--S 259 of 619
+m0:=a0-r0
+--R 
+--R
+--R                               2
+--R            2         p log(c x  + b x)       2       p + 1
+--R        (c x  + b x)%e                  - (c x  + b x)
+--R   (4)  ---------------------------------------------------
+--R                               p + 1
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R                             2
+--R                    p log(c x  + b x)                   2       p
+--R   (5)  (2c x + b)%e                  + (- 2c x - b)(c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 260
+
+)clear all
+
+--S 261 of 619
+t0:=x^(1+p)*(b+2*c*x^2)*(b*x+c*x^3)^p
+--R 
+--R
+--R             2      p + 1    3       p
+--R   (1)  (2c x  + b)x     (c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 619
+r0:=1/2*x^(1+p)*(b*x+c*x^3)^(1+p)/(1+p)
+--R 
+--R
+--R         p + 1    3       p + 1
+--R        x     (c x  + b x)
+--R   (2)  -----------------------
+--R                 2p + 2
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                              3
+--R            3         (p + 1)log(x)  p log(c x  + b x)
+--R        (d x  + b x)%e             %e
+--R   (3)  ----------------------------------------------
+--R                            2p + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 263
+
+--S 264 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         3
+--R       3         (p + 1)log(x)  p log(c x  + b x)    p + 1    3       p + 1
+--R   (d x  + b x)%e             %e                  - x     (c x  + b x)
+--R   ------------------------------------------------------------------------
+--R                                    2p + 2
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                             3
+--R            2        (p + 1)log(x)  p log(c x  + b x)    p    3       p + 1
+--R       (4c x  + 2b)%e             %e                  - x (c x  + b x)
+--R     + 
+--R              2      p + 1    3       p
+--R       (- 3c x  - b)x     (c x  + b x)
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 265
+
+)clear all
+
+--S 266 of 619
+t0:=b*x^(1+p)*(b*x+c*x^3)^p+2*c*x^(3+p)*(b*x+c*x^3)^p
+--R 
+--R
+--R             p + 3      p + 1     3       p
+--R   (1)  (2c x      + b x     )(c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 619
+r0:=1/2*x^(1+p)*(b*x+c*x^3)^(1+p)/(1+p)
+--R 
+--R
+--R         p + 1    3       p + 1
+--R        x     (c x  + b x)
+--R   (2)  -----------------------
+--R                 2p + 2
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                            3
+--R            2       (p + 3)log(x)  p log(c x  + b x)
+--R        (c x  + b)%e             %e
+--R   (3)  --------------------------------------------
+--R                          (2p + 2)x
+--R                                         Type: Union(Expression(Integer),...)
+--E 268
+
+--S 269 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       3
+--R       2       (p + 3)log(x)  p log(c x  + b x)      p + 1    3       p + 1
+--R   (c x  + b)%e             %e                  - x x     (c x  + b x)
+--R   ------------------------------------------------------------------------
+--R                                   (2p + 2)x
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                             3
+--R            2        (p + 3)log(x)  p log(c x  + b x)    2 p    3       p + 1
+--R       (4c x  + 2b)%e             %e                  - x x (c x  + b x)
+--R     + 
+--R              4      2  p + 1    3       p
+--R       (- 3c x  - b x )x     (c x  + b x)
+--R  /
+--R       2
+--R     2x
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 619
+t0:=x^(2*(1+p))*(b+2*c*x^3)*(b*x+c*x^4)^p
+--R 
+--R
+--R             3      2p + 2    4       p
+--R   (1)  (2c x  + b)x      (c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 619
+r0:=1/3*x^(3+2*p)*(b+c*x^3)*(b*x+c*x^4)^p/(1+p)
+--R 
+--R
+--R            3      2p + 3    4       p
+--R        (c x  + b)x      (c x  + b x)
+--R   (2)  ------------------------------
+--R                    3p + 3
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                               4
+--R            4         (2p + 2)log(x)  p log(c x  + b x)
+--R        (c x  + b x)%e              %e
+--R   (3)  -----------------------------------------------
+--R                             3p + 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 273
+
+--S 274 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              4
+--R           4         (2p + 2)log(x)  p log(c x  + b x)
+--R       (c x  + b x)%e              %e
+--R     + 
+--R             3      2p + 3    4       p
+--R       (- c x  - b)x      (c x  + b x)
+--R  /
+--R     3p + 3
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                             4
+--R                    3               (2p + 2)log(x)  p log(c x  + b x)
+--R       ((6c p + 6c)x  + 3b p + 3b)%e              %e
+--R     + 
+--R              2 2p + 3                  3              2p + 2     4       p
+--R       (- 3c x x       + ((- 2c p - 3c)x  - 2b p - 3b)x      )(c x  + b x)
+--R     + 
+--R            2   6           3    2   2p + 3    4       p - 1
+--R       (- 4c p x  - 5b c p x  - b p)x      (c x  + b x)
+--R  /
+--R     3p + 3
+--R                                                    Type: Expression(Integer)
+--E 275
+
+)clear all
+
+--S 276 of 619
+t0:=x^((-1+n)*(1+p))*(b+2*c*x^n)*(b*x+c*x^(1+n))^p
+--R 
+--R
+--R             n      (n - 1)p + n - 1    n + 1       p
+--R   (1)  (2c x  + b)x                (c x      + b x)
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 619
+r0:=x^(n-p+n*p)*(b+c*x^n)*(b*x+c*x^(1+n))^p/(n*(1+p))
+--R 
+--R
+--R            n      (n - 1)p + n    n + 1       p
+--R        (c x  + b)x            (c x      + b x)
+--R   (2)  ----------------------------------------
+--R                         n p + n
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            (n + 1)log(x)         ((n - 1)p + n - 1)log(x)
+--R       (c %e              + b x)%e
+--R    *
+--R                   (n + 1)log(x)
+--R         p log(c %e              + b x)
+--R       %e
+--R  /
+--R     n p + n
+--R                                         Type: Union(Expression(Integer),...)
+--E 278
+
+--S 279 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              (n + 1)log(x)         ((n - 1)p + n - 1)log(x)
+--R         (c %e              + b x)%e
+--R      *
+--R                     (n + 1)log(x)
+--R           p log(c %e              + b x)
+--R         %e
+--R     + 
+--R             n      (n - 1)p + n    n + 1       p
+--R       (- c x  - b)x            (c x      + b x)
+--R  /
+--R     n p + n
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                           (n + 1)log(x)
+--R         ((2c n p + 2c n)%e              + (b n p + b n)x)
+--R      *
+--R                                               (n + 1)log(x)
+--R           ((n - 1)p + n - 1)log(x)  p log(c %e              + b x)
+--R         %e                        %e
+--R     + 
+--R                    n - 1 (n - 1)p + n
+--R           - c n x x     x
+--R         + 
+--R                                   n                          (n - 1)p + n - 1
+--R           (((- c n + c)p - c n)x x  + ((- b n + b)p - b n)x)x
+--R      *
+--R             n + 1       p
+--R         (c x      + b x)
+--R     + 
+--R              2     2       n 2                        n    2     (n - 1)p + n
+--R         ((- c n - c )p x (x )  + (- b c n - 2b c)p x x  - b p x)x
+--R      *
+--R             n + 1       p - 1
+--R         (c x      + b x)
+--R  /
+--R     (n p + n)x
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 619
+t0:=(-4+4*x+x^2)*(5-12*x+6*x^2+x^3)
+--R 
+--R
+--R         5      4     3      2
+--R   (1)  x  + 10x  + 8x  - 67x  + 68x - 20
+--R                                                    Type: Polynomial(Integer)
+--E 281
+
+--S 282 of 619
+r0:=1/6*(5-12*x+6*x^2+x^3)^2
+--R 
+--R
+--R        1  6     5     4   67  3      2         25
+--R   (2)  - x  + 2x  + 2x  - -- x  + 34x  - 20x + --
+--R        6                   3                    6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 282
+
+--S 283 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  6     5     4   67  3      2
+--R   (3)  - x  + 2x  + 2x  - -- x  + 34x  - 20x
+--R        6                   3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 283
+
+--S 284 of 619
+m0:=a0-r0
+--R 
+--R
+--R          25
+--R   (4)  - --
+--R           6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 284
+
+--S 285 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 285
+
+)clear all
+
+--S 286 of 619
+t0:=(2*x+x^3)*(1+4*x^2+x^4)
+--R 
+--R
+--R         7     5     3
+--R   (1)  x  + 6x  + 9x  + 2x
+--R                                                    Type: Polynomial(Integer)
+--E 286
+
+--S 287 of 619
+r0:=1/8*(1+4*x^2+x^4)^2
+--R 
+--R
+--R        1  8    6   9  4    2   1
+--R   (2)  - x  + x  + - x  + x  + -
+--R        8           4           8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 287
+
+--S 288 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  8    6   9  4    2
+--R   (3)  - x  + x  + - x  + x
+--R        8           4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 288
+
+--S 289 of 619
+m0:=a0-r0
+--R 
+--R
+--R          1
+--R   (4)  - -
+--R          8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 289
+
+--S 290 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 290
+
+)clear all
+
+--S 291 of 619
+t0:=(1+2*x)*(x+x^2)^3*(-18+7*(x+x^2)^3)^2
+--R 
+--R
+--R   (1)
+--R        19       18        17        16         15         14         13
+--R     98x   + 931x   + 3969x   + 9996x   + 16464x   + 18522x   + 13902x
+--R   + 
+--R          12        11         10         9        8        7        6        5
+--R     4368x   - 6426x   - 13321x   - 12551x  - 6804x  - 1368x  + 2016x  + 2916x
+--R   + 
+--R          4       3
+--R     1620x  + 324x
+--R                                                    Type: Polynomial(Integer)
+--E 291
+
+--S 292 of 619
+r0:=81*x^4*(1+x)^4-36*x^7*(1+x)^7+49/10*x^10*(1+x)^10
+--R 
+--R
+--R   (2)
+--R     49  20      19   441  18       17        16   6174  15       14       13
+--R     -- x   + 49x   + --- x   + 588x   + 1029x   + ---- x   + 993x   + 336x
+--R     10                2                             5
+--R   + 
+--R       1071  12        11   12551  10       9       8       7       6       5
+--R     - ---- x   - 1211x   - ----- x   - 756x  - 171x  + 288x  + 486x  + 324x
+--R         2                    10
+--R   + 
+--R        4
+--R     81x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 292
+
+--S 293 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     49  20      19   441  18       17        16   6174  15       14       13
+--R     -- x   + 49x   + --- x   + 588x   + 1029x   + ---- x   + 993x   + 336x
+--R     10                2                             5
+--R   + 
+--R       1071  12        11   12551  10       9       8       7       6       5
+--R     - ---- x   - 1211x   - ----- x   - 756x  - 171x  + 288x  + 486x  + 324x
+--R         2                    10
+--R   + 
+--R        4
+--R     81x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 293
+
+--S 294 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 294
+
+--S 295 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 295
+
+)clear all
+
+--S 296 of 619
+t0:=x^3*(1+x)^3*(1+2*x)*(-18+7*x^3*(1+x)^3)^2
+--R 
+--R
+--R   (1)
+--R        19       18        17        16         15         14         13
+--R     98x   + 931x   + 3969x   + 9996x   + 16464x   + 18522x   + 13902x
+--R   + 
+--R          12        11         10         9        8        7        6        5
+--R     4368x   - 6426x   - 13321x   - 12551x  - 6804x  - 1368x  + 2016x  + 2916x
+--R   + 
+--R          4       3
+--R     1620x  + 324x
+--R                                                    Type: Polynomial(Integer)
+--E 296
+
+--S 297 of 619
+r0:=81*x^4*(1+x)^4-36*x^7*(1+x)^7+49/10*x^10*(1+x)^10
+--R 
+--R
+--R   (2)
+--R     49  20      19   441  18       17        16   6174  15       14       13
+--R     -- x   + 49x   + --- x   + 588x   + 1029x   + ---- x   + 993x   + 336x
+--R     10                2                             5
+--R   + 
+--R       1071  12        11   12551  10       9       8       7       6       5
+--R     - ---- x   - 1211x   - ----- x   - 756x  - 171x  + 288x  + 486x  + 324x
+--R         2                    10
+--R   + 
+--R        4
+--R     81x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 297
+
+--S 298 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     49  20      19   441  18       17        16   6174  15       14       13
+--R     -- x   + 49x   + --- x   + 588x   + 1029x   + ---- x   + 993x   + 336x
+--R     10                2                             5
+--R   + 
+--R       1071  12        11   12551  10       9       8       7       6       5
+--R     - ---- x   - 1211x   - ----- x   - 756x  - 171x  + 288x  + 486x  + 324x
+--R         2                    10
+--R   + 
+--R        4
+--R     81x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 298
+
+--S 299 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 299
+
+--S 300 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 300
+
+)clear all
+
+--S 301 of 619
+t0:=(2-x^2)/(1-6*x+x^3)^5
+--R 
+--R
+--R   (1)
+--R        2
+--R     - x  + 2
+--R  /
+--R        15      13     12       11       10        9        8        7        6
+--R       x   - 30x   + 5x   + 360x   - 120x   - 2150x  + 1080x  + 6300x  - 4310x
+--R     + 
+--R              5        4        3       2
+--R       - 6696x  + 6360x  - 2155x  + 360x  - 30x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 301
+
+--S 302 of 619
+r0:=1/12/(1-6*x+x^3)^4
+--R 
+--R
+--R   (2)
+--R      1
+--R     --
+--R     12
+--R  /
+--R        12      10     9       8      7       6       5        4       3       2
+--R       x   - 24x   + 4x  + 216x  - 72x  - 858x  + 432x  + 1224x  - 860x  + 216x
+--R     + 
+--R       - 24x + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 302
+
+--S 303 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1
+--R  /
+--R          12       10      9        8       7         6        5         4
+--R       12x   - 288x   + 48x  + 2592x  - 864x  - 10296x  + 5184x  + 14688x
+--R     + 
+--R               3        2
+--R       - 10320x  + 2592x  - 288x + 12
+--R                                         Type: Union(Expression(Integer),...)
+--E 303
+
+--S 304 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 305
+
+)clear all
+
+--S 306 of 619
+t0:=(2*x+x^2)/(4+3*x^2+x^3)
+--R 
+--R
+--R            2
+--R           x  + 2x
+--R   (1)  ------------
+--R         3     2
+--R        x  + 3x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 306
+
+--S 307 of 619
+r0:=1/3*log(4+3*x^2+x^3)
+--R 
+--R
+--R             3     2
+--R        log(x  + 3x  + 4)
+--R   (2)  -----------------
+--R                3
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3     2
+--R        log(x  + 3x  + 4)
+--R   (3)  -----------------
+--R                3
+--R                                         Type: Union(Expression(Integer),...)
+--E 308
+
+--S 309 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 310
+
+)clear all
+
+--S 311 of 619
+t0:=(2-x^2)/(1-6*x+x^3)^5
+--R 
+--R
+--R   (1)
+--R        2
+--R     - x  + 2
+--R  /
+--R        15      13     12       11       10        9        8        7        6
+--R       x   - 30x   + 5x   + 360x   - 120x   - 2150x  + 1080x  + 6300x  - 4310x
+--R     + 
+--R              5        4        3       2
+--R       - 6696x  + 6360x  - 2155x  + 360x  - 30x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 311
+
+--S 312 of 619
+r0:=1/12/(1-6*x+x^3)^4
+--R 
+--R
+--R   (2)
+--R      1
+--R     --
+--R     12
+--R  /
+--R        12      10     9       8      7       6       5        4       3       2
+--R       x   - 24x   + 4x  + 216x  - 72x  - 858x  + 432x  + 1224x  - 860x  + 216x
+--R     + 
+--R       - 24x + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 312
+
+--S 313 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1
+--R  /
+--R          12       10      9        8       7         6        5         4
+--R       12x   - 288x   + 48x  + 2592x  - 864x  - 10296x  + 5184x  + 14688x
+--R     + 
+--R               3        2
+--R       - 10320x  + 2592x  - 288x + 12
+--R                                         Type: Union(Expression(Integer),...)
+--E 313
+
+--S 314 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 619
+t0:=(1+x+x^3)/(4*x+2*x^2+x^4)
+--R 
+--R
+--R           3
+--R          x  + x + 1
+--R   (1)  -------------
+--R         4     2
+--R        x  + 2x  + 4x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 316
+
+--S 317 of 619
+r0:=1/4*log(x*(4+2*x+x^3))
+--R 
+--R
+--R             4     2
+--R        log(x  + 2x  + 4x)
+--R   (2)  ------------------
+--R                 4
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4     2
+--R        log(x  + 2x  + 4x)
+--R   (3)  ------------------
+--R                 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 318
+
+--S 319 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 320
+
+)clear all
+
+--S 321 of 619
+t0:=(-1+x^3)/(-4*x+x^4)^(2/3)
+--R 
+--R
+--R            3
+--R           x  - 1
+--R   (1)  -----------
+--R         +-------+2
+--R        3| 4
+--R        \|x  - 4x
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 619
+r0:=3/4*(-4*x+x^4)^(1/3)
+--R 
+--R
+--R          +-------+
+--R         3| 4
+--R        3\|x  - 4x
+--R   (2)  -----------
+--R             4
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +-------+
+--R         3| 4
+--R        3\|x  - 4x
+--R   (3)  -----------
+--R             4
+--R                                         Type: Union(Expression(Integer),...)
+--E 323
+
+--S 324 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 325
+
+)clear all
+
+--S 326 of 619
+t0:=(2-x^2)*(6*x-x^3)^(1/4)
+--R 
+--R
+--R                   +---------+
+--R            2     4|   3
+--R   (1)  (- x  + 2)\|- x  + 6x
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 619
+r0:=4/15*(6*x-x^3)^(5/4)
+--R 
+--R
+--R                      +---------+
+--R             3       4|   3
+--R        (- 4x  + 24x)\|- x  + 6x
+--R   (2)  -------------------------
+--R                    15
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +---------+
+--R             3       4|   3
+--R        (- 4x  + 24x)\|- x  + 6x
+--R   (3)  -------------------------
+--R                    15
+--R                                         Type: Union(Expression(Integer),...)
+--E 328
+
+--S 329 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 619
+t0:=(1+x^4)*sqrt(5*x+x^5)
+--R 
+--R
+--R                 +-------+
+--R          4      | 5
+--R   (1)  (x  + 1)\|x  + 5x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 619
+r0:=2/15*(5*x+x^5)^(3/2)
+--R 
+--R
+--R                    +-------+
+--R           5        | 5
+--R        (2x  + 10x)\|x  + 5x
+--R   (2)  ---------------------
+--R                  15
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    +-------+
+--R           5        | 5
+--R        (2x  + 10x)\|x  + 5x
+--R   (3)  ---------------------
+--R                  15
+--R                                         Type: Union(Expression(Integer),...)
+--E 333
+
+--S 334 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 335
+
+)clear all
+
+--S 336 of 619
+t0:=(2+5*x^4)*sqrt(2*x+x^5)
+--R 
+--R
+--R                  +-------+
+--R           4      | 5
+--R   (1)  (5x  + 2)\|x  + 2x
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 619
+r0:=2/3*(2*x+x^5)^(3/2)
+--R 
+--R
+--R                   +-------+
+--R           5       | 5
+--R        (2x  + 4x)\|x  + 2x
+--R   (2)  --------------------
+--R                  3
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +-------+
+--R           5       | 5
+--R        (2x  + 4x)\|x  + 2x
+--R   (3)  --------------------
+--R                  3
+--R                                         Type: Union(Expression(Integer),...)
+--E 338
+
+--S 339 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 340
+
+)clear all
+
+--S 341 of 619
+t0:=(x+3*x^2)/sqrt(x^2+2*x^3)
+--R 
+--R
+--R            2
+--R          3x  + x
+--R   (1)  -----------
+--R         +--------+
+--R         |  3    2
+--R        \|2x  + x
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 619
+r0:=sqrt(x^2+2*x^3)
+--R 
+--R
+--R         +--------+
+--R         |  3    2
+--R   (2)  \|2x  + x
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +------+
+--R   (3)  x\|2x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 343
+
+--S 344 of 619
+m0:=a0-r0
+--R 
+--R
+--R           +--------+
+--R           |  3    2      +------+
+--R   (4)  - \|2x  + x   + x\|2x + 1
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R                 +--------+
+--R                 |  3    2         2      +------+
+--R        (3x + 1)\|2x  + x   + (- 3x  - x)\|2x + 1
+--R   (5)  ------------------------------------------
+--R                             +--------+
+--R                    +------+ |  3    2
+--R                   \|2x + 1 \|2x  + x
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 619
+t0:=(2+(1-5*x)^(1/3))/(3+(1-5*x)^(1/3))
+--R 
+--R
+--R        3+--------+
+--R        \|- 5x + 1  + 2
+--R   (1)  ---------------
+--R        3+--------+
+--R        \|- 5x + 1  + 3
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 619
+r0:=-9/5*(1-5*x)^(1/3)+3/10*(1-5*x)^(2/3)+x+27/5*log(3+(1-5*x)^(1/3))
+--R 
+--R
+--R              3+--------+         3+--------+2     3+--------+
+--R        54log(\|- 5x + 1  + 3) + 3\|- 5x + 1   - 18\|- 5x + 1  + 10x
+--R   (2)  ------------------------------------------------------------
+--R                                     10
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3+--------+         3+--------+2     3+--------+
+--R        54log(\|- 5x + 1  + 3) + 3\|- 5x + 1   - 18\|- 5x + 1  + 10x
+--R   (3)  ------------------------------------------------------------
+--R                                     10
+--R                                         Type: Union(Expression(Integer),...)
+--E 348
+
+--S 349 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 350
+
+)clear all
+
+--S 351 of 619
+t0:=(1+sqrt(x))/(-1+sqrt(x))
+--R 
+--R
+--R         +-+
+--R        \|x  + 1
+--R   (1)  --------
+--R         +-+
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 619
+r0:=x+4*log(1-sqrt(x))+4*sqrt(x)
+--R 
+--R
+--R                +-+          +-+
+--R   (2)  4log(- \|x  + 1) + 4\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +-+          +-+
+--R   (3)  4log(\|x  - 1) + 4\|x  + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 353
+
+--S 354 of 619
+m0:=a0-r0
+--R 
+--R
+--R              +-+                +-+
+--R   (4)  4log(\|x  - 1) - 4log(- \|x  + 1)
+--R                                                    Type: Expression(Integer)
+--E 354
+
+--S 355 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 355
+
+)clear all
+
+--S 356 of 619
+t0:=(1-sqrt(2+3*x))/(1+sqrt(2+3*x))
+--R 
+--R
+--R           +------+
+--R        - \|3x + 2  + 1
+--R   (1)  ---------------
+--R          +------+
+--R         \|3x + 2  + 1
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 619
+r0:=-x-4/3*log(1+sqrt(2+3*x))+4/3*sqrt(2+3*x)
+--R 
+--R
+--R                +------+          +------+
+--R        - 4log(\|3x + 2  + 1) + 4\|3x + 2  - 3x
+--R   (2)  ---------------------------------------
+--R                           3
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +------+          +------+
+--R        - 4log(\|3x + 2  + 1) + 4\|3x + 2  - 3x
+--R   (3)  ---------------------------------------
+--R                           3
+--R                                         Type: Union(Expression(Integer),...)
+--E 358
+
+--S 359 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 619
+t0:=(-1+sqrt(a+b*x))/(1+sqrt(a+b*x))
+--R 
+--R
+--R         +-------+
+--R        \|b x + a  - 1
+--R   (1)  --------------
+--R         +-------+
+--R        \|b x + a  + 1
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 619
+r0:=x+4*log(1+sqrt(a+b*x))/b-4*sqrt(a+b*x)/b
+--R 
+--R
+--R              +-------+          +-------+
+--R        4log(\|b x + a  + 1) - 4\|b x + a  + b x
+--R   (2)  ----------------------------------------
+--R                            b
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +-------+          +-------+
+--R        4log(\|b x + a  + 1) - 4\|b x + a  + b x
+--R   (3)  ----------------------------------------
+--R                            b
+--R                                         Type: Union(Expression(Integer),...)
+--E 363
+
+--S 364 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 365
+
+)clear all
+
+--S 366 of 619
+t0:=(a+b*n*x^(-1+n))/(a*x+b*x^n)
+--R 
+--R
+--R             n - 1
+--R        b n x      + a
+--R   (1)  --------------
+--R             n
+--R          b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 619
+r0a:=log(a*x+b*x^n)
+--R 
+--R
+--R               n
+--R   (2)  log(b x  + a x)
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 619
+r0b:=n*log(x)+log(b+a*x^(1-n))
+--R 
+--R
+--R               - n + 1
+--R   (3)  log(a x        + b) + n log(x)
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                n log(x)
+--R   (4)  log(b %e         + a x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 369
+
+--S 370 of 619
+m0a:=a0-r0a
+--R 
+--R
+--R                n log(x)                 n
+--R   (5)  log(b %e         + a x) - log(b x  + a x)
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)
+--R         2   n    2     n - 1                    n log(x)          n
+--R       (b n x  - b n x x      + (a b n - a b)x)%e         + a b x x
+--R     + 
+--R                2 n - 1
+--R       - a b n x x
+--R  /
+--R       2   n        2   n log(x)        2 n    2 3
+--R     (b x x  + a b x )%e         + a b x x  + a x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 619
+m0b:=a0-r0b
+--R 
+--R
+--R                n log(x)                 - n + 1
+--R   (7)  log(b %e         + a x) - log(a x        + b) - n log(x)
+--R                                                    Type: Expression(Integer)
+--E 372
+
+--S 373 of 619
+d0:=D(m0b,x)
+--R 
+--R
+--R   (8)
+--R                     - n  n log(x)       2     2  - n + 1     2     2    - n
+--R       (a b n - a b)x   %e         + (- a n + a )x        + (a n - a )x x
+--R     + 
+--R       - a b n + a b
+--R  /
+--R           - n + 1    2   n log(x)    2   - n + 1
+--R     (a b x        + b )%e         + a x x        + a b x
+--R                                                    Type: Expression(Integer)
+--E 373
+
+)clear all
+
+--S 374 of 619
+t0:=(a+b*n*x^(-1+n))/(x^n*(b+a*x^(1-n)))
+--R 
+--R
+--R               n - 1
+--R          b n x      + a
+--R   (1)  ------------------
+--R            - n + 1      n
+--R        (a x        + b)x
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 619
+r0:=n*log(x)+log(b+a*x^(1-n))
+--R 
+--R
+--R               - n + 1
+--R   (2)  log(a x        + b) + n log(x)
+--R                                                    Type: Expression(Integer)
+--E 375
+
+--S 376 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                n log(x)
+--R   (3)  log(b %e         + a x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 376
+
+--S 377 of 619
+m0:=a0-r0
+--R 
+--R
+--R                n log(x)                 - n + 1
+--R   (4)  log(b %e         + a x) - log(a x        + b) - n log(x)
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     - n  n log(x)       2     2  - n + 1     2     2    - n
+--R       (a b n - a b)x   %e         + (- a n + a )x        + (a n - a )x x
+--R     + 
+--R       - a b n + a b
+--R  /
+--R           - n + 1    2   n log(x)    2   - n + 1
+--R     (a b x        + b )%e         + a x x        + a b x
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 619
+t0:=(-3+2*x)*(-3*x+x^2)^(2/3)
+--R 
+--R
+--R                 +-------+2
+--R                3| 2
+--R   (1)  (2x - 3)\|x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 619
+r0:=3/5*(-3*x+x^2)^(5/3)
+--R 
+--R
+--R                   +-------+2
+--R           2      3| 2
+--R        (3x  - 9x)\|x  - 3x
+--R   (2)  ---------------------
+--R                  5
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +-------+2
+--R           2      3| 2
+--R        (3x  - 9x)\|x  - 3x
+--R   (3)  ---------------------
+--R                  5
+--R                                         Type: Union(Expression(Integer),...)
+--E 381
+
+--S 382 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 383
+
+)clear all
+
+--S 384 of 619
+t0:=((-3+x)*x)^(2/3)*(-3+2*x)
+--R 
+--R
+--R                 +-------+2
+--R                3| 2
+--R   (1)  (2x - 3)\|x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 384
+
+--S 385 of 619
+r0:=3/5*(-3*x+x^2)^(5/3)
+--R 
+--R
+--R                   +-------+2
+--R           2      3| 2
+--R        (3x  - 9x)\|x  - 3x
+--R   (2)  ---------------------
+--R                  5
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +-------+2
+--R           2      3| 2
+--R        (3x  - 9x)\|x  - 3x
+--R   (3)  ---------------------
+--R                  5
+--R                                         Type: Union(Expression(Integer),...)
+--E 386
+
+--S 387 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 388
+
+)clear all
+
+--S 389 of 619
+t0:=x*(9-9*x+2*x^2)/((-3+x)*x)^(1/3)
+--R 
+--R
+--R          3     2
+--R        2x  - 9x  + 9x
+--R   (1)  --------------
+--R           +-------+
+--R          3| 2
+--R          \|x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 619
+r0:=3/5*(3-x)^2*x^2/(-(3-x)*x)^(1/3)
+--R 
+--R
+--R          4      3      2
+--R        3x  - 18x  + 27x
+--R   (2)  -----------------
+--R             +-------+
+--R            3| 2
+--R           5\|x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 390
+
+--S 391 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +-------+2
+--R           2      3| 2
+--R        (3x  - 9x)\|x  - 3x
+--R   (3)  ---------------------
+--R                  5
+--R                                         Type: Union(Expression(Integer),...)
+--E 391
+
+--S 392 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 619
+t0:=x^3/(a+b*(c+d*x)^3)
+--R 
+--R
+--R                            3
+--R                           x
+--R   (1)  ----------------------------------------
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 394
+
+--S 395 of 619
+r0:=x/(b*d^3)-1/3*(a+3*a^(1/3)*b^(2/3)*c^2+b*c^3)*log(a^(1/3)+b^(1/3)*_
+   (c+d*x))/(a^(2/3)*b^(4/3)*d^4)+1/6*(a+3*a^(1/3)*b^(2/3)*c^2+b*c^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*(c+d*x)+b^(2/3)*(c+d*x)^2)/(a^(2/3)*_
+   b^(4/3)*d^4)-c*log(a+b*(c+d*x)^3)/(b*d^4)+(a-3*a^(1/3)*b^(2/3)*c^2+_
+   b*c^3)*atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*_
+   b^(4/3)*d^4*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            2 +-+3+-+3+-+2       3      +-+
+--R         (3c \|3 \|a \|b   + (b c  + a)\|3 )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R            2 +-+3+-+3+-+2          3       +-+              3+-+   3+-+
+--R       (- 6c \|3 \|a \|b   + (- 2b c  - 2a)\|3 )log((d x + c)\|b  + \|a )
+--R     + 
+--R                                                   3+-+   3+-+
+--R           2 3+-+3+-+2      3           (2d x + 2c)\|b  - \|a
+--R       (18c  \|a \|b  - 6b c  - 6a)atan(----------------------)
+--R                                                +-+3+-+
+--R                                               \|3 \|a
+--R     + 
+--R           +-+       3 3         2 2       2         3             +-+ 3+-+2 3+-+
+--R     (- 6c\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a) + 6d x\|3 )\|a   \|b
+--R  /
+--R         4 +-+3+-+2 3+-+
+--R     6b d \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +---------------------------------------------+
+--R               |      2 8    2           4           5      2
+--R             4 |- 3a b d %%I0  - 6a b c d %%I0 + 4b c  + a c        4
+--R         (b d  |---------------------------------------------  - b d %%I0 - 3c)
+--R               |                       2 8
+--R              \|                    a b d
+--R      *
+--R         log
+--R                    2 3 2 8              3 6      2 2 3     3   4
+--R                (27a b c d %%I0 + (- 3a b c  + 21a b c  - 3a b)d )
+--R             *
+--R                 +---------------------------------------------+
+--R                 |      2 8    2           4           5      2
+--R                 |- 3a b d %%I0  - 6a b c d %%I0 + 4b c  + a c
+--R                 |---------------------------------------------
+--R                 |                       2 8
+--R                \|                    a b d
+--R            + 
+--R                 2 3 2 8    2        3 6      2 2 3     3   4
+--R              27a b c d %%I0  + (3a b c  + 60a b c  + 3a b)d %%I0
+--R            + 
+--R                 3 9        2 6     2   3     3         3 10        2 7
+--R              (2b c  - 48a b c  + 6a b c  + 2a )d x + 2b c   - 63a b c
+--R            + 
+--R                 2   4     3
+--R              21a b c  + 5a c
+--R     + 
+--R                    +---------------------------------------------+
+--R                    |      2 8    2           4           5      2
+--R                  4 |- 3a b d %%I0  - 6a b c d %%I0 + 4b c  + a c        4
+--R             - b d  |---------------------------------------------  - b d %%I0
+--R                    |                       2 8
+--R                   \|                    a b d
+--R           + 
+--R             - 3c
+--R      *
+--R         log
+--R                      2 3 2 8            3 6      2 2 3     3   4
+--R                (- 27a b c d %%I0 + (3a b c  - 21a b c  + 3a b)d )
+--R             *
+--R                 +---------------------------------------------+
+--R                 |      2 8    2           4           5      2
+--R                 |- 3a b d %%I0  - 6a b c d %%I0 + 4b c  + a c
+--R                 |---------------------------------------------
+--R                 |                       2 8
+--R                \|                    a b d
+--R            + 
+--R                 2 3 2 8    2        3 6      2 2 3     3   4
+--R              27a b c d %%I0  + (3a b c  + 60a b c  + 3a b)d %%I0
+--R            + 
+--R                 3 9        2 6     2   3     3         3 10        2 7
+--R              (2b c  - 48a b c  + 6a b c  + 2a )d x + 2b c   - 63a b c
+--R            + 
+--R                 2   4     3
+--R              21a b c  + 5a c
+--R     + 
+--R             4
+--R         2b d %%I0
+--R      *
+--R         log
+--R                   2 3 2 8    2          3 6      2 2 3     3   4
+--R              - 27a b c d %%I0  + (- 3a b c  - 60a b c  - 3a b)d %%I0
+--R            + 
+--R                3 9        2 6     2   3    3        3 10       2 7      2   4
+--R              (b c  - 24a b c  + 3a b c  + a )d x + b c   - 9a b c  - 12a b c
+--R            + 
+--R                  3
+--R              - 2a c
+--R     + 
+--R       2d x
+--R  /
+--R         4
+--R     2b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 396
+
+--S 397 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +---------------------------------------------+
+--R                               |      2 8    2           4           5      2
+--R               4 +-+3+-+2 3+-+ |- 3a b d %%I0  - 6a b c d %%I0 + 4b c  + a c
+--R           3b d \|3 \|a   \|b  |---------------------------------------------
+--R                               |                       2 8
+--R                              \|                    a b d
+--R         + 
+--R                 4 +-+3+-+2 3+-+         +-+3+-+2 3+-+
+--R           - 3b d \|3 \|a   \|b %%I - 9c\|3 \|a   \|b
+--R      *
+--R         log
+--R                    2 3 2 8              3 6      2 2 3     3   4
+--R                (27a b c d %%I0 + (- 3a b c  + 21a b c  - 3a b)d )
+--R             *
+--R                 +---------------------------------------------+
+--R                 |      2 8    2           4           5      2
+--R                 |- 3a b d %%I0  - 6a b c d %%I0 + 4b c  + a c
+--R                 |---------------------------------------------
+--R                 |                       2 8
+--R                \|                    a b d
+--R            + 
+--R                 2 3 2 8    2        3 6      2 2 3     3   4
+--R              27a b c d %%I0  + (3a b c  + 60a b c  + 3a b)d %%I0
+--R            + 
+--R                 3 9        2 6     2   3     3         3 10        2 7
+--R              (2b c  - 48a b c  + 6a b c  + 2a )d x + 2b c   - 63a b c
+--R            + 
+--R                 2   4     3
+--R              21a b c  + 5a c
+--R     + 
+--R                                 +---------------------------------------------+
+--R                                 |      2 8    2           4           5      2
+--R                 4 +-+3+-+2 3+-+ |- 3a b d %%I0  - 6a b c d %%I0 + 4b c  + a c
+--R           - 3b d \|3 \|a   \|b  |---------------------------------------------
+--R                                 |                       2 8
+--R                                \|                    a b d
+--R         + 
+--R                 4 +-+3+-+2 3+-+         +-+3+-+2 3+-+
+--R           - 3b d \|3 \|a   \|b %%I - 9c\|3 \|a   \|b
+--R      *
+--R         log
+--R                      2 3 2 8            3 6      2 2 3     3   4
+--R                (- 27a b c d %%I0 + (3a b c  - 21a b c  + 3a b)d )
+--R             *
+--R                 +---------------------------------------------+
+--R                 |      2 8    2           4           5      2
+--R                 |- 3a b d %%I0  - 6a b c d %%I0 + 4b c  + a c
+--R                 |---------------------------------------------
+--R                 |                       2 8
+--R                \|                    a b d
+--R            + 
+--R                 2 3 2 8    2        3 6      2 2 3     3   4
+--R              27a b c d %%I0  + (3a b c  + 60a b c  + 3a b)d %%I0
+--R            + 
+--R                 3 9        2 6     2   3     3         3 10        2 7
+--R              (2b c  - 48a b c  + 6a b c  + 2a )d x + 2b c   - 63a b c
+--R            + 
+--R                 2   4     3
+--R              21a b c  + 5a c
+--R     + 
+--R              2 +-+3+-+3+-+2         3      +-+
+--R         (- 3c \|3 \|a \|b   + (- b c  - a)\|3 )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R          2 +-+3+-+3+-+2        3       +-+              3+-+   3+-+
+--R       (6c \|3 \|a \|b   + (2b c  + 2a)\|3 )log((d x + c)\|b  + \|a )
+--R     + 
+--R             4 +-+3+-+2 3+-+
+--R         6b d \|3 \|a   \|b %%I0
+--R      *
+--R         log
+--R                   2 3 2 8    2          3 6      2 2 3     3   4
+--R              - 27a b c d %%I0  + (- 3a b c  - 60a b c  - 3a b)d %%I0
+--R            + 
+--R                3 9        2 6     2   3    3        3 10       2 7      2   4
+--R              (b c  - 24a b c  + 3a b c  + a )d x + b c   - 9a b c  - 12a b c
+--R            + 
+--R                  3
+--R              - 2a c
+--R     + 
+--R                                                     3+-+   3+-+
+--R             2 3+-+3+-+2      3           (2d x + 2c)\|b  - \|a
+--R       (- 18c  \|a \|b  + 6b c  + 6a)atan(----------------------)
+--R                                                  +-+3+-+
+--R                                                 \|3 \|a
+--R     + 
+--R          +-+       3 3         2 2       2         3     3+-+2 3+-+
+--R       6c\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a)\|a   \|b
+--R  /
+--R         4 +-+3+-+2 3+-+
+--R     6b d \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 398
+
+)clear all
+
+--S 399 of 619
+t0:=x^2/(a+b*(c+d*x)^3)
+--R 
+--R
+--R                            2
+--R                           x
+--R   (1)  ----------------------------------------
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 399
+
+--S 400 of 619
+r0:=1/3*c*(2*a^(1/3)+b^(1/3)*c)*log(a^(1/3)+b^(1/3)*(c+d*x))/(a^(2/3)*_
+   b^(2/3)*d^3)-1/6*c*(2*a^(1/3)+b^(1/3)*c)*log(a^(2/3)-a^(1/3)*b^(1/3)*_
+   (c+d*x)+b^(2/3)*(c+d*x)^2)/(a^(2/3)*b^(2/3)*d^3)+1/3*log(a+b*(c+_
+   d*x)^3)/(b*d^3)+c*(2*a^(1/3)-b^(1/3)*c)*atan((a^(1/3)-2*b^(1/3)*_
+   (c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(2/3)*d^3*sqrt(3))
+--R 
+--R
+--R   (2)
+--R               2 +-+3+-+        +-+3+-+
+--R         (- b c \|3 \|b  - 2b c\|3 \|a )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R            2 +-+3+-+        +-+3+-+              3+-+   3+-+
+--R       (2b c \|3 \|b  + 4b c\|3 \|a )log((d x + c)\|b  + \|a )
+--R     + 
+--R                                              3+-+   3+-+
+--R            2 3+-+       3+-+      (2d x + 2c)\|b  - \|a
+--R       (6b c  \|b - 12b c\|a )atan(----------------------)
+--R                                           +-+3+-+
+--R                                          \|3 \|a
+--R     + 
+--R         +-+       3 3         2 2       2         3     3+-+2 3+-+2
+--R       2\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a)\|a   \|b
+--R  /
+--R         3 +-+3+-+2 3+-+2
+--R     6b d \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +----------------------------------------+
+--R               |      2 6    2         3           3
+--R             3 |- 9a b d %%J0  + 6a b d %%J0 + 8b c  - a       3
+--R         (b d  |----------------------------------------  - b d %%J0 + 1)
+--R               |                     2 6
+--R              \|                 3a b d
+--R      *
+--R         log
+--R                    2 2 6            2 3     2   3
+--R                (18a b d %%J0 + (3a b c  - 6a b)d )
+--R             *
+--R                 +----------------------------------------+
+--R                 |      2 6    2         3           3
+--R                 |- 9a b d %%J0  + 6a b d %%J0 + 8b c  - a
+--R                 |----------------------------------------
+--R                 |                     2 6
+--R                \|                 3a b d
+--R            + 
+--R                 2 2 6    2          2 3      2   3          2 5          2
+--R              18a b d %%J0  + (- 3a b c  - 12a b)d %%J0 + (2b c  - 16a b c )d x
+--R            + 
+--R                2 6          3     2
+--R              2b c  - 23a b c  + 2a
+--R     + 
+--R                 +----------------------------------------+
+--R                 |      2 6    2         3           3
+--R               3 |- 9a b d %%J0  + 6a b d %%J0 + 8b c  - a       3
+--R         (- b d  |----------------------------------------  - b d %%J0 + 1)
+--R                 |                     2 6
+--R                \|                 3a b d
+--R      *
+--R         log
+--R                      2 2 6              2 3     2   3
+--R                (- 18a b d %%J0 + (- 3a b c  + 6a b)d )
+--R             *
+--R                 +----------------------------------------+
+--R                 |      2 6    2         3           3
+--R                 |- 9a b d %%J0  + 6a b d %%J0 + 8b c  - a
+--R                 |----------------------------------------
+--R                 |                     2 6
+--R                \|                 3a b d
+--R            + 
+--R                 2 2 6    2          2 3      2   3          2 5          2
+--R              18a b d %%J0  + (- 3a b c  - 12a b)d %%J0 + (2b c  - 16a b c )d x
+--R            + 
+--R                2 6          3     2
+--R              2b c  - 23a b c  + 2a
+--R     + 
+--R             3
+--R         2b d %%J0
+--R      *
+--R         log
+--R                   2 2 6    2        2 3      2   3         2 5         2
+--R              - 18a b d %%J0  + (3a b c  + 12a b)d %%J0 + (b c  - 8a b c )d x
+--R            + 
+--R               2 6        3     2
+--R              b c  - a b c  - 2a
+--R  /
+--R         3
+--R     2b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 401
+
+--S 402 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +----------------------------------------+
+--R                                |      2 6    2         3           3
+--R               3 +-+3+-+2 3+-+2 |- 9a b d %%J0  + 6a b d %%J0 + 8b c  - a
+--R           3b d \|3 \|a   \|b   |----------------------------------------
+--R                                |                     2 6
+--R                               \|                 3a b d
+--R         + 
+--R                 3 +-+3+-+2 3+-+2        +-+3+-+2 3+-+2
+--R           - 3b d \|3 \|a   \|b  %%J + 3\|3 \|a   \|b
+--R      *
+--R         log
+--R                    2 2 6            2 3     2   3
+--R                (18a b d %%J0 + (3a b c  - 6a b)d )
+--R             *
+--R                 +----------------------------------------+
+--R                 |      2 6    2         3           3
+--R                 |- 9a b d %%J0  + 6a b d %%J0 + 8b c  - a
+--R                 |----------------------------------------
+--R                 |                     2 6
+--R                \|                 3a b d
+--R            + 
+--R                 2 2 6    2          2 3      2   3          2 5          2
+--R              18a b d %%J0  + (- 3a b c  - 12a b)d %%J0 + (2b c  - 16a b c )d x
+--R            + 
+--R                2 6          3     2
+--R              2b c  - 23a b c  + 2a
+--R     + 
+--R                                  +----------------------------------------+
+--R                                  |      2 6    2         3           3
+--R                 3 +-+3+-+2 3+-+2 |- 9a b d %%J0  + 6a b d %%J0 + 8b c  - a
+--R           - 3b d \|3 \|a   \|b   |----------------------------------------
+--R                                  |                     2 6
+--R                                 \|                 3a b d
+--R         + 
+--R                 3 +-+3+-+2 3+-+2        +-+3+-+2 3+-+2
+--R           - 3b d \|3 \|a   \|b  %%J + 3\|3 \|a   \|b
+--R      *
+--R         log
+--R                      2 2 6              2 3     2   3
+--R                (- 18a b d %%J0 + (- 3a b c  + 6a b)d )
+--R             *
+--R                 +----------------------------------------+
+--R                 |      2 6    2         3           3
+--R                 |- 9a b d %%J0  + 6a b d %%J0 + 8b c  - a
+--R                 |----------------------------------------
+--R                 |                     2 6
+--R                \|                 3a b d
+--R            + 
+--R                 2 2 6    2          2 3      2   3          2 5          2
+--R              18a b d %%J0  + (- 3a b c  - 12a b)d %%J0 + (2b c  - 16a b c )d x
+--R            + 
+--R                2 6          3     2
+--R              2b c  - 23a b c  + 2a
+--R     + 
+--R             2 +-+3+-+        +-+3+-+
+--R         (b c \|3 \|b  + 2b c\|3 \|a )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R              2 +-+3+-+        +-+3+-+              3+-+   3+-+
+--R       (- 2b c \|3 \|b  - 4b c\|3 \|a )log((d x + c)\|b  + \|a )
+--R     + 
+--R             3 +-+3+-+2 3+-+2
+--R         6b d \|3 \|a   \|b  %%J0
+--R      *
+--R         log
+--R                   2 2 6    2        2 3      2   3         2 5         2
+--R              - 18a b d %%J0  + (3a b c  + 12a b)d %%J0 + (b c  - 8a b c )d x
+--R            + 
+--R               2 6        3     2
+--R              b c  - a b c  - 2a
+--R     + 
+--R                                                3+-+   3+-+
+--R              2 3+-+       3+-+      (2d x + 2c)\|b  - \|a
+--R       (- 6b c  \|b + 12b c\|a )atan(----------------------)
+--R                                             +-+3+-+
+--R                                            \|3 \|a
+--R     + 
+--R           +-+       3 3         2 2       2         3     3+-+2 3+-+2
+--R       - 2\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a)\|a   \|b
+--R  /
+--R         3 +-+3+-+2 3+-+2
+--R     6b d \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 402
+
+--S 403 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 403
+
+)clear all
+
+--S 404 of 619
+t0:=x/(a+b*(c+d*x)^3)
+--R 
+--R
+--R                            x
+--R   (1)  ----------------------------------------
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 404
+
+--S 405 of 619
+r0:=-1/3*(a^(1/3)+b^(1/3)*c)*log(a^(1/3)+b^(1/3)*(c+d*x))/(a^(2/3)*b^(2/3)*_
+   d^2)+1/6*(a^(1/3)+b^(1/3)*c)*log(a^(2/3)-a^(1/3)*b^(1/3)*(c+d*x)+_
+   b^(2/3)*(c+d*x)^2)/(a^(2/3)*b^(2/3)*d^2)-(a^(1/3)-b^(1/3)*c)*_
+   atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*_
+   b^(2/3)*d^2*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +-+3+-+    +-+3+-+
+--R         (c\|3 \|b  + \|3 \|a )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R             +-+3+-+     +-+3+-+              3+-+   3+-+
+--R       (- 2c\|3 \|b  - 2\|3 \|a )log((d x + c)\|b  + \|a )
+--R     + 
+--R                                         3+-+   3+-+
+--R            3+-+    3+-+      (2d x + 2c)\|b  - \|a
+--R       (- 6c\|b  + 6\|a )atan(----------------------)
+--R                                      +-+3+-+
+--R                                     \|3 \|a
+--R  /
+--R       2 +-+3+-+2 3+-+2
+--R     6d \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 405
+
+--S 406 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-------------------+
+--R           |        4    2
+--R           |- 9a b d %%K0  + 4c
+--R         ( |-------------------  - %%K0)
+--R           |            4
+--R          \|      3a b d
+--R      *
+--R         log
+--R                                        +-------------------+
+--R                                        |        4    2
+--R                 2   4             2 2  |- 9a b d %%K0  + 4c      2   4    2
+--R              (9a b d %%K0 - 3a b c d ) |-------------------  + 9a b d %%K0
+--R                                        |            4
+--R                                       \|      3a b d
+--R            + 
+--R                    2 2            3                4
+--R              3a b c d %%K0 + (2b c  - 2a)d x + 2b c  - 4a c
+--R     + 
+--R             +-------------------+
+--R             |        4    2
+--R             |- 9a b d %%K0  + 4c
+--R         (-  |-------------------  - %%K0)
+--R             |            4
+--R            \|      3a b d
+--R      *
+--R         log
+--R                                          +-------------------+
+--R                                          |        4    2
+--R                   2   4             2 2  |- 9a b d %%K0  + 4c      2   4    2
+--R              (- 9a b d %%K0 + 3a b c d ) |-------------------  + 9a b d %%K0
+--R                                          |            4
+--R                                         \|      3a b d
+--R            + 
+--R                    2 2            3                4
+--R              3a b c d %%K0 + (2b c  - 2a)d x + 2b c  - 4a c
+--R     + 
+--R                     2   4    2         2 2           3              4
+--R       2%%K0 log(- 9a b d %%K0  - 3a b c d %%K0 + (b c  - a)d x + b c  + a c)
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 406
+
+--S 407 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +-------------------+
+--R                             |        4    2
+--R            2 +-+3+-+2 3+-+2 |- 9a b d %%K0  + 4c     2 +-+3+-+2 3+-+2
+--R         (3d \|3 \|a   \|b   |------------------- - 3d \|3 \|a   \|b  %%K)
+--R                             |            4
+--R                            \|      3a b d
+--R      *
+--R         log
+--R                                        +-------------------+
+--R                                        |        4    2
+--R                 2   4             2 2  |- 9a b d %%K0  + 4c      2   4    2
+--R              (9a b d %%K0 - 3a b c d ) |-------------------  + 9a b d %%K0
+--R                                        |            4
+--R                                       \|      3a b d
+--R            + 
+--R                    2 2            3                4
+--R              3a b c d %%K0 + (2b c  - 2a)d x + 2b c  - 4a c
+--R     + 
+--R                               +-------------------+
+--R                               |        4    2
+--R              2 +-+3+-+2 3+-+2 |- 9a b d %%K0  + 4c     2 +-+3+-+2 3+-+2
+--R         (- 3d \|3 \|a   \|b   |------------------- - 3d \|3 \|a   \|b  %%K)
+--R                               |            4
+--R                              \|      3a b d
+--R      *
+--R         log
+--R                                          +-------------------+
+--R                                          |        4    2
+--R                   2   4             2 2  |- 9a b d %%K0  + 4c      2   4    2
+--R              (- 9a b d %%K0 + 3a b c d ) |-------------------  + 9a b d %%K0
+--R                                          |            4
+--R                                         \|      3a b d
+--R            + 
+--R                    2 2            3                4
+--R              3a b c d %%K0 + (2b c  - 2a)d x + 2b c  - 4a c
+--R     + 
+--R              +-+3+-+    +-+3+-+
+--R         (- c\|3 \|b  - \|3 \|a )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R           +-+3+-+     +-+3+-+              3+-+   3+-+
+--R       (2c\|3 \|b  + 2\|3 \|a )log((d x + c)\|b  + \|a )
+--R     + 
+--R           2 +-+3+-+2 3+-+2
+--R         6d \|3 \|a   \|b  %%K0
+--R      *
+--R                 2   4    2         2 2           3              4
+--R         log(- 9a b d %%K0  - 3a b c d %%K0 + (b c  - a)d x + b c  + a c)
+--R     + 
+--R                                       3+-+   3+-+
+--R          3+-+    3+-+      (2d x + 2c)\|b  - \|a
+--R       (6c\|b  - 6\|a )atan(----------------------)
+--R                                    +-+3+-+
+--R                                   \|3 \|a
+--R  /
+--R       2 +-+3+-+2 3+-+2
+--R     6d \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 619
+t0:=1/(a+b*(c+d*x)^3)
+--R 
+--R
+--R                            1
+--R   (1)  ----------------------------------------
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 409
+
+--S 410 of 619
+r0:=1/3*log(a^(1/3)+b^(1/3)*(c+d*x))/(a^(2/3)*b^(1/3)*d)-1/6*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*(c+d*x)+b^(2/3)*(c+d*x)^2)/(a^(2/3)*b^(1/3)*d)-_
+   atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(1/3)*_
+   d*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          +-+      2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R       - \|3 log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R                                                         3+-+   3+-+
+--R         +-+             3+-+   3+-+          (2d x + 2c)\|b  - \|a
+--R       2\|3 log((d x + c)\|b  + \|a ) + 6atan(----------------------)
+--R                                                      +-+3+-+
+--R                                                     \|3 \|a
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6d\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                      +---+2                   +---+
+--R          +-+      2 2             2 3| 2                     3| 2      2
+--R       - \|3 log((d x  + 2c d x + c )\|a b   + (- a d x - a c)\|a b  + a )
+--R     + 
+--R                                                             +---+
+--R                          +---+                          +-+3| 2       +-+
+--R         +-+             3| 2                (2d x + 2c)\|3 \|a b  - a\|3
+--R       2\|3 log((d x + c)\|a b  + a) + 6atan(-----------------------------)
+--R                                                           3a
+--R  /
+--R            +---+
+--R        +-+3| 2
+--R     6d\|3 \|a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 411
+
+--S 412 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R             +-+3+-+2 3+-+
+--R            \|3 \|a   \|b
+--R         *
+--R                                     +---+2                   +---+
+--R                  2 2             2 3| 2                     3| 2      2
+--R            log((d x  + 2c d x + c )\|a b   + (- a d x - a c)\|a b  + a )
+--R     + 
+--R                                    +---+
+--R         +-+3+-+2 3+-+             3| 2
+--R       2\|3 \|a   \|b log((d x + c)\|a b  + a)
+--R     + 
+--R            +---+
+--R        +-+3| 2        2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R       \|3 \|a b log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R               +---+
+--R           +-+3| 2               3+-+   3+-+
+--R       - 2\|3 \|a b log((d x + c)\|b  + \|a )
+--R     + 
+--R                                       +---+
+--R                                   +-+3| 2       +-+
+--R        3+-+2 3+-+     (2d x + 2c)\|3 \|a b  - a\|3
+--R       6\|a   \|b atan(-----------------------------)
+--R                                     3a
+--R     + 
+--R           +---+                3+-+   3+-+
+--R          3| 2       (2d x + 2c)\|b  - \|a
+--R       - 6\|a b atan(----------------------)
+--R                             +-+3+-+
+--R                            \|3 \|a
+--R  /
+--R                      +---+
+--R        +-+3+-+2 3+-+3| 2
+--R     6d\|3 \|a   \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 413
+
+)clear all
+
+--S 414 of 619
+t0:=1/(x*(a+b*(c+d*x)^3))
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R           3 4         2 3       2   2       3
+--R        b d x  + 3b c d x  + 3b c d x  + (b c  + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 414
+
+--S 415 of 619
+r0a:=log(x)/(a+b*c^3)-1/3*log(a^(1/3)+b^(1/3)*(c+d*x))/(a^(2/3)*(a^(1/3)+_
+   b^(1/3)*c))-1/6*(2*a^(1/3)-b^(1/3)*c)*log(a^(2/3)-a^(1/3)*b^(1/3)*_
+   (c+d*x)+b^(2/3)*(c+d*x)^2)/(a^(2/3)*(a^(2/3)-a^(1/3)*b^(1/3)*c+b^(2/3)*_
+   c^2))+b^(1/3)*c*atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/_
+   (a^(2/3)*(a^(2/3)-a^(1/3)*b^(1/3)*c+b^(2/3)*c^2)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              4        +-+3+-+3+-+          3       +-+3+-+2
+--R         ((b c  + a c)\|3 \|a \|b  + (- 2b c  - 2a)\|3 \|a  )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R                   2 +-+3+-+2          4         +-+3+-+3+-+
+--R             - 6a c \|3 \|b   + (- 2b c  + 4a c)\|3 \|a \|b
+--R           + 
+--R                  3       +-+3+-+2
+--R             (4b c  - 2a)\|3 \|a
+--R      *
+--R                      3+-+   3+-+
+--R         log((d x + c)\|b  + \|a )
+--R     + 
+--R                                               3+-+   3+-+
+--R              4        3+-+3+-+     (2d x + 2c)\|b  - \|a
+--R       (- 6b c  - 6a c)\|a \|b atan(----------------------)
+--R                                            +-+3+-+
+--R                                           \|3 \|a
+--R     + 
+--R           2 +-+      3+-+2        +-+      3+-+3+-+      +-+      3+-+2
+--R       6a c \|3 log(x)\|b   - 6a c\|3 log(x)\|a \|b  + 6a\|3 log(x)\|a
+--R  /
+--R              5     2 2  +-+3+-+2            4     2   +-+3+-+3+-+
+--R       (6a b c  + 6a c )\|3 \|b   + (- 6a b c  - 6a c)\|3 \|a \|b
+--R     + 
+--R              3     2  +-+3+-+2
+--R       (6a b c  + 6a )\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 619
+r0b:=log(x)/(a+b*c^3)+1/3*b^(1/3)*c*(a^(1/3)-b^(1/3)*c)*log(a^(1/3)+b^(1/3)*_
+   (c+d*x))/(a^(2/3)*(a+b*c^3))-1/6*b^(1/3)*c*(a^(1/3)-b^(1/3)*c)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*(c+d*x)+b^(2/3)*(c+d*x)^2)/(a^(2/3)*_
+   (a+b*c^3))-1/3*log(a+b*(c+d*x)^3)/(a+b*c^3)+b^(1/3)*c*(a^(1/3)+_
+   b^(1/3)*c)*atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*_
+   (a+b*c^3)*sqrt(3))
+--R 
+--R
+--R   (3)
+--R           2 +-+3+-+2     +-+3+-+3+-+
+--R         (c \|3 \|b   - c\|3 \|a \|b )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R            2 +-+3+-+2      +-+3+-+3+-+              3+-+   3+-+
+--R       (- 2c \|3 \|b   + 2c\|3 \|a \|b )log((d x + c)\|b  + \|a )
+--R     + 
+--R                                                3+-+   3+-+
+--R            2 3+-+2    3+-+3+-+      (2d x + 2c)\|b  - \|a
+--R       (- 6c  \|b  - 6c\|a \|b )atan(----------------------)
+--R                                             +-+3+-+
+--R                                            \|3 \|a
+--R     + 
+--R          +-+       3 3         2 2       2         3          +-+       3+-+2
+--R     (- 2\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a) + 6\|3 log(x))\|a
+--R  /
+--R          3       +-+3+-+2
+--R     (6b c  + 6a)\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R                   3
+--R             (- b c  - a)
+--R          *
+--R             ROOT
+--R                           2 6      2   3     3     2            3     2
+--R                    (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                  + 
+--R                          3
+--R                    - 4b c  - a
+--R               /
+--R                      2 6     2   3     3
+--R                  3a b c  + 6a b c  + 3a
+--R         + 
+--R                 3
+--R           (- b c  - a)%%M0 - 1
+--R      *
+--R         log
+--R                    2   3     3              3     2
+--R                ((9a b c  + 9a )%%M0 + 3a b c  + 3a )
+--R             *
+--R                ROOT
+--R                              2 6      2   3     3     2            3     2
+--R                       (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                     + 
+--R                             3
+--R                       - 4b c  - a
+--R                  /
+--R                         2 6     2   3     3
+--R                     3a b c  + 6a b c  + 3a
+--R            + 
+--R                 2   3     3     2          3     2            2          3
+--R            (- 9a b c  - 9a )%%M0  + (3a b c  - 6a )%%M0 + 2b c d x + 2b c  - a
+--R     + 
+--R                 3
+--R             (b c  + a)
+--R          *
+--R             ROOT
+--R                           2 6      2   3     3     2            3     2
+--R                    (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                  + 
+--R                          3
+--R                    - 4b c  - a
+--R               /
+--R                      2 6     2   3     3
+--R                  3a b c  + 6a b c  + 3a
+--R         + 
+--R                 3
+--R           (- b c  - a)%%M0 - 1
+--R      *
+--R         log
+--R                      2   3     3              3     2
+--R                ((- 9a b c  - 9a )%%M0 - 3a b c  - 3a )
+--R             *
+--R                ROOT
+--R                              2 6      2   3     3     2            3     2
+--R                       (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                     + 
+--R                             3
+--R                       - 4b c  - a
+--R                  /
+--R                         2 6     2   3     3
+--R                     3a b c  + 6a b c  + 3a
+--R            + 
+--R                 2   3     3     2          3     2            2          3
+--R            (- 9a b c  - 9a )%%M0  + (3a b c  - 6a )%%M0 + 2b c d x + 2b c  - a
+--R     + 
+--R              3
+--R         (2b c  + 2a)%%M0
+--R      *
+--R                2   3     3     2            3     2           2         3
+--R         log((9a b c  + 9a )%%M0  + (- 3a b c  + 6a )%%M0 + b c d x + b c  + a)
+--R     + 
+--R       2log(x)
+--R  /
+--R         3
+--R     2b c  + 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 417
+
+--S 418 of 619
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R                        5     2 2  +-+3+-+2          4     2   +-+3+-+3+-+
+--R               (- 3a b c  - 3a c )\|3 \|b   + (3a b c  + 3a c)\|3 \|a \|b
+--R             + 
+--R                        3     2  +-+3+-+2
+--R               (- 3a b c  - 3a )\|3 \|a
+--R          *
+--R             ROOT
+--R                           2 6      2   3     3     2            3     2
+--R                    (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                  + 
+--R                          3
+--R                    - 4b c  - a
+--R               /
+--R                      2 6     2   3     3
+--R                  3a b c  + 6a b c  + 3a
+--R         + 
+--R                        5     2 2  +-+3+-+2          4     2   +-+3+-+3+-+
+--R               (- 3a b c  - 3a c )\|3 \|b   + (3a b c  + 3a c)\|3 \|a \|b
+--R             + 
+--R                        3     2  +-+3+-+2
+--R               (- 3a b c  - 3a )\|3 \|a
+--R          *
+--R             %%M0
+--R         + 
+--R                 2 +-+3+-+2        +-+3+-+3+-+      +-+3+-+2
+--R           - 3a c \|3 \|b   + 3a c\|3 \|a \|b  - 3a\|3 \|a
+--R      *
+--R         log
+--R                    2   3     3              3     2
+--R                ((9a b c  + 9a )%%M0 + 3a b c  + 3a )
+--R             *
+--R                ROOT
+--R                              2 6      2   3     3     2            3     2
+--R                       (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                     + 
+--R                             3
+--R                       - 4b c  - a
+--R                  /
+--R                         2 6     2   3     3
+--R                     3a b c  + 6a b c  + 3a
+--R            + 
+--R                 2   3     3     2          3     2            2          3
+--R            (- 9a b c  - 9a )%%M0  + (3a b c  - 6a )%%M0 + 2b c d x + 2b c  - a
+--R     + 
+--R                      5     2 2  +-+3+-+2            4     2   +-+3+-+3+-+
+--R               (3a b c  + 3a c )\|3 \|b   + (- 3a b c  - 3a c)\|3 \|a \|b
+--R             + 
+--R                      3     2  +-+3+-+2
+--R               (3a b c  + 3a )\|3 \|a
+--R          *
+--R             ROOT
+--R                           2 6      2   3     3     2            3     2
+--R                    (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                  + 
+--R                          3
+--R                    - 4b c  - a
+--R               /
+--R                      2 6     2   3     3
+--R                  3a b c  + 6a b c  + 3a
+--R         + 
+--R                        5     2 2  +-+3+-+2          4     2   +-+3+-+3+-+
+--R               (- 3a b c  - 3a c )\|3 \|b   + (3a b c  + 3a c)\|3 \|a \|b
+--R             + 
+--R                        3     2  +-+3+-+2
+--R               (- 3a b c  - 3a )\|3 \|a
+--R          *
+--R             %%M0
+--R         + 
+--R                 2 +-+3+-+2        +-+3+-+3+-+      +-+3+-+2
+--R           - 3a c \|3 \|b   + 3a c\|3 \|a \|b  - 3a\|3 \|a
+--R      *
+--R         log
+--R                      2   3     3              3     2
+--R                ((- 9a b c  - 9a )%%M0 - 3a b c  - 3a )
+--R             *
+--R                ROOT
+--R                              2 6      2   3     3     2            3     2
+--R                       (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                     + 
+--R                             3
+--R                       - 4b c  - a
+--R                  /
+--R                         2 6     2   3     3
+--R                     3a b c  + 6a b c  + 3a
+--R            + 
+--R                 2   3     3     2          3     2            2          3
+--R            (- 9a b c  - 9a )%%M0  + (3a b c  - 6a )%%M0 + 2b c d x + 2b c  - a
+--R     + 
+--R                  5     2 2  +-+3+-+2            4     2   +-+3+-+3+-+
+--R           (6a b c  + 6a c )\|3 \|b   + (- 6a b c  - 6a c)\|3 \|a \|b
+--R         + 
+--R                  3     2  +-+3+-+2
+--R           (6a b c  + 6a )\|3 \|a
+--R      *
+--R         %%M0
+--R      *
+--R                2   3     3     2            3     2           2         3
+--R         log((9a b c  + 9a )%%M0  + (- 3a b c  + 6a )%%M0 + b c d x + b c  + a)
+--R     + 
+--R                4        +-+3+-+3+-+        3       +-+3+-+2
+--R         ((- b c  - a c)\|3 \|a \|b  + (2b c  + 2a)\|3 \|a  )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R              2 +-+3+-+2        4         +-+3+-+3+-+          3       +-+3+-+2
+--R         (6a c \|3 \|b   + (2b c  - 4a c)\|3 \|a \|b  + (- 4b c  + 2a)\|3 \|a  )
+--R      *
+--R                      3+-+   3+-+
+--R         log((d x + c)\|b  + \|a )
+--R     + 
+--R                                             3+-+   3+-+
+--R            4        3+-+3+-+     (2d x + 2c)\|b  - \|a
+--R       (6b c  + 6a c)\|a \|b atan(----------------------)
+--R                                          +-+3+-+
+--R                                         \|3 \|a
+--R  /
+--R              5     2 2  +-+3+-+2            4     2   +-+3+-+3+-+
+--R       (6a b c  + 6a c )\|3 \|b   + (- 6a b c  - 6a c)\|3 \|a \|b
+--R     + 
+--R              3     2  +-+3+-+2
+--R       (6a b c  + 6a )\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 619
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R                    3       +-+3+-+2
+--R             (- 3b c  - 3a)\|3 \|a
+--R          *
+--R             ROOT
+--R                           2 6      2   3     3     2            3     2
+--R                    (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                  + 
+--R                          3
+--R                    - 4b c  - a
+--R               /
+--R                      2 6     2   3     3
+--R                  3a b c  + 6a b c  + 3a
+--R         + 
+--R                  3       +-+3+-+2         +-+3+-+2
+--R           (- 3b c  - 3a)\|3 \|a  %%M0 - 3\|3 \|a
+--R      *
+--R         log
+--R                    2   3     3              3     2
+--R                ((9a b c  + 9a )%%M0 + 3a b c  + 3a )
+--R             *
+--R                ROOT
+--R                              2 6      2   3     3     2            3     2
+--R                       (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                     + 
+--R                             3
+--R                       - 4b c  - a
+--R                  /
+--R                         2 6     2   3     3
+--R                     3a b c  + 6a b c  + 3a
+--R            + 
+--R                 2   3     3     2          3     2            2          3
+--R            (- 9a b c  - 9a )%%M0  + (3a b c  - 6a )%%M0 + 2b c d x + 2b c  - a
+--R     + 
+--R                  3       +-+3+-+2
+--R             (3b c  + 3a)\|3 \|a
+--R          *
+--R             ROOT
+--R                           2 6      2   3     3     2            3     2
+--R                    (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                  + 
+--R                          3
+--R                    - 4b c  - a
+--R               /
+--R                      2 6     2   3     3
+--R                  3a b c  + 6a b c  + 3a
+--R         + 
+--R                  3       +-+3+-+2         +-+3+-+2
+--R           (- 3b c  - 3a)\|3 \|a  %%M0 - 3\|3 \|a
+--R      *
+--R         log
+--R                      2   3     3              3     2
+--R                ((- 9a b c  - 9a )%%M0 - 3a b c  - 3a )
+--R             *
+--R                ROOT
+--R                              2 6      2   3     3     2            3     2
+--R                       (- 9a b c  - 18a b c  - 9a )%%M0  + (- 6a b c  - 6a )%%M0
+--R                     + 
+--R                             3
+--R                       - 4b c  - a
+--R                  /
+--R                         2 6     2   3     3
+--R                     3a b c  + 6a b c  + 3a
+--R            + 
+--R                 2   3     3     2          3     2            2          3
+--R            (- 9a b c  - 9a )%%M0  + (3a b c  - 6a )%%M0 + 2b c d x + 2b c  - a
+--R     + 
+--R              3       +-+3+-+2
+--R         (6b c  + 6a)\|3 \|a  %%M0
+--R      *
+--R                2   3     3     2            3     2           2         3
+--R         log((9a b c  + 9a )%%M0  + (- 3a b c  + 6a )%%M0 + b c d x + b c  + a)
+--R     + 
+--R             2 +-+3+-+2     +-+3+-+3+-+
+--R         (- c \|3 \|b   + c\|3 \|a \|b )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R          2 +-+3+-+2      +-+3+-+3+-+              3+-+   3+-+
+--R       (2c \|3 \|b   - 2c\|3 \|a \|b )log((d x + c)\|b  + \|a )
+--R     + 
+--R                                              3+-+   3+-+
+--R          2 3+-+2    3+-+3+-+      (2d x + 2c)\|b  - \|a
+--R       (6c  \|b  + 6c\|a \|b )atan(----------------------)
+--R                                           +-+3+-+
+--R                                          \|3 \|a
+--R     + 
+--R         +-+       3 3         2 2       2         3     3+-+2
+--R       2\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a)\|a
+--R  /
+--R          3       +-+3+-+2
+--R     (6b c  + 6a)\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 420
+
+--S 421 of 619
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 421
+
+)clear all
+
+--S 422 of 619
+t0:=1/(x^2*(a+b*(c+d*x)^3))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R           3 5         2 4       2   3       3      2
+--R        b d x  + 3b c d x  + 3b c d x  + (b c  + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 422
+
+--S 423 of 619
+r0:=(-1)/((a+b*c^3)*x)-3*b*c^2*d*log(x)/(a+b*c^3)^2+1/3*b^(1/3)*(a^(1/3)*_
+   (a-2*b*c^3)-b^(1/3)*(2*a*c-b*c^4))*d*log(a^(1/3)+b^(1/3)*(c+d*x))/_
+   (a^(2/3)*(a+b*c^3)^2)-1/6*b^(1/3)*(a^(1/3)*(a-2*b*c^3)-b^(1/3)*_
+   (2*a*c-b*c^4))*d*log(a^(2/3)-a^(1/3)*b^(1/3)*(c+d*x)+b^(2/3)*_
+   (c+d*x)^2)/(a^(2/3)*(a+b*c^3)^2)+b*c^2*d*log(a+b*(c+d*x)^3)/(a+b*c^3)^2+_
+   b^(1/3)*(a^(1/3)-b^(1/3)*c)*(a^(1/3)+b^(1/3)*c)^3*d*atan((a^(1/3)-_
+   2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*(a+b*c^3)^2*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                4            +-+3+-+2        3         +-+3+-+3+-+
+--R         ((- b c  + 2a c)d x\|3 \|b   + (2b c  - a)d x\|3 \|a \|b )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R               4            +-+3+-+2          3          +-+3+-+3+-+
+--R         ((2b c  - 4a c)d x\|3 \|b   + (- 4b c  + 2a)d x\|3 \|a \|b )
+--R      *
+--R                      3+-+   3+-+
+--R         log((d x + c)\|b  + \|a )
+--R     + 
+--R               4             3+-+2         3         3+-+3+-+
+--R         ((6b c  - 12a c)d x \|b   + (12b c  - 6a)d x\|a \|b )
+--R      *
+--R                         3+-+   3+-+
+--R              (2d x + 2c)\|b  - \|a
+--R         atan(----------------------)
+--R                      +-+3+-+
+--R                     \|3 \|a
+--R     + 
+--R               2    +-+       3 3         2 2       2         3
+--R           6b c d x\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a)
+--R         + 
+--R                  2    +-+                3       +-+
+--R           - 18b c d x\|3 log(x) + (- 6b c  - 6a)\|3
+--R      *
+--R         3+-+2
+--R         \|a
+--R  /
+--R        2 6          3     2   +-+3+-+2
+--R     (6b c  + 12a b c  + 6a )x\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 423
+
+--S 424 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2 6         3    2
+--R             (- b c  - 2a b c  - a )x
+--R          *
+--R             ROOT
+--R                           4 12      2 3 9      3 2 6      4   3     5     2
+--R                    (- 9a b c   - 36a b c  - 54a b c  - 36a b c  - 9a )%%N0
+--R                  + 
+--R                          3 8      2 2 5      3   2
+--R                    (18a b c  + 36a b c  + 18a b c )d %%N0
+--R                  + 
+--R                         3 7        2 4     2     2
+--R                    (- 8b c  + 11a b c  - 8a b c)d
+--R               /
+--R                      4 12      2 3 9      3 2 6      4   3     5
+--R                  3a b c   + 12a b c  + 18a b c  + 12a b c  + 3a
+--R         + 
+--R               2 6         3    2              2
+--R           (- b c  - 2a b c  - a )x %%N0 + 3b c d x
+--R      *
+--R         log
+--R                      2 3 9      3 2 6     5
+--R                  (18a b c  + 27a b c  - 9a )%%N0
+--R                + 
+--R                         3 8     2 2 5     3   2
+--R                  (- 3a b c  - 6a b c  - 3a b c )d
+--R             *
+--R                ROOT
+--R                              4 12      2 3 9      3 2 6      4   3     5     2
+--R                       (- 9a b c   - 36a b c  - 54a b c  - 36a b c  - 9a )%%N0
+--R                     + 
+--R                             3 8      2 2 5      3   2
+--R                       (18a b c  + 36a b c  + 18a b c )d %%N0
+--R                     + 
+--R                            3 7        2 4     2     2
+--R                       (- 8b c  + 11a b c  - 8a b c)d
+--R                  /
+--R                         4 12      2 3 9      3 2 6      4   3     5
+--R                     3a b c   + 12a b c  + 18a b c  + 12a b c  + 3a
+--R            + 
+--R                    2 3 9      3 2 6     5     2
+--R              (- 18a b c  - 27a b c  + 9a )%%N0
+--R            + 
+--R                     3 8      2 2 5      3   2             3 6     2   3
+--R              (- 3a b c  + 48a b c  - 30a b c )d %%N0 + (2b c  - 2a b)d x
+--R            + 
+--R                 3 7       2 4     2     2
+--R              (2b c  - 5a b c  + 2a b c)d
+--R     + 
+--R               2 6         3    2
+--R             (b c  + 2a b c  + a )x
+--R          *
+--R             ROOT
+--R                           4 12      2 3 9      3 2 6      4   3     5     2
+--R                    (- 9a b c   - 36a b c  - 54a b c  - 36a b c  - 9a )%%N0
+--R                  + 
+--R                          3 8      2 2 5      3   2
+--R                    (18a b c  + 36a b c  + 18a b c )d %%N0
+--R                  + 
+--R                         3 7        2 4     2     2
+--R                    (- 8b c  + 11a b c  - 8a b c)d
+--R               /
+--R                      4 12      2 3 9      3 2 6      4   3     5
+--R                  3a b c   + 12a b c  + 18a b c  + 12a b c  + 3a
+--R         + 
+--R               2 6         3    2              2
+--R           (- b c  - 2a b c  - a )x %%N0 + 3b c d x
+--R      *
+--R         log
+--R                        2 3 9      3 2 6     5
+--R                  (- 18a b c  - 27a b c  + 9a )%%N0
+--R                + 
+--R                       3 8     2 2 5     3   2
+--R                  (3a b c  + 6a b c  + 3a b c )d
+--R             *
+--R                ROOT
+--R                              4 12      2 3 9      3 2 6      4   3     5     2
+--R                       (- 9a b c   - 36a b c  - 54a b c  - 36a b c  - 9a )%%N0
+--R                     + 
+--R                             3 8      2 2 5      3   2
+--R                       (18a b c  + 36a b c  + 18a b c )d %%N0
+--R                     + 
+--R                            3 7        2 4     2     2
+--R                       (- 8b c  + 11a b c  - 8a b c)d
+--R                  /
+--R                         4 12      2 3 9      3 2 6      4   3     5
+--R                     3a b c   + 12a b c  + 18a b c  + 12a b c  + 3a
+--R            + 
+--R                    2 3 9      3 2 6     5     2
+--R              (- 18a b c  - 27a b c  + 9a )%%N0
+--R            + 
+--R                     3 8      2 2 5      3   2             3 6     2   3
+--R              (- 3a b c  + 48a b c  - 30a b c )d %%N0 + (2b c  - 2a b)d x
+--R            + 
+--R                 3 7       2 4     2     2
+--R              (2b c  - 5a b c  + 2a b c)d
+--R     + 
+--R            2 6         3     2
+--R         (2b c  + 4a b c  + 2a )x %%N0
+--R      *
+--R         log
+--R                  2 3 9      3 2 6     5     2
+--R              (18a b c  + 27a b c  - 9a )%%N0
+--R            + 
+--R                   3 8      2 2 5      3   2            3 6    2   3
+--R              (3a b c  - 48a b c  + 30a b c )d %%N0 + (b c  - a b)d x
+--R            + 
+--R                3 7       2 4     2     2
+--R              (b c  + 5a b c  - 5a b c)d
+--R     + 
+--R             2                 3
+--R       - 6b c d x log(x) - 2b c  - 2a
+--R  /
+--R        2 6         3     2
+--R     (2b c  + 4a b c  + 2a )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 424
+
+--S 425 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  2 6         3     2  +-+3+-+2
+--R             (- 3b c  - 6a b c  - 3a )\|3 \|a
+--R          *
+--R             ROOT
+--R                           4 12      2 3 9      3 2 6      4   3     5     2
+--R                    (- 9a b c   - 36a b c  - 54a b c  - 36a b c  - 9a )%%N0
+--R                  + 
+--R                          3 8      2 2 5      3   2
+--R                    (18a b c  + 36a b c  + 18a b c )d %%N0
+--R                  + 
+--R                         3 7        2 4     2     2
+--R                    (- 8b c  + 11a b c  - 8a b c)d
+--R               /
+--R                      4 12      2 3 9      3 2 6      4   3     5
+--R                  3a b c   + 12a b c  + 18a b c  + 12a b c  + 3a
+--R         + 
+--R                2 6         3     2  +-+3+-+2           2  +-+3+-+2
+--R           (- 3b c  - 6a b c  - 3a )\|3 \|a  %%N0 + 9b c d\|3 \|a
+--R      *
+--R         log
+--R                      2 3 9      3 2 6     5
+--R                  (18a b c  + 27a b c  - 9a )%%N0
+--R                + 
+--R                         3 8     2 2 5     3   2
+--R                  (- 3a b c  - 6a b c  - 3a b c )d
+--R             *
+--R                ROOT
+--R                              4 12      2 3 9      3 2 6      4   3     5     2
+--R                       (- 9a b c   - 36a b c  - 54a b c  - 36a b c  - 9a )%%N0
+--R                     + 
+--R                             3 8      2 2 5      3   2
+--R                       (18a b c  + 36a b c  + 18a b c )d %%N0
+--R                     + 
+--R                            3 7        2 4     2     2
+--R                       (- 8b c  + 11a b c  - 8a b c)d
+--R                  /
+--R                         4 12      2 3 9      3 2 6      4   3     5
+--R                     3a b c   + 12a b c  + 18a b c  + 12a b c  + 3a
+--R            + 
+--R                    2 3 9      3 2 6     5     2
+--R              (- 18a b c  - 27a b c  + 9a )%%N0
+--R            + 
+--R                     3 8      2 2 5      3   2             3 6     2   3
+--R              (- 3a b c  + 48a b c  - 30a b c )d %%N0 + (2b c  - 2a b)d x
+--R            + 
+--R                 3 7       2 4     2     2
+--R              (2b c  - 5a b c  + 2a b c)d
+--R     + 
+--R                2 6         3     2  +-+3+-+2
+--R             (3b c  + 6a b c  + 3a )\|3 \|a
+--R          *
+--R             ROOT
+--R                           4 12      2 3 9      3 2 6      4   3     5     2
+--R                    (- 9a b c   - 36a b c  - 54a b c  - 36a b c  - 9a )%%N0
+--R                  + 
+--R                          3 8      2 2 5      3   2
+--R                    (18a b c  + 36a b c  + 18a b c )d %%N0
+--R                  + 
+--R                         3 7        2 4     2     2
+--R                    (- 8b c  + 11a b c  - 8a b c)d
+--R               /
+--R                      4 12      2 3 9      3 2 6      4   3     5
+--R                  3a b c   + 12a b c  + 18a b c  + 12a b c  + 3a
+--R         + 
+--R                2 6         3     2  +-+3+-+2           2  +-+3+-+2
+--R           (- 3b c  - 6a b c  - 3a )\|3 \|a  %%N0 + 9b c d\|3 \|a
+--R      *
+--R         log
+--R                        2 3 9      3 2 6     5
+--R                  (- 18a b c  - 27a b c  + 9a )%%N0
+--R                + 
+--R                       3 8     2 2 5     3   2
+--R                  (3a b c  + 6a b c  + 3a b c )d
+--R             *
+--R                ROOT
+--R                              4 12      2 3 9      3 2 6      4   3     5     2
+--R                       (- 9a b c   - 36a b c  - 54a b c  - 36a b c  - 9a )%%N0
+--R                     + 
+--R                             3 8      2 2 5      3   2
+--R                       (18a b c  + 36a b c  + 18a b c )d %%N0
+--R                     + 
+--R                            3 7        2 4     2     2
+--R                       (- 8b c  + 11a b c  - 8a b c)d
+--R                  /
+--R                         4 12      2 3 9      3 2 6      4   3     5
+--R                     3a b c   + 12a b c  + 18a b c  + 12a b c  + 3a
+--R            + 
+--R                    2 3 9      3 2 6     5     2
+--R              (- 18a b c  - 27a b c  + 9a )%%N0
+--R            + 
+--R                     3 8      2 2 5      3   2             3 6     2   3
+--R              (- 3a b c  + 48a b c  - 30a b c )d %%N0 + (2b c  - 2a b)d x
+--R            + 
+--R                 3 7       2 4     2     2
+--R              (2b c  - 5a b c  + 2a b c)d
+--R     + 
+--R            2 6          3     2  +-+3+-+2
+--R         (6b c  + 12a b c  + 6a )\|3 \|a  %%N0
+--R      *
+--R         log
+--R                  2 3 9      3 2 6     5     2
+--R              (18a b c  + 27a b c  - 9a )%%N0
+--R            + 
+--R                   3 8      2 2 5      3   2            3 6    2   3
+--R              (3a b c  - 48a b c  + 30a b c )d %%N0 + (b c  - a b)d x
+--R            + 
+--R                3 7       2 4     2     2
+--R              (b c  + 5a b c  - 5a b c)d
+--R     + 
+--R              4          +-+3+-+2          3       +-+3+-+3+-+
+--R         ((b c  - 2a c)d\|3 \|b   + (- 2b c  + a)d\|3 \|a \|b )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R                 4          +-+3+-+2        3        +-+3+-+3+-+
+--R         ((- 2b c  + 4a c)d\|3 \|b   + (4b c  - 2a)d\|3 \|a \|b )
+--R      *
+--R                      3+-+   3+-+
+--R         log((d x + c)\|b  + \|a )
+--R     + 
+--R                 4           3+-+2           3       3+-+3+-+
+--R         ((- 6b c  + 12a c)d \|b   + (- 12b c  + 6a)d\|a \|b )
+--R      *
+--R                         3+-+   3+-+
+--R              (2d x + 2c)\|b  - \|a
+--R         atan(----------------------)
+--R                      +-+3+-+
+--R                     \|3 \|a
+--R     + 
+--R             2  +-+       3 3         2 2       2         3     3+-+2
+--R       - 6b c d\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a)\|a
+--R  /
+--R        2 6          3     2  +-+3+-+2
+--R     (6b c  + 12a b c  + 6a )\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 619
+t0:=1/(x^3*(a+b*(c+d*x)^3))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R           3 6         2 5       2   4       3      3
+--R        b d x  + 3b c d x  + 3b c d x  + (b c  + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 427
+
+--S 428 of 619
+r0:=(-1/2)/((a+b*c^3)*x^2)+3*b*c^2*d/((a+b*c^3)^2*x)-3*b*c*(a-2*b*c^3)*d^2*_
+   log(x)/(a+b*c^3)^3-1/3*b^(2/3)*(a^2-7*a*b*c^3+b^2*c^6+3*a^(1/3)*_
+   b^(2/3)*c^2*(2*a-b*c^3))*d^2*log(a^(1/3)+b^(1/3)*(c+d*x))/(a^(2/3)*_
+   (a+b*c^3)^3)+1/6*b^(2/3)*(a^2-7*a*b*c^3+b^2*c^6+3*a^(1/3)*b^(2/3)*_
+   c^2*(2*a-b*c^3))*d^2*log(a^(2/3)-a^(1/3)*b^(1/3)*(c+d*x)+b^(2/3)*_
+   (c+d*x)^2)/(a^(2/3)*(a+b*c^3)^3)+b*c*(a-2*b*c^3)*d^2*log(a+b*(c+d*_
+   x)^3)/(a+b*c^3)^3+b^(2/3)*(a^(1/3)+b^(1/3)*c)^3*(a-3*a^(2/3)*b^(1/3)*c+_
+   b*c^3)*d^2*atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/_
+   (a^(2/3)*(a+b*c^3)^3*sqrt(3))
+--R 
+--R
+--R   (2)
+--R             2 6         3    2  2 2 +-+3+-+2
+--R           (b c  - 7a b c  + a )d x \|3 \|b
+--R         + 
+--R                2 5         2  2 2 +-+3+-+3+-+
+--R           (- 3b c  + 6a b c )d x \|3 \|a \|b
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R                2 6          3     2  2 2 +-+3+-+2
+--R           (- 2b c  + 14a b c  - 2a )d x \|3 \|b
+--R         + 
+--R              2 5          2  2 2 +-+3+-+3+-+
+--R           (6b c  - 12a b c )d x \|3 \|a \|b
+--R      *
+--R                      3+-+   3+-+
+--R         log((d x + c)\|b  + \|a )
+--R     + 
+--R                  2 6          3     2  2 2 3+-+2
+--R             (- 6b c  + 42a b c  - 6a )d x  \|b
+--R           + 
+--R                   2 5          2  2 2 3+-+3+-+
+--R             (- 18b c  + 36a b c )d x  \|a \|b
+--R      *
+--R                         3+-+   3+-+
+--R              (2d x + 2c)\|b  - \|a
+--R         atan(----------------------)
+--R                      +-+3+-+
+--R                     \|3 \|a
+--R     + 
+--R                   2 4           2 2 +-+
+--R             (- 12b c  + 6a b c)d x \|3
+--R          *
+--R                    3 3         2 2       2         3
+--R             log(b d x  + 3b c d x  + 3b c d x + b c  + a)
+--R         + 
+--R               2 4            2 2 +-+
+--R           (36b c  - 18a b c)d x \|3 log(x)
+--R         + 
+--R                2 5          2         2 6         3     2  +-+
+--R           ((18b c  + 18a b c )d x - 3b c  - 6a b c  - 3a )\|3
+--R      *
+--R         3+-+2
+--R         \|a
+--R  /
+--R        3 9        2 6      2   3     3  2 +-+3+-+2
+--R     (6b c  + 18a b c  + 18a b c  + 6a )x \|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3 9       2 6     2   3    3  2
+--R             (- b c  - 3a b c  - 3a b c  - a )x
+--R          *
+--R             ROOT
+--R                              6 18      2 5 15      3 4 12      4 3 9      5 2 6
+--R                        - 3a b c   - 18a b c   - 45a b c   - 60a b c  - 45a b c
+--R                      + 
+--R                             6   3     7
+--R                        - 18a b c  - 3a
+--R                   *
+--R                          2
+--R                      %%O0
+--R                  + 
+--R                              5 13      2 4 10      3 3 7     4 2 4     5     2
+--R                      (- 12a b c   - 30a b c   - 18a b c  + 6a b c  + 6a b c)d
+--R                   *
+--R                      %%O0
+--R                  + 
+--R                         5 11        4 8      2 3 5     3 2 2  4
+--R                    (- 4b c   + 24a b c  - 48a b c  + 5a b c )d
+--R               /
+--R                       6 18     2 5 15      3 4 12      4 3 9      5 2 6
+--R                    a b c   + 6a b c   + 15a b c   + 20a b c  + 15a b c
+--R                  + 
+--R                      6   3    7
+--R                    6a b c  + a
+--R         + 
+--R               3 9       2 6     2   3    3  2            2 4           2 2
+--R           (- b c  - 3a b c  - 3a b c  - a )x %%O0 + (- 6b c  + 3a b c)d x
+--R      *
+--R         log
+--R                      2 4 14      3 3 11      4 2 8       5   5      6 2
+--R                  (27a b c   + 27a b c   - 81a b c  - 135a b c  - 54a c )%%O0
+--R                + 
+--R                       4 12      2 3 9      3 2 6      4   3     5  2
+--R                  (3a b c   + 12a b c  + 18a b c  + 12a b c  + 3a )d
+--R             *
+--R                ROOT
+--R                                 6 18      2 5 15      3 4 12      4 3 9
+--R                           - 3a b c   - 18a b c   - 45a b c   - 60a b c
+--R                         + 
+--R                                5 2 6      6   3     7
+--R                           - 45a b c  - 18a b c  - 3a
+--R                      *
+--R                             2
+--R                         %%O0
+--R                     + 
+--R                                 5 13      2 4 10      3 3 7     4 2 4     5
+--R                         (- 12a b c   - 30a b c   - 18a b c  + 6a b c  + 6a b c)
+--R                      *
+--R                          2
+--R                         d %%O0
+--R                     + 
+--R                            5 11        4 8      2 3 5     3 2 2  4
+--R                       (- 4b c   + 24a b c  - 48a b c  + 5a b c )d
+--R                  /
+--R                          6 18     2 5 15      3 4 12      4 3 9      5 2 6
+--R                       a b c   + 6a b c   + 15a b c   + 20a b c  + 15a b c
+--R                     + 
+--R                         6   3    7
+--R                       6a b c  + a
+--R            + 
+--R                    2 4 14      3 3 11      4 2 8       5   5      6 2     2
+--R              (- 27a b c   - 27a b c   + 81a b c  + 135a b c  + 54a c )%%O0
+--R            + 
+--R                   4 12       2 3 9       3 2 6       4   3     5  2
+--R              (3a b c   - 150a b c  + 423a b c  - 150a b c  + 3a )d %%O0
+--R            + 
+--R                 4 9       3 6      2 2 3     3   5
+--R              (2b c  + 6a b c  - 48a b c  + 2a b)d x
+--R            + 
+--R                 4 10       3 7     2 2 4    3     4
+--R              (2b c   - 6a b c  - 9a b c  - a b c)d
+--R     + 
+--R               3 9       2 6     2   3    3  2
+--R             (b c  + 3a b c  + 3a b c  + a )x
+--R          *
+--R             ROOT
+--R                              6 18      2 5 15      3 4 12      4 3 9      5 2 6
+--R                        - 3a b c   - 18a b c   - 45a b c   - 60a b c  - 45a b c
+--R                      + 
+--R                             6   3     7
+--R                        - 18a b c  - 3a
+--R                   *
+--R                          2
+--R                      %%O0
+--R                  + 
+--R                              5 13      2 4 10      3 3 7     4 2 4     5     2
+--R                      (- 12a b c   - 30a b c   - 18a b c  + 6a b c  + 6a b c)d
+--R                   *
+--R                      %%O0
+--R                  + 
+--R                         5 11        4 8      2 3 5     3 2 2  4
+--R                    (- 4b c   + 24a b c  - 48a b c  + 5a b c )d
+--R               /
+--R                       6 18     2 5 15      3 4 12      4 3 9      5 2 6
+--R                    a b c   + 6a b c   + 15a b c   + 20a b c  + 15a b c
+--R                  + 
+--R                      6   3    7
+--R                    6a b c  + a
+--R         + 
+--R               3 9       2 6     2   3    3  2            2 4           2 2
+--R           (- b c  - 3a b c  - 3a b c  - a )x %%O0 + (- 6b c  + 3a b c)d x
+--R      *
+--R         log
+--R                        2 4 14      3 3 11      4 2 8       5   5      6 2
+--R                  (- 27a b c   - 27a b c   + 81a b c  + 135a b c  + 54a c )%%O0
+--R                + 
+--R                         4 12      2 3 9      3 2 6      4   3     5  2
+--R                  (- 3a b c   - 12a b c  - 18a b c  - 12a b c  - 3a )d
+--R             *
+--R                ROOT
+--R                                 6 18      2 5 15      3 4 12      4 3 9
+--R                           - 3a b c   - 18a b c   - 45a b c   - 60a b c
+--R                         + 
+--R                                5 2 6      6   3     7
+--R                           - 45a b c  - 18a b c  - 3a
+--R                      *
+--R                             2
+--R                         %%O0
+--R                     + 
+--R                                 5 13      2 4 10      3 3 7     4 2 4     5
+--R                         (- 12a b c   - 30a b c   - 18a b c  + 6a b c  + 6a b c)
+--R                      *
+--R                          2
+--R                         d %%O0
+--R                     + 
+--R                            5 11        4 8      2 3 5     3 2 2  4
+--R                       (- 4b c   + 24a b c  - 48a b c  + 5a b c )d
+--R                  /
+--R                          6 18     2 5 15      3 4 12      4 3 9      5 2 6
+--R                       a b c   + 6a b c   + 15a b c   + 20a b c  + 15a b c
+--R                     + 
+--R                         6   3    7
+--R                       6a b c  + a
+--R            + 
+--R                    2 4 14      3 3 11      4 2 8       5   5      6 2     2
+--R              (- 27a b c   - 27a b c   + 81a b c  + 135a b c  + 54a c )%%O0
+--R            + 
+--R                   4 12       2 3 9       3 2 6       4   3     5  2
+--R              (3a b c   - 150a b c  + 423a b c  - 150a b c  + 3a )d %%O0
+--R            + 
+--R                 4 9       3 6      2 2 3     3   5
+--R              (2b c  + 6a b c  - 48a b c  + 2a b)d x
+--R            + 
+--R                 4 10       3 7     2 2 4    3     4
+--R              (2b c   - 6a b c  - 9a b c  - a b c)d
+--R     + 
+--R            3 9       2 6     2   3     3  2
+--R         (2b c  + 6a b c  + 6a b c  + 2a )x %%O0
+--R      *
+--R         log
+--R                  2 4 14      3 3 11      4 2 8       5   5      6 2     2
+--R              (27a b c   + 27a b c   - 81a b c  - 135a b c  - 54a c )%%O0
+--R            + 
+--R                     4 12       2 3 9       3 2 6       4   3     5  2
+--R              (- 3a b c   + 150a b c  - 423a b c  + 150a b c  - 3a )d %%O0
+--R            + 
+--R                4 9       3 6      2 2 3    3   5
+--R              (b c  + 3a b c  - 24a b c  + a b)d x
+--R            + 
+--R                4 10        3 7      2 2 4     3     4
+--R              (b c   + 15a b c  - 63a b c  + 4a b c)d
+--R     + 
+--R           2 4           2 2            2 5         2        2 6         3    2
+--R       (12b c  - 6a b c)d x log(x) + (6b c  + 6a b c )d x - b c  - 2a b c  - a
+--R  /
+--R        3 9       2 6     2   3     3  2
+--R     (2b c  + 6a b c  + 6a b c  + 2a )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 429
+
+--S 430 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  3 9       2 6     2   3     3  +-+3+-+2
+--R             (- 3b c  - 9a b c  - 9a b c  - 3a )\|3 \|a
+--R          *
+--R             ROOT
+--R                              6 18      2 5 15      3 4 12      4 3 9      5 2 6
+--R                        - 3a b c   - 18a b c   - 45a b c   - 60a b c  - 45a b c
+--R                      + 
+--R                             6   3     7
+--R                        - 18a b c  - 3a
+--R                   *
+--R                          2
+--R                      %%O0
+--R                  + 
+--R                              5 13      2 4 10      3 3 7     4 2 4     5     2
+--R                      (- 12a b c   - 30a b c   - 18a b c  + 6a b c  + 6a b c)d
+--R                   *
+--R                      %%O0
+--R                  + 
+--R                         5 11        4 8      2 3 5     3 2 2  4
+--R                    (- 4b c   + 24a b c  - 48a b c  + 5a b c )d
+--R               /
+--R                       6 18     2 5 15      3 4 12      4 3 9      5 2 6
+--R                    a b c   + 6a b c   + 15a b c   + 20a b c  + 15a b c
+--R                  + 
+--R                      6   3    7
+--R                    6a b c  + a
+--R         + 
+--R                3 9       2 6     2   3     3  +-+3+-+2
+--R           (- 3b c  - 9a b c  - 9a b c  - 3a )\|3 \|a  %%O0
+--R         + 
+--R                 2 4           2 +-+3+-+2
+--R           (- 18b c  + 9a b c)d \|3 \|a
+--R      *
+--R         log
+--R                      2 4 14      3 3 11      4 2 8       5   5      6 2
+--R                  (27a b c   + 27a b c   - 81a b c  - 135a b c  - 54a c )%%O0
+--R                + 
+--R                       4 12      2 3 9      3 2 6      4   3     5  2
+--R                  (3a b c   + 12a b c  + 18a b c  + 12a b c  + 3a )d
+--R             *
+--R                ROOT
+--R                                 6 18      2 5 15      3 4 12      4 3 9
+--R                           - 3a b c   - 18a b c   - 45a b c   - 60a b c
+--R                         + 
+--R                                5 2 6      6   3     7
+--R                           - 45a b c  - 18a b c  - 3a
+--R                      *
+--R                             2
+--R                         %%O0
+--R                     + 
+--R                                 5 13      2 4 10      3 3 7     4 2 4     5
+--R                         (- 12a b c   - 30a b c   - 18a b c  + 6a b c  + 6a b c)
+--R                      *
+--R                          2
+--R                         d %%O0
+--R                     + 
+--R                            5 11        4 8      2 3 5     3 2 2  4
+--R                       (- 4b c   + 24a b c  - 48a b c  + 5a b c )d
+--R                  /
+--R                          6 18     2 5 15      3 4 12      4 3 9      5 2 6
+--R                       a b c   + 6a b c   + 15a b c   + 20a b c  + 15a b c
+--R                     + 
+--R                         6   3    7
+--R                       6a b c  + a
+--R            + 
+--R                    2 4 14      3 3 11      4 2 8       5   5      6 2     2
+--R              (- 27a b c   - 27a b c   + 81a b c  + 135a b c  + 54a c )%%O0
+--R            + 
+--R                   4 12       2 3 9       3 2 6       4   3     5  2
+--R              (3a b c   - 150a b c  + 423a b c  - 150a b c  + 3a )d %%O0
+--R            + 
+--R                 4 9       3 6      2 2 3     3   5
+--R              (2b c  + 6a b c  - 48a b c  + 2a b)d x
+--R            + 
+--R                 4 10       3 7     2 2 4    3     4
+--R              (2b c   - 6a b c  - 9a b c  - a b c)d
+--R     + 
+--R                3 9       2 6     2   3     3  +-+3+-+2
+--R             (3b c  + 9a b c  + 9a b c  + 3a )\|3 \|a
+--R          *
+--R             ROOT
+--R                              6 18      2 5 15      3 4 12      4 3 9      5 2 6
+--R                        - 3a b c   - 18a b c   - 45a b c   - 60a b c  - 45a b c
+--R                      + 
+--R                             6   3     7
+--R                        - 18a b c  - 3a
+--R                   *
+--R                          2
+--R                      %%O0
+--R                  + 
+--R                              5 13      2 4 10      3 3 7     4 2 4     5     2
+--R                      (- 12a b c   - 30a b c   - 18a b c  + 6a b c  + 6a b c)d
+--R                   *
+--R                      %%O0
+--R                  + 
+--R                         5 11        4 8      2 3 5     3 2 2  4
+--R                    (- 4b c   + 24a b c  - 48a b c  + 5a b c )d
+--R               /
+--R                       6 18     2 5 15      3 4 12      4 3 9      5 2 6
+--R                    a b c   + 6a b c   + 15a b c   + 20a b c  + 15a b c
+--R                  + 
+--R                      6   3    7
+--R                    6a b c  + a
+--R         + 
+--R                3 9       2 6     2   3     3  +-+3+-+2
+--R           (- 3b c  - 9a b c  - 9a b c  - 3a )\|3 \|a  %%O0
+--R         + 
+--R                 2 4           2 +-+3+-+2
+--R           (- 18b c  + 9a b c)d \|3 \|a
+--R      *
+--R         log
+--R                        2 4 14      3 3 11      4 2 8       5   5      6 2
+--R                  (- 27a b c   - 27a b c   + 81a b c  + 135a b c  + 54a c )%%O0
+--R                + 
+--R                         4 12      2 3 9      3 2 6      4   3     5  2
+--R                  (- 3a b c   - 12a b c  - 18a b c  - 12a b c  - 3a )d
+--R             *
+--R                ROOT
+--R                                 6 18      2 5 15      3 4 12      4 3 9
+--R                           - 3a b c   - 18a b c   - 45a b c   - 60a b c
+--R                         + 
+--R                                5 2 6      6   3     7
+--R                           - 45a b c  - 18a b c  - 3a
+--R                      *
+--R                             2
+--R                         %%O0
+--R                     + 
+--R                                 5 13      2 4 10      3 3 7     4 2 4     5
+--R                         (- 12a b c   - 30a b c   - 18a b c  + 6a b c  + 6a b c)
+--R                      *
+--R                          2
+--R                         d %%O0
+--R                     + 
+--R                            5 11        4 8      2 3 5     3 2 2  4
+--R                       (- 4b c   + 24a b c  - 48a b c  + 5a b c )d
+--R                  /
+--R                          6 18     2 5 15      3 4 12      4 3 9      5 2 6
+--R                       a b c   + 6a b c   + 15a b c   + 20a b c  + 15a b c
+--R                     + 
+--R                         6   3    7
+--R                       6a b c  + a
+--R            + 
+--R                    2 4 14      3 3 11      4 2 8       5   5      6 2     2
+--R              (- 27a b c   - 27a b c   + 81a b c  + 135a b c  + 54a c )%%O0
+--R            + 
+--R                   4 12       2 3 9       3 2 6       4   3     5  2
+--R              (3a b c   - 150a b c  + 423a b c  - 150a b c  + 3a )d %%O0
+--R            + 
+--R                 4 9       3 6      2 2 3     3   5
+--R              (2b c  + 6a b c  - 48a b c  + 2a b)d x
+--R            + 
+--R                 4 10       3 7     2 2 4    3     4
+--R              (2b c   - 6a b c  - 9a b c  - a b c)d
+--R     + 
+--R            3 9        2 6      2   3     3  +-+3+-+2
+--R         (6b c  + 18a b c  + 18a b c  + 6a )\|3 \|a  %%O0
+--R      *
+--R         log
+--R                  2 4 14      3 3 11      4 2 8       5   5      6 2     2
+--R              (27a b c   + 27a b c   - 81a b c  - 135a b c  - 54a c )%%O0
+--R            + 
+--R                     4 12       2 3 9       3 2 6       4   3     5  2
+--R              (- 3a b c   + 150a b c  - 423a b c  + 150a b c  - 3a )d %%O0
+--R            + 
+--R                4 9       3 6      2 2 3    3   5
+--R              (b c  + 3a b c  - 24a b c  + a b)d x
+--R            + 
+--R                4 10        3 7      2 2 4     3     4
+--R              (b c   + 15a b c  - 63a b c  + 4a b c)d
+--R     + 
+--R              2 6         3    2  2 +-+3+-+2      2 5         2  2 +-+3+-+3+-+
+--R         ((- b c  + 7a b c  - a )d \|3 \|b   + (3b c  - 6a b c )d \|3 \|a \|b )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R              2 6          3     2  2 +-+3+-+2
+--R           (2b c  - 14a b c  + 2a )d \|3 \|b
+--R         + 
+--R                2 5          2  2 +-+3+-+3+-+
+--R           (- 6b c  + 12a b c )d \|3 \|a \|b
+--R      *
+--R                      3+-+   3+-+
+--R         log((d x + c)\|b  + \|a )
+--R     + 
+--R             2 6          3     2  2 3+-+2      2 5          2  2 3+-+3+-+
+--R         ((6b c  - 42a b c  + 6a )d  \|b  + (18b c  - 36a b c )d  \|a \|b)
+--R      *
+--R                         3+-+   3+-+
+--R              (2d x + 2c)\|b  - \|a
+--R         atan(----------------------)
+--R                      +-+3+-+
+--R                     \|3 \|a
+--R     + 
+--R         2 4           2 +-+       3 3         2 2       2         3     3+-+2
+--R     (12b c  - 6a b c)d \|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a)\|a
+--R  /
+--R        3 9        2 6      2   3     3  +-+3+-+2
+--R     (6b c  + 18a b c  + 18a b c  + 6a )\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 431
+
+)clear all
+
+--S 432 of 619
+t0:=x^3/(a+b*(c+d*x)^4)
+--R 
+--R
+--R                                  3
+--R                                 x
+--R   (1)  ----------------------------------------------------
+--R           4 4         3 3       2 2 2       3         4
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 432
+
+--S 433 of 619
+r0:=1/4*log(a+b*(c+d*x)^4)/(b*d^4)+3/2*c^2*atan((c+d*x)^2*sqrt(b)/sqrt(a))/_
+   (d^4*sqrt(a)*sqrt(b))-1/4*c*log(-a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+_
+   sqrt(a)+(c+d*x)^2*sqrt(b))*(3*sqrt(a)-c^2*sqrt(b))/(a^(3/4)*b^(3/4)*_
+   d^4*sqrt(2))+1/4*c*log(a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*_
+   sqrt(b))*(3*sqrt(a)-c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^4*sqrt(2))+_
+   1/2*c*atan(1-b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))*(3*sqrt(a)+c^2*sqrt(b))/_
+   (a^(3/4)*b^(3/4)*d^4*sqrt(2))-1/2*c*atan(1+b^(1/4)*(c+d*x)*_
+   sqrt(2)/a^(1/4))*(3*sqrt(a)+c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^4*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 +-+    2 3 +-+
+--R         (3a b c\|b  - b c \|a )
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                   +-+    2 3 +-+
+--R         (- 3a b c\|b  + b c \|a )
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                                                +-+4+-+   4+-+
+--R                 +-+     2 3 +-+      (d x + c)\|2 \|b  + \|a
+--R       (- 6a b c\|b  - 2b c \|a )atan(------------------------)
+--R                                                4+-+
+--R                                                \|a
+--R     + 
+--R                                                +-+4+-+   4+-+
+--R                 +-+     2 3 +-+      (d x + c)\|2 \|b  - \|a
+--R       (- 6a b c\|b  - 2b c \|a )atan(------------------------)
+--R                                                4+-+
+--R                                                \|a
+--R     + 
+--R                                  2 2             2  +-+
+--R           2 +-+4+-+3 4+-+3     (d x  + 2c d x + c )\|b
+--R       6b c \|2 \|a   \|b  atan(------------------------)
+--R                                           +-+
+--R                                          \|a
+--R     + 
+--R          +-+       4 4         3 3       2 2 2       3         4      +-+4+-+3
+--R         \|2 log(b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a)\|a \|a
+--R      *
+--R          +-+4+-+3
+--R         \|b \|b
+--R  /
+--R         4 +-+ +-+4+-+3 +-+4+-+3
+--R     4b d \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                   4
+--R                b d
+--R             *
+--R                ROOT
+--R                             2 8    2          2 8             4
+--R                       - 6a b d %%P1  + (- 4a b d %%P0 + 4a b d )%%P1
+--R                     + 
+--R                             2 8    2         4            4
+--R                       - 6a b d %%P0  + 4a b d %%P0 - 15b c  - a
+--R                  /
+--R                         2 8
+--R                     2a b d
+--R         + 
+--R                4          4
+--R           - b d %%P1 - b d %%P0 + 1
+--R      *
+--R         log
+--R                           3 4 4       4 3  12
+--R                      (480a b c  + 864a b )d  %%P0
+--R                    + 
+--R                            2 4 8       3 3 4       4 2  8
+--R                      (- 24a b c  + 528a b c  - 216a b )d
+--R                 *
+--R                    %%P1
+--R                + 
+--R                        2 4 8       3 3 4       4 2  8
+--R                  (- 24a b c  + 528a b c  - 216a b )d %%P0
+--R                + 
+--R                       4 12       2 3 8      3 2 4      4   4
+--R                  (2a b c   - 150a b c  + 30a b c  + 54a b)d
+--R             *
+--R                ROOT
+--R                             2 8    2          2 8             4
+--R                       - 6a b d %%P1  + (- 4a b d %%P0 + 4a b d )%%P1
+--R                     + 
+--R                             2 8    2         4            4
+--R                       - 6a b d %%P0  + 4a b d %%P0 - 15b c  - a
+--R                  /
+--R                         2 8
+--R                     2a b d
+--R            + 
+--R                         3 4 4       4 3  12
+--R                  (- 480a b c  - 864a b )d  %%P0
+--R                + 
+--R                      2 4 8       3 3 4       4 2  8
+--R                  (24a b c  - 528a b c  + 216a b )d
+--R             *
+--R                    2
+--R                %%P1
+--R            + 
+--R                         3 4 4       4 3  12    2        3 3 4       4 2  8
+--R                  (- 480a b c  - 864a b )d  %%P0  + (480a b c  + 864a b )d %%P0
+--R                + 
+--R                       4 12       2 3 8       3 2 4       4   4
+--R                  (2a b c   - 174a b c  + 558a b c  - 162a b)d
+--R             *
+--R                %%P1
+--R            + 
+--R                  2 4 8       3 3 4       4 2  8    2
+--R              (24a b c  - 528a b c  + 216a b )d %%P0
+--R            + 
+--R                   4 12       2 3 8       3 2 4       4   4
+--R              (2a b c   - 174a b c  + 558a b c  - 162a b)d %%P0
+--R            + 
+--R                4 15         3 11        2 2 7       3   3        4 16
+--R              (b c   - 117a b c   - 1053a b c  + 729a b c )d x + b c
+--R            + 
+--R                      3 12        2 2 8        3   4      4
+--R              - 118a b c   - 1860a b c  + 1230a b c  + 27a
+--R     + 
+--R                4
+--R             b d
+--R          *
+--R             ROOT
+--R                          2 8    2          2 8             4
+--R                    - 6a b d %%P1  + (- 4a b d %%P0 + 4a b d )%%P1
+--R                  + 
+--R                          2 8    2         4            4
+--R                    - 6a b d %%P0  + 4a b d %%P0 - 15b c  - a
+--R               /
+--R                      2 8
+--R                  2a b d
+--R         + 
+--R                4          4
+--R           - b d %%P1 - b d %%P0 + 1
+--R      *
+--R         log
+--R                             3 4 4       4 3  12
+--R                      (- 480a b c  - 864a b )d  %%P0
+--R                    + 
+--R                          2 4 8       3 3 4       4 2  8
+--R                      (24a b c  - 528a b c  + 216a b )d
+--R                 *
+--R                    %%P1
+--R                + 
+--R                      2 4 8       3 3 4       4 2  8
+--R                  (24a b c  - 528a b c  + 216a b )d %%P0
+--R                + 
+--R                         4 12       2 3 8      3 2 4      4   4
+--R                  (- 2a b c   + 150a b c  - 30a b c  - 54a b)d
+--R             *
+--R                ROOT
+--R                             2 8    2          2 8             4
+--R                       - 6a b d %%P1  + (- 4a b d %%P0 + 4a b d )%%P1
+--R                     + 
+--R                             2 8    2         4            4
+--R                       - 6a b d %%P0  + 4a b d %%P0 - 15b c  - a
+--R                  /
+--R                         2 8
+--R                     2a b d
+--R            + 
+--R                         3 4 4       4 3  12
+--R                  (- 480a b c  - 864a b )d  %%P0
+--R                + 
+--R                      2 4 8       3 3 4       4 2  8
+--R                  (24a b c  - 528a b c  + 216a b )d
+--R             *
+--R                    2
+--R                %%P1
+--R            + 
+--R                         3 4 4       4 3  12    2        3 3 4       4 2  8
+--R                  (- 480a b c  - 864a b )d  %%P0  + (480a b c  + 864a b )d %%P0
+--R                + 
+--R                       4 12       2 3 8       3 2 4       4   4
+--R                  (2a b c   - 174a b c  + 558a b c  - 162a b)d
+--R             *
+--R                %%P1
+--R            + 
+--R                  2 4 8       3 3 4       4 2  8    2
+--R              (24a b c  - 528a b c  + 216a b )d %%P0
+--R            + 
+--R                   4 12       2 3 8       3 2 4       4   4
+--R              (2a b c   - 174a b c  + 558a b c  - 162a b)d %%P0
+--R            + 
+--R                4 15         3 11        2 2 7       3   3        4 16
+--R              (b c   - 117a b c   - 1053a b c  + 729a b c )d x + b c
+--R            + 
+--R                      3 12        2 2 8        3   4      4
+--R              - 118a b c   - 1860a b c  + 1230a b c  + 27a
+--R     + 
+--R             4
+--R         2b d %%P1
+--R      *
+--R         log
+--R                       3 4 4        4 3  12
+--R                  (960a b c  + 1728a b )d  %%P0
+--R                + 
+--R                        2 4 8        3 3 4       4 2  8
+--R                  (- 48a b c  + 1056a b c  - 432a b )d
+--R             *
+--R                    2
+--R                %%P1
+--R            + 
+--R                       3 4 4        4 3  12    2
+--R                  (960a b c  + 1728a b )d  %%P0
+--R                + 
+--R                         3 3 4        4 2  8
+--R                  (- 960a b c  - 1728a b )d %%P0
+--R                + 
+--R                         4 12       2 3 8        3 2 4       4   4
+--R                  (- 4a b c   + 348a b c  - 1116a b c  + 324a b)d
+--R             *
+--R                %%P1
+--R            + 
+--R                   3 4 4        4 3  12    3          3 3 4        4 2  8    2
+--R              (960a b c  + 1728a b )d  %%P0  + (- 960a b c  - 1728a b )d %%P0
+--R            + 
+--R                    2 3 8        3 2 4       4   4
+--R              (1800a b c  + 3600a b c  + 648a b)d %%P0
+--R            + 
+--R                4 15         3 11        2 2 7       3   3        4 16
+--R              (b c   - 117a b c   - 1053a b c  + 729a b c )d x + b c
+--R            + 
+--R                      3 12      2 2 8       3   4      4
+--R              - 206a b c   - 48a b c  + 846a b c  - 81a
+--R     + 
+--R             4
+--R         2b d %%P0
+--R      *
+--R         log
+--R                     3 4 4        4 3  12    3
+--R              (- 960a b c  - 1728a b )d  %%P0
+--R            + 
+--R                    2 4 8        3 3 4        4 2  8    2
+--R              (- 48a b c  + 2016a b c  + 1296a b )d %%P0
+--R            + 
+--R                     4 12        2 3 8        3 2 4       4   4
+--R              (- 4a b c   - 1452a b c  - 4716a b c  - 324a b)d %%P0
+--R            + 
+--R                4 15         3 11        2 2 7       3   3        4 16
+--R              (b c   - 117a b c   - 1053a b c  + 729a b c )d x + b c
+--R            + 
+--R                     3 12       2 2 8       3   4      4
+--R              - 26a b c   - 444a b c  - 390a b c  + 27a
+--R  /
+--R         4
+--R     2b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 434
+
+--S 435 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                    4 +-+ +-+4+-+3 +-+4+-+3
+--R                2b d \|2 \|a \|a  \|b \|b
+--R             *
+--R                ROOT
+--R                             2 8    2          2 8             4
+--R                       - 6a b d %%P1  + (- 4a b d %%P0 + 4a b d )%%P1
+--R                     + 
+--R                             2 8    2         4            4
+--R                       - 6a b d %%P0  + 4a b d %%P0 - 15b c  - a
+--R                  /
+--R                         2 8
+--R                     2a b d
+--R         + 
+--R                 4 +-+ +-+4+-+3 +-+4+-+3           4 +-+ +-+4+-+3 +-+4+-+3
+--R           - 2b d \|2 \|a \|a  \|b \|b  %%P1 - 2b d \|2 \|a \|a  \|b \|b  %%P0
+--R         + 
+--R             +-+ +-+4+-+3 +-+4+-+3
+--R           2\|2 \|a \|a  \|b \|b
+--R      *
+--R         log
+--R                           3 4 4       4 3  12
+--R                      (480a b c  + 864a b )d  %%P0
+--R                    + 
+--R                            2 4 8       3 3 4       4 2  8
+--R                      (- 24a b c  + 528a b c  - 216a b )d
+--R                 *
+--R                    %%P1
+--R                + 
+--R                        2 4 8       3 3 4       4 2  8
+--R                  (- 24a b c  + 528a b c  - 216a b )d %%P0
+--R                + 
+--R                       4 12       2 3 8      3 2 4      4   4
+--R                  (2a b c   - 150a b c  + 30a b c  + 54a b)d
+--R             *
+--R                ROOT
+--R                             2 8    2          2 8             4
+--R                       - 6a b d %%P1  + (- 4a b d %%P0 + 4a b d )%%P1
+--R                     + 
+--R                             2 8    2         4            4
+--R                       - 6a b d %%P0  + 4a b d %%P0 - 15b c  - a
+--R                  /
+--R                         2 8
+--R                     2a b d
+--R            + 
+--R                         3 4 4       4 3  12
+--R                  (- 480a b c  - 864a b )d  %%P0
+--R                + 
+--R                      2 4 8       3 3 4       4 2  8
+--R                  (24a b c  - 528a b c  + 216a b )d
+--R             *
+--R                    2
+--R                %%P1
+--R            + 
+--R                         3 4 4       4 3  12    2        3 3 4       4 2  8
+--R                  (- 480a b c  - 864a b )d  %%P0  + (480a b c  + 864a b )d %%P0
+--R                + 
+--R                       4 12       2 3 8       3 2 4       4   4
+--R                  (2a b c   - 174a b c  + 558a b c  - 162a b)d
+--R             *
+--R                %%P1
+--R            + 
+--R                  2 4 8       3 3 4       4 2  8    2
+--R              (24a b c  - 528a b c  + 216a b )d %%P0
+--R            + 
+--R                   4 12       2 3 8       3 2 4       4   4
+--R              (2a b c   - 174a b c  + 558a b c  - 162a b)d %%P0
+--R            + 
+--R                4 15         3 11        2 2 7       3   3        4 16
+--R              (b c   - 117a b c   - 1053a b c  + 729a b c )d x + b c
+--R            + 
+--R                      3 12        2 2 8        3   4      4
+--R              - 118a b c   - 1860a b c  + 1230a b c  + 27a
+--R     + 
+--R                 4 +-+ +-+4+-+3 +-+4+-+3
+--R             2b d \|2 \|a \|a  \|b \|b
+--R          *
+--R             ROOT
+--R                          2 8    2          2 8             4
+--R                    - 6a b d %%P1  + (- 4a b d %%P0 + 4a b d )%%P1
+--R                  + 
+--R                          2 8    2         4            4
+--R                    - 6a b d %%P0  + 4a b d %%P0 - 15b c  - a
+--R               /
+--R                      2 8
+--R                  2a b d
+--R         + 
+--R                 4 +-+ +-+4+-+3 +-+4+-+3           4 +-+ +-+4+-+3 +-+4+-+3
+--R           - 2b d \|2 \|a \|a  \|b \|b  %%P1 - 2b d \|2 \|a \|a  \|b \|b  %%P0
+--R         + 
+--R             +-+ +-+4+-+3 +-+4+-+3
+--R           2\|2 \|a \|a  \|b \|b
+--R      *
+--R         log
+--R                             3 4 4       4 3  12
+--R                      (- 480a b c  - 864a b )d  %%P0
+--R                    + 
+--R                          2 4 8       3 3 4       4 2  8
+--R                      (24a b c  - 528a b c  + 216a b )d
+--R                 *
+--R                    %%P1
+--R                + 
+--R                      2 4 8       3 3 4       4 2  8
+--R                  (24a b c  - 528a b c  + 216a b )d %%P0
+--R                + 
+--R                         4 12       2 3 8      3 2 4      4   4
+--R                  (- 2a b c   + 150a b c  - 30a b c  - 54a b)d
+--R             *
+--R                ROOT
+--R                             2 8    2          2 8             4
+--R                       - 6a b d %%P1  + (- 4a b d %%P0 + 4a b d )%%P1
+--R                     + 
+--R                             2 8    2         4            4
+--R                       - 6a b d %%P0  + 4a b d %%P0 - 15b c  - a
+--R                  /
+--R                         2 8
+--R                     2a b d
+--R            + 
+--R                         3 4 4       4 3  12
+--R                  (- 480a b c  - 864a b )d  %%P0
+--R                + 
+--R                      2 4 8       3 3 4       4 2  8
+--R                  (24a b c  - 528a b c  + 216a b )d
+--R             *
+--R                    2
+--R                %%P1
+--R            + 
+--R                         3 4 4       4 3  12    2        3 3 4       4 2  8
+--R                  (- 480a b c  - 864a b )d  %%P0  + (480a b c  + 864a b )d %%P0
+--R                + 
+--R                       4 12       2 3 8       3 2 4       4   4
+--R                  (2a b c   - 174a b c  + 558a b c  - 162a b)d
+--R             *
+--R                %%P1
+--R            + 
+--R                  2 4 8       3 3 4       4 2  8    2
+--R              (24a b c  - 528a b c  + 216a b )d %%P0
+--R            + 
+--R                   4 12       2 3 8       3 2 4       4   4
+--R              (2a b c   - 174a b c  + 558a b c  - 162a b)d %%P0
+--R            + 
+--R                4 15         3 11        2 2 7       3   3        4 16
+--R              (b c   - 117a b c   - 1053a b c  + 729a b c )d x + b c
+--R            + 
+--R                      3 12        2 2 8        3   4      4
+--R              - 118a b c   - 1860a b c  + 1230a b c  + 27a
+--R     + 
+--R             4 +-+ +-+4+-+3 +-+4+-+3
+--R         4b d \|2 \|a \|a  \|b \|b  %%P1
+--R      *
+--R         log
+--R                       3 4 4        4 3  12
+--R                  (960a b c  + 1728a b )d  %%P0
+--R                + 
+--R                        2 4 8        3 3 4       4 2  8
+--R                  (- 48a b c  + 1056a b c  - 432a b )d
+--R             *
+--R                    2
+--R                %%P1
+--R            + 
+--R                       3 4 4        4 3  12    2
+--R                  (960a b c  + 1728a b )d  %%P0
+--R                + 
+--R                         3 3 4        4 2  8
+--R                  (- 960a b c  - 1728a b )d %%P0
+--R                + 
+--R                         4 12       2 3 8        3 2 4       4   4
+--R                  (- 4a b c   + 348a b c  - 1116a b c  + 324a b)d
+--R             *
+--R                %%P1
+--R            + 
+--R                   3 4 4        4 3  12    3          3 3 4        4 2  8    2
+--R              (960a b c  + 1728a b )d  %%P0  + (- 960a b c  - 1728a b )d %%P0
+--R            + 
+--R                    2 3 8        3 2 4       4   4
+--R              (1800a b c  + 3600a b c  + 648a b)d %%P0
+--R            + 
+--R                4 15         3 11        2 2 7       3   3        4 16
+--R              (b c   - 117a b c   - 1053a b c  + 729a b c )d x + b c
+--R            + 
+--R                      3 12      2 2 8       3   4      4
+--R              - 206a b c   - 48a b c  + 846a b c  - 81a
+--R     + 
+--R                   +-+    2 3 +-+
+--R         (- 3a b c\|b  + b c \|a )
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                 +-+    2 3 +-+
+--R         (3a b c\|b  - b c \|a )
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R             4 +-+ +-+4+-+3 +-+4+-+3
+--R         4b d \|2 \|a \|a  \|b \|b  %%P0
+--R      *
+--R         log
+--R                     3 4 4        4 3  12    3
+--R              (- 960a b c  - 1728a b )d  %%P0
+--R            + 
+--R                    2 4 8        3 3 4        4 2  8    2
+--R              (- 48a b c  + 2016a b c  + 1296a b )d %%P0
+--R            + 
+--R                     4 12        2 3 8        3 2 4       4   4
+--R              (- 4a b c   - 1452a b c  - 4716a b c  - 324a b)d %%P0
+--R            + 
+--R                4 15         3 11        2 2 7       3   3        4 16
+--R              (b c   - 117a b c   - 1053a b c  + 729a b c )d x + b c
+--R            + 
+--R                     3 12       2 2 8       3   4      4
+--R              - 26a b c   - 444a b c  - 390a b c  + 27a
+--R     + 
+--R                                              +-+4+-+   4+-+
+--R               +-+     2 3 +-+      (d x + c)\|2 \|b  + \|a
+--R       (6a b c\|b  + 2b c \|a )atan(------------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                              +-+4+-+   4+-+
+--R               +-+     2 3 +-+      (d x + c)\|2 \|b  - \|a
+--R       (6a b c\|b  + 2b c \|a )atan(------------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                    2 2             2  +-+
+--R             2 +-+4+-+3 4+-+3     (d x  + 2c d x + c )\|b
+--R       - 6b c \|2 \|a   \|b  atan(------------------------)
+--R                                             +-+
+--R                                            \|a
+--R     + 
+--R       -
+--R             +-+       4 4         3 3       2 2 2       3         4      +-+
+--R            \|2 log(b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a)\|a
+--R         *
+--R            4+-+3 +-+4+-+3
+--R            \|a  \|b \|b
+--R  /
+--R         4 +-+ +-+4+-+3 +-+4+-+3
+--R     4b d \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 435
+
+--S 436 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       4 4      2 3 3      3 2 2      4         5  +-+4+-+2
+--R               (- 12c d x  - 48c d x  - 76c d x  - 56c d x - 16c )\|a \|a
+--R             + 
+--R                  3 6 6       4 5 5         5         4 4
+--R               b c d x  + 6b c d x  + (15b c  + 6a c)d x
+--R             + 
+--R                     6        2  3 3         7        3  2 2
+--R               (20b c  + 24a c )d x  + (15b c  + 35a c )d x
+--R             + 
+--R                    8        4          9       5
+--R               (6b c  + 22a c )d x + b c  + 5a c
+--R          *
+--R              +-+
+--R             \|b
+--R         + 
+--R                       6 6        2 5 5        3 4 4         4 3 3
+--R               - 6b c d x  - 36b c d x  - 92b c d x  - 128b c d x
+--R             + 
+--R                        5         2 2           6        2           7       3
+--R               (- 102b c  - 6a c)d x  + (- 44b c  - 12a c )d x - 8b c  - 8a c
+--R          *
+--R             4+-+2
+--R             \|a
+--R         + 
+--R                     6 6        2 5 5        3 4 4        4 3 3
+--R               3b c d x  + 18b c d x  + 47b c d x  + 68b c d x
+--R             + 
+--R                     5         2 2         6       2           7       3
+--R               (57b c  - 3a c)d x  + (26b c  - 6a c )d x + 5b c  - 3a c
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                    3 4 4       4 3 3          5         2 2
+--R               - b c d x  - 4b c d x  + (- 6b c  + 6a c)d x
+--R             + 
+--R                      6        2          7       3
+--R               (- 4b c  + 12a c )d x - b c  + 7a c
+--R          *
+--R             4+-+2
+--R             \|a
+--R         + 
+--R                     6 6        2 5 5        3 4 4        4 3 3
+--R               3b c d x  + 18b c d x  + 46b c d x  + 64b c d x
+--R             + 
+--R                     5         2 2         6       2           7       3
+--R               (51b c  + 3a c)d x  + (22b c  + 6a c )d x + 4b c  + 4a c
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R                4 4        2 3 3        3 2 2       4         5         +-+4+-+2
+--R       (- 3b c d x  - 12b c d x  - 16b c d x  - 8b c d x - b c  + 3a c)\|a \|a
+--R     + 
+--R          2 3 6 6     2 4 5 5         2 5           4 4
+--R       - b c d x  - 6b c d x  + (- 15b c  + 9a b c)d x
+--R     + 
+--R             2 6          2  3 3         2 7          3  2 2
+--R       (- 20b c  + 36a b c )d x  + (- 15b c  + 57a b c )d x
+--R     + 
+--R            2 8          4        2 9          5     2
+--R       (- 6b c  + 42a b c )d x - b c  + 12a b c  - 3a c
+--R  /
+--R                   9 6          8 5        2 7 4        3 6 3
+--R               4b d x  + 24b c d x  + 60b c d x  + 80b c d x
+--R             + 
+--R                     4       5 2         5         4         6       2  3
+--R               (60b c  + 4a)d x  + (24b c  + 8a c)d x + (4b c  + 4a c )d
+--R          *
+--R              +-+4+-+2 +-+
+--R             \|a \|a  \|b
+--R         + 
+--R                 2 11 8      2   10 7      2 2 9 6       2 3 8 5
+--R               2b d  x  + 16b c d  x  + 56b c d x  + 112b c d x
+--R             + 
+--R                    2 4         7 4        2 5            6 3
+--R               (140b c  + 4a b)d x  + (112b c  + 16a b c)d x
+--R             + 
+--R                   2 6          2  5 2       2 7          3  4
+--R               (56b c  + 24a b c )d x  + (16b c  + 16a b c )d x
+--R             + 
+--R                  2 8         4     2  3
+--R               (2b c  + 4a b c  + 2a )d
+--R          *
+--R             4+-+2
+--R             \|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R             2 9 6        2   8 5        2 2 7 4        2 3 6 3
+--R       - 4a b d x  - 24a b c d x  - 60a b c d x  - 80a b c d x
+--R     + 
+--R               2 4     2   5 2           2 5     2     4
+--R       (- 60a b c  - 4a b)d x  + (- 24a b c  - 8a b c)d x
+--R     + 
+--R              2 6     2   2  3
+--R       (- 4a b c  - 4a b c )d
+--R                                                    Type: Expression(Integer)
+--E 436
+
+)clear all
+
+--S 437 of 619
+t0:=x^2/(a+b*(c+d*x)^4)
+--R 
+--R
+--R                                  2
+--R                                 x
+--R   (1)  ----------------------------------------------------
+--R           4 4         3 3       2 2 2       3         4
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 437
+
+--S 438 of 619
+r0:=-c*atan((c+d*x)^2*sqrt(b)/sqrt(a))/(d^3*sqrt(a)*sqrt(b))+_
+   1/4*log(-a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))*_
+   (sqrt(a)-c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^3*sqrt(2))-1/4*log(a^(1/4)*_
+   b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))*(sqrt(a)-_
+   c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^3*sqrt(2))-1/2*atan(1-b^(1/4)*_
+   (c+d*x)*sqrt(2)/a^(1/4))*(sqrt(a)+c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^3*_
+   sqrt(2))+1/2*atan(1+b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))*(sqrt(a)+_
+   c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^3*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              +-+      2 +-+
+--R         (- a\|b  + b c \|a )
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R            +-+      2 +-+
+--R         (a\|b  - b c \|a )
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                                          +-+4+-+   4+-+
+--R           +-+       2 +-+      (d x + c)\|2 \|b  + \|a
+--R       (2a\|b  + 2b c \|a )atan(------------------------)
+--R                                          4+-+
+--R                                          \|a
+--R     + 
+--R                                          +-+4+-+   4+-+
+--R           +-+       2 +-+      (d x + c)\|2 \|b  - \|a
+--R       (2a\|b  + 2b c \|a )atan(------------------------)
+--R                                          4+-+
+--R                                          \|a
+--R     + 
+--R                                 2 2             2  +-+
+--R            +-+4+-+3 4+-+3     (d x  + 2c d x + c )\|b
+--R       - 4c\|2 \|a   \|b  atan(------------------------)
+--R                                          +-+
+--R                                         \|a
+--R  /
+--R       3 +-+ +-+4+-+3 +-+4+-+3
+--R     4d \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 438
+
+--S 439 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +------------------------------------------------------+
+--R              |        6    2         6                  6    2     2
+--R              |- 3a b d %%Q1  - 2a b d %%Q0 %%Q1 - 3a b d %%Q0  - 3c
+--R              |------------------------------------------------------  - %%Q1
+--R              |                             6
+--R             \|                        a b d
+--R           + 
+--R             - %%Q0
+--R      *
+--R         log
+--R                        3 3 4      4 2  9           2 3 7      3 2 3  6
+--R                  ((224a b c  + 32a b )d %%Q0 + (16a b c  - 80a b c )d )%%Q1
+--R                + 
+--R                    2 3 7      3 2 3  6            3 10      2 2 6     3   2  3
+--R                (16a b c  - 80a b c )d %%Q0 + (2a b c   - 40a b c  + 6a b c )d
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        6    2         6                  6    2     2
+--R                 |- 3a b d %%Q1  - 2a b d %%Q0 %%Q1 - 3a b d %%Q0  - 3c
+--R                 |------------------------------------------------------
+--R                 |                             6
+--R                \|                        a b d
+--R            + 
+--R                    3 3 4      4 2  9           2 3 7      3 2 3  6     2
+--R              ((224a b c  + 32a b )d %%Q0 + (16a b c  - 80a b c )d )%%Q1
+--R            + 
+--R                       3 3 4      4 2  9    2
+--R                  (224a b c  + 32a b )d %%Q0
+--R                + 
+--R                         3 10      2 2 6     3   2  3
+--R                  (- 2a b c   + 40a b c  - 6a b c )d
+--R             *
+--R                %%Q1
+--R            + 
+--R                  2 3 7      3 2 3  6    2
+--R              (16a b c  - 80a b c )d %%Q0
+--R            + 
+--R                     3 10      2 2 6     3   2  3
+--R              (- 2a b c   + 40a b c  - 6a b c )d %%Q0
+--R            + 
+--R                3 12        2 8      2   4    3        3 13        2 9
+--R              (b c   - 33a b c  - 33a b c  + a )d x + b c   - 35a b c
+--R            + 
+--R                   2   5     3
+--R              - 81a b c  + 3a c
+--R     + 
+--R              +------------------------------------------------------+
+--R              |        6    2         6                  6    2     2
+--R              |- 3a b d %%Q1  - 2a b d %%Q0 %%Q1 - 3a b d %%Q0  - 3c
+--R           -  |------------------------------------------------------  - %%Q1
+--R              |                             6
+--R             \|                        a b d
+--R         + 
+--R           - %%Q0
+--R      *
+--R         log
+--R                          3 3 4      4 2  9             2 3 7      3 2 3  6
+--R                  ((- 224a b c  - 32a b )d %%Q0 + (- 16a b c  + 80a b c )d )%%Q1
+--R                + 
+--R                        2 3 7      3 2 3  6
+--R                  (- 16a b c  + 80a b c )d %%Q0
+--R                + 
+--R                         3 10      2 2 6     3   2  3
+--R                  (- 2a b c   + 40a b c  - 6a b c )d
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        6    2         6                  6    2     2
+--R                 |- 3a b d %%Q1  - 2a b d %%Q0 %%Q1 - 3a b d %%Q0  - 3c
+--R                 |------------------------------------------------------
+--R                 |                             6
+--R                \|                        a b d
+--R            + 
+--R                    3 3 4      4 2  9           2 3 7      3 2 3  6     2
+--R              ((224a b c  + 32a b )d %%Q0 + (16a b c  - 80a b c )d )%%Q1
+--R            + 
+--R                       3 3 4      4 2  9    2
+--R                  (224a b c  + 32a b )d %%Q0
+--R                + 
+--R                         3 10      2 2 6     3   2  3
+--R                  (- 2a b c   + 40a b c  - 6a b c )d
+--R             *
+--R                %%Q1
+--R            + 
+--R                  2 3 7      3 2 3  6    2
+--R              (16a b c  - 80a b c )d %%Q0
+--R            + 
+--R                     3 10      2 2 6     3   2  3
+--R              (- 2a b c   + 40a b c  - 6a b c )d %%Q0
+--R            + 
+--R                3 12        2 8      2   4    3        3 13        2 9
+--R              (b c   - 33a b c  - 33a b c  + a )d x + b c   - 35a b c
+--R            + 
+--R                   2   5     3
+--R              - 81a b c  + 3a c
+--R     + 
+--R         2%%Q1
+--R      *
+--R         log
+--R                      3 3 4      4 2  9             2 3 7       3 2 3  6     2
+--R              ((- 448a b c  - 64a b )d %%Q0 + (- 32a b c  + 160a b c )d )%%Q1
+--R            + 
+--R                         3 3 4      4 2  9    2
+--R                  (- 448a b c  - 64a b )d %%Q0
+--R                + 
+--R                       3 10      2 2 6      3   2  3
+--R                  (4a b c   - 80a b c  + 12a b c )d
+--R             *
+--R                %%Q1
+--R            + 
+--R                     3 3 4      4 2  9    3          2 2 6      3   2  3
+--R              (- 448a b c  - 64a b )d %%Q0  + (- 336a b c  - 48a b c )d %%Q0
+--R            + 
+--R                3 12        2 8      2   4    3        3 13        2 9
+--R              (b c   - 33a b c  - 33a b c  + a )d x + b c   - 59a b c
+--R            + 
+--R                 2   5     3
+--R              39a b c  + 3a c
+--R     + 
+--R         2%%Q0
+--R      *
+--R         log
+--R                   3 3 4      4 2  9    3         2 3 7       3 2 3  6    2
+--R              (448a b c  + 64a b )d %%Q0  + (- 32a b c  + 160a b c )d %%Q0
+--R            + 
+--R                   3 10       2 2 6      3   2  3
+--R              (4a b c   + 256a b c  + 60a b c )d %%Q0
+--R            + 
+--R                3 12        2 8      2   4    3        3 13       2 9     2   5
+--R              (b c   - 33a b c  - 33a b c  + a )d x + b c   - 3a b c  - 9a b c
+--R            + 
+--R                  3
+--R              - 5a c
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 439
+
+--S 440 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               3 +-+ +-+4+-+3 +-+4+-+3
+--R             2d \|2 \|a \|a  \|b \|b
+--R          *
+--R              +------------------------------------------------------+
+--R              |        6    2         6                  6    2     2
+--R              |- 3a b d %%Q1  - 2a b d %%Q0 %%Q1 - 3a b d %%Q0  - 3c
+--R              |------------------------------------------------------
+--R              |                             6
+--R             \|                        a b d
+--R         + 
+--R               3 +-+ +-+4+-+3 +-+4+-+3         3 +-+ +-+4+-+3 +-+4+-+3
+--R           - 2d \|2 \|a \|a  \|b \|b  %%Q1 - 2d \|2 \|a \|a  \|b \|b  %%Q0
+--R      *
+--R         log
+--R                        3 3 4      4 2  9           2 3 7      3 2 3  6
+--R                  ((224a b c  + 32a b )d %%Q0 + (16a b c  - 80a b c )d )%%Q1
+--R                + 
+--R                    2 3 7      3 2 3  6            3 10      2 2 6     3   2  3
+--R                (16a b c  - 80a b c )d %%Q0 + (2a b c   - 40a b c  + 6a b c )d
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        6    2         6                  6    2     2
+--R                 |- 3a b d %%Q1  - 2a b d %%Q0 %%Q1 - 3a b d %%Q0  - 3c
+--R                 |------------------------------------------------------
+--R                 |                             6
+--R                \|                        a b d
+--R            + 
+--R                    3 3 4      4 2  9           2 3 7      3 2 3  6     2
+--R              ((224a b c  + 32a b )d %%Q0 + (16a b c  - 80a b c )d )%%Q1
+--R            + 
+--R                       3 3 4      4 2  9    2
+--R                  (224a b c  + 32a b )d %%Q0
+--R                + 
+--R                         3 10      2 2 6     3   2  3
+--R                  (- 2a b c   + 40a b c  - 6a b c )d
+--R             *
+--R                %%Q1
+--R            + 
+--R                  2 3 7      3 2 3  6    2
+--R              (16a b c  - 80a b c )d %%Q0
+--R            + 
+--R                     3 10      2 2 6     3   2  3
+--R              (- 2a b c   + 40a b c  - 6a b c )d %%Q0
+--R            + 
+--R                3 12        2 8      2   4    3        3 13        2 9
+--R              (b c   - 33a b c  - 33a b c  + a )d x + b c   - 35a b c
+--R            + 
+--R                   2   5     3
+--R              - 81a b c  + 3a c
+--R     + 
+--R           -
+--R                  3 +-+ +-+4+-+3 +-+4+-+3
+--R                2d \|2 \|a \|a  \|b \|b
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        6    2         6                  6    2     2
+--R                 |- 3a b d %%Q1  - 2a b d %%Q0 %%Q1 - 3a b d %%Q0  - 3c
+--R                 |------------------------------------------------------
+--R                 |                             6
+--R                \|                        a b d
+--R         + 
+--R               3 +-+ +-+4+-+3 +-+4+-+3         3 +-+ +-+4+-+3 +-+4+-+3
+--R           - 2d \|2 \|a \|a  \|b \|b  %%Q1 - 2d \|2 \|a \|a  \|b \|b  %%Q0
+--R      *
+--R         log
+--R                          3 3 4      4 2  9             2 3 7      3 2 3  6
+--R                  ((- 224a b c  - 32a b )d %%Q0 + (- 16a b c  + 80a b c )d )%%Q1
+--R                + 
+--R                        2 3 7      3 2 3  6
+--R                  (- 16a b c  + 80a b c )d %%Q0
+--R                + 
+--R                         3 10      2 2 6     3   2  3
+--R                  (- 2a b c   + 40a b c  - 6a b c )d
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |        6    2         6                  6    2     2
+--R                 |- 3a b d %%Q1  - 2a b d %%Q0 %%Q1 - 3a b d %%Q0  - 3c
+--R                 |------------------------------------------------------
+--R                 |                             6
+--R                \|                        a b d
+--R            + 
+--R                    3 3 4      4 2  9           2 3 7      3 2 3  6     2
+--R              ((224a b c  + 32a b )d %%Q0 + (16a b c  - 80a b c )d )%%Q1
+--R            + 
+--R                       3 3 4      4 2  9    2
+--R                  (224a b c  + 32a b )d %%Q0
+--R                + 
+--R                         3 10      2 2 6     3   2  3
+--R                  (- 2a b c   + 40a b c  - 6a b c )d
+--R             *
+--R                %%Q1
+--R            + 
+--R                  2 3 7      3 2 3  6    2
+--R              (16a b c  - 80a b c )d %%Q0
+--R            + 
+--R                     3 10      2 2 6     3   2  3
+--R              (- 2a b c   + 40a b c  - 6a b c )d %%Q0
+--R            + 
+--R                3 12        2 8      2   4    3        3 13        2 9
+--R              (b c   - 33a b c  - 33a b c  + a )d x + b c   - 35a b c
+--R            + 
+--R                   2   5     3
+--R              - 81a b c  + 3a c
+--R     + 
+--R           3 +-+ +-+4+-+3 +-+4+-+3
+--R         4d \|2 \|a \|a  \|b \|b  %%Q1
+--R      *
+--R         log
+--R                      3 3 4      4 2  9             2 3 7       3 2 3  6     2
+--R              ((- 448a b c  - 64a b )d %%Q0 + (- 32a b c  + 160a b c )d )%%Q1
+--R            + 
+--R                         3 3 4      4 2  9    2
+--R                  (- 448a b c  - 64a b )d %%Q0
+--R                + 
+--R                       3 10      2 2 6      3   2  3
+--R                  (4a b c   - 80a b c  + 12a b c )d
+--R             *
+--R                %%Q1
+--R            + 
+--R                     3 3 4      4 2  9    3          2 2 6      3   2  3
+--R              (- 448a b c  - 64a b )d %%Q0  + (- 336a b c  - 48a b c )d %%Q0
+--R            + 
+--R                3 12        2 8      2   4    3        3 13        2 9
+--R              (b c   - 33a b c  - 33a b c  + a )d x + b c   - 59a b c
+--R            + 
+--R                 2   5     3
+--R              39a b c  + 3a c
+--R     + 
+--R           3 +-+ +-+4+-+3 +-+4+-+3
+--R         4d \|2 \|a \|a  \|b \|b  %%Q0
+--R      *
+--R         log
+--R                   3 3 4      4 2  9    3         2 3 7       3 2 3  6    2
+--R              (448a b c  + 64a b )d %%Q0  + (- 32a b c  + 160a b c )d %%Q0
+--R            + 
+--R                   3 10       2 2 6      3   2  3
+--R              (4a b c   + 256a b c  + 60a b c )d %%Q0
+--R            + 
+--R                3 12        2 8      2   4    3        3 13       2 9     2   5
+--R              (b c   - 33a b c  - 33a b c  + a )d x + b c   - 3a b c  - 9a b c
+--R            + 
+--R                  3
+--R              - 5a c
+--R     + 
+--R            +-+      2 +-+
+--R         (a\|b  - b c \|a )
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R              +-+      2 +-+
+--R         (- a\|b  + b c \|a )
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                                            +-+4+-+   4+-+
+--R             +-+       2 +-+      (d x + c)\|2 \|b  + \|a
+--R       (- 2a\|b  - 2b c \|a )atan(------------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R                                            +-+4+-+   4+-+
+--R             +-+       2 +-+      (d x + c)\|2 \|b  - \|a
+--R       (- 2a\|b  - 2b c \|a )atan(------------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R                               2 2             2  +-+
+--R          +-+4+-+3 4+-+3     (d x  + 2c d x + c )\|b
+--R       4c\|2 \|a   \|b  atan(------------------------)
+--R                                        +-+
+--R                                       \|a
+--R  /
+--R       3 +-+ +-+4+-+3 +-+4+-+3
+--R     4d \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  4 4        3 3      2 2 2      3        4  +-+4+-+2      2 6 6
+--R               (4d x  + 16c d x  + 28c d x  + 24c d x + 8c )\|a \|a   - b c d x
+--R             + 
+--R                     3 5 5           4       4 4           5         3 3
+--R               - 6b c d x  + (- 15b c  - 2a)d x  + (- 20b c  - 8a c)d x
+--R             + 
+--R                       6        2  2 2          7       3          8      4
+--R               (- 15b c  - 11a c )d x  + (- 6b c  - 6a c )d x - b c  - a c
+--R          *
+--R              +-+
+--R             \|b
+--R         + 
+--R                   6 6          5 5        2 4 4        3 3 3
+--R               2b d x  + 12b c d x  + 32b c d x  + 48b c d x
+--R             + 
+--R                     4       2 2         5                  6       2
+--R               (42b c  + 2a)d x  + (20b c  + 4a c)d x + 4b c  + 4a c
+--R          *
+--R             4+-+2
+--R             \|a
+--R         + 
+--R                    6 6         5 5        2 4 4        3 3 3
+--R               - b d x  - 6b c d x  - 17b c d x  - 28b c d x
+--R             + 
+--R                       4      2 2           5                  6      2
+--R               (- 27b c  + a)d x  + (- 14b c  + 2a c)d x - 3b c  + a c
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                  2 4 4       3 3 3        4       2 2        5
+--R               b c d x  + 4b c d x  + (6b c  - 2a)d x  + (4b c  - 4a c)d x
+--R             + 
+--R                  6       2
+--R               b c  - 3a c
+--R          *
+--R             4+-+2
+--R             \|a
+--R         + 
+--R                    6 6         5 5        2 4 4        3 3 3
+--R               - b d x  - 6b c d x  - 16b c d x  - 24b c d x
+--R             + 
+--R                       4      2 2           5                  6       2
+--R               (- 21b c  - a)d x  + (- 10b c  - 2a c)d x - 2b c  - 2a c
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R           4 4         3 3       2 2 2      4      +-+4+-+2    2 2 6 6
+--R       (b d x  + 4b c d x  + 4b c d x  - b c  - a)\|a \|a   + b c d x
+--R     + 
+--R         2 3 5 5       2 4         4 4       2 5            3 3
+--R       6b c d x  + (15b c  - 3a b)d x  + (20b c  - 12a b c)d x
+--R     + 
+--R           2 6          2  2 2      2 7          3        2 8         4    2
+--R       (15b c  - 21a b c )d x  + (6b c  - 18a b c )d x + b c  - 6a b c  + a
+--R  /
+--R                   8 6          7 5        2 6 4        3 5 3
+--R               4b d x  + 24b c d x  + 60b c d x  + 80b c d x
+--R             + 
+--R                     4       4 2         5         3         6       2  2
+--R               (60b c  + 4a)d x  + (24b c  + 8a c)d x + (4b c  + 4a c )d
+--R          *
+--R              +-+4+-+2 +-+
+--R             \|a \|a  \|b
+--R         + 
+--R                 2 10 8      2   9 7      2 2 8 6       2 3 7 5
+--R               2b d  x  + 16b c d x  + 56b c d x  + 112b c d x
+--R             + 
+--R                    2 4         6 4        2 5            5 3
+--R               (140b c  + 4a b)d x  + (112b c  + 16a b c)d x
+--R             + 
+--R                   2 6          2  4 2       2 7          3  3
+--R               (56b c  + 24a b c )d x  + (16b c  + 16a b c )d x
+--R             + 
+--R                  2 8         4     2  2
+--R               (2b c  + 4a b c  + 2a )d
+--R          *
+--R             4+-+2
+--R             \|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R             2 8 6        2   7 5        2 2 6 4        2 3 5 3
+--R       - 4a b d x  - 24a b c d x  - 60a b c d x  - 80a b c d x
+--R     + 
+--R               2 4     2   4 2           2 5     2     3
+--R       (- 60a b c  - 4a b)d x  + (- 24a b c  - 8a b c)d x
+--R     + 
+--R              2 6     2   2  2
+--R       (- 4a b c  - 4a b c )d
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 619
+t0:=x/(a+b*(c+d*x)^4)
+--R 
+--R
+--R                                  x
+--R   (1)  ----------------------------------------------------
+--R           4 4         3 3       2 2 2       3         4
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 442
+
+--S 443 of 619
+r0:=1/2*c*atan(1-b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*d^2*_
+   sqrt(2))-1/2*c*atan(1+b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))/(a^(3/4)*_
+   b^(1/4)*d^2*sqrt(2))+1/4*c*log(-a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+_
+   sqrt(a)+(c+d*x)^2*sqrt(b))/(a^(3/4)*b^(1/4)*d^2*sqrt(2))-_
+   1/4*c*log(a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*_
+   sqrt(b))/(a^(3/4)*b^(1/4)*d^2*sqrt(2))+1/2*atan((c+d*x)^2*_
+   sqrt(b)/sqrt(a))/(d^2*sqrt(a)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R           +-+ +-+              +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       - c\|a \|b log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R         +-+ +-+                +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       c\|a \|b log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                                  +-+4+-+   4+-+
+--R            +-+ +-+     (d x + c)\|2 \|b  + \|a
+--R       - 2c\|a \|b atan(------------------------)
+--R                                  4+-+
+--R                                  \|a
+--R     + 
+--R                                  +-+4+-+   4+-+
+--R            +-+ +-+     (d x + c)\|2 \|b  - \|a
+--R       - 2c\|a \|b atan(------------------------)
+--R                                  4+-+
+--R                                  \|a
+--R     + 
+--R                             2 2             2  +-+
+--R         +-+4+-+3 4+-+     (d x  + 2c d x + c )\|b
+--R       2\|2 \|a   \|b atan(------------------------)
+--R                                      +-+
+--R                                     \|a
+--R  /
+--R       2 +-+ +-+4+-+3 +-+4+-+
+--R     4d \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                +----------------------------------------------------+
+--R                |        4    2         4                  4    2
+--R                |- 6a b d %%R1  - 4a b d %%R0 %%R1 - 6a b d %%R0  - 1
+--R             -  |----------------------------------------------------  - %%R1
+--R                |                             4
+--R               \|                       2a b d
+--R           + 
+--R             - %%R0
+--R      *
+--R         log
+--R                      3   6         2   2 4          2   2 4
+--R                  (64a b d %%R0 - 8a b c d )%%R1 - 8a b c d %%R0
+--R                + 
+--R                         4     2  2
+--R                  (2a b c  - 4a )d
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |        4    2         4                  4    2
+--R                 |- 6a b d %%R1  - 4a b d %%R0 %%R1 - 6a b d %%R0  - 1
+--R                 |----------------------------------------------------
+--R                 |                             4
+--R                \|                       2a b d
+--R            + 
+--R                    3   6         2   2 4     2
+--R              (- 64a b d %%R0 + 8a b c d )%%R1
+--R            + 
+--R                    3   6    2          4     2  2          2   2 4    2
+--R              (- 64a b d %%R0  + (2a b c  - 4a )d )%%R1 + 8a b c d %%R0
+--R            + 
+--R                     4     2  2           5                 6       2
+--R              (2a b c  - 4a )d %%R0 + (b c  - 4a c)d x + b c  - 5a c
+--R     + 
+--R           +----------------------------------------------------+
+--R           |        4    2         4                  4    2
+--R           |- 6a b d %%R1  - 4a b d %%R0 %%R1 - 6a b d %%R0  - 1
+--R         ( |----------------------------------------------------  - %%R1 - %%R0)
+--R           |                             4
+--R          \|                       2a b d
+--R      *
+--R         log
+--R                        3   6         2   2 4          2   2 4
+--R                  (- 64a b d %%R0 + 8a b c d )%%R1 + 8a b c d %%R0
+--R                + 
+--R                           4     2  2
+--R                  (- 2a b c  + 4a )d
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |        4    2         4                  4    2
+--R                 |- 6a b d %%R1  - 4a b d %%R0 %%R1 - 6a b d %%R0  - 1
+--R                 |----------------------------------------------------
+--R                 |                             4
+--R                \|                       2a b d
+--R            + 
+--R                    3   6         2   2 4     2
+--R              (- 64a b d %%R0 + 8a b c d )%%R1
+--R            + 
+--R                    3   6    2          4     2  2          2   2 4    2
+--R              (- 64a b d %%R0  + (2a b c  - 4a )d )%%R1 + 8a b c d %%R0
+--R            + 
+--R                     4     2  2           5                 6       2
+--R              (2a b c  - 4a )d %%R0 + (b c  - 4a c)d x + b c  - 5a c
+--R     + 
+--R         2%%R1
+--R      *
+--R         log
+--R                   3   6          2   2 4     2
+--R              (128a b d %%R0 - 16a b c d )%%R1
+--R            + 
+--R                   3   6    2            4     2  2            3   6    3
+--R              (128a b d %%R0  + (- 4a b c  + 8a )d )%%R1 + 128a b d %%R0
+--R            + 
+--R                 2 2           5                 6       2
+--R              16a d %%R0 + (b c  - 4a c)d x + b c  - 7a c
+--R     + 
+--R         2%%R0
+--R      *
+--R         log
+--R                    3   6    3      2   2 4    2            4     2  2
+--R              - 128a b d %%R0  - 16a b c d %%R0  + (- 4a b c  - 8a )d %%R0
+--R            + 
+--R                  5                 6      2
+--R              (b c  - 4a c)d x + b c  + a c
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 444
+
+--S 445 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                  2 +-+ +-+4+-+3 +-+4+-+
+--R                2d \|2 \|a \|a  \|b \|b
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |        4    2         4                  4    2
+--R                 |- 6a b d %%R1  - 4a b d %%R0 %%R1 - 6a b d %%R0  - 1
+--R                 |----------------------------------------------------
+--R                 |                             4
+--R                \|                       2a b d
+--R         + 
+--R               2 +-+ +-+4+-+3 +-+4+-+         2 +-+ +-+4+-+3 +-+4+-+
+--R           - 2d \|2 \|a \|a  \|b \|b %%R1 - 2d \|2 \|a \|a  \|b \|b %%R0
+--R      *
+--R         log
+--R                      3   6         2   2 4          2   2 4
+--R                  (64a b d %%R0 - 8a b c d )%%R1 - 8a b c d %%R0
+--R                + 
+--R                         4     2  2
+--R                  (2a b c  - 4a )d
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |        4    2         4                  4    2
+--R                 |- 6a b d %%R1  - 4a b d %%R0 %%R1 - 6a b d %%R0  - 1
+--R                 |----------------------------------------------------
+--R                 |                             4
+--R                \|                       2a b d
+--R            + 
+--R                    3   6         2   2 4     2
+--R              (- 64a b d %%R0 + 8a b c d )%%R1
+--R            + 
+--R                    3   6    2          4     2  2          2   2 4    2
+--R              (- 64a b d %%R0  + (2a b c  - 4a )d )%%R1 + 8a b c d %%R0
+--R            + 
+--R                     4     2  2           5                 6       2
+--R              (2a b c  - 4a )d %%R0 + (b c  - 4a c)d x + b c  - 5a c
+--R     + 
+--R               2 +-+ +-+4+-+3 +-+4+-+
+--R             2d \|2 \|a \|a  \|b \|b
+--R          *
+--R              +----------------------------------------------------+
+--R              |        4    2         4                  4    2
+--R              |- 6a b d %%R1  - 4a b d %%R0 %%R1 - 6a b d %%R0  - 1
+--R              |----------------------------------------------------
+--R              |                             4
+--R             \|                       2a b d
+--R         + 
+--R               2 +-+ +-+4+-+3 +-+4+-+         2 +-+ +-+4+-+3 +-+4+-+
+--R           - 2d \|2 \|a \|a  \|b \|b %%R1 - 2d \|2 \|a \|a  \|b \|b %%R0
+--R      *
+--R         log
+--R                        3   6         2   2 4          2   2 4
+--R                  (- 64a b d %%R0 + 8a b c d )%%R1 + 8a b c d %%R0
+--R                + 
+--R                           4     2  2
+--R                  (- 2a b c  + 4a )d
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |        4    2         4                  4    2
+--R                 |- 6a b d %%R1  - 4a b d %%R0 %%R1 - 6a b d %%R0  - 1
+--R                 |----------------------------------------------------
+--R                 |                             4
+--R                \|                       2a b d
+--R            + 
+--R                    3   6         2   2 4     2
+--R              (- 64a b d %%R0 + 8a b c d )%%R1
+--R            + 
+--R                    3   6    2          4     2  2          2   2 4    2
+--R              (- 64a b d %%R0  + (2a b c  - 4a )d )%%R1 + 8a b c d %%R0
+--R            + 
+--R                     4     2  2           5                 6       2
+--R              (2a b c  - 4a )d %%R0 + (b c  - 4a c)d x + b c  - 5a c
+--R     + 
+--R           2 +-+ +-+4+-+3 +-+4+-+
+--R         4d \|2 \|a \|a  \|b \|b %%R1
+--R      *
+--R         log
+--R                   3   6          2   2 4     2
+--R              (128a b d %%R0 - 16a b c d )%%R1
+--R            + 
+--R                   3   6    2            4     2  2            3   6    3
+--R              (128a b d %%R0  + (- 4a b c  + 8a )d )%%R1 + 128a b d %%R0
+--R            + 
+--R                 2 2           5                 6       2
+--R              16a d %%R0 + (b c  - 4a c)d x + b c  - 7a c
+--R     + 
+--R         +-+ +-+              +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       c\|a \|b log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R           +-+ +-+                +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       - c\|a \|b log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R           2 +-+ +-+4+-+3 +-+4+-+
+--R         4d \|2 \|a \|a  \|b \|b %%R0
+--R      *
+--R         log
+--R                    3   6    3      2   2 4    2            4     2  2
+--R              - 128a b d %%R0  - 16a b c d %%R0  + (- 4a b c  - 8a )d %%R0
+--R            + 
+--R                  5                 6      2
+--R              (b c  - 4a c)d x + b c  + a c
+--R     + 
+--R                                +-+4+-+   4+-+
+--R          +-+ +-+     (d x + c)\|2 \|b  + \|a
+--R       2c\|a \|b atan(------------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                                +-+4+-+   4+-+
+--R          +-+ +-+     (d x + c)\|2 \|b  - \|a
+--R       2c\|a \|b atan(------------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                               2 2             2  +-+
+--R           +-+4+-+3 4+-+     (d x  + 2c d x + c )\|b
+--R       - 2\|2 \|a   \|b atan(------------------------)
+--R                                        +-+
+--R                                       \|a
+--R  /
+--R       2 +-+ +-+4+-+3 +-+4+-+
+--R     4d \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      2 2     2        3  +-+4+-+2        6 6       2 5 5
+--R               (- 2c d x  - 4c d x - 2c )\|a \|a   - b c d x  - 6b c d x
+--R             + 
+--R                      3 4 4        4 3 3           5        2 2
+--R               - 15b c d x  - 20b c d x  + (- 15b c  - a c)d x
+--R             + 
+--R                      6       2          7      3
+--R               (- 6b c  - 2a c )d x - b c  - a c
+--R          *
+--R              +-+
+--R             \|b
+--R         + 
+--R                      4 4        2 3 3        3 2 2        4          5
+--R             (- 3b c d x  - 12b c d x  - 18b c d x  - 12b c d x - 3b c  - a c)
+--R          *
+--R             4+-+2
+--R             \|a
+--R         + 
+--R                 4 4       2 3 3       3 2 2       4         5        +-+
+--R           (b c d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a c)\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R              4 4       2 3 3        3 2 2       4          5  +-+ +-+
+--R       (2b c d x  + 8b c d x  + 12b c d x  + 8b c d x + 2b c )\|a \|b
+--R     + 
+--R        2   6 6     2 2 5 5      2 3 4 4      2 4 3 3       2 5           2 2
+--R       b c d x  + 6b c d x  + 15b c d x  + 20b c d x  + (15b c  + 3a b c)d x
+--R     + 
+--R          2 6         2        2 7         3
+--R       (6b c  + 6a b c )d x + b c  + 3a b c
+--R  /
+--R                   7 6          6 5        2 5 4        3 4 3
+--R               4b d x  + 24b c d x  + 60b c d x  + 80b c d x
+--R             + 
+--R                     4       3 2         5         2         6       2
+--R               (60b c  + 4a)d x  + (24b c  + 8a c)d x + (4b c  + 4a c )d
+--R          *
+--R              +-+4+-+2 +-+
+--R             \|a \|a  \|b
+--R         + 
+--R                 2 9 8      2   8 7      2 2 7 6       2 3 6 5
+--R               2b d x  + 16b c d x  + 56b c d x  + 112b c d x
+--R             + 
+--R                    2 4         5 4        2 5            4 3
+--R               (140b c  + 4a b)d x  + (112b c  + 16a b c)d x
+--R             + 
+--R                   2 6          2  3 2       2 7          3  2
+--R               (56b c  + 24a b c )d x  + (16b c  + 16a b c )d x
+--R             + 
+--R                  2 8         4     2
+--R               (2b c  + 4a b c  + 2a )d
+--R          *
+--R             4+-+2
+--R             \|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R             2 7 6        2   6 5        2 2 5 4        2 3 4 3
+--R       - 4a b d x  - 24a b c d x  - 60a b c d x  - 80a b c d x
+--R     + 
+--R             2 4     2   3 2           2 5     2     2           2 6     2   2
+--R     (- 60a b c  - 4a b)d x  + (- 24a b c  - 8a b c)d x + (- 4a b c  - 4a b c )d
+--R                                                    Type: Expression(Integer)
+--E 446
+
+)clear all
+
+--S 447 of 619
+t0:=1/(a+b*(c+d*x)^4)
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R           4 4         3 3       2 2 2       3         4
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 447
+
+--S 448 of 619
+r0:=-1/2*atan(1-b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*d*_
+   sqrt(2))+1/2*atan(1+b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*_
+   d*sqrt(2))-1/4*log(-a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*_
+   sqrt(b))/(a^(3/4)*b^(1/4)*d*sqrt(2))+1/4*log(a^(1/4)*b^(1/4)*(c+d*x)*_
+   sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))/(a^(3/4)*b^(1/4)*d*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                     +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       - log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                       +-+4+-+   4+-+                    +-+4+-+   4+-+
+--R             (d x + c)\|2 \|b  + \|a           (d x + c)\|2 \|b  - \|a
+--R       2atan(------------------------) + 2atan(------------------------)
+--R                       4+-+                              4+-+
+--R                       \|a                               \|a
+--R  /
+--R        +-+4+-+3 4+-+
+--R     4d\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      +-----------+          +-----------+
+--R      |      1               |      1
+--R      |- --------- log(4a d  |- --------- + d x + c)
+--R     4|      3   4          4|      3   4
+--R     \|  256a b d           \|  256a b d
+--R   + 
+--R        +-----------+            +-----------+
+--R        |      1                 |      1
+--R     -  |- --------- log(- 4a d  |- --------- + d x + c)
+--R       4|      3   4            4|      3   4
+--R       \|  256a b d             \|  256a b d
+--R   + 
+--R                                  +-----------+
+--R                                  |      1
+--R                            4a d  |- ---------
+--R          +-----------+          4|      3   4
+--R          |      1               \|  256a b d
+--R     - 2  |- --------- atan(------------------)
+--R         4|      3   4            d x + c
+--R         \|  256a b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 449
+
+--S 450 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       - log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R               +-----------+                    +-----------+
+--R          +-+  |      1     4+-+3 4+-+          |      1
+--R       4d\|2   |- --------- \|a   \|b log(4a d  |- --------- + d x + c)
+--R              4|      3   4                    4|      3   4
+--R              \|  256a b d                     \|  256a b d
+--R     + 
+--R                 +-----------+                      +-----------+
+--R            +-+  |      1     4+-+3 4+-+            |      1
+--R       - 4d\|2   |- --------- \|a   \|b log(- 4a d  |- --------- + d x + c)
+--R                4|      3   4                      4|      3   4
+--R                \|  256a b d                       \|  256a b d
+--R     + 
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                         +-+4+-+   4+-+                    +-+4+-+   4+-+
+--R               (d x + c)\|2 \|b  + \|a           (d x + c)\|2 \|b  - \|a
+--R       - 2atan(------------------------) - 2atan(------------------------)
+--R                         4+-+                              4+-+
+--R                         \|a                               \|a
+--R     + 
+--R                                                   +-----------+
+--R                                                   |      1
+--R                                             4a d  |- ---------
+--R                 +-----------+                    4|      3   4
+--R            +-+  |      1     4+-+3 4+-+          \|  256a b d
+--R       - 8d\|2   |- --------- \|a   \|b atan(------------------)
+--R                4|      3   4                      d x + c
+--R                \|  256a b d
+--R  /
+--R        +-+4+-+3 4+-+
+--R     4d\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 450
+
+--S 451 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  2 2              2  +-+4+-+2      6 6         5 5        2 4 4
+--R               (2d x  + 4c d x + 2c )\|a \|a   + b d x  + 6b c d x  + 15b c d x
+--R             + 
+--R                    3 3 3         4      2 2        5                 6      2
+--R               20b c d x  + (15b c  + a)d x  + (6b c  + 2a c)d x + b c  + a c
+--R          *
+--R              +-+
+--R             \|b
+--R         + 
+--R                4 4          3 3        2 2 2        3          4     4+-+2
+--R           (3b d x  + 12b c d x  + 18b c d x  + 12b c d x + 3b c  + a)\|a
+--R         + 
+--R                 4 4         3 3       2 2 2       3         4      +-+
+--R           (- b d x  - 4b c d x  - 6b c d x  - 4b c d x - b c  - a)\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R              4 4         3 3        2 2 2       3          4  +-+ +-+    2 6 6
+--R       (- 2b d x  - 8b c d x  - 12b c d x  - 8b c d x - 2b c )\|a \|b  - b d x
+--R     + 
+--R           2   5 5      2 2 4 4      2 3 3 3         2 4         2 2
+--R       - 6b c d x  - 15b c d x  - 20b c d x  + (- 15b c  - 3a b)d x
+--R     + 
+--R            2 5                 2 6         2
+--R       (- 6b c  - 6a b c)d x - b c  - 3a b c
+--R  /
+--R                   6 6          5 5        2 4 4        3 3 3
+--R               4b d x  + 24b c d x  + 60b c d x  + 80b c d x
+--R             + 
+--R                     4       2 2         5                  6       2
+--R               (60b c  + 4a)d x  + (24b c  + 8a c)d x + 4b c  + 4a c
+--R          *
+--R              +-+4+-+2 +-+
+--R             \|a \|a  \|b
+--R         + 
+--R                 2 8 8      2   7 7      2 2 6 6       2 3 5 5
+--R               2b d x  + 16b c d x  + 56b c d x  + 112b c d x
+--R             + 
+--R                    2 4         4 4        2 5            3 3
+--R               (140b c  + 4a b)d x  + (112b c  + 16a b c)d x
+--R             + 
+--R                   2 6          2  2 2       2 7          3         2 8
+--R               (56b c  + 24a b c )d x  + (16b c  + 16a b c )d x + 2b c
+--R             + 
+--R                     4     2
+--R               4a b c  + 2a
+--R          *
+--R             4+-+2
+--R             \|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R             2 6 6        2   5 5        2 2 4 4        2 3 3 3
+--R       - 4a b d x  - 24a b c d x  - 60a b c d x  - 80a b c d x
+--R     + 
+--R               2 4     2   2 2           2 5     2              2 6     2   2
+--R       (- 60a b c  - 4a b)d x  + (- 24a b c  - 8a b c)d x - 4a b c  - 4a b c
+--R                                                    Type: Expression(Integer)
+--E 451
+
+)clear all
+
+--S 452 of 619
+t0:=1/(x*(a+b*(c+d*x)^4))
+--R 
+--R
+--R                                    1
+--R   (1)  --------------------------------------------------------
+--R           4 5         3 4       2 2 3       3   2       4
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x  + (b c  + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 452
+
+--S 453 of 619
+r0:=log(x)/(a+b*c^4)-1/4*log(a+b*(c+d*x)^4)/(a+b*c^4)-1/2*c^2*atan((c+d*x)^2*_
+   sqrt(b)/sqrt(a))*sqrt(b)/((a+b*c^4)*sqrt(a))-1/4*b^(1/4)*c*_
+   log(-a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))*_
+   (sqrt(a)-c^2*sqrt(b))/(a^(3/4)*(a+b*c^4)*sqrt(2))+1/4*b^(1/4)*c*_
+   log(a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))*_
+   (sqrt(a)-c^2*sqrt(b))/(a^(3/4)*(a+b*c^4)*sqrt(2))+1/2*b^(1/4)*c*_
+   atan(1-b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))*(sqrt(a)+c^2*sqrt(b))/(a^(3/4)*_
+   (a+b*c^4)*sqrt(2))-1/2*b^(1/4)*c*atan(1+b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))*_
+   (sqrt(a)+c^2*sqrt(b))/(a^(3/4)*(a+b*c^4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             3 +-+ +-+       4+-+
+--R         (- c \|a \|b  + a c)\|b
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R           3 +-+ +-+       4+-+
+--R         (c \|a \|b  - a c)\|b
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                                                +-+4+-+   4+-+
+--R            3 +-+ +-+        4+-+     (d x + c)\|2 \|b  + \|a
+--R       (- 2c \|a \|b  - 2a c)\|b atan(------------------------)
+--R                                                4+-+
+--R                                                \|a
+--R     + 
+--R                                                +-+4+-+   4+-+
+--R            3 +-+ +-+        4+-+     (d x + c)\|2 \|b  - \|a
+--R       (- 2c \|a \|b  - 2a c)\|b atan(------------------------)
+--R                                                4+-+
+--R                                                \|a
+--R     + 
+--R                                2 2             2  +-+
+--R           2 +-+4+-+3 +-+     (d x  + 2c d x + c )\|b
+--R       - 2c \|2 \|a  \|b atan(------------------------)
+--R                                         +-+
+--R                                        \|a
+--R     + 
+--R              +-+       4 4         3 3       2 2 2       3         4
+--R           - \|2 log(b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a)
+--R         + 
+--R             +-+
+--R           4\|2 log(x)
+--R      *
+--R          +-+4+-+3
+--R         \|a \|a
+--R  /
+--R          4       +-+ +-+4+-+3
+--R     (4b c  + 4a)\|2 \|a \|a
+--R                                                    Type: Expression(Integer)
+--E 453
+
+--S 454 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   4
+--R             (- b c  - a)
+--R          *
+--R             ROOT
+--R                           2 8      2   4     3      2
+--R                    (- 6a b c  - 12a b c  - 6a )%%BB1
+--R                  + 
+--R                            2 8     2   4     3               4     2
+--R                    ((- 4a b c  - 8a b c  - 4a )%%BB0 - 4a b c  - 4a )%%BB1
+--R                  + 
+--R                           2 8      2   4     3      2            4     2
+--R                    (- 6a b c  - 12a b c  - 6a )%%BB0  + (- 4a b c  - 4a )%%BB0
+--R                  + 
+--R                          4
+--R                    - 3b c  - a
+--R               /
+--R                      2 8     2   4     3
+--R                  2a b c  + 4a b c  + 2a
+--R         + 
+--R                 4                   4
+--R           (- b c  - a)%%BB1 + (- b c  - a)%%BB0 - 1
+--R      *
+--R         log
+--R                       3   4      4           2   4     3
+--R                  ((32a b c  + 32a )%%BB0 + 8a b c  + 8a )%%BB1
+--R                + 
+--R                     2   4     3               4     2
+--R                  (8a b c  + 8a )%%BB0 + 2a b c  + 2a
+--R             *
+--R                ROOT
+--R                              2 8      2   4     3      2
+--R                       (- 6a b c  - 12a b c  - 6a )%%BB1
+--R                     + 
+--R                               2 8     2   4     3               4     2
+--R                       ((- 4a b c  - 8a b c  - 4a )%%BB0 - 4a b c  - 4a )%%BB1
+--R                     + 
+--R                              2 8      2   4     3      2
+--R                       (- 6a b c  - 12a b c  - 6a )%%BB0
+--R                     + 
+--R                                4     2             4
+--R                       (- 4a b c  - 4a )%%BB0 - 3b c  - a
+--R                  /
+--R                         2 8     2   4     3
+--R                     2a b c  + 4a b c  + 2a
+--R            + 
+--R                     3   4      4           2   4     3      2
+--R              ((- 32a b c  - 32a )%%BB0 - 8a b c  - 8a )%%BB1
+--R            + 
+--R                     3   4      4      2      3              4     2
+--R              ((- 32a b c  - 32a )%%BB0  - 32a %%BB0 + 2a b c  - 6a )%%BB1
+--R            + 
+--R                 2   4     3      2          4     2            3         4
+--R            (- 8a b c  - 8a )%%BB0  + (2a b c  - 6a )%%BB0 + b c d x + b c  - a
+--R     + 
+--R                 4
+--R             (b c  + a)
+--R          *
+--R             ROOT
+--R                           2 8      2   4     3      2
+--R                    (- 6a b c  - 12a b c  - 6a )%%BB1
+--R                  + 
+--R                            2 8     2   4     3               4     2
+--R                    ((- 4a b c  - 8a b c  - 4a )%%BB0 - 4a b c  - 4a )%%BB1
+--R                  + 
+--R                           2 8      2   4     3      2            4     2
+--R                    (- 6a b c  - 12a b c  - 6a )%%BB0  + (- 4a b c  - 4a )%%BB0
+--R                  + 
+--R                          4
+--R                    - 3b c  - a
+--R               /
+--R                      2 8     2   4     3
+--R                  2a b c  + 4a b c  + 2a
+--R         + 
+--R                 4                   4
+--R           (- b c  - a)%%BB1 + (- b c  - a)%%BB0 - 1
+--R      *
+--R         log
+--R                         3   4      4           2   4     3
+--R                  ((- 32a b c  - 32a )%%BB0 - 8a b c  - 8a )%%BB1
+--R                + 
+--R                       2   4     3               4     2
+--R                  (- 8a b c  - 8a )%%BB0 - 2a b c  - 2a
+--R             *
+--R                ROOT
+--R                              2 8      2   4     3      2
+--R                       (- 6a b c  - 12a b c  - 6a )%%BB1
+--R                     + 
+--R                               2 8     2   4     3               4     2
+--R                       ((- 4a b c  - 8a b c  - 4a )%%BB0 - 4a b c  - 4a )%%BB1
+--R                     + 
+--R                              2 8      2   4     3      2
+--R                       (- 6a b c  - 12a b c  - 6a )%%BB0
+--R                     + 
+--R                                4     2             4
+--R                       (- 4a b c  - 4a )%%BB0 - 3b c  - a
+--R                  /
+--R                         2 8     2   4     3
+--R                     2a b c  + 4a b c  + 2a
+--R            + 
+--R                     3   4      4           2   4     3      2
+--R              ((- 32a b c  - 32a )%%BB0 - 8a b c  - 8a )%%BB1
+--R            + 
+--R                     3   4      4      2      3              4     2
+--R              ((- 32a b c  - 32a )%%BB0  - 32a %%BB0 + 2a b c  - 6a )%%BB1
+--R            + 
+--R                 2   4     3      2          4     2            3         4
+--R            (- 8a b c  - 8a )%%BB0  + (2a b c  - 6a )%%BB0 + b c d x + b c  - a
+--R     + 
+--R              4
+--R         (2b c  + 2a)%%BB1
+--R      *
+--R         log
+--R                   3   4      4            2   4      3      2
+--R              ((64a b c  + 64a )%%BB0 + 16a b c  + 16a )%%BB1
+--R            + 
+--R                   3   4      4      2      3              4      2
+--R              ((64a b c  + 64a )%%BB0  + 64a %%BB0 - 4a b c  + 12a )%%BB1
+--R            + 
+--R                  3   4      4      3      3     2      2           3         4
+--R              (64a b c  + 64a )%%BB0  + 64a %%BB0  + 24a %%BB0 + b c d x + b c
+--R            + 
+--R              3a
+--R     + 
+--R              4
+--R         (2b c  + 2a)%%BB0
+--R      *
+--R         log
+--R                    3   4      4      3       2   4      3      2
+--R              (- 64a b c  - 64a )%%BB0  + (16a b c  - 48a )%%BB0
+--R            + 
+--R                       4      2            3         4
+--R              (- 4a b c  - 12a )%%BB0 + b c d x + b c  - a
+--R     + 
+--R       2log(x)
+--R  /
+--R         4
+--R     2b c  + 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 454
+
+--S 455 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    4       +-+ +-+4+-+3
+--R             (- 2b c  - 2a)\|2 \|a \|a
+--R          *
+--R             ROOT
+--R                           2 8      2   4     3      2
+--R                    (- 6a b c  - 12a b c  - 6a )%%BB1
+--R                  + 
+--R                            2 8     2   4     3               4     2
+--R                    ((- 4a b c  - 8a b c  - 4a )%%BB0 - 4a b c  - 4a )%%BB1
+--R                  + 
+--R                           2 8      2   4     3      2            4     2
+--R                    (- 6a b c  - 12a b c  - 6a )%%BB0  + (- 4a b c  - 4a )%%BB0
+--R                  + 
+--R                          4
+--R                    - 3b c  - a
+--R               /
+--R                      2 8     2   4     3
+--R                  2a b c  + 4a b c  + 2a
+--R         + 
+--R                  4       +-+ +-+4+-+3               4       +-+ +-+4+-+3
+--R           (- 2b c  - 2a)\|2 \|a \|a  %%BB1 + (- 2b c  - 2a)\|2 \|a \|a  %%BB0
+--R         + 
+--R               +-+ +-+4+-+3
+--R           - 2\|2 \|a \|a
+--R      *
+--R         log
+--R                       3   4      4           2   4     3
+--R                  ((32a b c  + 32a )%%BB0 + 8a b c  + 8a )%%BB1
+--R                + 
+--R                     2   4     3               4     2
+--R                  (8a b c  + 8a )%%BB0 + 2a b c  + 2a
+--R             *
+--R                ROOT
+--R                              2 8      2   4     3      2
+--R                       (- 6a b c  - 12a b c  - 6a )%%BB1
+--R                     + 
+--R                               2 8     2   4     3               4     2
+--R                       ((- 4a b c  - 8a b c  - 4a )%%BB0 - 4a b c  - 4a )%%BB1
+--R                     + 
+--R                              2 8      2   4     3      2
+--R                       (- 6a b c  - 12a b c  - 6a )%%BB0
+--R                     + 
+--R                                4     2             4
+--R                       (- 4a b c  - 4a )%%BB0 - 3b c  - a
+--R                  /
+--R                         2 8     2   4     3
+--R                     2a b c  + 4a b c  + 2a
+--R            + 
+--R                     3   4      4           2   4     3      2
+--R              ((- 32a b c  - 32a )%%BB0 - 8a b c  - 8a )%%BB1
+--R            + 
+--R                     3   4      4      2      3              4     2
+--R              ((- 32a b c  - 32a )%%BB0  - 32a %%BB0 + 2a b c  - 6a )%%BB1
+--R            + 
+--R                 2   4     3      2          4     2            3         4
+--R            (- 8a b c  - 8a )%%BB0  + (2a b c  - 6a )%%BB0 + b c d x + b c  - a
+--R     + 
+--R                  4       +-+ +-+4+-+3
+--R             (2b c  + 2a)\|2 \|a \|a
+--R          *
+--R             ROOT
+--R                           2 8      2   4     3      2
+--R                    (- 6a b c  - 12a b c  - 6a )%%BB1
+--R                  + 
+--R                            2 8     2   4     3               4     2
+--R                    ((- 4a b c  - 8a b c  - 4a )%%BB0 - 4a b c  - 4a )%%BB1
+--R                  + 
+--R                           2 8      2   4     3      2            4     2
+--R                    (- 6a b c  - 12a b c  - 6a )%%BB0  + (- 4a b c  - 4a )%%BB0
+--R                  + 
+--R                          4
+--R                    - 3b c  - a
+--R               /
+--R                      2 8     2   4     3
+--R                  2a b c  + 4a b c  + 2a
+--R         + 
+--R                  4       +-+ +-+4+-+3               4       +-+ +-+4+-+3
+--R           (- 2b c  - 2a)\|2 \|a \|a  %%BB1 + (- 2b c  - 2a)\|2 \|a \|a  %%BB0
+--R         + 
+--R               +-+ +-+4+-+3
+--R           - 2\|2 \|a \|a
+--R      *
+--R         log
+--R                         3   4      4           2   4     3
+--R                  ((- 32a b c  - 32a )%%BB0 - 8a b c  - 8a )%%BB1
+--R                + 
+--R                       2   4     3               4     2
+--R                  (- 8a b c  - 8a )%%BB0 - 2a b c  - 2a
+--R             *
+--R                ROOT
+--R                              2 8      2   4     3      2
+--R                       (- 6a b c  - 12a b c  - 6a )%%BB1
+--R                     + 
+--R                               2 8     2   4     3               4     2
+--R                       ((- 4a b c  - 8a b c  - 4a )%%BB0 - 4a b c  - 4a )%%BB1
+--R                     + 
+--R                              2 8      2   4     3      2
+--R                       (- 6a b c  - 12a b c  - 6a )%%BB0
+--R                     + 
+--R                                4     2             4
+--R                       (- 4a b c  - 4a )%%BB0 - 3b c  - a
+--R                  /
+--R                         2 8     2   4     3
+--R                     2a b c  + 4a b c  + 2a
+--R            + 
+--R                     3   4      4           2   4     3      2
+--R              ((- 32a b c  - 32a )%%BB0 - 8a b c  - 8a )%%BB1
+--R            + 
+--R                     3   4      4      2      3              4     2
+--R              ((- 32a b c  - 32a )%%BB0  - 32a %%BB0 + 2a b c  - 6a )%%BB1
+--R            + 
+--R                 2   4     3      2          4     2            3         4
+--R            (- 8a b c  - 8a )%%BB0  + (2a b c  - 6a )%%BB0 + b c d x + b c  - a
+--R     + 
+--R              4       +-+ +-+4+-+3
+--R         (4b c  + 4a)\|2 \|a \|a  %%BB1
+--R      *
+--R         log
+--R                   3   4      4            2   4      3      2
+--R              ((64a b c  + 64a )%%BB0 + 16a b c  + 16a )%%BB1
+--R            + 
+--R                   3   4      4      2      3              4      2
+--R              ((64a b c  + 64a )%%BB0  + 64a %%BB0 - 4a b c  + 12a )%%BB1
+--R            + 
+--R                  3   4      4      3      3     2      2           3         4
+--R              (64a b c  + 64a )%%BB0  + 64a %%BB0  + 24a %%BB0 + b c d x + b c
+--R            + 
+--R              3a
+--R     + 
+--R           3 +-+ +-+       4+-+
+--R         (c \|a \|b  - a c)\|b
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R             3 +-+ +-+       4+-+
+--R         (- c \|a \|b  + a c)\|b
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R              4       +-+ +-+4+-+3
+--R         (4b c  + 4a)\|2 \|a \|a  %%BB0
+--R      *
+--R         log
+--R                    3   4      4      3       2   4      3      2
+--R              (- 64a b c  - 64a )%%BB0  + (16a b c  - 48a )%%BB0
+--R            + 
+--R                       4      2            3         4
+--R              (- 4a b c  - 12a )%%BB0 + b c d x + b c  - a
+--R     + 
+--R                                              +-+4+-+   4+-+
+--R          3 +-+ +-+        4+-+     (d x + c)\|2 \|b  + \|a
+--R       (2c \|a \|b  + 2a c)\|b atan(------------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                              +-+4+-+   4+-+
+--R          3 +-+ +-+        4+-+     (d x + c)\|2 \|b  - \|a
+--R       (2c \|a \|b  + 2a c)\|b atan(------------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                              2 2             2  +-+
+--R         2 +-+4+-+3 +-+     (d x  + 2c d x + c )\|b
+--R       2c \|2 \|a  \|b atan(------------------------)
+--R                                       +-+
+--R                                      \|a
+--R     + 
+--R        +-+       4 4         3 3       2 2 2       3         4      +-+4+-+3
+--R       \|2 log(b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a)\|a \|a
+--R  /
+--R          4       +-+ +-+4+-+3
+--R     (4b c  + 4a)\|2 \|a \|a
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                      3 5 4       4 4 3        5         3 2
+--R                   b c d x  + 4b c d x  + (6b c  - 2a c)d x
+--R                 + 
+--R                        6       2  2        7       3
+--R                   (4b c  - 4a c )d x + (b c  - 3a c )d
+--R              *
+--R                 4+-+2
+--R                 \|a
+--R             + 
+--R                          7 6       2 6 5        3 5 4        4 4 3
+--R                   - b c d x  - 6b c d x  - 16b c d x  - 24b c d x
+--R                 + 
+--R                           5        3 2           6       2  2
+--R                   (- 21b c  - a c)d x  + (- 10b c  - 2a c )d x
+--R                 + 
+--R                          7       3
+--R                   (- 2b c  - 2a c )d
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +-+
+--R             \|b
+--R         + 
+--R                 5 4       2 4 3       3 3 2         5          +-+4+-+2
+--R           (b c d x  + 4b c d x  + 4b c d x  + (- b c  - a c)d)\|a \|a
+--R         + 
+--R            2 3 7 6     2 4 6 5       2 5           5 4
+--R           b c d x  + 6b c d x  + (15b c  - 3a b c)d x
+--R         + 
+--R               2 6          2  4 3       2 7          3  3 2
+--R           (20b c  - 12a b c )d x  + (15b c  - 21a b c )d x
+--R         + 
+--R              2 8          4  2      2 9         5    2
+--R           (6b c  - 18a b c )d x + (b c  - 6a b c  + a c)d
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                  5 4        2 4 3        3 3 2        4 2        5   +-+4+-+2
+--R           (4b c d x  + 16b c d x  + 28b c d x  + 24b c d x + 8b c d)\|a \|a
+--R         + 
+--R              2 3 7 6     2 4 6 5         2 5           5 4
+--R           - b c d x  - 6b c d x  + (- 15b c  - 2a b c)d x
+--R         + 
+--R                 2 6         2  4 3         2 7          3  3 2
+--R           (- 20b c  - 8a b c )d x  + (- 15b c  - 11a b c )d x
+--R         + 
+--R                2 8         4  2        2 9        5
+--R           (- 6b c  - 6a b c )d x + (- b c  - a b c )d
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R             2   7 6      2 2 6 5      2 3 5 4      2 4 4 3
+--R           2b c d x  + 12b c d x  + 32b c d x  + 48b c d x
+--R         + 
+--R               2 5           3 2       2 6         2  2       2 7         3
+--R           (42b c  + 2a b c)d x  + (20b c  + 4a b c )d x + (4b c  + 4a b c )d
+--R      *
+--R         4+-+2
+--R         \|a
+--R     + 
+--R              2   7 6     2 2 6 5      2 3 5 4      2 4 4 3
+--R           - b c d x  - 6b c d x  - 17b c d x  - 28b c d x
+--R         + 
+--R               2 5          3 2         2 6         2  2         2 7        3
+--R         (- 27b c  + a b c)d x  + (- 14b c  + 2a b c )d x + (- 3b c  + a b c )d
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                2 4     2   6 6         2 5      2     5 5
+--R           (4a b c  + 4a b)d x  + (24a b c  + 24a b c)d x
+--R         + 
+--R                 2 6      2   2  4 4         2 7      2   3  3 3
+--R           (60a b c  + 60a b c )d x  + (80a b c  + 80a b c )d x
+--R         + 
+--R                 2 8      2   4     3  2 2         2 9      2   5     3
+--R           (60a b c  + 64a b c  + 4a )d x  + (24a b c  + 32a b c  + 8a c)d x
+--R         + 
+--R               2 10     2   6     3 2
+--R           4a b c   + 8a b c  + 4a c
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                2 4         6 6         2 5            5 5
+--R           (- 4b c  - 4a b)d x  + (- 24b c  - 24a b c)d x
+--R         + 
+--R                 2 6          2  4 4         2 7          3  3 3
+--R           (- 60b c  - 60a b c )d x  + (- 80b c  - 80a b c )d x
+--R         + 
+--R                 2 8          4     2  2 2         2 9          5     2
+--R           (- 60b c  - 64a b c  - 4a )d x  + (- 24b c  - 32a b c  - 8a c)d x
+--R         + 
+--R               2 10         6     2 2
+--R           - 4b c   - 8a b c  - 4a c
+--R      *
+--R          +-+4+-+2 +-+
+--R         \|a \|a  \|b
+--R     + 
+--R                3 4       2  8 8         3 5        2   7 7
+--R           (- 2b c  - 2a b )d x  + (- 16b c  - 16a b c)d x
+--R         + 
+--R                 3 6        2 2  6 6          3 7         2 3  5 5
+--R           (- 56b c  - 56a b c )d x  + (- 112b c  - 112a b c )d x
+--R         + 
+--R                  3 8         2 4     2   4 4
+--R           (- 140b c  - 144a b c  - 4a b)d x
+--R         + 
+--R                  3 9         2 5      2     3 3
+--R           (- 112b c  - 128a b c  - 16a b c)d x
+--R         + 
+--R                 3 10        2 6      2   2  2 2
+--R           (- 56b c   - 80a b c  - 24a b c )d x
+--R         + 
+--R               3 11        2 7      2   3         3 12       2 8     2   4     3
+--R         (- 16b c   - 32a b c  - 16a b c )d x - 2b c   - 6a b c  - 6a b c  - 2a
+--R      *
+--R         4+-+2
+--R         \|a
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 619
+t0:=1/(x^2*(a+b*(c+d*x)^4))
+--R 
+--R
+--R                                    1
+--R   (1)  ---------------------------------------------------------
+--R           4 6         3 5       2 2 4       3   3       4      2
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x  + (b c  + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 457
+
+--S 458 of 619
+r0:=(-1)/((a+b*c^4)*x)-4*b*c^3*d*log(x)/(a+b*c^4)^2+b*c^3*d*log(a+b*(c+_
+   d*x)^4)/(a+b*c^4)^2-c*(a-b*c^4)*d*atan((c+d*x)^2*sqrt(b)/sqrt(a))*_
+   sqrt(b)/((a+b*c^4)^2*sqrt(a))-1/4*b^(1/4)*d*log(-a^(1/4)*b^(1/4)*_
+   (c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))*(a^(3/2)+b^(3/2)*c^6-_
+   3*b*c^4*sqrt(a)-3*a*c^2*sqrt(b))/(a^(3/4)*(a+b*c^4)^2*sqrt(2))+_
+   1/4*b^(1/4)*d*log(a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*_
+   sqrt(b))*(a^(3/2)+b^(3/2)*c^6-3*b*c^4*sqrt(a)-3*a*c^2*sqrt(b))/_
+   (a^(3/4)*(a+b*c^4)^2*sqrt(2))+1/2*b^(1/4)*d*atan(1-b^(1/4)*(c+d*x)*_
+   sqrt(2)/a^(1/4))*((a-3*b*c^4)*sqrt(a)+c^2*(3*a-b*c^4)*sqrt(b))/(a^(3/4)*_
+   (a+b*c^4)^2*sqrt(2))-1/2*b^(1/4)*d*atan(1+b^(1/4)*(c+d*x)*_
+   sqrt(2)/a^(1/4))*((a-3*b*c^4)*sqrt(a)+c^2*(3*a-b*c^4)*sqrt(b))/_
+   (a^(3/4)*(a+b*c^4)^2*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              6       2     +-+ +-+            4    2     4+-+
+--R         ((b c  - 3a c )d x\|a \|b  + (- 3a b c  + a )d x)\|b
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                6       2     +-+ +-+          4    2     4+-+
+--R         ((- b c  + 3a c )d x\|a \|b  + (3a b c  - a )d x)\|b
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R               6       2     +-+ +-+          4     2     4+-+
+--R         ((2b c  - 6a c )d x\|a \|b  + (6a b c  - 2a )d x)\|b
+--R      *
+--R                        +-+4+-+   4+-+
+--R              (d x + c)\|2 \|b  + \|a
+--R         atan(------------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R               6       2     +-+ +-+          4     2     4+-+
+--R         ((2b c  - 6a c )d x\|a \|b  + (6a b c  - 2a )d x)\|b
+--R      *
+--R                        +-+4+-+   4+-+
+--R              (d x + c)\|2 \|b  - \|a
+--R         atan(------------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R                                            2 2             2  +-+
+--R            5            +-+4+-+3 +-+     (d x  + 2c d x + c )\|b
+--R       (4b c  - 4a c)d x\|2 \|a  \|b atan(------------------------)
+--R                                                     +-+
+--R                                                    \|a
+--R     + 
+--R               3    +-+       4 4         3 3       2 2 2       3         4
+--R           4b c d x\|2 log(b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a)
+--R         + 
+--R                  3    +-+                4       +-+
+--R           - 16b c d x\|2 log(x) + (- 4b c  - 4a)\|2
+--R      *
+--R          +-+4+-+3
+--R         \|a \|a
+--R  /
+--R        2 8         4     2   +-+ +-+4+-+3
+--R     (4b c  + 8a b c  + 4a )x\|2 \|a \|a
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 8         4    2
+--R             (b c  + 2a b c  + a )x
+--R          *
+--R             ROOT
+--R                           4 16      2 3 12      3 2 8      4   4     5      2
+--R                    (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )%%BC1
+--R                  + 
+--R                               4 16     2 3 12      3 2 8     4   4     5
+--R                        (- 2a b c   - 8a b c   - 12a b c  - 8a b c  - 2a )%%BC0
+--R                      + 
+--R                             3 11      2 2 7     3   3
+--R                        (8a b c   + 16a b c  + 8a b c )d
+--R                   *
+--R                      %%BC1
+--R                  + 
+--R                           4 16      2 3 12      3 2 8      4   4     5      2
+--R                    (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )%%BC0
+--R                  + 
+--R                         3 11      2 2 7     3   3
+--R                    (8a b c   + 16a b c  + 8a b c )d %%BC0
+--R                  + 
+--R                         3 10       2 6     2   2  2
+--R                    (- 5b c   + 6a b c  - 5a b c )d
+--R               /
+--R                     4 16     2 3 12     3 2 8     4   4    5
+--R                  a b c   + 4a b c   + 6a b c  + 4a b c  + a
+--R         + 
+--R               2 8         4    2               2 8         4    2
+--R           (- b c  - 2a b c  - a )x %%BC1 + (- b c  - 2a b c  - a )x %%BC0
+--R         + 
+--R               3
+--R           4b c d x
+--R      *
+--R         log
+--R                           3 3 12       4 2 8       5   4      6
+--R                      (160a b c   + 352a b c  + 224a b c  + 32a )%%BC0
+--R                    + 
+--R                            2 3 11      3 2 7      4   3
+--R                      (- 16a b c   - 32a b c  - 16a b c )d
+--R                 *
+--R                    %%BC1
+--R                + 
+--R                        2 3 11      3 2 7      4   3
+--R                  (- 16a b c   - 32a b c  - 16a b c )d %%BC0
+--R                + 
+--R                       3 10     2 2 6     3   2  2
+--R                  (2a b c   + 4a b c  + 2a b c )d
+--R             *
+--R                ROOT
+--R                                4 16      2 3 12      3 2 8      4   4     5
+--R                         (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )
+--R                      *
+--R                              2
+--R                         %%BC1
+--R                     + 
+--R                                    4 16     2 3 12      3 2 8     4   4     5
+--R                             (- 2a b c   - 8a b c   - 12a b c  - 8a b c  - 2a )
+--R                          *
+--R                             %%BC0
+--R                         + 
+--R                                3 11      2 2 7     3   3
+--R                           (8a b c   + 16a b c  + 8a b c )d
+--R                      *
+--R                         %%BC1
+--R                     + 
+--R                                4 16      2 3 12      3 2 8      4   4     5
+--R                         (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )
+--R                      *
+--R                              2
+--R                         %%BC0
+--R                     + 
+--R                            3 11      2 2 7     3   3
+--R                       (8a b c   + 16a b c  + 8a b c )d %%BC0
+--R                     + 
+--R                            3 10       2 6     2   2  2
+--R                       (- 5b c   + 6a b c  - 5a b c )d
+--R                  /
+--R                        4 16     2 3 12     3 2 8     4   4    5
+--R                     a b c   + 4a b c   + 6a b c  + 4a b c  + a
+--R            + 
+--R                       3 3 12       4 2 8       5   4      6
+--R                  (160a b c   + 352a b c  + 224a b c  + 32a )%%BC0
+--R                + 
+--R                        2 3 11      3 2 7      4   3
+--R                  (- 16a b c   - 32a b c  - 16a b c )d
+--R             *
+--R                     2
+--R                %%BC1
+--R            + 
+--R                       3 3 12       4 2 8       5   4      6      2
+--R                  (160a b c   + 352a b c  + 224a b c  + 32a )%%BC0
+--R                + 
+--R                         3 2 7       4   3
+--R                  (- 640a b c  - 128a b c )d %%BC0
+--R                + 
+--R                         3 10      2 2 6     3   2  2
+--R                  (- 2a b c   + 60a b c  - 2a b c )d
+--R             *
+--R                %%BC1
+--R            + 
+--R                    2 3 11      3 2 7      4   3        2
+--R              (- 16a b c   - 32a b c  - 16a b c )d %%BC0
+--R            + 
+--R                     3 10      2 2 6     3   2  2          3 8    2   4
+--R              (- 2a b c   + 60a b c  - 2a b c )d %%BC0 + (b c  - a b)d x
+--R            + 
+--R                3 9       2 5    2     3
+--R              (b c  - 6a b c  + a b c)d
+--R     + 
+--R                 2 8         4    2
+--R             (- b c  - 2a b c  - a )x
+--R          *
+--R             ROOT
+--R                           4 16      2 3 12      3 2 8      4   4     5      2
+--R                    (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )%%BC1
+--R                  + 
+--R                               4 16     2 3 12      3 2 8     4   4     5
+--R                        (- 2a b c   - 8a b c   - 12a b c  - 8a b c  - 2a )%%BC0
+--R                      + 
+--R                             3 11      2 2 7     3   3
+--R                        (8a b c   + 16a b c  + 8a b c )d
+--R                   *
+--R                      %%BC1
+--R                  + 
+--R                           4 16      2 3 12      3 2 8      4   4     5      2
+--R                    (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )%%BC0
+--R                  + 
+--R                         3 11      2 2 7     3   3
+--R                    (8a b c   + 16a b c  + 8a b c )d %%BC0
+--R                  + 
+--R                         3 10       2 6     2   2  2
+--R                    (- 5b c   + 6a b c  - 5a b c )d
+--R               /
+--R                     4 16     2 3 12     3 2 8     4   4    5
+--R                  a b c   + 4a b c   + 6a b c  + 4a b c  + a
+--R         + 
+--R               2 8         4    2               2 8         4    2
+--R           (- b c  - 2a b c  - a )x %%BC1 + (- b c  - 2a b c  - a )x %%BC0
+--R         + 
+--R               3
+--R           4b c d x
+--R      *
+--R         log
+--R                             3 3 12       4 2 8       5   4      6
+--R                      (- 160a b c   - 352a b c  - 224a b c  - 32a )%%BC0
+--R                    + 
+--R                          2 3 11      3 2 7      4   3
+--R                      (16a b c   + 32a b c  + 16a b c )d
+--R                 *
+--R                    %%BC1
+--R                + 
+--R                      2 3 11      3 2 7      4   3
+--R                  (16a b c   + 32a b c  + 16a b c )d %%BC0
+--R                + 
+--R                         3 10     2 2 6     3   2  2
+--R                  (- 2a b c   - 4a b c  - 2a b c )d
+--R             *
+--R                ROOT
+--R                                4 16      2 3 12      3 2 8      4   4     5
+--R                         (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )
+--R                      *
+--R                              2
+--R                         %%BC1
+--R                     + 
+--R                                    4 16     2 3 12      3 2 8     4   4     5
+--R                             (- 2a b c   - 8a b c   - 12a b c  - 8a b c  - 2a )
+--R                          *
+--R                             %%BC0
+--R                         + 
+--R                                3 11      2 2 7     3   3
+--R                           (8a b c   + 16a b c  + 8a b c )d
+--R                      *
+--R                         %%BC1
+--R                     + 
+--R                                4 16      2 3 12      3 2 8      4   4     5
+--R                         (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )
+--R                      *
+--R                              2
+--R                         %%BC0
+--R                     + 
+--R                            3 11      2 2 7     3   3
+--R                       (8a b c   + 16a b c  + 8a b c )d %%BC0
+--R                     + 
+--R                            3 10       2 6     2   2  2
+--R                       (- 5b c   + 6a b c  - 5a b c )d
+--R                  /
+--R                        4 16     2 3 12     3 2 8     4   4    5
+--R                     a b c   + 4a b c   + 6a b c  + 4a b c  + a
+--R            + 
+--R                       3 3 12       4 2 8       5   4      6
+--R                  (160a b c   + 352a b c  + 224a b c  + 32a )%%BC0
+--R                + 
+--R                        2 3 11      3 2 7      4   3
+--R                  (- 16a b c   - 32a b c  - 16a b c )d
+--R             *
+--R                     2
+--R                %%BC1
+--R            + 
+--R                       3 3 12       4 2 8       5   4      6      2
+--R                  (160a b c   + 352a b c  + 224a b c  + 32a )%%BC0
+--R                + 
+--R                         3 2 7       4   3
+--R                  (- 640a b c  - 128a b c )d %%BC0
+--R                + 
+--R                         3 10      2 2 6     3   2  2
+--R                  (- 2a b c   + 60a b c  - 2a b c )d
+--R             *
+--R                %%BC1
+--R            + 
+--R                    2 3 11      3 2 7      4   3        2
+--R              (- 16a b c   - 32a b c  - 16a b c )d %%BC0
+--R            + 
+--R                     3 10      2 2 6     3   2  2          3 8    2   4
+--R              (- 2a b c   + 60a b c  - 2a b c )d %%BC0 + (b c  - a b)d x
+--R            + 
+--R                3 9       2 5    2     3
+--R              (b c  - 6a b c  + a b c)d
+--R     + 
+--R            2 8         4     2
+--R         (2b c  + 4a b c  + 2a )x %%BC1
+--R      *
+--R         log
+--R                         3 3 12       4 2 8       5   4      6
+--R                  (- 320a b c   - 704a b c  - 448a b c  - 64a )%%BC0
+--R                + 
+--R                      2 3 11      3 2 7      4   3
+--R                  (32a b c   + 64a b c  + 32a b c )d
+--R             *
+--R                     2
+--R                %%BC1
+--R            + 
+--R                         3 3 12       4 2 8       5   4      6      2
+--R                  (- 320a b c   - 704a b c  - 448a b c  - 64a )%%BC0
+--R                + 
+--R                        3 2 7       4   3
+--R                  (1280a b c  + 256a b c )d %%BC0
+--R                + 
+--R                       3 10       2 2 6     3   2  2
+--R                  (4a b c   - 120a b c  + 4a b c )d
+--R             *
+--R                %%BC1
+--R            + 
+--R                     3 3 12       4 2 8       5   4      6      3
+--R              (- 320a b c   - 704a b c  - 448a b c  - 64a )%%BC0
+--R            + 
+--R                    3 2 7       4   3        2          2 2 6      3   2  2
+--R              (1280a b c  + 256a b c )d %%BC0  + (- 400a b c  - 80a b c )d %%BC0
+--R            + 
+--R                3 8    2   4      3 9        2 5    2     3
+--R              (b c  - a b)d x + (b c  + 26a b c  + a b c)d
+--R     + 
+--R            2 8         4     2
+--R         (2b c  + 4a b c  + 2a )x %%BC0
+--R      *
+--R         log
+--R                   3 3 12       4 2 8       5   4      6      3
+--R              (320a b c   + 704a b c  + 448a b c  + 64a )%%BC0
+--R            + 
+--R                  2 3 11        3 2 7       4   3        2
+--R              (32a b c   - 1216a b c  - 224a b c )d %%BC0
+--R            + 
+--R                   3 10       2 2 6      3   2  2          3 8    2   4
+--R              (4a b c   + 280a b c  + 84a b c )d %%BC0 + (b c  - a b)d x
+--R            + 
+--R                3 9        2 5     2     3
+--R              (b c  - 14a b c  - 7a b c)d
+--R     + 
+--R             3                 4
+--R       - 8b c d x log(x) - 2b c  - 2a
+--R  /
+--R        2 8         4     2
+--R     (2b c  + 4a b c  + 2a )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 459
+
+--S 460 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2 8         4     2  +-+ +-+4+-+3
+--R             (2b c  + 4a b c  + 2a )\|2 \|a \|a
+--R          *
+--R             ROOT
+--R                           4 16      2 3 12      3 2 8      4   4     5      2
+--R                    (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )%%BC1
+--R                  + 
+--R                               4 16     2 3 12      3 2 8     4   4     5
+--R                        (- 2a b c   - 8a b c   - 12a b c  - 8a b c  - 2a )%%BC0
+--R                      + 
+--R                             3 11      2 2 7     3   3
+--R                        (8a b c   + 16a b c  + 8a b c )d
+--R                   *
+--R                      %%BC1
+--R                  + 
+--R                           4 16      2 3 12      3 2 8      4   4     5      2
+--R                    (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )%%BC0
+--R                  + 
+--R                         3 11      2 2 7     3   3
+--R                    (8a b c   + 16a b c  + 8a b c )d %%BC0
+--R                  + 
+--R                         3 10       2 6     2   2  2
+--R                    (- 5b c   + 6a b c  - 5a b c )d
+--R               /
+--R                     4 16     2 3 12     3 2 8     4   4    5
+--R                  a b c   + 4a b c   + 6a b c  + 4a b c  + a
+--R         + 
+--R                2 8         4     2  +-+ +-+4+-+3
+--R           (- 2b c  - 4a b c  - 2a )\|2 \|a \|a  %%BC1
+--R         + 
+--R                2 8         4     2  +-+ +-+4+-+3            3  +-+ +-+4+-+3
+--R           (- 2b c  - 4a b c  - 2a )\|2 \|a \|a  %%BC0 + 8b c d\|2 \|a \|a
+--R      *
+--R         log
+--R                           3 3 12       4 2 8       5   4      6
+--R                      (160a b c   + 352a b c  + 224a b c  + 32a )%%BC0
+--R                    + 
+--R                            2 3 11      3 2 7      4   3
+--R                      (- 16a b c   - 32a b c  - 16a b c )d
+--R                 *
+--R                    %%BC1
+--R                + 
+--R                        2 3 11      3 2 7      4   3
+--R                  (- 16a b c   - 32a b c  - 16a b c )d %%BC0
+--R                + 
+--R                       3 10     2 2 6     3   2  2
+--R                  (2a b c   + 4a b c  + 2a b c )d
+--R             *
+--R                ROOT
+--R                                4 16      2 3 12      3 2 8      4   4     5
+--R                         (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )
+--R                      *
+--R                              2
+--R                         %%BC1
+--R                     + 
+--R                                    4 16     2 3 12      3 2 8     4   4     5
+--R                             (- 2a b c   - 8a b c   - 12a b c  - 8a b c  - 2a )
+--R                          *
+--R                             %%BC0
+--R                         + 
+--R                                3 11      2 2 7     3   3
+--R                           (8a b c   + 16a b c  + 8a b c )d
+--R                      *
+--R                         %%BC1
+--R                     + 
+--R                                4 16      2 3 12      3 2 8      4   4     5
+--R                         (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )
+--R                      *
+--R                              2
+--R                         %%BC0
+--R                     + 
+--R                            3 11      2 2 7     3   3
+--R                       (8a b c   + 16a b c  + 8a b c )d %%BC0
+--R                     + 
+--R                            3 10       2 6     2   2  2
+--R                       (- 5b c   + 6a b c  - 5a b c )d
+--R                  /
+--R                        4 16     2 3 12     3 2 8     4   4    5
+--R                     a b c   + 4a b c   + 6a b c  + 4a b c  + a
+--R            + 
+--R                       3 3 12       4 2 8       5   4      6
+--R                  (160a b c   + 352a b c  + 224a b c  + 32a )%%BC0
+--R                + 
+--R                        2 3 11      3 2 7      4   3
+--R                  (- 16a b c   - 32a b c  - 16a b c )d
+--R             *
+--R                     2
+--R                %%BC1
+--R            + 
+--R                       3 3 12       4 2 8       5   4      6      2
+--R                  (160a b c   + 352a b c  + 224a b c  + 32a )%%BC0
+--R                + 
+--R                         3 2 7       4   3
+--R                  (- 640a b c  - 128a b c )d %%BC0
+--R                + 
+--R                         3 10      2 2 6     3   2  2
+--R                  (- 2a b c   + 60a b c  - 2a b c )d
+--R             *
+--R                %%BC1
+--R            + 
+--R                    2 3 11      3 2 7      4   3        2
+--R              (- 16a b c   - 32a b c  - 16a b c )d %%BC0
+--R            + 
+--R                     3 10      2 2 6     3   2  2          3 8    2   4
+--R              (- 2a b c   + 60a b c  - 2a b c )d %%BC0 + (b c  - a b)d x
+--R            + 
+--R                3 9       2 5    2     3
+--R              (b c  - 6a b c  + a b c)d
+--R     + 
+--R                  2 8         4     2  +-+ +-+4+-+3
+--R             (- 2b c  - 4a b c  - 2a )\|2 \|a \|a
+--R          *
+--R             ROOT
+--R                           4 16      2 3 12      3 2 8      4   4     5      2
+--R                    (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )%%BC1
+--R                  + 
+--R                               4 16     2 3 12      3 2 8     4   4     5
+--R                        (- 2a b c   - 8a b c   - 12a b c  - 8a b c  - 2a )%%BC0
+--R                      + 
+--R                             3 11      2 2 7     3   3
+--R                        (8a b c   + 16a b c  + 8a b c )d
+--R                   *
+--R                      %%BC1
+--R                  + 
+--R                           4 16      2 3 12      3 2 8      4   4     5      2
+--R                    (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )%%BC0
+--R                  + 
+--R                         3 11      2 2 7     3   3
+--R                    (8a b c   + 16a b c  + 8a b c )d %%BC0
+--R                  + 
+--R                         3 10       2 6     2   2  2
+--R                    (- 5b c   + 6a b c  - 5a b c )d
+--R               /
+--R                     4 16     2 3 12     3 2 8     4   4    5
+--R                  a b c   + 4a b c   + 6a b c  + 4a b c  + a
+--R         + 
+--R                2 8         4     2  +-+ +-+4+-+3
+--R           (- 2b c  - 4a b c  - 2a )\|2 \|a \|a  %%BC1
+--R         + 
+--R                2 8         4     2  +-+ +-+4+-+3            3  +-+ +-+4+-+3
+--R           (- 2b c  - 4a b c  - 2a )\|2 \|a \|a  %%BC0 + 8b c d\|2 \|a \|a
+--R      *
+--R         log
+--R                             3 3 12       4 2 8       5   4      6
+--R                      (- 160a b c   - 352a b c  - 224a b c  - 32a )%%BC0
+--R                    + 
+--R                          2 3 11      3 2 7      4   3
+--R                      (16a b c   + 32a b c  + 16a b c )d
+--R                 *
+--R                    %%BC1
+--R                + 
+--R                      2 3 11      3 2 7      4   3
+--R                  (16a b c   + 32a b c  + 16a b c )d %%BC0
+--R                + 
+--R                         3 10     2 2 6     3   2  2
+--R                  (- 2a b c   - 4a b c  - 2a b c )d
+--R             *
+--R                ROOT
+--R                                4 16      2 3 12      3 2 8      4   4     5
+--R                         (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )
+--R                      *
+--R                              2
+--R                         %%BC1
+--R                     + 
+--R                                    4 16     2 3 12      3 2 8     4   4     5
+--R                             (- 2a b c   - 8a b c   - 12a b c  - 8a b c  - 2a )
+--R                          *
+--R                             %%BC0
+--R                         + 
+--R                                3 11      2 2 7     3   3
+--R                           (8a b c   + 16a b c  + 8a b c )d
+--R                      *
+--R                         %%BC1
+--R                     + 
+--R                                4 16      2 3 12      3 2 8      4   4     5
+--R                         (- 3a b c   - 12a b c   - 18a b c  - 12a b c  - 3a )
+--R                      *
+--R                              2
+--R                         %%BC0
+--R                     + 
+--R                            3 11      2 2 7     3   3
+--R                       (8a b c   + 16a b c  + 8a b c )d %%BC0
+--R                     + 
+--R                            3 10       2 6     2   2  2
+--R                       (- 5b c   + 6a b c  - 5a b c )d
+--R                  /
+--R                        4 16     2 3 12     3 2 8     4   4    5
+--R                     a b c   + 4a b c   + 6a b c  + 4a b c  + a
+--R            + 
+--R                       3 3 12       4 2 8       5   4      6
+--R                  (160a b c   + 352a b c  + 224a b c  + 32a )%%BC0
+--R                + 
+--R                        2 3 11      3 2 7      4   3
+--R                  (- 16a b c   - 32a b c  - 16a b c )d
+--R             *
+--R                     2
+--R                %%BC1
+--R            + 
+--R                       3 3 12       4 2 8       5   4      6      2
+--R                  (160a b c   + 352a b c  + 224a b c  + 32a )%%BC0
+--R                + 
+--R                         3 2 7       4   3
+--R                  (- 640a b c  - 128a b c )d %%BC0
+--R                + 
+--R                         3 10      2 2 6     3   2  2
+--R                  (- 2a b c   + 60a b c  - 2a b c )d
+--R             *
+--R                %%BC1
+--R            + 
+--R                    2 3 11      3 2 7      4   3        2
+--R              (- 16a b c   - 32a b c  - 16a b c )d %%BC0
+--R            + 
+--R                     3 10      2 2 6     3   2  2          3 8    2   4
+--R              (- 2a b c   + 60a b c  - 2a b c )d %%BC0 + (b c  - a b)d x
+--R            + 
+--R                3 9       2 5    2     3
+--R              (b c  - 6a b c  + a b c)d
+--R     + 
+--R            2 8         4     2  +-+ +-+4+-+3
+--R         (4b c  + 8a b c  + 4a )\|2 \|a \|a  %%BC1
+--R      *
+--R         log
+--R                         3 3 12       4 2 8       5   4      6
+--R                  (- 320a b c   - 704a b c  - 448a b c  - 64a )%%BC0
+--R                + 
+--R                      2 3 11      3 2 7      4   3
+--R                  (32a b c   + 64a b c  + 32a b c )d
+--R             *
+--R                     2
+--R                %%BC1
+--R            + 
+--R                         3 3 12       4 2 8       5   4      6      2
+--R                  (- 320a b c   - 704a b c  - 448a b c  - 64a )%%BC0
+--R                + 
+--R                        3 2 7       4   3
+--R                  (1280a b c  + 256a b c )d %%BC0
+--R                + 
+--R                       3 10       2 2 6     3   2  2
+--R                  (4a b c   - 120a b c  + 4a b c )d
+--R             *
+--R                %%BC1
+--R            + 
+--R                     3 3 12       4 2 8       5   4      6      3
+--R              (- 320a b c   - 704a b c  - 448a b c  - 64a )%%BC0
+--R            + 
+--R                    3 2 7       4   3        2          2 2 6      3   2  2
+--R              (1280a b c  + 256a b c )d %%BC0  + (- 400a b c  - 80a b c )d %%BC0
+--R            + 
+--R                3 8    2   4      3 9        2 5    2     3
+--R              (b c  - a b)d x + (b c  + 26a b c  + a b c)d
+--R     + 
+--R            2 8         4     2  +-+ +-+4+-+3
+--R         (4b c  + 8a b c  + 4a )\|2 \|a \|a  %%BC0
+--R      *
+--R         log
+--R                   3 3 12       4 2 8       5   4      6      3
+--R              (320a b c   + 704a b c  + 448a b c  + 64a )%%BC0
+--R            + 
+--R                  2 3 11        3 2 7       4   3        2
+--R              (32a b c   - 1216a b c  - 224a b c )d %%BC0
+--R            + 
+--R                   3 10       2 2 6      3   2  2          3 8    2   4
+--R              (4a b c   + 280a b c  + 84a b c )d %%BC0 + (b c  - a b)d x
+--R            + 
+--R                3 9        2 5     2     3
+--R              (b c  - 14a b c  - 7a b c)d
+--R     + 
+--R                6       2   +-+ +-+          4    2   4+-+
+--R         ((- b c  + 3a c )d\|a \|b  + (3a b c  - a )d)\|b
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R              6       2   +-+ +-+            4    2   4+-+
+--R         ((b c  - 3a c )d\|a \|b  + (- 3a b c  + a )d)\|b
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                 6       2   +-+ +-+            4     2   4+-+
+--R         ((- 2b c  + 6a c )d\|a \|b  + (- 6a b c  + 2a )d)\|b
+--R      *
+--R                        +-+4+-+   4+-+
+--R              (d x + c)\|2 \|b  + \|a
+--R         atan(------------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R                 6       2   +-+ +-+            4     2   4+-+
+--R         ((- 2b c  + 6a c )d\|a \|b  + (- 6a b c  + 2a )d)\|b
+--R      *
+--R                        +-+4+-+   4+-+
+--R              (d x + c)\|2 \|b  - \|a
+--R         atan(------------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R                                            2 2             2  +-+
+--R              5          +-+4+-+3 +-+     (d x  + 2c d x + c )\|b
+--R       (- 4b c  + 4a c)d\|2 \|a  \|b atan(------------------------)
+--R                                                     +-+
+--R                                                    \|a
+--R     + 
+--R       -
+--R                3  +-+       4 4         3 3       2 2 2       3         4
+--R            4b c d\|2 log(b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a)
+--R         *
+--R             +-+4+-+3
+--R            \|a \|a
+--R  /
+--R        2 8         4     2  +-+ +-+4+-+3
+--R     (4b c  + 8a b c  + 4a )\|2 \|a \|a
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                       2 6         2  6 4        2 7          3  5 3
+--R                   (- b c  + 3a b c )d x  + (- 4b c  + 12a b c )d x
+--R                 + 
+--R                        2 8          4     2  4 2
+--R                   (- 6b c  + 24a b c  - 2a )d x
+--R                 + 
+--R                      2 9          5     2   3        2 10          6     2 2  2
+--R                 (- 4b c  + 24a b c  - 4a c)d x + (- b c   + 10a b c  - 5a c )d
+--R              *
+--R                 4+-+2
+--R                 \|a
+--R             + 
+--R                      2 4        8 6       2 5           7 5
+--R                   (3b c  - a b)d x  + (18b c  - 6a b c)d x
+--R                 + 
+--R                       2 6          2  6 4       2 7          3  5 3
+--R                   (46b c  - 18a b c )d x  + (64b c  - 32a b c )d x
+--R                 + 
+--R                       2 8          4    2  4 2       2 9          5     2   3
+--R                   (51b c  - 30a b c  - a )d x  + (22b c  - 12a b c  - 2a c)d x
+--R                 + 
+--R                      2 10     2 2  2
+--R                   (4b c   - 4a c )d
+--R              *
+--R                  +-+
+--R                 \|a
+--R          *
+--R              +-+
+--R             \|b
+--R         + 
+--R                    2 4        6 4         2 5           5 3      2 6 4 2
+--R               (- 3b c  + a b)d x  + (- 12b c  + 4a b c)d x  - 16b c d x
+--R             + 
+--R                    2 7         3  3        2 8         4    2  2
+--R               (- 8b c  - 8a b c )d x + (- b c  - 2a b c  - a )d
+--R          *
+--R              +-+4+-+2
+--R             \|a \|a
+--R         + 
+--R               3 6       2 2  8 6        3 7        2 3  7 5
+--R           (- b c  + 3a b c )d x  + (- 6b c  + 18a b c )d x
+--R         + 
+--R                 3 8        2 4     2   6 4
+--R           (- 15b c  + 54a b c  - 3a b)d x
+--R         + 
+--R                 3 9        2 5      2     5 3
+--R           (- 20b c  + 96a b c  - 12a b c)d x
+--R         + 
+--R                 3 10         2 6      2   2  4 2
+--R           (- 15b c   + 102a b c  - 27a b c )d x
+--R         + 
+--R                3 11        2 7      2   3  3
+--R           (- 6b c   + 60a b c  - 30a b c )d x
+--R         + 
+--R               3 12        2 8      2   4    3  2
+--R           (- b c   + 15a b c  - 15a b c  + a )d
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                     2 4         6 4         2 5            5 3
+--R               (- 12b c  + 4a b)d x  + (- 48b c  + 16a b c)d x
+--R             + 
+--R                     2 6          2  4 2         2 7          3  3
+--R               (- 76b c  + 36a b c )d x  + (- 56b c  + 40a b c )d x
+--R             + 
+--R                     2 8          4  2
+--R               (- 16b c  + 16a b c )d
+--R          *
+--R              +-+4+-+2
+--R             \|a \|a
+--R         + 
+--R             3 6       2 2  8 6      3 7        2 3  7 5
+--R           (b c  - 3a b c )d x  + (6b c  - 18a b c )d x
+--R         + 
+--R               3 8        2 4     2   6 4       3 9        2 5     2     5 3
+--R           (15b c  - 39a b c  - 2a b)d x  + (20b c  - 36a b c  - 8a b c)d x
+--R         + 
+--R               3 10        2 6     2   2  4 2      3 11       2 7     2   3  3
+--R           (15b c   - 10a b c  - 9a b c )d x  + (6b c   + 4a b c  - 2a b c )d x
+--R         + 
+--R             3 12       2 8    2   4  2
+--R           (b c   + 2a b c  + a b c )d
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R                3 4       2  8 6         3 5        2   7 5
+--R           (- 6b c  + 2a b )d x  + (- 36b c  + 12a b c)d x
+--R         + 
+--R                 3 6        2 2  6 4          3 7        2 3  5 3
+--R           (- 92b c  + 36a b c )d x  + (- 128b c  + 64a b c )d x
+--R         + 
+--R                  3 8        2 4     2   4 2         3 9        2 5     2     3
+--R           (- 102b c  + 60a b c  + 2a b)d x  + (- 44b c  + 24a b c  + 4a b c)d x
+--R         + 
+--R                3 10     2   2  2
+--R           (- 8b c   + 8a b c )d
+--R      *
+--R         4+-+2
+--R         \|a
+--R     + 
+--R              3 4      2  8 6       3 5       2   7 5       3 6        2 2  6 4
+--R           (3b c  - a b )d x  + (18b c  - 6a b c)d x  + (47b c  - 21a b c )d x
+--R         + 
+--R               3 7        2 3  5 3       3 8        2 4    2   4 2
+--R           (68b c  - 44a b c )d x  + (57b c  - 54a b c  + a b)d x
+--R         + 
+--R               3 9        2 5     2     3       3 10        2 6    2   2  2
+--R           (26b c  - 36a b c  + 2a b c)d x + (5b c   - 10a b c  + a b c )d
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                3 8     2 2 4     3   6 6         3 9      2 2 5      3     5 5
+--R           (4a b c  + 8a b c  + 4a b)d x  + (24a b c  + 48a b c  + 24a b c)d x
+--R         + 
+--R                 3 10       2 2 6      3   2  4 4
+--R           (60a b c   + 120a b c  + 60a b c )d x
+--R         + 
+--R                 3 11       2 2 7      3   3  3 3
+--R           (80a b c   + 160a b c  + 80a b c )d x
+--R         + 
+--R                 3 12       2 2 8      3   4     4  2 2
+--R           (60a b c   + 124a b c  + 68a b c  + 4a )d x
+--R         + 
+--R                 3 13      2 2 9      3   5     4            3 14      2 2 10
+--R           (24a b c   + 56a b c  + 40a b c  + 8a c)d x + 4a b c   + 12a b c
+--R         + 
+--R              3   6     4 2
+--R           12a b c  + 4a c
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                3 8       2 4     2   6 6         3 9        2 5      2     5 5
+--R           (- 4b c  - 8a b c  - 4a b)d x  + (- 24b c  - 48a b c  - 24a b c)d x
+--R         + 
+--R                 3 10         2 6      2   2  4 4
+--R           (- 60b c   - 120a b c  - 60a b c )d x
+--R         + 
+--R                 3 11         2 7      2   3  3 3
+--R           (- 80b c   - 160a b c  - 80a b c )d x
+--R         + 
+--R                 3 12         2 8      2   4     3  2 2
+--R           (- 60b c   - 124a b c  - 68a b c  - 4a )d x
+--R         + 
+--R                 3 13        2 9      2   5     3          3 14        2 10
+--R           (- 24b c   - 56a b c  - 40a b c  - 8a c)d x - 4b c   - 12a b c
+--R         + 
+--R                2   6     3 2
+--R           - 12a b c  - 4a c
+--R      *
+--R          +-+4+-+2 +-+
+--R         \|a \|a  \|b
+--R     + 
+--R                4 8       3 4     2 2  8 8         4 9        3 5      2 2   7 7
+--R           (- 2b c  - 4a b c  - 2a b )d x  + (- 16b c  - 32a b c  - 16a b c)d x
+--R         + 
+--R                 4 10         3 6      2 2 2  6 6
+--R           (- 56b c   - 112a b c  - 56a b c )d x
+--R         + 
+--R                  4 11         3 7       2 2 3  5 5
+--R           (- 112b c   - 224a b c  - 112a b c )d x
+--R         + 
+--R                  4 12         3 8       2 2 4     3   4 4
+--R           (- 140b c   - 284a b c  - 148a b c  - 4a b)d x
+--R         + 
+--R                  4 13         3 9       2 2 5      3     3 3
+--R           (- 112b c   - 240a b c  - 144a b c  - 16a b c)d x
+--R         + 
+--R                 4 14         3 10       2 2 6      3   2  2 2
+--R           (- 56b c   - 136a b c   - 104a b c  - 24a b c )d x
+--R         + 
+--R                 4 15        3 11      2 2 7      3   3         4 16       3 12
+--R           (- 16b c   - 48a b c   - 48a b c  - 16a b c )d x - 2b c   - 8a b c
+--R         + 
+--R                2 2 8     3   4     4
+--R           - 12a b c  - 8a b c  - 2a
+--R      *
+--R         4+-+2
+--R         \|a
+--R                                                    Type: Expression(Integer)
+--E 461
+
+)clear all
+
+--S 462 of 619
+t0:=x^3*(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R              3 +-------+    2   4     2     2  3
+--R   (1)  2a b x \|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 619
+r0:=-a^2*c^3*x/d^3-4/3*a*b*c^3*(c+d*x)^(3/2)/d^4+1/2*c^2*(3*a^2-b^2*c)*_
+   (c+d*x)^2/d^4+12/5*a*b*c^2*(c+d*x)^(5/2)/d^4-c*(a^2-b^2*c)*(c+d*x)^3/d^4-_
+   12/7*a*b*c*(c+d*x)^(7/2)/d^4+1/4*(a^2-3*b^2*c)*(c+d*x)^4/d^4+_
+   4/9*a*b*(c+d*x)^(9/2)/d^4+1/5*b^2*(c+d*x)^5/d^4
+--R 
+--R
+--R   (2)
+--R                  4 4            3 3          2 2 2           3              4
+--R         (560a b d x  + 80a b c d x  - 96a b c d x  + 128a b c d x - 256a b c )
+--R      *
+--R          +-------+
+--R         \|d x + c
+--R     + 
+--R           2 5 5        2        2  4 4      2 5       2 4
+--R       252b d x  + (315b c + 315a )d x  - 63b c  + 945a c
+--R  /
+--R          4
+--R     1260d
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  4 4            3 3          2 2 2           3              4
+--R         (560a b d x  + 80a b c d x  - 96a b c d x  + 128a b c d x - 256a b c )
+--R      *
+--R          +-------+
+--R         \|d x + c
+--R     + 
+--R           2 5 5        2        2  4 4
+--R       252b d x  + (315b c + 315a )d x
+--R  /
+--R          4
+--R     1260d
+--R                                         Type: Union(Expression(Integer),...)
+--E 464
+
+--S 465 of 619
+m0:=a0-r0
+--R 
+--R
+--R         2 5      2 4
+--R        b c  - 15a c
+--R   (4)  -------------
+--R                4
+--R             20d
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 466
+
+)clear all
+
+--S 467 of 619
+t0:=x^2*(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R              2 +-------+    2   3     2     2  2
+--R   (1)  2a b x \|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 619
+r0:=a^2*c^2*x/d^2+4/3*a*b*c^2*(c+d*x)^(3/2)/d^3-1/2*c*(2*a^2-b^2*c)*_
+   (c+d*x)^2/d^3-8/5*a*b*c*(c+d*x)^(5/2)/d^3+1/3*(a^2-2*b^2*c)*_
+   (c+d*x)^3/d^3+4/7*a*b*(c+d*x)^(7/2)/d^3+1/4*b^2*(c+d*x)^4/d^3
+--R 
+--R
+--R   (2)
+--R                3 3            2 2          2              3  +-------+
+--R       (240a b d x  + 48a b c d x  - 64a b c d x + 128a b c )\|d x + c
+--R     + 
+--R           2 4 4        2        2  3 3      2 4       2 3
+--R       105b d x  + (140b c + 140a )d x  + 35b c  - 280a c
+--R  /
+--R         3
+--R     420d
+--R                                                    Type: Expression(Integer)
+--E 468
+
+--S 469 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                3 3            2 2          2              3  +-------+
+--R       (240a b d x  + 48a b c d x  - 64a b c d x + 128a b c )\|d x + c
+--R     + 
+--R           2 4 4        2        2  3 3
+--R       105b d x  + (140b c + 140a )d x
+--R  /
+--R         3
+--R     420d
+--R                                         Type: Union(Expression(Integer),...)
+--E 469
+
+--S 470 of 619
+m0:=a0-r0
+--R 
+--R
+--R           2 4     2 3
+--R        - b c  + 8a c
+--R   (4)  --------------
+--R                3
+--R             12d
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 619
+t0:=x*(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R               +-------+    2   2     2     2
+--R   (1)  2a b x\|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 619
+r0:=-a^2*c*x/d-4/3*a*b*c*(c+d*x)^(3/2)/d^2+1/2*(a^2-b^2*c)*(c+d*x)^2/d^2+_
+   4/5*a*b*(c+d*x)^(5/2)/d^2+1/3*b^2*(c+d*x)^3/d^2
+--R 
+--R
+--R   (2)
+--R               2 2                       2  +-------+      2 3 3
+--R       (24a b d x  + 8a b c d x - 16a b c )\|d x + c  + 10b d x
+--R     + 
+--R           2       2  2 2     2 3      2 2
+--R       (15b c + 15a )d x  - 5b c  + 15a c
+--R  /
+--R        2
+--R     30d
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2 2                       2  +-------+      2 3 3
+--R       (24a b d x  + 8a b c d x - 16a b c )\|d x + c  + 10b d x
+--R     + 
+--R           2       2  2 2
+--R       (15b c + 15a )d x
+--R  /
+--R        2
+--R     30d
+--R                                         Type: Union(Expression(Integer),...)
+--E 474
+
+--S 475 of 619
+m0:=a0-r0
+--R 
+--R
+--R         2 3     2 2
+--R        b c  - 3a c
+--R   (4)  ------------
+--R               2
+--R             6d
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 476
+
+)clear all
+
+--S 477 of 619
+t0:=(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R             +-------+    2       2     2
+--R   (1)  2a b\|d x + c  + b d x + b c + a
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 619
+r0:=a^2*x+4/3*a*b*(c+d*x)^(3/2)/d+1/2*b^2*(c+d*x)^2/d
+--R 
+--R
+--R                            +-------+     2 2 2      2      2         2 2
+--R        (8a b d x + 8a b c)\|d x + c  + 3b d x  + (6b c + 6a )d x + 3b c
+--R   (2)  -----------------------------------------------------------------
+--R                                        6d
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            +-------+     2 2 2      2      2
+--R        (8a b d x + 8a b c)\|d x + c  + 3b d x  + (6b c + 6a )d x
+--R   (3)  ---------------------------------------------------------
+--R                                    6d
+--R                                         Type: Union(Expression(Integer),...)
+--E 479
+
+--S 480 of 619
+m0:=a0-r0
+--R 
+--R
+--R           2 2
+--R          b c
+--R   (4)  - ----
+--R           2d
+--R                                                    Type: Expression(Integer)
+--E 480
+
+--S 481 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 481
+
+)clear all
+
+--S 482 of 619
+t0:=(a+b*sqrt(c+d*x))^2/x
+--R 
+--R
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R   (1)  ---------------------------------
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 619
+r0:=b^2*d*x+(a^2+b^2*c)*log(x)-4*a*b*atanh(sqrt(c+d*x)/sqrt(c))*sqrt(c)+_
+   4*a*b*sqrt(c+d*x)
+--R 
+--R
+--R   (2)
+--R                    +-------+
+--R          +-+      \|d x + c          +-------+     2     2           2
+--R   - 4a b\|c atanh(----------) + 4a b\|d x + c  + (b c + a )log(x) + b d x
+--R                       +-+
+--R                      \|c
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       +-+ +-------+
+--R            +-+    - 2\|c \|d x + c  + d x + 2c         +-------+
+--R       2a b\|c log(----------------------------) + 4a b\|d x + c
+--R                                 x
+--R     + 
+--R         2     2           2
+--R       (b c + a )log(x) + b d x
+--R     ,
+--R                      +-------+
+--R           +---+     \|d x + c          +-------+     2     2           2
+--R    - 4a b\|- c atan(----------) + 4a b\|d x + c  + (b c + a )log(x) + b d x]
+--R                        +---+
+--R                       \|- c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 484
+
+--S 485 of 619
+m0a:=a0.1-r0
+--R 
+--R
+--R                        +-+ +-------+                              +-------+
+--R             +-+    - 2\|c \|d x + c  + d x + 2c         +-+      \|d x + c
+--R   (4)  2a b\|c log(----------------------------) + 4a b\|c atanh(----------)
+--R                                  x                                   +-+
+--R                                                                     \|c
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 619
+m0b:=a0.2-r0
+--R 
+--R
+--R                       +-------+                    +-------+
+--R             +-+      \|d x + c          +---+     \|d x + c
+--R   (6)  4a b\|c atanh(----------) - 4a b\|- c atan(----------)
+--R                          +-+                         +---+
+--R                         \|c                         \|- c
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 619
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 488
+
+)clear all
+
+--S 489 of 619
+t0:=(a+b*sqrt(c+d*x))^2/x^2
+--R 
+--R
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R   (1)  ---------------------------------
+--R                         2
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 619
+r0:=b^2*d*log(x)-2*a*b*d*atanh(sqrt(c+d*x)/sqrt(c))/sqrt(c)-_
+   (a+b*sqrt(c+d*x))^2/x
+--R 
+--R
+--R   (2)
+--R                         +-------+
+--R                        \|d x + c          +-+ +-------+
+--R       - 2a b d x atanh(----------) - 2a b\|c \|d x + c
+--R                            +-+
+--R                           \|c
+--R     + 
+--R         2              2       2     2  +-+
+--R       (b d x log(x) - b d x - b c - a )\|c
+--R  /
+--R       +-+
+--R     x\|c
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          +-------+              +-+
+--R                     - 2c\|d x + c  + (d x + 2c)\|c          +-+ +-------+
+--R         a b d x log(-------------------------------) - 2a b\|c \|d x + c
+--R                                    x
+--R       + 
+--R           2              2     2  +-+
+--R         (b d x log(x) - b c - a )\|c
+--R    /
+--R         +-+
+--R       x\|c
+--R     ,
+--R
+--R                          +---+ +-------+
+--R                         \|- c \|d x + c          +---+ +-------+
+--R         - 2a b d x atan(----------------) - 2a b\|- c \|d x + c
+--R                                 c
+--R       + 
+--R           2              2     2  +---+
+--R         (b d x log(x) - b c - a )\|- c
+--R    /
+--R         +---+
+--R       x\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 491
+
+--S 492 of 619
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      +-------+              +-+                  +-------+
+--R                 - 2c\|d x + c  + (d x + 2c)\|c                  \|d x + c
+--R       a b d log(-------------------------------) + 2a b d atanh(----------)
+--R                                x                                    +-+
+--R                                                                    \|c
+--R     + 
+--R        2  +-+
+--R       b d\|c
+--R  /
+--R      +-+
+--R     \|c
+--R                                                    Type: Expression(Integer)
+--E 492
+
+--S 493 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 619
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          +-------+                    +---+ +-------+
+--R              +---+      \|d x + c            +-+     \|- c \|d x + c
+--R       2a b d\|- c atanh(----------) - 2a b d\|c atan(----------------)
+--R                             +-+                              c
+--R                            \|c
+--R     + 
+--R        2  +---+ +-+
+--R       b d\|- c \|c
+--R  /
+--R      +---+ +-+
+--R     \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 619
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 619
+t0:=(a+b*sqrt(c+d*x))^2/x^3
+--R 
+--R
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R   (1)  ---------------------------------
+--R                         3
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 619
+r0:=1/2*a*b*d^2*atanh(sqrt(c+d*x)/sqrt(c))/c^(3/2)-_
+   1/2*b*d*(b*c+a*sqrt(c+d*x))/(c*x)-1/2*(a+b*sqrt(c+d*x))^2/x^2
+--R 
+--R
+--R   (2)
+--R                      +-------+
+--R            2 2      \|d x + c                          +-+ +-------+
+--R       a b d x atanh(----------) + (- a b d x - 2a b c)\|c \|d x + c
+--R                         +-+
+--R                        \|c
+--R     + 
+--R            2         2 2    2   +-+
+--R       (- 2b c d x - b c  - a c)\|c
+--R  /
+--R         2 +-+
+--R     2c x \|c
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        +-------+              +-+
+--R              2 2    2c\|d x + c  + (d x + 2c)\|c
+--R         a b d x log(-----------------------------)
+--R                                   x
+--R       + 
+--R                               +-+ +-------+        2          2 2     2   +-+
+--R         (- 2a b d x - 4a b c)\|c \|d x + c  + (- 4b c d x - 2b c  - 2a c)\|c
+--R    /
+--R           2 +-+
+--R       4c x \|c
+--R     ,
+--R
+--R                       +---+ +-------+
+--R              2 2     \|- c \|d x + c                          +---+ +-------+
+--R         a b d x atan(----------------) + (- a b d x - 2a b c)\|- c \|d x + c
+--R                              c
+--R       + 
+--R              2         2 2    2   +---+
+--R         (- 2b c d x - b c  - a c)\|- c
+--R    /
+--R           2 +---+
+--R       2c x \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 498
+
+--S 499 of 619
+m0a:=a0.1-r0
+--R 
+--R
+--R                     +-------+              +-+                  +-------+
+--R             2    2c\|d x + c  + (d x + 2c)\|c           2      \|d x + c
+--R        a b d log(-----------------------------) - 2a b d atanh(----------)
+--R                                x                                   +-+
+--R                                                                   \|c
+--R   (4)  -------------------------------------------------------------------
+--R                                          +-+
+--R                                       4c\|c
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 619
+m0b:=a0.2-r0
+--R 
+--R
+--R                             +-------+                    +---+ +-------+
+--R               2 +---+      \|d x + c          2 +-+     \|- c \|d x + c
+--R        - a b d \|- c atanh(----------) + a b d \|c atan(----------------)
+--R                                +-+                              c
+--R                               \|c
+--R   (6)  ------------------------------------------------------------------
+--R                                      +---+ +-+
+--R                                   2c\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 619
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 502
+
+)clear all
+
+--S 503 of 619
+t0:=x^3*sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R           +---------------+
+--R         3 |  +-------+
+--R   (1)  x \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 619
+r0:=-4/3*a*(a^2-b^2*c)^3*(a+b*sqrt(c+d*x))^(3/2)/(b^8*d^4)+4/5*(a^2-b^2*c)^2*_
+   (7*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(5/2)/(b^8*d^4)-12/7*a*(7*a^2-3*b^2*c)*_
+   (a^2-b^2*c)*(a+b*sqrt(c+d*x))^(7/2)/(b^8*d^4)+4/9*(35*a^4-_
+   30*a^2*b^2*c+3*b^4*c^2)*(a+b*sqrt(c+d*x))^(9/2)/(b^8*d^4)-20/11*a*_
+   (7*a^2-3*b^2*c)*(a+b*sqrt(c+d*x))^(11/2)/(b^8*d^4)+12/13*(7*a^2-b^2*c)*_
+   (a+b*sqrt(c+d*x))^(13/2)/(b^8*d^4)-28/15*a*(a+b*sqrt(c+d*x))^(15/2)/_
+   (b^8*d^4)+4/17*(a+b*sqrt(c+d*x))^(17/2)/(b^8*d^4)
+--R 
+--R
+--R   (2)
+--R                     7 3 3              7          3 5  2 2
+--R             12012a b d x  + (- 28224a b c + 14112a b )d x
+--R           + 
+--R                      7 2         3 5          5 3                7 3
+--R             (53376a b c  - 53376a b c + 17920a b )d x - 110592a b c
+--R           + 
+--R                    3 5 2          5 3          7
+--R             165888a b c  - 112640a b c + 28672a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R                8 4 4          8          2 6  3 3
+--R         180180b d x  + (13860b c - 12936a b )d x
+--R       + 
+--R                  8 2         2 6          4 4  2 2
+--R         (- 18480b c  + 32592a b c - 15680a b )d x
+--R       + 
+--R                8 3         2 6 2         4 4          6 2              8 4
+--R         (29568b c  - 71040a b c  + 66560a b c - 21504a b )d x - 118272b c
+--R       + 
+--R                2 6 3          4 4 2          6 2          8
+--R         291840a b c  - 384512a b c  + 239616a b c - 57344a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R            8 4
+--R     765765b d
+--R                                                    Type: Expression(Integer)
+--E 504
+
+--S 505 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     7 3 3              7          3 5  2 2
+--R             12012a b d x  + (- 28224a b c + 14112a b )d x
+--R           + 
+--R                      7 2         3 5          5 3                7 3
+--R             (53376a b c  - 53376a b c + 17920a b )d x - 110592a b c
+--R           + 
+--R                    3 5 2          5 3          7
+--R             165888a b c  - 112640a b c + 28672a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R                8 4 4          8          2 6  3 3
+--R         180180b d x  + (13860b c - 12936a b )d x
+--R       + 
+--R                  8 2         2 6          4 4  2 2
+--R         (- 18480b c  + 32592a b c - 15680a b )d x
+--R       + 
+--R                8 3         2 6 2         4 4          6 2              8 4
+--R         (29568b c  - 71040a b c  + 66560a b c - 21504a b )d x - 118272b c
+--R       + 
+--R                2 6 3          4 4 2          6 2          8
+--R         291840a b c  - 384512a b c  + 239616a b c - 57344a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R            8 4
+--R     765765b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 505
+
+--S 506 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 619
+t0:=x^2*sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R           +---------------+
+--R         2 |  +-------+
+--R   (1)  x \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 619
+r0:=-4/3*a*(a^2-b^2*c)^2*(a+b*sqrt(c+d*x))^(3/2)/(b^6*d^3)+4/5*(5*a^4-_
+   6*a^2*b^2*c+b^4*c^2)*(a+b*sqrt(c+d*x))^(5/2)/(b^6*d^3)-8/7*a*(5*a^2-_
+   3*b^2*c)*(a+b*sqrt(c+d*x))^(7/2)/(b^6*d^3)+8/9*(5*a^2-b^2*c)*(a+_
+   b*sqrt(c+d*x))^(9/2)/(b^6*d^3)-20/11*a*(a+b*sqrt(c+d*x))^(11/2)/(b^6*_
+   d^3)+4/13*(a+b*sqrt(c+d*x))^(13/2)/(b^6*d^3)
+--R 
+--R
+--R   (2)
+--R                    5 2 2             5         3 3              5 2        3 3
+--R             1260a b d x  + (- 3200a b c + 1600a b )d x + 7552a b c  - 7552a b c
+--R           + 
+--R                  5
+--R             2560a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R               6 3 3         6         2 4  2 2
+--R         13860b d x  + (1540b c - 1400a b )d x
+--R       + 
+--R                 6 2        2 4         4 2            6 3         2 4 2
+--R         (- 2464b c  + 4064a b c - 1920a b )d x + 9856b c  - 18560a b c
+--R       + 
+--R               4 2         6
+--R         16384a b c - 5120a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R           6 3
+--R     45045b d
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    5 2 2             5         3 3              5 2        3 3
+--R             1260a b d x  + (- 3200a b c + 1600a b )d x + 7552a b c  - 7552a b c
+--R           + 
+--R                  5
+--R             2560a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R               6 3 3         6         2 4  2 2
+--R         13860b d x  + (1540b c - 1400a b )d x
+--R       + 
+--R                 6 2        2 4         4 2            6 3         2 4 2
+--R         (- 2464b c  + 4064a b c - 1920a b )d x + 9856b c  - 18560a b c
+--R       + 
+--R               4 2         6
+--R         16384a b c - 5120a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R           6 3
+--R     45045b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 510
+
+--S 511 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 512
+
+)clear all
+
+--S 513 of 619
+t0:=x*sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R          +---------------+
+--R          |  +-------+
+--R   (1)  x\|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 513
+
+--S 514 of 619
+r0:=-4/3*a*(a^2-b^2*c)*(a+b*sqrt(c+d*x))^(3/2)/(b^4*d^2)+4/5*(3*a^2-b^2*c)*_
+   (a+b*sqrt(c+d*x))^(5/2)/(b^4*d^2)-12/7*a*(a+b*sqrt(c+d*x))^(7/2)/_
+   (b^4*d^2)+4/9*(a+b*sqrt(c+d*x))^(9/2)/(b^4*d^2)
+--R 
+--R
+--R   (2)
+--R               3           3       3   +-------+       4 2 2
+--R         (20a b d x - 64a b c + 32a b)\|d x + c  + 140b d x
+--R       + 
+--R             4       2 2           4 2       2 2       4
+--R         (28b c - 24a b )d x - 112b c  + 144a b c - 64a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R         4 2
+--R     315b d
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3           3       3   +-------+       4 2 2
+--R         (20a b d x - 64a b c + 32a b)\|d x + c  + 140b d x
+--R       + 
+--R             4       2 2           4 2       2 2       4
+--R         (28b c - 24a b )d x - 112b c  + 144a b c - 64a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R         4 2
+--R     315b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 515
+
+--S 516 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 517
+
+)clear all
+
+--S 518 of 619
+t0:=sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R         +---------------+
+--R         |  +-------+
+--R   (1)  \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 619
+r0:=-4/3*a*(a+b*sqrt(c+d*x))^(3/2)/(b^2*d)+4/5*(a+b*sqrt(c+d*x))^(5/2)/(b^2*d)
+--R 
+--R
+--R                                                 +---------------+
+--R              +-------+      2         2      2  |  +-------+
+--R        (4a b\|d x + c  + 12b d x + 12b c - 8a )\|b\|d x + c  + a
+--R   (2)  ----------------------------------------------------------
+--R                                      2
+--R                                   15b d
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                 +---------------+
+--R              +-------+      2         2      2  |  +-------+
+--R        (4a b\|d x + c  + 12b d x + 12b c - 8a )\|b\|d x + c  + a
+--R   (3)  ----------------------------------------------------------
+--R                                      2
+--R                                   15b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 520
+
+--S 521 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 619
+t0:=sqrt(a+b*sqrt(c+d*x))/x
+--R 
+--R
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 619
+r0:=-2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))*sqrt(a-b*sqrt(c))-_
+   2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a+b*sqrt(c)))*sqrt(a+b*sqrt(c))+_
+   4*sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R   (2)
+--R                             +---------------+
+--R         +-----------+       |  +-------+
+--R         |    +-+           \|b\|d x + c  + a
+--R     - 2\|- b\|c  + a atanh(------------------)
+--R                               +-----------+
+--R                               |    +-+
+--R                              \|- b\|c  + a
+--R   + 
+--R                           +---------------+
+--R         +---------+       |  +-------+           +---------------+
+--R         |  +-+           \|b\|d x + c  + a       |  +-------+
+--R     - 2\|b\|c  + a atanh(------------------) + 4\|b\|d x + c  + a
+--R                              +---------+
+--R                              |  +-+
+--R                             \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-------------+                           +-------------+
+--R          |  +----+            +---------------+    |  +----+
+--R          |  |  2              |  +-------+         |  |  2
+--R       - \|2\|4b c  + 4a log(2\|b\|d x + c  + a  + \|2\|4b c  + 4a )
+--R     + 
+--R          +---------------+                           +---------------+
+--R          |    +----+            +---------------+    |    +----+
+--R          |    |  2              |  +-------+         |    |  2
+--R       - \|- 2\|4b c  + 4a log(2\|b\|d x + c  + a  + \|- 2\|4b c  + 4a )
+--R     + 
+--R        +---------------+                           +---------------+
+--R        |    +----+            +---------------+    |    +----+
+--R        |    |  2              |  +-------+         |    |  2
+--R       \|- 2\|4b c  + 4a log(2\|b\|d x + c  + a  - \|- 2\|4b c  + 4a )
+--R     + 
+--R        +-------------+                           +-------------+
+--R        |  +----+            +---------------+    |  +----+
+--R        |  |  2              |  +-------+         |  |  2
+--R       \|2\|4b c  + 4a log(2\|b\|d x + c  + a  - \|2\|4b c  + 4a )
+--R     + 
+--R         +---------------+
+--R         |  +-------+
+--R       8\|b\|d x + c  + a
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 525
+
+--S 526 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +-------------+                           +-------------+
+--R          |  +----+            +---------------+    |  +----+
+--R          |  |  2              |  +-------+         |  |  2
+--R       - \|2\|4b c  + 4a log(2\|b\|d x + c  + a  + \|2\|4b c  + 4a )
+--R     + 
+--R          +---------------+                           +---------------+
+--R          |    +----+            +---------------+    |    +----+
+--R          |    |  2              |  +-------+         |    |  2
+--R       - \|- 2\|4b c  + 4a log(2\|b\|d x + c  + a  + \|- 2\|4b c  + 4a )
+--R     + 
+--R        +---------------+                           +---------------+
+--R        |    +----+            +---------------+    |    +----+
+--R        |    |  2              |  +-------+         |    |  2
+--R       \|- 2\|4b c  + 4a log(2\|b\|d x + c  + a  - \|- 2\|4b c  + 4a )
+--R     + 
+--R        +-------------+                           +-------------+
+--R        |  +----+            +---------------+    |  +----+
+--R        |  |  2              |  +-------+         |  |  2
+--R       \|2\|4b c  + 4a log(2\|b\|d x + c  + a  - \|2\|4b c  + 4a )
+--R     + 
+--R                             +---------------+
+--R         +-----------+       |  +-------+
+--R         |    +-+           \|b\|d x + c  + a
+--R       4\|- b\|c  + a atanh(------------------)
+--R                               +-----------+
+--R                               |    +-+
+--R                              \|- b\|c  + a
+--R     + 
+--R                           +---------------+
+--R         +---------+       |  +-------+
+--R         |  +-+           \|b\|d x + c  + a
+--R       4\|b\|c  + a atanh(------------------)
+--R                              +---------+
+--R                              |  +-+
+--R                             \|b\|c  + a
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 527
+
+)clear all
+
+--S 528 of 619
+t0:=sqrt(a+b*sqrt(c+d*x))/x^2
+--R 
+--R
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R   (1)  ------------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 528
+
+--S 529 of 619
+r0:=1/2*b*d*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))/(sqrt(c)*_
+   sqrt(a-b*sqrt(c)))-1/2*b*d*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a+_
+   b*sqrt(c)))/(sqrt(c)*sqrt(a+b*sqrt(c)))-sqrt(a+b*sqrt(c+d*x))/x
+--R 
+--R
+--R   (2)
+--R                               +---------------+
+--R             +---------+       |  +-------+
+--R             |  +-+           \|b\|d x + c  + a
+--R       b d x\|b\|c  + a atanh(------------------)
+--R                                 +-----------+
+--R                                 |    +-+
+--R                                \|- b\|c  + a
+--R     + 
+--R                                   +---------------+
+--R               +-----------+       |  +-------+
+--R               |    +-+           \|b\|d x + c  + a
+--R       - b d x\|- b\|c  + a atanh(------------------)
+--R                                      +---------+
+--R                                      |  +-+
+--R                                     \|b\|c  + a
+--R     + 
+--R               +-----------+ +---------+ +---------------+
+--R           +-+ |    +-+      |  +-+      |  +-------+
+--R       - 2\|c \|- b\|c  + a \|b\|c  + a \|b\|d x + c  + a
+--R  /
+--R            +-----------+ +---------+
+--R        +-+ |    +-+      |  +-+
+--R     2x\|c \|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R              +----------------------------------------------------+
+--R              |               +--------------------------+
+--R              |               |            6 4
+--R              |   2 2     2   |           b d                   2 2
+--R              |(8b c  - 8a c) |--------------------------  - a b d
+--R              |               |   4 3       2 2 2      4
+--R              |              \|64b c  - 128a b c  + 64a c
+--R            x |----------------------------------------------------
+--R              |                      2 2     2
+--R             \|                    4b c  - 4a c
+--R         *
+--R            log
+--R                      +---------------+
+--R                  4 3 |  +-------+
+--R                 b d \|b\|d x + c  + a
+--R               + 
+--R                                       +--------------------------+
+--R                                       |            6 4
+--R                          2 2      3   |           b d                  4   2
+--R                   ((16a b c  - 16a c) |--------------------------  + 2b c d )
+--R                                       |   4 3       2 2 2      4
+--R                                      \|64b c  - 128a b c  + 64a c
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |               +--------------------------+
+--R                    |               |            6 4
+--R                    |   2 2     2   |           b d                   2 2
+--R                    |(8b c  - 8a c) |--------------------------  - a b d
+--R                    |               |   4 3       2 2 2      4
+--R                    |              \|64b c  - 128a b c  + 64a c
+--R                    |----------------------------------------------------
+--R                    |                      2 2     2
+--R                   \|                    4b c  - 4a c
+--R     + 
+--R           +------------------------------------------------------+
+--R           |                 +--------------------------+
+--R           |                 |            6 4
+--R           |     2 2     2   |           b d                   2 2
+--R           |(- 8b c  + 8a c) |--------------------------  - a b d
+--R           |                 |   4 3       2 2 2      4
+--R           |                \|64b c  - 128a b c  + 64a c
+--R         x |------------------------------------------------------
+--R           |                       2 2     2
+--R          \|                     4b c  - 4a c
+--R      *
+--R         log
+--R                   +---------------+
+--R               4 3 |  +-------+
+--R              b d \|b\|d x + c  + a
+--R            + 
+--R                                    +--------------------------+
+--R                                    |            6 4
+--R                       2 2      3   |           b d                  4   2
+--R                ((16a b c  - 16a c) |--------------------------  - 2b c d )
+--R                                    |   4 3       2 2 2      4
+--R                                   \|64b c  - 128a b c  + 64a c
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                 +--------------------------+
+--R                 |                 |            6 4
+--R                 |     2 2     2   |           b d                   2 2
+--R                 |(- 8b c  + 8a c) |--------------------------  - a b d
+--R                 |                 |   4 3       2 2 2      4
+--R                 |                \|64b c  - 128a b c  + 64a c
+--R                 |------------------------------------------------------
+--R                 |                       2 2     2
+--R                \|                     4b c  - 4a c
+--R     + 
+--R       -
+--R              +------------------------------------------------------+
+--R              |                 +--------------------------+
+--R              |                 |            6 4
+--R              |     2 2     2   |           b d                   2 2
+--R              |(- 8b c  + 8a c) |--------------------------  - a b d
+--R              |                 |   4 3       2 2 2      4
+--R              |                \|64b c  - 128a b c  + 64a c
+--R            x |------------------------------------------------------
+--R              |                       2 2     2
+--R             \|                     4b c  - 4a c
+--R         *
+--R            log
+--R                      +---------------+
+--R                  4 3 |  +-------+
+--R                 b d \|b\|d x + c  + a
+--R               + 
+--R                                         +--------------------------+
+--R                                         |            6 4
+--R                            2 2      3   |           b d                  4   2
+--R                   ((- 16a b c  + 16a c) |--------------------------  + 2b c d )
+--R                                         |   4 3       2 2 2      4
+--R                                        \|64b c  - 128a b c  + 64a c
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                 +--------------------------+
+--R                    |                 |            6 4
+--R                    |     2 2     2   |           b d                   2 2
+--R                    |(- 8b c  + 8a c) |--------------------------  - a b d
+--R                    |                 |   4 3       2 2 2      4
+--R                    |                \|64b c  - 128a b c  + 64a c
+--R                    |------------------------------------------------------
+--R                    |                       2 2     2
+--R                   \|                     4b c  - 4a c
+--R     + 
+--R           +----------------------------------------------------+
+--R           |               +--------------------------+
+--R           |               |            6 4
+--R           |   2 2     2   |           b d                   2 2
+--R           |(8b c  - 8a c) |--------------------------  - a b d
+--R           |               |   4 3       2 2 2      4
+--R           |              \|64b c  - 128a b c  + 64a c
+--R         x |----------------------------------------------------
+--R           |                      2 2     2
+--R          \|                    4b c  - 4a c
+--R      *
+--R         log
+--R                   +---------------+
+--R               4 3 |  +-------+
+--R              b d \|b\|d x + c  + a
+--R            + 
+--R                                      +--------------------------+
+--R                                      |            6 4
+--R                         2 2      3   |           b d                  4   2
+--R                ((- 16a b c  + 16a c) |--------------------------  - 2b c d )
+--R                                      |   4 3       2 2 2      4
+--R                                     \|64b c  - 128a b c  + 64a c
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |               +--------------------------+
+--R                 |               |            6 4
+--R                 |   2 2     2   |           b d                   2 2
+--R                 |(8b c  - 8a c) |--------------------------  - a b d
+--R                 |               |   4 3       2 2 2      4
+--R                 |              \|64b c  - 128a b c  + 64a c
+--R                 |----------------------------------------------------
+--R                 |                      2 2     2
+--R                \|                    4b c  - 4a c
+--R     + 
+--R           +---------------+
+--R           |  +-------+
+--R       - 2\|b\|d x + c  + a
+--R  /
+--R     2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 530
+
+--S 531 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                 +-----------+ +---------+
+--R             +-+ |    +-+      |  +-+
+--R            \|c \|- b\|c  + a \|b\|c  + a
+--R         *
+--R             +----------------------------------------------------+
+--R             |               +--------------------------+
+--R             |               |            6 4
+--R             |   2 2     2   |           b d                   2 2
+--R             |(8b c  - 8a c) |--------------------------  - a b d
+--R             |               |   4 3       2 2 2      4
+--R             |              \|64b c  - 128a b c  + 64a c
+--R             |----------------------------------------------------
+--R             |                      2 2     2
+--R            \|                    4b c  - 4a c
+--R         *
+--R            log
+--R                      +---------------+
+--R                  4 3 |  +-------+
+--R                 b d \|b\|d x + c  + a
+--R               + 
+--R                                       +--------------------------+
+--R                                       |            6 4
+--R                          2 2      3   |           b d                  4   2
+--R                   ((16a b c  - 16a c) |--------------------------  + 2b c d )
+--R                                       |   4 3       2 2 2      4
+--R                                      \|64b c  - 128a b c  + 64a c
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |               +--------------------------+
+--R                    |               |            6 4
+--R                    |   2 2     2   |           b d                   2 2
+--R                    |(8b c  - 8a c) |--------------------------  - a b d
+--R                    |               |   4 3       2 2 2      4
+--R                    |              \|64b c  - 128a b c  + 64a c
+--R                    |----------------------------------------------------
+--R                    |                      2 2     2
+--R                   \|                    4b c  - 4a c
+--R     + 
+--R              +------------------------------------------------------+
+--R              |                 +--------------------------+
+--R              |                 |            6 4
+--R              |     2 2     2   |           b d                   2 2
+--R              |(- 8b c  + 8a c) |--------------------------  - a b d
+--R              |                 |   4 3       2 2 2      4
+--R          +-+ |                \|64b c  - 128a b c  + 64a c
+--R         \|c  |------------------------------------------------------
+--R              |                       2 2     2
+--R             \|                     4b c  - 4a c
+--R      *
+--R          +-----------+ +---------+
+--R          |    +-+      |  +-+
+--R         \|- b\|c  + a \|b\|c  + a
+--R      *
+--R         log
+--R                   +---------------+
+--R               4 3 |  +-------+
+--R              b d \|b\|d x + c  + a
+--R            + 
+--R                                    +--------------------------+
+--R                                    |            6 4
+--R                       2 2      3   |           b d                  4   2
+--R                ((16a b c  - 16a c) |--------------------------  - 2b c d )
+--R                                    |   4 3       2 2 2      4
+--R                                   \|64b c  - 128a b c  + 64a c
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |                 +--------------------------+
+--R                 |                 |            6 4
+--R                 |     2 2     2   |           b d                   2 2
+--R                 |(- 8b c  + 8a c) |--------------------------  - a b d
+--R                 |                 |   4 3       2 2 2      4
+--R                 |                \|64b c  - 128a b c  + 64a c
+--R                 |------------------------------------------------------
+--R                 |                       2 2     2
+--R                \|                     4b c  - 4a c
+--R     + 
+--R       -
+--R                 +------------------------------------------------------+
+--R                 |                 +--------------------------+
+--R                 |                 |            6 4
+--R                 |     2 2     2   |           b d                   2 2
+--R                 |(- 8b c  + 8a c) |--------------------------  - a b d
+--R                 |                 |   4 3       2 2 2      4
+--R             +-+ |                \|64b c  - 128a b c  + 64a c
+--R            \|c  |------------------------------------------------------
+--R                 |                       2 2     2
+--R                \|                     4b c  - 4a c
+--R         *
+--R             +-----------+ +---------+
+--R             |    +-+      |  +-+
+--R            \|- b\|c  + a \|b\|c  + a
+--R         *
+--R            log
+--R                      +---------------+
+--R                  4 3 |  +-------+
+--R                 b d \|b\|d x + c  + a
+--R               + 
+--R                                         +--------------------------+
+--R                                         |            6 4
+--R                            2 2      3   |           b d                  4   2
+--R                   ((- 16a b c  + 16a c) |--------------------------  + 2b c d )
+--R                                         |   4 3       2 2 2      4
+--R                                        \|64b c  - 128a b c  + 64a c
+--R                *
+--R                    +------------------------------------------------------+
+--R                    |                 +--------------------------+
+--R                    |                 |            6 4
+--R                    |     2 2     2   |           b d                   2 2
+--R                    |(- 8b c  + 8a c) |--------------------------  - a b d
+--R                    |                 |   4 3       2 2 2      4
+--R                    |                \|64b c  - 128a b c  + 64a c
+--R                    |------------------------------------------------------
+--R                    |                       2 2     2
+--R                   \|                     4b c  - 4a c
+--R     + 
+--R              +-----------+ +---------+
+--R          +-+ |    +-+      |  +-+
+--R         \|c \|- b\|c  + a \|b\|c  + a
+--R      *
+--R          +----------------------------------------------------+
+--R          |               +--------------------------+
+--R          |               |            6 4
+--R          |   2 2     2   |           b d                   2 2
+--R          |(8b c  - 8a c) |--------------------------  - a b d
+--R          |               |   4 3       2 2 2      4
+--R          |              \|64b c  - 128a b c  + 64a c
+--R          |----------------------------------------------------
+--R          |                      2 2     2
+--R         \|                    4b c  - 4a c
+--R      *
+--R         log
+--R                   +---------------+
+--R               4 3 |  +-------+
+--R              b d \|b\|d x + c  + a
+--R            + 
+--R                                      +--------------------------+
+--R                                      |            6 4
+--R                         2 2      3   |           b d                  4   2
+--R                ((- 16a b c  + 16a c) |--------------------------  - 2b c d )
+--R                                      |   4 3       2 2 2      4
+--R                                     \|64b c  - 128a b c  + 64a c
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |               +--------------------------+
+--R                 |               |            6 4
+--R                 |   2 2     2   |           b d                   2 2
+--R                 |(8b c  - 8a c) |--------------------------  - a b d
+--R                 |               |   4 3       2 2 2      4
+--R                 |              \|64b c  - 128a b c  + 64a c
+--R                 |----------------------------------------------------
+--R                 |                      2 2     2
+--R                \|                    4b c  - 4a c
+--R     + 
+--R                               +---------------+
+--R             +---------+       |  +-------+
+--R             |  +-+           \|b\|d x + c  + a
+--R       - b d\|b\|c  + a atanh(------------------)
+--R                                 +-----------+
+--R                                 |    +-+
+--R                                \|- b\|c  + a
+--R     + 
+--R                               +---------------+
+--R           +-----------+       |  +-------+
+--R           |    +-+           \|b\|d x + c  + a
+--R       b d\|- b\|c  + a atanh(------------------)
+--R                                  +---------+
+--R                                  |  +-+
+--R                                 \|b\|c  + a
+--R  /
+--R           +-----------+ +---------+
+--R       +-+ |    +-+      |  +-+
+--R     2\|c \|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 532
+
+)clear all
+
+--S 533 of 619
+t0:=sqrt(a+b*sqrt(c+d*x))/x^3
+--R 
+--R
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R   (1)  ------------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 619
+r0:=-1/16*b*d^2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))*(2*a-_
+   3*b*sqrt(c))/(c^(3/2)*(a-b*sqrt(c))^(3/2))+1/16*b*d^2*atanh(sqrt(a+_
+   b*sqrt(c+d*x))/sqrt(a+b*sqrt(c)))*(2*a+3*b*sqrt(c))/(c^(3/2)*(a+_
+   b*sqrt(c))^(3/2))-1/2*sqrt(a+b*sqrt(c+d*x))/x^2+1/8*b*d*(b*c-_
+   a*sqrt(c+d*x))*sqrt(a+b*sqrt(c+d*x))/(c*(a^2-b^2*c)*x)
+--R 
+--R
+--R   (2)
+--R                                                +---------+
+--R               3      2   2 2 +-+      2   2 2  |  +-+
+--R         ((- 3b c + 2a b)d x \|c  - a b c d x )\|b\|c  + a
+--R      *
+--R                +---------------+
+--R                |  +-------+
+--R               \|b\|d x + c  + a
+--R         atanh(------------------)
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- b\|c  + a
+--R     + 
+--R                                              +-----------+
+--R             3      2   2 2 +-+      2   2 2  |    +-+
+--R         ((3b c - 2a b)d x \|c  - a b c d x )\|- b\|c  + a
+--R      *
+--R                +---------------+
+--R                |  +-------+
+--R               \|b\|d x + c  + a
+--R         atanh(------------------)
+--R                   +---------+
+--R                   |  +-+
+--R                  \|b\|c  + a
+--R     + 
+--R                                                           +-----------+
+--R                     +-------+     2 2        2 3     2 2  |    +-+
+--R         (2a b c d x\|d x + c  - 2b c d x - 8b c  + 8a c )\|- b\|c  + a
+--R      *
+--R          +---------+ +---------------+
+--R          |  +-+      |  +-------+
+--R         \|b\|c  + a \|b\|d x + c  + a
+--R  /
+--R                         +-----------+ +---------+
+--R         2 3      2 2  2 |    +-+      |  +-+
+--R     (16b c  - 16a c )x \|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2 2     2   2
+--R         (4b c  - 4a c)x
+--R      *
+--R         ROOT
+--R                       6 6        2 4 5        4 2 4       6 3
+--R                  (512b c  - 1536a b c  + 1536a b c  - 512a c )
+--R               *
+--R                  ROOT
+--R                           14 2      2 12       4 10  8
+--R                       (81b  c  - 90a b  c + 25a b  )d
+--R                    /
+--R                                12 9           2 10 8           4 8 7
+--R                         262144b  c  - 1572864a b  c  + 3932160a b c
+--R                       + 
+--R                                   6 6 6           8 4 5           10 2 4
+--R                         - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                       + 
+--R                                12 3
+--R                         262144a  c
+--R              + 
+--R                        6 2      3 4      5 2  4
+--R                (- 15a b c  + 15a b c - 4a b )d
+--R           /
+--R                  6 6       2 4 5       4 2 4       6 3
+--R              256b c  - 768a b c  + 768a b c  - 256a c
+--R      *
+--R         log
+--R                                             +---------------+
+--R                  10 2      2 8       4 6  6 |  +-------+
+--R              (81b  c  - 81a b c + 20a b )d \|b\|d x + c  + a
+--R            + 
+--R                              8 7          3 6 6          5 4 5         7 2 4
+--R                      32768a b c  - 114688a b c  + 147456a b c  - 81920a b c
+--R                    + 
+--R                            9 3
+--R                      16384a c
+--R                 *
+--R                    ROOT
+--R                             14 2      2 12       4 10  8
+--R                         (81b  c  - 90a b  c + 25a b  )d
+--R                      /
+--R                                  12 9           2 10 8           4 8 7
+--R                           262144b  c  - 1572864a b  c  + 3932160a b c
+--R                         + 
+--R                                     6 6 6           8 4 5           10 2 4
+--R                           - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                         + 
+--R                                  12 3
+--R                           262144a  c
+--R                + 
+--R                       10 4       2 8 3      4 6 2  4
+--R                  (432b  c  - 384a b c  + 80a b c )d
+--R             *
+--R                ROOT
+--R                              6 6        2 4 5        4 2 4       6 3
+--R                         (512b c  - 1536a b c  + 1536a b c  - 512a c )
+--R                      *
+--R                         ROOT
+--R                                  14 2      2 12       4 10  8
+--R                              (81b  c  - 90a b  c + 25a b  )d
+--R                           /
+--R                                       12 9           2 10 8           4 8 7
+--R                                262144b  c  - 1572864a b  c  + 3932160a b c
+--R                              + 
+--R                                          6 6 6           8 4 5           10 2 4
+--R                                - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                              + 
+--R                                       12 3
+--R                                262144a  c
+--R                     + 
+--R                               6 2      3 4      5 2  4
+--R                       (- 15a b c  + 15a b c - 4a b )d
+--R                  /
+--R                         6 6       2 4 5       4 2 4       6 3
+--R                     256b c  - 768a b c  + 768a b c  - 256a c
+--R     + 
+--R              2 2     2   2
+--R         (- 4b c  + 4a c)x
+--R      *
+--R         ROOT
+--R                         6 6        2 4 5        4 2 4       6 3
+--R                  (- 512b c  + 1536a b c  - 1536a b c  + 512a c )
+--R               *
+--R                  ROOT
+--R                           14 2      2 12       4 10  8
+--R                       (81b  c  - 90a b  c + 25a b  )d
+--R                    /
+--R                                12 9           2 10 8           4 8 7
+--R                         262144b  c  - 1572864a b  c  + 3932160a b c
+--R                       + 
+--R                                   6 6 6           8 4 5           10 2 4
+--R                         - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                       + 
+--R                                12 3
+--R                         262144a  c
+--R              + 
+--R                        6 2      3 4      5 2  4
+--R                (- 15a b c  + 15a b c - 4a b )d
+--R           /
+--R                  6 6       2 4 5       4 2 4       6 3
+--R              256b c  - 768a b c  + 768a b c  - 256a c
+--R      *
+--R         log
+--R                                             +---------------+
+--R                  10 2      2 8       4 6  6 |  +-------+
+--R              (81b  c  - 81a b c + 20a b )d \|b\|d x + c  + a
+--R            + 
+--R                              8 7          3 6 6          5 4 5         7 2 4
+--R                      32768a b c  - 114688a b c  + 147456a b c  - 81920a b c
+--R                    + 
+--R                            9 3
+--R                      16384a c
+--R                 *
+--R                    ROOT
+--R                             14 2      2 12       4 10  8
+--R                         (81b  c  - 90a b  c + 25a b  )d
+--R                      /
+--R                                  12 9           2 10 8           4 8 7
+--R                           262144b  c  - 1572864a b  c  + 3932160a b c
+--R                         + 
+--R                                     6 6 6           8 4 5           10 2 4
+--R                           - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                         + 
+--R                                  12 3
+--R                           262144a  c
+--R                + 
+--R                         10 4       2 8 3      4 6 2  4
+--R                  (- 432b  c  + 384a b c  - 80a b c )d
+--R             *
+--R                ROOT
+--R                                6 6        2 4 5        4 2 4       6 3
+--R                         (- 512b c  + 1536a b c  - 1536a b c  + 512a c )
+--R                      *
+--R                         ROOT
+--R                                  14 2      2 12       4 10  8
+--R                              (81b  c  - 90a b  c + 25a b  )d
+--R                           /
+--R                                       12 9           2 10 8           4 8 7
+--R                                262144b  c  - 1572864a b  c  + 3932160a b c
+--R                              + 
+--R                                          6 6 6           8 4 5           10 2 4
+--R                                - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                              + 
+--R                                       12 3
+--R                                262144a  c
+--R                     + 
+--R                               6 2      3 4      5 2  4
+--R                       (- 15a b c  + 15a b c - 4a b )d
+--R                  /
+--R                         6 6       2 4 5       4 2 4       6 3
+--R                     256b c  - 768a b c  + 768a b c  - 256a c
+--R     + 
+--R            2 2     2   2
+--R         (4b c  - 4a c)x
+--R      *
+--R         ROOT
+--R                         6 6        2 4 5        4 2 4       6 3
+--R                  (- 512b c  + 1536a b c  - 1536a b c  + 512a c )
+--R               *
+--R                  ROOT
+--R                           14 2      2 12       4 10  8
+--R                       (81b  c  - 90a b  c + 25a b  )d
+--R                    /
+--R                                12 9           2 10 8           4 8 7
+--R                         262144b  c  - 1572864a b  c  + 3932160a b c
+--R                       + 
+--R                                   6 6 6           8 4 5           10 2 4
+--R                         - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                       + 
+--R                                12 3
+--R                         262144a  c
+--R              + 
+--R                        6 2      3 4      5 2  4
+--R                (- 15a b c  + 15a b c - 4a b )d
+--R           /
+--R                  6 6       2 4 5       4 2 4       6 3
+--R              256b c  - 768a b c  + 768a b c  - 256a c
+--R      *
+--R         log
+--R                                             +---------------+
+--R                  10 2      2 8       4 6  6 |  +-------+
+--R              (81b  c  - 81a b c + 20a b )d \|b\|d x + c  + a
+--R            + 
+--R                                8 7          3 6 6          5 4 5         7 2 4
+--R                      - 32768a b c  + 114688a b c  - 147456a b c  + 81920a b c
+--R                    + 
+--R                              9 3
+--R                      - 16384a c
+--R                 *
+--R                    ROOT
+--R                             14 2      2 12       4 10  8
+--R                         (81b  c  - 90a b  c + 25a b  )d
+--R                      /
+--R                                  12 9           2 10 8           4 8 7
+--R                           262144b  c  - 1572864a b  c  + 3932160a b c
+--R                         + 
+--R                                     6 6 6           8 4 5           10 2 4
+--R                           - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                         + 
+--R                                  12 3
+--R                           262144a  c
+--R                + 
+--R                       10 4       2 8 3      4 6 2  4
+--R                  (432b  c  - 384a b c  + 80a b c )d
+--R             *
+--R                ROOT
+--R                                6 6        2 4 5        4 2 4       6 3
+--R                         (- 512b c  + 1536a b c  - 1536a b c  + 512a c )
+--R                      *
+--R                         ROOT
+--R                                  14 2      2 12       4 10  8
+--R                              (81b  c  - 90a b  c + 25a b  )d
+--R                           /
+--R                                       12 9           2 10 8           4 8 7
+--R                                262144b  c  - 1572864a b  c  + 3932160a b c
+--R                              + 
+--R                                          6 6 6           8 4 5           10 2 4
+--R                                - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                              + 
+--R                                       12 3
+--R                                262144a  c
+--R                     + 
+--R                               6 2      3 4      5 2  4
+--R                       (- 15a b c  + 15a b c - 4a b )d
+--R                  /
+--R                         6 6       2 4 5       4 2 4       6 3
+--R                     256b c  - 768a b c  + 768a b c  - 256a c
+--R     + 
+--R              2 2     2   2
+--R         (- 4b c  + 4a c)x
+--R      *
+--R         ROOT
+--R                       6 6        2 4 5        4 2 4       6 3
+--R                  (512b c  - 1536a b c  + 1536a b c  - 512a c )
+--R               *
+--R                  ROOT
+--R                           14 2      2 12       4 10  8
+--R                       (81b  c  - 90a b  c + 25a b  )d
+--R                    /
+--R                                12 9           2 10 8           4 8 7
+--R                         262144b  c  - 1572864a b  c  + 3932160a b c
+--R                       + 
+--R                                   6 6 6           8 4 5           10 2 4
+--R                         - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                       + 
+--R                                12 3
+--R                         262144a  c
+--R              + 
+--R                        6 2      3 4      5 2  4
+--R                (- 15a b c  + 15a b c - 4a b )d
+--R           /
+--R                  6 6       2 4 5       4 2 4       6 3
+--R              256b c  - 768a b c  + 768a b c  - 256a c
+--R      *
+--R         log
+--R                                             +---------------+
+--R                  10 2      2 8       4 6  6 |  +-------+
+--R              (81b  c  - 81a b c + 20a b )d \|b\|d x + c  + a
+--R            + 
+--R                                8 7          3 6 6          5 4 5         7 2 4
+--R                      - 32768a b c  + 114688a b c  - 147456a b c  + 81920a b c
+--R                    + 
+--R                              9 3
+--R                      - 16384a c
+--R                 *
+--R                    ROOT
+--R                             14 2      2 12       4 10  8
+--R                         (81b  c  - 90a b  c + 25a b  )d
+--R                      /
+--R                                  12 9           2 10 8           4 8 7
+--R                           262144b  c  - 1572864a b  c  + 3932160a b c
+--R                         + 
+--R                                     6 6 6           8 4 5           10 2 4
+--R                           - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                         + 
+--R                                  12 3
+--R                           262144a  c
+--R                + 
+--R                         10 4       2 8 3      4 6 2  4
+--R                  (- 432b  c  + 384a b c  - 80a b c )d
+--R             *
+--R                ROOT
+--R                              6 6        2 4 5        4 2 4       6 3
+--R                         (512b c  - 1536a b c  + 1536a b c  - 512a c )
+--R                      *
+--R                         ROOT
+--R                                  14 2      2 12       4 10  8
+--R                              (81b  c  - 90a b  c + 25a b  )d
+--R                           /
+--R                                       12 9           2 10 8           4 8 7
+--R                                262144b  c  - 1572864a b  c  + 3932160a b c
+--R                              + 
+--R                                          6 6 6           8 4 5           10 2 4
+--R                                - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                              + 
+--R                                       12 3
+--R                                262144a  c
+--R                     + 
+--R                               6 2      3 4      5 2  4
+--R                       (- 15a b c  + 15a b c - 4a b )d
+--R                  /
+--R                         6 6       2 4 5       4 2 4       6 3
+--R                     256b c  - 768a b c  + 768a b c  - 256a c
+--R     + 
+--R                                                    +---------------+
+--R                +-------+    2          2 2     2   |  +-------+
+--R       (a b d x\|d x + c  - b c d x - 4b c  + 4a c)\|b\|d x + c  + a
+--R  /
+--R        2 2     2   2
+--R     (8b c  - 8a c)x
+--R                                         Type: Union(Expression(Integer),...)
+--E 535
+
+--S 536 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +-----------+ +---------+
+--R            2 3     2 2  |    +-+      |  +-+
+--R         (8b c  - 8a c )\|- b\|c  + a \|b\|c  + a
+--R      *
+--R         ROOT
+--R                       6 6        2 4 5        4 2 4       6 3
+--R                  (512b c  - 1536a b c  + 1536a b c  - 512a c )
+--R               *
+--R                  ROOT
+--R                           14 2      2 12       4 10  8
+--R                       (81b  c  - 90a b  c + 25a b  )d
+--R                    /
+--R                                12 9           2 10 8           4 8 7
+--R                         262144b  c  - 1572864a b  c  + 3932160a b c
+--R                       + 
+--R                                   6 6 6           8 4 5           10 2 4
+--R                         - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                       + 
+--R                                12 3
+--R                         262144a  c
+--R              + 
+--R                        6 2      3 4      5 2  4
+--R                (- 15a b c  + 15a b c - 4a b )d
+--R           /
+--R                  6 6       2 4 5       4 2 4       6 3
+--R              256b c  - 768a b c  + 768a b c  - 256a c
+--R      *
+--R         log
+--R                                             +---------------+
+--R                  10 2      2 8       4 6  6 |  +-------+
+--R              (81b  c  - 81a b c + 20a b )d \|b\|d x + c  + a
+--R            + 
+--R                              8 7          3 6 6          5 4 5         7 2 4
+--R                      32768a b c  - 114688a b c  + 147456a b c  - 81920a b c
+--R                    + 
+--R                            9 3
+--R                      16384a c
+--R                 *
+--R                    ROOT
+--R                             14 2      2 12       4 10  8
+--R                         (81b  c  - 90a b  c + 25a b  )d
+--R                      /
+--R                                  12 9           2 10 8           4 8 7
+--R                           262144b  c  - 1572864a b  c  + 3932160a b c
+--R                         + 
+--R                                     6 6 6           8 4 5           10 2 4
+--R                           - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                         + 
+--R                                  12 3
+--R                           262144a  c
+--R                + 
+--R                       10 4       2 8 3      4 6 2  4
+--R                  (432b  c  - 384a b c  + 80a b c )d
+--R             *
+--R                ROOT
+--R                              6 6        2 4 5        4 2 4       6 3
+--R                         (512b c  - 1536a b c  + 1536a b c  - 512a c )
+--R                      *
+--R                         ROOT
+--R                                  14 2      2 12       4 10  8
+--R                              (81b  c  - 90a b  c + 25a b  )d
+--R                           /
+--R                                       12 9           2 10 8           4 8 7
+--R                                262144b  c  - 1572864a b  c  + 3932160a b c
+--R                              + 
+--R                                          6 6 6           8 4 5           10 2 4
+--R                                - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                              + 
+--R                                       12 3
+--R                                262144a  c
+--R                     + 
+--R                               6 2      3 4      5 2  4
+--R                       (- 15a b c  + 15a b c - 4a b )d
+--R                  /
+--R                         6 6       2 4 5       4 2 4       6 3
+--R                     256b c  - 768a b c  + 768a b c  - 256a c
+--R     + 
+--R              2 3     2 2
+--R         (- 8b c  + 8a c )
+--R      *
+--R         ROOT
+--R                         6 6        2 4 5        4 2 4       6 3
+--R                  (- 512b c  + 1536a b c  - 1536a b c  + 512a c )
+--R               *
+--R                  ROOT
+--R                           14 2      2 12       4 10  8
+--R                       (81b  c  - 90a b  c + 25a b  )d
+--R                    /
+--R                                12 9           2 10 8           4 8 7
+--R                         262144b  c  - 1572864a b  c  + 3932160a b c
+--R                       + 
+--R                                   6 6 6           8 4 5           10 2 4
+--R                         - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                       + 
+--R                                12 3
+--R                         262144a  c
+--R              + 
+--R                        6 2      3 4      5 2  4
+--R                (- 15a b c  + 15a b c - 4a b )d
+--R           /
+--R                  6 6       2 4 5       4 2 4       6 3
+--R              256b c  - 768a b c  + 768a b c  - 256a c
+--R      *
+--R          +-----------+ +---------+
+--R          |    +-+      |  +-+
+--R         \|- b\|c  + a \|b\|c  + a
+--R      *
+--R         log
+--R                                             +---------------+
+--R                  10 2      2 8       4 6  6 |  +-------+
+--R              (81b  c  - 81a b c + 20a b )d \|b\|d x + c  + a
+--R            + 
+--R                              8 7          3 6 6          5 4 5         7 2 4
+--R                      32768a b c  - 114688a b c  + 147456a b c  - 81920a b c
+--R                    + 
+--R                            9 3
+--R                      16384a c
+--R                 *
+--R                    ROOT
+--R                             14 2      2 12       4 10  8
+--R                         (81b  c  - 90a b  c + 25a b  )d
+--R                      /
+--R                                  12 9           2 10 8           4 8 7
+--R                           262144b  c  - 1572864a b  c  + 3932160a b c
+--R                         + 
+--R                                     6 6 6           8 4 5           10 2 4
+--R                           - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                         + 
+--R                                  12 3
+--R                           262144a  c
+--R                + 
+--R                         10 4       2 8 3      4 6 2  4
+--R                  (- 432b  c  + 384a b c  - 80a b c )d
+--R             *
+--R                ROOT
+--R                                6 6        2 4 5        4 2 4       6 3
+--R                         (- 512b c  + 1536a b c  - 1536a b c  + 512a c )
+--R                      *
+--R                         ROOT
+--R                                  14 2      2 12       4 10  8
+--R                              (81b  c  - 90a b  c + 25a b  )d
+--R                           /
+--R                                       12 9           2 10 8           4 8 7
+--R                                262144b  c  - 1572864a b  c  + 3932160a b c
+--R                              + 
+--R                                          6 6 6           8 4 5           10 2 4
+--R                                - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                              + 
+--R                                       12 3
+--R                                262144a  c
+--R                     + 
+--R                               6 2      3 4      5 2  4
+--R                       (- 15a b c  + 15a b c - 4a b )d
+--R                  /
+--R                         6 6       2 4 5       4 2 4       6 3
+--R                     256b c  - 768a b c  + 768a b c  - 256a c
+--R     + 
+--R            2 3     2 2
+--R         (8b c  - 8a c )
+--R      *
+--R         ROOT
+--R                         6 6        2 4 5        4 2 4       6 3
+--R                  (- 512b c  + 1536a b c  - 1536a b c  + 512a c )
+--R               *
+--R                  ROOT
+--R                           14 2      2 12       4 10  8
+--R                       (81b  c  - 90a b  c + 25a b  )d
+--R                    /
+--R                                12 9           2 10 8           4 8 7
+--R                         262144b  c  - 1572864a b  c  + 3932160a b c
+--R                       + 
+--R                                   6 6 6           8 4 5           10 2 4
+--R                         - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                       + 
+--R                                12 3
+--R                         262144a  c
+--R              + 
+--R                        6 2      3 4      5 2  4
+--R                (- 15a b c  + 15a b c - 4a b )d
+--R           /
+--R                  6 6       2 4 5       4 2 4       6 3
+--R              256b c  - 768a b c  + 768a b c  - 256a c
+--R      *
+--R          +-----------+ +---------+
+--R          |    +-+      |  +-+
+--R         \|- b\|c  + a \|b\|c  + a
+--R      *
+--R         log
+--R                                             +---------------+
+--R                  10 2      2 8       4 6  6 |  +-------+
+--R              (81b  c  - 81a b c + 20a b )d \|b\|d x + c  + a
+--R            + 
+--R                                8 7          3 6 6          5 4 5         7 2 4
+--R                      - 32768a b c  + 114688a b c  - 147456a b c  + 81920a b c
+--R                    + 
+--R                              9 3
+--R                      - 16384a c
+--R                 *
+--R                    ROOT
+--R                             14 2      2 12       4 10  8
+--R                         (81b  c  - 90a b  c + 25a b  )d
+--R                      /
+--R                                  12 9           2 10 8           4 8 7
+--R                           262144b  c  - 1572864a b  c  + 3932160a b c
+--R                         + 
+--R                                     6 6 6           8 4 5           10 2 4
+--R                           - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                         + 
+--R                                  12 3
+--R                           262144a  c
+--R                + 
+--R                       10 4       2 8 3      4 6 2  4
+--R                  (432b  c  - 384a b c  + 80a b c )d
+--R             *
+--R                ROOT
+--R                                6 6        2 4 5        4 2 4       6 3
+--R                         (- 512b c  + 1536a b c  - 1536a b c  + 512a c )
+--R                      *
+--R                         ROOT
+--R                                  14 2      2 12       4 10  8
+--R                              (81b  c  - 90a b  c + 25a b  )d
+--R                           /
+--R                                       12 9           2 10 8           4 8 7
+--R                                262144b  c  - 1572864a b  c  + 3932160a b c
+--R                              + 
+--R                                          6 6 6           8 4 5           10 2 4
+--R                                - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                              + 
+--R                                       12 3
+--R                                262144a  c
+--R                     + 
+--R                               6 2      3 4      5 2  4
+--R                       (- 15a b c  + 15a b c - 4a b )d
+--R                  /
+--R                         6 6       2 4 5       4 2 4       6 3
+--R                     256b c  - 768a b c  + 768a b c  - 256a c
+--R     + 
+--R                           +-----------+ +---------+
+--R              2 3     2 2  |    +-+      |  +-+
+--R         (- 8b c  + 8a c )\|- b\|c  + a \|b\|c  + a
+--R      *
+--R         ROOT
+--R                       6 6        2 4 5        4 2 4       6 3
+--R                  (512b c  - 1536a b c  + 1536a b c  - 512a c )
+--R               *
+--R                  ROOT
+--R                           14 2      2 12       4 10  8
+--R                       (81b  c  - 90a b  c + 25a b  )d
+--R                    /
+--R                                12 9           2 10 8           4 8 7
+--R                         262144b  c  - 1572864a b  c  + 3932160a b c
+--R                       + 
+--R                                   6 6 6           8 4 5           10 2 4
+--R                         - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                       + 
+--R                                12 3
+--R                         262144a  c
+--R              + 
+--R                        6 2      3 4      5 2  4
+--R                (- 15a b c  + 15a b c - 4a b )d
+--R           /
+--R                  6 6       2 4 5       4 2 4       6 3
+--R              256b c  - 768a b c  + 768a b c  - 256a c
+--R      *
+--R         log
+--R                                             +---------------+
+--R                  10 2      2 8       4 6  6 |  +-------+
+--R              (81b  c  - 81a b c + 20a b )d \|b\|d x + c  + a
+--R            + 
+--R                                8 7          3 6 6          5 4 5         7 2 4
+--R                      - 32768a b c  + 114688a b c  - 147456a b c  + 81920a b c
+--R                    + 
+--R                              9 3
+--R                      - 16384a c
+--R                 *
+--R                    ROOT
+--R                             14 2      2 12       4 10  8
+--R                         (81b  c  - 90a b  c + 25a b  )d
+--R                      /
+--R                                  12 9           2 10 8           4 8 7
+--R                           262144b  c  - 1572864a b  c  + 3932160a b c
+--R                         + 
+--R                                     6 6 6           8 4 5           10 2 4
+--R                           - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                         + 
+--R                                  12 3
+--R                           262144a  c
+--R                + 
+--R                         10 4       2 8 3      4 6 2  4
+--R                  (- 432b  c  + 384a b c  - 80a b c )d
+--R             *
+--R                ROOT
+--R                              6 6        2 4 5        4 2 4       6 3
+--R                         (512b c  - 1536a b c  + 1536a b c  - 512a c )
+--R                      *
+--R                         ROOT
+--R                                  14 2      2 12       4 10  8
+--R                              (81b  c  - 90a b  c + 25a b  )d
+--R                           /
+--R                                       12 9           2 10 8           4 8 7
+--R                                262144b  c  - 1572864a b  c  + 3932160a b c
+--R                              + 
+--R                                          6 6 6           8 4 5           10 2 4
+--R                                - 5242880a b c  + 3932160a b c  - 1572864a  b c
+--R                              + 
+--R                                       12 3
+--R                                262144a  c
+--R                     + 
+--R                               6 2      3 4      5 2  4
+--R                       (- 15a b c  + 15a b c - 4a b )d
+--R                  /
+--R                         6 6       2 4 5       4 2 4       6 3
+--R                     256b c  - 768a b c  + 768a b c  - 256a c
+--R     + 
+--R                                                          +---------------+
+--R                                        +---------+       |  +-------+
+--R           3      2   2 +-+      2   2  |  +-+           \|b\|d x + c  + a
+--R       ((3b c - 2a b)d \|c  + a b c d )\|b\|c  + a atanh(------------------)
+--R                                                            +-----------+
+--R                                                            |    +-+
+--R                                                           \|- b\|c  + a
+--R     + 
+--R                                                            +---------------+
+--R                                        +-----------+       |  +-------+
+--R           3      2   2 +-+      2   2  |    +-+           \|b\|d x + c  + a
+--R     ((- 3b c + 2a b)d \|c  + a b c d )\|- b\|c  + a atanh(------------------)
+--R                                                               +---------+
+--R                                                               |  +-+
+--R                                                              \|b\|c  + a
+--R  /
+--R                       +-----------+ +---------+
+--R         2 3      2 2  |    +-+      |  +-+
+--R     (16b c  - 16a c )\|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 537
+
+)clear all
+
+--S 538 of 619
+t0:=x^3/(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R          +-------+
+--R        b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 619
+r0:=-a*(a^4-3*a^2*b^2*c+3*b^4*c^2)*x/(b^6*d^3)+2/3*(a^4-3*a^2*b^2*c+_
+   3*b^4*c^2)*(c+d*x)^(3/2)/(b^5*d^4)-1/2*a*(a^2-3*b^2*c)*(c+d*x)^2/_
+   (b^4*d^4)+2/5*(a^2-3*b^2*c)*(c+d*x)^(5/2)/(b^3*d^4)-1/3*a*(c+d*x)^3/_
+   (b^2*d^4)+2/7*(c+d*x)^(7/2)/(b*d^4)-2*a*(a^2-b^2*c)^3*log(a+b*_
+   sqrt(c+d*x))/(b^8*d^4)+2*(a^2-b^2*c)^3*sqrt(c+d*x)/(b^7*d^4)
+--R 
+--R
+--R   (2)
+--R              6 3        3 4 2        5 2        7       +-------+
+--R       (420a b c  - 1260a b c  + 1260a b c - 420a )log(b\|d x + c  + a)
+--R     + 
+--R              7 3 3         7       2 5  2 2       7 2       2 5        4 3
+--R           60b d x  + (- 72b c + 84a b )d x  + (96b c  - 252a b c + 140a b )d x
+--R         + 
+--R                 7 3       2 5 2        4 3        6
+--R           - 192b c  + 924a b c  - 1120a b c + 420a b
+--R      *
+--R          +-------+
+--R         \|d x + c
+--R     + 
+--R              6 3 3          6        3 4  2 2
+--R       - 70a b d x  + (105a b c - 105a b )d x
+--R     + 
+--R                6 2       3 4        5 2             6 3       3 4 2
+--R       (- 210a b c  + 420a b c - 210a b )d x + 245a b c  - 105a b c
+--R  /
+--R         8 4
+--R     210b d
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              6 3        3 4 2        5 2        7       +-------+
+--R       (420a b c  - 1260a b c  + 1260a b c - 420a )log(b\|d x + c  + a)
+--R     + 
+--R              7 3 3         7       2 5  2 2       7 2       2 5        4 3
+--R           60b d x  + (- 72b c + 84a b )d x  + (96b c  - 252a b c + 140a b )d x
+--R         + 
+--R                 7 3       2 5 2        4 3        6
+--R           - 192b c  + 924a b c  - 1120a b c + 420a b
+--R      *
+--R          +-------+
+--R         \|d x + c
+--R     + 
+--R              6 3 3          6        3 4  2 2
+--R       - 70a b d x  + (105a b c - 105a b )d x
+--R     + 
+--R                6 2       3 4        5 2
+--R       (- 210a b c  + 420a b c - 210a b )d x
+--R  /
+--R         8 4
+--R     210b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 540
+
+--S 541 of 619
+m0:=a0-r0
+--R 
+--R
+--R              2 3     3 2
+--R        - 7a b c  + 3a c
+--R   (4)  -----------------
+--R                4 4
+--R              6b d
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 542
+
+)clear all
+
+--S 543 of 619
+t0:=x^2/(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R          +-------+
+--R        b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 619
+r0:=-a*(a^2-2*b^2*c)*x/(b^4*d^2)+2/3*(a^2-2*b^2*c)*(c+d*x)^(3/2)/(b^3*d^3)-_
+   1/2*a*(c+d*x)^2/(b^2*d^3)+2/5*(c+d*x)^(5/2)/(b*d^3)-2*a*(a^2-b^2*c)^2*_
+   log(a+b*sqrt(c+d*x))/(b^6*d^3)+2*(a^2-b^2*c)^2*sqrt(c+d*x)/(b^5*d^3)
+--R 
+--R
+--R   (2)
+--R               4 2       3 2       5       +-------+
+--R       (- 60a b c  + 120a b c - 60a )log(b\|d x + c  + a)
+--R     + 
+--R           5 2 2         5       2 3          5 2       2 3       4   +-------+
+--R       (12b d x  + (- 16b c + 20a b )d x + 32b c  - 100a b c + 60a b)\|d x + c
+--R     + 
+--R              4 2 2         4       3 2            4 2
+--R       - 15a b d x  + (30a b c - 30a b )d x - 15a b c
+--R  /
+--R        6 3
+--R     30b d
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 2       3 2       5       +-------+
+--R       (- 60a b c  + 120a b c - 60a )log(b\|d x + c  + a)
+--R     + 
+--R           5 2 2         5       2 3          5 2       2 3       4   +-------+
+--R       (12b d x  + (- 16b c + 20a b )d x + 32b c  - 100a b c + 60a b)\|d x + c
+--R     + 
+--R              4 2 2         4       3 2
+--R       - 15a b d x  + (30a b c - 30a b )d x
+--R  /
+--R        6 3
+--R     30b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 545
+
+--S 546 of 619
+m0:=a0-r0
+--R 
+--R
+--R            2
+--R         a c
+--R   (4)  -----
+--R          2 3
+--R        2b d
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 547
+
+)clear all
+
+--S 548 of 619
+t0:=x/(a+b*sqrt(c+d*x))
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R          +-------+
+--R        b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 619
+r0:=-a*x/(b^2*d)+2/3*(c+d*x)^(3/2)/(b*d^2)-2*a*(a^2-b^2*c)*_
+   log(a+b*sqrt(c+d*x))/(b^4*d^2)+2*(a^2-b^2*c)*sqrt(c+d*x)/(b^3*d^2)
+--R 
+--R
+--R   (2)
+--R            2      3       +-------+           3        3      2   +-------+
+--R       (6a b c - 6a )log(b\|d x + c  + a) + (2b d x - 4b c + 6a b)\|d x + c
+--R     + 
+--R             2
+--R       - 3a b d x
+--R  /
+--R       4 2
+--R     3b d
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2      3       +-------+           3        3      2   +-------+
+--R       (6a b c - 6a )log(b\|d x + c  + a) + (2b d x - 4b c + 6a b)\|d x + c
+--R     + 
+--R             2
+--R       - 3a b d x
+--R  /
+--R       4 2
+--R     3b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 550
+
+--S 551 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 619
+t0:=1/(a+b*sqrt(c+d*x))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          +-------+
+--R        b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 619
+r0:=-2*a*log(a+b*sqrt(c+d*x))/(b^2*d)+2*sqrt(c+d*x)/(b*d)
+--R 
+--R
+--R                   +-------+           +-------+
+--R        - 2a log(b\|d x + c  + a) + 2b\|d x + c
+--R   (2)  ----------------------------------------
+--R                            2
+--R                           b d
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +-------+           +-------+
+--R        - 2a log(b\|d x + c  + a) + 2b\|d x + c
+--R   (3)  ----------------------------------------
+--R                            2
+--R                           b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 555
+
+--S 556 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 557
+
+)clear all
+
+--S 558 of 619
+t0:=1/(x*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R            +-------+
+--R        b x\|d x + c  + a x
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 619
+r0:=a*log(x)/(a^2-b^2*c)-2*a*log(a+b*sqrt(c+d*x))/(a^2-b^2*c)+_
+   2*b*atanh(sqrt(c+d*x)/sqrt(c))*sqrt(c)/(a^2-b^2*c)
+--R 
+--R
+--R                                               +-------+
+--R                 +-------+           +-+      \|d x + c
+--R        2a log(b\|d x + c  + a) - 2b\|c atanh(----------) - a log(x)
+--R                                                  +-+
+--R                                                 \|c
+--R   (2)  ------------------------------------------------------------
+--R                                   2     2
+--R                                  b c - a
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                           +-+ +-------+
+--R             +-------+          +-+    - 2\|c \|d x + c  + d x + 2c
+--R    2a log(b\|d x + c  + a) + b\|c log(----------------------------) - a log(x)
+--R                                                     x
+--R   [---------------------------------------------------------------------------,
+--R                                       2     2
+--R                                      b c - a
+--R                                            +-------+
+--R             +-------+           +---+     \|d x + c
+--R    2a log(b\|d x + c  + a) - 2b\|- c atan(----------) - a log(x)
+--R                                              +---+
+--R                                             \|- c
+--R    -------------------------------------------------------------]
+--R                                2     2
+--R                               b c - a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 560
+
+--S 561 of 619
+m0a:=a0.1-r0
+--R 
+--R
+--R                     +-+ +-------+                            +-------+
+--R          +-+    - 2\|c \|d x + c  + d x + 2c       +-+      \|d x + c
+--R        b\|c log(----------------------------) + 2b\|c atanh(----------)
+--R                               x                                 +-+
+--R                                                                \|c
+--R   (4)  ----------------------------------------------------------------
+--R                                     2     2
+--R                                    b c - a
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 619
+m0b:=a0.2-r0
+--R 
+--R
+--R                     +-------+                  +-------+
+--R           +-+      \|d x + c        +---+     \|d x + c
+--R        2b\|c atanh(----------) - 2b\|- c atan(----------)
+--R                        +-+                       +---+
+--R                       \|c                       \|- c
+--R   (6)  --------------------------------------------------
+--R                              2     2
+--R                             b c - a
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 619
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 619
+t0:=1/(x^2*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R           2 +-------+      2
+--R        b x \|d x + c  + a x
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 619
+r0:=a*b^2*d*log(x)/(a^2-b^2*c)^2-2*a*b^2*d*log(a+b*sqrt(c+d*x))/_
+   (a^2-b^2*c)^2+b*(a^2+b^2*c)*d*atanh(sqrt(c+d*x)/sqrt(c))/((a^2-b^2*c)^2*_
+   sqrt(c))+(-a+b*sqrt(c+d*x))/((a^2-b^2*c)*x)
+--R 
+--R
+--R   (2)
+--R                                                                  +-------+
+--R             2    +-+      +-------+          3     2            \|d x + c
+--R       - 2a b d x\|c log(b\|d x + c  + a) + (b c + a b)d x atanh(----------)
+--R                                                                     +-+
+--R                                                                    \|c
+--R     + 
+--R           3     2   +-+ +-------+       2                2     3  +-+
+--R       (- b c + a b)\|c \|d x + c  + (a b d x log(x) + a b c - a )\|c
+--R  /
+--R       4 2     2 2     4   +-+
+--R     (b c  - 2a b c + a )x\|c
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               2    +-+      +-------+
+--R         - 4a b d x\|c log(b\|d x + c  + a)
+--R       + 
+--R                               +-------+              +-+
+--R           3     2          2c\|d x + c  + (d x + 2c)\|c
+--R         (b c + a b)d x log(-----------------------------)
+--R                                          x
+--R       + 
+--R              3      2   +-+ +-------+        2                 2      3  +-+
+--R         (- 2b c + 2a b)\|c \|d x + c  + (2a b d x log(x) + 2a b c - 2a )\|c
+--R    /
+--R          4 2     2 2      4   +-+
+--R       (2b c  - 4a b c + 2a )x\|c
+--R     ,
+--R
+--R               2    +---+      +-------+
+--R         - 2a b d x\|- c log(b\|d x + c  + a)
+--R       + 
+--R                              +---+ +-------+
+--R           3     2           \|- c \|d x + c         3     2   +---+ +-------+
+--R         (b c + a b)d x atan(----------------) + (- b c + a b)\|- c \|d x + c
+--R                                     c
+--R       + 
+--R             2                2     3  +---+
+--R         (a b d x log(x) + a b c - a )\|- c
+--R    /
+--R         4 2     2 2     4   +---+
+--R       (b c  - 2a b c + a )x\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 567
+
+--S 568 of 619
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           +-------+              +-+
+--R         3     2        2c\|d x + c  + (d x + 2c)\|c
+--R       (b c + a b)d log(-----------------------------)
+--R                                      x
+--R     + 
+--R                               +-------+
+--R            3      2          \|d x + c
+--R       (- 2b c - 2a b)d atanh(----------)
+--R                                  +-+
+--R                                 \|c
+--R  /
+--R        4 2     2 2      4  +-+
+--R     (2b c  - 4a b c + 2a )\|c
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 619
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                  +-------+
+--R           3     2    +---+      \|d x + c
+--R       (- b c - a b)d\|- c atanh(----------)
+--R                                     +-+
+--R                                    \|c
+--R     + 
+--R                             +---+ +-------+
+--R         3     2    +-+     \|- c \|d x + c
+--R       (b c + a b)d\|c atan(----------------)
+--R                                    c
+--R  /
+--R       4 2     2 2     4  +---+ +-+
+--R     (b c  - 2a b c + a )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 619
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 571
+
+)clear all
+
+--S 572 of 619
+t0:=1/(x^3*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R           3 +-------+      3
+--R        b x \|d x + c  + a x
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 619
+r0:=-1/4*b*(a^4-6*a^2*b^2*c-3*b^4*c^2)*d^2*atanh(sqrt(c+d*x)/sqrt(c))/_
+   (c^(3/2)*(a^2-b^2*c)^3)+a*b^4*d^2*log(x)/(a^2-b^2*c)^3-2*a*b^4*d^2*_
+   log(a+b*sqrt(c+d*x))/(a^2-b^2*c)^3+1/2*(-a+b*sqrt(c+d*x))/((a^2-_
+   b^2*c)*x^2)-1/4*b*d*(4*a*b*c-(a^2+3*b^2*c)*sqrt(c+d*x))/(c*(a^2-b^2*c)^2*x)
+--R 
+--R
+--R   (2)
+--R           4   2 2 +-+      +-------+
+--R       8a b c d x \|c log(b\|d x + c  + a)
+--R     + 
+--R                                          +-------+
+--R            5 2     2 3     4   2 2      \|d x + c
+--R       (- 3b c  - 6a b c + a b)d x atanh(----------)
+--R                                             +-+
+--R                                            \|c
+--R     + 
+--R           5 2     2 3     4          5 3     2 3 2     4     +-+ +-------+
+--R       ((3b c  - 2a b c - a b)d x - 2b c  + 4a b c  - 2a b c)\|c \|d x + c
+--R     + 
+--R                 4   2 2                4 2     3 2            4 3     3 2 2
+--R           - 4a b c d x log(x) + (- 4a b c  + 4a b c)d x + 2a b c  - 4a b c
+--R         + 
+--R             5
+--R           2a c
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R        6 4      2 4 3      4 2 2     6   2 +-+
+--R     (4b c  - 12a b c  + 12a b c  - 4a c)x \|c
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              4   2 2 +-+      +-------+
+--R         16a b c d x \|c log(b\|d x + c  + a)
+--R       + 
+--R                                            +-------+              +-+
+--R            5 2     2 3     4   2 2    - 2c\|d x + c  + (d x + 2c)\|c
+--R         (3b c  + 6a b c - a b)d x log(-------------------------------)
+--R                                                      x
+--R       + 
+--R             5 2     2 3      4          5 3     2 3 2     4     +-+ +-------+
+--R         ((6b c  - 4a b c - 2a b)d x - 4b c  + 8a b c  - 4a b c)\|c \|d x + c
+--R       + 
+--R                   4   2 2                4 2     3 2            4 3     3 2 2
+--R             - 8a b c d x log(x) + (- 8a b c  + 8a b c)d x + 4a b c  - 8a b c
+--R           + 
+--R               5
+--R             4a c
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R          6 4      2 4 3      4 2 2     6   2 +-+
+--R       (8b c  - 24a b c  + 24a b c  - 8a c)x \|c
+--R     ,
+--R
+--R             4   2 2 +---+      +-------+
+--R         8a b c d x \|- c log(b\|d x + c  + a)
+--R       + 
+--R                                           +---+ +-------+
+--R              5 2     2 3     4   2 2     \|- c \|d x + c
+--R         (- 3b c  - 6a b c + a b)d x atan(----------------)
+--R                                                  c
+--R       + 
+--R             5 2     2 3     4          5 3     2 3 2     4     +---+ +-------+
+--R         ((3b c  - 2a b c - a b)d x - 2b c  + 4a b c  - 2a b c)\|- c \|d x + c
+--R       + 
+--R                   4   2 2                4 2     3 2            4 3     3 2 2
+--R             - 4a b c d x log(x) + (- 4a b c  + 4a b c)d x + 2a b c  - 4a b c
+--R           + 
+--R               5
+--R             2a c
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R          6 4      2 4 3      4 2 2     6   2 +---+
+--R       (4b c  - 12a b c  + 12a b c  - 4a c)x \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 574
+
+--S 575 of 619
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                        +-------+              +-+
+--R          5 2     2 3     4   2    - 2c\|d x + c  + (d x + 2c)\|c
+--R       (3b c  + 6a b c - a b)d log(-------------------------------)
+--R                                                  x
+--R     + 
+--R                                        +-------+
+--R          5 2      2 3      4   2      \|d x + c
+--R       (6b c  + 12a b c - 2a b)d atanh(----------)
+--R                                           +-+
+--R                                          \|c
+--R  /
+--R        6 4      2 4 3      4 2 2     6   +-+
+--R     (8b c  - 24a b c  + 24a b c  - 8a c)\|c
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 619
+m0b:=a0.1-r0
+--R 
+--R
+--R   (6)
+--R                                        +-------+              +-+
+--R          5 2     2 3     4   2    - 2c\|d x + c  + (d x + 2c)\|c
+--R       (3b c  + 6a b c - a b)d log(-------------------------------)
+--R                                                  x
+--R     + 
+--R                                        +-------+
+--R          5 2      2 3      4   2      \|d x + c
+--R       (6b c  + 12a b c - 2a b)d atanh(----------)
+--R                                           +-+
+--R                                          \|c
+--R  /
+--R        6 4      2 4 3      4 2 2     6   +-+
+--R     (8b c  - 24a b c  + 24a b c  - 8a c)\|c
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 619
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 578
+
+)clear all
+
+--S 579 of 619
+t0:=x^3/(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R                         3
+--R                        x
+--R   (1)  ---------------------------------
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 619
+r0:=(5*a^4-9*a^2*b^2*c+3*b^4*c^2)*x/(b^6*d^3)-4/3*a*(2*a^2-3*b^2*c)*_
+   (c+d*x)^(3/2)/(b^5*d^4)+3/2*(a^2-b^2*c)*(c+d*x)^2/(b^4*d^4)-4/5*a*_
+   (c+d*x)^(5/2)/(b^3*d^4)+1/3*(c+d*x)^3/(b^2*d^4)+2*(a^2-b^2*c)^2*_
+   (7*a^2-b^2*c)*log(a+b*sqrt(c+d*x))/(b^8*d^4)-12*a*(a^2-b^2*c)^2*_
+   sqrt(c+d*x)/(b^7*d^4)+2*a*(a^2-b^2*c)^3/(b^8*d^4*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R                 7 3       2 5 2       4 3        6   +-------+        6 3
+--R           (- 60b c  + 540a b c  - 900a b c + 420a b)\|d x + c  - 60a b c
+--R         + 
+--R               3 4 2       5 2        7
+--R           540a b c  - 900a b c + 420a
+--R      *
+--R               +-------+
+--R         log(b\|d x + c  + a)
+--R     + 
+--R              7 3 3         7       2 5  2 2       7 2       2 5       4 3
+--R           10b d x  + (- 15b c + 21a b )d x  + (30b c  - 108a b c + 70a b )d x
+--R         + 
+--R                7 3       2 5 2       4 3        6
+--R           - 35b c  - 219a b c  + 640a b c - 360a b
+--R      *
+--R          +-------+
+--R         \|d x + c
+--R     + 
+--R              6 3 3         6       3 4  2 2
+--R       - 14a b d x  + (33a b c - 35a b )d x
+--R     + 
+--R                6 2       3 4        5 2             6 3       3 4 2       5 2
+--R       (- 162a b c  + 380a b c - 210a b )d x - 359a b c  + 865a b c  - 540a b c
+--R     + 
+--R          7
+--R       60a
+--R  /
+--R        9 4 +-------+        8 4
+--R     30b d \|d x + c  + 30a b d
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 7 3       2 5 2       4 3        6   +-------+        6 3
+--R           (- 60b c  + 540a b c  - 900a b c + 420a b)\|d x + c  - 60a b c
+--R         + 
+--R               3 4 2       5 2        7
+--R           540a b c  - 900a b c + 420a
+--R      *
+--R               +-------+
+--R         log(b\|d x + c  + a)
+--R     + 
+--R              7 3 3         7       2 5  2 2       7 2       2 5       4 3
+--R           10b d x  + (- 15b c + 21a b )d x  + (30b c  - 108a b c + 70a b )d x
+--R         + 
+--R              7 3       2 5 2       4 3        6
+--R           55b c  - 489a b c  + 790a b c - 360a b
+--R      *
+--R          +-------+
+--R         \|d x + c
+--R     + 
+--R              6 3 3         6       3 4  2 2
+--R       - 14a b d x  + (33a b c - 35a b )d x
+--R     + 
+--R                6 2       3 4        5 2             6 3       3 4 2       5 2
+--R       (- 162a b c  + 380a b c - 210a b )d x - 269a b c  + 595a b c  - 390a b c
+--R     + 
+--R          7
+--R       60a
+--R  /
+--R        9 4 +-------+        8 4
+--R     30b d \|d x + c  + 30a b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 581
+
+--S 582 of 619
+m0:=a0-r0
+--R 
+--R
+--R          4 3     2 2 2     4
+--R        3b c  - 9a b c  + 5a c
+--R   (4)  ----------------------
+--R                  6 4
+--R                 b d
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 583
+
+)clear all
+
+--S 584 of 619
+t0:=x^2/(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R                         2
+--R                        x
+--R   (1)  ---------------------------------
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 619
+r0:=(3*a^2-2*b^2*c)*x/(b^4*d^2)-4/3*a*(c+d*x)^(3/2)/(b^3*d^3)+1/2*(c+d*x)^2/_
+   (b^2*d^3)+2*(5*a^4-6*a^2*b^2*c+b^4*c^2)*log(a+b*sqrt(c+d*x))/(b^6*d^3)-_
+   8*a*(a^2-b^2*c)*sqrt(c+d*x)/(b^5*d^3)+2*a*(a^2-b^2*c)^2/(b^6*d^3*_
+   (a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R              5 2      2 3       4   +-------+        4 2      3 2       5
+--R         ((12b c  - 72a b c + 60a b)\|d x + c  + 12a b c  - 72a b c + 60a )
+--R      *
+--R               +-------+
+--R         log(b\|d x + c  + a)
+--R     + 
+--R          5 2 2        5       2 3         5 2      2 3       4   +-------+
+--R       (3b d x  + (- 6b c + 10a b )d x + 3b c  + 40a b c - 48a b)\|d x + c
+--R     + 
+--R             4 2 2         4       3 2            4 2      3 2       5
+--R       - 5a b d x  + (26a b c - 30a b )d x + 55a b c  - 72a b c + 12a
+--R  /
+--R       7 3 +-------+       6 3
+--R     6b d \|d x + c  + 6a b d
+--R                                                    Type: Expression(Integer)
+--E 585
+
+--S 586 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              5 2      2 3       4   +-------+        4 2      3 2       5
+--R         ((12b c  - 72a b c + 60a b)\|d x + c  + 12a b c  - 72a b c + 60a )
+--R      *
+--R               +-------+
+--R         log(b\|d x + c  + a)
+--R     + 
+--R          5 2 2        5       2 3         5 2      2 3       4   +-------+
+--R       (3b d x  + (- 6b c + 10a b )d x - 9b c  + 58a b c - 48a b)\|d x + c
+--R     + 
+--R             4 2 2         4       3 2            4 2      3 2       5
+--R       - 5a b d x  + (26a b c - 30a b )d x + 43a b c  - 54a b c + 12a
+--R  /
+--R       7 3 +-------+       6 3
+--R     6b d \|d x + c  + 6a b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 586
+
+--S 587 of 619
+m0:=a0-r0
+--R 
+--R
+--R            2 2     2
+--R        - 2b c  + 3a c
+--R   (4)  --------------
+--R              4 3
+--R             b d
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 588
+
+)clear all
+
+--S 589 of 619
+t0:=x/(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R                        x
+--R   (1)  ---------------------------------
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 619
+r0:=x/(b^2*d)+2*(3*a^2-b^2*c)*log(a+b*sqrt(c+d*x))/(b^4*d^2)-_
+   4*a*sqrt(c+d*x)/(b^3*d^2)+2*a*(a^2-b^2*c)/(b^4*d^2*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R             3      2   +-------+       2      3       +-------+
+--R       ((- 2b c + 6a b)\|d x + c  - 2a b c + 6a )log(b\|d x + c  + a)
+--R     + 
+--R         3        2   +-------+       2          2      3
+--R       (b d x - 4a b)\|d x + c  - 3a b d x - 6a b c + 2a
+--R  /
+--R      5 2 +-------+      4 2
+--R     b d \|d x + c  + a b d
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3      2   +-------+       2      3       +-------+
+--R       ((- 2b c + 6a b)\|d x + c  - 2a b c + 6a )log(b\|d x + c  + a)
+--R     + 
+--R         3       3      2   +-------+       2          2      3
+--R       (b d x + b c - 4a b)\|d x + c  - 3a b d x - 5a b c + 2a
+--R  /
+--R      5 2 +-------+      4 2
+--R     b d \|d x + c  + a b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 591
+
+--S 592 of 619
+m0:=a0-r0
+--R 
+--R
+--R          c
+--R   (4)  ----
+--R         2 2
+--R        b d
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 593
+
+)clear all
+
+--S 594 of 619
+t0:=1/(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 619
+r0:=2*log(a+b*sqrt(c+d*x))/(b^2*d)+2*a/(b^2*d*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R            +-------+            +-------+
+--R        (2b\|d x + c  + 2a)log(b\|d x + c  + a) + 2a
+--R   (2)  --------------------------------------------
+--R                     3  +-------+      2
+--R                    b d\|d x + c  + a b d
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +-------+            +-------+
+--R        (2b\|d x + c  + 2a)log(b\|d x + c  + a) + 2a
+--R   (3)  --------------------------------------------
+--R                     3  +-------+      2
+--R                    b d\|d x + c  + a b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 596
+
+--S 597 of 619
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 619
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 598
+
+)clear all
+
+--S 599 of 619
+t0:=1/(x*(a+b*sqrt(c+d*x))^2)
+--R 
+--R
+--R                           1
+--R   (1)  ---------------------------------------
+--R               +-------+    2   2     2     2
+--R        2a b x\|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 619
+r0:=(a^2+b^2*c)*log(x)/(a^2-b^2*c)^2-2*(a^2+b^2*c)*log(a+b*sqrt(c+d*x))/_
+   (a^2-b^2*c)^2+4*a*b*atanh(sqrt(c+d*x)/sqrt(c))*sqrt(c)/(a^2-b^2*c)^2+_
+   2*a/((a^2-b^2*c)*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R             3      2   +-------+       2      3       +-------+
+--R       ((- 2b c - 2a b)\|d x + c  - 2a b c - 2a )log(b\|d x + c  + a)
+--R     + 
+--R                                              +-------+
+--R            2 +-+ +-------+     2  +-+       \|d x + c
+--R       (4a b \|c \|d x + c  + 4a b\|c )atanh(----------)
+--R                                                 +-+
+--R                                                \|c
+--R     + 
+--R         3     2         +-------+       2     3              2      3
+--R       (b c + a b)log(x)\|d x + c  + (a b c + a )log(x) - 2a b c + 2a
+--R  /
+--R       5 2     2 3     4   +-------+      4 2     3 2     5
+--R     (b c  - 2a b c + a b)\|d x + c  + a b c  - 2a b c + a
+--R                                                    Type: Expression(Integer)
+--E 600
+
+--S 601 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                               +-+ +-------+
+--R              2 +-+ +-------+     2  +-+     2\|c \|d x + c  + d x + 2c
+--R         (2a b \|c \|d x + c  + 2a b\|c )log(--------------------------)
+--R                                                          x
+--R       + 
+--R               3      2   +-------+       2      3       +-------+
+--R         ((- 2b c - 2a b)\|d x + c  - 2a b c - 2a )log(b\|d x + c  + a)
+--R       + 
+--R           3     2         +-------+       2     3              2      3
+--R         (b c + a b)log(x)\|d x + c  + (a b c + a )log(x) - 2a b c + 2a
+--R    /
+--R         5 2     2 3     4   +-------+      4 2     3 2     5
+--R       (b c  - 2a b c + a b)\|d x + c  + a b c  - 2a b c + a
+--R     ,
+--R
+--R               3      2   +-------+       2      3       +-------+
+--R         ((- 2b c - 2a b)\|d x + c  - 2a b c - 2a )log(b\|d x + c  + a)
+--R       + 
+--R                                                   +-------+
+--R              2 +---+ +-------+     2  +---+      \|d x + c
+--R         (4a b \|- c \|d x + c  + 4a b\|- c )atan(----------)
+--R                                                     +---+
+--R                                                    \|- c
+--R       + 
+--R           3     2         +-------+       2     3              2      3
+--R         (b c + a b)log(x)\|d x + c  + (a b c + a )log(x) - 2a b c + 2a
+--R    /
+--R         5 2     2 3     4   +-------+      4 2     3 2     5
+--R       (b c  - 2a b c + a b)\|d x + c  + a b c  - 2a b c + a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 601
+
+--S 602 of 619
+m0a:=a0.1-r0
+--R 
+--R
+--R                      +-+ +-------+                              +-------+
+--R             +-+    2\|c \|d x + c  + d x + 2c         +-+      \|d x + c
+--R        2a b\|c log(--------------------------) - 4a b\|c atanh(----------)
+--R                                 x                                  +-+
+--R                                                                   \|c
+--R   (4)  -------------------------------------------------------------------
+--R                                  4 2     2 2     4
+--R                                 b c  - 2a b c + a
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 619
+m0b:=a0.2-r0
+--R 
+--R
+--R                         +-------+                    +-------+
+--R               +-+      \|d x + c          +---+     \|d x + c
+--R        - 4a b\|c atanh(----------) + 4a b\|- c atan(----------)
+--R                            +-+                         +---+
+--R                           \|c                         \|- c
+--R   (6)  --------------------------------------------------------
+--R                            4 2     2 2     4
+--R                           b c  - 2a b c + a
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 619
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 605
+
+)clear all
+
+--S 606 of 619
+t0:=1/(x^2*(a+b*sqrt(c+d*x))^2)
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R              2 +-------+    2   3     2     2  2
+--R        2a b x \|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 619
+r0:=b^2*(3*a^2+b^2*c)*d*log(x)/(a^2-b^2*c)^3-2*b^2*(3*a^2+b^2*c)*d*_
+   log(a+b*sqrt(c+d*x))/(a^2-b^2*c)^3+2*a*b*(a^2+3*b^2*c)*d*_
+   atanh(sqrt(c+d*x)/sqrt(c))/((a^2-b^2*c)^3*sqrt(c))+4*a*b^2*d/_
+   ((a^2-b^2*c)^2*(a+b*sqrt(c+d*x)))+(-a+b*sqrt(c+d*x))/((a^2-b^2*c)*_
+   x*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R             5      2 3     +-+ +-------+        4      3 2     +-+
+--R         ((2b c + 6a b )d x\|c \|d x + c  + (2a b c + 6a b )d x\|c )
+--R      *
+--R               +-------+
+--R         log(b\|d x + c  + a)
+--R     + 
+--R                                                                      +-------+
+--R               4      3 2     +-------+        2 3      4            \|d x + c
+--R       ((- 6a b c - 2a b )d x\|d x + c  + (- 6a b c - 2a b)d x)atanh(----------)
+--R                                                                         +-+
+--R                                                                        \|c
+--R     + 
+--R            5      2 3               5 2     2 3     4   +-+ +-------+
+--R       ((- b c - 3a b )d x log(x) - b c  + 2a b c - a b)\|c \|d x + c
+--R     + 
+--R                 4      3 2                   4      3 2          4 2     3 2
+--R           (- a b c - 3a b )d x log(x) + (4a b c - 4a b )d x + a b c  - 2a b c
+--R         + 
+--R            5
+--R           a
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R         7 3     2 5 2     4 3     6    +-+ +-------+
+--R       (b c  - 3a b c  + 3a b c - a b)x\|c \|d x + c
+--R     + 
+--R           6 3     3 4 2     5 2     7   +-+
+--R       (a b c  - 3a b c  + 3a b c - a )x\|c
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               5      2 3     +-+ +-------+        4      3 2     +-+
+--R           ((2b c + 6a b )d x\|c \|d x + c  + (2a b c + 6a b )d x\|c )
+--R        *
+--R                 +-------+
+--R           log(b\|d x + c  + a)
+--R       + 
+--R                 4     3 2     +-------+      2 3     4
+--R           ((3a b c + a b )d x\|d x + c  + (3a b c + a b)d x)
+--R        *
+--R                    +-------+              +-+
+--R               - 2c\|d x + c  + (d x + 2c)\|c
+--R           log(-------------------------------)
+--R                              x
+--R       + 
+--R              5      2 3               5 2     2 3     4   +-+ +-------+
+--R         ((- b c - 3a b )d x log(x) - b c  + 2a b c - a b)\|c \|d x + c
+--R       + 
+--R                   4      3 2                   4      3 2          4 2     3 2
+--R             (- a b c - 3a b )d x log(x) + (4a b c - 4a b )d x + a b c  - 2a b c
+--R           + 
+--R              5
+--R             a
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R           7 3     2 5 2     4 3     6    +-+ +-------+
+--R         (b c  - 3a b c  + 3a b c - a b)x\|c \|d x + c
+--R       + 
+--R             6 3     3 4 2     5 2     7   +-+
+--R         (a b c  - 3a b c  + 3a b c - a )x\|c
+--R     ,
+--R
+--R               5      2 3     +---+ +-------+        4      3 2     +---+
+--R           ((2b c + 6a b )d x\|- c \|d x + c  + (2a b c + 6a b )d x\|- c )
+--R        *
+--R                 +-------+
+--R           log(b\|d x + c  + a)
+--R       + 
+--R                   4      3 2     +-------+        2 3      4
+--R           ((- 6a b c - 2a b )d x\|d x + c  + (- 6a b c - 2a b)d x)
+--R        *
+--R                 +---+ +-------+
+--R                \|- c \|d x + c
+--R           atan(----------------)
+--R                        c
+--R       + 
+--R              5      2 3               5 2     2 3     4   +---+ +-------+
+--R         ((- b c - 3a b )d x log(x) - b c  + 2a b c - a b)\|- c \|d x + c
+--R       + 
+--R                   4      3 2                   4      3 2          4 2     3 2
+--R             (- a b c - 3a b )d x log(x) + (4a b c - 4a b )d x + a b c  - 2a b c
+--R           + 
+--R              5
+--R             a
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R           7 3     2 5 2     4 3     6    +---+ +-------+
+--R         (b c  - 3a b c  + 3a b c - a b)x\|- c \|d x + c
+--R       + 
+--R             6 3     3 4 2     5 2     7   +---+
+--R         (a b c  - 3a b c  + 3a b c - a )x\|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 608
+
+--S 609 of 619
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                +-------+              +-+
+--R            3     3        - 2c\|d x + c  + (d x + 2c)\|c
+--R       (3a b c + a b)d log(-------------------------------)
+--R                                          x
+--R     + 
+--R                               +-------+
+--R            3      3          \|d x + c
+--R       (6a b c + 2a b)d atanh(----------)
+--R                                  +-+
+--R                                 \|c
+--R  /
+--R       6 3     2 4 2     4 2     6  +-+
+--R     (b c  - 3a b c  + 3a b c - a )\|c
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 619
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                    +-------+
+--R            3      3    +---+      \|d x + c
+--R       (6a b c + 2a b)d\|- c atanh(----------)
+--R                                       +-+
+--R                                      \|c
+--R     + 
+--R                                   +---+ +-------+
+--R              3      3    +-+     \|- c \|d x + c
+--R       (- 6a b c - 2a b)d\|c atan(----------------)
+--R                                          c
+--R  /
+--R       6 3     2 4 2     4 2     6  +---+ +-+
+--R     (b c  - 3a b c  + 3a b c - a )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 619
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 612
+
+)clear all
+
+--S 613 of 619
+t0:=1/(x^3*(a+b*sqrt(c+d*x))^2)
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R              3 +-------+    2   4     2     2  3
+--R        2a b x \|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 619
+r0:=-1/2*a*b*(a^4-10*a^2*b^2*c-15*b^4*c^2)*d^2*atanh(sqrt(c+d*x)/sqrt(c))/_
+   (c^(3/2)*(a^2-b^2*c)^4)+b^4*(5*a^2+b^2*c)*d^2*log(x)/(a^2-b^2*c)^4-_
+   2*b^4*(5*a^2+b^2*c)*d^2*log(a+b*sqrt(c+d*x))/(a^2-b^2*c)^4+1/2*a*b^2*_
+   (a^2+11*b^2*c)*d^2/(c*(a^2-b^2*c)^3*(a+b*sqrt(c+d*x)))+1/2*(-a+b*_
+   sqrt(c+d*x))/((a^2-b^2*c)*x^2*(a+b*sqrt(c+d*x)))-1/2*b*d*(3*a*b*c-_
+   (a^2+2*b^2*c)*sqrt(c+d*x))/(c*(a^2-b^2*c)^2*x*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R               7 2      2 5   2 2 +-+ +-------+          6 2      3 4   2 2 +-+
+--R         ((- 4b c  - 20a b c)d x \|c \|d x + c  + (- 4a b c  - 20a b c)d x \|c )
+--R      *
+--R               +-------+
+--R         log(b\|d x + c  + a)
+--R     + 
+--R                 6 2      3 4     5 2  2 2 +-------+
+--R           (15a b c  + 10a b c - a b )d x \|d x + c
+--R         + 
+--R               2 5 2      4 3     6   2 2
+--R           (15a b c  + 10a b c - a b)d x
+--R      *
+--R                +-------+
+--R               \|d x + c
+--R         atanh(----------)
+--R                   +-+
+--R                  \|c
+--R     + 
+--R              7 2      2 5   2 2            7 3     2 5 2    6         7 4
+--R           (2b c  + 10a b c)d x log(x) + (2b c  - 3a b c  + a b)d x - b c
+--R         + 
+--R             2 5 3     4 3 2    6
+--R           3a b c  - 3a b c  + a b c
+--R      *
+--R          +-+ +-------+
+--R         \|c \|d x + c
+--R     + 
+--R                6 2      3 4   2 2                 6 2      3 4     5 2  2 2
+--R           (2a b c  + 10a b c)d x log(x) + (- 11a b c  + 10a b c + a b )d x
+--R         + 
+--R                  6 3     3 4 2     5 2           6 4     3 4 3     5 2 2    7
+--R           (- 3a b c  + 6a b c  - 3a b c)d x + a b c  - 3a b c  + 3a b c  - a c
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R          9 5     2 7 4      4 5 3     6 3 2     8     2 +-+ +-------+
+--R       (2b c  - 8a b c  + 12a b c  - 8a b c  + 2a b c)x \|c \|d x + c
+--R     + 
+--R            8 5     3 6 4      5 4 3     7 2 2     9   2 +-+
+--R       (2a b c  - 8a b c  + 12a b c  - 8a b c  + 2a c)x \|c
+--R                                                    Type: Expression(Integer)
+--E 614
+
+--S 615 of 619
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    7 2      2 5   2 2 +-+ +-------+
+--R               (- 8b c  - 40a b c)d x \|c \|d x + c
+--R             + 
+--R                      6 2      3 4   2 2 +-+
+--R               (- 8a b c  - 40a b c)d x \|c
+--R        *
+--R                 +-------+
+--R           log(b\|d x + c  + a)
+--R       + 
+--R                   6 2      3 4     5 2  2 2 +-------+
+--R             (15a b c  + 10a b c - a b )d x \|d x + c
+--R           + 
+--R                 2 5 2      4 3     6   2 2
+--R             (15a b c  + 10a b c - a b)d x
+--R        *
+--R                  +-------+              +-+
+--R               2c\|d x + c  + (d x + 2c)\|c
+--R           log(-----------------------------)
+--R                             x
+--R       + 
+--R                7 2      2 5   2 2            7 3     2 5 2     6          7 4
+--R             (4b c  + 20a b c)d x log(x) + (4b c  - 6a b c  + 2a b)d x - 2b c
+--R           + 
+--R               2 5 3     4 3 2     6
+--R             6a b c  - 6a b c  + 2a b c
+--R        *
+--R            +-+ +-------+
+--R           \|c \|d x + c
+--R       + 
+--R                  6 2      3 4   2 2                 6 2      3 4      5 2  2 2
+--R             (4a b c  + 20a b c)d x log(x) + (- 22a b c  + 20a b c + 2a b )d x
+--R           + 
+--R                    6 3      3 4 2     5 2            6 4     3 4 3     5 2 2
+--R             (- 6a b c  + 12a b c  - 6a b c)d x + 2a b c  - 6a b c  + 6a b c
+--R           + 
+--R                 7
+--R             - 2a c
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R            9 5      2 7 4      4 5 3      6 3 2     8     2 +-+ +-------+
+--R         (4b c  - 16a b c  + 24a b c  - 16a b c  + 4a b c)x \|c \|d x + c
+--R       + 
+--R              8 5      3 6 4      5 4 3      7 2 2     9   2 +-+
+--R         (4a b c  - 16a b c  + 24a b c  - 16a b c  + 4a c)x \|c
+--R     ,
+--R
+--R                  7 2      2 5   2 2 +---+ +-------+
+--R             (- 4b c  - 20a b c)d x \|- c \|d x + c
+--R           + 
+--R                    6 2      3 4   2 2 +---+
+--R             (- 4a b c  - 20a b c)d x \|- c
+--R        *
+--R                 +-------+
+--R           log(b\|d x + c  + a)
+--R       + 
+--R                   6 2      3 4     5 2  2 2 +-------+
+--R             (15a b c  + 10a b c - a b )d x \|d x + c
+--R           + 
+--R                 2 5 2      4 3     6   2 2
+--R             (15a b c  + 10a b c - a b)d x
+--R        *
+--R                 +---+ +-------+
+--R                \|- c \|d x + c
+--R           atan(----------------)
+--R                        c
+--R       + 
+--R                7 2      2 5   2 2            7 3     2 5 2    6         7 4
+--R             (2b c  + 10a b c)d x log(x) + (2b c  - 3a b c  + a b)d x - b c
+--R           + 
+--R               2 5 3     4 3 2    6
+--R             3a b c  - 3a b c  + a b c
+--R        *
+--R            +---+ +-------+
+--R           \|- c \|d x + c
+--R       + 
+--R                  6 2      3 4   2 2                 6 2      3 4     5 2  2 2
+--R             (2a b c  + 10a b c)d x log(x) + (- 11a b c  + 10a b c + a b )d x
+--R           + 
+--R                  6 3     3 4 2     5 2           6 4     3 4 3     5 2 2    7
+--R           (- 3a b c  + 6a b c  - 3a b c)d x + a b c  - 3a b c  + 3a b c  - a c
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R            9 5     2 7 4      4 5 3     6 3 2     8     2 +---+ +-------+
+--R         (2b c  - 8a b c  + 12a b c  - 8a b c  + 2a b c)x \|- c \|d x + c
+--R       + 
+--R              8 5     3 6 4      5 4 3     7 2 2     9   2 +---+
+--R         (2a b c  - 8a b c  + 12a b c  - 8a b c  + 2a c)x \|- c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 615
+
+--S 616 of 619
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                          +-------+              +-+
+--R             5 2      3 3     5   2    2c\|d x + c  + (d x + 2c)\|c
+--R       (15a b c  + 10a b c - a b)d log(-----------------------------)
+--R                                                     x
+--R     + 
+--R                                             +-------+
+--R               5 2      3 3      5   2      \|d x + c
+--R       (- 30a b c  - 20a b c + 2a b)d atanh(----------)
+--R                                                +-+
+--R                                               \|c
+--R  /
+--R        8 5      2 6 4      4 4 3      6 2 2     8   +-+
+--R     (4b c  - 16a b c  + 24a b c  - 16a b c  + 4a c)\|c
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 619
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 619
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                  +-------+
+--R               5 2      3 3     5   2 +---+      \|d x + c
+--R       (- 15a b c  - 10a b c + a b)d \|- c atanh(----------)
+--R                                                     +-+
+--R                                                    \|c
+--R     + 
+--R                                             +---+ +-------+
+--R             5 2      3 3     5   2 +-+     \|- c \|d x + c
+--R       (15a b c  + 10a b c - a b)d \|c atan(----------------)
+--R                                                    c
+--R  /
+--R        8 5     2 6 4      4 4 3     6 2 2     8   +---+ +-+
+--R     (2b c  - 8a b c  + 12a b c  - 8a b c  + 2a c)\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 619
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 619
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich20b.input.pamphlet b/src/input/rich20b.input.pamphlet
new file mode 100644
index 0000000..541462e
--- /dev/null
+++ b/src/input/rich20b.input.pamphlet
@@ -0,0 +1,16806 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich20b.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|y'[x] f[y[x]]|
+There are:
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich20b.output
+)spool rich20b.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 649
+t0:=x^3/sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 649
+r0:=4/3*(a^2-b^2*c)^2*(7*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(3/2)/(b^8*d^4)-_
+   12/5*a*(7*a^2-3*b^2*c)*(a^2-b^2*c)*(a+b*sqrt(c+d*x))^(5/2)/(b^8*d^4)+_
+   4/7*(35*a^4-30*a^2*b^2*c+3*b^4*c^2)*(a+b*sqrt(c+d*x))^(7/2)/(b^8*d^4)-_
+   20/9*a*(7*a^2-3*b^2*c)*(a+b*sqrt(c+d*x))^(9/2)/(b^8*d^4)+_
+   12/11*(7*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(11/2)/(b^8*d^4)-_
+   28/13*a*(a+b*sqrt(c+d*x))^(13/2)/(b^8*d^4)+_
+   4/15*(a+b*sqrt(c+d*x))^(15/2)/(b^8*d^4)-4*a*(a^2-b^2*c)^3*_
+   sqrt(a+b*sqrt(c+d*x))/(b^8*d^4)
+--R 
+--R
+--R   (2)
+--R                   7 3 3            7          2 5  2 2
+--R             12012b d x  + (- 13104b c + 14112a b )d x
+--R           + 
+--R                    7 2         2 5          4 3             7 3         2 5 2
+--R             (14976b c  - 34176a b c + 17920a b )d x - 19968b c  + 75264a b c
+--R           + 
+--R                     4 3          6
+--R             - 81920a b c + 28672a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R                   6 3 3            6          3 4  2 2
+--R         - 12936a b d x  + (15792a b c - 15680a b )d x
+--R       + 
+--R                    6 2         3 4          5 2               6 3
+--R         (- 22272a b c  + 43520a b c - 21504a b )d x + 69120a b c
+--R       + 
+--R                  3 4 2          5 2          7
+--R         - 187904a b c  + 178176a b c - 57344a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R           8 4
+--R     45045b d
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   7 3 3            7          2 5  2 2
+--R             12012b d x  + (- 13104b c + 14112a b )d x
+--R           + 
+--R                    7 2         2 5          4 3             7 3         2 5 2
+--R             (14976b c  - 34176a b c + 17920a b )d x - 19968b c  + 75264a b c
+--R           + 
+--R                     4 3          6
+--R             - 81920a b c + 28672a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R                   6 3 3            6          3 4  2 2
+--R         - 12936a b d x  + (15792a b c - 15680a b )d x
+--R       + 
+--R                    6 2         3 4          5 2               6 3
+--R         (- 22272a b c  + 43520a b c - 21504a b )d x + 69120a b c
+--R       + 
+--R                  3 4 2          5 2          7
+--R         - 187904a b c  + 178176a b c - 57344a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R           8 4
+--R     45045b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 649
+t0:=x^2/sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 649
+r0:=4/3*(5*a^4-6*a^2*b^2*c+b^4*c^2)*(a+b*sqrt(c+d*x))^(3/2)/(b^6*d^3)-_
+   8/5*a*(5*a^2-3*b^2*c)*(a+b*sqrt(c+d*x))^(5/2)/(b^6*d^3)+8/7*(5*a^2-_
+   b^2*c)*(a+b*sqrt(c+d*x))^(7/2)/(b^6*d^3)-20/9*a*(a+b*sqrt(c+d*x))^(9/2)/_
+   (b^6*d^3)+4/11*(a+b*sqrt(c+d*x))^(11/2)/(b^6*d^3)-4*a*(a^2-b^2*c)^2*_
+   sqrt(a+b*sqrt(c+d*x))/(b^6*d^3)
+--R 
+--R
+--R   (2)
+--R                  5 2 2           5         2 3            5 2        2 3
+--R             1260b d x  + (- 1440b c + 1600a b )d x + 1920b c  - 4736a b c
+--R           + 
+--R                  4
+--R             2560a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R                  4 2 2           4         3 2              4 2         3 2
+--R         - 1400a b d x  + (1952a b c - 1920a b )d x - 5888a b c  + 10752a b c
+--R       + 
+--R                5
+--R         - 5120a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R          6 3
+--R     3465b d
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  5 2 2           5         2 3            5 2        2 3
+--R             1260b d x  + (- 1440b c + 1600a b )d x + 1920b c  - 4736a b c
+--R           + 
+--R                  4
+--R             2560a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R                  4 2 2           4         3 2              4 2         3 2
+--R         - 1400a b d x  + (1952a b c - 1920a b )d x - 5888a b c  + 10752a b c
+--R       + 
+--R                5
+--R         - 5120a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R          6 3
+--R     3465b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 649
+t0:=x/sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                 x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 649
+r0:=4/3*(3*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(3/2)/(b^4*d^2)-_
+   12/5*a*(a+b*sqrt(c+d*x))^(5/2)/(b^4*d^2)+4/7*(a+b*sqrt(c+d*x))^(7/2)/_
+   (b^4*d^2)-4*a*(a^2-b^2*c)*sqrt(a+b*sqrt(c+d*x))/(b^4*d^2)
+--R 
+--R
+--R   (2)
+--R            3         3       2   +-------+        2            2        3
+--R       ((60b d x - 80b c + 96a b)\|d x + c  - 72a b d x + 208a b c - 192a )
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R         4 2
+--R     105b d
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3         3       2   +-------+        2            2        3
+--R       ((60b d x - 80b c + 96a b)\|d x + c  - 72a b d x + 208a b c - 192a )
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R         4 2
+--R     105b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 13
+
+--S 14 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 649
+t0:=1/sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 649
+r0:=4/3*(a+b*sqrt(c+d*x))^(3/2)/(b^2*d)-4*a*sqrt(a+b*sqrt(c+d*x))/(b^2*d)
+--R 
+--R
+--R                            +---------------+
+--R            +-------+       |  +-------+
+--R        (4b\|d x + c  - 8a)\|b\|d x + c  + a
+--R   (2)  -------------------------------------
+--R                           2
+--R                         3b d
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            +---------------+
+--R            +-------+       |  +-------+
+--R        (4b\|d x + c  - 8a)\|b\|d x + c  + a
+--R   (3)  -------------------------------------
+--R                           2
+--R                         3b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 649
+t0:=1/(x*sqrt(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R          +---------------+
+--R          |  +-------+
+--R        x\|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 649
+r0:=-2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))/sqrt(a-b*sqrt(c))-_
+   2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a+b*sqrt(c)))/sqrt(a+b*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                             +---------------+
+--R           +---------+       |  +-------+
+--R           |  +-+           \|b\|d x + c  + a
+--R       - 2\|b\|c  + a atanh(------------------)
+--R                               +-----------+
+--R                               |    +-+
+--R                              \|- b\|c  + a
+--R     + 
+--R                               +---------------+
+--R           +-----------+       |  +-------+
+--R           |    +-+           \|b\|d x + c  + a
+--R       - 2\|- b\|c  + a atanh(------------------)
+--R                                  +---------+
+--R                                  |  +-+
+--R                                 \|b\|c  + a
+--R  /
+--R      +-----------+ +---------+
+--R      |    +-+      |  +-+
+--R     \|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +--------------------------------------+
+--R             |             +------------------+
+--R             |             |         2
+--R             |   2      2  |       4b c
+--R             |(2b c - 2a ) |------------------  - 4a
+--R             |             | 4 2     2 2     4
+--R             |            \|b c  - 2a b c + a
+--R             |--------------------------------------
+--R             |                2     2
+--R            \|               b c - a
+--R         *
+--R            log
+--R                   +---------------+
+--R                   |  +-------+
+--R                 4\|b\|d x + c  + a
+--R               + 
+--R                               +------------------+
+--R                               |         2
+--R                      2     2  |       4b c
+--R                   ((b c - a ) |------------------  + 2a)
+--R                               | 4 2     2 2     4
+--R                              \|b c  - 2a b c + a
+--R                *
+--R                    +--------------------------------------+
+--R                    |             +------------------+
+--R                    |             |         2
+--R                    |   2      2  |       4b c
+--R                    |(2b c - 2a ) |------------------  - 4a
+--R                    |             | 4 2     2 2     4
+--R                    |            \|b c  - 2a b c + a
+--R                    |--------------------------------------
+--R                    |                2     2
+--R                   \|               b c - a
+--R     + 
+--R          +----------------------------------------+
+--R          |               +------------------+
+--R          |               |         2
+--R          |     2      2  |       4b c
+--R          |(- 2b c + 2a ) |------------------  - 4a
+--R          |               | 4 2     2 2     4
+--R          |              \|b c  - 2a b c + a
+--R          |----------------------------------------
+--R          |                 2     2
+--R         \|                b c - a
+--R      *
+--R         log
+--R                +---------------+
+--R                |  +-------+
+--R              4\|b\|d x + c  + a
+--R            + 
+--R                            +------------------+
+--R                            |         2
+--R                   2     2  |       4b c
+--R                ((b c - a ) |------------------  - 2a)
+--R                            | 4 2     2 2     4
+--R                           \|b c  - 2a b c + a
+--R             *
+--R                 +----------------------------------------+
+--R                 |               +------------------+
+--R                 |               |         2
+--R                 |     2      2  |       4b c
+--R                 |(- 2b c + 2a ) |------------------  - 4a
+--R                 |               | 4 2     2 2     4
+--R                 |              \|b c  - 2a b c + a
+--R                 |----------------------------------------
+--R                 |                 2     2
+--R                \|                b c - a
+--R     + 
+--R       -
+--R             +----------------------------------------+
+--R             |               +------------------+
+--R             |               |         2
+--R             |     2      2  |       4b c
+--R             |(- 2b c + 2a ) |------------------  - 4a
+--R             |               | 4 2     2 2     4
+--R             |              \|b c  - 2a b c + a
+--R             |----------------------------------------
+--R             |                 2     2
+--R            \|                b c - a
+--R         *
+--R            log
+--R                   +---------------+
+--R                   |  +-------+
+--R                 4\|b\|d x + c  + a
+--R               + 
+--R                                 +------------------+
+--R                                 |         2
+--R                        2     2  |       4b c
+--R                   ((- b c + a ) |------------------  + 2a)
+--R                                 | 4 2     2 2     4
+--R                                \|b c  - 2a b c + a
+--R                *
+--R                    +----------------------------------------+
+--R                    |               +------------------+
+--R                    |               |         2
+--R                    |     2      2  |       4b c
+--R                    |(- 2b c + 2a ) |------------------  - 4a
+--R                    |               | 4 2     2 2     4
+--R                    |              \|b c  - 2a b c + a
+--R                    |----------------------------------------
+--R                    |                 2     2
+--R                   \|                b c - a
+--R     + 
+--R          +--------------------------------------+
+--R          |             +------------------+
+--R          |             |         2
+--R          |   2      2  |       4b c
+--R          |(2b c - 2a ) |------------------  - 4a
+--R          |             | 4 2     2 2     4
+--R          |            \|b c  - 2a b c + a
+--R          |--------------------------------------
+--R          |                2     2
+--R         \|               b c - a
+--R      *
+--R         log
+--R                +---------------+
+--R                |  +-------+
+--R              4\|b\|d x + c  + a
+--R            + 
+--R                              +------------------+
+--R                              |         2
+--R                     2     2  |       4b c
+--R                ((- b c + a ) |------------------  - 2a)
+--R                              | 4 2     2 2     4
+--R                             \|b c  - 2a b c + a
+--R             *
+--R                 +--------------------------------------+
+--R                 |             +------------------+
+--R                 |             |         2
+--R                 |   2      2  |       4b c
+--R                 |(2b c - 2a ) |------------------  - 4a
+--R                 |             | 4 2     2 2     4
+--R                 |            \|b c  - 2a b c + a
+--R                 |--------------------------------------
+--R                 |                2     2
+--R                \|               b c - a
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 23
+
+--S 24 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                           +--------------------------------------+
+--R                           |             +------------------+
+--R                           |             |         2
+--R                           |   2      2  |       4b c
+--R                           |(2b c - 2a ) |------------------  - 4a
+--R             +-----------+ |             | 4 2     2 2     4        +---------+
+--R             |    +-+      |            \|b c  - 2a b c + a         |  +-+
+--R            \|- b\|c  + a  |-------------------------------------- \|b\|c  + a
+--R                           |                2     2
+--R                          \|               b c - a
+--R         *
+--R            log
+--R                   +---------------+
+--R                   |  +-------+
+--R                 4\|b\|d x + c  + a
+--R               + 
+--R                               +------------------+
+--R                               |         2
+--R                      2     2  |       4b c
+--R                   ((b c - a ) |------------------  + 2a)
+--R                               | 4 2     2 2     4
+--R                              \|b c  - 2a b c + a
+--R                *
+--R                    +--------------------------------------+
+--R                    |             +------------------+
+--R                    |             |         2
+--R                    |   2      2  |       4b c
+--R                    |(2b c - 2a ) |------------------  - 4a
+--R                    |             | 4 2     2 2     4
+--R                    |            \|b c  - 2a b c + a
+--R                    |--------------------------------------
+--R                    |                2     2
+--R                   \|               b c - a
+--R     + 
+--R                        +----------------------------------------+
+--R                        |               +------------------+
+--R                        |               |         2
+--R                        |     2      2  |       4b c
+--R                        |(- 2b c + 2a ) |------------------  - 4a
+--R          +-----------+ |               | 4 2     2 2     4        +---------+
+--R          |    +-+      |              \|b c  - 2a b c + a         |  +-+
+--R         \|- b\|c  + a  |---------------------------------------- \|b\|c  + a
+--R                        |                 2     2
+--R                       \|                b c - a
+--R      *
+--R         log
+--R                +---------------+
+--R                |  +-------+
+--R              4\|b\|d x + c  + a
+--R            + 
+--R                            +------------------+
+--R                            |         2
+--R                   2     2  |       4b c
+--R                ((b c - a ) |------------------  - 2a)
+--R                            | 4 2     2 2     4
+--R                           \|b c  - 2a b c + a
+--R             *
+--R                 +----------------------------------------+
+--R                 |               +------------------+
+--R                 |               |         2
+--R                 |     2      2  |       4b c
+--R                 |(- 2b c + 2a ) |------------------  - 4a
+--R                 |               | 4 2     2 2     4
+--R                 |              \|b c  - 2a b c + a
+--R                 |----------------------------------------
+--R                 |                 2     2
+--R                \|                b c - a
+--R     + 
+--R       -
+--R                           +----------------------------------------+
+--R                           |               +------------------+
+--R                           |               |         2
+--R                           |     2      2  |       4b c
+--R                           |(- 2b c + 2a ) |------------------  - 4a
+--R             +-----------+ |               | 4 2     2 2     4
+--R             |    +-+      |              \|b c  - 2a b c + a
+--R            \|- b\|c  + a  |----------------------------------------
+--R                           |                 2     2
+--R                          \|                b c - a
+--R         *
+--R             +---------+
+--R             |  +-+
+--R            \|b\|c  + a
+--R         *
+--R            log
+--R                   +---------------+
+--R                   |  +-------+
+--R                 4\|b\|d x + c  + a
+--R               + 
+--R                                 +------------------+
+--R                                 |         2
+--R                        2     2  |       4b c
+--R                   ((- b c + a ) |------------------  + 2a)
+--R                                 | 4 2     2 2     4
+--R                                \|b c  - 2a b c + a
+--R                *
+--R                    +----------------------------------------+
+--R                    |               +------------------+
+--R                    |               |         2
+--R                    |     2      2  |       4b c
+--R                    |(- 2b c + 2a ) |------------------  - 4a
+--R                    |               | 4 2     2 2     4
+--R                    |              \|b c  - 2a b c + a
+--R                    |----------------------------------------
+--R                    |                 2     2
+--R                   \|                b c - a
+--R     + 
+--R                        +--------------------------------------+
+--R                        |             +------------------+
+--R                        |             |         2
+--R                        |   2      2  |       4b c
+--R                        |(2b c - 2a ) |------------------  - 4a
+--R          +-----------+ |             | 4 2     2 2     4        +---------+
+--R          |    +-+      |            \|b c  - 2a b c + a         |  +-+
+--R         \|- b\|c  + a  |-------------------------------------- \|b\|c  + a
+--R                        |                2     2
+--R                       \|               b c - a
+--R      *
+--R         log
+--R                +---------------+
+--R                |  +-------+
+--R              4\|b\|d x + c  + a
+--R            + 
+--R                              +------------------+
+--R                              |         2
+--R                     2     2  |       4b c
+--R                ((- b c + a ) |------------------  - 2a)
+--R                              | 4 2     2 2     4
+--R                             \|b c  - 2a b c + a
+--R             *
+--R                 +--------------------------------------+
+--R                 |             +------------------+
+--R                 |             |         2
+--R                 |   2      2  |       4b c
+--R                 |(2b c - 2a ) |------------------  - 4a
+--R                 |             | 4 2     2 2     4
+--R                 |            \|b c  - 2a b c + a
+--R                 |--------------------------------------
+--R                 |                2     2
+--R                \|               b c - a
+--R     + 
+--R                           +---------------+
+--R         +---------+       |  +-------+
+--R         |  +-+           \|b\|d x + c  + a
+--R       4\|b\|c  + a atanh(------------------)
+--R                             +-----------+
+--R                             |    +-+
+--R                            \|- b\|c  + a
+--R     + 
+--R                             +---------------+
+--R         +-----------+       |  +-------+
+--R         |    +-+           \|b\|d x + c  + a
+--R       4\|- b\|c  + a atanh(------------------)
+--R                                +---------+
+--R                                |  +-+
+--R                               \|b\|c  + a
+--R  /
+--R       +-----------+ +---------+
+--R       |    +-+      |  +-+
+--R     2\|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 25
+
+)clear all
+
+--S 26 of 649
+t0:=1/(x^2*sqrt(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         2 |  +-------+
+--R        x \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 649
+r0:=-1/2*b*d*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))/(sqrt(c)*_
+   (a-b*sqrt(c))^(3/2))+1/2*b*d*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a+b*_
+   sqrt(c)))/(sqrt(c)*(a+b*sqrt(c))^(3/2))-(a-b*sqrt(c+d*x))*_
+   sqrt(a+b*sqrt(c+d*x))/((a^2-b^2*c)*x)
+--R 
+--R
+--R   (2)
+--R                                                 +---------------+
+--R                               +---------+       |  +-------+
+--R                +-+    2       |  +-+           \|b\|d x + c  + a
+--R       (a b d x\|c  + b c d x)\|b\|c  + a atanh(------------------)
+--R                                                   +-----------+
+--R                                                   |    +-+
+--R                                                  \|- b\|c  + a
+--R     + 
+--R                                                     +---------------+
+--R                                 +-----------+       |  +-------+
+--R                  +-+    2       |    +-+           \|b\|d x + c  + a
+--R       (- a b d x\|c  + b c d x)\|- b\|c  + a atanh(------------------)
+--R                                                        +---------+
+--R                                                        |  +-+
+--R                                                       \|b\|c  + a
+--R     + 
+--R                                 +-----------+ +---------+ +---------------+
+--R               +-------+         |    +-+      |  +-+      |  +-------+
+--R       (- 2b c\|d x + c  + 2a c)\|- b\|c  + a \|b\|c  + a \|b\|d x + c  + a
+--R  /
+--R                     +-----------+ +---------+
+--R        2 2     2    |    +-+      |  +-+
+--R     (2b c  - 2a c)x\|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2     2
+--R         (b c - a )x
+--R      *
+--R         ROOT
+--R                     6 4      2 4 3      4 2 2     6
+--R                  (8b c  - 24a b c  + 24a b c  - 8a c)
+--R               *
+--R                  ROOT
+--R                         10 2     2 8      4 6  4
+--R                       (b  c  + 6a b c + 9a b )d
+--R                    /
+--R                            12 7       2 10 6       4 8 5        6 6 4
+--R                         64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                       + 
+--R                             8 4 3       10 2 2      12
+--R                         960a b c  - 384a  b c  + 64a  c
+--R              + 
+--R                       4     3 2  2
+--R                (- 3a b c - a b )d
+--R           /
+--R                6 4      2 4 3      4 2 2     6
+--R              4b c  - 12a b c  + 12a b c  - 4a c
+--R      *
+--R         log
+--R                              +---------------+
+--R                6      2 4  3 |  +-------+
+--R              (b c + 3a b )d \|b\|d x + c  + a
+--R            + 
+--R                        8 5      2 6 4      6 2 2      8
+--R                    (16b c  - 32a b c  + 32a b c  - 16a c)
+--R                 *
+--R                    ROOT
+--R                           10 2     2 8      4 6  4
+--R                         (b  c  + 6a b c + 9a b )d
+--R                      /
+--R                              12 7       2 10 6       4 8 5        6 6 4
+--R                           64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                         + 
+--R                               8 4 3       10 2 2      12
+--R                           960a b c  - 384a  b c  + 64a  c
+--R                + 
+--R                       6 2      3 4   2
+--R                  (4a b c  + 12a b c)d
+--R             *
+--R                ROOT
+--R                            6 4      2 4 3      4 2 2     6
+--R                         (8b c  - 24a b c  + 24a b c  - 8a c)
+--R                      *
+--R                         ROOT
+--R                                10 2     2 8      4 6  4
+--R                              (b  c  + 6a b c + 9a b )d
+--R                           /
+--R                                   12 7       2 10 6       4 8 5        6 6 4
+--R                                64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                              + 
+--R                                    8 4 3       10 2 2      12
+--R                                960a b c  - 384a  b c  + 64a  c
+--R                     + 
+--R                              4     3 2  2
+--R                       (- 3a b c - a b )d
+--R                  /
+--R                       6 4      2 4 3      4 2 2     6
+--R                     4b c  - 12a b c  + 12a b c  - 4a c
+--R     + 
+--R             2     2
+--R         (- b c + a )x
+--R      *
+--R         ROOT
+--R                       6 4      2 4 3      4 2 2     6
+--R                  (- 8b c  + 24a b c  - 24a b c  + 8a c)
+--R               *
+--R                  ROOT
+--R                         10 2     2 8      4 6  4
+--R                       (b  c  + 6a b c + 9a b )d
+--R                    /
+--R                            12 7       2 10 6       4 8 5        6 6 4
+--R                         64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                       + 
+--R                             8 4 3       10 2 2      12
+--R                         960a b c  - 384a  b c  + 64a  c
+--R              + 
+--R                       4     3 2  2
+--R                (- 3a b c - a b )d
+--R           /
+--R                6 4      2 4 3      4 2 2     6
+--R              4b c  - 12a b c  + 12a b c  - 4a c
+--R      *
+--R         log
+--R                              +---------------+
+--R                6      2 4  3 |  +-------+
+--R              (b c + 3a b )d \|b\|d x + c  + a
+--R            + 
+--R                        8 5      2 6 4      6 2 2      8
+--R                    (16b c  - 32a b c  + 32a b c  - 16a c)
+--R                 *
+--R                    ROOT
+--R                           10 2     2 8      4 6  4
+--R                         (b  c  + 6a b c + 9a b )d
+--R                      /
+--R                              12 7       2 10 6       4 8 5        6 6 4
+--R                           64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                         + 
+--R                               8 4 3       10 2 2      12
+--R                           960a b c  - 384a  b c  + 64a  c
+--R                + 
+--R                         6 2      3 4   2
+--R                  (- 4a b c  - 12a b c)d
+--R             *
+--R                ROOT
+--R                              6 4      2 4 3      4 2 2     6
+--R                         (- 8b c  + 24a b c  - 24a b c  + 8a c)
+--R                      *
+--R                         ROOT
+--R                                10 2     2 8      4 6  4
+--R                              (b  c  + 6a b c + 9a b )d
+--R                           /
+--R                                   12 7       2 10 6       4 8 5        6 6 4
+--R                                64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                              + 
+--R                                    8 4 3       10 2 2      12
+--R                                960a b c  - 384a  b c  + 64a  c
+--R                     + 
+--R                              4     3 2  2
+--R                       (- 3a b c - a b )d
+--R                  /
+--R                       6 4      2 4 3      4 2 2     6
+--R                     4b c  - 12a b c  + 12a b c  - 4a c
+--R     + 
+--R           2     2
+--R         (b c - a )x
+--R      *
+--R         ROOT
+--R                       6 4      2 4 3      4 2 2     6
+--R                  (- 8b c  + 24a b c  - 24a b c  + 8a c)
+--R               *
+--R                  ROOT
+--R                         10 2     2 8      4 6  4
+--R                       (b  c  + 6a b c + 9a b )d
+--R                    /
+--R                            12 7       2 10 6       4 8 5        6 6 4
+--R                         64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                       + 
+--R                             8 4 3       10 2 2      12
+--R                         960a b c  - 384a  b c  + 64a  c
+--R              + 
+--R                       4     3 2  2
+--R                (- 3a b c - a b )d
+--R           /
+--R                6 4      2 4 3      4 2 2     6
+--R              4b c  - 12a b c  + 12a b c  - 4a c
+--R      *
+--R         log
+--R                              +---------------+
+--R                6      2 4  3 |  +-------+
+--R              (b c + 3a b )d \|b\|d x + c  + a
+--R            + 
+--R                          8 5      2 6 4      6 2 2      8
+--R                    (- 16b c  + 32a b c  - 32a b c  + 16a c)
+--R                 *
+--R                    ROOT
+--R                           10 2     2 8      4 6  4
+--R                         (b  c  + 6a b c + 9a b )d
+--R                      /
+--R                              12 7       2 10 6       4 8 5        6 6 4
+--R                           64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                         + 
+--R                               8 4 3       10 2 2      12
+--R                           960a b c  - 384a  b c  + 64a  c
+--R                + 
+--R                       6 2      3 4   2
+--R                  (4a b c  + 12a b c)d
+--R             *
+--R                ROOT
+--R                              6 4      2 4 3      4 2 2     6
+--R                         (- 8b c  + 24a b c  - 24a b c  + 8a c)
+--R                      *
+--R                         ROOT
+--R                                10 2     2 8      4 6  4
+--R                              (b  c  + 6a b c + 9a b )d
+--R                           /
+--R                                   12 7       2 10 6       4 8 5        6 6 4
+--R                                64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                              + 
+--R                                    8 4 3       10 2 2      12
+--R                                960a b c  - 384a  b c  + 64a  c
+--R                     + 
+--R                              4     3 2  2
+--R                       (- 3a b c - a b )d
+--R                  /
+--R                       6 4      2 4 3      4 2 2     6
+--R                     4b c  - 12a b c  + 12a b c  - 4a c
+--R     + 
+--R             2     2
+--R         (- b c + a )x
+--R      *
+--R         ROOT
+--R                     6 4      2 4 3      4 2 2     6
+--R                  (8b c  - 24a b c  + 24a b c  - 8a c)
+--R               *
+--R                  ROOT
+--R                         10 2     2 8      4 6  4
+--R                       (b  c  + 6a b c + 9a b )d
+--R                    /
+--R                            12 7       2 10 6       4 8 5        6 6 4
+--R                         64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                       + 
+--R                             8 4 3       10 2 2      12
+--R                         960a b c  - 384a  b c  + 64a  c
+--R              + 
+--R                       4     3 2  2
+--R                (- 3a b c - a b )d
+--R           /
+--R                6 4      2 4 3      4 2 2     6
+--R              4b c  - 12a b c  + 12a b c  - 4a c
+--R      *
+--R         log
+--R                              +---------------+
+--R                6      2 4  3 |  +-------+
+--R              (b c + 3a b )d \|b\|d x + c  + a
+--R            + 
+--R                          8 5      2 6 4      6 2 2      8
+--R                    (- 16b c  + 32a b c  - 32a b c  + 16a c)
+--R                 *
+--R                    ROOT
+--R                           10 2     2 8      4 6  4
+--R                         (b  c  + 6a b c + 9a b )d
+--R                      /
+--R                              12 7       2 10 6       4 8 5        6 6 4
+--R                           64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                         + 
+--R                               8 4 3       10 2 2      12
+--R                           960a b c  - 384a  b c  + 64a  c
+--R                + 
+--R                         6 2      3 4   2
+--R                  (- 4a b c  - 12a b c)d
+--R             *
+--R                ROOT
+--R                            6 4      2 4 3      4 2 2     6
+--R                         (8b c  - 24a b c  + 24a b c  - 8a c)
+--R                      *
+--R                         ROOT
+--R                                10 2     2 8      4 6  4
+--R                              (b  c  + 6a b c + 9a b )d
+--R                           /
+--R                                   12 7       2 10 6       4 8 5        6 6 4
+--R                                64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                              + 
+--R                                    8 4 3       10 2 2      12
+--R                                960a b c  - 384a  b c  + 64a  c
+--R                     + 
+--R                              4     3 2  2
+--R                       (- 3a b c - a b )d
+--R                  /
+--R                       6 4      2 4 3      4 2 2     6
+--R                     4b c  - 12a b c  + 12a b c  - 4a c
+--R     + 
+--R                             +---------------+
+--R             +-------+       |  +-------+
+--R       (- 2b\|d x + c  + 2a)\|b\|d x + c  + a
+--R  /
+--R        2      2
+--R     (2b c - 2a )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 28
+
+--S 29 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +-----------+ +---------+
+--R           2 2    2   |    +-+      |  +-+
+--R         (b c  - a c)\|- b\|c  + a \|b\|c  + a
+--R      *
+--R         ROOT
+--R                     6 4      2 4 3      4 2 2     6
+--R                  (8b c  - 24a b c  + 24a b c  - 8a c)
+--R               *
+--R                  ROOT
+--R                         10 2     2 8      4 6  4
+--R                       (b  c  + 6a b c + 9a b )d
+--R                    /
+--R                            12 7       2 10 6       4 8 5        6 6 4
+--R                         64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                       + 
+--R                             8 4 3       10 2 2      12
+--R                         960a b c  - 384a  b c  + 64a  c
+--R              + 
+--R                       4     3 2  2
+--R                (- 3a b c - a b )d
+--R           /
+--R                6 4      2 4 3      4 2 2     6
+--R              4b c  - 12a b c  + 12a b c  - 4a c
+--R      *
+--R         log
+--R                              +---------------+
+--R                6      2 4  3 |  +-------+
+--R              (b c + 3a b )d \|b\|d x + c  + a
+--R            + 
+--R                        8 5      2 6 4      6 2 2      8
+--R                    (16b c  - 32a b c  + 32a b c  - 16a c)
+--R                 *
+--R                    ROOT
+--R                           10 2     2 8      4 6  4
+--R                         (b  c  + 6a b c + 9a b )d
+--R                      /
+--R                              12 7       2 10 6       4 8 5        6 6 4
+--R                           64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                         + 
+--R                               8 4 3       10 2 2      12
+--R                           960a b c  - 384a  b c  + 64a  c
+--R                + 
+--R                       6 2      3 4   2
+--R                  (4a b c  + 12a b c)d
+--R             *
+--R                ROOT
+--R                            6 4      2 4 3      4 2 2     6
+--R                         (8b c  - 24a b c  + 24a b c  - 8a c)
+--R                      *
+--R                         ROOT
+--R                                10 2     2 8      4 6  4
+--R                              (b  c  + 6a b c + 9a b )d
+--R                           /
+--R                                   12 7       2 10 6       4 8 5        6 6 4
+--R                                64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                              + 
+--R                                    8 4 3       10 2 2      12
+--R                                960a b c  - 384a  b c  + 64a  c
+--R                     + 
+--R                              4     3 2  2
+--R                       (- 3a b c - a b )d
+--R                  /
+--R                       6 4      2 4 3      4 2 2     6
+--R                     4b c  - 12a b c  + 12a b c  - 4a c
+--R     + 
+--R             2 2    2
+--R         (- b c  + a c)
+--R      *
+--R         ROOT
+--R                       6 4      2 4 3      4 2 2     6
+--R                  (- 8b c  + 24a b c  - 24a b c  + 8a c)
+--R               *
+--R                  ROOT
+--R                         10 2     2 8      4 6  4
+--R                       (b  c  + 6a b c + 9a b )d
+--R                    /
+--R                            12 7       2 10 6       4 8 5        6 6 4
+--R                         64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                       + 
+--R                             8 4 3       10 2 2      12
+--R                         960a b c  - 384a  b c  + 64a  c
+--R              + 
+--R                       4     3 2  2
+--R                (- 3a b c - a b )d
+--R           /
+--R                6 4      2 4 3      4 2 2     6
+--R              4b c  - 12a b c  + 12a b c  - 4a c
+--R      *
+--R          +-----------+ +---------+
+--R          |    +-+      |  +-+
+--R         \|- b\|c  + a \|b\|c  + a
+--R      *
+--R         log
+--R                              +---------------+
+--R                6      2 4  3 |  +-------+
+--R              (b c + 3a b )d \|b\|d x + c  + a
+--R            + 
+--R                        8 5      2 6 4      6 2 2      8
+--R                    (16b c  - 32a b c  + 32a b c  - 16a c)
+--R                 *
+--R                    ROOT
+--R                           10 2     2 8      4 6  4
+--R                         (b  c  + 6a b c + 9a b )d
+--R                      /
+--R                              12 7       2 10 6       4 8 5        6 6 4
+--R                           64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                         + 
+--R                               8 4 3       10 2 2      12
+--R                           960a b c  - 384a  b c  + 64a  c
+--R                + 
+--R                         6 2      3 4   2
+--R                  (- 4a b c  - 12a b c)d
+--R             *
+--R                ROOT
+--R                              6 4      2 4 3      4 2 2     6
+--R                         (- 8b c  + 24a b c  - 24a b c  + 8a c)
+--R                      *
+--R                         ROOT
+--R                                10 2     2 8      4 6  4
+--R                              (b  c  + 6a b c + 9a b )d
+--R                           /
+--R                                   12 7       2 10 6       4 8 5        6 6 4
+--R                                64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                              + 
+--R                                    8 4 3       10 2 2      12
+--R                                960a b c  - 384a  b c  + 64a  c
+--R                     + 
+--R                              4     3 2  2
+--R                       (- 3a b c - a b )d
+--R                  /
+--R                       6 4      2 4 3      4 2 2     6
+--R                     4b c  - 12a b c  + 12a b c  - 4a c
+--R     + 
+--R           2 2    2
+--R         (b c  - a c)
+--R      *
+--R         ROOT
+--R                       6 4      2 4 3      4 2 2     6
+--R                  (- 8b c  + 24a b c  - 24a b c  + 8a c)
+--R               *
+--R                  ROOT
+--R                         10 2     2 8      4 6  4
+--R                       (b  c  + 6a b c + 9a b )d
+--R                    /
+--R                            12 7       2 10 6       4 8 5        6 6 4
+--R                         64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                       + 
+--R                             8 4 3       10 2 2      12
+--R                         960a b c  - 384a  b c  + 64a  c
+--R              + 
+--R                       4     3 2  2
+--R                (- 3a b c - a b )d
+--R           /
+--R                6 4      2 4 3      4 2 2     6
+--R              4b c  - 12a b c  + 12a b c  - 4a c
+--R      *
+--R          +-----------+ +---------+
+--R          |    +-+      |  +-+
+--R         \|- b\|c  + a \|b\|c  + a
+--R      *
+--R         log
+--R                              +---------------+
+--R                6      2 4  3 |  +-------+
+--R              (b c + 3a b )d \|b\|d x + c  + a
+--R            + 
+--R                          8 5      2 6 4      6 2 2      8
+--R                    (- 16b c  + 32a b c  - 32a b c  + 16a c)
+--R                 *
+--R                    ROOT
+--R                           10 2     2 8      4 6  4
+--R                         (b  c  + 6a b c + 9a b )d
+--R                      /
+--R                              12 7       2 10 6       4 8 5        6 6 4
+--R                           64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                         + 
+--R                               8 4 3       10 2 2      12
+--R                           960a b c  - 384a  b c  + 64a  c
+--R                + 
+--R                       6 2      3 4   2
+--R                  (4a b c  + 12a b c)d
+--R             *
+--R                ROOT
+--R                              6 4      2 4 3      4 2 2     6
+--R                         (- 8b c  + 24a b c  - 24a b c  + 8a c)
+--R                      *
+--R                         ROOT
+--R                                10 2     2 8      4 6  4
+--R                              (b  c  + 6a b c + 9a b )d
+--R                           /
+--R                                   12 7       2 10 6       4 8 5        6 6 4
+--R                                64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                              + 
+--R                                    8 4 3       10 2 2      12
+--R                                960a b c  - 384a  b c  + 64a  c
+--R                     + 
+--R                              4     3 2  2
+--R                       (- 3a b c - a b )d
+--R                  /
+--R                       6 4      2 4 3      4 2 2     6
+--R                     4b c  - 12a b c  + 12a b c  - 4a c
+--R     + 
+--R                        +-----------+ +---------+
+--R             2 2    2   |    +-+      |  +-+
+--R         (- b c  + a c)\|- b\|c  + a \|b\|c  + a
+--R      *
+--R         ROOT
+--R                     6 4      2 4 3      4 2 2     6
+--R                  (8b c  - 24a b c  + 24a b c  - 8a c)
+--R               *
+--R                  ROOT
+--R                         10 2     2 8      4 6  4
+--R                       (b  c  + 6a b c + 9a b )d
+--R                    /
+--R                            12 7       2 10 6       4 8 5        6 6 4
+--R                         64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                       + 
+--R                             8 4 3       10 2 2      12
+--R                         960a b c  - 384a  b c  + 64a  c
+--R              + 
+--R                       4     3 2  2
+--R                (- 3a b c - a b )d
+--R           /
+--R                6 4      2 4 3      4 2 2     6
+--R              4b c  - 12a b c  + 12a b c  - 4a c
+--R      *
+--R         log
+--R                              +---------------+
+--R                6      2 4  3 |  +-------+
+--R              (b c + 3a b )d \|b\|d x + c  + a
+--R            + 
+--R                          8 5      2 6 4      6 2 2      8
+--R                    (- 16b c  + 32a b c  - 32a b c  + 16a c)
+--R                 *
+--R                    ROOT
+--R                           10 2     2 8      4 6  4
+--R                         (b  c  + 6a b c + 9a b )d
+--R                      /
+--R                              12 7       2 10 6       4 8 5        6 6 4
+--R                           64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                         + 
+--R                               8 4 3       10 2 2      12
+--R                           960a b c  - 384a  b c  + 64a  c
+--R                + 
+--R                         6 2      3 4   2
+--R                  (- 4a b c  - 12a b c)d
+--R             *
+--R                ROOT
+--R                            6 4      2 4 3      4 2 2     6
+--R                         (8b c  - 24a b c  + 24a b c  - 8a c)
+--R                      *
+--R                         ROOT
+--R                                10 2     2 8      4 6  4
+--R                              (b  c  + 6a b c + 9a b )d
+--R                           /
+--R                                   12 7       2 10 6       4 8 5        6 6 4
+--R                                64b  c  - 384a b  c  + 960a b c  - 1280a b c
+--R                              + 
+--R                                    8 4 3       10 2 2      12
+--R                                960a b c  - 384a  b c  + 64a  c
+--R                     + 
+--R                              4     3 2  2
+--R                       (- 3a b c - a b )d
+--R                  /
+--R                       6 4      2 4 3      4 2 2     6
+--R                     4b c  - 12a b c  + 12a b c  - 4a c
+--R     + 
+--R                                               +---------------+
+--R                             +---------+       |  +-------+
+--R                +-+    2     |  +-+           \|b\|d x + c  + a
+--R       (- a b d\|c  - b c d)\|b\|c  + a atanh(------------------)
+--R                                                 +-----------+
+--R                                                 |    +-+
+--R                                                \|- b\|c  + a
+--R     + 
+--R                                               +---------------+
+--R                           +-----------+       |  +-------+
+--R              +-+    2     |    +-+           \|b\|d x + c  + a
+--R       (a b d\|c  - b c d)\|- b\|c  + a atanh(------------------)
+--R                                                  +---------+
+--R                                                  |  +-+
+--R                                                 \|b\|c  + a
+--R  /
+--R                    +-----------+ +---------+
+--R        2 2     2   |    +-+      |  +-+
+--R     (2b c  - 2a c)\|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 649
+t0:=1/(x^3*sqrt(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         3 |  +-------+
+--R        x \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 649
+r0:=1/16*b*d^2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))*_
+   (2*a-5*b*sqrt(c))/(c^(3/2)*(a-b*sqrt(c))^(5/2))-1/16*b*d^2*_
+   atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a+b*sqrt(c)))*(2*a+5*b*sqrt(c))/_
+   (c^(3/2)*(a+b*sqrt(c))^(5/2))-1/2*(a-b*sqrt(c+d*x))*sqrt(a+b*_
+   sqrt(c+d*x))/((a^2-b^2*c)*x^2)-1/8*b*d*(6*a*b*c-(a^2+5*b^2*c)*_
+   sqrt(c+d*x))*sqrt(a+b*sqrt(c+d*x))/(c*(a^2-b^2*c)^2*x)
+--R 
+--R
+--R   (2)
+--R                                                             +---------+
+--R                 3      3   2 2 +-+        4 2    2 2   2 2  |  +-+
+--R         ((- 8a b c + 2a b)d x \|c  + (- 5b c  - a b c)d x )\|b\|c  + a
+--R      *
+--R                +---------------+
+--R                |  +-------+
+--R               \|b\|d x + c  + a
+--R         atanh(------------------)
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- b\|c  + a
+--R     + 
+--R                                                           +-----------+
+--R               3      3   2 2 +-+        4 2    2 2   2 2  |    +-+
+--R         ((8a b c - 2a b)d x \|c  + (- 5b c  - a b c)d x )\|- b\|c  + a
+--R      *
+--R                +---------------+
+--R                |  +-------+
+--R               \|b\|d x + c  + a
+--R         atanh(------------------)
+--R                   +---------+
+--R                   |  +-+
+--R                  \|b\|c  + a
+--R     + 
+--R                3 2     2            3 3     2   2  +-------+        2 2
+--R           ((10b c  + 2a b c)d x - 8b c  + 8a b c )\|d x + c  - 12a b c d x
+--R         + 
+--R               2 3     3 2
+--R           8a b c  - 8a c
+--R      *
+--R          +-----------+ +---------+ +---------------+
+--R          |    +-+      |  +-+      |  +-------+
+--R         \|- b\|c  + a \|b\|c  + a \|b\|d x + c  + a
+--R  /
+--R                                    +-----------+ +---------+
+--R         4 4      2 2 3      4 2  2 |    +-+      |  +-+
+--R     (16b c  - 32a b c  + 16a c )x \|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              4 3     2 2 2     4   2
+--R         (- 4b c  + 8a b c  - 4a c)x
+--R      *
+--R         ROOT
+--R                        10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                    512b  c  - 2560a b c  + 5120a b c  - 5120a b c  + 2560a b c
+--R                  + 
+--R                          10 3
+--R                    - 512a  c
+--R               *
+--R                  ROOT
+--R                               18 4        2 16 3         4 14 2         6 12
+--R                           625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                         + 
+--R                                8 10
+--R                           1225a b
+--R                      *
+--R                          8
+--R                         d
+--R                    /
+--R                                20 13           2 18 12            4 16 11
+--R                         262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                       + 
+--R                                    6 14 10            8 12 9            10 10 8
+--R                         - 31457280a b  c   + 55050240a b  c  - 66060288a  b  c
+--R                       + 
+--R                                  12 8 7            14 6 6            16 4 5
+--R                         55050240a  b c  - 31457280a  b c  + 11796480a  b c
+--R                       + 
+--R                                   18 2 4          20 3
+--R                         - 2621440a  b c  + 262144a  c
+--R              + 
+--R                         8 3      3 6 2      5 4      7 2  4
+--R                (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R           /
+--R                    10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                256b  c  - 1280a b c  + 2560a b c  - 2560a b c  + 1280a b c
+--R              + 
+--R                      10 3
+--R                - 256a  c
+--R      *
+--R         log
+--R                                                               +---------------+
+--R                   12 3        2 10 2        4 8        6 6  6 |  +-------+
+--R              (625b  c  + 3750a b  c  - 1491a b c + 140a b )d \|b\|d x + c  + a
+--R            + 
+--R                            14 10          2 12 9         4 10 8          6 8 7
+--R                      40960b  c   - 131072a b  c  + 24576a b  c  + 409600a b c
+--R                    + 
+--R                             8 6 6          10 4 5          12 2 4         14 3
+--R                    - 696320a b c  + 491520a  b c  - 155648a  b c  + 16384a  c
+--R                 *
+--R                    ROOT
+--R                                 18 4        2 16 3         4 14 2         6 12
+--R                             625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                           + 
+--R                                  8 10
+--R                             1225a b
+--R                        *
+--R                            8
+--R                           d
+--R                      /
+--R                                  20 13           2 18 12            4 16 11
+--R                           262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                         + 
+--R                                      6 14 10            8 12 9
+--R                           - 31457280a b  c   + 55050240a b  c
+--R                         + 
+--R                                      10 10 8            12 8 7
+--R                           - 66060288a  b  c  + 55050240a  b c
+--R                         + 
+--R                                      14 6 6            16 4 5           18 2 4
+--R                           - 31457280a  b c  + 11796480a  b c  - 2621440a  b c
+--R                         + 
+--R                                  20 3
+--R                           262144a  c
+--R                + 
+--R                          12 5         3 10 4        5 8 3       7 6 2  4
+--R                  (5200a b  c  + 31632a b  c  - 9744a b c  + 560a b c )d
+--R             *
+--R                ROOT
+--R                               10 8        2 8 7        4 6 6        6 4 5
+--R                           512b  c  - 2560a b c  + 5120a b c  - 5120a b c
+--R                         + 
+--R                                8 2 4       10 3
+--R                           2560a b c  - 512a  c
+--R                      *
+--R                         ROOT
+--R                                      18 4        2 16 3         4 14 2
+--R                                  625b  c  + 7700a b  c  + 21966a b  c
+--R                                + 
+--R                                          6 12         8 10
+--R                                  - 10780a b  c + 1225a b
+--R                             *
+--R                                 8
+--R                                d
+--R                           /
+--R                                       20 13           2 18 12
+--R                                262144b  c   - 2621440a b  c
+--R                              + 
+--R                                         4 16 11            6 14 10
+--R                                11796480a b  c   - 31457280a b  c
+--R                              + 
+--R                                         8 12 9            10 10 8
+--R                                55050240a b  c  - 66060288a  b  c
+--R                              + 
+--R                                         12 8 7            14 6 6
+--R                                55050240a  b c  - 31457280a  b c
+--R                              + 
+--R                                         16 4 5           18 2 4          20 3
+--R                                11796480a  b c  - 2621440a  b c  + 262144a  c
+--R                     + 
+--R                                8 3      3 6 2      5 4      7 2  4
+--R                       (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R                  /
+--R                           10 8        2 8 7        4 6 6        6 4 5
+--R                       256b  c  - 1280a b c  + 2560a b c  - 2560a b c
+--R                     + 
+--R                            8 2 4       10 3
+--R                       1280a b c  - 256a  c
+--R     + 
+--R            4 3     2 2 2     4   2
+--R         (4b c  - 8a b c  + 4a c)x
+--R      *
+--R         ROOT
+--R                          10 8        2 8 7        4 6 6        6 4 5
+--R                    - 512b  c  + 2560a b c  - 5120a b c  + 5120a b c
+--R                  + 
+--R                           8 2 4       10 3
+--R                    - 2560a b c  + 512a  c
+--R               *
+--R                  ROOT
+--R                               18 4        2 16 3         4 14 2         6 12
+--R                           625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                         + 
+--R                                8 10
+--R                           1225a b
+--R                      *
+--R                          8
+--R                         d
+--R                    /
+--R                                20 13           2 18 12            4 16 11
+--R                         262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                       + 
+--R                                    6 14 10            8 12 9            10 10 8
+--R                         - 31457280a b  c   + 55050240a b  c  - 66060288a  b  c
+--R                       + 
+--R                                  12 8 7            14 6 6            16 4 5
+--R                         55050240a  b c  - 31457280a  b c  + 11796480a  b c
+--R                       + 
+--R                                   18 2 4          20 3
+--R                         - 2621440a  b c  + 262144a  c
+--R              + 
+--R                         8 3      3 6 2      5 4      7 2  4
+--R                (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R           /
+--R                    10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                256b  c  - 1280a b c  + 2560a b c  - 2560a b c  + 1280a b c
+--R              + 
+--R                      10 3
+--R                - 256a  c
+--R      *
+--R         log
+--R                                                               +---------------+
+--R                   12 3        2 10 2        4 8        6 6  6 |  +-------+
+--R              (625b  c  + 3750a b  c  - 1491a b c + 140a b )d \|b\|d x + c  + a
+--R            + 
+--R                            14 10          2 12 9         4 10 8          6 8 7
+--R                      40960b  c   - 131072a b  c  + 24576a b  c  + 409600a b c
+--R                    + 
+--R                             8 6 6          10 4 5          12 2 4         14 3
+--R                    - 696320a b c  + 491520a  b c  - 155648a  b c  + 16384a  c
+--R                 *
+--R                    ROOT
+--R                                 18 4        2 16 3         4 14 2         6 12
+--R                             625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                           + 
+--R                                  8 10
+--R                             1225a b
+--R                        *
+--R                            8
+--R                           d
+--R                      /
+--R                                  20 13           2 18 12            4 16 11
+--R                           262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                         + 
+--R                                      6 14 10            8 12 9
+--R                           - 31457280a b  c   + 55050240a b  c
+--R                         + 
+--R                                      10 10 8            12 8 7
+--R                           - 66060288a  b  c  + 55050240a  b c
+--R                         + 
+--R                                      14 6 6            16 4 5           18 2 4
+--R                           - 31457280a  b c  + 11796480a  b c  - 2621440a  b c
+--R                         + 
+--R                                  20 3
+--R                           262144a  c
+--R                + 
+--R                            12 5         3 10 4        5 8 3       7 6 2  4
+--R                  (- 5200a b  c  - 31632a b  c  + 9744a b c  - 560a b c )d
+--R             *
+--R                ROOT
+--R                                 10 8        2 8 7        4 6 6        6 4 5
+--R                           - 512b  c  + 2560a b c  - 5120a b c  + 5120a b c
+--R                         + 
+--R                                  8 2 4       10 3
+--R                           - 2560a b c  + 512a  c
+--R                      *
+--R                         ROOT
+--R                                      18 4        2 16 3         4 14 2
+--R                                  625b  c  + 7700a b  c  + 21966a b  c
+--R                                + 
+--R                                          6 12         8 10
+--R                                  - 10780a b  c + 1225a b
+--R                             *
+--R                                 8
+--R                                d
+--R                           /
+--R                                       20 13           2 18 12
+--R                                262144b  c   - 2621440a b  c
+--R                              + 
+--R                                         4 16 11            6 14 10
+--R                                11796480a b  c   - 31457280a b  c
+--R                              + 
+--R                                         8 12 9            10 10 8
+--R                                55050240a b  c  - 66060288a  b  c
+--R                              + 
+--R                                         12 8 7            14 6 6
+--R                                55050240a  b c  - 31457280a  b c
+--R                              + 
+--R                                         16 4 5           18 2 4          20 3
+--R                                11796480a  b c  - 2621440a  b c  + 262144a  c
+--R                     + 
+--R                                8 3      3 6 2      5 4      7 2  4
+--R                       (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R                  /
+--R                           10 8        2 8 7        4 6 6        6 4 5
+--R                       256b  c  - 1280a b c  + 2560a b c  - 2560a b c
+--R                     + 
+--R                            8 2 4       10 3
+--R                       1280a b c  - 256a  c
+--R     + 
+--R              4 3     2 2 2     4   2
+--R         (- 4b c  + 8a b c  - 4a c)x
+--R      *
+--R         ROOT
+--R                          10 8        2 8 7        4 6 6        6 4 5
+--R                    - 512b  c  + 2560a b c  - 5120a b c  + 5120a b c
+--R                  + 
+--R                           8 2 4       10 3
+--R                    - 2560a b c  + 512a  c
+--R               *
+--R                  ROOT
+--R                               18 4        2 16 3         4 14 2         6 12
+--R                           625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                         + 
+--R                                8 10
+--R                           1225a b
+--R                      *
+--R                          8
+--R                         d
+--R                    /
+--R                                20 13           2 18 12            4 16 11
+--R                         262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                       + 
+--R                                    6 14 10            8 12 9            10 10 8
+--R                         - 31457280a b  c   + 55050240a b  c  - 66060288a  b  c
+--R                       + 
+--R                                  12 8 7            14 6 6            16 4 5
+--R                         55050240a  b c  - 31457280a  b c  + 11796480a  b c
+--R                       + 
+--R                                   18 2 4          20 3
+--R                         - 2621440a  b c  + 262144a  c
+--R              + 
+--R                         8 3      3 6 2      5 4      7 2  4
+--R                (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R           /
+--R                    10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                256b  c  - 1280a b c  + 2560a b c  - 2560a b c  + 1280a b c
+--R              + 
+--R                      10 3
+--R                - 256a  c
+--R      *
+--R         log
+--R                                                               +---------------+
+--R                   12 3        2 10 2        4 8        6 6  6 |  +-------+
+--R              (625b  c  + 3750a b  c  - 1491a b c + 140a b )d \|b\|d x + c  + a
+--R            + 
+--R                              14 10          2 12 9         4 10 8
+--R                      - 40960b  c   + 131072a b  c  - 24576a b  c
+--R                    + 
+--R                               6 8 7          8 6 6          10 4 5
+--R                      - 409600a b c  + 696320a b c  - 491520a  b c
+--R                    + 
+--R                             12 2 4         14 3
+--R                      155648a  b c  - 16384a  c
+--R                 *
+--R                    ROOT
+--R                                 18 4        2 16 3         4 14 2         6 12
+--R                             625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                           + 
+--R                                  8 10
+--R                             1225a b
+--R                        *
+--R                            8
+--R                           d
+--R                      /
+--R                                  20 13           2 18 12            4 16 11
+--R                           262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                         + 
+--R                                      6 14 10            8 12 9
+--R                           - 31457280a b  c   + 55050240a b  c
+--R                         + 
+--R                                      10 10 8            12 8 7
+--R                           - 66060288a  b  c  + 55050240a  b c
+--R                         + 
+--R                                      14 6 6            16 4 5           18 2 4
+--R                           - 31457280a  b c  + 11796480a  b c  - 2621440a  b c
+--R                         + 
+--R                                  20 3
+--R                           262144a  c
+--R                + 
+--R                          12 5         3 10 4        5 8 3       7 6 2  4
+--R                  (5200a b  c  + 31632a b  c  - 9744a b c  + 560a b c )d
+--R             *
+--R                ROOT
+--R                                 10 8        2 8 7        4 6 6        6 4 5
+--R                           - 512b  c  + 2560a b c  - 5120a b c  + 5120a b c
+--R                         + 
+--R                                  8 2 4       10 3
+--R                           - 2560a b c  + 512a  c
+--R                      *
+--R                         ROOT
+--R                                      18 4        2 16 3         4 14 2
+--R                                  625b  c  + 7700a b  c  + 21966a b  c
+--R                                + 
+--R                                          6 12         8 10
+--R                                  - 10780a b  c + 1225a b
+--R                             *
+--R                                 8
+--R                                d
+--R                           /
+--R                                       20 13           2 18 12
+--R                                262144b  c   - 2621440a b  c
+--R                              + 
+--R                                         4 16 11            6 14 10
+--R                                11796480a b  c   - 31457280a b  c
+--R                              + 
+--R                                         8 12 9            10 10 8
+--R                                55050240a b  c  - 66060288a  b  c
+--R                              + 
+--R                                         12 8 7            14 6 6
+--R                                55050240a  b c  - 31457280a  b c
+--R                              + 
+--R                                         16 4 5           18 2 4          20 3
+--R                                11796480a  b c  - 2621440a  b c  + 262144a  c
+--R                     + 
+--R                                8 3      3 6 2      5 4      7 2  4
+--R                       (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R                  /
+--R                           10 8        2 8 7        4 6 6        6 4 5
+--R                       256b  c  - 1280a b c  + 2560a b c  - 2560a b c
+--R                     + 
+--R                            8 2 4       10 3
+--R                       1280a b c  - 256a  c
+--R     + 
+--R            4 3     2 2 2     4   2
+--R         (4b c  - 8a b c  + 4a c)x
+--R      *
+--R         ROOT
+--R                        10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                    512b  c  - 2560a b c  + 5120a b c  - 5120a b c  + 2560a b c
+--R                  + 
+--R                          10 3
+--R                    - 512a  c
+--R               *
+--R                  ROOT
+--R                               18 4        2 16 3         4 14 2         6 12
+--R                           625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                         + 
+--R                                8 10
+--R                           1225a b
+--R                      *
+--R                          8
+--R                         d
+--R                    /
+--R                                20 13           2 18 12            4 16 11
+--R                         262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                       + 
+--R                                    6 14 10            8 12 9            10 10 8
+--R                         - 31457280a b  c   + 55050240a b  c  - 66060288a  b  c
+--R                       + 
+--R                                  12 8 7            14 6 6            16 4 5
+--R                         55050240a  b c  - 31457280a  b c  + 11796480a  b c
+--R                       + 
+--R                                   18 2 4          20 3
+--R                         - 2621440a  b c  + 262144a  c
+--R              + 
+--R                         8 3      3 6 2      5 4      7 2  4
+--R                (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R           /
+--R                    10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                256b  c  - 1280a b c  + 2560a b c  - 2560a b c  + 1280a b c
+--R              + 
+--R                      10 3
+--R                - 256a  c
+--R      *
+--R         log
+--R                                                               +---------------+
+--R                   12 3        2 10 2        4 8        6 6  6 |  +-------+
+--R              (625b  c  + 3750a b  c  - 1491a b c + 140a b )d \|b\|d x + c  + a
+--R            + 
+--R                              14 10          2 12 9         4 10 8
+--R                      - 40960b  c   + 131072a b  c  - 24576a b  c
+--R                    + 
+--R                               6 8 7          8 6 6          10 4 5
+--R                      - 409600a b c  + 696320a b c  - 491520a  b c
+--R                    + 
+--R                             12 2 4         14 3
+--R                      155648a  b c  - 16384a  c
+--R                 *
+--R                    ROOT
+--R                                 18 4        2 16 3         4 14 2         6 12
+--R                             625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                           + 
+--R                                  8 10
+--R                             1225a b
+--R                        *
+--R                            8
+--R                           d
+--R                      /
+--R                                  20 13           2 18 12            4 16 11
+--R                           262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                         + 
+--R                                      6 14 10            8 12 9
+--R                           - 31457280a b  c   + 55050240a b  c
+--R                         + 
+--R                                      10 10 8            12 8 7
+--R                           - 66060288a  b  c  + 55050240a  b c
+--R                         + 
+--R                                      14 6 6            16 4 5           18 2 4
+--R                           - 31457280a  b c  + 11796480a  b c  - 2621440a  b c
+--R                         + 
+--R                                  20 3
+--R                           262144a  c
+--R                + 
+--R                            12 5         3 10 4        5 8 3       7 6 2  4
+--R                  (- 5200a b  c  - 31632a b  c  + 9744a b c  - 560a b c )d
+--R             *
+--R                ROOT
+--R                               10 8        2 8 7        4 6 6        6 4 5
+--R                           512b  c  - 2560a b c  + 5120a b c  - 5120a b c
+--R                         + 
+--R                                8 2 4       10 3
+--R                           2560a b c  - 512a  c
+--R                      *
+--R                         ROOT
+--R                                      18 4        2 16 3         4 14 2
+--R                                  625b  c  + 7700a b  c  + 21966a b  c
+--R                                + 
+--R                                          6 12         8 10
+--R                                  - 10780a b  c + 1225a b
+--R                             *
+--R                                 8
+--R                                d
+--R                           /
+--R                                       20 13           2 18 12
+--R                                262144b  c   - 2621440a b  c
+--R                              + 
+--R                                         4 16 11            6 14 10
+--R                                11796480a b  c   - 31457280a b  c
+--R                              + 
+--R                                         8 12 9            10 10 8
+--R                                55050240a b  c  - 66060288a  b  c
+--R                              + 
+--R                                         12 8 7            14 6 6
+--R                                55050240a  b c  - 31457280a  b c
+--R                              + 
+--R                                         16 4 5           18 2 4          20 3
+--R                                11796480a  b c  - 2621440a  b c  + 262144a  c
+--R                     + 
+--R                                8 3      3 6 2      5 4      7 2  4
+--R                       (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R                  /
+--R                           10 8        2 8 7        4 6 6        6 4 5
+--R                       256b  c  - 1280a b c  + 2560a b c  - 2560a b c
+--R                     + 
+--R                            8 2 4       10 3
+--R                       1280a b c  - 256a  c
+--R     + 
+--R               3     2          3 2     2     +-------+       2            2 2
+--R           ((5b c + a b)d x - 4b c  + 4a b c)\|d x + c  - 6a b c d x + 4a b c
+--R         + 
+--R               3
+--R           - 4a c
+--R      *
+--R          +---------------+
+--R          |  +-------+
+--R         \|b\|d x + c  + a
+--R  /
+--R        4 3      2 2 2     4   2
+--R     (8b c  - 16a b c  + 8a c)x
+--R                                         Type: Union(Expression(Integer),...)
+--E 33
+
+--S 34 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +-----------+ +---------+
+--R              4 4      2 2 3     4 2  |    +-+      |  +-+
+--R         (- 8b c  + 16a b c  - 8a c )\|- b\|c  + a \|b\|c  + a
+--R      *
+--R         ROOT
+--R                        10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                    512b  c  - 2560a b c  + 5120a b c  - 5120a b c  + 2560a b c
+--R                  + 
+--R                          10 3
+--R                    - 512a  c
+--R               *
+--R                  ROOT
+--R                               18 4        2 16 3         4 14 2         6 12
+--R                           625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                         + 
+--R                                8 10
+--R                           1225a b
+--R                      *
+--R                          8
+--R                         d
+--R                    /
+--R                                20 13           2 18 12            4 16 11
+--R                         262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                       + 
+--R                                    6 14 10            8 12 9            10 10 8
+--R                         - 31457280a b  c   + 55050240a b  c  - 66060288a  b  c
+--R                       + 
+--R                                  12 8 7            14 6 6            16 4 5
+--R                         55050240a  b c  - 31457280a  b c  + 11796480a  b c
+--R                       + 
+--R                                   18 2 4          20 3
+--R                         - 2621440a  b c  + 262144a  c
+--R              + 
+--R                         8 3      3 6 2      5 4      7 2  4
+--R                (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R           /
+--R                    10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                256b  c  - 1280a b c  + 2560a b c  - 2560a b c  + 1280a b c
+--R              + 
+--R                      10 3
+--R                - 256a  c
+--R      *
+--R         log
+--R                                                               +---------------+
+--R                   12 3        2 10 2        4 8        6 6  6 |  +-------+
+--R              (625b  c  + 3750a b  c  - 1491a b c + 140a b )d \|b\|d x + c  + a
+--R            + 
+--R                            14 10          2 12 9         4 10 8          6 8 7
+--R                      40960b  c   - 131072a b  c  + 24576a b  c  + 409600a b c
+--R                    + 
+--R                             8 6 6          10 4 5          12 2 4         14 3
+--R                    - 696320a b c  + 491520a  b c  - 155648a  b c  + 16384a  c
+--R                 *
+--R                    ROOT
+--R                                 18 4        2 16 3         4 14 2         6 12
+--R                             625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                           + 
+--R                                  8 10
+--R                             1225a b
+--R                        *
+--R                            8
+--R                           d
+--R                      /
+--R                                  20 13           2 18 12            4 16 11
+--R                           262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                         + 
+--R                                      6 14 10            8 12 9
+--R                           - 31457280a b  c   + 55050240a b  c
+--R                         + 
+--R                                      10 10 8            12 8 7
+--R                           - 66060288a  b  c  + 55050240a  b c
+--R                         + 
+--R                                      14 6 6            16 4 5           18 2 4
+--R                           - 31457280a  b c  + 11796480a  b c  - 2621440a  b c
+--R                         + 
+--R                                  20 3
+--R                           262144a  c
+--R                + 
+--R                          12 5         3 10 4        5 8 3       7 6 2  4
+--R                  (5200a b  c  + 31632a b  c  - 9744a b c  + 560a b c )d
+--R             *
+--R                ROOT
+--R                               10 8        2 8 7        4 6 6        6 4 5
+--R                           512b  c  - 2560a b c  + 5120a b c  - 5120a b c
+--R                         + 
+--R                                8 2 4       10 3
+--R                           2560a b c  - 512a  c
+--R                      *
+--R                         ROOT
+--R                                      18 4        2 16 3         4 14 2
+--R                                  625b  c  + 7700a b  c  + 21966a b  c
+--R                                + 
+--R                                          6 12         8 10
+--R                                  - 10780a b  c + 1225a b
+--R                             *
+--R                                 8
+--R                                d
+--R                           /
+--R                                       20 13           2 18 12
+--R                                262144b  c   - 2621440a b  c
+--R                              + 
+--R                                         4 16 11            6 14 10
+--R                                11796480a b  c   - 31457280a b  c
+--R                              + 
+--R                                         8 12 9            10 10 8
+--R                                55050240a b  c  - 66060288a  b  c
+--R                              + 
+--R                                         12 8 7            14 6 6
+--R                                55050240a  b c  - 31457280a  b c
+--R                              + 
+--R                                         16 4 5           18 2 4          20 3
+--R                                11796480a  b c  - 2621440a  b c  + 262144a  c
+--R                     + 
+--R                                8 3      3 6 2      5 4      7 2  4
+--R                       (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R                  /
+--R                           10 8        2 8 7        4 6 6        6 4 5
+--R                       256b  c  - 1280a b c  + 2560a b c  - 2560a b c
+--R                     + 
+--R                            8 2 4       10 3
+--R                       1280a b c  - 256a  c
+--R     + 
+--R            4 4      2 2 3     4 2
+--R         (8b c  - 16a b c  + 8a c )
+--R      *
+--R         ROOT
+--R                          10 8        2 8 7        4 6 6        6 4 5
+--R                    - 512b  c  + 2560a b c  - 5120a b c  + 5120a b c
+--R                  + 
+--R                           8 2 4       10 3
+--R                    - 2560a b c  + 512a  c
+--R               *
+--R                  ROOT
+--R                               18 4        2 16 3         4 14 2         6 12
+--R                           625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                         + 
+--R                                8 10
+--R                           1225a b
+--R                      *
+--R                          8
+--R                         d
+--R                    /
+--R                                20 13           2 18 12            4 16 11
+--R                         262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                       + 
+--R                                    6 14 10            8 12 9            10 10 8
+--R                         - 31457280a b  c   + 55050240a b  c  - 66060288a  b  c
+--R                       + 
+--R                                  12 8 7            14 6 6            16 4 5
+--R                         55050240a  b c  - 31457280a  b c  + 11796480a  b c
+--R                       + 
+--R                                   18 2 4          20 3
+--R                         - 2621440a  b c  + 262144a  c
+--R              + 
+--R                         8 3      3 6 2      5 4      7 2  4
+--R                (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R           /
+--R                    10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                256b  c  - 1280a b c  + 2560a b c  - 2560a b c  + 1280a b c
+--R              + 
+--R                      10 3
+--R                - 256a  c
+--R      *
+--R          +-----------+ +---------+
+--R          |    +-+      |  +-+
+--R         \|- b\|c  + a \|b\|c  + a
+--R      *
+--R         log
+--R                                                               +---------------+
+--R                   12 3        2 10 2        4 8        6 6  6 |  +-------+
+--R              (625b  c  + 3750a b  c  - 1491a b c + 140a b )d \|b\|d x + c  + a
+--R            + 
+--R                            14 10          2 12 9         4 10 8          6 8 7
+--R                      40960b  c   - 131072a b  c  + 24576a b  c  + 409600a b c
+--R                    + 
+--R                             8 6 6          10 4 5          12 2 4         14 3
+--R                    - 696320a b c  + 491520a  b c  - 155648a  b c  + 16384a  c
+--R                 *
+--R                    ROOT
+--R                                 18 4        2 16 3         4 14 2         6 12
+--R                             625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                           + 
+--R                                  8 10
+--R                             1225a b
+--R                        *
+--R                            8
+--R                           d
+--R                      /
+--R                                  20 13           2 18 12            4 16 11
+--R                           262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                         + 
+--R                                      6 14 10            8 12 9
+--R                           - 31457280a b  c   + 55050240a b  c
+--R                         + 
+--R                                      10 10 8            12 8 7
+--R                           - 66060288a  b  c  + 55050240a  b c
+--R                         + 
+--R                                      14 6 6            16 4 5           18 2 4
+--R                           - 31457280a  b c  + 11796480a  b c  - 2621440a  b c
+--R                         + 
+--R                                  20 3
+--R                           262144a  c
+--R                + 
+--R                            12 5         3 10 4        5 8 3       7 6 2  4
+--R                  (- 5200a b  c  - 31632a b  c  + 9744a b c  - 560a b c )d
+--R             *
+--R                ROOT
+--R                                 10 8        2 8 7        4 6 6        6 4 5
+--R                           - 512b  c  + 2560a b c  - 5120a b c  + 5120a b c
+--R                         + 
+--R                                  8 2 4       10 3
+--R                           - 2560a b c  + 512a  c
+--R                      *
+--R                         ROOT
+--R                                      18 4        2 16 3         4 14 2
+--R                                  625b  c  + 7700a b  c  + 21966a b  c
+--R                                + 
+--R                                          6 12         8 10
+--R                                  - 10780a b  c + 1225a b
+--R                             *
+--R                                 8
+--R                                d
+--R                           /
+--R                                       20 13           2 18 12
+--R                                262144b  c   - 2621440a b  c
+--R                              + 
+--R                                         4 16 11            6 14 10
+--R                                11796480a b  c   - 31457280a b  c
+--R                              + 
+--R                                         8 12 9            10 10 8
+--R                                55050240a b  c  - 66060288a  b  c
+--R                              + 
+--R                                         12 8 7            14 6 6
+--R                                55050240a  b c  - 31457280a  b c
+--R                              + 
+--R                                         16 4 5           18 2 4          20 3
+--R                                11796480a  b c  - 2621440a  b c  + 262144a  c
+--R                     + 
+--R                                8 3      3 6 2      5 4      7 2  4
+--R                       (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R                  /
+--R                           10 8        2 8 7        4 6 6        6 4 5
+--R                       256b  c  - 1280a b c  + 2560a b c  - 2560a b c
+--R                     + 
+--R                            8 2 4       10 3
+--R                       1280a b c  - 256a  c
+--R     + 
+--R              4 4      2 2 3     4 2
+--R         (- 8b c  + 16a b c  - 8a c )
+--R      *
+--R         ROOT
+--R                          10 8        2 8 7        4 6 6        6 4 5
+--R                    - 512b  c  + 2560a b c  - 5120a b c  + 5120a b c
+--R                  + 
+--R                           8 2 4       10 3
+--R                    - 2560a b c  + 512a  c
+--R               *
+--R                  ROOT
+--R                               18 4        2 16 3         4 14 2         6 12
+--R                           625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                         + 
+--R                                8 10
+--R                           1225a b
+--R                      *
+--R                          8
+--R                         d
+--R                    /
+--R                                20 13           2 18 12            4 16 11
+--R                         262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                       + 
+--R                                    6 14 10            8 12 9            10 10 8
+--R                         - 31457280a b  c   + 55050240a b  c  - 66060288a  b  c
+--R                       + 
+--R                                  12 8 7            14 6 6            16 4 5
+--R                         55050240a  b c  - 31457280a  b c  + 11796480a  b c
+--R                       + 
+--R                                   18 2 4          20 3
+--R                         - 2621440a  b c  + 262144a  c
+--R              + 
+--R                         8 3      3 6 2      5 4      7 2  4
+--R                (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R           /
+--R                    10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                256b  c  - 1280a b c  + 2560a b c  - 2560a b c  + 1280a b c
+--R              + 
+--R                      10 3
+--R                - 256a  c
+--R      *
+--R          +-----------+ +---------+
+--R          |    +-+      |  +-+
+--R         \|- b\|c  + a \|b\|c  + a
+--R      *
+--R         log
+--R                                                               +---------------+
+--R                   12 3        2 10 2        4 8        6 6  6 |  +-------+
+--R              (625b  c  + 3750a b  c  - 1491a b c + 140a b )d \|b\|d x + c  + a
+--R            + 
+--R                              14 10          2 12 9         4 10 8
+--R                      - 40960b  c   + 131072a b  c  - 24576a b  c
+--R                    + 
+--R                               6 8 7          8 6 6          10 4 5
+--R                      - 409600a b c  + 696320a b c  - 491520a  b c
+--R                    + 
+--R                             12 2 4         14 3
+--R                      155648a  b c  - 16384a  c
+--R                 *
+--R                    ROOT
+--R                                 18 4        2 16 3         4 14 2         6 12
+--R                             625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                           + 
+--R                                  8 10
+--R                             1225a b
+--R                        *
+--R                            8
+--R                           d
+--R                      /
+--R                                  20 13           2 18 12            4 16 11
+--R                           262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                         + 
+--R                                      6 14 10            8 12 9
+--R                           - 31457280a b  c   + 55050240a b  c
+--R                         + 
+--R                                      10 10 8            12 8 7
+--R                           - 66060288a  b  c  + 55050240a  b c
+--R                         + 
+--R                                      14 6 6            16 4 5           18 2 4
+--R                           - 31457280a  b c  + 11796480a  b c  - 2621440a  b c
+--R                         + 
+--R                                  20 3
+--R                           262144a  c
+--R                + 
+--R                          12 5         3 10 4        5 8 3       7 6 2  4
+--R                  (5200a b  c  + 31632a b  c  - 9744a b c  + 560a b c )d
+--R             *
+--R                ROOT
+--R                                 10 8        2 8 7        4 6 6        6 4 5
+--R                           - 512b  c  + 2560a b c  - 5120a b c  + 5120a b c
+--R                         + 
+--R                                  8 2 4       10 3
+--R                           - 2560a b c  + 512a  c
+--R                      *
+--R                         ROOT
+--R                                      18 4        2 16 3         4 14 2
+--R                                  625b  c  + 7700a b  c  + 21966a b  c
+--R                                + 
+--R                                          6 12         8 10
+--R                                  - 10780a b  c + 1225a b
+--R                             *
+--R                                 8
+--R                                d
+--R                           /
+--R                                       20 13           2 18 12
+--R                                262144b  c   - 2621440a b  c
+--R                              + 
+--R                                         4 16 11            6 14 10
+--R                                11796480a b  c   - 31457280a b  c
+--R                              + 
+--R                                         8 12 9            10 10 8
+--R                                55050240a b  c  - 66060288a  b  c
+--R                              + 
+--R                                         12 8 7            14 6 6
+--R                                55050240a  b c  - 31457280a  b c
+--R                              + 
+--R                                         16 4 5           18 2 4          20 3
+--R                                11796480a  b c  - 2621440a  b c  + 262144a  c
+--R                     + 
+--R                                8 3      3 6 2      5 4      7 2  4
+--R                       (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R                  /
+--R                           10 8        2 8 7        4 6 6        6 4 5
+--R                       256b  c  - 1280a b c  + 2560a b c  - 2560a b c
+--R                     + 
+--R                            8 2 4       10 3
+--R                       1280a b c  - 256a  c
+--R     + 
+--R                                    +-----------+ +---------+
+--R            4 4      2 2 3     4 2  |    +-+      |  +-+
+--R         (8b c  - 16a b c  + 8a c )\|- b\|c  + a \|b\|c  + a
+--R      *
+--R         ROOT
+--R                        10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                    512b  c  - 2560a b c  + 5120a b c  - 5120a b c  + 2560a b c
+--R                  + 
+--R                          10 3
+--R                    - 512a  c
+--R               *
+--R                  ROOT
+--R                               18 4        2 16 3         4 14 2         6 12
+--R                           625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                         + 
+--R                                8 10
+--R                           1225a b
+--R                      *
+--R                          8
+--R                         d
+--R                    /
+--R                                20 13           2 18 12            4 16 11
+--R                         262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                       + 
+--R                                    6 14 10            8 12 9            10 10 8
+--R                         - 31457280a b  c   + 55050240a b  c  - 66060288a  b  c
+--R                       + 
+--R                                  12 8 7            14 6 6            16 4 5
+--R                         55050240a  b c  - 31457280a  b c  + 11796480a  b c
+--R                       + 
+--R                                   18 2 4          20 3
+--R                         - 2621440a  b c  + 262144a  c
+--R              + 
+--R                         8 3      3 6 2      5 4      7 2  4
+--R                (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R           /
+--R                    10 8        2 8 7        4 6 6        6 4 5        8 2 4
+--R                256b  c  - 1280a b c  + 2560a b c  - 2560a b c  + 1280a b c
+--R              + 
+--R                      10 3
+--R                - 256a  c
+--R      *
+--R         log
+--R                                                               +---------------+
+--R                   12 3        2 10 2        4 8        6 6  6 |  +-------+
+--R              (625b  c  + 3750a b  c  - 1491a b c + 140a b )d \|b\|d x + c  + a
+--R            + 
+--R                              14 10          2 12 9         4 10 8
+--R                      - 40960b  c   + 131072a b  c  - 24576a b  c
+--R                    + 
+--R                               6 8 7          8 6 6          10 4 5
+--R                      - 409600a b c  + 696320a b c  - 491520a  b c
+--R                    + 
+--R                             12 2 4         14 3
+--R                      155648a  b c  - 16384a  c
+--R                 *
+--R                    ROOT
+--R                                 18 4        2 16 3         4 14 2         6 12
+--R                             625b  c  + 7700a b  c  + 21966a b  c  - 10780a b  c
+--R                           + 
+--R                                  8 10
+--R                             1225a b
+--R                        *
+--R                            8
+--R                           d
+--R                      /
+--R                                  20 13           2 18 12            4 16 11
+--R                           262144b  c   - 2621440a b  c   + 11796480a b  c
+--R                         + 
+--R                                      6 14 10            8 12 9
+--R                           - 31457280a b  c   + 55050240a b  c
+--R                         + 
+--R                                      10 10 8            12 8 7
+--R                           - 66060288a  b  c  + 55050240a  b c
+--R                         + 
+--R                                      14 6 6            16 4 5           18 2 4
+--R                           - 31457280a  b c  + 11796480a  b c  - 2621440a  b c
+--R                         + 
+--R                                  20 3
+--R                           262144a  c
+--R                + 
+--R                            12 5         3 10 4        5 8 3       7 6 2  4
+--R                  (- 5200a b  c  - 31632a b  c  + 9744a b c  - 560a b c )d
+--R             *
+--R                ROOT
+--R                               10 8        2 8 7        4 6 6        6 4 5
+--R                           512b  c  - 2560a b c  + 5120a b c  - 5120a b c
+--R                         + 
+--R                                8 2 4       10 3
+--R                           2560a b c  - 512a  c
+--R                      *
+--R                         ROOT
+--R                                      18 4        2 16 3         4 14 2
+--R                                  625b  c  + 7700a b  c  + 21966a b  c
+--R                                + 
+--R                                          6 12         8 10
+--R                                  - 10780a b  c + 1225a b
+--R                             *
+--R                                 8
+--R                                d
+--R                           /
+--R                                       20 13           2 18 12
+--R                                262144b  c   - 2621440a b  c
+--R                              + 
+--R                                         4 16 11            6 14 10
+--R                                11796480a b  c   - 31457280a b  c
+--R                              + 
+--R                                         8 12 9            10 10 8
+--R                                55050240a b  c  - 66060288a  b  c
+--R                              + 
+--R                                         12 8 7            14 6 6
+--R                                55050240a  b c  - 31457280a  b c
+--R                              + 
+--R                                         16 4 5           18 2 4          20 3
+--R                                11796480a  b c  - 2621440a  b c  + 262144a  c
+--R                     + 
+--R                                8 3      3 6 2      5 4      7 2  4
+--R                       (- 105a b c  - 70a b c  + 35a b c - 4a b )d
+--R                  /
+--R                           10 8        2 8 7        4 6 6        6 4 5
+--R                       256b  c  - 1280a b c  + 2560a b c  - 2560a b c
+--R                     + 
+--R                            8 2 4       10 3
+--R                       1280a b c  - 256a  c
+--R     + 
+--R                                                     +---------+
+--R               3      3   2 +-+      4 2    2 2   2  |  +-+
+--R         ((8a b c - 2a b)d \|c  + (5b c  + a b c)d )\|b\|c  + a
+--R      *
+--R                +---------------+
+--R                |  +-------+
+--R               \|b\|d x + c  + a
+--R         atanh(------------------)
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- b\|c  + a
+--R     + 
+--R                                                       +-----------+
+--R                 3      3   2 +-+      4 2    2 2   2  |    +-+
+--R         ((- 8a b c + 2a b)d \|c  + (5b c  + a b c)d )\|- b\|c  + a
+--R      *
+--R                +---------------+
+--R                |  +-------+
+--R               \|b\|d x + c  + a
+--R         atanh(------------------)
+--R                   +---------+
+--R                   |  +-+
+--R                  \|b\|c  + a
+--R  /
+--R                                  +-----------+ +---------+
+--R         4 4      2 2 3      4 2  |    +-+      |  +-+
+--R     (16b c  - 32a b c  + 16a c )\|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 35
+
+)clear all
+
+--S 36 of 649
+t0:=x^3*(a+b*sqrt(c+d*x))^p
+--R 
+--R
+--R         3   +-------+     p
+--R   (1)  x (b\|d x + c  + a)
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 649
+r0:=-2*a*(a^2-b^2*c)^3*(a+b*sqrt(c+d*x))^(1+p)/(b^8*d^4*(1+p))+_
+   2*(a^2-b^2*c)^2*(7*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(2+p)/(b^8*d^4*(2+p))-_
+   6*a*(7*a^2-3*b^2*c)*(a^2-b^2*c)*(a+b*sqrt(c+d*x))^(3+p)/(b^8*d^4*(3+p))+_
+   2*(35*a^4-30*a^2*b^2*c+3*b^4*c^2)*(a+b*sqrt(c+d*x))^(4+p)/(b^8*_
+   d^4*(4+p))-10*a*(7*a^2-3*b^2*c)*(a+b*sqrt(c+d*x))^(5+p)/(b^8*_
+   d^4*(5+p))+6*(7*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(6+p)/(b^8*d^4*(6+p))-_
+   14*a*(a+b*sqrt(c+d*x))^(7+p)/(b^8*d^4*(7+p))+2*(a+b*sqrt(c+_
+   d*x))^(8+p)/(b^8*d^4*(8+p))
+--R 
+--R
+--R   (2)
+--R            7      6       5        4         3         2
+--R         (2p  + 56p  + 644p  + 3920p  + 13538p  + 26264p  + 26136p + 10080)
+--R      *
+--R            +-------+     p + 8
+--R         (b\|d x + c  + a)
+--R     + 
+--R                  7         6          5           4            3            2
+--R           - 14a p  - 406a p  - 4802a p  - 29890a p  - 105056a p  - 206584a p
+--R         + 
+--R           - 207648a p - 80640a
+--R      *
+--R            +-------+     p + 7
+--R         (b\|d x + c  + a)
+--R     + 
+--R                2       2  7          2         2  6           2          2  5
+--R           (- 6b c + 42a )p  + (- 180b c + 1260a )p  + (- 2196b c + 15372a )p
+--R         + 
+--R                    2          2  4            2           2  3
+--R           (- 14040b c + 98280a )p  + (- 50454b c + 353178a )p
+--R         + 
+--R                     2           2  2             2           2           2
+--R           (- 100980b c + 706860a )p  + (- 102864b c + 720048a )p - 40320b c
+--R         + 
+--R                  2
+--R           282240a
+--R      *
+--R            +-------+     p + 6
+--R         (b\|d x + c  + a)
+--R     + 
+--R                 2       3  7          2         3  6            2          3  5
+--R           (30a b c - 70a )p  + (930a b c - 2170a )p  + (11730a b c - 27370a )p
+--R         + 
+--R                    2           3  4             2           3  3
+--R           (77430a b c - 180670a )p  + (286320a b c - 668080a )p
+--R         + 
+--R                     2            3  2             2            3
+--R           (586920a b c - 1369480a )p  + (609120a b c - 1421280a )p
+--R         + 
+--R                    2           3
+--R           241920a b c - 564480a
+--R      *
+--R            +-------+     p + 5
+--R         (b\|d x + c  + a)
+--R     + 
+--R              4 2      2 2       4  7        4 2        2 2         4  6
+--R           (6b c  - 60a b c + 70a )p  + (192b c  - 1920a b c + 2240a )p
+--R         + 
+--R                 4 2         2 2          4  5
+--R           (2508b c  - 25080a b c + 29260a )p
+--R         + 
+--R                  4 2          2 2           4  4
+--R           (17184b c  - 171840a b c + 200480a )p
+--R         + 
+--R                  4 2          2 2           4  3
+--R           (65958b c  - 659580a b c + 769510a )p
+--R         + 
+--R                   4 2           2 2            4  2
+--R           (139872b c  - 1398720a b c + 1631840a )p
+--R         + 
+--R                   4 2           2 2            4           4 2          2 2
+--R           (149256b c  - 1492560a b c + 1741320a )p + 60480b c  - 604800a b c
+--R         + 
+--R                  4
+--R           705600a
+--R      *
+--R            +-------+     p + 4
+--R         (b\|d x + c  + a)
+--R     + 
+--R                   4 2      3 2       5  7
+--R           (- 18a b c  + 60a b c - 42a )p
+--R         + 
+--R                    4 2        3 2         5  6
+--R           (- 594a b c  + 1980a b c - 1386a )p
+--R         + 
+--R                     4 2         3 2          5  5
+--R           (- 8046a b c  + 26820a b c - 18774a )p
+--R         + 
+--R                      4 2          3 2           5  4
+--R           (- 57510a b c  + 191700a b c - 134190a )p
+--R         + 
+--R                       4 2          3 2           5  3
+--R           (- 231552a b c  + 771840a b c - 540288a )p
+--R         + 
+--R                       4 2           3 2            5  2
+--R           (- 516456a b c  + 1721520a b c - 1205064a )p
+--R         + 
+--R                       4 2           3 2            5              4 2
+--R           (- 576864a b c  + 1922880a b c - 1346016a )p - 241920a b c
+--R         + 
+--R                  3 2           5
+--R           806400a b c - 564480a
+--R      *
+--R            +-------+     p + 3
+--R         (b\|d x + c  + a)
+--R     + 
+--R                6 3      2 4 2      4 2       6  7
+--R           (- 2b c  + 18a b c  - 30a b c + 14a )p
+--R         + 
+--R                 6 3       2 4 2        4 2        6  6
+--R           (- 68b c  + 612a b c  - 1020a b c + 476a )p
+--R         + 
+--R                  6 3        2 4 2         4 2         6  5
+--R           (- 956b c  + 8604a b c  - 14340a b c + 6692a )p
+--R         + 
+--R                   6 3         2 4 2          4 2          6  4
+--R           (- 7160b c  + 64440a b c  - 107400a b c + 50120a )p
+--R         + 
+--R                    6 3          2 4 2          4 2           6  3
+--R           (- 30578b c  + 275202a b c  - 458670a b c + 214046a )p
+--R         + 
+--R                    6 3          2 4 2           4 2           6  2
+--R           (- 73412b c  + 660708a b c  - 1101180a b c + 513884a )p
+--R         + 
+--R                    6 3          2 4 2           4 2           6           6 3
+--R           (- 89424b c  + 804816a b c  - 1341360a b c + 625968a )p - 40320b c
+--R         + 
+--R                  2 4 2          4 2           6
+--R           362880a b c  - 604800a b c + 282240a
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R                6 3     3 4 2     5 2      7  7
+--R           (2a b c  - 6a b c  + 6a b c - 2a )p
+--R         + 
+--R                 6 3       3 4 2       5 2       7  6
+--R           (70a b c  - 210a b c  + 210a b c - 70a )p
+--R         + 
+--R                   6 3        3 4 2        5 2         7  5
+--R           (1022a b c  - 3066a b c  + 3066a b c - 1022a )p
+--R         + 
+--R                   6 3         3 4 2         5 2         7  4
+--R           (8050a b c  - 24150a b c  + 24150a b c - 8050a )p
+--R         + 
+--R                    6 3          3 4 2          5 2          7  3
+--R           (36848a b c  - 110544a b c  + 110544a b c - 36848a )p
+--R         + 
+--R                    6 3          3 4 2          5 2          7  2
+--R           (97720a b c  - 293160a b c  + 293160a b c - 97720a )p
+--R         + 
+--R                     6 3          3 4 2          5 2           7             6 3
+--R           (138528a b c  - 415584a b c  + 415584a b c - 138528a )p + 80640a b c
+--R         + 
+--R                    3 4 2          5 2          7
+--R           - 241920a b c  + 241920a b c - 80640a
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R  /
+--R        8 4 8      8 4 7       8 4 6        8 4 5         8 4 4         8 4 3
+--R       b d p  + 36b d p  + 546b d p  + 4536b d p  + 22449b d p  + 67284b d p
+--R     + 
+--R              8 4 2          8 4          8 4
+--R       118124b d p  + 109584b d p + 40320b d
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     7 3 7        7 3 6         7 3 5          7 3 4
+--R                 2a b d p  + 42a b d p  + 350a b d p  + 1470a b d p
+--R               + 
+--R                        7 3 3          7 3 2          7 3
+--R                 3248a b d p  + 3528a b d p  + 1440a b d p
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                        7   2 6            7       3 5  2 5
+--R                 - 24a b c d p  + (- 396a b c + 84a b )d p
+--R               + 
+--R                           7        3 5  2 4             7         3 5  2 3
+--R                 (- 2400a b c + 840a b )d p  + (- 6660a b c + 2940a b )d p
+--R               + 
+--R                           7         3 5  2 2             7         3 5  2
+--R                 (- 8376a b c + 4200a b )d p  + (- 3744a b c + 2016a b )d p
+--R            *
+--R                2
+--R               x
+--R           + 
+--R                        7 2      3 5     5           7 2       3 5     4
+--R                 (144a b c  + 48a b c)d p  + (2016a b c  - 480a b c)d p
+--R               + 
+--R                         7 2        3 5         5 3    3
+--R                 (9216a b c  - 6480a b c + 1680a b )d p
+--R               + 
+--R                          7 2         3 5         5 3    2
+--R                 (15696a b c  - 15360a b c + 5040a b )d p
+--R               + 
+--R                         7 2        3 5         5 3
+--R                 (8352a b c  - 9408a b c + 3360a b )d p
+--R            *
+--R               x
+--R           + 
+--R                      7 3       3 5 2  4
+--R             (- 384a b c  - 384a b c )p
+--R           + 
+--R                       7 3       3 5 2       5 3   3
+--R             (- 5184a b c  - 384a b c  + 960a b c)p
+--R           + 
+--R                        7 3         3 5 2        5 3   2
+--R             (- 21504a b c  + 18816a b c  - 5760a b c)p
+--R           + 
+--R                        7 3         3 5 2         5 3          7
+--R             (- 26784a b c  + 49056a b c  - 36960a b c + 10080a b)p
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R               8 4 7      8 4 6       8 4 5        8 4 4         8 4 3
+--R             2b d p  + 56b d p  + 644b d p  + 3920b d p  + 13538b d p
+--R           + 
+--R                   8 4 2         8 4          8 4
+--R             26264b d p  + 26136b d p + 10080b d
+--R        *
+--R            4
+--R           x
+--R       + 
+--R               8   3 7       8       2 6  3 6        8        2 6  3 5
+--R             2b c d p  + (44b c - 14a b )d p  + (380b c - 210a b )d p
+--R           + 
+--R                   8         2 6  3 4         8         2 6  3 3
+--R             (1640b c - 1190a b )d p  + (3698b c - 3150a b )d p
+--R           + 
+--R                   8         2 6  3 2         8         2 6  3
+--R             (4076b c - 3836a b )d p  + (1680b c - 1680a b )d p
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                   8 2      2 6   2 6       8 2 2 5
+--R             (- 12b c  - 12a b c)d p  - 216b c d p
+--R           + 
+--R                     8 2        2 6        4 4  2 4
+--R             (- 1416b c  + 1140a b c - 420a b )d p
+--R           + 
+--R                     8 2        2 6         4 4  2 3
+--R             (- 4176b c  + 5760a b c - 2520a b )d p
+--R           + 
+--R                     8 2        2 6         4 4  2 2
+--R             (- 5484b c  + 9672a b c - 4620a b )d p
+--R           + 
+--R                     8 2        2 6         4 4  2
+--R             (- 2520b c  + 5040a b c - 2520a b )d p
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                 8 3       2 6 2    5        8 3       2 6 2       4 4     4
+--R             (48b c  + 144a b c )d p  + (768b c  + 864a b c  - 480a b c)d p
+--R           + 
+--R                   8 3        2 6 2       4 4     3
+--R             (4128b c  - 2736a b c  + 720a b c)d p
+--R           + 
+--R                   8 3         2 6 2         4 4         6 2    2
+--R             (8448b c  - 18576a b c  + 16320a b c - 5040a b )d p
+--R           + 
+--R                   8 3         2 6 2         4 4         6 2
+--R             (5040b c  - 15120a b c  + 15120a b c - 5040a b )d p
+--R        *
+--R           x
+--R       + 
+--R               8 4       2 6 3      4 4 2  4
+--R         (- 96b c  - 576a b c  - 96a b c )p
+--R       + 
+--R                 8 4        2 6 3        4 4 2  3
+--R         (- 1536b c  - 5376a b c  + 2304a b c )p
+--R       + 
+--R                 8 4        2 6 3         4 4 2        6 2   2
+--R         (- 8256b c  - 7776a b c  + 11904a b c  - 4320a b c)p
+--R       + 
+--R                  8 4         2 6 3         4 4 2        6 2            8 4
+--R         (- 16896b c  + 27264a b c  - 20736a b c  + 5760a b c)p - 10080b c
+--R       + 
+--R               2 6 3         4 4 2         6 2          8
+--R         40320a b c  - 60480a b c  + 40320a b c - 10080a
+--R    *
+--R                 +-------+
+--R         p log(b\|d x + c  + a)
+--R       %e
+--R  /
+--R        8 4 8      8 4 7       8 4 6        8 4 5         8 4 4         8 4 3
+--R       b d p  + 36b d p  + 546b d p  + 4536b d p  + 22449b d p  + 67284b d p
+--R     + 
+--R              8 4 2          8 4          8 4
+--R       118124b d p  + 109584b d p + 40320b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 38
+
+--S 39 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       7 3 7        7 3 6         7 3 5          7 3 4
+--R                   2a b d p  + 42a b d p  + 350a b d p  + 1470a b d p
+--R                 + 
+--R                          7 3 3          7 3 2          7 3
+--R                   3248a b d p  + 3528a b d p  + 1440a b d p
+--R              *
+--R                  3
+--R                 x
+--R             + 
+--R                          7   2 6            7       3 5  2 5
+--R                   - 24a b c d p  + (- 396a b c + 84a b )d p
+--R                 + 
+--R                             7        3 5  2 4             7         3 5  2 3
+--R                   (- 2400a b c + 840a b )d p  + (- 6660a b c + 2940a b )d p
+--R                 + 
+--R                             7         3 5  2 2             7         3 5  2
+--R                   (- 8376a b c + 4200a b )d p  + (- 3744a b c + 2016a b )d p
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          7 2      3 5     5           7 2       3 5     4
+--R                   (144a b c  + 48a b c)d p  + (2016a b c  - 480a b c)d p
+--R                 + 
+--R                           7 2        3 5         5 3    3
+--R                   (9216a b c  - 6480a b c + 1680a b )d p
+--R                 + 
+--R                            7 2         3 5         5 3    2
+--R                   (15696a b c  - 15360a b c + 5040a b )d p
+--R                 + 
+--R                           7 2        3 5         5 3
+--R                   (8352a b c  - 9408a b c + 3360a b )d p
+--R              *
+--R                 x
+--R             + 
+--R                        7 3       3 5 2  4
+--R               (- 384a b c  - 384a b c )p
+--R             + 
+--R                         7 3       3 5 2       5 3   3
+--R               (- 5184a b c  - 384a b c  + 960a b c)p
+--R             + 
+--R                          7 3         3 5 2        5 3   2
+--R               (- 21504a b c  + 18816a b c  - 5760a b c)p
+--R             + 
+--R                          7 3         3 5 2         5 3          7
+--R               (- 26784a b c  + 49056a b c  - 36960a b c + 10080a b)p
+--R          *
+--R              +-------+
+--R             \|d x + c
+--R         + 
+--R                 8 4 7      8 4 6       8 4 5        8 4 4         8 4 3
+--R               2b d p  + 56b d p  + 644b d p  + 3920b d p  + 13538b d p
+--R             + 
+--R                     8 4 2         8 4          8 4
+--R               26264b d p  + 26136b d p + 10080b d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                 8   3 7       8       2 6  3 6        8        2 6  3 5
+--R               2b c d p  + (44b c - 14a b )d p  + (380b c - 210a b )d p
+--R             + 
+--R                     8         2 6  3 4         8         2 6  3 3
+--R               (1640b c - 1190a b )d p  + (3698b c - 3150a b )d p
+--R             + 
+--R                     8         2 6  3 2         8         2 6  3
+--R               (4076b c - 3836a b )d p  + (1680b c - 1680a b )d p
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                     8 2      2 6   2 6       8 2 2 5
+--R               (- 12b c  - 12a b c)d p  - 216b c d p
+--R             + 
+--R                       8 2        2 6        4 4  2 4
+--R               (- 1416b c  + 1140a b c - 420a b )d p
+--R             + 
+--R                       8 2        2 6         4 4  2 3
+--R               (- 4176b c  + 5760a b c - 2520a b )d p
+--R             + 
+--R                       8 2        2 6         4 4  2 2
+--R               (- 5484b c  + 9672a b c - 4620a b )d p
+--R             + 
+--R                       8 2        2 6         4 4  2
+--R               (- 2520b c  + 5040a b c - 2520a b )d p
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   8 3       2 6 2    5        8 3       2 6 2       4 4     4
+--R               (48b c  + 144a b c )d p  + (768b c  + 864a b c  - 480a b c)d p
+--R             + 
+--R                     8 3        2 6 2       4 4     3
+--R               (4128b c  - 2736a b c  + 720a b c)d p
+--R             + 
+--R                     8 3         2 6 2         4 4         6 2    2
+--R               (8448b c  - 18576a b c  + 16320a b c - 5040a b )d p
+--R             + 
+--R                     8 3         2 6 2         4 4         6 2
+--R               (5040b c  - 15120a b c  + 15120a b c - 5040a b )d p
+--R          *
+--R             x
+--R         + 
+--R                 8 4       2 6 3      4 4 2  4
+--R           (- 96b c  - 576a b c  - 96a b c )p
+--R         + 
+--R                   8 4        2 6 3        4 4 2  3
+--R           (- 1536b c  - 5376a b c  + 2304a b c )p
+--R         + 
+--R                   8 4        2 6 3         4 4 2        6 2   2
+--R           (- 8256b c  - 7776a b c  + 11904a b c  - 4320a b c)p
+--R         + 
+--R                    8 4         2 6 3         4 4 2        6 2            8 4
+--R           (- 16896b c  + 27264a b c  - 20736a b c  + 5760a b c)p - 10080b c
+--R         + 
+--R                 2 6 3         4 4 2         6 2          8
+--R           40320a b c  - 60480a b c  + 40320a b c - 10080a
+--R      *
+--R                   +-------+
+--R           p log(b\|d x + c  + a)
+--R         %e
+--R     + 
+--R              7      6       5        4         3         2
+--R         (- 2p  - 56p  - 644p  - 3920p  - 13538p  - 26264p  - 26136p - 10080)
+--R      *
+--R            +-------+     p + 8
+--R         (b\|d x + c  + a)
+--R     + 
+--R                7         6          5           4            3            2
+--R           14a p  + 406a p  + 4802a p  + 29890a p  + 105056a p  + 206584a p
+--R         + 
+--R           207648a p + 80640a
+--R      *
+--R            +-------+     p + 7
+--R         (b\|d x + c  + a)
+--R     + 
+--R              2       2  7        2         2  6         2          2  5
+--R           (6b c - 42a )p  + (180b c - 1260a )p  + (2196b c - 15372a )p
+--R         + 
+--R                  2          2  4          2           2  3
+--R           (14040b c - 98280a )p  + (50454b c - 353178a )p
+--R         + 
+--R                   2           2  2           2           2           2
+--R           (100980b c - 706860a )p  + (102864b c - 720048a )p + 40320b c
+--R         + 
+--R                    2
+--R           - 282240a
+--R      *
+--R            +-------+     p + 6
+--R         (b\|d x + c  + a)
+--R     + 
+--R                   2       3  7            2         3  6
+--R           (- 30a b c + 70a )p  + (- 930a b c + 2170a )p
+--R         + 
+--R                      2          3  5              2           3  4
+--R           (- 11730a b c + 27370a )p  + (- 77430a b c + 180670a )p
+--R         + 
+--R                       2           3  3               2            3  2
+--R           (- 286320a b c + 668080a )p  + (- 586920a b c + 1369480a )p
+--R         + 
+--R                       2            3              2           3
+--R           (- 609120a b c + 1421280a )p - 241920a b c + 564480a
+--R      *
+--R            +-------+     p + 5
+--R         (b\|d x + c  + a)
+--R     + 
+--R                4 2      2 2       4  7          4 2        2 2         4  6
+--R           (- 6b c  + 60a b c - 70a )p  + (- 192b c  + 1920a b c - 2240a )p
+--R         + 
+--R                   4 2         2 2          4  5
+--R           (- 2508b c  + 25080a b c - 29260a )p
+--R         + 
+--R                    4 2          2 2           4  4
+--R           (- 17184b c  + 171840a b c - 200480a )p
+--R         + 
+--R                    4 2          2 2           4  3
+--R           (- 65958b c  + 659580a b c - 769510a )p
+--R         + 
+--R                     4 2           2 2            4  2
+--R           (- 139872b c  + 1398720a b c - 1631840a )p
+--R         + 
+--R                     4 2           2 2            4           4 2          2 2
+--R           (- 149256b c  + 1492560a b c - 1741320a )p - 60480b c  + 604800a b c
+--R         + 
+--R                    4
+--R           - 705600a
+--R      *
+--R            +-------+     p + 4
+--R         (b\|d x + c  + a)
+--R     + 
+--R                 4 2      3 2       5  7          4 2        3 2         5  6
+--R           (18a b c  - 60a b c + 42a )p  + (594a b c  - 1980a b c + 1386a )p
+--R         + 
+--R                   4 2         3 2          5  5
+--R           (8046a b c  - 26820a b c + 18774a )p
+--R         + 
+--R                    4 2          3 2           5  4
+--R           (57510a b c  - 191700a b c + 134190a )p
+--R         + 
+--R                     4 2          3 2           5  3
+--R           (231552a b c  - 771840a b c + 540288a )p
+--R         + 
+--R                     4 2           3 2            5  2
+--R           (516456a b c  - 1721520a b c + 1205064a )p
+--R         + 
+--R                     4 2           3 2            5              4 2
+--R           (576864a b c  - 1922880a b c + 1346016a )p + 241920a b c
+--R         + 
+--R                    3 2           5
+--R           - 806400a b c + 564480a
+--R      *
+--R            +-------+     p + 3
+--R         (b\|d x + c  + a)
+--R     + 
+--R              6 3      2 4 2      4 2       6  7
+--R           (2b c  - 18a b c  + 30a b c - 14a )p
+--R         + 
+--R               6 3       2 4 2        4 2        6  6
+--R           (68b c  - 612a b c  + 1020a b c - 476a )p
+--R         + 
+--R                6 3        2 4 2         4 2         6  5
+--R           (956b c  - 8604a b c  + 14340a b c - 6692a )p
+--R         + 
+--R                 6 3         2 4 2          4 2          6  4
+--R           (7160b c  - 64440a b c  + 107400a b c - 50120a )p
+--R         + 
+--R                  6 3          2 4 2          4 2           6  3
+--R           (30578b c  - 275202a b c  + 458670a b c - 214046a )p
+--R         + 
+--R                  6 3          2 4 2           4 2           6  2
+--R           (73412b c  - 660708a b c  + 1101180a b c - 513884a )p
+--R         + 
+--R                  6 3          2 4 2           4 2           6           6 3
+--R           (89424b c  - 804816a b c  + 1341360a b c - 625968a )p + 40320b c
+--R         + 
+--R                    2 4 2          4 2           6
+--R           - 362880a b c  + 604800a b c - 282240a
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R                  6 3     3 4 2     5 2      7  7
+--R           (- 2a b c  + 6a b c  - 6a b c + 2a )p
+--R         + 
+--R                   6 3       3 4 2       5 2       7  6
+--R           (- 70a b c  + 210a b c  - 210a b c + 70a )p
+--R         + 
+--R                     6 3        3 4 2        5 2         7  5
+--R           (- 1022a b c  + 3066a b c  - 3066a b c + 1022a )p
+--R         + 
+--R                     6 3         3 4 2         5 2         7  4
+--R           (- 8050a b c  + 24150a b c  - 24150a b c + 8050a )p
+--R         + 
+--R                      6 3          3 4 2          5 2          7  3
+--R           (- 36848a b c  + 110544a b c  - 110544a b c + 36848a )p
+--R         + 
+--R                      6 3          3 4 2          5 2          7  2
+--R           (- 97720a b c  + 293160a b c  - 293160a b c + 97720a )p
+--R         + 
+--R                       6 3          3 4 2          5 2           7
+--R           (- 138528a b c  + 415584a b c  - 415584a b c + 138528a )p
+--R         + 
+--R                     6 3          3 4 2          5 2          7
+--R           - 80640a b c  + 241920a b c  - 241920a b c + 80640a
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R  /
+--R        8 4 8      8 4 7       8 4 6        8 4 5         8 4 4         8 4 3
+--R       b d p  + 36b d p  + 546b d p  + 4536b d p  + 22449b d p  + 67284b d p
+--R     + 
+--R              8 4 2          8 4          8 4
+--R       118124b d p  + 109584b d p + 40320b d
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            8 4 4    8   3 3  +-------+      7 4 4      7   3 3
+--R         ((b d x  + b c d x )\|d x + c  + a b d x  + a b c d x )
+--R      *
+--R                   +-------+
+--R           p log(b\|d x + c  + a)
+--R         %e
+--R     + 
+--R            +-------+                  +-------+     p + 7
+--R       (- a\|d x + c  - b d x - b c)(b\|d x + c  + a)
+--R     + 
+--R          2 +-------+                        +-------+     p + 6
+--R       (7a \|d x + c  + 7a b d x + 7a b c)(b\|d x + c  + a)
+--R     + 
+--R               2       3  +-------+      3       2          3 2      2
+--R         ((3a b c - 21a )\|d x + c  + (3b c - 21a b)d x + 3b c  - 21a b c)
+--R      *
+--R            +-------+     p + 5
+--R         (b\|d x + c  + a)
+--R     + 
+--R                 2 2       4  +-------+           3       3             3 2
+--R           (- 15a b c + 35a )\|d x + c  + (- 15a b c + 35a b)d x - 15a b c
+--R         + 
+--R              3
+--R           35a b c
+--R      *
+--R            +-------+     p + 4
+--R         (b\|d x + c  + a)
+--R     + 
+--R                  4 2      3 2       5  +-------+
+--R           (- 3a b c  + 30a b c - 35a )\|d x + c
+--R         + 
+--R                5 2      2 3       4          5 3      2 3 2      4
+--R           (- 3b c  + 30a b c - 35a b)d x - 3b c  + 30a b c  - 35a b c
+--R      *
+--R            +-------+     p + 3
+--R         (b\|d x + c  + a)
+--R     + 
+--R              2 4 2      4 2       6  +-------+        5 2      3 3       5
+--R           (9a b c  - 30a b c + 21a )\|d x + c  + (9a b c  - 30a b c + 21a b)d x
+--R         + 
+--R               5 3      3 3 2      5
+--R           9a b c  - 30a b c  + 21a b c
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R               6 3     3 4 2      5 2      7  +-------+
+--R           (a b c  - 9a b c  + 15a b c - 7a )\|d x + c
+--R         + 
+--R             7 3     2 5 2      4 3      6         7 4     2 5 3      4 3 2
+--R           (b c  - 9a b c  + 15a b c - 7a b)d x + b c  - 9a b c  + 15a b c
+--R         + 
+--R               6
+--R           - 7a b c
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R     + 
+--R               2 6 3     4 4 2     6 2     8  +-------+
+--R           (- a b c  + 3a b c  - 3a b c + a )\|d x + c
+--R         + 
+--R                 7 3     3 5 2     5 3     7           7 4     3 5 3     5 3 2
+--R           (- a b c  + 3a b c  - 3a b c + a b)d x - a b c  + 3a b c  - 3a b c
+--R         + 
+--R            7
+--R           a b c
+--R      *
+--R            +-------+     p
+--R         (b\|d x + c  + a)
+--R  /
+--R       8 4     8   3  +-------+      7 4       7   3
+--R     (b d x + b c d )\|d x + c  + a b d x + a b c d
+--R                                                    Type: Expression(Integer)
+--E 40
+
+)clear all
+
+--S 41 of 649
+t0:=x^2*(a+b*sqrt(c+d*x))^p
+--R 
+--R
+--R         2   +-------+     p
+--R   (1)  x (b\|d x + c  + a)
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 649
+r0:=-2*a*(a^2-b^2*c)^2*(a+b*sqrt(c+d*x))^(1+p)/(b^6*d^3*(1+p))+2*(5*a^4-_
+   6*a^2*b^2*c+b^4*c^2)*(a+b*sqrt(c+d*x))^(2+p)/(b^6*d^3*(2+p))-_
+   4*a*(5*a^2-3*b^2*c)*(a+b*sqrt(c+d*x))^(3+p)/(b^6*d^3*(3+p))+_
+   4*(5*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(4+p)/(b^6*d^3*(4+p))-_
+   10*a*(a+b*sqrt(c+d*x))^(5+p)/(b^6*d^3*(5+p))+2*(a+b*_
+   sqrt(c+d*x))^(6+p)/(b^6*d^3*(6+p))
+--R 
+--R
+--R   (2)
+--R          5      4       3       2                 +-------+     p + 6
+--R       (2p  + 30p  + 170p  + 450p  + 548p + 240)(b\|d x + c  + a)
+--R     + 
+--R                 5         4         3          2
+--R         (- 10a p  - 160a p  - 950a p  - 2600a p  - 3240a p - 1440a)
+--R      *
+--R            +-------+     p + 5
+--R         (b\|d x + c  + a)
+--R     + 
+--R                2       2  5         2        2  4          2         2  3
+--R           (- 4b c + 20a )p  + (- 68b c + 340a )p  + (- 428b c + 2140a )p
+--R         + 
+--R                   2         2  2           2         2         2         2
+--R           (- 1228b c + 6140a )p  + (- 1584b c + 7920a )p - 720b c + 3600a
+--R      *
+--R            +-------+     p + 4
+--R         (b\|d x + c  + a)
+--R     + 
+--R                 2       3  5          2        3  4           2         3  3
+--R           (12a b c - 20a )p  + (216a b c - 360a )p  + (1452a b c - 2420a )p
+--R         + 
+--R                   2         3  2           2          3            2         3
+--R           (4464a b c - 7440a )p  + (6096a b c - 10160a )p + 2880a b c - 4800a
+--R      *
+--R            +-------+     p + 3
+--R         (b\|d x + c  + a)
+--R     + 
+--R              4 2      2 2       4  5       4 2       2 2        4  4
+--R           (2b c  - 12a b c + 10a )p  + (38b c  - 228a b c + 190a )p
+--R         + 
+--R                4 2        2 2         4  3        4 2        2 2         4  2
+--R           (274b c  - 1644a b c + 1370a )p  + (922b c  - 5532a b c + 4610a )p
+--R         + 
+--R                 4 2        2 2         4         4 2        2 2         4
+--R           (1404b c  - 8424a b c + 7020a )p + 720b c  - 4320a b c + 3600a
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R                  4 2     3 2      5  5           4 2      3 2       5  4
+--R           (- 2a b c  + 4a b c - 2a )p  + (- 40a b c  + 80a b c - 40a )p
+--R         + 
+--R                    4 2       3 2        5  3
+--R           (- 310a b c  + 620a b c - 310a )p
+--R         + 
+--R                     4 2        3 2         5  2
+--R           (- 1160a b c  + 2320a b c - 1160a )p
+--R         + 
+--R                   4 2        3 2         5            4 2        3 2         5
+--R         (- 2088a b c  + 4176a b c - 2088a )p - 1440a b c  + 2880a b c - 1440a
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R  /
+--R        6 3 6      6 3 5       6 3 4       6 3 3        6 3 2        6 3
+--R       b d p  + 21b d p  + 175b d p  + 735b d p  + 1624b d p  + 1764b d p
+--R     + 
+--R           6 3
+--R       720b d
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  5 2 5        5 2 4        5 2 3         5 2 2        5 2   2
+--R             (2a b d p  + 20a b d p  + 70a b d p  + 100a b d p  + 48a b d p)x
+--R           + 
+--R                        5     4            5       3 3    3
+--R                 - 16a b c d p  + (- 120a b c + 40a b )d p
+--R               + 
+--R                          5        3 3    2            5       3 3
+--R                 (- 248a b c + 120a b )d p  + (- 144a b c + 80a b )d p
+--R            *
+--R               x
+--R           + 
+--R                   5 2      3 3   3          5 2       3 3   2
+--R             (48a b c  + 16a b c)p  + (336a b c  - 144a b c)p
+--R           + 
+--R                    5 2       3 3        5
+--R             (528a b c  - 640a b c + 240a b)p
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R            6 3 5      6 3 4       6 3 3       6 3 2       6 3        6 3  3
+--R         (2b d p  + 30b d p  + 170b d p  + 450b d p  + 548b d p + 240b d )x
+--R       + 
+--R               6   2 5       6       2 4  2 4       6       2 4  2 3
+--R             2b c d p  + (22b c - 10a b )d p  + (82b c - 60a b )d p
+--R           + 
+--R                  6        2 4  2 2       6       2 4  2
+--R             (122b c - 110a b )d p  + (60b c - 60a b )d p
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                  6 2     2 4     4         6 2      2 4     3
+--R             (- 8b c  - 8a b c)d p  + (- 72b c  + 24a b c)d p
+--R           + 
+--R                    6 2       2 4        4 2    2
+--R             (- 184b c  + 272a b c - 120a b )d p
+--R           + 
+--R                    6 2       2 4        4 2
+--R             (- 120b c  + 240a b c - 120a b )d p
+--R        *
+--R           x
+--R       + 
+--R             6 3      2 4 2  3        6 3       2 4 2      4 2   2
+--R         (16b c  + 48a b c )p  + (144b c  + 144a b c  - 96a b c)p
+--R       + 
+--R              6 3       2 4 2       4 2          6 3       2 4 2       4 2
+--R         (368b c  - 384a b c  + 144a b c)p + 240b c  - 720a b c  + 720a b c
+--R       + 
+--R               6
+--R         - 240a
+--R    *
+--R                 +-------+
+--R         p log(b\|d x + c  + a)
+--R       %e
+--R  /
+--R        6 3 6      6 3 5       6 3 4       6 3 3        6 3 2        6 3
+--R       b d p  + 21b d p  + 175b d p  + 735b d p  + 1624b d p  + 1764b d p
+--R     + 
+--R           6 3
+--R       720b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 43
+
+--S 44 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    5 2 5        5 2 4        5 2 3         5 2 2        5 2   2
+--R               (2a b d p  + 20a b d p  + 70a b d p  + 100a b d p  + 48a b d p)x
+--R             + 
+--R                          5     4            5       3 3    3
+--R                   - 16a b c d p  + (- 120a b c + 40a b )d p
+--R                 + 
+--R                            5        3 3    2            5       3 3
+--R                   (- 248a b c + 120a b )d p  + (- 144a b c + 80a b )d p
+--R              *
+--R                 x
+--R             + 
+--R                     5 2      3 3   3          5 2       3 3   2
+--R               (48a b c  + 16a b c)p  + (336a b c  - 144a b c)p
+--R             + 
+--R                      5 2       3 3        5
+--R               (528a b c  - 640a b c + 240a b)p
+--R          *
+--R              +-------+
+--R             \|d x + c
+--R         + 
+--R              6 3 5      6 3 4       6 3 3       6 3 2       6 3        6 3  3
+--R           (2b d p  + 30b d p  + 170b d p  + 450b d p  + 548b d p + 240b d )x
+--R         + 
+--R                 6   2 5       6       2 4  2 4       6       2 4  2 3
+--R               2b c d p  + (22b c - 10a b )d p  + (82b c - 60a b )d p
+--R             + 
+--R                    6        2 4  2 2       6       2 4  2
+--R               (122b c - 110a b )d p  + (60b c - 60a b )d p
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    6 2     2 4     4         6 2      2 4     3
+--R               (- 8b c  - 8a b c)d p  + (- 72b c  + 24a b c)d p
+--R             + 
+--R                      6 2       2 4        4 2    2
+--R               (- 184b c  + 272a b c - 120a b )d p
+--R             + 
+--R                      6 2       2 4        4 2
+--R               (- 120b c  + 240a b c - 120a b )d p
+--R          *
+--R             x
+--R         + 
+--R               6 3      2 4 2  3        6 3       2 4 2      4 2   2
+--R           (16b c  + 48a b c )p  + (144b c  + 144a b c  - 96a b c)p
+--R         + 
+--R                6 3       2 4 2       4 2          6 3       2 4 2       4 2
+--R           (368b c  - 384a b c  + 144a b c)p + 240b c  - 720a b c  + 720a b c
+--R         + 
+--R                 6
+--R           - 240a
+--R      *
+--R                   +-------+
+--R           p log(b\|d x + c  + a)
+--R         %e
+--R     + 
+--R            5      4       3       2                 +-------+     p + 6
+--R       (- 2p  - 30p  - 170p  - 450p  - 548p - 240)(b\|d x + c  + a)
+--R     + 
+--R               5         4         3          2
+--R         (10a p  + 160a p  + 950a p  + 2600a p  + 3240a p + 1440a)
+--R      *
+--R            +-------+     p + 5
+--R         (b\|d x + c  + a)
+--R     + 
+--R              2       2  5       2        2  4        2         2  3
+--R           (4b c - 20a )p  + (68b c - 340a )p  + (428b c - 2140a )p
+--R         + 
+--R                 2         2  2         2         2         2         2
+--R           (1228b c - 6140a )p  + (1584b c - 7920a )p + 720b c - 3600a
+--R      *
+--R            +-------+     p + 4
+--R         (b\|d x + c  + a)
+--R     + 
+--R                   2       3  5            2        3  4
+--R           (- 12a b c + 20a )p  + (- 216a b c + 360a )p
+--R         + 
+--R                     2         3  3             2         3  2
+--R           (- 1452a b c + 2420a )p  + (- 4464a b c + 7440a )p
+--R         + 
+--R                     2          3            2         3
+--R           (- 6096a b c + 10160a )p - 2880a b c + 4800a
+--R      *
+--R            +-------+     p + 3
+--R         (b\|d x + c  + a)
+--R     + 
+--R                4 2      2 2       4  5         4 2       2 2        4  4
+--R           (- 2b c  + 12a b c - 10a )p  + (- 38b c  + 228a b c - 190a )p
+--R         + 
+--R                  4 2        2 2         4  3
+--R           (- 274b c  + 1644a b c - 1370a )p
+--R         + 
+--R                  4 2        2 2         4  2
+--R           (- 922b c  + 5532a b c - 4610a )p
+--R         + 
+--R                   4 2        2 2         4         4 2        2 2         4
+--R           (- 1404b c  + 8424a b c - 7020a )p - 720b c  + 4320a b c - 3600a
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R                4 2     3 2      5  5         4 2      3 2       5  4
+--R           (2a b c  - 4a b c + 2a )p  + (40a b c  - 80a b c + 40a )p
+--R         + 
+--R                  4 2       3 2        5  3
+--R           (310a b c  - 620a b c + 310a )p
+--R         + 
+--R                   4 2        3 2         5  2
+--R           (1160a b c  - 2320a b c + 1160a )p
+--R         + 
+--R                   4 2        3 2         5            4 2        3 2         5
+--R           (2088a b c  - 4176a b c + 2088a )p + 1440a b c  - 2880a b c + 1440a
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R  /
+--R        6 3 6      6 3 5       6 3 4       6 3 3        6 3 2        6 3
+--R       b d p  + 21b d p  + 175b d p  + 735b d p  + 1624b d p  + 1764b d p
+--R     + 
+--R           6 3
+--R       720b d
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            6 3 3    6   2 2  +-------+      5 3 3      5   2 2
+--R         ((b d x  + b c d x )\|d x + c  + a b d x  + a b c d x )
+--R      *
+--R                   +-------+
+--R           p log(b\|d x + c  + a)
+--R         %e
+--R     + 
+--R            +-------+                  +-------+     p + 5
+--R       (- a\|d x + c  - b d x - b c)(b\|d x + c  + a)
+--R     + 
+--R          2 +-------+                        +-------+     p + 4
+--R       (5a \|d x + c  + 5a b d x + 5a b c)(b\|d x + c  + a)
+--R     + 
+--R               2       3  +-------+      3       2          3 2      2
+--R         ((2a b c - 10a )\|d x + c  + (2b c - 10a b)d x + 2b c  - 10a b c)
+--R      *
+--R            +-------+     p + 3
+--R         (b\|d x + c  + a)
+--R     + 
+--R                  2 2       4  +-------+          3       3            3 2
+--R             (- 6a b c + 10a )\|d x + c  + (- 6a b c + 10a b)d x - 6a b c
+--R           + 
+--R                3
+--R             10a b c
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R                 4 2     3 2      5  +-------+       5 2     2 3      4
+--R           (- a b c  + 6a b c - 5a )\|d x + c  + (- b c  + 6a b c - 5a b)d x
+--R         + 
+--R              5 3     2 3 2     4
+--R           - b c  + 6a b c  - 5a b c
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R     + 
+--R             2 4 2     4 2     6  +-------+       5 2     3 3     5
+--R           (a b c  - 2a b c + a )\|d x + c  + (a b c  - 2a b c + a b)d x
+--R         + 
+--R              5 3     3 3 2    5
+--R           a b c  - 2a b c  + a b c
+--R      *
+--R            +-------+     p
+--R         (b\|d x + c  + a)
+--R  /
+--R       6 3     6   2  +-------+      5 3       5   2
+--R     (b d x + b c d )\|d x + c  + a b d x + a b c d
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 649
+t0:=x*(a+b*sqrt(c+d*x))^p
+--R 
+--R
+--R             +-------+     p
+--R   (1)  x (b\|d x + c  + a)
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 649
+r0:=-2*a*(a^2-b^2*c)*(a+b*sqrt(c+d*x))^(1+p)/(b^4*d^2*(1+p))+_
+   2*(3*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(2+p)/(b^4*d^2*(2+p))-_
+   6*a*(a+b*sqrt(c+d*x))^(3+p)/(b^4*d^2*(3+p))+2*(a+b*sqrt(c+d*x))^(4+p)/_
+   (b^4*d^2*(4+p))
+--R 
+--R
+--R   (2)
+--R          3      2               +-------+     p + 4
+--R       (2p  + 12p  + 22p + 12)(b\|d x + c  + a)
+--R     + 
+--R              3        2                  +-------+     p + 3
+--R       (- 6a p  - 42a p  - 84a p - 48a)(b\|d x + c  + a)
+--R     + 
+--R                2      2  3         2       2  2         2        2        2
+--R           (- 2b c + 6a )p  + (- 16b c + 48a )p  + (- 38b c + 114a )p - 24b c
+--R         + 
+--R              2
+--R           72a
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R                2      3  3         2       3  2         2       3          2
+--R           (2a b c - 2a )p  + (18a b c - 18a )p  + (52a b c - 52a )p + 48a b c
+--R         + 
+--R                3
+--R           - 48a
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R  /
+--R      4 2 4      4 2 3      4 2 2      4 2       4 2
+--R     b d p  + 10b d p  + 35b d p  + 50b d p + 24b d
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  3   3       3   2       3            3   2
+--R             (2a b d p  + 6a b d p  + 4a b d p)x - 8a b c p
+--R           + 
+--R                     3       3
+--R             (- 20a b c + 12a b)p
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R            4 2 3      4 2 2      4 2       4 2  2
+--R         (2b d p  + 12b d p  + 22b d p + 12b d )x
+--R       + 
+--R            4     3      4      2 2    2      4      2 2
+--R         (2b c d p  + (8b c - 6a b )d p  + (6b c - 6a b )d p)x
+--R       + 
+--R              4 2     2 2   2         4 2     2 2         4 2      2 2       4
+--R         (- 4b c  - 4a b c)p  + (- 16b c  + 8a b c)p - 12b c  + 24a b c - 12a
+--R    *
+--R                 +-------+
+--R         p log(b\|d x + c  + a)
+--R       %e
+--R  /
+--R      4 2 4      4 2 3      4 2 2      4 2       4 2
+--R     b d p  + 10b d p  + 35b d p  + 50b d p + 24b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    3   3       3   2       3            3   2
+--R               (2a b d p  + 6a b d p  + 4a b d p)x - 8a b c p
+--R             + 
+--R                       3       3
+--R               (- 20a b c + 12a b)p
+--R          *
+--R              +-------+
+--R             \|d x + c
+--R         + 
+--R              4 2 3      4 2 2      4 2       4 2  2
+--R           (2b d p  + 12b d p  + 22b d p + 12b d )x
+--R         + 
+--R              4     3      4      2 2    2      4      2 2
+--R           (2b c d p  + (8b c - 6a b )d p  + (6b c - 6a b )d p)x
+--R         + 
+--R              4 2     2 2   2         4 2     2 2         4 2      2 2       4
+--R         (- 4b c  - 4a b c)p  + (- 16b c  + 8a b c)p - 12b c  + 24a b c - 12a
+--R      *
+--R                   +-------+
+--R           p log(b\|d x + c  + a)
+--R         %e
+--R     + 
+--R            3      2               +-------+     p + 4
+--R       (- 2p  - 12p  - 22p - 12)(b\|d x + c  + a)
+--R     + 
+--R            3        2                  +-------+     p + 3
+--R       (6a p  + 42a p  + 84a p + 48a)(b\|d x + c  + a)
+--R     + 
+--R             2      2  3       2       2  2       2        2        2       2
+--R         ((2b c - 6a )p  + (16b c - 48a )p  + (38b c - 114a )p + 24b c - 72a )
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R                  2      3  3           2       3  2           2       3
+--R           (- 2a b c + 2a )p  + (- 18a b c + 18a )p  + (- 52a b c + 52a )p
+--R         + 
+--R                  2       3
+--R           - 48a b c + 48a
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R  /
+--R      4 2 4      4 2 3      4 2 2      4 2       4 2
+--R     b d p  + 10b d p  + 35b d p  + 50b d p + 24b d
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            4 2 2    4       +-------+      3 2 2      3
+--R         ((b d x  + b c d x)\|d x + c  + a b d x  + a b c d x)
+--R      *
+--R                   +-------+
+--R           p log(b\|d x + c  + a)
+--R         %e
+--R     + 
+--R            +-------+                  +-------+     p + 3
+--R       (- a\|d x + c  - b d x - b c)(b\|d x + c  + a)
+--R     + 
+--R          2 +-------+                        +-------+     p + 2
+--R       (3a \|d x + c  + 3a b d x + 3a b c)(b\|d x + c  + a)
+--R     + 
+--R              2      3  +-------+     3      2         3 2     2
+--R         ((a b c - 3a )\|d x + c  + (b c - 3a b)d x + b c  - 3a b c)
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R     + 
+--R              2 2     4  +-------+         3     3           3 2    3
+--R         ((- a b c + a )\|d x + c  + (- a b c + a b)d x - a b c  + a b c)
+--R      *
+--R            +-------+     p
+--R         (b\|d x + c  + a)
+--R  /
+--R       4 2     4     +-------+      3 2       3
+--R     (b d x + b c d)\|d x + c  + a b d x + a b c d
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 649
+t0:=(a+b*sqrt(c+d*x))^p
+--R 
+--R
+--R           +-------+     p
+--R   (1)  (b\|d x + c  + a)
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 649
+r0:=-2*a*(a+b*sqrt(c+d*x))^(1+p)/(b^2*d*(1+p))+_
+   2*(a+b*sqrt(c+d*x))^(2+p)/(b^2*d*(2+p))
+--R 
+--R
+--R                   +-------+     p + 2                   +-------+     p + 1
+--R        (2p + 2)(b\|d x + c  + a)      + (- 2a p - 4a)(b\|d x + c  + a)
+--R   (2)  --------------------------------------------------------------------
+--R                                2   2     2        2
+--R                               b d p  + 3b d p + 2b d
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +-------+      2        2        2        2      2
+--R       (2a b p\|d x + c  + (2b d p + 2b d)x + 2b c p + 2b c - 2a )
+--R    *
+--R                 +-------+
+--R         p log(b\|d x + c  + a)
+--R       %e
+--R  /
+--R      2   2     2        2
+--R     b d p  + 3b d p + 2b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 53
+
+--S 54 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 +-------+      2        2        2        2      2
+--R         (2a b p\|d x + c  + (2b d p + 2b d)x + 2b c p + 2b c - 2a )
+--R      *
+--R                   +-------+
+--R           p log(b\|d x + c  + a)
+--R         %e
+--R     + 
+--R                    +-------+     p + 2                 +-------+     p + 1
+--R       (- 2p - 2)(b\|d x + c  + a)      + (2a p + 4a)(b\|d x + c  + a)
+--R  /
+--R      2   2     2        2
+--R     b d p  + 3b d p + 2b d
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                            +-------+
+--R          2       2   +-------+                     p log(b\|d x + c  + a)
+--R       ((b d x + b c)\|d x + c  + a b d x + a b c)%e
+--R     + 
+--R            +-------+                  +-------+     p + 1
+--R       (- a\|d x + c  - b d x - b c)(b\|d x + c  + a)
+--R     + 
+--R         2 +-------+                      +-------+     p
+--R       (a \|d x + c  + a b d x + a b c)(b\|d x + c  + a)
+--R  /
+--R       2       2   +-------+
+--R     (b d x + b c)\|d x + c  + a b d x + a b c
+--R                                                    Type: Expression(Integer)
+--E 55
+
+)clear all
+
+--S 56 of 649
+t0:=(a+b*sqrt(c+d*x))^p/x
+--R 
+--R
+--R           +-------+     p
+--R        (b\|d x + c  + a)
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 649
+--r0:=-hypergeometric(1,1+p,2+p,(a+b*sqrt(c+d*x))/(a-b*sqrt(c)))*_
+--   (a+b*sqrt(c+d*x))^(1+p)/((1+p)*(a-b*sqrt(c)))-_
+--   hypergeometric(1,1+p,2+p,(a+b*sqrt(c+d*x))/(a+b*sqrt(c)))*_
+--   (a+b*sqrt(c+d*x))^(1+p)/((1+p)*(a+b*sqrt(c)))
+--E 57
+
+--S 58 of 649
+--a0:=integrate(t0,x)
+--E 58
+
+--S 59 of 649
+--m0:=a0-r0
+--E 59
+
+--S 60 of 649
+--d0:=D(m0,x)
+--E 60
+
+)clear all
+
+--S 61 of 649
+t0:=(a+b*(c*x)^n)^(5/2)/x
+--R 
+--R
+--R                                         +------------+
+--R          2      n 2             n    2  |       n
+--R        (b ((c x) )  + 2a b (c x)  + a )\|b (c x)  + a
+--R   (1)  -----------------------------------------------
+--R                               x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 649
+r0:=2/3*a*(a+b*(c*x)^n)^(3/2)/n+2/5*(a+b*(c*x)^n)^(5/2)/n-_
+   2*a^(5/2)*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))/n+2*a^2*sqrt(a+b*(c*x)^n)/n
+--R 
+--R
+--R   (2)
+--R                        +------------+
+--R                        |       n
+--R            2 +-+      \|b (c x)  + a
+--R       - 30a \|a atanh(---------------)
+--R                              +-+
+--R                             \|a
+--R     + 
+--R                                            +------------+
+--R          2      n 2              n      2  |       n
+--R       (6b ((c x) )  + 22a b (c x)  + 46a )\|b (c x)  + a
+--R  /
+--R     15n
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             +------------------+
+--R                         +-+ |    n log(c x)            n log(c x)
+--R            2 +-+    - 2\|a \|b %e           + a  + b %e           + 2a
+--R         15a \|a log(--------------------------------------------------)
+--R                                          n log(c x)
+--R                                        %e
+--R       + 
+--R                                                          +------------------+
+--R            2   n log(c x) 2           n log(c x)      2  |    n log(c x)
+--R         (6b (%e          )  + 22a b %e           + 46a )\|b %e           + a
+--R    /
+--R       15n
+--R     ,
+--R
+--R                           +------------------+
+--R                           |    n log(c x)
+--R              2 +---+     \|b %e           + a
+--R         - 30a \|- a atan(---------------------)
+--R                                   +---+
+--R                                  \|- a
+--R       + 
+--R                                                          +------------------+
+--R            2   n log(c x) 2           n log(c x)      2  |    n log(c x)
+--R         (6b (%e          )  + 22a b %e           + 46a )\|b %e           + a
+--R    /
+--R       15n
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 63
+
+--S 64 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           +------------------+
+--R                       +-+ |    n log(c x)            n log(c x)
+--R          2 +-+    - 2\|a \|b %e           + a  + b %e           + 2a
+--R       15a \|a log(--------------------------------------------------)
+--R                                        n log(c x)
+--R                                      %e
+--R     + 
+--R                                                        +------------------+
+--R          2   n log(c x) 2           n log(c x)      2  |    n log(c x)
+--R       (6b (%e          )  + 22a b %e           + 46a )\|b %e           + a
+--R     + 
+--R                      +------------+
+--R                      |       n
+--R          2 +-+      \|b (c x)  + a
+--R       30a \|a atanh(---------------)
+--R                            +-+
+--R                           \|a
+--R     + 
+--R                                              +------------+
+--R            2      n 2              n      2  |       n
+--R       (- 6b ((c x) )  - 22a b (c x)  - 46a )\|b (c x)  + a
+--R  /
+--R     15n
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                  3     n   n log(c x) 3       2     n   n log(c x) 2
+--R               - b (c x) (%e          )  - 4a b (c x) (%e          )
+--R             + 
+--R                   2       n  n log(c x)     3     n
+--R               - 5a b (c x) %e           - 2a (c x)
+--R          *
+--R              +------------+
+--R              |       n
+--R             \|b (c x)  + a
+--R         + 
+--R                   3         n - 1      n 3       2         n - 1      n 2
+--R               - 2b c x (c x)     ((c x) )  - 6a b c x (c x)     ((c x) )
+--R             + 
+--R                   2           n - 1     n     3         n - 1
+--R               - 6a b c x (c x)     (c x)  - 2a c x (c x)
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R             3     n +-+   n log(c x) 3       2     n +-+   n log(c x) 2
+--R           2b (c x) \|a (%e          )  + 6a b (c x) \|a (%e          )
+--R         + 
+--R             2       n +-+  n log(c x)     3     n +-+
+--R           6a b (c x) \|a %e           + 2a (c x) \|a
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  + a
+--R     + 
+--R            4         n - 1      n 3       3         n - 1      n 2
+--R           b c x (c x)     ((c x) )  + 3a b c x (c x)     ((c x) )
+--R         + 
+--R             2 2         n - 1     n    3           n - 1
+--R           3a b c x (c x)     (c x)  + a b c x (c x)
+--R      *
+--R           n log(c x)
+--R         %e
+--R     + 
+--R           3         n - 1      n 3     2 2         n - 1      n 2
+--R       2a b c x (c x)     ((c x) )  + 6a b c x (c x)     ((c x) )
+--R     + 
+--R         3           n - 1     n     4         n - 1
+--R       6a b c x (c x)     (c x)  + 2a c x (c x)
+--R  /
+--R                     +------------+ +------------------+
+--R               n +-+ |       n      |    n log(c x)
+--R       2x (c x) \|a \|b (c x)  + a \|b %e           + a
+--R     + 
+--R                                                +------------+
+--R                   n  n log(c x)             n  |       n
+--R       (- b x (c x) %e           - 2a x (c x) )\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         +------------------+
+--R                         |    n log(c x)
+--R            2 +---+     \|b %e           + a
+--R       - 30a \|- a atan(---------------------)
+--R                                 +---+
+--R                                \|- a
+--R     + 
+--R                                                        +------------------+
+--R          2   n log(c x) 2           n log(c x)      2  |    n log(c x)
+--R       (6b (%e          )  + 22a b %e           + 46a )\|b %e           + a
+--R     + 
+--R                      +------------+
+--R                      |       n
+--R          2 +-+      \|b (c x)  + a
+--R       30a \|a atanh(---------------)
+--R                            +-+
+--R                           \|a
+--R     + 
+--R                                              +------------+
+--R            2      n 2              n      2  |       n
+--R       (- 6b ((c x) )  - 22a b (c x)  - 46a )\|b (c x)  + a
+--R  /
+--R     15n
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R              3         n - 1      n 3       2         n - 1      n 2
+--R           - b c x (c x)     ((c x) )  - 3a b c x (c x)     ((c x) )
+--R         + 
+--R               2           n - 1     n    3         n - 1
+--R           - 3a b c x (c x)     (c x)  - a c x (c x)
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R            3     n   n log(c x) 3       2     n   n log(c x) 2
+--R           b (c x) (%e          )  + 3a b (c x) (%e          )
+--R         + 
+--R             2       n  n log(c x)    3     n
+--R           3a b (c x) %e           + a (c x)
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  + a
+--R  /
+--R              +------------+ +------------------+
+--R            n |       n      |    n log(c x)
+--R     x (c x) \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 67
+
+)clear all
+
+--S 68 of 649
+t0:=(a+b*(c*x)^n)^(3/2)/x
+--R 
+--R
+--R                       +------------+
+--R                n      |       n
+--R        (b (c x)  + a)\|b (c x)  + a
+--R   (1)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 649
+r0:=2/3*(a+b*(c*x)^n)^(3/2)/n-2*a^(3/2)*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))/n+_
+   2*a*sqrt(a+b*(c*x)^n)/n
+--R 
+--R
+--R                       +------------+
+--R                       |       n                          +------------+
+--R             +-+      \|b (c x)  + a              n       |       n
+--R        - 6a\|a atanh(---------------) + (2b (c x)  + 8a)\|b (c x)  + a
+--R                             +-+
+--R                            \|a
+--R   (2)  ----------------------------------------------------------------
+--R                                       3n
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                           +------------------+
+--R                       +-+ |    n log(c x)            n log(c x)
+--R            +-+    - 2\|a \|b %e           + a  + b %e           + 2a
+--R         3a\|a log(--------------------------------------------------)
+--R                                        n log(c x)
+--R                                      %e
+--R       + 
+--R                                +------------------+
+--R               n log(c x)       |    n log(c x)
+--R         (2b %e           + 8a)\|b %e           + a
+--R    /
+--R       3n
+--R     ,
+--R
+--R                         +------------------+
+--R                         |    n log(c x)
+--R              +---+     \|b %e           + a
+--R         - 6a\|- a atan(---------------------)
+--R                                 +---+
+--R                                \|- a
+--R       + 
+--R                                +------------------+
+--R               n log(c x)       |    n log(c x)
+--R         (2b %e           + 8a)\|b %e           + a
+--R    /
+--R       3n
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 70
+
+--S 71 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         +------------------+
+--R                     +-+ |    n log(c x)            n log(c x)
+--R          +-+    - 2\|a \|b %e           + a  + b %e           + 2a
+--R       3a\|a log(--------------------------------------------------)
+--R                                      n log(c x)
+--R                                    %e
+--R     + 
+--R                              +------------------+
+--R             n log(c x)       |    n log(c x)
+--R       (2b %e           + 8a)\|b %e           + a
+--R     + 
+--R                    +------------+
+--R                    |       n                            +------------+
+--R          +-+      \|b (c x)  + a                n       |       n
+--R       6a\|a atanh(---------------) + (- 2b (c x)  - 8a)\|b (c x)  + a
+--R                          +-+
+--R                         \|a
+--R  /
+--R     3n
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                 2     n   n log(c x) 2             n  n log(c x)     2     n
+--R             (- b (c x) (%e          )  - 3a b (c x) %e           - 2a (c x) )
+--R          *
+--R              +------------+
+--R              |       n
+--R             \|b (c x)  + a
+--R         + 
+--R                   2         n - 1      n 2                 n - 1     n
+--R               - 2b c x (c x)     ((c x) )  - 4a b c x (c x)     (c x)
+--R             + 
+--R                   2         n - 1
+--R               - 2a c x (c x)
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R             2     n +-+   n log(c x) 2             n +-+  n log(c x)
+--R           2b (c x) \|a (%e          )  + 4a b (c x) \|a %e
+--R         + 
+--R             2     n +-+
+--R           2a (c x) \|a
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  + a
+--R     + 
+--R            3         n - 1      n 2       2         n - 1     n
+--R           b c x (c x)     ((c x) )  + 2a b c x (c x)     (c x)
+--R         + 
+--R            2           n - 1
+--R           a b c x (c x)
+--R      *
+--R           n log(c x)
+--R         %e
+--R     + 
+--R           2         n - 1      n 2     2           n - 1     n
+--R       2a b c x (c x)     ((c x) )  + 4a b c x (c x)     (c x)
+--R     + 
+--R         3         n - 1
+--R       2a c x (c x)
+--R  /
+--R                     +------------+ +------------------+
+--R               n +-+ |       n      |    n log(c x)
+--R       2x (c x) \|a \|b (c x)  + a \|b %e           + a
+--R     + 
+--R                                                +------------+
+--R                   n  n log(c x)             n  |       n
+--R       (- b x (c x) %e           - 2a x (c x) )\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +------------------+
+--R                       |    n log(c x)
+--R            +---+     \|b %e           + a
+--R       - 6a\|- a atan(---------------------)
+--R                               +---+
+--R                              \|- a
+--R     + 
+--R                              +------------------+
+--R             n log(c x)       |    n log(c x)
+--R       (2b %e           + 8a)\|b %e           + a
+--R     + 
+--R                    +------------+
+--R                    |       n                            +------------+
+--R          +-+      \|b (c x)  + a                n       |       n
+--R       6a\|a atanh(---------------) + (- 2b (c x)  - 8a)\|b (c x)  + a
+--R                          +-+
+--R                         \|a
+--R  /
+--R     3n
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R              2         n - 1      n 2                 n - 1     n
+--R           - b c x (c x)     ((c x) )  - 2a b c x (c x)     (c x)
+--R         + 
+--R              2         n - 1
+--R           - a c x (c x)
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R           2     n   n log(c x) 2             n  n log(c x)    2     n
+--R         (b (c x) (%e          )  + 2a b (c x) %e           + a (c x) )
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  + a
+--R  /
+--R              +------------+ +------------------+
+--R            n |       n      |    n log(c x)
+--R     x (c x) \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 74
+
+)clear all
+
+--S 75 of 649
+t0:=(a+b*(c*x)^n)^(1/2)/x
+--R 
+--R
+--R         +------------+
+--R         |       n
+--R        \|b (c x)  + a
+--R   (1)  ---------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 75
+
+--S 76 of 649
+r0:=-2*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))*sqrt(a)/n+2*sqrt(a+b*(c*x)^n)/n
+--R 
+--R
+--R                      +------------+
+--R                      |       n           +------------+
+--R            +-+      \|b (c x)  + a       |       n
+--R        - 2\|a atanh(---------------) + 2\|b (c x)  + a
+--R                            +-+
+--R                           \|a
+--R   (2)  ------------------------------------------------
+--R                                n
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         +------------------+
+--R                     +-+ |    n log(c x)            n log(c x)
+--R          +-+    - 2\|a \|b %e           + a  + b %e           + 2a
+--R         \|a log(--------------------------------------------------)
+--R                                      n log(c x)
+--R                                    %e
+--R       + 
+--R           +------------------+
+--R           |    n log(c x)
+--R         2\|b %e           + a
+--R    /
+--R       n
+--R     ,
+--R                   +------------------+
+--R                   |    n log(c x)           +------------------+
+--R        +---+     \|b %e           + a       |    n log(c x)
+--R    - 2\|- a atan(---------------------) + 2\|b %e           + a
+--R                           +---+
+--R                          \|- a
+--R    -------------------------------------------------------------]
+--R                                  n
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 77
+
+--S 78 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       +------------------+
+--R                   +-+ |    n log(c x)            n log(c x)
+--R        +-+    - 2\|a \|b %e           + a  + b %e           + 2a
+--R       \|a log(--------------------------------------------------)
+--R                                    n log(c x)
+--R                                  %e
+--R     + 
+--R                                            +------------+
+--R         +------------------+               |       n           +------------+
+--R         |    n log(c x)          +-+      \|b (c x)  + a       |       n
+--R       2\|b %e           + a  + 2\|a atanh(---------------) - 2\|b (c x)  + a
+--R                                                  +-+
+--R                                                 \|a
+--R  /
+--R     n
+--R                                                    Type: Expression(Integer)
+--E 78
+
+--S 79 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                                +------------+
+--R                     n  n log(c x)           n  |       n
+--R           (- b (c x) %e           - 2a (c x) )\|b (c x)  + a
+--R         + 
+--R                          n - 1     n               n - 1  +-+
+--R           (- 2b c x (c x)     (c x)  - 2a c x (c x)     )\|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R                                                   +------------+
+--R                n +-+  n log(c x)           n +-+  |       n
+--R       (2b (c x) \|a %e           + 2a (c x) \|a )\|b (c x)  + a
+--R     + 
+--R         2         n - 1     n                n - 1   n log(c x)
+--R       (b c x (c x)     (c x)  + a b c x (c x)     )%e
+--R     + 
+--R                     n - 1     n     2         n - 1
+--R       2a b c x (c x)     (c x)  + 2a c x (c x)
+--R  /
+--R                     +------------+ +------------------+
+--R               n +-+ |       n      |    n log(c x)
+--R       2x (c x) \|a \|b (c x)  + a \|b %e           + a
+--R     + 
+--R                                                +------------+
+--R                   n  n log(c x)             n  |       n
+--R       (- b x (c x) %e           - 2a x (c x) )\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      +------------------+
+--R                      |    n log(c x)           +------------------+
+--R           +---+     \|b %e           + a       |    n log(c x)
+--R       - 2\|- a atan(---------------------) + 2\|b %e           + a
+--R                              +---+
+--R                             \|- a
+--R     + 
+--R                   +------------+
+--R                   |       n           +------------+
+--R         +-+      \|b (c x)  + a       |       n
+--R       2\|a atanh(---------------) - 2\|b (c x)  + a
+--R                         +-+
+--R                        \|a
+--R  /
+--R     n
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                                     +------------------+
+--R                     n - 1     n              n - 1  |    n log(c x)
+--R       (- b c x (c x)     (c x)  - a c x (c x)     )\|b %e           + a
+--R     + 
+--R                                         +------------+
+--R               n  n log(c x)          n  |       n
+--R       (b (c x) %e           + a (c x) )\|b (c x)  + a
+--R  /
+--R              +------------+ +------------------+
+--R            n |       n      |    n log(c x)
+--R     x (c x) \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 649
+t0:=1/(x*(a+b*(c*x)^n)^(1/2))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R          +------------+
+--R          |       n
+--R        x\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 649
+r0:=-2*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))/(n*sqrt(a))
+--R 
+--R
+--R                  +------------+
+--R                  |       n
+--R                 \|b (c x)  + a
+--R          2atanh(---------------)
+--R                        +-+
+--R                       \|a
+--R   (2)  - -----------------------
+--R                     +-+
+--R                   n\|a
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +------------------+
+--R             |    n log(c x)          +-+  n log(c x)      +-+
+--R        - 2a\|b %e           + a  + b\|a %e           + 2a\|a
+--R    log(------------------------------------------------------)
+--R                               n log(c x)
+--R                             %e
+--R   [-----------------------------------------------------------,
+--R                                 +-+
+--R                               n\|a
+--R                   +------------------+
+--R             +---+ |    n log(c x)
+--R            \|- a \|b %e           + a
+--R      2atan(---------------------------)
+--R                         a
+--R    - ----------------------------------]
+--R                      +---+
+--R                    n\|- a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 84
+
+--S 85 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                +------------------+
+--R                |    n log(c x)          +-+  n log(c x)      +-+
+--R           - 2a\|b %e           + a  + b\|a %e           + 2a\|a
+--R       log(------------------------------------------------------)
+--R                                  n log(c x)
+--R                                %e
+--R     + 
+--R               +------------+
+--R               |       n
+--R              \|b (c x)  + a
+--R       2atanh(---------------)
+--R                     +-+
+--R                    \|a
+--R  /
+--R       +-+
+--R     n\|a
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                       +------------+
+--R                     n |       n                   n - 1 +-+  n log(c x)
+--R           - 2a (c x) \|b (c x)  + a  - b c x (c x)     \|a %e
+--R         + 
+--R                         n - 1 +-+
+--R           - 2a c x (c x)     \|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R                                                  +------------+
+--R               n +-+  n log(c x)           n +-+  |       n
+--R       (b (c x) \|a %e           + 2a (c x) \|a )\|b (c x)  + a
+--R     + 
+--R                     n - 1  n log(c x)     2         n - 1
+--R       2a b c x (c x)     %e           + 2a c x (c x)
+--R  /
+--R                                                        +------------+
+--R                   n +-+  n log(c x)             n +-+  |       n
+--R         (b x (c x) \|a %e           + 2a x (c x) \|a )\|b (c x)  + a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R                                                   +------------+
+--R                      n  n log(c x)     2       n  |       n
+--R       (- 2a b x (c x) %e           - 2a x (c x) )\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      +------------------+                  +------------+
+--R                +---+ |    n log(c x)                       |       n
+--R       +-+     \|- a \|b %e           + a       +---+      \|b (c x)  + a
+--R   - 2\|a atan(---------------------------) + 2\|- a atanh(---------------)
+--R                            a                                     +-+
+--R                                                                 \|a
+--R   ------------------------------------------------------------------------
+--R                                    +---+ +-+
+--R                                  n\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R                         +------------------+          +------------+
+--R                   n - 1 |    n log(c x)             n |       n
+--R        - c x (c x)     \|b %e           + a  + (c x) \|b (c x)  + a
+--R   (7)  -------------------------------------------------------------
+--R                          +------------+ +------------------+
+--R                        n |       n      |    n log(c x)
+--R                 x (c x) \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 88
+
+)clear all
+
+--S 89 of 649
+t0:=1/(x*(a+b*(c*x)^n)^(3/2))
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R                           +------------+
+--R                  n        |       n
+--R        (b x (c x)  + a x)\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 649
+r0:=-2*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))/(a^(3/2)*n)+2/(a*n*sqrt(a+b*(c*x)^n))
+--R 
+--R
+--R                                 +------------+
+--R            +------------+       |       n
+--R            |       n           \|b (c x)  + a       +-+
+--R        - 2\|b (c x)  + a atanh(---------------) + 2\|a
+--R                                       +-+
+--R                                      \|a
+--R   (2)  ------------------------------------------------
+--R                             +------------+
+--R                         +-+ |       n
+--R                     a n\|a \|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 90
+
+--S 91 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R            +------------------+
+--R            |    n log(c x)
+--R           \|b %e           + a
+--R        *
+--R                    +------------------+
+--R                    |    n log(c x)          +-+  n log(c x)      +-+
+--R               - 2a\|b %e           + a  + b\|a %e           + 2a\|a
+--R           log(------------------------------------------------------)
+--R                                      n log(c x)
+--R                                    %e
+--R       + 
+--R           +-+
+--R         2\|a
+--R    /
+--R               +------------------+
+--R           +-+ |    n log(c x)
+--R       a n\|a \|b %e           + a
+--R     ,
+--R                                        +------------------+
+--R        +------------------+      +---+ |    n log(c x)
+--R        |    n log(c x)          \|- a \|b %e           + a       +---+
+--R    - 2\|b %e           + a atan(---------------------------) + 2\|- a
+--R                                              a
+--R    -------------------------------------------------------------------]
+--R                                 +------------------+
+--R                           +---+ |    n log(c x)
+--R                       a n\|- a \|b %e           + a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 91
+
+--S 92 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +------------+ +------------------+
+--R          |       n      |    n log(c x)
+--R         \|b (c x)  + a \|b %e           + a
+--R      *
+--R                  +------------------+
+--R                  |    n log(c x)          +-+  n log(c x)      +-+
+--R             - 2a\|b %e           + a  + b\|a %e           + 2a\|a
+--R         log(------------------------------------------------------)
+--R                                    n log(c x)
+--R                                  %e
+--R     + 
+--R                               +------------+
+--R          +------------+       |       n                +------------------+
+--R          |       n           \|b (c x)  + a       +-+  |    n log(c x)
+--R       (2\|b (c x)  + a atanh(---------------) - 2\|a )\|b %e           + a
+--R                                     +-+
+--R                                    \|a
+--R     + 
+--R             +------------+
+--R         +-+ |       n
+--R       2\|a \|b (c x)  + a
+--R  /
+--R             +------------+ +------------------+
+--R         +-+ |       n      |    n log(c x)
+--R     a n\|a \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                          +------------+
+--R                         n 2     2     n  |       n
+--R           (- 2a b ((c x) )  - 2a (c x) )\|b (c x)  + a
+--R         + 
+--R              2         n - 1 +-+   n log(c x) 2
+--R           - b c x (c x)     \|a (%e          )
+--R         + 
+--R                           n - 1 +-+  n log(c x)     2         n - 1 +-+
+--R           - 3a b c x (c x)     \|a %e           - 2a c x (c x)     \|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R             2      n 2            n  +-+  n log(c x)
+--R           (b ((c x) )  + a b (c x) )\|a %e
+--R         + 
+--R                       n 2     2     n  +-+
+--R           (2a b ((c x) )  + 2a (c x) )\|a
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  + a
+--R     + 
+--R           2         n - 1   n log(c x) 2     2           n - 1  n log(c x)
+--R       2a b c x (c x)     (%e          )  + 4a b c x (c x)     %e
+--R     + 
+--R         3         n - 1
+--R       2a c x (c x)
+--R  /
+--R             3        n 2      2       n  +-+   n log(c x) 2
+--R           (b x ((c x) )  + a b x (c x) )\|a (%e          )
+--R         + 
+--R                2        n 2     2         n  +-+  n log(c x)
+--R           (3a b x ((c x) )  + 3a b x (c x) )\|a %e
+--R         + 
+--R              2          n 2     3       n  +-+
+--R           (2a b x ((c x) )  + 2a x (c x) )\|a
+--R      *
+--R          +------------+ +------------------+
+--R          |       n      |    n log(c x)
+--R         \|b (c x)  + a \|b %e           + a
+--R     + 
+--R                  3        n 2     2 2       n    n log(c x) 2
+--R           (- 2a b x ((c x) )  - 2a b x (c x) )(%e          )
+--R         + 
+--R                2 2        n 2     3         n   n log(c x)     3          n 2
+--R           (- 4a b x ((c x) )  - 4a b x (c x) )%e           - 2a b x ((c x) )
+--R         + 
+--R               4       n
+--R           - 2a x (c x)
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 93
+
+--S 94 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       -
+--R                  +------------+ +------------------+
+--R              +-+ |       n      |    n log(c x)
+--R            2\|a \|b (c x)  + a \|b %e           + a
+--R         *
+--R                        +------------------+
+--R                  +---+ |    n log(c x)
+--R                 \|- a \|b %e           + a
+--R            atan(---------------------------)
+--R                              a
+--R     + 
+--R                                       +------------+
+--R                  +------------+       |       n
+--R            +---+ |       n           \|b (c x)  + a       +---+ +-+
+--R         (2\|- a \|b (c x)  + a atanh(---------------) - 2\|- a \|a )
+--R                                             +-+
+--R                                            \|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R                   +------------+
+--R         +---+ +-+ |       n
+--R       2\|- a \|a \|b (c x)  + a
+--R  /
+--R                   +------------+ +------------------+
+--R         +---+ +-+ |       n      |    n log(c x)
+--R     a n\|- a \|a \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                                           +------------------+
+--R                     n - 1  n log(c x)              n - 1  |    n log(c x)
+--R       (- b c x (c x)     %e           - a c x (c x)     )\|b %e           + a
+--R     + 
+--R                                +------------+
+--R                n 2          n  |       n
+--R       (b ((c x) )  + a (c x) )\|b (c x)  + a
+--R  /
+--R             2        n 2              n   n log(c x)               n 2
+--R           (b x ((c x) )  + a b x (c x) )%e           + a b x ((c x) )
+--R         + 
+--R            2       n
+--R           a x (c x)
+--R    *
+--R        +------------+ +------------------+
+--R        |       n      |    n log(c x)
+--R       \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 95
+
+)clear all
+
+--S 96 of 649
+t0:=1/(x*(a+b*(c*x)^n)^(5/2))
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R                                              +------------+
+--R          2        n 2               n    2   |       n
+--R        (b x ((c x) )  + 2a b x (c x)  + a x)\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 649
+r0:=2/3/(a*n*(a+b*(c*x)^n)^(3/2))-2*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))/_
+   (a^(5/2)*n)+2/(a^2*n*sqrt(a+b*(c*x)^n))
+--R 
+--R
+--R   (2)
+--R                                               +------------+
+--R                          +------------+       |       n
+--R                  n       |       n           \|b (c x)  + a
+--R       (- 6b (c x)  - 6a)\|b (c x)  + a atanh(---------------)
+--R                                                     +-+
+--R                                                    \|a
+--R     + 
+--R                n       +-+
+--R       (6b (c x)  + 8a)\|a
+--R  /
+--R                                +------------+
+--R        2         n     3   +-+ |       n
+--R     (3a b n (c x)  + 3a n)\|a \|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                  +------------------+
+--R                 n log(c x)       |    n log(c x)
+--R           (3b %e           + 3a)\|b %e           + a
+--R        *
+--R                    +------------------+
+--R                    |    n log(c x)          +-+  n log(c x)      +-+
+--R               - 2a\|b %e           + a  + b\|a %e           + 2a\|a
+--R           log(------------------------------------------------------)
+--R                                      n log(c x)
+--R                                    %e
+--R       + 
+--R            +-+  n log(c x)      +-+
+--R         6b\|a %e           + 8a\|a
+--R    /
+--R                                           +------------------+
+--R          2    +-+  n log(c x)     3  +-+  |    n log(c x)
+--R       (3a b n\|a %e           + 3a n\|a )\|b %e           + a
+--R     ,
+--R
+--R                                    +------------------+
+--R                   n log(c x)       |    n log(c x)
+--R           (- 6b %e           - 6a)\|b %e           + a
+--R        *
+--R                       +------------------+
+--R                 +---+ |    n log(c x)
+--R                \|- a \|b %e           + a
+--R           atan(---------------------------)
+--R                             a
+--R       + 
+--R            +---+  n log(c x)      +---+
+--R         6b\|- a %e           + 8a\|- a
+--R    /
+--R                                               +------------------+
+--R          2    +---+  n log(c x)     3  +---+  |    n log(c x)
+--R       (3a b n\|- a %e           + 3a n\|- a )\|b %e           + a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 98
+
+--S 99 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                              +------------+
+--R             2     n          n log(c x)             n     2  |       n
+--R         ((3b (c x)  + 3a b)%e           + 3a b (c x)  + 3a )\|b (c x)  + a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R      *
+--R                  +------------------+
+--R                  |    n log(c x)          +-+  n log(c x)      +-+
+--R             - 2a\|b %e           + a  + b\|a %e           + 2a\|a
+--R         log(------------------------------------------------------)
+--R                                    n log(c x)
+--R                                  %e
+--R     + 
+--R                                                                  +------------+
+--R                 2     n          n log(c x)             n     2  |       n
+--R             ((6b (c x)  + 6a b)%e           + 6a b (c x)  + 6a )\|b (c x)  + a
+--R          *
+--R                    +------------+
+--R                    |       n
+--R                   \|b (c x)  + a
+--R             atanh(---------------)
+--R                          +-+
+--R                         \|a
+--R         + 
+--R                2     n         +-+  n log(c x)                n     2  +-+
+--R           (- 6b (c x)  - 8a b)\|a %e           + (- 6a b (c x)  - 8a )\|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R             2     n         +-+  n log(c x)              n     2  +-+
+--R         ((6b (c x)  + 6a b)\|a %e           + (8a b (c x)  + 8a )\|a )
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  + a
+--R  /
+--R           2 2       n     3     +-+  n log(c x)      3         n     4   +-+
+--R       ((3a b n (c x)  + 3a b n)\|a %e           + (3a b n (c x)  + 3a n)\|a )
+--R    *
+--R        +------------+ +------------------+
+--R        |       n      |    n log(c x)
+--R       \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                                           +------------+
+--R                  2      n 3     2        n 2     3     n  |       n
+--R           (- 2a b ((c x) )  - 4a b ((c x) )  - 2a (c x) )\|b (c x)  + a
+--R         + 
+--R              3         n - 1 +-+   n log(c x) 3
+--R           - b c x (c x)     \|a (%e          )
+--R         + 
+--R                 2         n - 1 +-+   n log(c x) 2
+--R           - 4a b c x (c x)     \|a (%e          )
+--R         + 
+--R               2           n - 1 +-+  n log(c x)     3         n - 1 +-+
+--R           - 5a b c x (c x)     \|a %e           - 2a c x (c x)     \|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R             3      n 3       2      n 2    2       n  +-+  n log(c x)
+--R           (b ((c x) )  + 2a b ((c x) )  + a b (c x) )\|a %e
+--R         + 
+--R                2      n 3     2        n 2     3     n  +-+
+--R           (2a b ((c x) )  + 4a b ((c x) )  + 2a (c x) )\|a
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  + a
+--R     + 
+--R           3         n - 1   n log(c x) 3     2 2         n - 1   n log(c x) 2
+--R       2a b c x (c x)     (%e          )  + 6a b c x (c x)     (%e          )
+--R     + 
+--R         3           n - 1  n log(c x)     4         n - 1
+--R       6a b c x (c x)     %e           + 2a c x (c x)
+--R  /
+--R             5        n 3       4        n 2    2 3       n  +-+   n log(c x) 3
+--R           (b x ((c x) )  + 2a b x ((c x) )  + a b x (c x) )\|a (%e          )
+--R         + 
+--R                  4        n 3     2 3        n 2     3 2       n  +-+
+--R             (4a b x ((c x) )  + 8a b x ((c x) )  + 4a b x (c x) )\|a
+--R          *
+--R                n log(c x) 2
+--R             (%e          )
+--R         + 
+--R                2 3        n 3      3 2        n 2     4         n  +-+
+--R             (5a b x ((c x) )  + 10a b x ((c x) )  + 5a b x (c x) )\|a
+--R          *
+--R               n log(c x)
+--R             %e
+--R         + 
+--R              3 2        n 3     4          n 2     5       n  +-+
+--R           (2a b x ((c x) )  + 4a b x ((c x) )  + 2a x (c x) )\|a
+--R      *
+--R          +------------+ +------------------+
+--R          |       n      |    n log(c x)
+--R         \|b (c x)  + a \|b %e           + a
+--R     + 
+--R                    5        n 3     2 4        n 2     3 3       n
+--R             (- 2a b x ((c x) )  - 4a b x ((c x) )  - 2a b x (c x) )
+--R          *
+--R                n log(c x) 3
+--R             (%e          )
+--R         + 
+--R                  2 4        n 3      3 3        n 2     4 2       n
+--R             (- 6a b x ((c x) )  - 12a b x ((c x) )  - 6a b x (c x) )
+--R          *
+--R                n log(c x) 2
+--R             (%e          )
+--R         + 
+--R                3 3        n 3      4 2        n 2     5         n   n log(c x)
+--R           (- 6a b x ((c x) )  - 12a b x ((c x) )  - 6a b x (c x) )%e
+--R         + 
+--R               4 2        n 3     5          n 2     6       n
+--R           - 2a b x ((c x) )  - 4a b x ((c x) )  - 2a x (c x)
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               2     n         +-+  n log(c x)                n     2  +-+
+--R         ((- 6b (c x)  - 6a b)\|a %e           + (- 6a b (c x)  - 6a )\|a )
+--R      *
+--R                                                         +------------------+
+--R          +------------+ +------------------+      +---+ |    n log(c x)
+--R          |       n      |    n log(c x)          \|- a \|b %e           + a
+--R         \|b (c x)  + a \|b %e           + a atan(---------------------------)
+--R                                                               a
+--R     + 
+--R                 2     n         +---+  n log(c x)              n     2  +---+
+--R             ((6b (c x)  + 6a b)\|- a %e           + (6a b (c x)  + 6a )\|- a )
+--R          *
+--R                                   +------------+
+--R              +------------+       |       n
+--R              |       n           \|b (c x)  + a
+--R             \|b (c x)  + a atanh(---------------)
+--R                                         +-+
+--R                                        \|a
+--R         + 
+--R                2     n         +---+ +-+  n log(c x)
+--R           (- 6b (c x)  - 8a b)\|- a \|a %e
+--R         + 
+--R                        n     2  +---+ +-+
+--R           (- 6a b (c x)  - 8a )\|- a \|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R              2     n         +---+ +-+  n log(c x)
+--R           (6b (c x)  + 6a b)\|- a \|a %e
+--R         + 
+--R                      n     2  +---+ +-+
+--R           (8a b (c x)  + 8a )\|- a \|a
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  + a
+--R  /
+--R            2 2       n     3     +---+ +-+  n log(c x)
+--R         (3a b n (c x)  + 3a b n)\|- a \|a %e
+--R       + 
+--R            3         n     4   +---+ +-+
+--R         (3a b n (c x)  + 3a n)\|- a \|a
+--R    *
+--R        +------------+ +------------------+
+--R        |       n      |    n log(c x)
+--R       \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R              2         n - 1   n log(c x) 2                 n - 1  n log(c x)
+--R           - b c x (c x)     (%e          )  - 2a b c x (c x)     %e
+--R         + 
+--R              2         n - 1
+--R           - a c x (c x)
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           + a
+--R     + 
+--R                                                 +------------+
+--R         2      n 3              n 2    2     n  |       n
+--R       (b ((c x) )  + 2a b ((c x) )  + a (c x) )\|b (c x)  + a
+--R  /
+--R           4        n 3       3        n 2    2 2       n    n log(c x) 2
+--R         (b x ((c x) )  + 2a b x ((c x) )  + a b x (c x) )(%e          )
+--R       + 
+--R              3        n 3     2 2        n 2     3         n   n log(c x)
+--R         (2a b x ((c x) )  + 4a b x ((c x) )  + 2a b x (c x) )%e
+--R       + 
+--R          2 2        n 3     3          n 2    4       n
+--R         a b x ((c x) )  + 2a b x ((c x) )  + a x (c x)
+--R    *
+--R        +------------+ +------------------+
+--R        |       n      |    n log(c x)
+--R       \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 649
+t0:=(-a+b*(c*x)^n)^(5/2)/x
+--R 
+--R
+--R                                         +------------+
+--R          2      n 2             n    2  |       n
+--R        (b ((c x) )  - 2a b (c x)  + a )\|b (c x)  - a
+--R   (1)  -----------------------------------------------
+--R                               x
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 649
+r0:=-2/3*a*(-a+b*(c*x)^n)^(3/2)/n+2/5*(-a+b*(c*x)^n)^(5/2)/n-_
+   2*a^(5/2)*atan(sqrt(-a+b*(c*x)^n)/sqrt(a))/n+2*a^2*sqrt(-a+b*(c*x)^n)/n
+--R 
+--R
+--R   (2)
+--R                       +------------+
+--R                       |       n
+--R            2 +-+     \|b (c x)  - a
+--R       - 30a \|a atan(---------------)
+--R                             +-+
+--R                            \|a
+--R     + 
+--R                                            +------------+
+--R          2      n 2              n      2  |       n
+--R       (6b ((c x) )  - 22a b (c x)  + 46a )\|b (c x)  - a
+--R  /
+--R     15n
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                 +------------------+
+--R                           +---+ |    n log(c x)            n log(c x)
+--R            2 +---+    - 2\|- a \|b %e           - a  + b %e           - 2a
+--R         15a \|- a log(----------------------------------------------------)
+--R                                             n log(c x)
+--R                                           %e
+--R       + 
+--R                                                          +------------------+
+--R            2   n log(c x) 2           n log(c x)      2  |    n log(c x)
+--R         (6b (%e          )  - 22a b %e           + 46a )\|b %e           - a
+--R    /
+--R       15n
+--R     ,
+--R
+--R                         +------------------+
+--R                         |    n log(c x)
+--R              2 +-+     \|b %e           - a
+--R         - 30a \|a atan(---------------------)
+--R                                  +-+
+--R                                 \|a
+--R       + 
+--R                                                          +------------------+
+--R            2   n log(c x) 2           n log(c x)      2  |    n log(c x)
+--R         (6b (%e          )  - 22a b %e           + 46a )\|b %e           - a
+--R    /
+--R       15n
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 105
+
+--S 106 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                               +------------------+
+--R                         +---+ |    n log(c x)            n log(c x)
+--R          2 +---+    - 2\|- a \|b %e           - a  + b %e           - 2a
+--R       15a \|- a log(----------------------------------------------------)
+--R                                           n log(c x)
+--R                                         %e
+--R     + 
+--R                                                        +------------------+
+--R          2   n log(c x) 2           n log(c x)      2  |    n log(c x)
+--R       (6b (%e          )  - 22a b %e           + 46a )\|b %e           - a
+--R     + 
+--R                     +------------+
+--R                     |       n
+--R          2 +-+     \|b (c x)  - a
+--R       30a \|a atan(---------------)
+--R                           +-+
+--R                          \|a
+--R     + 
+--R                                              +------------+
+--R            2      n 2              n      2  |       n
+--R       (- 6b ((c x) )  + 22a b (c x)  - 46a )\|b (c x)  - a
+--R  /
+--R     15n
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                  3     n   n log(c x) 3       2     n   n log(c x) 2
+--R               - b (c x) (%e          )  + 4a b (c x) (%e          )
+--R             + 
+--R                   2       n  n log(c x)     3     n
+--R               - 5a b (c x) %e           + 2a (c x)
+--R          *
+--R              +------------+
+--R              |       n
+--R             \|b (c x)  - a
+--R         + 
+--R                   3         n - 1      n 3       2         n - 1      n 2
+--R               - 2b c x (c x)     ((c x) )  + 6a b c x (c x)     ((c x) )
+--R             + 
+--R                   2           n - 1     n     3         n - 1
+--R               - 6a b c x (c x)     (c x)  + 2a c x (c x)
+--R          *
+--R              +---+
+--R             \|- a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R             3     n +---+   n log(c x) 3       2     n +---+   n log(c x) 2
+--R           2b (c x) \|- a (%e          )  - 6a b (c x) \|- a (%e          )
+--R         + 
+--R             2       n +---+  n log(c x)     3     n +---+
+--R           6a b (c x) \|- a %e           - 2a (c x) \|- a
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  - a
+--R     + 
+--R            4         n - 1      n 3       3         n - 1      n 2
+--R           b c x (c x)     ((c x) )  - 3a b c x (c x)     ((c x) )
+--R         + 
+--R             2 2         n - 1     n    3           n - 1
+--R           3a b c x (c x)     (c x)  - a b c x (c x)
+--R      *
+--R           n log(c x)
+--R         %e
+--R     + 
+--R             3         n - 1      n 3     2 2         n - 1      n 2
+--R       - 2a b c x (c x)     ((c x) )  + 6a b c x (c x)     ((c x) )
+--R     + 
+--R           3           n - 1     n     4         n - 1
+--R       - 6a b c x (c x)     (c x)  + 2a c x (c x)
+--R  /
+--R                       +------------+ +------------------+
+--R               n +---+ |       n      |    n log(c x)
+--R       2x (c x) \|- a \|b (c x)  - a \|b %e           - a
+--R     + 
+--R                                                +------------+
+--R                   n  n log(c x)             n  |       n
+--R       (- b x (c x) %e           + 2a x (c x) )\|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +------------------+
+--R                       |    n log(c x)
+--R            2 +-+     \|b %e           - a
+--R       - 30a \|a atan(---------------------)
+--R                                +-+
+--R                               \|a
+--R     + 
+--R                                                        +------------------+
+--R          2   n log(c x) 2           n log(c x)      2  |    n log(c x)
+--R       (6b (%e          )  - 22a b %e           + 46a )\|b %e           - a
+--R     + 
+--R                     +------------+
+--R                     |       n
+--R          2 +-+     \|b (c x)  - a
+--R       30a \|a atan(---------------)
+--R                           +-+
+--R                          \|a
+--R     + 
+--R                                              +------------+
+--R            2      n 2              n      2  |       n
+--R       (- 6b ((c x) )  + 22a b (c x)  - 46a )\|b (c x)  - a
+--R  /
+--R     15n
+--R                                                    Type: Expression(Integer)
+--E 108
+
+--S 109 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R              3         n - 1      n 3       2         n - 1      n 2
+--R           - b c x (c x)     ((c x) )  + 3a b c x (c x)     ((c x) )
+--R         + 
+--R               2           n - 1     n    3         n - 1
+--R           - 3a b c x (c x)     (c x)  + a c x (c x)
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R            3     n   n log(c x) 3       2     n   n log(c x) 2
+--R           b (c x) (%e          )  - 3a b (c x) (%e          )
+--R         + 
+--R             2       n  n log(c x)    3     n
+--R           3a b (c x) %e           - a (c x)
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  - a
+--R  /
+--R              +------------+ +------------------+
+--R            n |       n      |    n log(c x)
+--R     x (c x) \|b (c x)  - a \|b %e           - a
+--R                                                    Type: Expression(Integer)
+--E 109
+
+)clear all
+
+--S 110 of 649
+t0:=(-a+b*(c*x)^n)^(3/2)/x
+--R 
+--R
+--R                       +------------+
+--R                n      |       n
+--R        (b (c x)  - a)\|b (c x)  - a
+--R   (1)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 649
+r0:=2/3*(-a+b*(c*x)^n)^(3/2)/n+2*a^(3/2)*_
+   atan(sqrt(-a+b*(c*x)^n)/sqrt(a))/n-2*a*sqrt(-a+b*(c*x)^n)/n
+--R 
+--R
+--R                    +------------+
+--R                    |       n                          +------------+
+--R           +-+     \|b (c x)  - a              n       |       n
+--R        6a\|a atan(---------------) + (2b (c x)  - 8a)\|b (c x)  - a
+--R                          +-+
+--R                         \|a
+--R   (2)  -------------------------------------------------------------
+--R                                      3n
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             +------------------+
+--R                       +---+ |    n log(c x)            n log(c x)
+--R            +---+    2\|- a \|b %e           - a  + b %e           - 2a
+--R         3a\|- a log(--------------------------------------------------)
+--R                                          n log(c x)
+--R                                        %e
+--R       + 
+--R                                +------------------+
+--R               n log(c x)       |    n log(c x)
+--R         (2b %e           - 8a)\|b %e           - a
+--R    /
+--R       3n
+--R     ,
+--R
+--R                     +------------------+
+--R                     |    n log(c x)
+--R            +-+     \|b %e           - a
+--R         6a\|a atan(---------------------)
+--R                              +-+
+--R                             \|a
+--R       + 
+--R                                +------------------+
+--R               n log(c x)       |    n log(c x)
+--R         (2b %e           - 8a)\|b %e           - a
+--R    /
+--R       3n
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 112
+
+--S 113 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           +------------------+
+--R                     +---+ |    n log(c x)            n log(c x)
+--R          +---+    2\|- a \|b %e           - a  + b %e           - 2a
+--R       3a\|- a log(--------------------------------------------------)
+--R                                        n log(c x)
+--R                                      %e
+--R     + 
+--R                                                                 +------------+
+--R                              +------------------+               |       n
+--R             n log(c x)       |    n log(c x)           +-+     \|b (c x)  - a
+--R       (2b %e           - 8a)\|b %e           - a  - 6a\|a atan(---------------)
+--R                                                                       +-+
+--R                                                                      \|a
+--R     + 
+--R                          +------------+
+--R                  n       |       n
+--R       (- 2b (c x)  + 8a)\|b (c x)  - a
+--R  /
+--R     3n
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R               2     n   n log(c x) 2             n  n log(c x)     2     n
+--R             (b (c x) (%e          )  - 3a b (c x) %e           + 2a (c x) )
+--R          *
+--R              +------------+
+--R              |       n
+--R             \|b (c x)  - a
+--R         + 
+--R                   2         n - 1      n 2                 n - 1     n
+--R               - 2b c x (c x)     ((c x) )  + 4a b c x (c x)     (c x)
+--R             + 
+--R                   2         n - 1
+--R               - 2a c x (c x)
+--R          *
+--R              +---+
+--R             \|- a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R             2     n +---+   n log(c x) 2             n +---+  n log(c x)
+--R           2b (c x) \|- a (%e          )  - 4a b (c x) \|- a %e
+--R         + 
+--R             2     n +---+
+--R           2a (c x) \|- a
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  - a
+--R     + 
+--R              3         n - 1      n 2       2         n - 1     n
+--R           - b c x (c x)     ((c x) )  + 2a b c x (c x)     (c x)
+--R         + 
+--R              2           n - 1
+--R           - a b c x (c x)
+--R      *
+--R           n log(c x)
+--R         %e
+--R     + 
+--R           2         n - 1      n 2     2           n - 1     n
+--R       2a b c x (c x)     ((c x) )  - 4a b c x (c x)     (c x)
+--R     + 
+--R         3         n - 1
+--R       2a c x (c x)
+--R  /
+--R                       +------------+ +------------------+
+--R               n +---+ |       n      |    n log(c x)
+--R       2x (c x) \|- a \|b (c x)  - a \|b %e           - a
+--R     + 
+--R                                              +------------+
+--R                 n  n log(c x)             n  |       n
+--R       (b x (c x) %e           - 2a x (c x) )\|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                   +------------------+
+--R                   |    n log(c x)
+--R          +-+     \|b %e           - a
+--R       6a\|a atan(---------------------)
+--R                            +-+
+--R                           \|a
+--R     + 
+--R                                                                 +------------+
+--R                              +------------------+               |       n
+--R             n log(c x)       |    n log(c x)           +-+     \|b (c x)  - a
+--R       (2b %e           - 8a)\|b %e           - a  - 6a\|a atan(---------------)
+--R                                                                       +-+
+--R                                                                      \|a
+--R     + 
+--R                          +------------+
+--R                  n       |       n
+--R       (- 2b (c x)  + 8a)\|b (c x)  - a
+--R  /
+--R     3n
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R              2         n - 1      n 2                 n - 1     n
+--R           - b c x (c x)     ((c x) )  + 2a b c x (c x)     (c x)
+--R         + 
+--R              2         n - 1
+--R           - a c x (c x)
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R           2     n   n log(c x) 2             n  n log(c x)    2     n
+--R         (b (c x) (%e          )  - 2a b (c x) %e           + a (c x) )
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  - a
+--R  /
+--R              +------------+ +------------------+
+--R            n |       n      |    n log(c x)
+--R     x (c x) \|b (c x)  - a \|b %e           - a
+--R                                                    Type: Expression(Integer)
+--E 116
+
+)clear all
+
+--S 117 of 649
+t0:=(-a+b*(c*x)^n)^(1/2)/x
+--R 
+--R
+--R         +------------+
+--R         |       n
+--R        \|b (c x)  - a
+--R   (1)  ---------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 649
+r0:=-2*atan(sqrt(-a+b*(c*x)^n)/sqrt(a))*sqrt(a)/n+2*sqrt(-a+b*(c*x)^n)/n
+--R 
+--R
+--R                     +------------+
+--R                     |       n           +------------+
+--R            +-+     \|b (c x)  - a       |       n
+--R        - 2\|a atan(---------------) + 2\|b (c x)  - a
+--R                           +-+
+--R                          \|a
+--R   (2)  -----------------------------------------------
+--R                               n
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             +------------------+
+--R                       +---+ |    n log(c x)            n log(c x)
+--R          +---+    - 2\|- a \|b %e           - a  + b %e           - 2a
+--R         \|- a log(----------------------------------------------------)
+--R                                         n log(c x)
+--R                                       %e
+--R       + 
+--R           +------------------+
+--R           |    n log(c x)
+--R         2\|b %e           - a
+--R    /
+--R       n
+--R     ,
+--R                 +------------------+
+--R                 |    n log(c x)           +------------------+
+--R        +-+     \|b %e           - a       |    n log(c x)
+--R    - 2\|a atan(---------------------) + 2\|b %e           - a
+--R                          +-+
+--R                         \|a
+--R    -----------------------------------------------------------]
+--R                                 n
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 119
+
+--S 120 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           +------------------+
+--R                     +---+ |    n log(c x)            n log(c x)
+--R        +---+    - 2\|- a \|b %e           - a  + b %e           - 2a
+--R       \|- a log(----------------------------------------------------)
+--R                                       n log(c x)
+--R                                     %e
+--R     + 
+--R                                           +------------+
+--R         +------------------+              |       n           +------------+
+--R         |    n log(c x)          +-+     \|b (c x)  - a       |       n
+--R       2\|b %e           - a  + 2\|a atan(---------------) - 2\|b (c x)  - a
+--R                                                 +-+
+--R                                                \|a
+--R  /
+--R     n
+--R                                                    Type: Expression(Integer)
+--E 120
+
+--S 121 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                                +------------+
+--R                     n  n log(c x)           n  |       n
+--R           (- b (c x) %e           + 2a (c x) )\|b (c x)  - a
+--R         + 
+--R                          n - 1     n               n - 1  +---+
+--R           (- 2b c x (c x)     (c x)  + 2a c x (c x)     )\|- a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R                                                       +------------+
+--R                n +---+  n log(c x)           n +---+  |       n
+--R       (2b (c x) \|- a %e           - 2a (c x) \|- a )\|b (c x)  - a
+--R     + 
+--R         2         n - 1     n                n - 1   n log(c x)
+--R       (b c x (c x)     (c x)  - a b c x (c x)     )%e
+--R     + 
+--R                       n - 1     n     2         n - 1
+--R       - 2a b c x (c x)     (c x)  + 2a c x (c x)
+--R  /
+--R                       +------------+ +------------------+
+--R               n +---+ |       n      |    n log(c x)
+--R       2x (c x) \|- a \|b (c x)  - a \|b %e           - a
+--R     + 
+--R                                                +------------+
+--R                   n  n log(c x)             n  |       n
+--R       (- b x (c x) %e           + 2a x (c x) )\|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                    +------------------+
+--R                    |    n log(c x)           +------------------+
+--R           +-+     \|b %e           - a       |    n log(c x)
+--R       - 2\|a atan(---------------------) + 2\|b %e           - a
+--R                             +-+
+--R                            \|a
+--R     + 
+--R                  +------------+
+--R                  |       n           +------------+
+--R         +-+     \|b (c x)  - a       |       n
+--R       2\|a atan(---------------) - 2\|b (c x)  - a
+--R                        +-+
+--R                       \|a
+--R  /
+--R     n
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                                     +------------------+
+--R                     n - 1     n              n - 1  |    n log(c x)
+--R       (- b c x (c x)     (c x)  + a c x (c x)     )\|b %e           - a
+--R     + 
+--R                                         +------------+
+--R               n  n log(c x)          n  |       n
+--R       (b (c x) %e           - a (c x) )\|b (c x)  - a
+--R  /
+--R              +------------+ +------------------+
+--R            n |       n      |    n log(c x)
+--R     x (c x) \|b (c x)  - a \|b %e           - a
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 649
+t0:=1/(x*(-a+b*(c*x)^n)^(1/2))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R          +------------+
+--R          |       n
+--R        x\|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 649
+r0:=2*atan(sqrt(-a+b*(c*x)^n)/sqrt(a))/(n*sqrt(a))
+--R 
+--R
+--R               +------------+
+--R               |       n
+--R              \|b (c x)  - a
+--R        2atan(---------------)
+--R                     +-+
+--R                    \|a
+--R   (2)  ----------------------
+--R                   +-+
+--R                 n\|a
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +------------------+
+--R           |    n log(c x)          +---+  n log(c x)      +---+
+--R        2a\|b %e           - a  + b\|- a %e           - 2a\|- a
+--R    log(--------------------------------------------------------)
+--R                                n log(c x)
+--R                              %e
+--R   [-------------------------------------------------------------,
+--R                                 +---+
+--R                               n\|- a
+--R               +------------------+
+--R           +-+ |    n log(c x)
+--R          \|a \|b %e           - a
+--R    2atan(-------------------------)
+--R                      a
+--R    --------------------------------]
+--R                    +-+
+--R                  n\|a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 126
+
+--S 127 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  +------------------+
+--R                  |    n log(c x)          +---+  n log(c x)      +---+
+--R        +-+    2a\|b %e           - a  + b\|- a %e           - 2a\|- a
+--R       \|a log(--------------------------------------------------------)
+--R                                       n log(c x)
+--R                                     %e
+--R     + 
+--R                      +------------+
+--R                      |       n
+--R           +---+     \|b (c x)  - a
+--R       - 2\|- a atan(---------------)
+--R                            +-+
+--R                           \|a
+--R  /
+--R       +---+ +-+
+--R     n\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                     +------------+
+--R                   n |       n                   n - 1 +---+  n log(c x)
+--R           2a (c x) \|b (c x)  - a  - b c x (c x)     \|- a %e
+--R         + 
+--R                       n - 1 +---+
+--R           2a c x (c x)     \|- a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R                                                      +------------+
+--R               n +---+  n log(c x)           n +---+  |       n
+--R       (b (c x) \|- a %e           - 2a (c x) \|- a )\|b (c x)  - a
+--R     + 
+--R                       n - 1  n log(c x)     2         n - 1
+--R       - 2a b c x (c x)     %e           + 2a c x (c x)
+--R  /
+--R                                                            +------------+
+--R                   n +---+  n log(c x)             n +---+  |       n
+--R         (b x (c x) \|- a %e           - 2a x (c x) \|- a )\|b (c x)  - a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R                                                 +------------+
+--R                    n  n log(c x)     2       n  |       n
+--R       (2a b x (c x) %e           - 2a x (c x) )\|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R                   +------------------+           +------------+
+--R               +-+ |    n log(c x)                |       n
+--R              \|a \|b %e           - a           \|b (c x)  - a
+--R        2atan(-------------------------) - 2atan(---------------)
+--R                          a                             +-+
+--R                                                       \|a
+--R   (6)  ---------------------------------------------------------
+--R                                    +-+
+--R                                  n\|a
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R                         +------------------+          +------------+
+--R                   n - 1 |    n log(c x)             n |       n
+--R        - c x (c x)     \|b %e           - a  + (c x) \|b (c x)  - a
+--R   (7)  -------------------------------------------------------------
+--R                          +------------+ +------------------+
+--R                        n |       n      |    n log(c x)
+--R                 x (c x) \|b (c x)  - a \|b %e           - a
+--R                                                    Type: Expression(Integer)
+--E 130
+
+)clear all
+
+--S 131 of 649
+t0:=1/(x*(-a+b*(c*x)^n)^(3/2))
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R                           +------------+
+--R                  n        |       n
+--R        (b x (c x)  - a x)\|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 649
+r0:=-2*atan(sqrt(-a+b*(c*x)^n)/sqrt(a))/(a^(3/2)*n)+(-2)/(a*n*_
+   sqrt(-a+b*(c*x)^n))
+--R 
+--R
+--R                                +------------+
+--R            +------------+      |       n
+--R            |       n          \|b (c x)  - a       +-+
+--R        - 2\|b (c x)  - a atan(---------------) - 2\|a
+--R                                      +-+
+--R                                     \|a
+--R   (2)  -----------------------------------------------
+--R                             +------------+
+--R                         +-+ |       n
+--R                     a n\|a \|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R            +------------------+
+--R            |    n log(c x)
+--R           \|b %e           - a
+--R        *
+--R                    +------------------+
+--R                    |    n log(c x)          +---+  n log(c x)      +---+
+--R               - 2a\|b %e           - a  + b\|- a %e           - 2a\|- a
+--R           log(----------------------------------------------------------)
+--R                                        n log(c x)
+--R                                      %e
+--R       + 
+--R             +---+
+--R         - 2\|- a
+--R    /
+--R                 +------------------+
+--R           +---+ |    n log(c x)
+--R       a n\|- a \|b %e           - a
+--R     ,
+--R                                      +------------------+
+--R        +------------------+      +-+ |    n log(c x)
+--R        |    n log(c x)          \|a \|b %e           - a       +-+
+--R    - 2\|b %e           - a atan(-------------------------) - 2\|a
+--R                                             a
+--R    ---------------------------------------------------------------]
+--R                              +------------------+
+--R                          +-+ |    n log(c x)
+--R                      a n\|a \|b %e           - a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 133
+
+--S 134 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              +------------+ +------------------+
+--R          +-+ |       n      |    n log(c x)
+--R         \|a \|b (c x)  - a \|b %e           - a
+--R      *
+--R                  +------------------+
+--R                  |    n log(c x)          +---+  n log(c x)      +---+
+--R             - 2a\|b %e           - a  + b\|- a %e           - 2a\|- a
+--R         log(----------------------------------------------------------)
+--R                                      n log(c x)
+--R                                    %e
+--R     + 
+--R                                      +------------+
+--R                  +------------+      |       n
+--R            +---+ |       n          \|b (c x)  - a       +---+ +-+
+--R         (2\|- a \|b (c x)  - a atan(---------------) + 2\|- a \|a )
+--R                                            +-+
+--R                                           \|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R                     +------------+
+--R           +---+ +-+ |       n
+--R       - 2\|- a \|a \|b (c x)  - a
+--R  /
+--R                   +------------+ +------------------+
+--R         +---+ +-+ |       n      |    n log(c x)
+--R     a n\|- a \|a \|b (c x)  - a \|b %e           - a
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                          +------------+
+--R                         n 2     2     n  |       n
+--R           (- 2a b ((c x) )  + 2a (c x) )\|b (c x)  - a
+--R         + 
+--R              2         n - 1 +---+   n log(c x) 2
+--R           - b c x (c x)     \|- a (%e          )
+--R         + 
+--R                         n - 1 +---+  n log(c x)     2         n - 1 +---+
+--R           3a b c x (c x)     \|- a %e           - 2a c x (c x)     \|- a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R             2      n 2            n  +---+  n log(c x)
+--R           (b ((c x) )  - a b (c x) )\|- a %e
+--R         + 
+--R                         n 2     2     n  +---+
+--R           (- 2a b ((c x) )  + 2a (c x) )\|- a
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  - a
+--R     + 
+--R           2         n - 1   n log(c x) 2     2           n - 1  n log(c x)
+--R       2a b c x (c x)     (%e          )  - 4a b c x (c x)     %e
+--R     + 
+--R         3         n - 1
+--R       2a c x (c x)
+--R  /
+--R             3        n 2      2       n  +---+   n log(c x) 2
+--R           (b x ((c x) )  - a b x (c x) )\|- a (%e          )
+--R         + 
+--R                  2        n 2     2         n  +---+  n log(c x)
+--R           (- 3a b x ((c x) )  + 3a b x (c x) )\|- a %e
+--R         + 
+--R              2          n 2     3       n  +---+
+--R           (2a b x ((c x) )  - 2a x (c x) )\|- a
+--R      *
+--R          +------------+ +------------------+
+--R          |       n      |    n log(c x)
+--R         \|b (c x)  - a \|b %e           - a
+--R     + 
+--R                  3        n 2     2 2       n    n log(c x) 2
+--R           (- 2a b x ((c x) )  + 2a b x (c x) )(%e          )
+--R         + 
+--R              2 2        n 2     3         n   n log(c x)     3          n 2
+--R           (4a b x ((c x) )  - 4a b x (c x) )%e           - 2a b x ((c x) )
+--R         + 
+--R             4       n
+--R           2a x (c x)
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 135
+
+--S 136 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                        +------------------+
+--R           +------------+ +------------------+      +-+ |    n log(c x)
+--R           |       n      |    n log(c x)          \|a \|b %e           - a
+--R       - 2\|b (c x)  - a \|b %e           - a atan(-------------------------)
+--R                                                               a
+--R     + 
+--R                              +------------+
+--R          +------------+      |       n                +------------------+
+--R          |       n          \|b (c x)  - a       +-+  |    n log(c x)
+--R       (2\|b (c x)  - a atan(---------------) + 2\|a )\|b %e           - a
+--R                                    +-+
+--R                                   \|a
+--R     + 
+--R               +------------+
+--R           +-+ |       n
+--R       - 2\|a \|b (c x)  - a
+--R  /
+--R             +------------+ +------------------+
+--R         +-+ |       n      |    n log(c x)
+--R     a n\|a \|b (c x)  - a \|b %e           - a
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                                           +------------------+
+--R                     n - 1  n log(c x)              n - 1  |    n log(c x)
+--R       (- b c x (c x)     %e           + a c x (c x)     )\|b %e           - a
+--R     + 
+--R                                +------------+
+--R                n 2          n  |       n
+--R       (b ((c x) )  - a (c x) )\|b (c x)  - a
+--R  /
+--R             2        n 2              n   n log(c x)               n 2
+--R           (b x ((c x) )  - a b x (c x) )%e           - a b x ((c x) )
+--R         + 
+--R            2       n
+--R           a x (c x)
+--R    *
+--R        +------------+ +------------------+
+--R        |       n      |    n log(c x)
+--R       \|b (c x)  - a \|b %e           - a
+--R                                                    Type: Expression(Integer)
+--E 137
+
+)clear all
+
+--S 138 of 649
+t0:=1/(x*(-a+b*(c*x)^n)^(5/2))
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R                                              +------------+
+--R          2        n 2               n    2   |       n
+--R        (b x ((c x) )  - 2a b x (c x)  + a x)\|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 138
+
+--S 139 of 649
+r0:=(-2/3)/(a*n*(-a+b*(c*x)^n)^(3/2))+2*atan(sqrt(-a+b*(c*x)^n)/_
+   sqrt(a))/(a^(5/2)*n)+2/(a^2*n*sqrt(-a+b*(c*x)^n))
+--R 
+--R
+--R   (2)
+--R                                        +------------+
+--R                    +------------+      |       n
+--R            n       |       n          \|b (c x)  - a              n       +-+
+--R   (6b (c x)  - 6a)\|b (c x)  - a atan(---------------) + (6b (c x)  - 8a)\|a
+--R                                              +-+
+--R                                             \|a
+--R   ---------------------------------------------------------------------------
+--R                                               +------------+
+--R                       2         n     3   +-+ |       n
+--R                    (3a b n (c x)  - 3a n)\|a \|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                  +------------------+
+--R                 n log(c x)       |    n log(c x)
+--R           (3b %e           - 3a)\|b %e           - a
+--R        *
+--R                  +------------------+
+--R                  |    n log(c x)          +---+  n log(c x)      +---+
+--R               2a\|b %e           - a  + b\|- a %e           - 2a\|- a
+--R           log(--------------------------------------------------------)
+--R                                       n log(c x)
+--R                                     %e
+--R       + 
+--R            +---+  n log(c x)      +---+
+--R         6b\|- a %e           - 8a\|- a
+--R    /
+--R                                               +------------------+
+--R          2    +---+  n log(c x)     3  +---+  |    n log(c x)
+--R       (3a b n\|- a %e           - 3a n\|- a )\|b %e           - a
+--R     ,
+--R
+--R                                  +------------------+
+--R                 n log(c x)       |    n log(c x)
+--R           (6b %e           - 6a)\|b %e           - a
+--R        *
+--R                     +------------------+
+--R                 +-+ |    n log(c x)
+--R                \|a \|b %e           - a
+--R           atan(-------------------------)
+--R                            a
+--R       + 
+--R            +-+  n log(c x)      +-+
+--R         6b\|a %e           - 8a\|a
+--R    /
+--R                                           +------------------+
+--R          2    +-+  n log(c x)     3  +-+  |    n log(c x)
+--R       (3a b n\|a %e           - 3a n\|a )\|b %e           - a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 140
+
+--S 141 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2     n         +-+  n log(c x)                n     2  +-+
+--R         ((3b (c x)  - 3a b)\|a %e           + (- 3a b (c x)  + 3a )\|a )
+--R      *
+--R          +------------+ +------------------+
+--R          |       n      |    n log(c x)
+--R         \|b (c x)  - a \|b %e           - a
+--R      *
+--R                +------------------+
+--R                |    n log(c x)          +---+  n log(c x)      +---+
+--R             2a\|b %e           - a  + b\|- a %e           - 2a\|- a
+--R         log(--------------------------------------------------------)
+--R                                     n log(c x)
+--R                                   %e
+--R     + 
+--R                      2     n         +---+  n log(c x)
+--R                 (- 6b (c x)  + 6a b)\|- a %e
+--R               + 
+--R                            n     2  +---+
+--R                 (6a b (c x)  - 6a )\|- a
+--R          *
+--R                                  +------------+
+--R              +------------+      |       n
+--R              |       n          \|b (c x)  - a
+--R             \|b (c x)  - a atan(---------------)
+--R                                        +-+
+--R                                       \|a
+--R         + 
+--R                2     n         +---+ +-+  n log(c x)
+--R           (- 6b (c x)  + 8a b)\|- a \|a %e
+--R         + 
+--R                      n     2  +---+ +-+
+--R           (6a b (c x)  - 8a )\|- a \|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R              2     n         +---+ +-+  n log(c x)
+--R           (6b (c x)  - 6a b)\|- a \|a %e
+--R         + 
+--R                        n     2  +---+ +-+
+--R           (- 8a b (c x)  + 8a )\|- a \|a
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  - a
+--R  /
+--R            2 2       n     3     +---+ +-+  n log(c x)
+--R         (3a b n (c x)  - 3a b n)\|- a \|a %e
+--R       + 
+--R              3         n     4   +---+ +-+
+--R         (- 3a b n (c x)  + 3a n)\|- a \|a
+--R    *
+--R        +------------+ +------------------+
+--R        |       n      |    n log(c x)
+--R       \|b (c x)  - a \|b %e           - a
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                                         +------------+
+--R                2      n 3     2        n 2     3     n  |       n
+--R           (2a b ((c x) )  - 4a b ((c x) )  + 2a (c x) )\|b (c x)  - a
+--R         + 
+--R              3         n - 1 +---+   n log(c x) 3
+--R           - b c x (c x)     \|- a (%e          )
+--R         + 
+--R               2         n - 1 +---+   n log(c x) 2
+--R           4a b c x (c x)     \|- a (%e          )
+--R         + 
+--R               2           n - 1 +---+  n log(c x)     3         n - 1 +---+
+--R           - 5a b c x (c x)     \|- a %e           + 2a c x (c x)     \|- a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R             3      n 3       2      n 2    2       n  +---+  n log(c x)
+--R           (b ((c x) )  - 2a b ((c x) )  + a b (c x) )\|- a %e
+--R         + 
+--R                  2      n 3     2        n 2     3     n  +---+
+--R           (- 2a b ((c x) )  + 4a b ((c x) )  - 2a (c x) )\|- a
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  - a
+--R     + 
+--R             3         n - 1   n log(c x) 3     2 2         n - 1   n log(c x) 2
+--R       - 2a b c x (c x)     (%e          )  + 6a b c x (c x)     (%e          )
+--R     + 
+--R           3           n - 1  n log(c x)     4         n - 1
+--R       - 6a b c x (c x)     %e           + 2a c x (c x)
+--R  /
+--R               5        n 3       4        n 2    2 3       n  +---+
+--R             (b x ((c x) )  - 2a b x ((c x) )  + a b x (c x) )\|- a
+--R          *
+--R                n log(c x) 3
+--R             (%e          )
+--R         + 
+--R                    4        n 3     2 3        n 2     3 2       n  +---+
+--R             (- 4a b x ((c x) )  + 8a b x ((c x) )  - 4a b x (c x) )\|- a
+--R          *
+--R                n log(c x) 2
+--R             (%e          )
+--R         + 
+--R                2 3        n 3      3 2        n 2     4         n  +---+
+--R             (5a b x ((c x) )  - 10a b x ((c x) )  + 5a b x (c x) )\|- a
+--R          *
+--R               n log(c x)
+--R             %e
+--R         + 
+--R                3 2        n 3     4          n 2     5       n  +---+
+--R           (- 2a b x ((c x) )  + 4a b x ((c x) )  - 2a x (c x) )\|- a
+--R      *
+--R          +------------+ +------------------+
+--R          |       n      |    n log(c x)
+--R         \|b (c x)  - a \|b %e           - a
+--R     + 
+--R                5        n 3     2 4        n 2     3 3       n    n log(c x) 3
+--R           (2a b x ((c x) )  - 4a b x ((c x) )  + 2a b x (c x) )(%e          )
+--R         + 
+--R                  2 4        n 3      3 3        n 2     4 2       n
+--R             (- 6a b x ((c x) )  + 12a b x ((c x) )  - 6a b x (c x) )
+--R          *
+--R                n log(c x) 2
+--R             (%e          )
+--R         + 
+--R              3 3        n 3      4 2        n 2     5         n   n log(c x)
+--R           (6a b x ((c x) )  - 12a b x ((c x) )  + 6a b x (c x) )%e
+--R         + 
+--R               4 2        n 3     5          n 2     6       n
+--R           - 2a b x ((c x) )  + 4a b x ((c x) )  - 2a x (c x)
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                              +------------+
+--R             2     n          n log(c x)             n     2  |       n
+--R         ((6b (c x)  - 6a b)%e           - 6a b (c x)  + 6a )\|b (c x)  - a
+--R      *
+--R                                        +------------------+
+--R          +------------------+      +-+ |    n log(c x)
+--R          |    n log(c x)          \|a \|b %e           - a
+--R         \|b %e           - a atan(-------------------------)
+--R                                               a
+--R     + 
+--R                   2     n          n log(c x)             n     2
+--R             ((- 6b (c x)  + 6a b)%e           + 6a b (c x)  - 6a )
+--R          *
+--R                                  +------------+
+--R              +------------+      |       n
+--R              |       n          \|b (c x)  - a
+--R             \|b (c x)  - a atan(---------------)
+--R                                        +-+
+--R                                       \|a
+--R         + 
+--R                2     n         +-+  n log(c x)              n     2  +-+
+--R           (- 6b (c x)  + 8a b)\|a %e           + (6a b (c x)  - 8a )\|a
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R             2     n         +-+  n log(c x)                n     2  +-+
+--R         ((6b (c x)  - 6a b)\|a %e           + (- 8a b (c x)  + 8a )\|a )
+--R      *
+--R          +------------+
+--R          |       n
+--R         \|b (c x)  - a
+--R  /
+--R           2 2       n     3     +-+  n log(c x)        3         n     4   +-+
+--R       ((3a b n (c x)  - 3a b n)\|a %e           + (- 3a b n (c x)  + 3a n)\|a )
+--R    *
+--R        +------------+ +------------------+
+--R        |       n      |    n log(c x)
+--R       \|b (c x)  - a \|b %e           - a
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R              2         n - 1   n log(c x) 2                 n - 1  n log(c x)
+--R           - b c x (c x)     (%e          )  + 2a b c x (c x)     %e
+--R         + 
+--R              2         n - 1
+--R           - a c x (c x)
+--R      *
+--R          +------------------+
+--R          |    n log(c x)
+--R         \|b %e           - a
+--R     + 
+--R                                                 +------------+
+--R         2      n 3              n 2    2     n  |       n
+--R       (b ((c x) )  - 2a b ((c x) )  + a (c x) )\|b (c x)  - a
+--R  /
+--R           4        n 3       3        n 2    2 2       n    n log(c x) 2
+--R         (b x ((c x) )  - 2a b x ((c x) )  + a b x (c x) )(%e          )
+--R       + 
+--R                3        n 3     2 2        n 2     3         n   n log(c x)
+--R         (- 2a b x ((c x) )  + 4a b x ((c x) )  - 2a b x (c x) )%e
+--R       + 
+--R          2 2        n 3     3          n 2    4       n
+--R         a b x ((c x) )  - 2a b x ((c x) )  + a x (c x)
+--R    *
+--R        +------------+ +------------------+
+--R        |       n      |    n log(c x)
+--R       \|b (c x)  - a \|b %e           - a
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 649
+t0:=1/(x*sqrt(a+b*x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R          +-------+
+--R        x\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 649
+r0:=-2*atanh(sqrt(a+b*x)/sqrt(a))/sqrt(a)
+--R 
+--R
+--R                  +-------+
+--R                 \|b x + a
+--R          2atanh(----------)
+--R                     +-+
+--R                    \|a
+--R   (2)  - ------------------
+--R                  +-+
+--R                 \|a
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +-------+              +-+           +---+ +-------+
+--R             - 2a\|b x + a  + (b x + 2a)\|a           \|- a \|b x + a
+--R         log(-------------------------------)   2atan(----------------)
+--R                            x                                 a
+--R   (3)  [------------------------------------,- -----------------------]
+--R                          +-+                             +---+
+--R                         \|a                             \|- a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 147
+
+--S 148 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R                 +-------+              +-+            +-------+
+--R            - 2a\|b x + a  + (b x + 2a)\|a            \|b x + a
+--R        log(-------------------------------) + 2atanh(----------)
+--R                           x                              +-+
+--R                                                         \|a
+--R   (4)  ---------------------------------------------------------
+--R                                    +-+
+--R                                   \|a
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R                      +-------+               +---+ +-------+
+--R          +---+      \|b x + a       +-+     \|- a \|b x + a
+--R        2\|- a atanh(----------) - 2\|a atan(----------------)
+--R                         +-+                         a
+--R                        \|a
+--R   (6)  ------------------------------------------------------
+--R                               +---+ +-+
+--R                              \|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 150
+
+--S 151 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 151
+
+)clear all
+
+--S 152 of 649
+t0:=1/(x*sqrt(a+b*(c*x)^m))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R          +------------+
+--R          |       m
+--R        x\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 649
+r0:=-2*atanh(sqrt(a+b*(c*x)^m)/sqrt(a))/(m*sqrt(a))
+--R 
+--R
+--R                  +------------+
+--R                  |       m
+--R                 \|b (c x)  + a
+--R          2atanh(---------------)
+--R                        +-+
+--R                       \|a
+--R   (2)  - -----------------------
+--R                     +-+
+--R                   m\|a
+--R                                                    Type: Expression(Integer)
+--E 153
+
+--S 154 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +------------------+
+--R             |    m log(c x)          +-+  m log(c x)      +-+
+--R        - 2a\|b %e           + a  + b\|a %e           + 2a\|a
+--R    log(------------------------------------------------------)
+--R                               m log(c x)
+--R                             %e
+--R   [-----------------------------------------------------------,
+--R                                 +-+
+--R                               m\|a
+--R                   +------------------+
+--R             +---+ |    m log(c x)
+--R            \|- a \|b %e           + a
+--R      2atan(---------------------------)
+--R                         a
+--R    - ----------------------------------]
+--R                      +---+
+--R                    m\|- a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 154
+
+--S 155 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                +------------------+
+--R                |    m log(c x)          +-+  m log(c x)      +-+
+--R           - 2a\|b %e           + a  + b\|a %e           + 2a\|a
+--R       log(------------------------------------------------------)
+--R                                  m log(c x)
+--R                                %e
+--R     + 
+--R               +------------+
+--R               |       m
+--R              \|b (c x)  + a
+--R       2atanh(---------------)
+--R                     +-+
+--R                    \|a
+--R  /
+--R       +-+
+--R     m\|a
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                       +------------+
+--R                     m |       m                   m - 1 +-+  m log(c x)
+--R           - 2a (c x) \|b (c x)  + a  - b c x (c x)     \|a %e
+--R         + 
+--R                         m - 1 +-+
+--R           - 2a c x (c x)     \|a
+--R      *
+--R          +------------------+
+--R          |    m log(c x)
+--R         \|b %e           + a
+--R     + 
+--R                                                  +------------+
+--R               m +-+  m log(c x)           m +-+  |       m
+--R       (b (c x) \|a %e           + 2a (c x) \|a )\|b (c x)  + a
+--R     + 
+--R                     m - 1  m log(c x)     2         m - 1
+--R       2a b c x (c x)     %e           + 2a c x (c x)
+--R  /
+--R                                                        +------------+
+--R                   m +-+  m log(c x)             m +-+  |       m
+--R         (b x (c x) \|a %e           + 2a x (c x) \|a )\|b (c x)  + a
+--R      *
+--R          +------------------+
+--R          |    m log(c x)
+--R         \|b %e           + a
+--R     + 
+--R                                                   +------------+
+--R                      m  m log(c x)     2       m  |       m
+--R       (- 2a b x (c x) %e           - 2a x (c x) )\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      +------------------+                  +------------+
+--R                +---+ |    m log(c x)                       |       m
+--R       +-+     \|- a \|b %e           + a       +---+      \|b (c x)  + a
+--R   - 2\|a atan(---------------------------) + 2\|- a atanh(---------------)
+--R                            a                                     +-+
+--R                                                                 \|a
+--R   ------------------------------------------------------------------------
+--R                                    +---+ +-+
+--R                                  m\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R                         +------------------+          +------------+
+--R                   m - 1 |    m log(c x)             m |       m
+--R        - c x (c x)     \|b %e           + a  + (c x) \|b (c x)  + a
+--R   (7)  -------------------------------------------------------------
+--R                          +------------+ +------------------+
+--R                        m |       m      |    m log(c x)
+--R                 x (c x) \|b (c x)  + a \|b %e           + a
+--R                                                    Type: Expression(Integer)
+--E 158
+
+)clear all
+
+--S 159 of 649
+t0:=1/(x*sqrt(a+b*(c*(d*x)^m)^n))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R          +-----------------+
+--R          |          m n
+--R        x\|b (c (d x) )  + a
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 649
+r0:=-2*atanh(sqrt(a+b*(c*(d*x)^m)^n)/sqrt(a))/(m*n*sqrt(a))
+--R 
+--R
+--R                  +-----------------+
+--R                  |          m n
+--R                 \|b (c (d x) )  + a
+--R          2atanh(--------------------)
+--R                          +-+
+--R                         \|a
+--R   (2)  - ----------------------------
+--R                         +-+
+--R                     m n\|a
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                   +-------------------------------+
+--R                   |    m n log(d x) + n log(c)
+--R              - 2a\|b %e                        + a
+--R            + 
+--R                +-+  m n log(d x) + n log(c)      +-+
+--R              b\|a %e                        + 2a\|a
+--R         /
+--R              m n log(d x) + n log(c)
+--R            %e
+--R    /
+--R           +-+
+--R       m n\|a
+--R     ,
+--R                   +-------------------------------+
+--R             +---+ |    m n log(d x) + n log(c)
+--R            \|- a \|b %e                        + a
+--R      2atan(----------------------------------------)
+--R                                a
+--R    - -----------------------------------------------]
+--R                             +---+
+--R                         m n\|- a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 161
+
+--S 162 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                   +-------------------------------+
+--R                   |    m n log(d x) + n log(c)
+--R              - 2a\|b %e                        + a
+--R            + 
+--R                +-+  m n log(d x) + n log(c)      +-+
+--R              b\|a %e                        + 2a\|a
+--R         /
+--R              m n log(d x) + n log(c)
+--R            %e
+--R     + 
+--R               +-----------------+
+--R               |          m n
+--R              \|b (c (d x) )  + a
+--R       2atanh(--------------------)
+--R                       +-+
+--R                      \|a
+--R  /
+--R         +-+
+--R     m n\|a
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                            +-------------------------------+
+--R                        m n |    m n log(d x) + n log(c)
+--R           - 2a (c (d x) ) \|b %e                        + a
+--R         + 
+--R              +-+  m n log(d x) + n log(c)      +-+         m n
+--R           (b\|a %e                        + 2a\|a )(c (d x) )
+--R      *
+--R          +-----------------+
+--R          |          m n
+--R         \|b (c (d x) )  + a
+--R     + 
+--R                          m - 1 +-+  m n log(d x) + n log(c)
+--R           - b c d x (d x)     \|a %e
+--R         + 
+--R                           m - 1 +-+
+--R           - 2a c d x (d x)     \|a
+--R      *
+--R                         +-------------------------------+
+--R                 m n - 1 |    m n log(d x) + n log(c)
+--R         (c (d x) )     \|b %e                        + a
+--R     + 
+--R                          m - 1  m n log(d x) + n log(c)     2           m - 1
+--R         (2a b c d x (d x)     %e                        + 2a c d x (d x)     )
+--R      *
+--R                 m n - 1
+--R         (c (d x) )
+--R  /
+--R                +-+  m n log(d x) + n log(c)        +-+         m n
+--R           (b x\|a %e                        + 2a x\|a )(c (d x) )
+--R        *
+--R            +-------------------------------+
+--R            |    m n log(d x) + n log(c)
+--R           \|b %e                        + a
+--R       + 
+--R                     m n log(d x) + n log(c)     2          m n
+--R         (- 2a b x %e                        - 2a x)(c (d x) )
+--R    *
+--R        +-----------------+
+--R        |          m n
+--R       \|b (c (d x) )  + a
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +-----------------+
+--R                     |          m n
+--R         +---+      \|b (c (d x) )  + a
+--R       2\|- a atanh(--------------------)
+--R                             +-+
+--R                            \|a
+--R     + 
+--R                          +-------------------------------+
+--R                    +---+ |    m n log(d x) + n log(c)
+--R           +-+     \|- a \|b %e                        + a
+--R       - 2\|a atan(----------------------------------------)
+--R                                       a
+--R  /
+--R         +---+ +-+
+--R     m n\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                   +-----------------+
+--R               m n |          m n
+--R       (c (d x) ) \|b (c (d x) )  + a
+--R     + 
+--R                                         +-------------------------------+
+--R                    m - 1        m n - 1 |    m n log(d x) + n log(c)
+--R       - c d x (d x)     (c (d x) )     \|b %e                        + a
+--R  /
+--R                   +-------------------------------+ +-----------------+
+--R               m n |    m n log(d x) + n log(c)      |          m n
+--R     x (c (d x) ) \|b %e                        + a \|b (c (d x) )  + a
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 649
+t0:=1/(x*sqrt(a+b*(c*(d*(e*x)^m)^n)^p))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R          +----------------------+
+--R          |             m n p
+--R        x\|b (c (d (e x) ) )  + a
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 649
+r0:=-2*atanh(sqrt(a+b*(c*(d*(e*x)^m)^n)^p)/sqrt(a))/(m*n*p*sqrt(a))
+--R 
+--R
+--R                  +----------------------+
+--R                  |             m n p
+--R                 \|b (c (d (e x) ) )  + a
+--R          2atanh(-------------------------)
+--R                             +-+
+--R                            \|a
+--R   (2)  - ---------------------------------
+--R                            +-+
+--R                      m n p\|a
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                   +----------------------------------------------+
+--R                   |    m n p log(e x) + n p log(d) + p log(c)
+--R              - 2a\|b %e                                       + a
+--R            + 
+--R                +-+  m n p log(e x) + n p log(d) + p log(c)      +-+
+--R              b\|a %e                                       + 2a\|a
+--R         /
+--R              m n p log(e x) + n p log(d) + p log(c)
+--R            %e
+--R    /
+--R             +-+
+--R       m n p\|a
+--R     ,
+--R                   +----------------------------------------------+
+--R             +---+ |    m n p log(e x) + n p log(d) + p log(c)
+--R            \|- a \|b %e                                       + a
+--R      2atan(-------------------------------------------------------)
+--R                                       a
+--R    - --------------------------------------------------------------]
+--R                                      +---+
+--R                                m n p\|- a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 168
+
+--S 169 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               +----------------------+
+--R               |             m n p
+--R              \|b (c (d (e x) ) )  + a
+--R       2atanh(-------------------------)
+--R                          +-+
+--R                         \|a
+--R     + 
+--R       log
+--R                   +----------------------------------------------+
+--R                   |    m n p log(e x) + n p log(d) + p log(c)
+--R              - 2a\|b %e                                       + a
+--R            + 
+--R                +-+  m n p log(e x) + n p log(d) + p log(c)      +-+
+--R              b\|a %e                                       + 2a\|a
+--R         /
+--R              m n p log(e x) + n p log(d) + p log(c)
+--R            %e
+--R  /
+--R           +-+
+--R     m n p\|a
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R           -
+--R                              m n p
+--R                2a (c (d (e x) ) )
+--R             *
+--R                 +----------------------------------------------+
+--R                 |    m n p log(e x) + n p log(d) + p log(c)
+--R                \|b %e                                       + a
+--R         + 
+--R                +-+  m n p log(e x) + n p log(d) + p log(c)      +-+
+--R             (b\|a %e                                       + 2a\|a )
+--R          *
+--R                        m n p
+--R             (c (d (e x) ) )
+--R      *
+--R          +----------------------+
+--R          |             m n p
+--R         \|b (c (d (e x) ) )  + a
+--R     + 
+--R                            m - 1 +-+  m n p log(e x) + n p log(d) + p log(c)
+--R           - b c d e x (e x)     \|a %e
+--R         + 
+--R                             m - 1 +-+
+--R           - 2a c d e x (e x)     \|a
+--R      *
+--R                 m n - 1           m n p - 1
+--R         (d (e x) )     (c (d (e x) ) )
+--R      *
+--R          +----------------------------------------------+
+--R          |    m n p log(e x) + n p log(d) + p log(c)
+--R         \|b %e                                       + a
+--R     + 
+--R                             m - 1  m n p log(e x) + n p log(d) + p log(c)
+--R           2a b c d e x (e x)     %e
+--R         + 
+--R             2             m - 1
+--R           2a c d e x (e x)
+--R      *
+--R                 m n - 1           m n p - 1
+--R         (d (e x) )     (c (d (e x) ) )
+--R  /
+--R                +-+  m n p log(e x) + n p log(d) + p log(c)        +-+
+--R           (b x\|a %e                                       + 2a x\|a )
+--R        *
+--R                            +----------------------------------------------+
+--R                      m n p |    m n p log(e x) + n p log(d) + p log(c)
+--R           (c (d (e x) ) ) \|b %e                                       + a
+--R       + 
+--R                       m n p log(e x) + n p log(d) + p log(c)     2
+--R           (- 2a b x %e                                       - 2a x)
+--R        *
+--R                      m n p
+--R           (c (d (e x) ) )
+--R    *
+--R        +----------------------+
+--R        |             m n p
+--R       \|b (c (d (e x) ) )  + a
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +----------------------+
+--R                     |             m n p
+--R         +---+      \|b (c (d (e x) ) )  + a
+--R       2\|- a atanh(-------------------------)
+--R                                +-+
+--R                               \|a
+--R     + 
+--R                          +----------------------------------------------+
+--R                    +---+ |    m n p log(e x) + n p log(d) + p log(c)
+--R           +-+     \|- a \|b %e                                       + a
+--R       - 2\|a atan(-------------------------------------------------------)
+--R                                              a
+--R  /
+--R           +---+ +-+
+--R     m n p\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                        +----------------------+
+--R                  m n p |             m n p
+--R       (c (d (e x) ) ) \|b (c (d (e x) ) )  + a
+--R     + 
+--R       -
+--R                         m - 1        m n - 1           m n p - 1
+--R            c d e x (e x)     (d (e x) )     (c (d (e x) ) )
+--R         *
+--R             +----------------------------------------------+
+--R             |    m n p log(e x) + n p log(d) + p log(c)
+--R            \|b %e                                       + a
+--R  /
+--R                          +----------------------------------------------+
+--R                    m n p |    m n p log(e x) + n p log(d) + p log(c)
+--R       x (c (d (e x) ) ) \|b %e                                       + a
+--R    *
+--R        +----------------------+
+--R        |             m n p
+--R       \|b (c (d (e x) ) )  + a
+--R                                                    Type: Expression(Integer)
+--E 172
+
+)clear all
+
+--S 173 of 649
+t0:=1/(x*sqrt(a+b*(c*(d*(e*(f*x)^m)^n)^p)^q))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R          +---------------------------+
+--R          |                m n p q
+--R        x\|b (c (d (e (f x) ) ) )  + a
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 649
+r0:=-2*atanh(sqrt(a+b*(c*(d*(e*(f*x)^m)^n)^p)^q)/sqrt(a))/(m*n*p*q*sqrt(a))
+--R 
+--R
+--R                  +---------------------------+
+--R                  |                m n p q
+--R                 \|b (c (d (e (f x) ) ) )  + a
+--R          2atanh(------------------------------)
+--R                               +-+
+--R                              \|a
+--R   (2)  - --------------------------------------
+--R                                +-+
+--R                        m n p q\|a
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R              -
+--R                   2a
+--R                *
+--R                   ROOT
+--R                          b
+--R                       *
+--R                            %e
+--R                         **
+--R                              m n p q log(f x) + n p q log(e) + p q log(d)
+--R                            + 
+--R                              q log(c)
+--R                      + 
+--R                        a
+--R            + 
+--R                +-+  m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R              b\|a %e
+--R            + 
+--R                 +-+
+--R              2a\|a
+--R         /
+--R              m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R            %e
+--R    /
+--R               +-+
+--R       m n p q\|a
+--R     ,
+--R
+--R     -
+--R            2
+--R         *
+--R            atan
+--R                    +---+
+--R                   \|- a
+--R                *
+--R                   ROOT
+--R                          b
+--R                       *
+--R                            %e
+--R                         **
+--R                              m n p q log(f x) + n p q log(e) + p q log(d)
+--R                            + 
+--R                              q log(c)
+--R                      + 
+--R                        a
+--R              /
+--R                 a
+--R       /
+--R                  +---+
+--R          m n p q\|- a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 175
+
+--S 176 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R               +---------------------------+
+--R               |                m n p q
+--R              \|b (c (d (e (f x) ) ) )  + a
+--R       2atanh(------------------------------)
+--R                            +-+
+--R                           \|a
+--R     + 
+--R       log
+--R              -
+--R                   2a
+--R                *
+--R                   ROOT
+--R                          b
+--R                       *
+--R                            %e
+--R                         **
+--R                              m n p q log(f x) + n p q log(e) + p q log(d)
+--R                            + 
+--R                              q log(c)
+--R                      + 
+--R                        a
+--R            + 
+--R                +-+  m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R              b\|a %e
+--R            + 
+--R                 +-+
+--R              2a\|a
+--R         /
+--R              m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R            %e
+--R  /
+--R             +-+
+--R     m n p q\|a
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R           -
+--R                2a
+--R             *
+--R               +---------------------------------------------------------------+
+--R               |    m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R              \|b %e                                                        + a
+--R         + 
+--R           +-+  m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)      +-+
+--R         b\|a %e                                                        + 2a\|a
+--R      *
+--R                               +---------------------------+
+--R                       m n p q |                m n p q
+--R         (c (d (e (f x) ) ) ) \|b (c (d (e (f x) ) ) )  + a
+--R     + 
+--R               -
+--R                                     m - 1 +-+
+--R                    b c d e f x (f x)     \|a
+--R                 *
+--R                      m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R                    %e
+--R             + 
+--R                                   m - 1 +-+
+--R               - 2a c d e f x (f x)     \|a
+--R          *
+--R                     m n - 1           m n p - 1
+--R             (e (f x) )     (d (e (f x) ) )
+--R          *
+--R              +---------------------------------------------------------------+
+--R              |    m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R             \|b %e                                                        + a
+--R         + 
+--R                                     m - 1
+--R                 2a b c d e f x (f x)
+--R              *
+--R                   m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R                 %e
+--R             + 
+--R                 2               m - 1
+--R               2a c d e f x (f x)
+--R          *
+--R                     m n - 1           m n p - 1
+--R             (e (f x) )     (d (e (f x) ) )
+--R      *
+--R                       m n p q - 1
+--R         (c (d (e (f x) ) ) )
+--R  /
+--R                 +-+  m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R             b x\|a %e
+--R           + 
+--R                  +-+
+--R             2a x\|a
+--R        *
+--R            +---------------------------------------------------------------+
+--R            |    m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R           \|b %e                                                        + a
+--R       + 
+--R                  m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)     2
+--R       - 2a b x %e                                                        - 2a x
+--R    *
+--R                             +---------------------------+
+--R                     m n p q |                m n p q
+--R       (c (d (e (f x) ) ) ) \|b (c (d (e (f x) ) ) )  + a
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---------------------------+
+--R                     |                m n p q
+--R         +---+      \|b (c (d (e (f x) ) ) )  + a
+--R       2\|- a atanh(------------------------------)
+--R                                  +-+
+--R                                 \|a
+--R     + 
+--R       -
+--R              +-+
+--R            2\|a
+--R         *
+--R            atan
+--R                    +---+
+--R                   \|- a
+--R                *
+--R                   ROOT
+--R                          b
+--R                       *
+--R                            %e
+--R                         **
+--R                              m n p q log(f x) + n p q log(e) + p q log(d)
+--R                            + 
+--R                              q log(c)
+--R                      + 
+--R                        a
+--R              /
+--R                 a
+--R  /
+--R             +---+ +-+
+--R     m n p q\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                             +---------------------------+
+--R                     m n p q |                m n p q
+--R       (c (d (e (f x) ) ) ) \|b (c (d (e (f x) ) ) )  + a
+--R     + 
+--R       -
+--R                           m - 1        m n - 1           m n p - 1
+--R            c d e f x (f x)     (e (f x) )     (d (e (f x) ) )
+--R         *
+--R             +---------------------------------------------------------------+
+--R             |    m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R            \|b %e                                                        + a
+--R         *
+--R                          m n p q - 1
+--R            (c (d (e (f x) ) ) )
+--R  /
+--R         +---------------------------------------------------------------+
+--R         |    m n p q log(f x) + n p q log(e) + p q log(d) + q log(c)
+--R       x\|b %e                                                        + a
+--R    *
+--R                             +---------------------------+
+--R                     m n p q |                m n p q
+--R       (c (d (e (f x) ) ) ) \|b (c (d (e (f x) ) ) )  + a
+--R                                                    Type: Expression(Integer)
+--E 179
+
+)clear all
+
+--S 180 of 649
+t0:=(-1+x^2)^3*sqrt(-1+1/x^2)/x
+--R 
+--R
+--R                             +--------+
+--R                             |   2
+--R          6     4     2      |- x  + 1
+--R        (x  - 3x  + 3x  - 1) |--------
+--R                             |    2
+--R                            \|   x
+--R   (1)  -------------------------------
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 180
+
+--S 181 of 649
+r0:=-35/48*(-1+1/x^2)^(3/2)*x^2-7/24*(-1+1/x^2)^(5/2)*x^4-_
+   1/6*(-1+1/x^2)^(7/2)*x^6-35/16*atan(sqrt(-1+1/x^2))+35/16*sqrt(-1+1/x^2)
+--R 
+--R
+--R                   +--------+                             +--------+
+--R                   |   2                                  |   2
+--R                   |- x  + 1        6      4      2       |- x  + 1
+--R        - 105atan( |-------- ) + (8x  - 38x  + 87x  + 48) |--------
+--R                   |    2                                 |    2
+--R                  \|   x                                 \|   x
+--R   (2)  ------------------------------------------------------------
+--R                                     48
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                 +--------+
+--R                  7        5         3           |   2             7         5
+--R           (- 210x  + 5040x  - 16800x  + 13440x)\|- x  + 1  + 1470x  - 11760x
+--R         + 
+--R                 3
+--R           23520x  - 13440x
+--R      *
+--R               +--------+
+--R               |   2
+--R              \|- x  + 1  - 1
+--R         atan(---------------)
+--R                     x
+--R     + 
+--R                                                                    +--------+
+--R             12       10        8        6        4       2         |   2
+--R       (- 56x   + 714x   - 3633x  + 9304x  - 9488x  + 192x  + 3072)\|- x  + 1
+--R     + 
+--R           14       12        10        8         6        4        2
+--R       - 8x   + 238x   - 1869x   + 7231x  - 13832x  + 9968x  + 1344x  - 3072
+--R  /
+--R                                        +--------+
+--R           7        5        3          |   2            7        5        3
+--R       (48x  - 1152x  + 3840x  - 3072x)\|- x  + 1  - 336x  + 2688x  - 5376x
+--R     + 
+--R       3072x
+--R                                         Type: Union(Expression(Integer),...)
+--E 182
+
+--S 183 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +--------+
+--R                7        5        3          |   2            7        5
+--R           (105x  - 2520x  + 8400x  - 6720x)\|- x  + 1  - 735x  + 5880x
+--R         + 
+--R                   3
+--R           - 11760x  + 6720x
+--R      *
+--R               +--------+
+--R               |   2
+--R               |- x  + 1
+--R         atan( |-------- )
+--R               |    2
+--R              \|   x
+--R     + 
+--R                                                 +--------+
+--R                  7        5         3           |   2             7         5
+--R           (- 210x  + 5040x  - 16800x  + 13440x)\|- x  + 1  + 1470x  - 11760x
+--R         + 
+--R                 3
+--R           23520x  - 13440x
+--R      *
+--R               +--------+
+--R               |   2
+--R              \|- x  + 1  - 1
+--R         atan(---------------)
+--R                     x
+--R     + 
+--R                  13       11        9        7        5        3
+--R             (- 8x   + 230x   - 1639x  + 5592x  - 8240x  + 1728x  + 3072x)
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|- x  + 1
+--R         + 
+--R              13       11        9        7        5       3
+--R           56x   - 714x   + 3633x  - 9304x  + 9488x  - 192x  - 3072x
+--R      *
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R          |--------
+--R          |    2
+--R         \|   x
+--R     + 
+--R                                                                    +--------+
+--R             12       10        8        6        4       2         |   2
+--R       (- 56x   + 714x   - 3633x  + 9304x  - 9488x  + 192x  + 3072)\|- x  + 1
+--R     + 
+--R           14       12        10        8         6        4        2
+--R       - 8x   + 238x   - 1869x   + 7231x  - 13832x  + 9968x  + 1344x  - 3072
+--R  /
+--R                                        +--------+
+--R           7        5        3          |   2            7        5        3
+--R       (48x  - 1152x  + 3840x  - 3072x)\|- x  + 1  - 336x  + 2688x  - 5376x
+--R     + 
+--R       3072x
+--R                                                    Type: Expression(Integer)
+--E 183
+
+--S 184 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    21       19        17         15          13          11
+--R               - 14x   + 504x   - 5908x   + 34232x   - 115598x   + 245952x
+--R             + 
+--R                        9          7          5         3
+--R               - 340928x  + 308224x  - 175616x  + 57344x  - 8192x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|- x  + 1
+--R         + 
+--R              23       21        19         17         15          13
+--R           - x   + 102x   - 1966x   + 16272x   - 74313x   + 209762x
+--R         + 
+--R                    11          9          7          5         3
+--R           - 386848x   + 476352x  - 389376x  + 203264x  - 61440x  + 8192x
+--R      *
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R          |--------
+--R          |    2
+--R         \|   x
+--R     + 
+--R            22       20        18         16         14          12          10
+--R           x   - 102x   + 1966x   - 16272x   + 74313x   - 209762x   + 386848x
+--R         + 
+--R                    8          6          4         2
+--R           - 476352x  + 389376x  - 203264x  + 61440x  - 8192
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|- x  + 1
+--R     + 
+--R            22       20        18         16          14          12          10
+--R       - 14x   + 518x   - 6412x   + 40140x   - 149830x   + 361550x   - 586880x
+--R     + 
+--R              8          6          4         2
+--R       649152x  - 483840x  + 232960x  - 65536x  + 8192
+--R  /
+--R              17      15        13        11         9         7         5
+--R             x   - 98x   + 1568x   - 9408x   + 26880x  - 39424x  + 28672x
+--R           + 
+--R                    3
+--R             - 8192x
+--R        *
+--R            +--------+
+--R            |   2
+--R           \|- x  + 1
+--R       + 
+--R              17       15        13         11         9         7         5
+--R         - 14x   + 462x   - 4480x   + 19392x   - 43520x  + 52736x  - 32768x
+--R       + 
+--R              3
+--R         8192x
+--R    *
+--R        +--------+
+--R        |   2
+--R        |- x  + 1
+--R        |--------
+--R        |    2
+--R       \|   x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+)clear all
+
+--S 185 of 649
+t0:=(-1+x^2)^2*sqrt(-1+1/x^2)/x
+--R 
+--R
+--R                       +--------+
+--R                       |   2
+--R          4     2      |- x  + 1
+--R        (x  - 2x  + 1) |--------
+--R                       |    2
+--R                      \|   x
+--R   (1)  -------------------------
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 649
+r0:=5/8*(-1+1/x^2)^(3/2)*x^2+1/4*(-1+1/x^2)^(5/2)*x^4+_
+   15/8*atan(sqrt(-1+1/x^2))-15/8*sqrt(-1+1/x^2)
+--R 
+--R
+--R                +--------+                    +--------+
+--R                |   2                         |   2
+--R                |- x  + 1        4     2      |- x  + 1
+--R        15atan( |-------- ) + (2x  - 9x  - 8) |--------
+--R                |    2                        |    2
+--R               \|   x                        \|   x
+--R   (2)  ------------------------------------------------
+--R                                8
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                +--------+
+--R              5       3         |   2            5       3
+--R         ((30x  - 360x  + 480x)\|- x  + 1  - 150x  + 600x  - 480x)
+--R      *
+--R               +--------+
+--R               |   2
+--R              \|- x  + 1  - 1
+--R         atan(---------------)
+--R                     x
+--R     + 
+--R                                            +--------+
+--R             8      6       4      2        |   2          10      8       6
+--R       (- 10x  + 85x  - 172x  - 16x  + 128)\|- x  + 1  - 2x   + 35x  - 165x
+--R     + 
+--R           4      2
+--R       180x  + 80x  - 128
+--R  /
+--R                         +--------+
+--R        5      3         |   2           5       3
+--R     (8x  - 96x  + 128x)\|- x  + 1  - 40x  + 160x  - 128x
+--R                                         Type: Union(Expression(Integer),...)
+--E 187
+
+--S 188 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  +--------+
+--R                5       3         |   2           5       3
+--R         ((- 15x  + 180x  - 240x)\|- x  + 1  + 75x  - 300x  + 240x)
+--R      *
+--R               +--------+
+--R               |   2
+--R               |- x  + 1
+--R         atan( |-------- )
+--R               |    2
+--R              \|   x
+--R     + 
+--R                                +--------+
+--R              5       3         |   2            5       3
+--R         ((30x  - 360x  + 480x)\|- x  + 1  - 150x  + 600x  - 480x)
+--R      *
+--R               +--------+
+--R               |   2
+--R              \|- x  + 1  - 1
+--R         atan(---------------)
+--R                     x
+--R     + 
+--R                                                +--------+
+--R                9      7       5      3         |   2           9      7       5
+--R           (- 2x  + 33x  - 132x  + 48x  + 128x)\|- x  + 1  + 10x  - 85x  + 172x
+--R         + 
+--R              3
+--R           16x  - 128x
+--R      *
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R          |--------
+--R          |    2
+--R         \|   x
+--R     + 
+--R                                            +--------+
+--R             8      6       4      2        |   2          10      8       6
+--R       (- 10x  + 85x  - 172x  - 16x  + 128)\|- x  + 1  - 2x   + 35x  - 165x
+--R     + 
+--R           4      2
+--R       180x  + 80x  - 128
+--R  /
+--R                         +--------+
+--R        5      3         |   2           5       3
+--R     (8x  - 96x  + 128x)\|- x  + 1  - 40x  + 160x  - 128x
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                    15       13        11        9        7        5        3
+--R               - 10x   + 190x   - 1182x   + 3530x  - 5760x  + 5280x  - 2560x
+--R             + 
+--R               512x
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|- x  + 1
+--R         + 
+--R              17      15       13        11        9        7        5        3
+--R           - x   + 53x   - 553x   + 2471x   - 5890x  + 8112x  - 6496x  + 2816x
+--R         + 
+--R           - 512x
+--R      *
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R          |--------
+--R          |    2
+--R         \|   x
+--R     + 
+--R            16      14       12        10        8        6        4        2
+--R           x   - 53x   + 553x   - 2471x   + 5890x  - 8112x  + 6496x  - 2816x
+--R         + 
+--R           512
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|- x  + 1
+--R     + 
+--R            16       14        12        10        8         6        4        2
+--R       - 10x   + 200x   - 1372x   + 4712x   - 9290x  + 11040x  - 7840x  + 3072x
+--R     + 
+--R       - 512
+--R  /
+--R                                                         +--------+
+--R           13      11       9        7        5       3  |   2           13
+--R         (x   - 50x   + 400x  - 1120x  + 1280x  - 512x )\|- x  + 1  - 10x
+--R       + 
+--R             11       9        7        5       3
+--R         170x   - 832x  + 1696x  - 1536x  + 512x
+--R    *
+--R        +--------+
+--R        |   2
+--R        |- x  + 1
+--R        |--------
+--R        |    2
+--R       \|   x
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 649
+t0:=(-1+x^2)*sqrt(-1+1/x^2)/x
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R          2      |- x  + 1
+--R        (x  - 1) |--------
+--R                 |    2
+--R                \|   x
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 649
+r0:=-1/2*(-1+1/x^2)^(3/2)*x^2-3/2*atan(sqrt(-1+1/x^2))+3/2*sqrt(-1+1/x^2)
+--R 
+--R
+--R                 +--------+             +--------+
+--R                 |   2                  |   2
+--R                 |- x  + 1       2      |- x  + 1
+--R        - 3atan( |-------- ) + (x  + 2) |--------
+--R                 |    2                 |    2
+--R                \|   x                 \|   x
+--R   (2)  ------------------------------------------
+--R                             2
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                    +--------+
+--R                      +--------+                    |   2
+--R             3        |   2           3            \|- x  + 1  - 1
+--R       ((- 6x  + 24x)\|- x  + 1  + 18x  - 24x)atan(---------------)
+--R                                                          x
+--R     + 
+--R                         +--------+
+--R            4     2      |   2         6     4     2
+--R       (- 3x  - 2x  + 8)\|- x  + 1  - x  + 3x  + 6x  - 8
+--R  /
+--R                +--------+
+--R        3       |   2          3
+--R     (2x  - 8x)\|- x  + 1  - 6x  + 8x
+--R                                         Type: Union(Expression(Integer),...)
+--E 192
+
+--S 193 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +--------+
+--R                    +--------+                   |   2
+--R           3        |   2          3             |- x  + 1
+--R       ((3x  - 12x)\|- x  + 1  - 9x  + 12x)atan( |-------- )
+--R                                                 |    2
+--R                                                \|   x
+--R     + 
+--R                                                    +--------+
+--R                      +--------+                    |   2
+--R             3        |   2           3            \|- x  + 1  - 1
+--R       ((- 6x  + 24x)\|- x  + 1  + 18x  - 24x)atan(---------------)
+--R                                                          x
+--R     + 
+--R                                                       +--------+
+--R                          +--------+                   |   2
+--R            5     3       |   2          5     3       |- x  + 1
+--R       ((- x  + 2x  + 8x)\|- x  + 1  + 3x  + 2x  - 8x) |--------
+--R                                                       |    2
+--R                                                      \|   x
+--R     + 
+--R                         +--------+
+--R            4     2      |   2         6     4     2
+--R       (- 3x  - 2x  + 8)\|- x  + 1  - x  + 3x  + 6x  - 8
+--R  /
+--R                +--------+
+--R        3       |   2          3
+--R     (2x  - 8x)\|- x  + 1  - 6x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                               +--------+
+--R                9      7       5      3        |   2         11      9      7
+--R           (- 6x  + 44x  - 102x  + 96x  - 32x)\|- x  + 1  - x   + 20x  - 85x
+--R         + 
+--R               5       3
+--R           146x  - 112x  + 32x
+--R      *
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R          |--------
+--R          |    2
+--R         \|   x
+--R     + 
+--R                                                +--------+
+--R         10      8      6       4       2       |   2          10      8       6
+--R       (x   - 20x  + 85x  - 146x  + 112x  - 32)\|- x  + 1  - 6x   + 50x  - 146x
+--R     + 
+--R           4       2
+--R       198x  - 128x  + 32
+--R  /
+--R                                  +--------+
+--R          9      7      5      3  |   2          9      7      5      3
+--R       ((x  - 18x  + 48x  - 32x )\|- x  + 1  - 6x  + 38x  - 64x  + 32x )
+--R    *
+--R        +--------+
+--R        |   2
+--R        |- x  + 1
+--R        |--------
+--R        |    2
+--R       \|   x
+--R                                                    Type: Expression(Integer)
+--E 194
+
+)clear all
+
+--S 195 of 649
+t0:=sqrt(-1+1/x^2)/(x*(-1+x^2))
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R         |- x  + 1
+--R         |--------
+--R         |    2
+--R        \|   x
+--R   (1)  -----------
+--R            3
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 195
+
+--S 196 of 649
+r0:=sqrt(-1+1/x^2)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R         |- x  + 1
+--R   (2)   |--------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R           +--------+
+--R           |   2         2
+--R        - \|- x  + 1  - x  + 1
+--R   (3)  ----------------------
+--R             +--------+
+--R             |   2
+--R           x\|- x  + 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 197
+
+--S 198 of 649
+m0:=a0-r0
+--R 
+--R
+--R                             +--------+
+--R             +--------+      |   2         +--------+
+--R             |   2           |- x  + 1     |   2         2
+--R        (- x\|- x  + 1  + x) |--------  - \|- x  + 1  - x  + 1
+--R                             |    2
+--R                            \|   x
+--R   (4)  ------------------------------------------------------
+--R                             +--------+
+--R                             |   2
+--R                           x\|- x  + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 198
+
+--S 199 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R                                    +--------+
+--R              +--------+            |   2                 +--------+
+--R              |   2         3       |- x  + 1      2      |   2          2
+--R        (- 2x\|- x  + 1  - x  + 2x) |--------  + (x  - 2)\|- x  + 1  - 2x  + 2
+--R                                    |    2
+--R                                   \|   x
+--R   (5)  ----------------------------------------------------------------------
+--R                                                        +--------+
+--R                                +--------+              |   2
+--R                       5     3  |   2          5     3  |- x  + 1
+--R                    ((x  - 2x )\|- x  + 1  - 2x  + 2x ) |--------
+--R                                                        |    2
+--R                                                       \|   x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+)clear all
+
+--S 200 of 649
+t0:=sqrt(-1+1/x^2)/(x*(-1+x^2)^2)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R          |--------
+--R          |    2
+--R         \|   x
+--R   (1)  ------------
+--R         5     3
+--R        x  - 2x  + x
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 649
+r0:=1/sqrt(-1+1/x^2)-sqrt(-1+1/x^2)
+--R 
+--R
+--R             2
+--R           2x  - 1
+--R   (2)  -------------
+--R           +--------+
+--R           |   2
+--R         2 |- x  + 1
+--R        x  |--------
+--R           |    2
+--R          \|   x
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +--------+
+--R           2      |   2          4     2
+--R        (4x  - 2)\|- x  + 1  + 2x  - 5x  + 2
+--R   (3)  ------------------------------------
+--R                     +--------+
+--R             3       |   2          3
+--R           (x  - 2x)\|- x  + 1  - 2x  + 2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 202
+
+--S 203 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                +--------+
+--R                   +--------+                   |   2
+--R           3       |   2          5     3       |- x  + 1
+--R       ((4x  - 2x)\|- x  + 1  + 2x  - 5x  + 2x) |--------
+--R                                                |    2
+--R                                               \|   x
+--R     + 
+--R                         +--------+
+--R            4     2      |   2          4     2
+--R       (- 2x  + 5x  - 2)\|- x  + 1  + 4x  - 6x  + 2
+--R  /
+--R                                         +--------+
+--R                 +--------+              |   2
+--R        4     2  |   2          4     2  |- x  + 1
+--R     ((x  - 2x )\|- x  + 1  - 2x  + 2x ) |--------
+--R                                         |    2
+--R                                        \|   x
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                 +--------+
+--R                     +--------+                  |   2
+--R             3       |   2         5     3       |- x  + 1
+--R       ((- 4x  + 8x)\|- x  + 1  - x  + 8x  - 8x) |--------
+--R                                                 |    2
+--R                                                \|   x
+--R     + 
+--R                      +--------+
+--R         4     2      |   2          4      2
+--R       (x  - 8x  + 8)\|- x  + 1  - 4x  + 12x  - 8
+--R  /
+--R                                                                    +--------+
+--R                              +--------+                            |   2
+--R        9     7      5     3  |   2          9      7      5     3  |- x  + 1
+--R     ((x  - 9x  + 16x  - 8x )\|- x  + 1  - 4x  + 16x  - 20x  + 8x ) |--------
+--R                                                                    |    2
+--R                                                                   \|   x
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 649
+t0:=sqrt(-1+1/x^2)/(x*(-1+x^2)^3)
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R             |- x  + 1
+--R             |--------
+--R             |    2
+--R            \|   x
+--R   (1)  ------------------
+--R         7     5     3
+--R        x  - 3x  + 3x  - x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 649
+r0:=(-1/3)/(-1+1/x^2)^(3/2)+(-2)/sqrt(-1+1/x^2)+sqrt(-1+1/x^2)
+--R 
+--R
+--R               4      2
+--R           - 8x  + 12x  - 3
+--R   (2)  ----------------------
+--R                    +--------+
+--R                    |   2
+--R           4     2  |- x  + 1
+--R        (3x  - 3x ) |--------
+--R                    |    2
+--R                   \|   x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 +--------+
+--R         6       4       2       |   2          8      6       4       2
+--R   (- 32x  + 112x  - 108x  + 24)\|- x  + 1  - 8x  + 76x  - 163x  + 120x  - 24
+--R   --------------------------------------------------------------------------
+--R                                   +--------+
+--R            7      5      3        |   2           7      5      3
+--R         (3x  - 27x  + 48x  - 24x)\|- x  + 1  - 12x  + 48x  - 60x  + 24x
+--R                                         Type: Union(Expression(Integer),...)
+--E 207
+
+--S 208 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                          +--------+
+--R                 7       5       3        |   2          9      7       5
+--R           (- 32x  + 112x  - 108x  + 24x)\|- x  + 1  - 8x  + 76x  - 163x
+--R         + 
+--R               3
+--R           120x  - 24x
+--R      *
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R          |--------
+--R          |    2
+--R         \|   x
+--R     + 
+--R                                         +--------+
+--R          8      6       4       2       |   2           8       6       4
+--R       (8x  - 76x  + 163x  - 120x  + 24)\|- x  + 1  - 32x  + 144x  - 220x
+--R     + 
+--R           2
+--R       132x  - 24
+--R  /
+--R                                   +--------+
+--R           8      6      4      2  |   2           8      6      4      2
+--R       ((3x  - 27x  + 48x  - 24x )\|- x  + 1  - 12x  + 48x  - 60x  + 24x )
+--R    *
+--R        +--------+
+--R        |   2
+--R        |- x  + 1
+--R        |--------
+--R        |    2
+--R       \|   x
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                         +--------+
+--R                7      5       3         |   2         9      7       5       3
+--R           (- 8x  + 80x  - 192x  + 128x)\|- x  + 1  - x  + 32x  - 160x  + 256x
+--R         + 
+--R           - 128x
+--R      *
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R          |--------
+--R          |    2
+--R         \|   x
+--R     + 
+--R                                         +--------+
+--R         8      6       4       2        |   2          8      6       4       2
+--R       (x  - 32x  + 160x  - 256x  + 128)\|- x  + 1  - 8x  + 88x  - 272x  + 320x
+--R     + 
+--R       - 128
+--R  /
+--R                                                                +--------+
+--R           15      13       11       9       7       5       3  |   2
+--R         (x   - 34x   + 225x   - 608x  + 800x  - 512x  + 128x )\|- x  + 1
+--R       + 
+--R             15       13       11       9        7       5       3
+--R         - 8x   + 104x   - 456x   + 952x  - 1040x  + 576x  - 128x
+--R    *
+--R        +--------+
+--R        |   2
+--R        |- x  + 1
+--R        |--------
+--R        |    2
+--R       \|   x
+--R                                                    Type: Expression(Integer)
+--E 209
+
+)clear all
+
+--S 210 of 649
+t0:=x*sqrt(1+1/x^2)/(1+x^2)^2
+--R 
+--R
+--R           +------+
+--R           | 2
+--R           |x  + 1
+--R         x |------
+--R           |   2
+--R          \|  x
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                                    Type: Expression(Integer)
+--E 210
+
+--S 211 of 649
+r0:=1/sqrt(1+1/x^2)
+--R 
+--R
+--R            1
+--R   (2)  ---------
+--R         +------+
+--R         | 2
+--R         |x  + 1
+--R         |------
+--R         |   2
+--R        \|  x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   1
+--R   (3)  - -------------------
+--R            +------+
+--R            | 2         2
+--R          x\|x  + 1  - x  - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 212
+
+--S 213 of 649
+m0:=a0-r0
+--R 
+--R
+--R                            +------+
+--R                +------+    | 2
+--R                | 2         |x  + 1     2
+--R            - x\|x  + 1  -  |------  + x  + 1
+--R                            |   2
+--R                           \|  x
+--R   (4)  -----------------------------------------
+--R          +------+                       +------+
+--R          | 2      +------+              | 2
+--R          |x  + 1  | 2            2      |x  + 1
+--R        x |------ \|x  + 1  + (- x  - 1) |------
+--R          |   2                          |   2
+--R         \|  x                          \|  x
+--R                                                    Type: Expression(Integer)
+--E 213
+
+--S 214 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R               +------+                                 +------+
+--R               | 2                 +------+             | 2
+--R             2 |x  + 1      2      | 2           3      |x  + 1      3
+--R        (- 2x  |------  - 2x  - 1)\|x  + 1  + (2x  + x) |------  + 2x  + 2x
+--R               |   2                                    |   2
+--R              \|  x                                    \|  x
+--R   (5)  -------------------------------------------------------------------
+--R                          +------+                                +------+
+--R                          | 2      +------+                       | 2
+--R             5     3      |x  + 1  | 2             6     4     2  |x  + 1
+--R          (2x  + 3x  + x) |------ \|x  + 1  + (- 2x  - 4x  - 2x ) |------
+--R                          |   2                                   |   2
+--R                         \|  x                                   \|  x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+)clear all
+
+--S 215 of 649
+t0:=1/(x*(1+x^2)*sqrt(1+1/x^2))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R                 +------+
+--R                 | 2
+--R          3      |x  + 1
+--R        (x  + x) |------
+--R                 |   2
+--R                \|  x
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 649
+r0:=1/sqrt(1+1/x^2)
+--R 
+--R
+--R            1
+--R   (2)  ---------
+--R         +------+
+--R         | 2
+--R         |x  + 1
+--R         |------
+--R         |   2
+--R        \|  x
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   1
+--R   (3)  - -------------------
+--R            +------+
+--R            | 2         2
+--R          x\|x  + 1  - x  - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 217
+
+--S 218 of 649
+m0:=a0-r0
+--R 
+--R
+--R                            +------+
+--R                +------+    | 2
+--R                | 2         |x  + 1     2
+--R            - x\|x  + 1  -  |------  + x  + 1
+--R                            |   2
+--R                           \|  x
+--R   (4)  -----------------------------------------
+--R          +------+                       +------+
+--R          | 2      +------+              | 2
+--R          |x  + 1  | 2            2      |x  + 1
+--R        x |------ \|x  + 1  + (- x  - 1) |------
+--R          |   2                          |   2
+--R         \|  x                          \|  x
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R               +------+                                 +------+
+--R               | 2                 +------+             | 2
+--R             2 |x  + 1      2      | 2           3      |x  + 1      3
+--R        (- 2x  |------  - 2x  - 1)\|x  + 1  + (2x  + x) |------  + 2x  + 2x
+--R               |   2                                    |   2
+--R              \|  x                                    \|  x
+--R   (5)  -------------------------------------------------------------------
+--R                          +------+                                +------+
+--R                          | 2      +------+                       | 2
+--R             5     3      |x  + 1  | 2             6     4     2  |x  + 1
+--R          (2x  + 3x  + x) |------ \|x  + 1  + (- 2x  - 4x  - 2x ) |------
+--R                          |   2                                   |   2
+--R                         \|  x                                   \|  x
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 649
+t0:=x/(a+b*x^2+sqrt(a+b*x^2))
+--R 
+--R
+--R                   x
+--R   (1)  ----------------------
+--R         +--------+
+--R         |   2           2
+--R        \|b x  + a  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 649
+r0:=log(1+sqrt(a+b*x^2))/b
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R        log(\|b x  + a  + 1)
+--R   (2)  --------------------
+--R                  b
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +--------+
+--R                     |   2            2          +-+      2
+--R           (- a + 1)\|b x  + a  + (b x  + a - 1)\|a  + b x
+--R       log(------------------------------------------------)
+--R                                   2
+--R                                  x
+--R     + 
+--R                     +--------+
+--R                     |   2            2          +-+      2
+--R           (- a + 1)\|b x  + a  + (b x  + a - 1)\|a  - b x            2
+--R     - log(------------------------------------------------) + log(b x  + a - 1)
+--R                                   2
+--R                                  x
+--R  /
+--R     2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 222
+
+--S 223 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +--------+
+--R               |   2
+--R       - 2log(\|b x  + a  + 1)
+--R     + 
+--R                     +--------+
+--R                     |   2            2          +-+      2
+--R           (- a + 1)\|b x  + a  + (b x  + a - 1)\|a  + b x
+--R       log(------------------------------------------------)
+--R                                   2
+--R                                  x
+--R     + 
+--R                     +--------+
+--R                     |   2            2          +-+      2
+--R           (- a + 1)\|b x  + a  + (b x  + a - 1)\|a  - b x            2
+--R     - log(------------------------------------------------) + log(b x  + a - 1)
+--R                                   2
+--R                                  x
+--R  /
+--R     2b
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 224
+
+)clear all
+
+--S 225 of 649
+t0:=x/(x^2-(x^2)^(1/3))
+--R 
+--R
+--R               x
+--R   (1)  - ----------
+--R           +--+
+--R          3| 2     2
+--R          \|x   - x
+--R                                                    Type: Expression(Integer)
+--E 225
+
+--S 226 of 649
+r0:=3/4*log(1-(x^2)^(2/3))
+--R 
+--R
+--R                +--+2
+--R               3| 2
+--R        3log(- \|x    + 1)
+--R   (2)  ------------------
+--R                 4
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +--+2
+--R             3| 2
+--R        3log(\|x    - 1)
+--R   (3)  ----------------
+--R                4
+--R                                         Type: Union(Expression(Integer),...)
+--E 227
+
+--S 228 of 649
+m0:=a0-r0
+--R 
+--R
+--R              +--+2                +--+2
+--R             3| 2                 3| 2
+--R        3log(\|x    - 1) - 3log(- \|x    + 1)
+--R   (4)  -------------------------------------
+--R                          4
+--R                                                    Type: Expression(Integer)
+--E 228
+
+--S 229 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 229
+
+)clear all
+
+--S 230 of 649
+t0:=x*(1+x^2)^3*sqrt(2+2*x^2+x^4)
+--R 
+--R
+--R                             +------------+
+--R          7     5     3      | 4     2
+--R   (1)  (x  + 3x  + 3x  + x)\|x  + 2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 649
+r0:=-1/15*(2+2*x^2+x^4)^(3/2)+1/10*(1+x^2)^2*(2+2*x^2+x^4)^(3/2)
+--R 
+--R
+--R                                       +------------+
+--R           8      6      4      2      | 4     2
+--R        (3x  + 12x  + 19x  + 14x  + 2)\|x  + 2x  + 2
+--R   (2)  ---------------------------------------------
+--R                              30
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                       +------------+
+--R           8      6      4      2      | 4     2
+--R        (3x  + 12x  + 19x  + 14x  + 2)\|x  + 2x  + 2
+--R   (3)  ---------------------------------------------
+--R                              30
+--R                                         Type: Union(Expression(Integer),...)
+--E 232
+
+--S 233 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 649
+t0:=x*sqrt((1-x^2)/(1+x^2))
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R   (1)  x |--------
+--R          |  2
+--R         \| x  + 1
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 649
+r0a:=-atan(sqrt((1-x^2)/(1+x^2)))+1/2*(1+x^2)*sqrt((1-x^2)/(1+x^2))
+--R 
+--R
+--R                 +--------+             +--------+
+--R                 |   2                  |   2
+--R                 |- x  + 1       2      |- x  + 1
+--R        - 2atan( |-------- ) + (x  + 1) |--------
+--R                 |  2                   |  2
+--R                \| x  + 1              \| x  + 1
+--R   (2)  ------------------------------------------
+--R                             2
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 649
+r0b:=-atan(sqrt((1-x^2)/(1+x^2)))+sqrt((1-x^2)/(1+x^2))/(1+(1-x^2)/(1+x^2))
+--R 
+--R
+--R                 +--------+             +--------+
+--R                 |   2                  |   2
+--R                 |- x  + 1       2      |- x  + 1
+--R        - 2atan( |-------- ) + (x  + 1) |--------
+--R                 |  2                   |  2
+--R                \| x  + 1              \| x  + 1
+--R   (3)  ------------------------------------------
+--R                             2
+--R                                                    Type: Expression(Integer)
+--E 237
+
+--S 238 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                  +--------+
+--R                                                  |   2
+--R                                           2      |- x  + 1
+--R                     +--------+          (x  + 1) |--------  - 1
+--R                     |   2                        |  2
+--R              2      |- x  + 1                   \| x  + 1           4
+--R        ((- 2x  - 2) |--------  + 2)atan(-----------------------) - x
+--R                     |  2                            2
+--R                    \| x  + 1                       x
+--R   (4)  --------------------------------------------------------------
+--R                                     +--------+
+--R                                     |   2
+--R                              2      |- x  + 1
+--R                           (2x  + 2) |--------  - 2
+--R                                     |  2
+--R                                    \| x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 238
+
+--S 239 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R                         +--------+
+--R                         |   2
+--R                  2      |- x  + 1
+--R                (x  + 1) |--------  - 1           +--------+
+--R                         |  2                     |   2
+--R                        \| x  + 1                 |- x  + 1
+--R        - 2atan(-----------------------) + 2atan( |-------- ) + 1
+--R                            2                     |  2
+--R                           x                     \| x  + 1
+--R   (5)  ---------------------------------------------------------
+--R                                    2
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+--S 241 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R                         +--------+
+--R                         |   2
+--R                  2      |- x  + 1
+--R                (x  + 1) |--------  - 1           +--------+
+--R                         |  2                     |   2
+--R                        \| x  + 1                 |- x  + 1
+--R        - 2atan(-----------------------) + 2atan( |-------- ) + 1
+--R                            2                     |  2
+--R                           x                     \| x  + 1
+--R   (7)  ---------------------------------------------------------
+--R                                    2
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 242
+
+)clear all
+
+--S 243 of 649
+t0:=x*sqrt((5-7*x^2)/(7+5*x^2))
+--R 
+--R
+--R          +---------+
+--R          |    2
+--R          |- 7x  + 5
+--R   (1)  x |---------
+--R          |   2
+--R         \| 5x  + 7
+--R                                                    Type: Expression(Integer)
+--E 243
+
+--S 244 of 649
+r0a:=-37/5*atan(sqrt(5/7)*sqrt((5-7*x^2)/(7+5*x^2)))/sqrt(35)+_
+   1/10*(7+5*x^2)*sqrt((5-7*x^2)/(7+5*x^2))
+--R 
+--R
+--R                      +---------+
+--R                      |    2
+--R                  +-+ |- 7x  + 5
+--R                 \|5  |---------                    +---------+
+--R                      |   2                         |    2
+--R                     \| 5x  + 7         2      +--+ |- 7x  + 5
+--R        - 74atan(----------------) + (5x  + 7)\|35  |---------
+--R                        +-+                         |   2
+--R                       \|7                         \| 5x  + 7
+--R   (2)  -------------------------------------------------------
+--R                                   +--+
+--R                                10\|35
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 649
+r0b:=-37/5*atan(sqrt(5/7)*sqrt((5-7*x^2)/(7+5*x^2)))/sqrt(35)+_
+   37/5*sqrt((5-7*x^2)/(7+5*x^2))/(7+5*(5-7*x^2)/(7+5*x^2))
+--R 
+--R
+--R                      +---------+
+--R                      |    2
+--R                  +-+ |- 7x  + 5
+--R                 \|5  |---------                    +---------+
+--R                      |   2                         |    2
+--R                     \| 5x  + 7         2      +--+ |- 7x  + 5
+--R        - 74atan(----------------) + (5x  + 7)\|35  |---------
+--R                        +-+                         |   2
+--R                       \|7                         \| 5x  + 7
+--R   (3)  -------------------------------------------------------
+--R                                   +--+
+--R                                10\|35
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R                               +---------+
+--R                               |    2
+--R                 2        +--+ |- 7x  + 5        2
+--R         ((- 370x  - 518)\|35  |---------  - 888x  + 2590)
+--R                               |   2
+--R                              \| 5x  + 7
+--R      *
+--R                             +---------+
+--R                             |    2
+--R                 2      +--+ |- 7x  + 5
+--R              (5x  + 7)\|35  |---------  - 35
+--R                             |   2
+--R                            \| 5x  + 7
+--R         atan(-------------------------------)
+--R                               2
+--R                            35x
+--R     + 
+--R                          +---------+
+--R                          |    2
+--R           4      2  +--+ |- 7x  + 5         4       2
+--R       (60x  + 84x )\|35  |---------  - 1225x  - 420x
+--R                          |   2
+--R                         \| 5x  + 7
+--R  /
+--R                     +---------+
+--R                     |    2
+--R           2         |- 7x  + 5         2        +--+
+--R     (1750x  + 2450) |---------  + (120x  - 350)\|35
+--R                     |   2
+--R                    \| 5x  + 7
+--R                                         Type: Union(Expression(Integer),...)
+--E 246
+
+--S 247 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R                              +---------+
+--R                              |    2
+--R                   2          |- 7x  + 5           2         +--+
+--R         ((- 12950x  - 18130) |---------  + (- 888x  + 2590)\|35 )
+--R                              |   2
+--R                             \| 5x  + 7
+--R      *
+--R                             +---------+
+--R                             |    2
+--R                 2      +--+ |- 7x  + 5
+--R              (5x  + 7)\|35  |---------  - 35
+--R                             |   2
+--R                            \| 5x  + 7
+--R         atan(-------------------------------)
+--R                               2
+--R                            35x
+--R     + 
+--R                            +---------+
+--R                            |    2
+--R                 2          |- 7x  + 5         2         +--+
+--R         ((12950x  + 18130) |---------  + (888x  - 2590)\|35 )
+--R                            |   2
+--R                           \| 5x  + 7
+--R      *
+--R                   +---------+
+--R                   |    2
+--R               +-+ |- 7x  + 5
+--R              \|5  |---------
+--R                   |   2
+--R                  \| 5x  + 7
+--R         atan(----------------)
+--R                     +-+
+--R                    \|7
+--R     + 
+--R                       +---------+
+--R                       |    2
+--R             2         |- 7x  + 5         2         +--+
+--R       (6125x  + 8575) |---------  + (420x  - 1225)\|35
+--R                       |   2
+--R                      \| 5x  + 7
+--R  /
+--R                          +---------+
+--R                          |    2
+--R           2         +--+ |- 7x  + 5         2
+--R     (1750x  + 2450)\|35  |---------  + 4200x  - 12250
+--R                          |   2
+--R                         \| 5x  + 7
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)
+--R                    7           5           3             +-+ +-+ +--+
+--R           (1567764x  - 3080805x  - 6526800x  + 6345500x)\|5 \|7 \|35
+--R         + 
+--R                      7             5             3
+--R           - 54871740x  + 107828175x  + 228438000x  - 222092500x
+--R      *
+--R          +---------+
+--R          |    2
+--R          |- 7x  + 5
+--R          |---------
+--R          |   2
+--R         \| 5x  + 7
+--R     + 
+--R                7            5            3              +--+
+--R       (7188545x  + 25323725x  - 66174500x  + 31727500x)\|35
+--R     + 
+--R                  7            5            3              +-+ +-+
+--R       (- 7188545x  - 25323725x  + 66174500x  - 31727500x)\|5 \|7
+--R  /
+--R                  8            6            4            2             +--+
+--R         (4857125x  + 23910600x  - 20757625x  - 41160000x  + 30012500)\|35
+--R      *
+--R          +---------+
+--R          |    2
+--R          |- 7x  + 5
+--R          |---------
+--R          |   2
+--R         \| 5x  + 7
+--R     + 
+--R                8             6             4             2
+--R       51905700x  - 139075125x  - 143233125x  + 364437500x  - 150062500
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R                              +---------+
+--R                              |    2
+--R                   2          |- 7x  + 5           2         +--+
+--R         ((- 12950x  - 18130) |---------  + (- 888x  + 2590)\|35 )
+--R                              |   2
+--R                             \| 5x  + 7
+--R      *
+--R                             +---------+
+--R                             |    2
+--R                 2      +--+ |- 7x  + 5
+--R              (5x  + 7)\|35  |---------  - 35
+--R                             |   2
+--R                            \| 5x  + 7
+--R         atan(-------------------------------)
+--R                               2
+--R                            35x
+--R     + 
+--R                            +---------+
+--R                            |    2
+--R                 2          |- 7x  + 5         2         +--+
+--R         ((12950x  + 18130) |---------  + (888x  - 2590)\|35 )
+--R                            |   2
+--R                           \| 5x  + 7
+--R      *
+--R                   +---------+
+--R                   |    2
+--R               +-+ |- 7x  + 5
+--R              \|5  |---------
+--R                   |   2
+--R                  \| 5x  + 7
+--R         atan(----------------)
+--R                     +-+
+--R                    \|7
+--R     + 
+--R                       +---------+
+--R                       |    2
+--R             2         |- 7x  + 5         2         +--+
+--R       (6125x  + 8575) |---------  + (420x  - 1225)\|35
+--R                       |   2
+--R                      \| 5x  + 7
+--R  /
+--R                          +---------+
+--R                          |    2
+--R           2         +--+ |- 7x  + 5         2
+--R     (1750x  + 2450)\|35  |---------  + 4200x  - 12250
+--R                          |   2
+--R                         \| 5x  + 7
+--R                                                    Type: Expression(Integer)
+--E 249
+
+--S 250 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)
+--R                    7           5           3             +-+ +-+ +--+
+--R           (1567764x  - 3080805x  - 6526800x  + 6345500x)\|5 \|7 \|35
+--R         + 
+--R                      7             5             3
+--R           - 54871740x  + 107828175x  + 228438000x  - 222092500x
+--R      *
+--R          +---------+
+--R          |    2
+--R          |- 7x  + 5
+--R          |---------
+--R          |   2
+--R         \| 5x  + 7
+--R     + 
+--R                7            5            3              +--+
+--R       (7188545x  + 25323725x  - 66174500x  + 31727500x)\|35
+--R     + 
+--R                  7            5            3              +-+ +-+
+--R       (- 7188545x  - 25323725x  + 66174500x  - 31727500x)\|5 \|7
+--R  /
+--R                  8            6            4            2             +--+
+--R         (4857125x  + 23910600x  - 20757625x  - 41160000x  + 30012500)\|35
+--R      *
+--R          +---------+
+--R          |    2
+--R          |- 7x  + 5
+--R          |---------
+--R          |   2
+--R         \| 5x  + 7
+--R     + 
+--R                8             6             4             2
+--R       51905700x  - 139075125x  - 143233125x  + 364437500x  - 150062500
+--R                                                    Type: Expression(Integer)
+--E 250
+
+)clear all
+
+--S 251 of 649
+t0:=x^2*sqrt((1-x^3)/(1+x^3))
+--R 
+--R
+--R           +--------+
+--R           |   3
+--R         2 |- x  + 1
+--R   (1)  x  |--------
+--R           |  3
+--R          \| x  + 1
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 649
+r0a:=-2/3*atan(sqrt((1-x^3)/(1+x^3)))+1/3*(1+x^3)*sqrt((1-x^3)/(1+x^3))
+--R 
+--R
+--R                 +--------+             +--------+
+--R                 |   3                  |   3
+--R                 |- x  + 1       3      |- x  + 1
+--R        - 2atan( |-------- ) + (x  + 1) |--------
+--R                 |  3                   |  3
+--R                \| x  + 1              \| x  + 1
+--R   (2)  ------------------------------------------
+--R                             3
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 649
+r0b:=-2/3*atan(sqrt((1-x^3)/(1+x^3)))+2/3*sqrt((1-x^3)/(1+x^3))/_
+   (1+(1-x^3)/(1+x^3))
+--R 
+--R
+--R                 +--------+             +--------+
+--R                 |   3                  |   3
+--R                 |- x  + 1       3      |- x  + 1
+--R        - 2atan( |-------- ) + (x  + 1) |--------
+--R                 |  3                   |  3
+--R                \| x  + 1              \| x  + 1
+--R   (3)  ------------------------------------------
+--R                             3
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                  +--------+
+--R                                                  |   3
+--R                                           3      |- x  + 1
+--R                     +--------+          (x  + 1) |--------  - 1
+--R                     |   3                        |  3
+--R              3      |- x  + 1                   \| x  + 1           6
+--R        ((- 2x  - 2) |--------  + 2)atan(-----------------------) - x
+--R                     |  3                            3
+--R                    \| x  + 1                       x
+--R   (4)  --------------------------------------------------------------
+--R                                     +--------+
+--R                                     |   3
+--R                              3      |- x  + 1
+--R                           (3x  + 3) |--------  - 3
+--R                                     |  3
+--R                                    \| x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 254
+
+--S 255 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R                         +--------+
+--R                         |   3
+--R                  3      |- x  + 1
+--R                (x  + 1) |--------  - 1           +--------+
+--R                         |  3                     |   3
+--R                        \| x  + 1                 |- x  + 1
+--R        - 2atan(-----------------------) + 2atan( |-------- ) + 1
+--R                            3                     |  3
+--R                           x                     \| x  + 1
+--R   (5)  ---------------------------------------------------------
+--R                                    3
+--R                                                    Type: Expression(Integer)
+--E 255
+
+--S 256 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R                         +--------+
+--R                         |   3
+--R                  3      |- x  + 1
+--R                (x  + 1) |--------  - 1           +--------+
+--R                         |  3                     |   3
+--R                        \| x  + 1                 |- x  + 1
+--R        - 2atan(-----------------------) + 2atan( |-------- ) + 1
+--R                            3                     |  3
+--R                           x                     \| x  + 1
+--R   (7)  ---------------------------------------------------------
+--R                                    3
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 649
+t0:=x^5*(1+x^9)^2*sqrt(1-x^3)
+--R 
+--R
+--R                          +--------+
+--R          23     14    5  |   3
+--R   (1)  (x   + 2x   + x )\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 649
+r0:=-8/9*(1-x^3)^(3/2)+32/15*(1-x^3)^(5/2)-22/7*(1-x^3)^(7/2)+_
+   86/27*(1-x^3)^(9/2)-74/33*(1-x^3)^(11/2)+14/13*(1-x^3)^(13/2)-_
+   14/45*(1-x^3)^(15/2)+2/51*(1-x^3)^(17/2)
+--R 
+--R
+--R   (2)
+--R               24        21        18          15         12         9
+--R         90090x   - 6006x   - 6468x   + 271404x   - 38780x   - 44320x
+--R       + 
+--R                6          3
+--R         253122x  - 173014x  - 346028
+--R    *
+--R        +--------+
+--R        |   3
+--R       \|- x  + 1
+--R  /
+--R     2297295
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               24        21        18          15         12         9
+--R         90090x   - 6006x   - 6468x   + 271404x   - 38780x   - 44320x
+--R       + 
+--R                6          3
+--R         253122x  - 173014x  - 346028
+--R    *
+--R        +--------+
+--R        |   3
+--R       \|- x  + 1
+--R  /
+--R     2297295
+--R                                         Type: Union(Expression(Integer),...)
+--E 261
+
+--S 262 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 263
+
+)clear all
+
+--S 264 of 649
+t0:=x^8*sqrt((1-x^3)/(1+x^3))
+--R 
+--R
+--R           +--------+
+--R           |   3
+--R         8 |- x  + 1
+--R   (1)  x  |--------
+--R           |  3
+--R          \| x  + 1
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 649
+r0:=-8/9*((1-x^3)/(1+x^3))^(3/2)/(1+(1-x^3)/(1+x^3))^3+2/3*((1-x^3)/_
+   (1+x^3))^(3/2)/(1+(1-x^3)/(1+x^3))^2-1/3*atan(sqrt((1-x^3)/(1+x^3)))+_
+   1/3*sqrt((1-x^3)/(1+x^3))/(1+(1-x^3)/(1+x^3))
+--R 
+--R
+--R                 +--------+                        +--------+
+--R                 |   3                             |   3
+--R                 |- x  + 1        9    6    3      |- x  + 1
+--R        - 6atan( |-------- ) + (2x  - x  + x  + 4) |--------
+--R                 |  3                              |  3
+--R                \| x  + 1                         \| x  + 1
+--R   (2)  -----------------------------------------------------
+--R                                  18
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                    +--------+
+--R                                    |   3
+--R               9     6      3       |- x  + 1       6
+--R         ((- 6x  - 6x  + 24x  + 24) |--------  + 18x  - 24)
+--R                                    |  3
+--R                                   \| x  + 1
+--R      *
+--R                       +--------+
+--R                       |   3
+--R                3      |- x  + 1
+--R              (x  + 1) |--------  - 1
+--R                       |  3
+--R                      \| x  + 1
+--R         atan(-----------------------)
+--R                          3
+--R                         x
+--R     + 
+--R                                           +--------+
+--R                                           |   3
+--R            15     12     9      6      3  |- x  + 1      18     15     12
+--R       (- 6x   + 3x   + 9x  - 12x  - 12x ) |--------  - 2x   + 3x   + 6x
+--R                                           |  3
+--R                                          \| x  + 1
+--R     + 
+--R            9      3
+--R       - 15x  + 12x
+--R  /
+--R                               +--------+
+--R                               |   3
+--R         9      6      3       |- x  + 1       6
+--R     (18x  + 18x  - 72x  - 72) |--------  - 54x  + 72
+--R                               |  3
+--R                              \| x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 266
+
+--S 267 of 649
+m0:=a0-r0
+--R 
+--R
+--R                         +--------+
+--R                         |   3
+--R                  3      |- x  + 1
+--R                (x  + 1) |--------  - 1           +--------+
+--R                         |  3                     |   3
+--R                        \| x  + 1                 |- x  + 1
+--R        - 3atan(-----------------------) + 3atan( |-------- ) + 2
+--R                            3                     |  3
+--R                           x                     \| x  + 1
+--R   (4)  ---------------------------------------------------------
+--R                                    9
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 268
+
+)clear all
+
+--S 269 of 649
+t0:=x^9*sqrt((5-7*x^5)/(7+5*x^5))
+--R 
+--R
+--R           +---------+
+--R           |    5
+--R         9 |- 7x  + 5
+--R   (1)  x  |---------
+--R           |   5
+--R          \| 5x  + 7
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 649
+r0:=-2738/175*((5-7*x^5)/(7+5*x^5))^(3/2)/(7+5*(5-7*x^5)/(7+5*x^5))^2+_
+   2257/875*atan(sqrt(5/7)*sqrt((5-7*x^5)/(7+5*x^5)))/sqrt(35)-_
+   2257/875*sqrt((5-7*x^5)/(7+5*x^5))/(7+5*(5-7*x^5)/(7+5*x^5))
+--R 
+--R
+--R                      +---------+
+--R                      |    5
+--R                  +-+ |- 7x  + 5
+--R                 \|5  |---------                                 +---------+
+--R                      |   5                                      |    5
+--R                     \| 5x  + 7           10       5        +--+ |- 7x  + 5
+--R        4514atan(----------------) + (175x   - 185x  - 602)\|35  |---------
+--R                        +-+                                      |   5
+--R                       \|7                                      \| 5x  + 7
+--R   (2)  --------------------------------------------------------------------
+--R                                           +--+
+--R                                      1750\|35
+--R                                                    Type: Expression(Integer)
+--E 270
+
+--S 271 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                 +---------+
+--R                                                 |    5
+--R                     10            5             |- 7x  + 5
+--R           (18958800x   - 28754180x  - 77415100) |---------
+--R                                                 |   5
+--R                                                \| 5x  + 7
+--R         + 
+--R                      10           5             +--+
+--R           (- 4879634x   - 7583520x  + 11059300)\|35
+--R      *
+--R                             +---------+
+--R                             |    5
+--R                 5      +--+ |- 7x  + 5
+--R              (5x  + 7)\|35  |---------  - 35
+--R                             |   5
+--R                            \| 5x  + 7
+--R         atan(-------------------------------)
+--R                               5
+--R                            35x
+--R     + 
+--R                                                              +---------+
+--R                                                              |    5
+--R                  20           15            10            5  |- 7x  + 5
+--R       (- 6621125x   - 3290525x   + 36018920x   + 38707550x ) |---------
+--R                                                              |   5
+--R                                                             \| 5x  + 7
+--R     + 
+--R                  20           15          10           5  +--+
+--R       (- 1029000x   + 4824050x   + 700070x   - 5529650x )\|35
+--R  /
+--R                                                 +---------+
+--R                                                 |    5
+--R                10            5             +--+ |- 7x  + 5             10
+--R       (7350000x   - 11147500x  - 30012500)\|35  |---------  - 66211250x
+--R                                                 |   5
+--R                                                \| 5x  + 7
+--R     + 
+--R                   5
+--R       - 102900000x  + 150062500
+--R                                         Type: Union(Expression(Integer),...)
+--E 271
+
+--S 272 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           +---------+                       +---------+
+--R                           |    5                            |    5
+--R               5      +--+ |- 7x  + 5                    +-+ |- 7x  + 5
+--R            (5x  + 7)\|35  |---------  - 35             \|5  |---------
+--R                           |   5                             |   5
+--R                          \| 5x  + 7                        \| 5x  + 7
+--R   2257atan(-------------------------------) - 2257atan(----------------) - 1505
+--R                             5                                 +-+
+--R                          35x                                 \|7
+--R   -----------------------------------------------------------------------------
+--R                                          +--+
+--R                                      875\|35
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                                   +---------+
+--R                                                                   |    5
+--R                 9         4  +-+ +-+ +--+          9           4  |- 7x  + 5
+--R       ((- 27084x  + 78995x )\|5 \|7 \|35  + 947940x  - 2764825x ) |---------
+--R                                                                   |   5
+--R                                                                  \| 5x  + 7
+--R     + 
+--R                 9          4  +--+           9          4  +-+ +-+
+--R       (- 552965x  + 394975x )\|35  + (552965x  - 394975x )\|5 \|7
+--R  /
+--R                                            +---------+
+--R                                            |    5
+--R               10          5           +--+ |- 7x  + 5            10           5
+--R       (428750x   + 294000x  - 428750)\|35  |---------  + 1029000x   - 3736250x
+--R                                            |   5
+--R                                           \| 5x  + 7
+--R     + 
+--R       2143750
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 649
+t0:=x/(a+b*x^2)^(3/2)+x/((1+x^2)*sqrt(a+b*x^2))
+--R 
+--R
+--R                       3
+--R               (b + 1)x  + (a + 1)x
+--R   (1)  ---------------------------------
+--R                               +--------+
+--R            4           2      |   2
+--R        (b x  + (b + a)x  + a)\|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 649
+r0:=-atanh(sqrt(a+b*x^2)/sqrt(a-b))/sqrt(a-b)+(-1)/(b*sqrt(a+b*x^2))
+--R 
+--R
+--R                             +--------+
+--R            +--------+       |   2
+--R            |   2           \|b x  + a      +-------+
+--R        - b\|b x  + a atanh(-----------) - \|- b + a
+--R                              +-------+
+--R                             \|- b + a
+--R   (2)  ---------------------------------------------
+--R                                +--------+
+--R                      +-------+ |   2
+--R                    b\|- b + a \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  +--------+
+--R              +-+ |   2             2    2
+--R           (a\|a \|b x  + a  - a b x  - a )
+--R        *
+--R           log
+--R                          2            2  4             2  2  +-+
+--R                      ((2b  + 2a b - 4a )x  + (8a b - 8a )x )\|a
+--R                    + 
+--R                         2 4             2  2     2  +-------+
+--R                      (4a x  + (4a b + 8a )x  + 8a )\|- b + a
+--R                 *
+--R                     +--------+
+--R                     |   2
+--R                    \|b x  + a
+--R                + 
+--R                        2         6       2            2  4               2  2
+--R                      (b  - 2a b)x  + (- b  - 4a b - 4a )x  + (- 8a b - 8a )x
+--R                    + 
+--R                          2
+--R                      - 8a
+--R                 *
+--R                     +-------+ +-+
+--R                    \|- b + a \|a
+--R                + 
+--R                       2     2   6          2     2      3  4        2      3  2
+--R                (- 2a b  + 2a b)x  + (- 6a b  + 2a b + 4a )x  + (- 8a b + 8a )x
+--R             /
+--R                                                   +--------+
+--R                         4             2  2     2  |   2
+--R                  (4a b x  + (4a b + 8a )x  + 8a )\|b x  + a
+--R                + 
+--R                      2 6       2         4               2  2     2  +-+
+--R                  (- b x  + (- b  - 8a b)x  + (- 8a b - 8a )x  - 8a )\|a
+--R       + 
+--R           2 +-------+ +-+
+--R         2x \|- b + a \|a
+--R    /
+--R                        +--------+
+--R          +-------+ +-+ |   2                 2     2  +-------+
+--R       2a\|- b + a \|a \|b x  + a  + (- 2a b x  - 2a )\|- b + a
+--R     ,
+--R
+--R                    +--------+
+--R                +-+ |   2             2    2
+--R           (- a\|a \|b x  + a  + a b x  + a )
+--R        *
+--R                         +--------+
+--R                 +-----+ |   2            2      +-+ +-----+
+--R                \|b - a \|b x  + a  + (- x  - 1)\|a \|b - a
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  (b - a)x
+--R       + 
+--R          2 +-+ +-----+
+--R         x \|a \|b - a
+--R    /
+--R                     +--------+
+--R         +-+ +-----+ |   2                2    2  +-----+
+--R       a\|a \|b - a \|b x  + a  + (- a b x  - a )\|b - a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 276
+
+--S 277 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              +--------+
+--R              |   2            +-+
+--R         (a b\|b x  + a  - a b\|a )
+--R      *
+--R         log
+--R                        2            2  4             2  2  +-+
+--R                    ((2b  + 2a b - 4a )x  + (8a b - 8a )x )\|a
+--R                  + 
+--R                       2 4             2  2     2  +-------+
+--R                    (4a x  + (4a b + 8a )x  + 8a )\|- b + a
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|b x  + a
+--R              + 
+--R                        2         6       2            2  4               2  2
+--R                      (b  - 2a b)x  + (- b  - 4a b - 4a )x  + (- 8a b - 8a )x
+--R                    + 
+--R                          2
+--R                      - 8a
+--R               *
+--R                   +-------+ +-+
+--R                  \|- b + a \|a
+--R              + 
+--R                     2     2   6          2     2      3  4        2      3  2
+--R              (- 2a b  + 2a b)x  + (- 6a b  + 2a b + 4a )x  + (- 8a b + 8a )x
+--R           /
+--R                                                 +--------+
+--R                       4             2  2     2  |   2
+--R                (4a b x  + (4a b + 8a )x  + 8a )\|b x  + a
+--R              + 
+--R                    2 6       2         4               2  2     2  +-+
+--R                (- b x  + (- b  - 8a b)x  + (- 8a b - 8a )x  - 8a )\|a
+--R     + 
+--R                                          +--------+
+--R             +--------+                   |   2
+--R             |   2             +-+       \|b x  + a
+--R       (2a b\|b x  + a  - 2a b\|a )atanh(-----------)
+--R                                           +-------+
+--R                                          \|- b + a
+--R     + 
+--R                         +--------+
+--R           +-------+ +-+ |   2           +-------+
+--R       - 2\|- b + a \|a \|b x  + a  + 2a\|- b + a
+--R  /
+--R                    +--------+
+--R          +-------+ |   2             +-------+ +-+
+--R     2a b\|- b + a \|b x  + a  - 2a b\|- b + a \|a
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                        +--------+
+--R                    +--------+                          |   2
+--R            +-----+ |   2            +-+ +-----+       \|b x  + a
+--R       (a b\|b - a \|b x  + a  - a b\|a \|b - a )atanh(-----------)
+--R                                                         +-------+
+--R                                                        \|- b + a
+--R     + 
+--R                          +--------+
+--R                +-------+ |   2            +-------+ +-+
+--R         (- a b\|- b + a \|b x  + a  + a b\|- b + a \|a )
+--R      *
+--R                       +--------+
+--R               +-----+ |   2            2      +-+ +-----+
+--R              \|b - a \|b x  + a  + (- x  - 1)\|a \|b - a
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                (b - a)x
+--R     + 
+--R                                +--------+
+--R          +-------+ +-+ +-----+ |   2          +-------+ +-----+
+--R       - \|- b + a \|a \|b - a \|b x  + a  + a\|- b + a \|b - a
+--R  /
+--R                           +--------+
+--R         +-------+ +-----+ |   2            +-------+ +-+ +-----+
+--R     a b\|- b + a \|b - a \|b x  + a  - a b\|- b + a \|a \|b - a
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 649
+t0:=x*(1+a+x^2+b*x^2)/((1+x^2)*(a+b*x^2)^(3/2))
+--R 
+--R
+--R                       3
+--R               (b + 1)x  + (a + 1)x
+--R   (1)  ---------------------------------
+--R                               +--------+
+--R            4           2      |   2
+--R        (b x  + (b + a)x  + a)\|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 649
+r0:=-atanh(sqrt(a+b*x^2)/sqrt(a-b))/sqrt(a-b)+(-1)/(b*sqrt(a+b*x^2))
+--R 
+--R
+--R                             +--------+
+--R            +--------+       |   2
+--R            |   2           \|b x  + a      +-------+
+--R        - b\|b x  + a atanh(-----------) - \|- b + a
+--R                              +-------+
+--R                             \|- b + a
+--R   (2)  ---------------------------------------------
+--R                                +--------+
+--R                      +-------+ |   2
+--R                    b\|- b + a \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  +--------+
+--R              +-+ |   2             2    2
+--R           (a\|a \|b x  + a  - a b x  - a )
+--R        *
+--R           log
+--R                          2            2  4             2  2  +-+
+--R                      ((2b  + 2a b - 4a )x  + (8a b - 8a )x )\|a
+--R                    + 
+--R                         2 4             2  2     2  +-------+
+--R                      (4a x  + (4a b + 8a )x  + 8a )\|- b + a
+--R                 *
+--R                     +--------+
+--R                     |   2
+--R                    \|b x  + a
+--R                + 
+--R                        2         6       2            2  4               2  2
+--R                      (b  - 2a b)x  + (- b  - 4a b - 4a )x  + (- 8a b - 8a )x
+--R                    + 
+--R                          2
+--R                      - 8a
+--R                 *
+--R                     +-------+ +-+
+--R                    \|- b + a \|a
+--R                + 
+--R                       2     2   6          2     2      3  4        2      3  2
+--R                (- 2a b  + 2a b)x  + (- 6a b  + 2a b + 4a )x  + (- 8a b + 8a )x
+--R             /
+--R                                                   +--------+
+--R                         4             2  2     2  |   2
+--R                  (4a b x  + (4a b + 8a )x  + 8a )\|b x  + a
+--R                + 
+--R                      2 6       2         4               2  2     2  +-+
+--R                  (- b x  + (- b  - 8a b)x  + (- 8a b - 8a )x  - 8a )\|a
+--R       + 
+--R           2 +-------+ +-+
+--R         2x \|- b + a \|a
+--R    /
+--R                        +--------+
+--R          +-------+ +-+ |   2                 2     2  +-------+
+--R       2a\|- b + a \|a \|b x  + a  + (- 2a b x  - 2a )\|- b + a
+--R     ,
+--R
+--R                    +--------+
+--R                +-+ |   2             2    2
+--R           (- a\|a \|b x  + a  + a b x  + a )
+--R        *
+--R                         +--------+
+--R                 +-----+ |   2            2      +-+ +-----+
+--R                \|b - a \|b x  + a  + (- x  - 1)\|a \|b - a
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  (b - a)x
+--R       + 
+--R          2 +-+ +-----+
+--R         x \|a \|b - a
+--R    /
+--R                     +--------+
+--R         +-+ +-----+ |   2                2    2  +-----+
+--R       a\|a \|b - a \|b x  + a  + (- a b x  - a )\|b - a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 283
+
+--S 284 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              +--------+
+--R              |   2            +-+
+--R         (a b\|b x  + a  - a b\|a )
+--R      *
+--R         log
+--R                        2            2  4             2  2  +-+
+--R                    ((2b  + 2a b - 4a )x  + (8a b - 8a )x )\|a
+--R                  + 
+--R                       2 4             2  2     2  +-------+
+--R                    (4a x  + (4a b + 8a )x  + 8a )\|- b + a
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|b x  + a
+--R              + 
+--R                        2         6       2            2  4               2  2
+--R                      (b  - 2a b)x  + (- b  - 4a b - 4a )x  + (- 8a b - 8a )x
+--R                    + 
+--R                          2
+--R                      - 8a
+--R               *
+--R                   +-------+ +-+
+--R                  \|- b + a \|a
+--R              + 
+--R                     2     2   6          2     2      3  4        2      3  2
+--R              (- 2a b  + 2a b)x  + (- 6a b  + 2a b + 4a )x  + (- 8a b + 8a )x
+--R           /
+--R                                                 +--------+
+--R                       4             2  2     2  |   2
+--R                (4a b x  + (4a b + 8a )x  + 8a )\|b x  + a
+--R              + 
+--R                    2 6       2         4               2  2     2  +-+
+--R                (- b x  + (- b  - 8a b)x  + (- 8a b - 8a )x  - 8a )\|a
+--R     + 
+--R                                          +--------+
+--R             +--------+                   |   2
+--R             |   2             +-+       \|b x  + a
+--R       (2a b\|b x  + a  - 2a b\|a )atanh(-----------)
+--R                                           +-------+
+--R                                          \|- b + a
+--R     + 
+--R                         +--------+
+--R           +-------+ +-+ |   2           +-------+
+--R       - 2\|- b + a \|a \|b x  + a  + 2a\|- b + a
+--R  /
+--R                    +--------+
+--R          +-------+ |   2             +-------+ +-+
+--R     2a b\|- b + a \|b x  + a  - 2a b\|- b + a \|a
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+--S 286 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                        +--------+
+--R                    +--------+                          |   2
+--R            +-----+ |   2            +-+ +-----+       \|b x  + a
+--R       (a b\|b - a \|b x  + a  - a b\|a \|b - a )atanh(-----------)
+--R                                                         +-------+
+--R                                                        \|- b + a
+--R     + 
+--R                          +--------+
+--R                +-------+ |   2            +-------+ +-+
+--R         (- a b\|- b + a \|b x  + a  + a b\|- b + a \|a )
+--R      *
+--R                       +--------+
+--R               +-----+ |   2            2      +-+ +-----+
+--R              \|b - a \|b x  + a  + (- x  - 1)\|a \|b - a
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                (b - a)x
+--R     + 
+--R                                +--------+
+--R          +-------+ +-+ +-----+ |   2          +-------+ +-----+
+--R       - \|- b + a \|a \|b - a \|b x  + a  + a\|- b + a \|b - a
+--R  /
+--R                           +--------+
+--R         +-------+ +-----+ |   2            +-------+ +-+ +-----+
+--R     a b\|- b + a \|b - a \|b x  + a  - a b\|- b + a \|a \|b - a
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 287
+
+)clear all
+
+--S 288 of 649
+t0:=x/(a+b*x^2)^(5/2)+x/(a+b*x^2)^(3/2)+x/((1+x^2)*sqrt(a+b*x^2))
+--R 
+--R
+--R            2      5                       3     2
+--R          (b  + b)x  + ((2a + 1)b + a + 1)x  + (a  + a + 1)x
+--R   (1)  ------------------------------------------------------
+--R                                                    +--------+
+--R          2 6     2         4            2  2    2  |   2
+--R        (b x  + (b  + 2a b)x  + (2a b + a )x  + a )\|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 288
+
+--S 289 of 649
+r0:=(-1/3)/(b*(a+b*x^2)^(3/2))-atanh(sqrt(a+b*x^2)/sqrt(a-b))/sqrt(a-b)+_
+   (-1)/(b*sqrt(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                     +--------+
+--R                    +--------+       |   2
+--R        2 2         |   2           \|b x  + a            2           +-------+
+--R   (- 3b x  - 3a b)\|b x  + a atanh(-----------) + (- 3b x  - 3a - 1)\|- b + a
+--R                                      +-------+
+--R                                     \|- b + a
+--R   ----------------------------------------------------------------------------
+--R                                                 +--------+
+--R                           2 2         +-------+ |   2
+--R                        (3b x  + 3a b)\|- b + a \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                             +--------+
+--R                2 2 4      3   2      4  +-+ |   2          2 3 6      3 2 4
+--R             (9a b x  + 21a b x  + 12a )\|a \|b x  + a  - 3a b x  - 18a b x
+--R           + 
+--R                  4   2      5
+--R             - 27a b x  - 12a
+--R        *
+--R           log
+--R                          2            2  4             2  2  +-+
+--R                      ((2b  + 2a b - 4a )x  + (8a b - 8a )x )\|a
+--R                    + 
+--R                         2 4             2  2     2  +-------+
+--R                      (4a x  + (4a b + 8a )x  + 8a )\|- b + a
+--R                 *
+--R                     +--------+
+--R                     |   2
+--R                    \|b x  + a
+--R                + 
+--R                        2         6       2            2  4               2  2
+--R                      (b  - 2a b)x  + (- b  - 4a b - 4a )x  + (- 8a b - 8a )x
+--R                    + 
+--R                          2
+--R                      - 8a
+--R                 *
+--R                     +-------+ +-+
+--R                    \|- b + a \|a
+--R                + 
+--R                       2     2   6          2     2      3  4        2      3  2
+--R                (- 2a b  + 2a b)x  + (- 6a b  + 2a b + 4a )x  + (- 8a b + 8a )x
+--R             /
+--R                                                   +--------+
+--R                         4             2  2     2  |   2
+--R                  (4a b x  + (4a b + 8a )x  + 8a )\|b x  + a
+--R                + 
+--R                      2 6       2         4               2  2     2  +-+
+--R                  (- b x  + (- b  - 8a b)x  + (- 8a b - 8a )x  - 8a )\|a
+--R       + 
+--R                                                           +--------+
+--R                2         4         3      2  2  +-------+ |   2
+--R         ((- 12a  - 6a)b x  + (- 12a  - 12a )x )\|- b + a \|b x  + a
+--R       + 
+--R                   2 6       2          4       3      2  2  +-------+ +-+
+--R         ((6a + 2)b x  + (18a  + 12a)b x  + (12a  + 12a )x )\|- b + a \|a
+--R    /
+--R                                                    +--------+
+--R             2 2 4      3   2      4  +-------+ +-+ |   2
+--R         (18a b x  + 42a b x  + 24a )\|- b + a \|a \|b x  + a
+--R       + 
+--R              2 3 6      3 2 4      4   2      5  +-------+
+--R         (- 6a b x  - 36a b x  - 54a b x  - 24a )\|- b + a
+--R     ,
+--R
+--R                                               +--------+
+--R                  2 2 4      3   2      4  +-+ |   2          2 3 6      3 2 4
+--R             (- 9a b x  - 21a b x  - 12a )\|a \|b x  + a  + 3a b x  + 18a b x
+--R           + 
+--R                4   2      5
+--R             27a b x  + 12a
+--R        *
+--R                         +--------+
+--R                 +-----+ |   2            2      +-+ +-----+
+--R                \|b - a \|b x  + a  + (- x  - 1)\|a \|b - a
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  (b - a)x
+--R       + 
+--R                                                      +--------+
+--R               2         4        3     2  2  +-----+ |   2
+--R         ((- 6a  - 3a)b x  + (- 6a  - 6a )x )\|b - a \|b x  + a
+--R       + 
+--R                   2 6      2         4      3     2  2  +-+ +-----+
+--R         ((3a + 1)b x  + (9a  + 6a)b x  + (6a  + 6a )x )\|a \|b - a
+--R    /
+--R                                                 +--------+
+--R            2 2 4      3   2      4  +-+ +-----+ |   2
+--R         (9a b x  + 21a b x  + 12a )\|a \|b - a \|b x  + a
+--R       + 
+--R              2 3 6      3 2 4      4   2      5  +-----+
+--R         (- 3a b x  - 18a b x  - 27a b x  - 12a )\|b - a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 290
+
+--S 291 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            +--------+
+--R             2 2 2      3   |   2             2 2 2      3   +-+
+--R         ((3a b x  + 12a b)\|b x  + a  + (- 9a b x  - 12a b)\|a )
+--R      *
+--R         log
+--R                        2            2  4             2  2  +-+
+--R                    ((2b  + 2a b - 4a )x  + (8a b - 8a )x )\|a
+--R                  + 
+--R                       2 4             2  2     2  +-------+
+--R                    (4a x  + (4a b + 8a )x  + 8a )\|- b + a
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|b x  + a
+--R              + 
+--R                        2         6       2            2  4               2  2
+--R                      (b  - 2a b)x  + (- b  - 4a b - 4a )x  + (- 8a b - 8a )x
+--R                    + 
+--R                          2
+--R                      - 8a
+--R               *
+--R                   +-------+ +-+
+--R                  \|- b + a \|a
+--R              + 
+--R                     2     2   6          2     2      3  4        2      3  2
+--R              (- 2a b  + 2a b)x  + (- 6a b  + 2a b + 4a )x  + (- 8a b + 8a )x
+--R           /
+--R                                                 +--------+
+--R                       4             2  2     2  |   2
+--R                (4a b x  + (4a b + 8a )x  + 8a )\|b x  + a
+--R              + 
+--R                    2 6       2         4               2  2     2  +-+
+--R                (- b x  + (- b  - 8a b)x  + (- 8a b - 8a )x  - 8a )\|a
+--R     + 
+--R                            +--------+
+--R             2 2 2      3   |   2              2 2 2      3   +-+
+--R         ((6a b x  + 24a b)\|b x  + a  + (- 18a b x  - 24a b)\|a )
+--R      *
+--R                +--------+
+--R                |   2
+--R               \|b x  + a
+--R         atanh(-----------)
+--R                 +-------+
+--R                \|- b + a
+--R     + 
+--R                                                  +--------+
+--R                     2      2       +-------+ +-+ |   2
+--R       ((- 6a - 2)b x  - 24a  - 8a)\|- b + a \|a \|b x  + a
+--R     + 
+--R            2         2      3     2  +-------+
+--R       ((18a  + 6a)b x  + 24a  + 8a )\|- b + a
+--R  /
+--R                                 +--------+
+--R        2 2 2      3   +-------+ |   2              2 2 2      3   +-------+ +-+
+--R     (6a b x  + 24a b)\|- b + a \|b x  + a  + (- 18a b x  - 24a b)\|- b + a \|a
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                       +--------+
+--R                2 2 2      3   +-----+ |   2
+--R             (3a b x  + 12a b)\|b - a \|b x  + a
+--R           + 
+--R                  2 2 2      3   +-+ +-----+
+--R             (- 9a b x  - 12a b)\|a \|b - a
+--R      *
+--R                +--------+
+--R                |   2
+--R               \|b x  + a
+--R         atanh(-----------)
+--R                 +-------+
+--R                \|- b + a
+--R     + 
+--R                                         +--------+
+--R                2 2 2      3   +-------+ |   2
+--R           (- 3a b x  - 12a b)\|- b + a \|b x  + a
+--R         + 
+--R              2 2 2      3   +-------+ +-+
+--R           (9a b x  + 12a b)\|- b + a \|a
+--R      *
+--R                       +--------+
+--R               +-----+ |   2            2      +-+ +-----+
+--R              \|b - a \|b x  + a  + (- x  - 1)\|a \|b - a
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                (b - a)x
+--R     + 
+--R                                                          +--------+
+--R                     2      2       +-------+ +-+ +-----+ |   2
+--R       ((- 3a - 1)b x  - 12a  - 4a)\|- b + a \|a \|b - a \|b x  + a
+--R     + 
+--R           2         2      3     2  +-------+ +-----+
+--R       ((9a  + 3a)b x  + 12a  + 4a )\|- b + a \|b - a
+--R  /
+--R                                           +--------+
+--R          2 2 2      3   +-------+ +-----+ |   2
+--R       (3a b x  + 12a b)\|- b + a \|b - a \|b x  + a
+--R     + 
+--R            2 2 2      3   +-------+ +-+ +-----+
+--R       (- 9a b x  - 12a b)\|- b + a \|a \|b - a
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 649
+t0:=x*(1+a+a^2+x^2+a*x^2+b*x^2+2*a*b*x^2+b*x^4+b^2*x^4)/((1+x^2)*(a+b*x^2)^(5/2))
+--R 
+--R
+--R            2      5                       3     2
+--R          (b  + b)x  + ((2a + 1)b + a + 1)x  + (a  + a + 1)x
+--R   (1)  ------------------------------------------------------
+--R                                                    +--------+
+--R          2 6     2         4            2  2    2  |   2
+--R        (b x  + (b  + 2a b)x  + (2a b + a )x  + a )\|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 649
+r0:=(-1/3)/(b*(a+b*x^2)^(3/2))-atanh(sqrt(a+b*x^2)/sqrt(a-b))/sqrt(a-b)+_
+   (-1)/(b*sqrt(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                     +--------+
+--R                    +--------+       |   2
+--R        2 2         |   2           \|b x  + a            2           +-------+
+--R   (- 3b x  - 3a b)\|b x  + a atanh(-----------) + (- 3b x  - 3a - 1)\|- b + a
+--R                                      +-------+
+--R                                     \|- b + a
+--R   ----------------------------------------------------------------------------
+--R                                                 +--------+
+--R                           2 2         +-------+ |   2
+--R                        (3b x  + 3a b)\|- b + a \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                             +--------+
+--R                2 2 4      3   2      4  +-+ |   2          2 3 6      3 2 4
+--R             (9a b x  + 21a b x  + 12a )\|a \|b x  + a  - 3a b x  - 18a b x
+--R           + 
+--R                  4   2      5
+--R             - 27a b x  - 12a
+--R        *
+--R           log
+--R                          2            2  4             2  2  +-+
+--R                      ((2b  + 2a b - 4a )x  + (8a b - 8a )x )\|a
+--R                    + 
+--R                         2 4             2  2     2  +-------+
+--R                      (4a x  + (4a b + 8a )x  + 8a )\|- b + a
+--R                 *
+--R                     +--------+
+--R                     |   2
+--R                    \|b x  + a
+--R                + 
+--R                        2         6       2            2  4               2  2
+--R                      (b  - 2a b)x  + (- b  - 4a b - 4a )x  + (- 8a b - 8a )x
+--R                    + 
+--R                          2
+--R                      - 8a
+--R                 *
+--R                     +-------+ +-+
+--R                    \|- b + a \|a
+--R                + 
+--R                       2     2   6          2     2      3  4        2      3  2
+--R                (- 2a b  + 2a b)x  + (- 6a b  + 2a b + 4a )x  + (- 8a b + 8a )x
+--R             /
+--R                                                   +--------+
+--R                         4             2  2     2  |   2
+--R                  (4a b x  + (4a b + 8a )x  + 8a )\|b x  + a
+--R                + 
+--R                      2 6       2         4               2  2     2  +-+
+--R                  (- b x  + (- b  - 8a b)x  + (- 8a b - 8a )x  - 8a )\|a
+--R       + 
+--R                                                           +--------+
+--R                2         4         3      2  2  +-------+ |   2
+--R         ((- 12a  - 6a)b x  + (- 12a  - 12a )x )\|- b + a \|b x  + a
+--R       + 
+--R                   2 6       2          4       3      2  2  +-------+ +-+
+--R         ((6a + 2)b x  + (18a  + 12a)b x  + (12a  + 12a )x )\|- b + a \|a
+--R    /
+--R                                                    +--------+
+--R             2 2 4      3   2      4  +-------+ +-+ |   2
+--R         (18a b x  + 42a b x  + 24a )\|- b + a \|a \|b x  + a
+--R       + 
+--R              2 3 6      3 2 4      4   2      5  +-------+
+--R         (- 6a b x  - 36a b x  - 54a b x  - 24a )\|- b + a
+--R     ,
+--R
+--R                                               +--------+
+--R                  2 2 4      3   2      4  +-+ |   2          2 3 6      3 2 4
+--R             (- 9a b x  - 21a b x  - 12a )\|a \|b x  + a  + 3a b x  + 18a b x
+--R           + 
+--R                4   2      5
+--R             27a b x  + 12a
+--R        *
+--R                         +--------+
+--R                 +-----+ |   2            2      +-+ +-----+
+--R                \|b - a \|b x  + a  + (- x  - 1)\|a \|b - a
+--R           atan(--------------------------------------------)
+--R                                          2
+--R                                  (b - a)x
+--R       + 
+--R                                                      +--------+
+--R               2         4        3     2  2  +-----+ |   2
+--R         ((- 6a  - 3a)b x  + (- 6a  - 6a )x )\|b - a \|b x  + a
+--R       + 
+--R                   2 6      2         4      3     2  2  +-+ +-----+
+--R         ((3a + 1)b x  + (9a  + 6a)b x  + (6a  + 6a )x )\|a \|b - a
+--R    /
+--R                                                 +--------+
+--R            2 2 4      3   2      4  +-+ +-----+ |   2
+--R         (9a b x  + 21a b x  + 12a )\|a \|b - a \|b x  + a
+--R       + 
+--R              2 3 6      3 2 4      4   2      5  +-----+
+--R         (- 3a b x  - 18a b x  - 27a b x  - 12a )\|b - a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 297
+
+--S 298 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            +--------+
+--R             2 2 2      3   |   2             2 2 2      3   +-+
+--R         ((3a b x  + 12a b)\|b x  + a  + (- 9a b x  - 12a b)\|a )
+--R      *
+--R         log
+--R                        2            2  4             2  2  +-+
+--R                    ((2b  + 2a b - 4a )x  + (8a b - 8a )x )\|a
+--R                  + 
+--R                       2 4             2  2     2  +-------+
+--R                    (4a x  + (4a b + 8a )x  + 8a )\|- b + a
+--R               *
+--R                   +--------+
+--R                   |   2
+--R                  \|b x  + a
+--R              + 
+--R                        2         6       2            2  4               2  2
+--R                      (b  - 2a b)x  + (- b  - 4a b - 4a )x  + (- 8a b - 8a )x
+--R                    + 
+--R                          2
+--R                      - 8a
+--R               *
+--R                   +-------+ +-+
+--R                  \|- b + a \|a
+--R              + 
+--R                     2     2   6          2     2      3  4        2      3  2
+--R              (- 2a b  + 2a b)x  + (- 6a b  + 2a b + 4a )x  + (- 8a b + 8a )x
+--R           /
+--R                                                 +--------+
+--R                       4             2  2     2  |   2
+--R                (4a b x  + (4a b + 8a )x  + 8a )\|b x  + a
+--R              + 
+--R                    2 6       2         4               2  2     2  +-+
+--R                (- b x  + (- b  - 8a b)x  + (- 8a b - 8a )x  - 8a )\|a
+--R     + 
+--R                            +--------+
+--R             2 2 2      3   |   2              2 2 2      3   +-+
+--R         ((6a b x  + 24a b)\|b x  + a  + (- 18a b x  - 24a b)\|a )
+--R      *
+--R                +--------+
+--R                |   2
+--R               \|b x  + a
+--R         atanh(-----------)
+--R                 +-------+
+--R                \|- b + a
+--R     + 
+--R                                                  +--------+
+--R                     2      2       +-------+ +-+ |   2
+--R       ((- 6a - 2)b x  - 24a  - 8a)\|- b + a \|a \|b x  + a
+--R     + 
+--R            2         2      3     2  +-------+
+--R       ((18a  + 6a)b x  + 24a  + 8a )\|- b + a
+--R  /
+--R                                 +--------+
+--R        2 2 2      3   +-------+ |   2              2 2 2      3   +-------+ +-+
+--R     (6a b x  + 24a b)\|- b + a \|b x  + a  + (- 18a b x  - 24a b)\|- b + a \|a
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                       +--------+
+--R                2 2 2      3   +-----+ |   2
+--R             (3a b x  + 12a b)\|b - a \|b x  + a
+--R           + 
+--R                  2 2 2      3   +-+ +-----+
+--R             (- 9a b x  - 12a b)\|a \|b - a
+--R      *
+--R                +--------+
+--R                |   2
+--R               \|b x  + a
+--R         atanh(-----------)
+--R                 +-------+
+--R                \|- b + a
+--R     + 
+--R                                         +--------+
+--R                2 2 2      3   +-------+ |   2
+--R           (- 3a b x  - 12a b)\|- b + a \|b x  + a
+--R         + 
+--R              2 2 2      3   +-------+ +-+
+--R           (9a b x  + 12a b)\|- b + a \|a
+--R      *
+--R                       +--------+
+--R               +-----+ |   2            2      +-+ +-----+
+--R              \|b - a \|b x  + a  + (- x  - 1)\|a \|b - a
+--R         atan(--------------------------------------------)
+--R                                        2
+--R                                (b - a)x
+--R     + 
+--R                                                          +--------+
+--R                     2      2       +-------+ +-+ +-----+ |   2
+--R       ((- 3a - 1)b x  - 12a  - 4a)\|- b + a \|a \|b - a \|b x  + a
+--R     + 
+--R           2         2      3     2  +-------+ +-----+
+--R       ((9a  + 3a)b x  + 12a  + 4a )\|- b + a \|b - a
+--R  /
+--R                                           +--------+
+--R          2 2 2      3   +-------+ +-----+ |   2
+--R       (3a b x  + 12a b)\|- b + a \|b - a \|b x  + a
+--R     + 
+--R            2 2 2      3   +-------+ +-+ +-----+
+--R       (- 9a b x  - 12a b)\|- b + a \|a \|b - a
+--R                                                    Type: Expression(Integer)
+--E 300
+
+--S 301 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 301
+
+)clear all
+
+--S 302 of 649
+t0:=1/sqrt(x+sqrt(x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         | +-+
+--R        \|\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 649
+r0:=-2*atanh(sqrt(x)/sqrt(x+sqrt(x)))+2*sqrt(x+sqrt(x))
+--R 
+--R
+--R                      +-+         +--------+
+--R                     \|x          | +-+
+--R   (2)  - 2atanh(-----------) + 2\|\|x  + x
+--R                  +--------+
+--R                  | +-+
+--R                 \|\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 303
+
+--S 304 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          +--------+                       +--------+
+--R                 +-+      | +-+          +-+               | +-+
+--R        - log((8\|x  + 4)\|\|x  + x  + 8\|x  + 8x + 1) + 4\|\|x  + x
+--R   (3)  -------------------------------------------------------------
+--R                                      2
+--R                                         Type: Union(Expression(Integer),...)
+--E 304
+
+--S 305 of 649
+m0:=a0-r0
+--R 
+--R
+--R                          +--------+                                 +-+
+--R                 +-+      | +-+          +-+                        \|x
+--R        - log((8\|x  + 4)\|\|x  + x  + 8\|x  + 8x + 1) + 4atanh(-----------)
+--R                                                                 +--------+
+--R                                                                 | +-+
+--R                                                                \|\|x  + x
+--R   (4)  --------------------------------------------------------------------
+--R                                          2
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 649
+t0:=sqrt(x+sqrt(x))
+--R 
+--R
+--R         +--------+
+--R         | +-+
+--R   (1)  \|\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 649
+r0:=1/4*atanh(sqrt(x)/sqrt(x+sqrt(x)))-1/4*sqrt(x+sqrt(x))+_
+   2/3*x*sqrt(x+sqrt(x))+1/6*sqrt(x)*sqrt(x+sqrt(x))
+--R 
+--R
+--R                    +-+                        +--------+
+--R                   \|x           +-+           | +-+
+--R        3atanh(-----------) + (2\|x  + 8x - 3)\|\|x  + x
+--R                +--------+
+--R                | +-+
+--R               \|\|x  + x
+--R   (2)  -------------------------------------------------
+--R                                12
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          +--------+
+--R                 +-+      | +-+          +-+
+--R       - 3log((8\|x  + 4)\|\|x  + x  - 8\|x  - 8x - 1)
+--R     + 
+--R                          +--------+
+--R          +-+             | +-+
+--R       (8\|x  + 32x - 12)\|\|x  + x
+--R  /
+--R     48
+--R                                         Type: Union(Expression(Integer),...)
+--E 309
+
+--S 310 of 649
+m0:=a0-r0
+--R 
+--R
+--R                          +--------+                                 +-+
+--R                 +-+      | +-+          +-+                        \|x
+--R        - log((8\|x  + 4)\|\|x  + x  - 8\|x  - 8x - 1) - 4atanh(-----------)
+--R                                                                 +--------+
+--R                                                                 | +-+
+--R                                                                \|\|x  + x
+--R   (4)  --------------------------------------------------------------------
+--R                                         16
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 311
+
+)clear all
+
+--S 312 of 649
+t0:=sqrt(-x)*(x+sqrt(-x))
+--R 
+--R
+--R          +---+
+--R   (1)  x\|- x  - x
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 649
+r0:=2/5*(-x)^(5/2)-1/2*x^2
+--R 
+--R
+--R          2 +---+     2
+--R        4x \|- x  - 5x
+--R   (2)  ---------------
+--R               10
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 +---+     2
+--R        4x \|- x  - 5x
+--R   (3)  ---------------
+--R               10
+--R                                         Type: Union(Expression(Integer),...)
+--E 314
+
+--S 315 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+--S 316 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 316
+
+)clear all
+
+--S 317 of 649
+t0:=(5+x^(1/4))/(-6+x)
+--R 
+--R
+--R        4+-+
+--R        \|x  + 5
+--R   (1)  --------
+--R          x - 6
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 649
+r0:=4*x^(1/4)-2*6^(1/4)*atan(x^(1/4)/6^(1/4))-_
+   2*6^(1/4)*atanh(x^(1/4)/6^(1/4))+5*log(6-x)
+--R 
+--R
+--R                     4+-+              4+-+
+--R           4+-+      \|x      4+-+     \|x      4+-+
+--R   (2)  - 2\|6 atanh(----) - 2\|6 atan(----) + 4\|x  + 5log(- x + 6)
+--R                     4+-+              4+-+
+--R                     \|6               \|6
+--R                                                    Type: Expression(Integer)
+--E 318
+
+--S 319 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-----+           +-----+
+--R           |  +-+            |  +-+     4+-+          4+-+2    +-+
+--R       (- \|4\|6   + 10)log(\|4\|6   + 2\|x ) + 10log(\|x   + \|6 )
+--R     + 
+--R                                                               +-----+
+--R         +-----+             +-----+              +-----+      |  +-+
+--R         |  +-+              |  +-+     4+-+      |  +-+      \|4\|6       4+-+
+--R       (\|4\|6   + 10)log(- \|4\|6   + 2\|x ) + 2\|4\|6  atan(--------) + 8\|x
+--R                                                                 4+-+
+--R                                                                2\|x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 319
+
+--S 320 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           +-----+           +-----+
+--R           |  +-+            |  +-+     4+-+          4+-+2    +-+
+--R       (- \|4\|6   + 10)log(\|4\|6   + 2\|x ) + 10log(\|x   + \|6 )
+--R     + 
+--R         +-----+             +-----+                       4+-+
+--R         |  +-+              |  +-+     4+-+     4+-+      \|x
+--R       (\|4\|6   + 10)log(- \|4\|6   + 2\|x ) + 4\|6 atanh(----)
+--R                                                           4+-+
+--R                                                           \|6
+--R     + 
+--R                      +-----+
+--R         +-----+      |  +-+               4+-+
+--R         |  +-+      \|4\|6       4+-+     \|x
+--R       2\|4\|6  atan(--------) + 4\|6 atan(----) - 10log(- x + 6)
+--R                        4+-+               4+-+
+--R                       2\|x                \|6
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 649
+t0:=1/(4-x+sqrt(4-x))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +-------+
+--R        \|- x + 4  - x + 4
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 649
+r0:=-2*log(1+sqrt(4-x))
+--R 
+--R
+--R                +-------+
+--R   (2)  - 2log(\|- x + 4  + 1)
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +-------+
+--R   (3)  - 2log(\|- x + 4  + 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 324
+
+--S 325 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 326
+
+)clear all
+
+--S 327 of 649
+t0:=1/(1+x-sqrt(2+x))
+--R 
+--R
+--R                  1
+--R   (1)  - ----------------
+--R           +-----+
+--R          \|x + 2  - x - 1
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 649
+r0:=1/5*log(1-sqrt(5)-2*sqrt(2+x))*(5-sqrt(5))+_
+   1/5*log(1+sqrt(5)-2*sqrt(2+x))*(5+sqrt(5))
+--R 
+--R
+--R   (2)
+--R         +-+             +-----+    +-+
+--R       (\|5  + 5)log(- 2\|x + 2  + \|5  + 1)
+--R     + 
+--R           +-+             +-----+    +-+
+--R       (- \|5  + 5)log(- 2\|x + 2  - \|5  + 1)
+--R  /
+--R     5
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-+       +-----+              +-+
+--R       (2\|5  + 10)\|x + 2  + (- 2x - 7)\|5  - 5     +-+       +-----+
+--R   log(-----------------------------------------) + \|5 log(- \|x + 2  + x + 1)
+--R                     +-----+
+--R                    \|x + 2  - x - 1
+--R   ----------------------------------------------------------------------------
+--R                                        +-+
+--R                                       \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 329
+
+--S 330 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+       +-----+              +-+
+--R           (2\|5  + 10)\|x + 2  + (- 2x - 7)\|5  - 5
+--R       log(-----------------------------------------)
+--R                         +-----+
+--R                        \|x + 2  - x - 1
+--R     + 
+--R        +-+       +-----+                +-+             +-----+    +-+
+--R       \|5 log(- \|x + 2  + x + 1) + (- \|5  - 1)log(- 2\|x + 2  + \|5  + 1)
+--R     + 
+--R           +-+             +-----+    +-+
+--R       (- \|5  + 1)log(- 2\|x + 2  - \|5  + 1)
+--R  /
+--R      +-+
+--R     \|5
+--R                                                    Type: Expression(Integer)
+--E 330
+
+--S 331 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 331
+
+)clear all
+
+--S 332 of 649
+t0:=1/(4+x+sqrt(1+x))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R         +-----+
+--R        \|x + 1  + x + 4
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 649
+r0:=log(4+x+sqrt(1+x))-2*atan((1+2*sqrt(1+x))/sqrt(11))/sqrt(11)
+--R 
+--R
+--R                                             +-----+
+--R         +--+     +-----+                  2\|x + 1  + 1
+--R        \|11 log(\|x + 1  + x + 4) - 2atan(-------------)
+--R                                                +--+
+--R                                               \|11
+--R   (2)  -------------------------------------------------
+--R                               +--+
+--R                              \|11
+--R                                                    Type: Expression(Integer)
+--E 333
+
+--S 334 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                             +--+ +-----+    +--+
+--R         +--+     +-----+                  2\|11 \|x + 1  + \|11
+--R        \|11 log(\|x + 1  + x + 4) - 2atan(----------------------)
+--R                                                     11
+--R   (3)  ----------------------------------------------------------
+--R                                    +--+
+--R                                   \|11
+--R                                         Type: Union(Expression(Integer),...)
+--E 334
+
+--S 335 of 649
+m0:=a0-r0
+--R 
+--R
+--R                  +--+ +-----+    +--+            +-----+
+--R                2\|11 \|x + 1  + \|11           2\|x + 1  + 1
+--R        - 2atan(----------------------) + 2atan(-------------)
+--R                          11                         +--+
+--R                                                    \|11
+--R   (4)  ------------------------------------------------------
+--R                                  +--+
+--R                                 \|11
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 649
+t0:=1/(x-sqrt(1+x))
+--R 
+--R
+--R                1
+--R   (1)  - ------------
+--R           +-----+
+--R          \|x + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 649
+r0:=1/5*log(1-sqrt(5)-2*sqrt(1+x))*(5-sqrt(5))+_
+   1/5*log(1+sqrt(5)-2*sqrt(1+x))*(5+sqrt(5))
+--R 
+--R
+--R   (2)
+--R         +-+             +-----+    +-+
+--R       (\|5  + 5)log(- 2\|x + 1  + \|5  + 1)
+--R     + 
+--R           +-+             +-----+    +-+
+--R       (- \|5  + 5)log(- 2\|x + 1  - \|5  + 1)
+--R  /
+--R     5
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-+       +-----+              +-+
+--R       (2\|5  + 10)\|x + 1  + (- 2x - 5)\|5  - 5     +-+       +-----+
+--R   log(-----------------------------------------) + \|5 log(- \|x + 1  + x)
+--R                       +-----+
+--R                      \|x + 1  - x
+--R   ------------------------------------------------------------------------
+--R                                      +-+
+--R                                     \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 339
+
+--S 340 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+       +-----+              +-+
+--R           (2\|5  + 10)\|x + 1  + (- 2x - 5)\|5  - 5     +-+       +-----+
+--R       log(-----------------------------------------) + \|5 log(- \|x + 1  + x)
+--R                           +-----+
+--R                          \|x + 1  - x
+--R     + 
+--R           +-+             +-----+    +-+
+--R       (- \|5  - 1)log(- 2\|x + 1  + \|5  + 1)
+--R     + 
+--R           +-+             +-----+    +-+
+--R       (- \|5  + 1)log(- 2\|x + 1  - \|5  + 1)
+--R  /
+--R      +-+
+--R     \|5
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 341
+
+)clear all
+
+--S 342 of 649
+t0:=1/(x-sqrt(2+x))
+--R 
+--R
+--R                1
+--R   (1)  - ------------
+--R           +-----+
+--R          \|x + 2  - x
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 649
+r0:=4/3*log(2-sqrt(2+x))+2/3*log(1+sqrt(2+x))
+--R 
+--R
+--R              +-----+                +-----+
+--R        2log(\|x + 2  + 1) + 4log(- \|x + 2  + 2)
+--R   (2)  -----------------------------------------
+--R                            3
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +-----+              +-----+
+--R        2log(\|x + 2  + 1) + 4log(\|x + 2  - 2)
+--R   (3)  ---------------------------------------
+--R                           3
+--R                                         Type: Union(Expression(Integer),...)
+--E 344
+
+--S 345 of 649
+m0:=a0-r0
+--R 
+--R
+--R              +-----+                +-----+
+--R        4log(\|x + 2  - 2) - 4log(- \|x + 2  + 2)
+--R   (4)  -----------------------------------------
+--R                            3
+--R                                                    Type: Expression(Integer)
+--E 345
+
+--S 346 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 346
+
+)clear all
+
+--S 347 of 649
+t0:=1/(x-sqrt(1-x))
+--R 
+--R
+--R                 1
+--R   (1)  - --------------
+--R           +-------+
+--R          \|- x + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 649
+r0:=1/5*log(1-sqrt(5)+2*sqrt(1-x))*(5-sqrt(5))+_
+   1/5*log(1+sqrt(5)+2*sqrt(1-x))*(5+sqrt(5))
+--R 
+--R
+--R   (2)
+--R         +-+           +-------+    +-+
+--R       (\|5  + 5)log(2\|- x + 1  + \|5  + 1)
+--R     + 
+--R           +-+           +-------+    +-+
+--R       (- \|5  + 5)log(2\|- x + 1  - \|5  + 1)
+--R  /
+--R     5
+--R                                                    Type: Expression(Integer)
+--E 348
+
+--S 349 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                    +-+       +-------+              +-+
+--R    +-+     +-------+            (2\|5  + 10)\|- x + 1  + (- 2x + 5)\|5  + 5
+--R   \|5 log(\|- x + 1  - x) + log(-------------------------------------------)
+--R                                                 +-------+
+--R                                                \|- x + 1  - x
+--R   --------------------------------------------------------------------------
+--R                                       +-+
+--R                                      \|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 349
+
+--S 350 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           +-+           +-------+    +-+
+--R       (- \|5  - 1)log(2\|- x + 1  + \|5  + 1)
+--R     + 
+--R           +-+           +-------+    +-+         +-+     +-------+
+--R       (- \|5  + 1)log(2\|- x + 1  - \|5  + 1) + \|5 log(\|- x + 1  - x)
+--R     + 
+--R              +-+       +-------+              +-+
+--R           (2\|5  + 10)\|- x + 1  + (- 2x + 5)\|5  + 5
+--R       log(-------------------------------------------)
+--R                           +-------+
+--R                          \|- x + 1  - x
+--R  /
+--R      +-+
+--R     \|5
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 649
+t0:=1/(sqrt(-1+x)+sqrt(x))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         +-+    +-----+
+--R        \|x  + \|x - 1
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 649
+r0:=-2/3*(-1+x)^(3/2)+2/3*x^(3/2)
+--R 
+--R
+--R           +-+              +-----+
+--R        2x\|x  + (- 2x + 2)\|x - 1
+--R   (2)  ---------------------------
+--R                     3
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +-----+ +-+      2
+--R        (12x - 6)\|x - 1 \|x  + 12x  - 12x + 2
+--R   (3)  --------------------------------------
+--R                     +-+             +-----+
+--R           (12x - 9)\|x  + (12x - 3)\|x - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 354
+
+--S 355 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 356
+
+)clear all
+
+--S 357 of 649
+t0:=sqrt(1+x+sqrt(x))
+--R 
+--R
+--R         +------------+
+--R         | +-+
+--R   (1)  \|\|x  + x + 1
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 649
+r0:=-3/8*asinh((1+2*sqrt(x))/sqrt(3))+2/3*(1+x+sqrt(x))^(3/2)-_
+   1/4*(1+2*sqrt(x))*sqrt(1+x+sqrt(x))
+--R 
+--R
+--R                           +------------+            +-+
+--R           +-+             | +-+                   2\|x  + 1
+--R        (4\|x  + 16x + 10)\|\|x  + x + 1  - 9asinh(---------)
+--R                                                       +-+
+--R                                                      \|3
+--R   (2)  -----------------------------------------------------
+--R                                  24
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          +------------+
+--R                 +-+      | +-+              +-+
+--R       - 9log((8\|x  + 4)\|\|x  + x + 1  + 8\|x  + 8x + 5)
+--R     + 
+--R                          +------------+
+--R          +-+             | +-+
+--R       (8\|x  + 32x + 20)\|\|x  + x + 1
+--R  /
+--R     48
+--R                                         Type: Union(Expression(Integer),...)
+--E 359
+
+--S 360 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +------------+                              +-+
+--R             +-+      | +-+              +-+                    2\|x  + 1
+--R   - 3log((8\|x  + 4)\|\|x  + x + 1  + 8\|x  + 8x + 5) + 6asinh(---------)
+--R                                                                    +-+
+--R                                                                   \|3
+--R   -----------------------------------------------------------------------
+--R                                      16
+--R                                                    Type: Expression(Integer)
+--E 360
+
+--S 361 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R            +--------------+     +------------+
+--R            |  +-+               | +-+
+--R        - 3\|4\|x  + 4x + 4  + 6\|\|x  + x + 1
+--R   (5)  ---------------------------------------
+--R                +------------+ +--------------+
+--R            +-+ | +-+          |  +-+
+--R         16\|x \|\|x  + x + 1 \|4\|x  + 4x + 4
+--R                                                    Type: Expression(Integer)
+--E 361
+
+)clear all
+
+--S 362 of 649
+t0:=sqrt(1+x+sqrt(1+x))
+--R 
+--R
+--R         +----------------+
+--R         | +-----+
+--R   (1)  \|\|x + 1  + x + 1
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 649
+r0:=1/4*atanh(sqrt(1+x)/sqrt(1+x+sqrt(1+x)))-1/4*sqrt(1+x+sqrt(1+x))+_
+   2/3*(1+x)*sqrt(1+x+sqrt(1+x))+1/6*sqrt(1+x)*sqrt(1+x+sqrt(1+x))
+--R 
+--R
+--R                      +-----+                              +----------------+
+--R                     \|x + 1             +-----+           | +-----+
+--R        3atanh(-------------------) + (2\|x + 1  + 8x + 5)\|\|x + 1  + x + 1
+--R                +----------------+
+--R                | +-----+
+--R               \|\|x + 1  + x + 1
+--R   (2)  ---------------------------------------------------------------------
+--R                                          12
+--R                                                    Type: Expression(Integer)
+--E 363
+
+--S 364 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                +----------------+
+--R                   +-----+      | +-----+              +-----+
+--R       - 3log((- 8\|x + 1  - 4)\|\|x + 1  + x + 1  + 8\|x + 1  + 8x + 9)
+--R     + 
+--R                              +----------------+
+--R          +-----+             | +-----+
+--R       (8\|x + 1  + 32x + 20)\|\|x + 1  + x + 1
+--R  /
+--R     48
+--R                                         Type: Union(Expression(Integer),...)
+--E 364
+
+--S 365 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----------------+
+--R                  +-----+      | +-----+              +-----+
+--R       - log((- 8\|x + 1  - 4)\|\|x + 1  + x + 1  + 8\|x + 1  + 8x + 9)
+--R     + 
+--R                       +-----+
+--R                      \|x + 1
+--R       - 4atanh(-------------------)
+--R                 +----------------+
+--R                 | +-----+
+--R                \|\|x + 1  + x + 1
+--R  /
+--R     16
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 649
+t0:=sqrt(x+sqrt(-1+x))
+--R 
+--R
+--R         +------------+
+--R         | +-----+
+--R   (1)  \|\|x - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 649
+r0:=-3/8*asinh((1+2*sqrt(-1+x))/sqrt(3))+2/3*(x+sqrt(-1+x))^(3/2)-_
+   1/4*(1+2*sqrt(-1+x))*sqrt(x+sqrt(-1+x))
+--R 
+--R
+--R                              +------------+            +-----+
+--R           +-----+            | +-----+               2\|x - 1  + 1
+--R        (4\|x - 1  + 16x - 6)\|\|x - 1  + x  - 9asinh(-------------)
+--R                                                            +-+
+--R                                                           \|3
+--R   (2)  ------------------------------------------------------------
+--R                                     24
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                +------------+
+--R                   +-----+      | +-----+          +-----+
+--R       - 9log((- 8\|x - 1  - 4)\|\|x - 1  + x  - 8\|x - 1  - 8x + 3)
+--R     + 
+--R                              +------------+
+--R          +-----+             | +-----+
+--R       (8\|x - 1  + 32x - 12)\|\|x - 1  + x
+--R  /
+--R     48
+--R                                         Type: Union(Expression(Integer),...)
+--E 369
+
+--S 370 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +------------+
+--R                   +-----+      | +-----+          +-----+
+--R       - 3log((- 8\|x - 1  - 4)\|\|x - 1  + x  - 8\|x - 1  - 8x + 3)
+--R     + 
+--R                +-----+
+--R              2\|x - 1  + 1
+--R       6asinh(-------------)
+--R                    +-+
+--R                   \|3
+--R  /
+--R     16
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R              +--------------+     +------------+
+--R              |  +-----+           | +-----+
+--R          - 3\|4\|x - 1  + 4x  + 6\|\|x - 1  + x
+--R   (5)  ------------------------------------------
+--R                   +------------+ +--------------+
+--R           +-----+ | +-----+      |  +-----+
+--R        16\|x - 1 \|\|x - 1  + x \|4\|x - 1  + 4x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+)clear all
+
+--S 372 of 649
+t0:=sqrt(2*x+sqrt(-1+2*x))
+--R 
+--R
+--R         +--------------+
+--R         | +------+
+--R   (1)  \|\|2x - 1  + 2x
+--R                                                    Type: Expression(Integer)
+--E 372
+
+--S 373 of 649
+r0:=-3/16*asinh((1+2*sqrt(-1+2*x))/sqrt(3))+1/3*(2*x+sqrt(-1+2*x))^(3/2)-_
+   1/8*(1+2*sqrt(-1+2*x))*sqrt(2*x+sqrt(-1+2*x))
+--R 
+--R
+--R                               +--------------+            +------+
+--R           +------+            | +------+                2\|2x - 1  + 1
+--R        (4\|2x - 1  + 32x - 6)\|\|2x - 1  + 2x  - 9asinh(--------------)
+--R                                                               +-+
+--R                                                              \|3
+--R   (2)  ----------------------------------------------------------------
+--R                                       48
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 +--------------+
+--R                   +------+      | +------+           +------+
+--R       - 9log((- 8\|2x - 1  - 4)\|\|2x - 1  + 2x  - 8\|2x - 1  - 16x + 3)
+--R     + 
+--R                               +--------------+
+--R          +------+             | +------+
+--R       (8\|2x - 1  + 64x - 12)\|\|2x - 1  + 2x
+--R  /
+--R     96
+--R                                         Type: Union(Expression(Integer),...)
+--E 374
+
+--S 375 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +--------------+
+--R                   +------+      | +------+           +------+
+--R       - 3log((- 8\|2x - 1  - 4)\|\|2x - 1  + 2x  - 8\|2x - 1  - 16x + 3)
+--R     + 
+--R                +------+
+--R              2\|2x - 1  + 1
+--R       6asinh(--------------)
+--R                    +-+
+--R                   \|3
+--R  /
+--R     32
+--R                                                    Type: Expression(Integer)
+--E 375
+
+--S 376 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R              +---------------+     +--------------+
+--R              |  +------+           | +------+
+--R          - 3\|4\|2x - 1  + 8x  + 6\|\|2x - 1  + 2x
+--R   (5)  ----------------------------------------------
+--R                    +--------------+ +---------------+
+--R           +------+ | +------+       |  +------+
+--R        16\|2x - 1 \|\|2x - 1  + 2x \|4\|2x - 1  + 8x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+)clear all
+
+--S 377 of 649
+t0:=sqrt(3*x+sqrt(-7+8*x))
+--R 
+--R
+--R         +--------------+
+--R         | +------+
+--R   (1)  \|\|8x - 7  + 3x
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 649
+r0:=-47/36*asinh((4+3*sqrt(-7+8*x))/sqrt(47))/sqrt(6)+1/72*(21-3*(7-8*x)+_
+   8*sqrt(-7+8*x))^(3/2)/sqrt(2)-1/36*(4+3*sqrt(-7+8*x))*_
+   sqrt(21-3*(7-8*x)+8*sqrt(-7+8*x))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R                                       +----------------+
+--R         +-+ +------+             +-+  |  +------+
+--R       (\|6 \|8x - 7  + (12x - 4)\|6 )\|8\|8x - 7  + 24x
+--R     + 
+--R                       +------+
+--R            +-+      3\|8x - 7  + 4
+--R       - 47\|2 asinh(--------------)
+--R                           +--+
+--R                          \|47
+--R  /
+--R        +-+ +-+
+--R     36\|2 \|6
+--R                                                    Type: Expression(Integer)
+--E 378
+
+--S 379 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R               +-+
+--R            47\|6
+--R         *
+--R            log
+--R                                              +--------------+
+--R                       +-+ +------+      +-+  | +------+            +------+
+--R                 (- 12\|6 \|8x - 7  - 16\|6 )\|\|8x - 7  + 3x  - 48\|8x - 7
+--R               + 
+--R                 - 144x + 47
+--R     + 
+--R                                 +--------------+
+--R           +------+              | +------+
+--R       (24\|8x - 7  + 288x - 96)\|\|8x - 7  + 3x
+--R  /
+--R     432
+--R                                         Type: Union(Expression(Integer),...)
+--E 379
+
+--S 380 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R               +-+
+--R            47\|2
+--R         *
+--R            log
+--R                                              +--------------+
+--R                       +-+ +------+      +-+  | +------+            +------+
+--R                 (- 12\|6 \|8x - 7  - 16\|6 )\|\|8x - 7  + 3x  - 48\|8x - 7
+--R               + 
+--R                 - 144x + 47
+--R     + 
+--R                                            +----------------+
+--R            +-+ +------+               +-+  |  +------+
+--R       (- 2\|6 \|8x - 7  + (- 24x + 8)\|6 )\|8\|8x - 7  + 24x
+--R     + 
+--R                                                 +--------------+
+--R          +-+ +-+ +------+              +-+ +-+  | +------+
+--R       (4\|2 \|6 \|8x - 7  + (48x - 16)\|2 \|6 )\|\|8x - 7  + 3x
+--R     + 
+--R                     +------+
+--R          +-+      3\|8x - 7  + 4
+--R       94\|2 asinh(--------------)
+--R                         +--+
+--R                        \|47
+--R  /
+--R        +-+ +-+
+--R     72\|2 \|6
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                        2                 +------+         2
+--R                 ((7776x  + 4374x - 6048)\|8x - 7  + 41472x  - 43056x + 5922)
+--R              *
+--R                  +--------------+
+--R                  | +------+
+--R                 \|\|8x - 7  + 3x
+--R             + 
+--R                      2                 +-+ +------+
+--R               (12960x  - 6768x - 2016)\|6 \|8x - 7
+--R             + 
+--R                      3         2                   +-+
+--R               (15552x  + 14040x  - 36288x + 10584)\|6
+--R          *
+--R              +----------------+
+--R              |  +------+
+--R             \|8\|8x - 7  + 24x
+--R         + 
+--R                        2                  +-+ +-+ +------+
+--R               (- 25920x  + 11844x + 3280)\|2 \|6 \|8x - 7
+--R             + 
+--R                        3         2                   +-+ +-+
+--R               (- 31104x  - 28080x  + 65808x - 17220)\|2 \|6
+--R          *
+--R              +--------------+
+--R              | +------+
+--R             \|\|8x - 7  + 3x
+--R         + 
+--R                    3          2                   +-+ +------+
+--R           (- 46656x  - 109188x  + 108864x - 9635)\|2 \|8x - 7
+--R         + 
+--R                     3          2                    +-+
+--R           (- 373248x  + 276912x  + 111051x - 68880)\|2
+--R      *
+--R          +-----------------+
+--R          |   +------+
+--R         \|24\|8x - 7  + 72x
+--R     + 
+--R                                                       +--------------+
+--R                            +------+                   | +------+
+--R           ((10152x + 4512)\|8x - 7  + 40608x - 23688)\|\|8x - 7  + 3x
+--R         + 
+--R                           +-+ +------+          2                   +-+
+--R           (13536x - 2209)\|6 \|8x - 7  + (20304x  + 11421x - 15792)\|6
+--R      *
+--R          +----------------+
+--R          |  +------+
+--R         \|8\|8x - 7  + 24x
+--R  /
+--R                           +-+ +------+         2                 +-+
+--R           ((2592x - 1512)\|6 \|8x - 7  + (5184x  - 2232x - 2016)\|6 )
+--R        *
+--R            +--------------+
+--R            | +------+
+--R           \|\|8x - 7  + 3x
+--R       + 
+--R               2                 +------+         2
+--R         (7776x  + 4374x - 6048)\|8x - 7  + 41472x  - 43056x + 5922
+--R    *
+--R        +----------------+ +-----------------+
+--R        |  +------+        |   +------+
+--R       \|8\|8x - 7  + 24x \|24\|8x - 7  + 72x
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 649
+t0:=1/sqrt(x+sqrt(1+x))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         +------------+
+--R         | +-----+
+--R        \|\|x + 1  + x
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 649
+r0:=-atanh(1/2*(1+2*sqrt(1+x))/sqrt(x+sqrt(1+x)))+2*sqrt(x+sqrt(1+x))
+--R 
+--R
+--R                    +-----+           +------------+
+--R                  2\|x + 1  + 1       | +-----+
+--R   (2)  - atanh(----------------) + 2\|\|x + 1  + x
+--R                  +------------+
+--R                  | +-----+
+--R                2\|\|x + 1  + x
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         +------------+                           +------------+
+--R            +-----+      | +-----+          +-----+               | +-----+
+--R   - log((8\|x + 1  + 4)\|\|x + 1  + x  + 8\|x + 1  + 8x + 5) + 4\|\|x + 1  + x
+--R   -----------------------------------------------------------------------------
+--R                                         2
+--R                                         Type: Union(Expression(Integer),...)
+--E 384
+
+--S 385 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +------------+
+--R                +-----+      | +-----+          +-----+
+--R       - log((8\|x + 1  + 4)\|\|x + 1  + x  + 8\|x + 1  + 8x + 5)
+--R     + 
+--R                  +-----+
+--R                2\|x + 1  + 1
+--R       2atanh(----------------)
+--R                +------------+
+--R                | +-----+
+--R              2\|\|x + 1  + x
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 386
+
+)clear all
+
+--S 387 of 649
+t0:=(1+x)/(4+x+sqrt(-9+6*x))
+--R 
+--R
+--R              x + 1
+--R   (1)  -----------------
+--R         +------+
+--R        \|6x - 9  + x + 4
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 649
+r0:=x+3*log(4+x+sqrt(-9+6*x))+4*atan(1/2*(3+sqrt(-9+6*x))/sqrt(6))*sqrt(6)-_
+   2*sqrt(3)*sqrt(-3+2*x)
+--R 
+--R
+--R   (2)
+--R                                        +------+
+--R         +------+              +-+     \|6x - 9  + 3      +-+ +------+
+--R   3log(\|6x - 9  + x + 4) + 4\|6 atan(-------------) - 2\|3 \|2x - 3  + x
+--R                                             +-+
+--R                                           2\|6
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                             +------+
+--R              +------+              +-+     \|6x - 9  + 3      +------+
+--R   (3)  3log(\|6x - 9  + x + 4) + 4\|6 atan(-------------) - 2\|6x - 9  + x
+--R                                                  +-+
+--R                                                2\|6
+--R                                         Type: Union(Expression(Integer),...)
+--E 389
+
+--S 390 of 649
+m0:=a0-r0
+--R 
+--R
+--R            +------+     +-+ +------+
+--R   (4)  - 2\|6x - 9  + 2\|3 \|2x - 3
+--R                                                    Type: Expression(Integer)
+--E 390
+
+--S 391 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R          +-+ +------+     +------+
+--R        2\|3 \|6x - 9  - 6\|2x - 3
+--R   (5)  ---------------------------
+--R              +------+ +------+
+--R             \|2x - 3 \|6x - 9
+--R                                                    Type: Expression(Integer)
+--E 391
+
+)clear all
+
+--S 392 of 649
+t0:=(12-x)/(4+x+sqrt(-9+6*x))
+--R 
+--R
+--R             - x + 12
+--R   (1)  -----------------
+--R         +------+
+--R        \|6x - 9  + x + 4
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 649
+r0:=-x+10*log(4+x+sqrt(-9+6*x))-21*atan(1/2*(3+sqrt(-9+6*x))/sqrt(6))*_
+   sqrt(3/2)+2*sqrt(3)*sqrt(-3+2*x)
+--R 
+--R
+--R   (2)
+--R                                                  +------+
+--R          +-+     +------+               +-+     \|6x - 9  + 3
+--R       10\|2 log(\|6x - 9  + x + 4) - 21\|3 atan(-------------)
+--R                                                       +-+
+--R                                                     2\|6
+--R     + 
+--R         +-+ +-+ +------+     +-+
+--R       2\|2 \|3 \|2x - 3  - x\|2
+--R  /
+--R      +-+
+--R     \|2
+--R                                                    Type: Expression(Integer)
+--E 393
+
+--S 394 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                  +-+ +------+     +-+
+--R          +-+     +------+               +-+     \|2 \|6x - 9  + 3\|2
+--R       10\|2 log(\|6x - 9  + x + 4) - 21\|3 atan(---------------------)
+--R                                                           +-+
+--R                                                         4\|3
+--R     + 
+--R         +-+ +------+     +-+
+--R       2\|2 \|6x - 9  - x\|2
+--R  /
+--R      +-+
+--R     \|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 394
+
+--S 395 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +-+ +------+     +-+                +------+
+--R            +-+     \|2 \|6x - 9  + 3\|2        +-+     \|6x - 9  + 3
+--R       - 21\|3 atan(---------------------) + 21\|3 atan(-------------)
+--R                              +-+                             +-+
+--R                            4\|3                            2\|6
+--R     + 
+--R         +-+ +------+     +-+ +-+ +------+
+--R       2\|2 \|6x - 9  - 2\|2 \|3 \|2x - 3
+--R  /
+--R      +-+
+--R     \|2
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R           +-+ +-+ +-+            +------+               +-+  +------+
+--R       ((7\|2 \|3 \|6  + 4x - 26)\|2x - 3  + (- 8x + 12)\|3 )\|6x - 9
+--R     + 
+--R                  +------+        2             +-+
+--R       (24x - 36)\|2x - 3  + (- 8x  - 20x + 48)\|3
+--R  /
+--R              +------+ +------+      2             +------+
+--R     (4x - 6)\|2x - 3 \|6x - 9  + (4x  + 10x - 24)\|2x - 3
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 649
+t0:=(-1+x^3)/((1+x^2)*sqrt(x))
+--R 
+--R
+--R            3
+--R           x  - 1
+--R   (1)  ------------
+--R          2      +-+
+--R        (x  + 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 649
+r0:=2/3*x^(3/2)+atan(1-sqrt(2)*sqrt(x))*sqrt(2)-atan(1+sqrt(2)*sqrt(x))*sqrt(2)
+--R 
+--R
+--R            +-+      +-+ +-+          +-+      +-+ +-+           +-+
+--R        - 3\|2 atan(\|2 \|x  + 1) - 3\|2 atan(\|2 \|x  - 1) + 2x\|x
+--R   (2)  ------------------------------------------------------------
+--R                                      3
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +-+ +-+
+--R          +-+     \|2 \|x        +-+
+--R        3\|2 atan(--------) + 2x\|x
+--R                    x - 1
+--R   (3)  ----------------------------
+--R                      3
+--R                                         Type: Union(Expression(Integer),...)
+--E 399
+
+--S 400 of 649
+m0:=a0-r0
+--R 
+--R
+--R                                                                    +-+ +-+
+--R         +-+      +-+ +-+         +-+      +-+ +-+         +-+     \|2 \|x
+--R   (4)  \|2 atan(\|2 \|x  + 1) + \|2 atan(\|2 \|x  - 1) + \|2 atan(--------)
+--R                                                                     x - 1
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 401
+
+)clear all
+
+--S 402 of 649
+t0:=1/2/(sqrt(-1+x)*sqrt(x-sqrt(-1+x)))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                  +--------------+
+--R          +-----+ |   +-----+
+--R        2\|x - 1 \|- \|x - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 402
+
+--S 403 of 649
+r0:=-asinh((1-2*sqrt(-1+x))/sqrt(3))
+--R 
+--R
+--R                +-----+
+--R              2\|x - 1  - 1
+--R   (2)  asinh(-------------)
+--R                    +-+
+--R                   \|3
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                              +--------------+
+--R                 +-----+      |   +-----+          +-----+
+--R          log((8\|x - 1  - 4)\|- \|x - 1  + x  + 8\|x - 1  - 8x + 3)
+--R   (3)  - ----------------------------------------------------------
+--R                                       2
+--R                                         Type: Union(Expression(Integer),...)
+--E 404
+
+--S 405 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +--------------+
+--R                +-----+      |   +-----+          +-----+
+--R       - log((8\|x - 1  - 4)\|- \|x - 1  + x  + 8\|x - 1  - 8x + 3)
+--R     + 
+--R                  +-----+
+--R                2\|x - 1  - 1
+--R       - 2asinh(-------------)
+--R                      +-+
+--R                     \|3
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 405
+
+--S 406 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R              +--------------+    +----------------+
+--R              |   +-----+         |    +-----+
+--R          - 2\|- \|x - 1  + x  + \|- 4\|x - 1  + 4x
+--R   (5)  ---------------------------------------------
+--R                  +----------------+ +--------------+
+--R          +-----+ |    +-----+       |   +-----+
+--R        2\|x - 1 \|- 4\|x - 1  + 4x \|- \|x - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+)clear all
+
+--S 407 of 649
+t0:=(1+x^(7/2))/(1-x^2)
+--R 
+--R
+--R           3 +-+
+--R        - x \|x  - 1
+--R   (1)  ------------
+--R            2
+--R           x  - 1
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 649
+r0:=-2/5*x^(5/2)+atan(sqrt(x))+atanh(x)+atanh(sqrt(x))-2*sqrt(x)
+--R 
+--R
+--R                +-+           +-+         2       +-+
+--R        5atanh(\|x ) + 5atan(\|x ) + (- 2x  - 10)\|x  + 5atanh(x)
+--R   (2)  ---------------------------------------------------------
+--R                                    5
+--R                                                    Type: Expression(Integer)
+--E 408
+
+--S 409 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-+                +-+         2       +-+
+--R        - 10log(\|x  - 1) + 10atan(\|x ) + (- 4x  - 20)\|x  + 5log(x + 1)
+--R   (3)  -----------------------------------------------------------------
+--R                                        10
+--R                                         Type: Union(Expression(Integer),...)
+--E 409
+
+--S 410 of 649
+m0:=a0-r0
+--R 
+--R
+--R                +-+                +-+
+--R        - 2log(\|x  - 1) - 2atanh(\|x ) + log(x + 1) - 2atanh(x)
+--R   (4)  --------------------------------------------------------
+--R                                    2
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 649
+t0:=(4+2*x)/((-1+2*x)^(1/3)+sqrt(-1+2*x))
+--R 
+--R
+--R                2x + 4
+--R   (1)  ---------------------
+--R        3+------+    +------+
+--R        \|2x - 1  + \|2x - 1
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 649
+r0:=-x+18*(-1+2*x)^(1/6)-9*(-1+2*x)^(1/3)-3/4*(-1+2*x)^(2/3)+_
+   3/5*(-1+2*x)^(5/6)+3/7*(-1+2*x)^(7/6)-3/8*(-1+2*x)^(4/3)+_
+   1/3*(-1+2*x)^(3/2)-18*log(1+(-1+2*x)^(1/6))+6*sqrt(-1+2*x)
+--R 
+--R
+--R   (2)
+--R                  6+------+           6+------+5                 6+------+
+--R       - 15120log(\|2x - 1  + 1) + 504\|2x - 1   + (720x + 14760)\|2x - 1
+--R     + 
+--R          3+------+2                  3+------+                 +------+
+--R     - 630\|2x - 1   + (- 630x - 7245)\|2x - 1  + (560x + 4760)\|2x - 1  - 840x
+--R  /
+--R     840
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  6+------+           6+------+5      6+------+4
+--R       - 15120log(\|2x - 1  + 1) + 504\|2x - 1   - 630\|2x - 1
+--R     + 
+--R                    6+------+3                  6+------+2
+--R       (560x + 4760)\|2x - 1   + (- 630x - 7245)\|2x - 1
+--R     + 
+--R                     6+------+
+--R       (720x + 14760)\|2x - 1  - 840x
+--R  /
+--R     840
+--R                                         Type: Union(Expression(Integer),...)
+--E 414
+
+--S 415 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           6+------+4              6+------+3                6+------+2
+--R       - 18\|2x - 1   + (16x + 136)\|2x - 1   + (- 18x - 207)\|2x - 1
+--R     + 
+--R         3+------+2              3+------+                 +------+
+--R       18\|2x - 1   + (18x + 207)\|2x - 1  + (- 16x - 136)\|2x - 1
+--R  /
+--R     24
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  3+------+2    +------+3+------+            +------+ 6+------+4
+--R       ((- 2x - 5)\|2x - 1   + \|2x - 1 \|2x - 1  + (2x + 5)\|2x - 1 )\|2x - 1
+--R     + 
+--R          +------+3+------+2 6+------+2           +------+3+------+2 6+------+
+--R       - \|2x - 1 \|2x - 1   \|2x - 1  + (2x + 5)\|2x - 1 \|2x - 1   \|2x - 1
+--R     + 
+--R                  +------+3+------+2
+--R       (- 2x - 5)\|2x - 1 \|2x - 1
+--R  /
+--R      +------+3+------+2 6+------+4
+--R     \|2x - 1 \|2x - 1   \|2x - 1
+--R                                                    Type: Expression(Integer)
+--E 416
+
+)clear all
+
+--S 417 of 649
+t0:=1/sqrt(2+sqrt(1+sqrt(x)))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         | +--------+
+--R         | | +-+
+--R        \|\|\|x  + 1  + 2
+--R                                                    Type: Expression(Integer)
+--E 417
+
+--S 418 of 649
+r0:=88/3*(2+sqrt(1+sqrt(x)))^(3/2)-48/5*(2+sqrt(1+sqrt(x)))^(5/2)+_
+   8/7*(2+sqrt(1+sqrt(x)))^(7/2)-48*sqrt(2+sqrt(1+sqrt(x)))
+--R 
+--R
+--R                                                      +---------------+
+--R                         +--------+                   | +--------+
+--R              +-+        | +-+            +-+         | | +-+
+--R        ((120\|x  + 608)\|\|x  + 1  - 288\|x  - 2240)\|\|\|x  + 1  + 2
+--R   (2)  ---------------------------------------------------------------
+--R                                      105
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                      +---------------+
+--R                         +--------+                   | +--------+
+--R              +-+        | +-+            +-+         | | +-+
+--R        ((120\|x  + 608)\|\|x  + 1  - 288\|x  - 2240)\|\|\|x  + 1  + 2
+--R   (3)  ---------------------------------------------------------------
+--R                                      105
+--R                                         Type: Union(Expression(Integer),...)
+--E 419
+
+--S 420 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+--S 421 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 421
+
+)clear all
+
+--S 422 of 649
+t0:=sqrt(2+sqrt(4+sqrt(x)))
+--R 
+--R
+--R         +---------------+
+--R         | +--------+
+--R         | | +-+
+--R   (1)  \|\|\|x  + 4  + 2
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 649
+r0:=64/5*(2+sqrt(4+sqrt(x)))^(5/2)-48/7*(2+sqrt(4+sqrt(x)))^(7/2)+_
+   8/9*(2+sqrt(4+sqrt(x)))^(9/2)
+--R 
+--R
+--R                                                           +---------------+
+--R                        +--------+                         | +--------+
+--R             +-+        | +-+           +-+                | | +-+
+--R        ((80\|x  - 512)\|\|x  + 4  + 32\|x  + 280x - 1024)\|\|\|x  + 4  + 2
+--R   (2)  --------------------------------------------------------------------
+--R                                         315
+--R                                                    Type: Expression(Integer)
+--E 423
+
+--S 424 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                           +---------------+
+--R                        +--------+                         | +--------+
+--R             +-+        | +-+           +-+                | | +-+
+--R        ((80\|x  - 512)\|\|x  + 4  + 32\|x  + 280x - 1024)\|\|\|x  + 4  + 2
+--R   (3)  --------------------------------------------------------------------
+--R                                         315
+--R                                         Type: Union(Expression(Integer),...)
+--E 424
+
+--S 425 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 649
+t0:=sqrt(2-sqrt(4+sqrt(-9+5*x)))
+--R 
+--R
+--R         +----------------------+
+--R         |   +-------------+
+--R         |   | +------+
+--R   (1)  \|- \|\|5x - 9  + 4  + 2
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 649
+r0:=64/25*(2-sqrt(4+sqrt(-9+5*x)))^(5/2)-_
+   48/35*(2-sqrt(4+sqrt(-9+5*x)))^(7/2)+8/45*(2-sqrt(4+sqrt(-9+5*x)))^(9/2)
+--R 
+--R
+--R   (2)
+--R                              +-------------+
+--R              +------+        | +------+           +------+
+--R       ((- 80\|5x - 9  + 512)\|\|5x - 9  + 4  + 32\|5x - 9  + 1400x - 3544)
+--R    *
+--R        +----------------------+
+--R        |   +-------------+
+--R        |   | +------+
+--R       \|- \|\|5x - 9  + 4  + 2
+--R  /
+--R     1575
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                              +-------------+
+--R              +------+        | +------+           +------+
+--R       ((- 80\|5x - 9  + 512)\|\|5x - 9  + 4  + 32\|5x - 9  + 1400x - 3544)
+--R    *
+--R        +----------------------+
+--R        |   +-------------+
+--R        |   | +------+
+--R       \|- \|\|5x - 9  + 4  + 2
+--R  /
+--R     1575
+--R                                         Type: Union(Expression(Integer),...)
+--E 429
+
+--S 430 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 431
+
+)clear all
+
+--S 432 of 649
+t0:=1/sqrt(2+sqrt(1+sqrt(x)))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         | +--------+
+--R         | | +-+
+--R        \|\|\|x  + 1  + 2
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 649
+r0:=88/3*(2+sqrt(1+sqrt(x)))^(3/2)-48/5*(2+sqrt(1+sqrt(x)))^(5/2)+_
+   8/7*(2+sqrt(1+sqrt(x)))^(7/2)-48*sqrt(2+sqrt(1+sqrt(x)))
+--R 
+--R
+--R                                                      +---------------+
+--R                         +--------+                   | +--------+
+--R              +-+        | +-+            +-+         | | +-+
+--R        ((120\|x  + 608)\|\|x  + 1  - 288\|x  - 2240)\|\|\|x  + 1  + 2
+--R   (2)  ---------------------------------------------------------------
+--R                                      105
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                      +---------------+
+--R                         +--------+                   | +--------+
+--R              +-+        | +-+            +-+         | | +-+
+--R        ((120\|x  + 608)\|\|x  + 1  - 288\|x  - 2240)\|\|\|x  + 1  + 2
+--R   (3)  ---------------------------------------------------------------
+--R                                      105
+--R                                         Type: Union(Expression(Integer),...)
+--E 434
+
+--S 435 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+--S 436 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 436
+
+)clear all
+
+--S 437 of 649
+t0:=sqrt(1+sqrt(1+sqrt(1+sqrt(x))))
+--R 
+--R
+--R         +----------------------+
+--R         | +---------------+
+--R         | | +--------+
+--R         | | | +-+
+--R   (1)  \|\|\|\|x  + 1  + 1  + 1
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 649
+r0:=-32/5*(1+sqrt(1+sqrt(1+sqrt(x))))^(5/2)+48/7*(1+sqrt(1+sqrt(1+_
+   sqrt(x))))^(7/2)+112/9*(1+sqrt(1+sqrt(1+sqrt(x))))^(9/2)-_
+   320/11*(1+sqrt(1+sqrt(1+sqrt(x))))^(11/2)+288/13*(1+sqrt(1+_
+   sqrt(1+sqrt(x))))^(13/2)-112/15*(1+sqrt(1+sqrt(1+sqrt(x))))^(15/2)+_
+   16/17*(1+sqrt(1+sqrt(1+sqrt(x))))^(17/2)
+--R 
+--R
+--R   (2)
+--R                                                               +---------------+
+--R                              +--------+                       | +--------+
+--R                 +-+          | +-+              +-+           | | +-+
+--R         ((48048\|x  - 74752)\|\|x  + 1  - 56448\|x  + 140032)\|\|\|x  + 1  + 1
+--R       + 
+--R                            +--------+
+--R               +-+          | +-+              +-+
+--R         (3696\|x  - 20864)\|\|x  + 1  + 73808\|x  + 720720x - 450432
+--R    *
+--R        +----------------------+
+--R        | +---------------+
+--R        | | +--------+
+--R        | | | +-+
+--R       \|\|\|\|x  + 1  + 1  + 1
+--R  /
+--R     765765
+--R                                                    Type: Expression(Integer)
+--E 438
+
+--S 439 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                               +---------------+
+--R                              +--------+                       | +--------+
+--R                 +-+          | +-+              +-+           | | +-+
+--R         ((48048\|x  - 74752)\|\|x  + 1  - 56448\|x  + 140032)\|\|\|x  + 1  + 1
+--R       + 
+--R                            +--------+
+--R               +-+          | +-+              +-+
+--R         (3696\|x  - 20864)\|\|x  + 1  + 73808\|x  + 720720x - 450432
+--R    *
+--R        +----------------------+
+--R        | +---------------+
+--R        | | +--------+
+--R        | | | +-+
+--R       \|\|\|\|x  + 1  + 1  + 1
+--R  /
+--R     765765
+--R                                         Type: Union(Expression(Integer),...)
+--E 439
+
+--S 440 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 649
+t0:=sqrt(2+sqrt(3+sqrt(-1+2*sqrt(x))))
+--R 
+--R
+--R         +-----------------------+
+--R         | +----------------+
+--R         | | +---------+
+--R         | | |  +-+
+--R   (1)  \|\|\|2\|x  - 1  + 3  + 2
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 649
+r0:=-16/3*(2+sqrt(3+sqrt(-1+2*sqrt(x))))^(3/2)+136/5*(2+sqrt(3+_
+   sqrt(-1+2*sqrt(x))))^(5/2)-480/7*(2+sqrt(3+sqrt(-1+2*sqrt(x))))^(7/2)+_
+   304/3*(2+sqrt(3+sqrt(-1+2*sqrt(x))))^(9/2)-760/11*(2+sqrt(3+_
+   sqrt(-1+2*sqrt(x))))^(11/2)+300/13*(2+sqrt(3+sqrt(-1+_
+   2*sqrt(x))))^(13/2)-56/15*(2+sqrt(3+sqrt(-1+2*sqrt(x))))^(15/2)+_
+   4/17*(2+sqrt(3+sqrt(-1+2*sqrt(x))))^(17/2)
+--R 
+--R
+--R   (2)
+--R                                 +---------+
+--R                   +-+           |  +-+              +-+
+--R           ((16016\|x  + 108800)\|2\|x  - 1  - 37632\|x  - 475392)
+--R        *
+--R            +----------------+
+--R            | +---------+
+--R            | |  +-+
+--R           \|\|2\|x  - 1  + 3
+--R       + 
+--R                              +---------+
+--R                 +-+          |  +-+              +-+
+--R         (- 6776\|x  + 13504)\|2\|x  - 1  - 30744\|x  + 240240x - 992640
+--R    *
+--R        +-----------------------+
+--R        | +----------------+
+--R        | | +---------+
+--R        | | |  +-+
+--R       \|\|\|2\|x  - 1  + 3  + 2
+--R  /
+--R     255255
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 +---------+
+--R                   +-+           |  +-+              +-+
+--R           ((16016\|x  + 108800)\|2\|x  - 1  - 37632\|x  - 475392)
+--R        *
+--R            +----------------+
+--R            | +---------+
+--R            | |  +-+
+--R           \|\|2\|x  - 1  + 3
+--R       + 
+--R                              +---------+
+--R                 +-+          |  +-+              +-+
+--R         (- 6776\|x  + 13504)\|2\|x  - 1  - 30744\|x  + 240240x - 992640
+--R    *
+--R        +-----------------------+
+--R        | +----------------+
+--R        | | +---------+
+--R        | | |  +-+
+--R       \|\|\|2\|x  - 1  + 3  + 2
+--R  /
+--R     255255
+--R                                         Type: Union(Expression(Integer),...)
+--E 444
+
+--S 445 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 446
+
+)clear all
+
+--S 447 of 649
+t0:=x*sqrt(1+sqrt(1+sqrt(-1+x)))
+--R 
+--R
+--R          +-------------------+
+--R          | +------------+
+--R          | | +-----+
+--R   (1)  x\|\|\|x - 1  + 1  + 1
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 649
+r0:=16/5*(1+sqrt(1+sqrt(-1+x)))^(5/2)-24/7*(1+sqrt(1+sqrt(-1+x)))^(7/2)+_
+   8*(1+sqrt(1+sqrt(-1+x)))^(9/2)-160/11*(1+sqrt(1+sqrt(-1+x)))^(11/2)+_
+   144/13*(1+sqrt(1+sqrt(-1+x)))^(13/2)-56/15*(1+sqrt(1+_
+   sqrt(-1+x)))^(15/2)+8/17*(1+sqrt(1+sqrt(-1+x)))^(17/2)
+--R 
+--R
+--R   (2)
+--R                                                   +------------+
+--R                          +-----+                  | +-----+
+--R         ((8008x + 36352)\|x - 1  - 9408x - 61568)\|\|x - 1  + 1
+--R       + 
+--R                       +-----+          2
+--R         (616x + 8256)\|x - 1  + 120120x  - 14392x - 176704
+--R    *
+--R        +-------------------+
+--R        | +------------+
+--R        | | +-----+
+--R       \|\|\|x - 1  + 1  + 1
+--R  /
+--R     255255
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                   +------------+
+--R                          +-----+                  | +-----+
+--R         ((8008x + 36352)\|x - 1  - 9408x - 61568)\|\|x - 1  + 1
+--R       + 
+--R                       +-----+          2
+--R         (616x + 8256)\|x - 1  + 120120x  - 14392x - 176704
+--R    *
+--R        +-------------------+
+--R        | +------------+
+--R        | | +-----+
+--R       \|\|\|x - 1  + 1  + 1
+--R  /
+--R     255255
+--R                                         Type: Union(Expression(Integer),...)
+--E 449
+
+--S 450 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+--S 451 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 451
+
+)clear all
+
+--S 452 of 649
+t0:=1/(sqrt(-1+x)*sqrt(x-sqrt(-1+x)))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R                 +--------------+
+--R         +-----+ |   +-----+
+--R        \|x - 1 \|- \|x - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 649
+r0:=-2*asinh((1-2*sqrt(-1+x))/sqrt(3))
+--R 
+--R
+--R                 +-----+
+--R               2\|x - 1  - 1
+--R   (2)  2asinh(-------------)
+--R                     +-+
+--R                    \|3
+--R                                                    Type: Expression(Integer)
+--E 453
+
+--S 454 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                              +--------------+
+--R                 +-----+      |   +-----+          +-----+
+--R   (3)  - log((8\|x - 1  - 4)\|- \|x - 1  + x  + 8\|x - 1  - 8x + 3)
+--R                                         Type: Union(Expression(Integer),...)
+--E 454
+
+--S 455 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           +--------------+
+--R              +-----+      |   +-----+          +-----+
+--R     - log((8\|x - 1  - 4)\|- \|x - 1  + x  + 8\|x - 1  - 8x + 3)
+--R   + 
+--R                +-----+
+--R              2\|x - 1  - 1
+--R     - 2asinh(-------------)
+--R                    +-+
+--R                   \|3
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R             +--------------+    +----------------+
+--R             |   +-----+         |    +-----+
+--R         - 2\|- \|x - 1  + x  + \|- 4\|x - 1  + 4x
+--R   (5)  --------------------------------------------
+--R                 +----------------+ +--------------+
+--R         +-----+ |    +-----+       |   +-----+
+--R        \|x - 1 \|- 4\|x - 1  + 4x \|- \|x - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 649
+t0:=1/sqrt(1+x+sqrt(-1+2*x))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-----------------+
+--R         | +------+
+--R        \|\|2x - 1  + x + 1
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 649
+r0a:=-asinh((1+sqrt(-1+2*x))/sqrt(2))*sqrt(2)+2*sqrt(1+x+sqrt(-1+2*x))
+--R 
+--R
+--R          +-----------------+              +------+
+--R          | +------+             +-+      \|2x - 1  + 1
+--R   (2)  2\|\|2x - 1  + x + 1  - \|2 asinh(-------------)
+--R                                                +-+
+--R                                               \|2
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 649
+r0b:=-asinh((1+sqrt(-1+2*x))/sqrt(2))*sqrt(2)+_
+   sqrt(2)*sqrt(2+2*x+2*sqrt(-1+2*x))
+--R 
+--R
+--R             +-------------------+              +------+
+--R         +-+ |  +------+              +-+      \|2x - 1  + 1
+--R   (3)  \|2 \|2\|2x - 1  + 2x + 2  - \|2 asinh(-------------)
+--R                                                     +-+
+--R                                                    \|2
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R       -
+--R             +-+
+--R            \|2
+--R         *
+--R                                     +-----------------+
+--R                +-+ +------+    +-+  | +------+              +------+
+--R          log((\|2 \|2x - 1  + \|2 )\|\|2x - 1  + x + 1  + 2\|2x - 1  + 2x + 1)
+--R     + 
+--R         +-----------------+
+--R         | +------+
+--R       4\|\|2x - 1  + x + 1
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 460
+
+--S 461 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R       -
+--R             +-+
+--R            \|2
+--R         *
+--R                                     +-----------------+
+--R                +-+ +------+    +-+  | +------+              +------+
+--R          log((\|2 \|2x - 1  + \|2 )\|\|2x - 1  + x + 1  + 2\|2x - 1  + 2x + 1)
+--R     + 
+--R                   +------+
+--R         +-+      \|2x - 1  + 1
+--R       2\|2 asinh(-------------)
+--R                        +-+
+--R                       \|2
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R       -
+--R             +-+
+--R            \|2
+--R         *
+--R                                     +-----------------+
+--R                +-+ +------+    +-+  | +------+              +------+
+--R          log((\|2 \|2x - 1  + \|2 )\|\|2x - 1  + x + 1  + 2\|2x - 1  + 2x + 1)
+--R     + 
+--R               +-------------------+     +-----------------+
+--R           +-+ |  +------+               | +------+
+--R       - 2\|2 \|2\|2x - 1  + 2x + 2  + 4\|\|2x - 1  + x + 1
+--R     + 
+--R                   +------+
+--R         +-+      \|2x - 1  + 1
+--R       2\|2 asinh(-------------)
+--R                        +-+
+--R                       \|2
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)
+--R                                                         +-----------------+
+--R               2           +-+ +------+      2      +-+  | +------+
+--R           ((2x  + 6x - 2)\|2 \|2x - 1  + (8x  - 2)\|2 )\|\|2x - 1  + x + 1
+--R         + 
+--R               2           +------+     3      2
+--R           (10x  + 9x - 4)\|2x - 1  + 4x  + 20x  - 7x - 2
+--R      *
+--R          +-------------------+
+--R          |  +------+
+--R         \|2\|2x - 1  + 2x + 2
+--R     + 
+--R                2           +-+ +------+        3      2           +-+
+--R         ((- 10x  - 9x + 4)\|2 \|2x - 1  + (- 4x  - 20x  + 7x + 2)\|2 )
+--R      *
+--R          +-----------------+
+--R          | +------+
+--R         \|\|2x - 1  + x + 1
+--R     + 
+--R            3      2           +------+      3      2
+--R       (- 4x  - 32x  - 8x + 8)\|2x - 1  - 24x  - 36x  + 24x
+--R  /
+--R                                                         +-----------------+
+--R             2           +------+     3      2           | +------+
+--R         ((8x  + 2x - 3)\|2x - 1  + 4x  + 12x  - 9x + 1)\|\|2x - 1  + x + 1
+--R       + 
+--R            3      2           +-+ +------+       3     2            +-+
+--R         (2x  + 11x  - 2x - 2)\|2 \|2x - 1  + (10x  + 7x  - 10x + 2)\|2
+--R    *
+--R        +-------------------+
+--R        |  +------+
+--R       \|2\|2x - 1  + 2x + 2
+--R                                                    Type: Expression(Integer)
+--E 464
+
+)clear all
+
+--S 465 of 649
+t0:=(q+p*x)/(sqrt(b+a*x)*(f+sqrt(b+a*x)))
+--R 
+--R
+--R               p x + q
+--R   (1)  ---------------------
+--R          +-------+
+--R        f\|a x + b  + a x + b
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 649
+r0:=p*x/a-2*(b*p-f^2*p-a*q)*log(f+sqrt(b+a*x))/a^2-2*f*p*sqrt(b+a*x)/a^2
+--R 
+--R
+--R                   2             +-------+             +-------+
+--R        (2a q + (2f  - 2b)p)log(\|a x + b  + f) - 2f p\|a x + b  + a p x
+--R   (2)  ----------------------------------------------------------------
+--R                                        2
+--R                                       a
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   2             +-------+             +-------+
+--R        (2a q + (2f  - 2b)p)log(\|a x + b  + f) - 2f p\|a x + b  + a p x
+--R   (3)  ----------------------------------------------------------------
+--R                                        2
+--R                                       a
+--R                                         Type: Union(Expression(Integer),...)
+--E 467
+
+--S 468 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+--S 469 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 469
+
+)clear all
+
+--S 470 of 649
+t0:=sqrt(1-x-sqrt(x))
+--R 
+--R
+--R         +--------------+
+--R         |   +-+
+--R   (1)  \|- \|x  - x + 1
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 649
+r0:=-5/8*asin((1+2*sqrt(x))/sqrt(5))-2/3*(1-x-sqrt(x))^(3/2)-_
+   1/4*(1+2*sqrt(x))*sqrt(1-x-sqrt(x))
+--R 
+--R
+--R                           +--------------+            +-+
+--R           +-+             |   +-+                   2\|x  + 1
+--R        (4\|x  + 16x - 22)\|- \|x  - x + 1  - 15asin(---------)
+--R                                                         +-+
+--R                                                        \|5
+--R   (2)  -------------------------------------------------------
+--R                                   24
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +-+                                       +--------------+
+--R                   8\|x  + 8x - 3              +-+             |   +-+
+--R   - 15atan(----------------------------) + (8\|x  + 32x - 44)\|- \|x  - x + 1
+--R                        +--------------+
+--R               +-+      |   +-+
+--R            (8\|x  + 4)\|- \|x  - x + 1
+--R   ----------------------------------------------------------------------------
+--R                                        48
+--R                                         Type: Union(Expression(Integer),...)
+--E 472
+
+--S 473 of 649
+m0:=a0-r0
+--R 
+--R
+--R                         +-+                             +-+
+--R                       8\|x  + 8x - 3                  2\|x  + 1
+--R        - 5atan(----------------------------) + 10asin(---------)
+--R                            +--------------+               +-+
+--R                   +-+      |   +-+                       \|5
+--R                (8\|x  + 4)\|- \|x  - x + 1
+--R   (4)  ---------------------------------------------------------
+--R                                    16
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                            +--------------+
+--R            2             +-+      2        |   +-+
+--R       ((40x  + 10x - 10)\|x  + 80x  - 30x)\|- \|x  - x + 1
+--R     + 
+--R                                            +----------------+
+--R              2           +-+      2        |    +-+
+--R       ((- 20x  - 5x + 5)\|x  - 40x  + 15x)\|- 4\|x  - 4x + 4
+--R  /
+--R                                             +----------------+ +--------------+
+--R           2        +-+      3      2        |    +-+           |   +-+
+--R     ((128x  - 48x)\|x  + 64x  + 16x  - 16x)\|- 4\|x  - 4x + 4 \|- \|x  - x + 1
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 649
+t0:=(9+x+6*sqrt(x))/(x+4*sqrt(x))
+--R 
+--R
+--R          +-+
+--R        6\|x  + x + 9
+--R   (1)  -------------
+--R            +-+
+--R          4\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 649
+r0:=x+2*log(4+sqrt(x))+4*sqrt(x)
+--R 
+--R
+--R              +-+          +-+
+--R   (2)  2log(\|x  + 4) + 4\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +-+          +-+
+--R   (3)  2log(\|x  + 4) + 4\|x  + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 477
+
+--S 478 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 479
+
+)clear all
+
+--S 480 of 649
+t0:=(6-8*x^(7/2))/(5-9*sqrt(x))
+--R 
+--R
+--R          3 +-+
+--R        8x \|x  - 6
+--R   (1)  -----------
+--R           +-+
+--R         9\|x  - 5
+--R                                                    Type: Expression(Integer)
+--E 480
+
+--S 481 of 649
+r0:=125000/4782969*x+50000/1594323*x^(3/2)+2500/59049*x^2+400/6561*x^(5/2)+_
+   200/2187*x^3+80/567*x^(7/2)+2/9*x^4-280728140/387420489*log(5-9*sqrt(x))-_
+   56145628/43046721*sqrt(x)
+--R 
+--R
+--R   (2)
+--R                           +-+
+--R       - 1965096980log(- 9\|x  + 5)
+--R     + 
+--R                  3             2                           +-+             4
+--R       (382637520x  + 165337200x  + 85050000x - 3537174564)\|x  + 602654094x
+--R     + 
+--R                 3             2
+--R       248005800x  + 114817500x  + 70875000x
+--R  /
+--R     2711943423
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         +-+
+--R       - 1965096980log(9\|x  - 5)
+--R     + 
+--R                  3             2                           +-+             4
+--R       (382637520x  + 165337200x  + 85050000x - 3537174564)\|x  + 602654094x
+--R     + 
+--R                 3             2
+--R       248005800x  + 114817500x  + 70875000x
+--R  /
+--R     2711943423
+--R                                         Type: Union(Expression(Integer),...)
+--E 482
+
+--S 483 of 649
+m0:=a0-r0
+--R 
+--R
+--R                         +-+                         +-+
+--R        - 280728140log(9\|x  - 5) + 280728140log(- 9\|x  + 5)
+--R   (4)  -----------------------------------------------------
+--R                              387420489
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 484
+
+)clear all
+
+--S 485 of 649
+t0:=(1+x^3)*sqrt(1+x)/(1+x^2)
+--R 
+--R
+--R          3      +-----+
+--R        (x  + 1)\|x + 1
+--R   (1)  ----------------
+--R              2
+--R             x  + 1
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 649
+r0a:=-2/3*(1+x)^(3/2)+2/5*(1+x)^(5/2)+(1-%i)^(3/2)*atanh(sqrt(1+x)/_
+   sqrt(1-%i))+(1+%i)^(3/2)*atanh(sqrt(1+x)/sqrt(1+%i))-2*sqrt(1+x)
+--R 
+--R
+--R   (2)
+--R                                   +-----+
+--R                   +------+       \|x + 1
+--R       (15 - 15%i)\|1 - %i atanh(---------)
+--R                                  +------+
+--R                                 \|1 - %i
+--R     + 
+--R                                   +-----+
+--R                   +------+       \|x + 1        2            +-----+
+--R       (15 + 15%i)\|1 + %i atanh(---------) + (6x  + 2x - 34)\|x + 1
+--R                                  +------+
+--R                                 \|1 + %i
+--R  /
+--R     15
+--R                                           Type: Expression(Complex(Integer))
+--E 486
+
+--S 487 of 649
+r0b:=-2/3*(1+x)^(3/2)+2/5*(1+x)^(5/2)-2*sqrt(1+x)-1/2*log(1+x+sqrt(2)-_
+   sqrt(1+x)*sqrt(2*(1+sqrt(2))))/sqrt(1+sqrt(2))+1/2*log(1+x+sqrt(2)+_
+   sqrt(1+x)*sqrt(2*(1+sqrt(2))))/sqrt(1+sqrt(2))-atan((-2*sqrt(1+x)+_
+   sqrt(2*(1+sqrt(2))))/sqrt(2*(-1+sqrt(2))))*sqrt(1+sqrt(2))+_
+   atan((2*sqrt(1+x)+sqrt(2*(1+sqrt(2))))/sqrt(2*(-1+sqrt(2))))*_
+   sqrt(1+sqrt(2))
+--R 
+--R
+--R   (3)
+--R                      +---------+
+--R              +-----+ |  +-+         +-+
+--R       15log(\|x + 1 \|2\|2  + 2  + \|2  + x + 1)
+--R     + 
+--R                          +---------+
+--R                  +-----+ |  +-+         +-+
+--R       - 15log(- \|x + 1 \|2\|2  + 2  + \|2  + x + 1)
+--R     + 
+--R                          +---------+
+--R                          |  +-+          +-----+
+--R           +-+           \|2\|2  + 2  + 2\|x + 1
+--R       (30\|2  + 30)atan(------------------------)
+--R                                +---------+
+--R                                |  +-+
+--R                               \|2\|2  - 2
+--R     + 
+--R                            +---------+
+--R                            |  +-+          +-----+
+--R             +-+           \|2\|2  + 2  - 2\|x + 1
+--R       (- 30\|2  - 30)atan(------------------------)
+--R                                  +---------+
+--R                                  |  +-+
+--R                                 \|2\|2  - 2
+--R     + 
+--R                                +--------+
+--R           2            +-----+ | +-+
+--R       (12x  + 4x - 68)\|x + 1 \|\|2  + 1
+--R  /
+--R        +--------+
+--R        | +-+
+--R     30\|\|2  + 1
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R       -
+--R              4+-+    %pi
+--R            15\|8 cos(---)
+--R                       8
+--R         *
+--R            log
+--R                   4+-+    %pi     4+-+    %pi   +-----+   4+-+2    %pi 2
+--R                 (2\|8 sin(---) - 2\|8 cos(---))\|x + 1  + \|8  sin(---)
+--R                            8               8                        8
+--R               + 
+--R                 4+-+2    %pi 2
+--R                 \|8  cos(---)  + 2x + 2
+--R                           8
+--R     + 
+--R           4+-+    %pi
+--R         15\|8 cos(---)
+--R                    8
+--R      *
+--R         log
+--R                  4+-+    %pi     4+-+    %pi   +-----+   4+-+2    %pi 2
+--R              (- 2\|8 sin(---) + 2\|8 cos(---))\|x + 1  + \|8  sin(---)
+--R                           8               8                        8
+--R            + 
+--R              4+-+2    %pi 2
+--R              \|8  cos(---)  + 2x + 2
+--R                        8
+--R     + 
+--R                                  4+-+    %pi    4+-+    %pi
+--R                                  \|8 sin(---) + \|8 cos(---)
+--R           4+-+    %pi                     8              8
+--R       - 30\|8 sin(---)atan(---------------------------------------)
+--R                    8         +-----+   4+-+    %pi    4+-+    %pi
+--R                            2\|x + 1  - \|8 sin(---) + \|8 cos(---)
+--R                                                 8              8
+--R     + 
+--R                                  4+-+    %pi    4+-+    %pi
+--R                                  \|8 sin(---) + \|8 cos(---)
+--R           4+-+    %pi                     8              8
+--R       - 30\|8 sin(---)atan(---------------------------------------)
+--R                    8         +-----+   4+-+    %pi    4+-+    %pi
+--R                            2\|x + 1  + \|8 sin(---) - \|8 cos(---)
+--R                                                 8              8
+--R     + 
+--R           2            +-----+
+--R       (12x  + 4x - 68)\|x + 1
+--R  /
+--R     30
+--R                                         Type: Union(Expression(Integer),...)
+--E 488
+
+--S 489 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R       -
+--R            4+-+    %pi
+--R            \|8 cos(---)
+--R                     8
+--R         *
+--R            log
+--R                   4+-+    %pi     4+-+    %pi   +-----+   4+-+2    %pi 2
+--R                 (2\|8 sin(---) - 2\|8 cos(---))\|x + 1  + \|8  sin(---)
+--R                            8               8                        8
+--R               + 
+--R                 4+-+2    %pi 2
+--R                 \|8  cos(---)  + 2x + 2
+--R                           8
+--R     + 
+--R         4+-+    %pi
+--R         \|8 cos(---)
+--R                  8
+--R      *
+--R         log
+--R                  4+-+    %pi     4+-+    %pi   +-----+   4+-+2    %pi 2
+--R              (- 2\|8 sin(---) + 2\|8 cos(---))\|x + 1  + \|8  sin(---)
+--R                           8               8                        8
+--R            + 
+--R              4+-+2    %pi 2
+--R              \|8  cos(---)  + 2x + 2
+--R                        8
+--R     + 
+--R                                   +-----+
+--R                   +------+       \|x + 1
+--R       (- 2 + 2%i)\|1 - %i atanh(---------)
+--R                                  +------+
+--R                                 \|1 - %i
+--R     + 
+--R                                   +-----+
+--R                   +------+       \|x + 1
+--R       (- 2 - 2%i)\|1 + %i atanh(---------)
+--R                                  +------+
+--R                                 \|1 + %i
+--R     + 
+--R                                 4+-+    %pi    4+-+    %pi
+--R                                 \|8 sin(---) + \|8 cos(---)
+--R          4+-+    %pi                     8              8
+--R       - 2\|8 sin(---)atan(---------------------------------------)
+--R                   8         +-----+   4+-+    %pi    4+-+    %pi
+--R                           2\|x + 1  - \|8 sin(---) + \|8 cos(---)
+--R                                                8              8
+--R     + 
+--R                                 4+-+    %pi    4+-+    %pi
+--R                                 \|8 sin(---) + \|8 cos(---)
+--R          4+-+    %pi                     8              8
+--R       - 2\|8 sin(---)atan(---------------------------------------)
+--R                   8         +-----+   4+-+    %pi    4+-+    %pi
+--R                           2\|x + 1  + \|8 sin(---) - \|8 cos(---)
+--R                                                8              8
+--R  /
+--R     2
+--R                                           Type: Expression(Complex(Integer))
+--E 489
+
+--S 490 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)
+--R          2         %pi 12         2          %pi     %pi 11
+--R       (8x  - 8)sin(---)   + (- 32x  + 32)cos(---)sin(---)
+--R                     8                         8       8
+--R     + 
+--R            2          %pi 2        3     2            4+-+2     %pi 10
+--R       ((80x  - 80)cos(---)  + (- 6x  - 6x  + 10x + 10)\|8  )sin(---)
+--R                        8                                         8
+--R     + 
+--R                 2           %pi 3       3      2            4+-+2    %pi
+--R         ((- 160x  + 160)cos(---)  + (20x  + 20x  - 44x - 44)\|8  cos(---))
+--R                              8                                        8
+--R      *
+--R             %pi 9
+--R         sin(---)
+--R              8
+--R     + 
+--R                2           %pi 4         3      2              4+-+2    %pi 2
+--R           (248x  - 248)cos(---)  + (- 74x  - 74x  + 134x + 134)\|8  cos(---)
+--R                             8                                            8
+--R         + 
+--R             4     3      2
+--R           4x  + 8x  - 40x  - 88x - 44
+--R      *
+--R             %pi 8
+--R         sin(---)
+--R              8
+--R     + 
+--R                  2           %pi 5        3       2              4+-+2    %pi 3
+--R           (- 320x  + 320)cos(---)  + (144x  + 144x  - 240x - 240)\|8  cos(---)
+--R                               8                                            8
+--R         + 
+--R                 4       3       2                  %pi
+--R           (- 64x  - 128x  + 192x  + 512x + 256)cos(---)
+--R                                                     8
+--R      *
+--R             %pi 7
+--R         sin(---)
+--R              8
+--R     + 
+--R                2           %pi 6          3       2              4+-+2    %pi 4
+--R           (352x  - 352)cos(---)  + (- 212x  - 212x  + 332x + 332)\|8  cos(---)
+--R                             8                                              8
+--R         + 
+--R                4       3       2                   %pi 2
+--R           (224x  + 448x  - 448x  - 1344x - 672)cos(---)
+--R                                                     8
+--R         + 
+--R             5     4      3      2            4+-+2
+--R           (x  + 3x  + 20x  + 52x  + 51x + 17)\|8
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              8
+--R     + 
+--R                  2           %pi 7        3       2              4+-+2    %pi 5
+--R           (- 320x  + 320)cos(---)  + (264x  + 264x  - 376x - 376)\|8  cos(---)
+--R                               8                                            8
+--R         + 
+--R                  4       3       2                    %pi 3
+--R           (- 352x  - 704x  + 768x  + 2240x + 1120)cos(---)
+--R                                                        8
+--R         + 
+--R               5      4      3       2             4+-+2    %pi
+--R           (14x  + 42x  - 56x  - 280x  - 294x - 98)\|8  cos(---)
+--R                                                             8
+--R      *
+--R             %pi 5
+--R         sin(---)
+--R              8
+--R     + 
+--R                2           %pi 8          3       2              4+-+2    %pi 6
+--R           (248x  - 248)cos(---)  + (- 236x  - 236x  + 308x + 308)\|8  cos(---)
+--R                             8                                              8
+--R         + 
+--R                4        3       2                    %pi 4
+--R           (728x  + 1456x  - 752x  - 2960x - 1480)cos(---)
+--R                                                       8
+--R         + 
+--R                 5      4       3       2              4+-+2    %pi 2      4
+--R           (- 11x  - 33x  + 196x  + 676x  + 687x + 229)\|8  cos(---)  - 36x
+--R                                                                 8
+--R         + 
+--R                 3       2
+--R           - 144x  - 216x  - 144x - 36
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              8
+--R     + 
+--R                  2           %pi 9        3       2              4+-+2    %pi 7
+--R           (- 160x  + 160)cos(---)  + (176x  + 176x  - 208x - 208)\|8  cos(---)
+--R                               8                                            8
+--R         + 
+--R                  4        3       2                   %pi 5
+--R           (- 576x  - 1152x  + 320x  + 1792x + 896)cos(---)
+--R                                                        8
+--R         + 
+--R                5       4      3        2               4+-+2    %pi 3
+--R           (140x  + 420x  + 16x  - 1072x  - 1212x - 404)\|8  cos(---)
+--R                                                                  8
+--R         + 
+--R               6       5       4       3        2                  %pi
+--R           (32x  + 128x  + 368x  + 832x  + 1088x  + 704x + 176)cos(---)
+--R                                                                    8
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              8
+--R     + 
+--R               2          %pi 10          3       2              4+-+2    %pi 8
+--R           (80x  - 80)cos(---)   + (- 102x  - 102x  + 106x + 106)\|8  cos(---)
+--R                           8                                               8
+--R         + 
+--R                4       3      2                  %pi 6
+--R           (416x  + 832x  - 64x  - 960x - 480)cos(---)
+--R                                                   8
+--R         + 
+--R                 5       4       3       2              4+-+2    %pi 4
+--R           (- 93x  - 279x  - 132x  + 348x  + 441x + 147)\|8  cos(---)
+--R                                                                  8
+--R         + 
+--R                6       5       4        3        2                   %pi 2
+--R           (112x  + 448x  + 184x  - 1504x  - 2816x  - 1952x - 488)cos(---)
+--R                                                                       8
+--R         + 
+--R              7      6      5      4      3      2           4+-+2
+--R           (2x  + 10x  + 26x  + 50x  + 70x  + 62x  + 30x + 6)\|8
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              8
+--R     + 
+--R                 2          %pi 11       3      2            4+-+2    %pi 9
+--R           (- 32x  + 32)cos(---)   + (36x  + 36x  - 28x - 28)\|8  cos(---)
+--R                             8                                         8
+--R         + 
+--R                  4       3                  %pi 7
+--R           (- 160x  - 320x  + 320x + 160)cos(---)
+--R                                              8
+--R         + 
+--R               5       4       3       2             4+-+2    %pi 5
+--R           (54x  + 162x  + 104x  - 120x  - 174x - 58)\|8  cos(---)
+--R                                                               8
+--R         + 
+--R                 6       5       4      3       2                 %pi 3
+--R           (- 64x  - 256x  - 304x  + 64x  + 416x  + 320x + 80)cos(---)
+--R                                                                   8
+--R         + 
+--R              7      6     5       4       3       2             4+-+2    %pi
+--R           (4x  + 20x  + 4x  - 140x  - 340x  - 356x  - 180x - 36)\|8  cos(---)
+--R                                                                           8
+--R      *
+--R             %pi
+--R         sin(---)
+--R              8
+--R     + 
+--R          2         %pi 12         3      2          4+-+2    %pi 10
+--R       (8x  - 8)cos(---)   + (- 10x  - 10x  + 6x + 6)\|8  cos(---)
+--R                     8                                         8
+--R     + 
+--R           4      3      2                %pi 8
+--R       (36x  + 72x  + 24x  - 24x - 12)cos(---)
+--R                                           8
+--R     + 
+--R            5      4      3      2           4+-+2    %pi 6
+--R       (- 9x  - 27x  - 20x  + 12x  + 21x + 7)\|8  cos(---)
+--R                                                       8
+--R     + 
+--R           6      5      4      3       2                %pi 4
+--R       (16x  + 64x  + 76x  - 16x  - 104x  - 80x - 20)cos(---)
+--R                                                          8
+--R     + 
+--R            7      6      5      4      3      2           4+-+2    %pi 2     6
+--R       (- 2x  - 10x  - 18x  - 10x  + 10x  + 18x  + 10x + 2)\|8  cos(---)  - 8x
+--R                                                                     8
+--R     + 
+--R            5       4       3       2
+--R       - 48x  - 120x  - 160x  - 120x  - 48x - 8
+--R  /
+--R            2         %pi 12         2          %pi     %pi 11
+--R         (8x  + 8)sin(---)   + (- 32x  - 32)cos(---)sin(---)
+--R                       8                         8       8
+--R       + 
+--R              2          %pi 2        3     2          4+-+2     %pi 10
+--R         ((80x  + 80)cos(---)  + (- 8x  - 8x  - 8x - 8)\|8  )sin(---)
+--R                          8                                       8
+--R       + 
+--R                   2           %pi 3       3      2            4+-+2    %pi
+--R           ((- 160x  - 160)cos(---)  + (32x  + 32x  + 32x + 32)\|8  cos(---))
+--R                                8                                        8
+--R        *
+--R               %pi 9
+--R           sin(---)
+--R                8
+--R       + 
+--R                  2           %pi 4
+--R             (248x  + 248)cos(---)
+--R                               8
+--R           + 
+--R                    3       2              4+-+2    %pi 2      4      3      2
+--R             (- 104x  - 104x  - 104x - 104)\|8  cos(---)  + 24x  + 48x  + 48x
+--R                                                     8
+--R           + 
+--R             48x + 24
+--R        *
+--R               %pi 8
+--R           sin(---)
+--R                8
+--R       + 
+--R                    2           %pi 5
+--R             (- 320x  - 320)cos(---)
+--R                                 8
+--R           + 
+--R                  3       2              4+-+2    %pi 3
+--R             (192x  + 192x  + 192x + 192)\|8  cos(---)
+--R                                                   8
+--R           + 
+--R                    4       3       2                  %pi
+--R             (- 160x  - 320x  - 320x  - 320x - 160)cos(---)
+--R                                                        8
+--R        *
+--R               %pi 7
+--R           sin(---)
+--R                8
+--R       + 
+--R                  2           %pi 6
+--R             (352x  + 352)cos(---)
+--R                               8
+--R           + 
+--R                    3       2              4+-+2    %pi 4
+--R             (- 272x  - 272x  - 272x - 272)\|8  cos(---)
+--R                                                     8
+--R           + 
+--R                  4       3       2                  %pi 2
+--R             (448x  + 896x  + 896x  + 896x + 448)cos(---)
+--R                                                      8
+--R           + 
+--R                  5      4      3      2           4+-+2
+--R             (- 8x  - 24x  - 32x  - 32x  - 24x - 8)\|8
+--R        *
+--R               %pi 6
+--R           sin(---)
+--R                8
+--R       + 
+--R                    2           %pi 7
+--R             (- 320x  - 320)cos(---)
+--R                                 8
+--R           + 
+--R                  3       2              4+-+2    %pi 5
+--R             (320x  + 320x  + 320x + 320)\|8  cos(---)
+--R                                                   8
+--R           + 
+--R                    4        3        2                   %pi 3
+--R             (- 736x  - 1472x  - 1472x  - 1472x - 736)cos(---)
+--R                                                           8
+--R           + 
+--R                 5       4       3       2             4+-+2    %pi
+--R             (56x  + 168x  + 224x  + 224x  + 168x + 56)\|8  cos(---)
+--R                                                                 8
+--R        *
+--R               %pi 5
+--R           sin(---)
+--R                8
+--R       + 
+--R                  2           %pi 8
+--R             (248x  + 248)cos(---)
+--R                               8
+--R           + 
+--R                    3       2              4+-+2    %pi 6
+--R             (- 272x  - 272x  - 272x - 272)\|8  cos(---)
+--R                                                     8
+--R           + 
+--R                   4        3        2                    %pi 4
+--R             (1104x  + 2208x  + 2208x  + 2208x + 1104)cos(---)
+--R                                                           8
+--R           + 
+--R                    5       4       3       2              4+-+2    %pi 2      6
+--R             (- 120x  - 360x  - 480x  - 480x  - 360x - 120)\|8  cos(---)  + 18x
+--R                                                                     8
+--R           + 
+--R                5       4       3       2
+--R             72x  + 126x  + 144x  + 126x  + 72x + 18
+--R        *
+--R               %pi 4
+--R           sin(---)
+--R                8
+--R       + 
+--R                    2           %pi 9
+--R             (- 160x  - 160)cos(---)
+--R                                 8
+--R           + 
+--R                  3       2              4+-+2    %pi 7
+--R             (192x  + 192x  + 192x + 192)\|8  cos(---)
+--R                                                   8
+--R           + 
+--R                    4        3        2                   %pi 5
+--R             (- 736x  - 1472x  - 1472x  - 1472x - 736)cos(---)
+--R                                                           8
+--R           + 
+--R                  5       4        3        2              4+-+2    %pi 3
+--R             (272x  + 816x  + 1088x  + 1088x  + 816x + 272)\|8  cos(---)
+--R                                                                     8
+--R           + 
+--R                   6       5       4       3       2                 %pi
+--R             (- 72x  - 288x  - 504x  - 576x  - 504x  - 288x - 72)cos(---)
+--R                                                                      8
+--R        *
+--R               %pi 3
+--R           sin(---)
+--R                8
+--R       + 
+--R                 2          %pi 10
+--R             (80x  + 80)cos(---)
+--R                             8
+--R           + 
+--R                    3       2              4+-+2    %pi 8
+--R             (- 104x  - 104x  - 104x - 104)\|8  cos(---)
+--R                                                     8
+--R           + 
+--R                  4       3       2                  %pi 6
+--R             (448x  + 896x  + 896x  + 896x + 448)cos(---)
+--R                                                      8
+--R           + 
+--R                    5       4       3       2              4+-+2    %pi 4
+--R             (- 120x  - 360x  - 480x  - 480x  - 360x - 120)\|8  cos(---)
+--R                                                                     8
+--R           + 
+--R                  6        5        4        3        2                   %pi 2
+--R             (300x  + 1200x  + 2100x  + 2400x  + 2100x  + 1200x + 300)cos(---)
+--R                                                                           8
+--R           + 
+--R                  7      6      5      4      3      2           4+-+2
+--R             (- 2x  - 10x  - 22x  - 30x  - 30x  - 22x  - 10x - 2)\|8
+--R        *
+--R               %pi 2
+--R           sin(---)
+--R                8
+--R       + 
+--R                   2          %pi 11       3      2            4+-+2    %pi 9
+--R             (- 32x  - 32)cos(---)   + (32x  + 32x  + 32x + 32)\|8  cos(---)
+--R                               8                                         8
+--R           + 
+--R                    4       3       2                  %pi 7
+--R             (- 160x  - 320x  - 320x  - 320x - 160)cos(---)
+--R                                                        8
+--R           + 
+--R                 5       4       3       2             4+-+2    %pi 5
+--R             (56x  + 168x  + 224x  + 224x  + 168x + 56)\|8  cos(---)
+--R                                                                 8
+--R           + 
+--R                   6       5       4       3       2                 %pi 3
+--R             (- 72x  - 288x  - 504x  - 576x  - 504x  - 288x - 72)cos(---)
+--R                                                                      8
+--R           + 
+--R                   7       6       5       4       3       2             4+-+2
+--R               (20x  + 100x  + 220x  + 300x  + 300x  + 220x  + 100x + 20)\|8
+--R            *
+--R                   %pi
+--R               cos(---)
+--R                    8
+--R        *
+--R               %pi
+--R           sin(---)
+--R                8
+--R       + 
+--R            2         %pi 12        3     2          4+-+2    %pi 10
+--R         (8x  + 8)cos(---)   + (- 8x  - 8x  - 8x - 8)\|8  cos(---)
+--R                       8                                       8
+--R       + 
+--R             4      3      2                %pi 8
+--R         (24x  + 48x  + 48x  + 48x + 24)cos(---)
+--R                                             8
+--R       + 
+--R              5      4      3      2           4+-+2    %pi 6
+--R         (- 8x  - 24x  - 32x  - 32x  - 24x - 8)\|8  cos(---)
+--R                                                         8
+--R       + 
+--R             6      5       4       3       2                %pi 4
+--R         (18x  + 72x  + 126x  + 144x  + 126x  + 72x + 18)cos(---)
+--R                                                              8
+--R       + 
+--R              7      6      5      4      3      2           4+-+2    %pi 2
+--R         (- 2x  - 10x  - 22x  - 30x  - 30x  - 22x  - 10x - 2)\|8  cos(---)
+--R                                                                       8
+--R       + 
+--R           8      7      6       5       4       3      2
+--R         4x  + 24x  + 64x  + 104x  + 120x  + 104x  + 64x  + 24x + 4
+--R    *
+--R        +-----+
+--R       \|x + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 490
+
+--S 491 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R                      +---------+
+--R              +-----+ |  +-+         +-+
+--R       - log(\|x + 1 \|2\|2  + 2  + \|2  + x + 1)
+--R     + 
+--R       -
+--R                         +--------+
+--R            4+-+    %pi  | +-+
+--R            \|8 cos(---)\|\|2  + 1
+--R                     8
+--R         *
+--R            log
+--R                   4+-+    %pi     4+-+    %pi   +-----+   4+-+2    %pi 2
+--R                 (2\|8 sin(---) - 2\|8 cos(---))\|x + 1  + \|8  sin(---)
+--R                            8               8                        8
+--R               + 
+--R                 4+-+2    %pi 2
+--R                 \|8  cos(---)  + 2x + 2
+--R                           8
+--R     + 
+--R                      +--------+
+--R         4+-+    %pi  | +-+
+--R         \|8 cos(---)\|\|2  + 1
+--R                  8
+--R      *
+--R         log
+--R                  4+-+    %pi     4+-+    %pi   +-----+   4+-+2    %pi 2
+--R              (- 2\|8 sin(---) + 2\|8 cos(---))\|x + 1  + \|8  sin(---)
+--R                           8               8                        8
+--R            + 
+--R              4+-+2    %pi 2
+--R              \|8  cos(---)  + 2x + 2
+--R                        8
+--R     + 
+--R                      +---------+
+--R              +-----+ |  +-+         +-+
+--R       log(- \|x + 1 \|2\|2  + 2  + \|2  + x + 1)
+--R     + 
+--R                          +---------+
+--R                          |  +-+          +-----+
+--R            +-+          \|2\|2  + 2  + 2\|x + 1
+--R       (- 2\|2  - 2)atan(------------------------)
+--R                                +---------+
+--R                                |  +-+
+--R                               \|2\|2  - 2
+--R     + 
+--R                        +---------+
+--R                        |  +-+          +-----+
+--R          +-+          \|2\|2  + 2  - 2\|x + 1
+--R       (2\|2  + 2)atan(------------------------)
+--R                              +---------+
+--R                              |  +-+
+--R                             \|2\|2  - 2
+--R     + 
+--R                                            4+-+    %pi    4+-+    %pi
+--R                       +--------+           \|8 sin(---) + \|8 cos(---)
+--R          4+-+    %pi  | +-+                         8              8
+--R       - 2\|8 sin(---)\|\|2  + 1 atan(---------------------------------------)
+--R                   8                    +-----+   4+-+    %pi    4+-+    %pi
+--R                                      2\|x + 1  - \|8 sin(---) + \|8 cos(---)
+--R                                                           8              8
+--R     + 
+--R                                            4+-+    %pi    4+-+    %pi
+--R                       +--------+           \|8 sin(---) + \|8 cos(---)
+--R          4+-+    %pi  | +-+                         8              8
+--R       - 2\|8 sin(---)\|\|2  + 1 atan(---------------------------------------)
+--R                   8                    +-----+   4+-+    %pi    4+-+    %pi
+--R                                      2\|x + 1  + \|8 sin(---) - \|8 cos(---)
+--R                                                           8              8
+--R  /
+--R       +--------+
+--R       | +-+
+--R     2\|\|2  + 1
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)
+--R                +-+              %pi 12       +-+                %pi     %pi 11
+--R           (- 4\|2  + 4x + 4)sin(---)   + (16\|2  - 16x - 16)cos(---)sin(---)
+--R                                  8                               8       8
+--R         + 
+--R                       +-+                %pi 2
+--R                 (- 40\|2  + 40x + 40)cos(---)
+--R                                           8
+--R               + 
+--R                           +-+     2          4+-+2
+--R                 ((4x + 4)\|2  - 4x  - 8x - 4)\|8
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  8
+--R         + 
+--R                   +-+                %pi 3
+--R               (80\|2  - 80x - 80)cos(---)
+--R                                       8
+--R             + 
+--R                             +-+      2            4+-+2    %pi
+--R               ((- 16x - 16)\|2  + 16x  + 32x + 16)\|8  cos(---)
+--R                                                             8
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      +-+                  %pi 4
+--R               (- 124\|2  + 124x + 124)cos(---)
+--R                                            8
+--R             + 
+--R                           +-+      2             4+-+2    %pi 2
+--R               ((52x + 52)\|2  - 52x  - 104x - 52)\|8  cos(---)
+--R                                                            8
+--R             + 
+--R                     2             +-+      3      2
+--R               (- 12x  - 24x - 12)\|2  + 12x  + 36x  + 36x + 12
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  8
+--R         + 
+--R                    +-+                  %pi 5
+--R               (160\|2  - 160x - 160)cos(---)
+--R                                          8
+--R             + 
+--R                             +-+      2             4+-+2    %pi 3
+--R               ((- 96x - 96)\|2  + 96x  + 192x + 96)\|8  cos(---)
+--R                                                              8
+--R             + 
+--R                    2              +-+      3       2                 %pi
+--R               ((80x  + 160x + 80)\|2  - 80x  - 240x  - 240x - 80)cos(---)
+--R                                                                       8
+--R          *
+--R                 %pi 7
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      +-+                  %pi 6
+--R               (- 176\|2  + 176x + 176)cos(---)
+--R                                            8
+--R             + 
+--R                             +-+       2              4+-+2    %pi 4
+--R               ((136x + 136)\|2  - 136x  - 272x - 136)\|8  cos(---)
+--R                                                                8
+--R             + 
+--R                         2               +-+       3       2
+--R                 ((- 224x  - 448x - 224)\|2  + 224x  + 672x  + 672x + 224)
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                   3      2            +-+     4      3      2           4+-+2
+--R               ((4x  + 12x  + 12x + 4)\|2  - 4x  - 16x  - 24x  - 16x - 4)\|8
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  8
+--R         + 
+--R                    +-+                  %pi 7
+--R               (160\|2  - 160x - 160)cos(---)
+--R                                          8
+--R             + 
+--R                               +-+       2              4+-+2    %pi 5
+--R               ((- 160x - 160)\|2  + 160x  + 320x + 160)\|8  cos(---)
+--R                                                                  8
+--R             + 
+--R                       2               +-+       3        2
+--R                 ((368x  + 736x + 368)\|2  - 368x  - 1104x  - 1104x - 368)
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         3      2             +-+      4       3       2
+--R                   (- 28x  - 84x  - 84x - 28)\|2  + 28x  + 112x  + 168x  + 112x
+--R                 + 
+--R                   28
+--R              *
+--R                 4+-+2    %pi
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      +-+                  %pi 8
+--R               (- 124\|2  + 124x + 124)cos(---)
+--R                                            8
+--R             + 
+--R                             +-+       2              4+-+2    %pi 6
+--R               ((136x + 136)\|2  - 136x  - 272x - 136)\|8  cos(---)
+--R                                                                8
+--R             + 
+--R                         2                +-+       3        2
+--R                 ((- 552x  - 1104x - 552)\|2  + 552x  + 1656x  + 1656x + 552)
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                       3       2              +-+      4       3       2
+--R                   (60x  + 180x  + 180x + 60)\|2  - 60x  - 240x  - 360x  - 240x
+--R                 + 
+--R                   - 60
+--R              *
+--R                 4+-+2    %pi 2
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                    4      3      2            +-+     5      4      3      2
+--R               (- 9x  - 36x  - 54x  - 36x - 9)\|2  + 9x  + 45x  + 90x  + 90x
+--R             + 
+--R               45x + 9
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  8
+--R         + 
+--R                   +-+                %pi 9
+--R               (80\|2  - 80x - 80)cos(---)
+--R                                       8
+--R             + 
+--R                             +-+      2             4+-+2    %pi 7
+--R               ((- 96x - 96)\|2  + 96x  + 192x + 96)\|8  cos(---)
+--R                                                              8
+--R             + 
+--R                       2               +-+       3        2
+--R                 ((368x  + 736x + 368)\|2  - 368x  - 1104x  - 1104x - 368)
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                          3       2               +-+       4       3       2
+--R                   (- 136x  - 408x  - 408x - 136)\|2  + 136x  + 544x  + 816x
+--R                 + 
+--R                   544x + 136
+--R              *
+--R                 4+-+2    %pi 3
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                       4       3       2              +-+      5       4       3
+--R                   (36x  + 144x  + 216x  + 144x + 36)\|2  - 36x  - 180x  - 360x
+--R                 + 
+--R                         2
+--R                   - 360x  - 180x - 36
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      8
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  8
+--R         + 
+--R                     +-+                %pi 10
+--R               (- 40\|2  + 40x + 40)cos(---)
+--R                                         8
+--R             + 
+--R                           +-+      2             4+-+2    %pi 8
+--R               ((52x + 52)\|2  - 52x  - 104x - 52)\|8  cos(---)
+--R                                                            8
+--R             + 
+--R                         2               +-+       3       2
+--R                 ((- 224x  - 448x - 224)\|2  + 224x  + 672x  + 672x + 224)
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                       3       2              +-+      4       3       2
+--R                   (60x  + 180x  + 180x + 60)\|2  - 60x  - 240x  - 360x  - 240x
+--R                 + 
+--R                   - 60
+--R              *
+--R                 4+-+2    %pi 4
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                          4       3       2               +-+       5       4
+--R                   (- 150x  - 600x  - 900x  - 600x - 150)\|2  + 150x  + 750x
+--R                 + 
+--R                        3        2
+--R                   1500x  + 1500x  + 750x + 150
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                     5     4      3      2           +-+    6     5      4
+--R                   (x  + 5x  + 10x  + 10x  + 5x + 1)\|2  - x  - 6x  - 15x
+--R                 + 
+--R                        3      2
+--R                   - 20x  - 15x  - 6x - 1
+--R              *
+--R                 4+-+2
+--R                 \|8
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  8
+--R         + 
+--R                   +-+                %pi 11
+--R               (16\|2  - 16x - 16)cos(---)
+--R                                       8
+--R             + 
+--R                             +-+      2            4+-+2    %pi 9
+--R               ((- 16x - 16)\|2  + 16x  + 32x + 16)\|8  cos(---)
+--R                                                             8
+--R             + 
+--R                    2              +-+      3       2                 %pi 7
+--R               ((80x  + 160x + 80)\|2  - 80x  - 240x  - 240x - 80)cos(---)
+--R                                                                       8
+--R             + 
+--R                         3      2             +-+      4       3       2
+--R                   (- 28x  - 84x  - 84x - 28)\|2  + 28x  + 112x  + 168x  + 112x
+--R                 + 
+--R                   28
+--R              *
+--R                 4+-+2    %pi 5
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                       4       3       2              +-+      5       4       3
+--R                   (36x  + 144x  + 216x  + 144x + 36)\|2  - 36x  - 180x  - 360x
+--R                 + 
+--R                         2
+--R                   - 360x  - 180x - 36
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         5      4       3       2             +-+      6      5
+--R                   (- 10x  - 50x  - 100x  - 100x  - 50x - 10)\|2  + 10x  + 60x
+--R                 + 
+--R                       4       3       2
+--R                   150x  + 200x  + 150x  + 60x + 10
+--R              *
+--R                 4+-+2    %pi
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  8
+--R         + 
+--R                +-+              %pi 12
+--R           (- 4\|2  + 4x + 4)cos(---)
+--R                                  8
+--R         + 
+--R                     +-+     2          4+-+2    %pi 10
+--R           ((4x + 4)\|2  - 4x  - 8x - 4)\|8  cos(---)
+--R                                                  8
+--R         + 
+--R                  2             +-+      3      2                %pi 8
+--R           ((- 12x  - 24x - 12)\|2  + 12x  + 36x  + 36x + 12)cos(---)
+--R                                                                  8
+--R         + 
+--R                 3      2            +-+     4      3      2           4+-+2
+--R             ((4x  + 12x  + 12x + 4)\|2  - 4x  - 16x  - 24x  - 16x - 4)\|8
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    4      3      2            +-+     5      4      3      2
+--R               (- 9x  - 36x  - 54x  - 36x - 9)\|2  + 9x  + 45x  + 90x  + 90x
+--R             + 
+--R               45x + 9
+--R          *
+--R                 %pi 4
+--R             cos(---)
+--R                  8
+--R         + 
+--R                 5     4      3      2           +-+    6     5      4      3
+--R               (x  + 5x  + 10x  + 10x  + 5x + 1)\|2  - x  - 6x  - 15x  - 20x
+--R             + 
+--R                    2
+--R               - 15x  - 6x - 1
+--R          *
+--R             4+-+2    %pi 2
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                6      5      4      3      2            +-+     7      6      5
+--R           (- 2x  - 12x  - 30x  - 40x  - 30x  - 12x - 2)\|2  + 2x  + 14x  + 42x
+--R         + 
+--R              4      3      2
+--R           70x  + 70x  + 42x  + 14x + 2
+--R      *
+--R                  +--------+ +---------+
+--R          +-----+ | +-+      |  +-+
+--R         \|x + 1 \|\|2  + 1 \|2\|2  + 2
+--R     + 
+--R                       +-+               %pi 12
+--R           ((- 4x - 8)\|2  - 4x - 12)sin(---)
+--R                                          8
+--R         + 
+--R                       +-+                %pi     %pi 11
+--R           ((16x + 32)\|2  + 16x + 48)cos(---)sin(---)
+--R                                           8       8
+--R         + 
+--R                             +-+                 %pi 2
+--R               ((- 40x - 80)\|2  - 40x - 120)cos(---)
+--R                                                  8
+--R             + 
+--R                   2            +-+     2            4+-+2
+--R               ((4x  + 12x + 8)\|2  + 4x  + 16x + 12)\|8
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  8
+--R         + 
+--R                            +-+                 %pi 3
+--R               ((80x + 160)\|2  + 80x + 240)cos(---)
+--R                                                 8
+--R             + 
+--R                      2             +-+      2            4+-+2    %pi
+--R               ((- 16x  - 48x - 32)\|2  - 16x  - 64x - 48)\|8  cos(---)
+--R                                                                    8
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  8
+--R         + 
+--R                               +-+                  %pi 4
+--R               ((- 124x - 248)\|2  - 124x - 372)cos(---)
+--R                                                     8
+--R             + 
+--R                    2               +-+      2              4+-+2    %pi 2
+--R               ((52x  + 156x + 104)\|2  + 52x  + 208x + 156)\|8  cos(---)
+--R                                                                      8
+--R             + 
+--R                     3      2             +-+      3      2
+--R               (- 12x  - 48x  - 60x - 24)\|2  - 12x  - 60x  - 84x - 36
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  8
+--R         + 
+--R                             +-+                  %pi 5
+--R               ((160x + 320)\|2  + 160x + 480)cos(---)
+--R                                                   8
+--R             + 
+--R                      2               +-+      2              4+-+2    %pi 3
+--R               ((- 96x  - 288x - 192)\|2  - 96x  - 384x - 288)\|8  cos(---)
+--R                                                                        8
+--R             + 
+--R                      3       2               +-+      3       2
+--R                 ((80x  + 320x  + 400x + 160)\|2  + 80x  + 400x  + 560x + 240)
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      8
+--R          *
+--R                 %pi 7
+--R             sin(---)
+--R                  8
+--R         + 
+--R                               +-+                  %pi 6
+--R               ((- 176x - 352)\|2  - 176x - 528)cos(---)
+--R                                                     8
+--R             + 
+--R                     2               +-+       2              4+-+2    %pi 4
+--R               ((136x  + 408x + 272)\|2  + 136x  + 544x + 408)\|8  cos(---)
+--R                                                                        8
+--R             + 
+--R                          3       2                +-+       3        2
+--R                   (- 224x  - 896x  - 1120x - 448)\|2  - 224x  - 1120x  - 1568x
+--R                 + 
+--R                   - 672
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                      4      3      2            +-+     4      3      2
+--R                   (4x  + 20x  + 36x  + 28x + 8)\|2  + 4x  + 24x  + 48x  + 40x
+--R                 + 
+--R                   12
+--R              *
+--R                 4+-+2
+--R                 \|8
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  8
+--R         + 
+--R                             +-+                  %pi 7
+--R               ((160x + 320)\|2  + 160x + 480)cos(---)
+--R                                                   8
+--R             + 
+--R                       2               +-+       2              4+-+2    %pi 5
+--R               ((- 160x  - 480x - 320)\|2  - 160x  - 640x - 480)\|8  cos(---)
+--R                                                                          8
+--R             + 
+--R                        3        2                +-+       3        2
+--R                   (368x  + 1472x  + 1840x + 736)\|2  + 368x  + 1840x  + 2576x
+--R                 + 
+--R                   1104
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         4       3       2              +-+      4       3
+--R                   (- 28x  - 140x  - 252x  - 196x - 56)\|2  - 28x  - 168x
+--R                 + 
+--R                         2
+--R                   - 336x  - 280x - 84
+--R              *
+--R                 4+-+2    %pi
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  8
+--R         + 
+--R                               +-+                  %pi 8
+--R               ((- 124x - 248)\|2  - 124x - 372)cos(---)
+--R                                                     8
+--R             + 
+--R                     2               +-+       2              4+-+2    %pi 6
+--R               ((136x  + 408x + 272)\|2  + 136x  + 544x + 408)\|8  cos(---)
+--R                                                                        8
+--R             + 
+--R                          3        2                 +-+       3        2
+--R                   (- 552x  - 2208x  - 2760x - 1104)\|2  - 552x  - 2760x
+--R                 + 
+--R                   - 3864x - 1656
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                       4       3       2               +-+      4       3
+--R                   (60x  + 300x  + 540x  + 420x + 120)\|2  + 60x  + 360x
+--R                 + 
+--R                       2
+--R                   720x  + 600x + 180
+--R              *
+--R                 4+-+2    %pi 2
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                    5      4       3       2             +-+     5      4
+--R               (- 9x  - 54x  - 126x  - 144x  - 81x - 18)\|2  - 9x  - 63x
+--R             + 
+--R                     3       2
+--R               - 162x  - 198x  - 117x - 27
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  8
+--R         + 
+--R                            +-+                 %pi 9
+--R               ((80x + 160)\|2  + 80x + 240)cos(---)
+--R                                                 8
+--R             + 
+--R                      2               +-+      2              4+-+2    %pi 7
+--R               ((- 96x  - 288x - 192)\|2  - 96x  - 384x - 288)\|8  cos(---)
+--R                                                                        8
+--R             + 
+--R                        3        2                +-+       3        2
+--R                   (368x  + 1472x  + 1840x + 736)\|2  + 368x  + 1840x  + 2576x
+--R                 + 
+--R                   1104
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                          4       3        2               +-+       4       3
+--R                   (- 136x  - 680x  - 1224x  - 952x - 272)\|2  - 136x  - 816x
+--R                 + 
+--R                          2
+--R                   - 1632x  - 1360x - 408
+--R              *
+--R                 4+-+2    %pi 3
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                       5       4       3       2              +-+      5       4
+--R                   (36x  + 216x  + 504x  + 576x  + 324x + 72)\|2  + 36x  + 252x
+--R                 + 
+--R                       3       2
+--R                   648x  + 792x  + 468x + 108
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      8
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  8
+--R         + 
+--R                             +-+                 %pi 10
+--R               ((- 40x - 80)\|2  - 40x - 120)cos(---)
+--R                                                  8
+--R             + 
+--R                    2               +-+      2              4+-+2    %pi 8
+--R               ((52x  + 156x + 104)\|2  + 52x  + 208x + 156)\|8  cos(---)
+--R                                                                      8
+--R             + 
+--R                          3       2                +-+       3        2
+--R                   (- 224x  - 896x  - 1120x - 448)\|2  - 224x  - 1120x  - 1568x
+--R                 + 
+--R                   - 672
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                       4       3       2               +-+      4       3
+--R                   (60x  + 300x  + 540x  + 420x + 120)\|2  + 60x  + 360x
+--R                 + 
+--R                       2
+--R                   720x  + 600x + 180
+--R              *
+--R                 4+-+2    %pi 4
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                          5       4        3        2                +-+       5
+--R                   (- 150x  - 900x  - 2100x  - 2400x  - 1350x - 300)\|2  - 150x
+--R                 + 
+--R                          4        3        2
+--R                   - 1050x  - 2700x  - 3300x  - 1950x - 450
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                     6     5      4      3      2            +-+    6     5
+--R                   (x  + 7x  + 20x  + 30x  + 25x  + 11x + 2)\|2  + x  + 8x
+--R                 + 
+--R                      4      3      2
+--R                   25x  + 40x  + 35x  + 16x + 3
+--R              *
+--R                 4+-+2
+--R                 \|8
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  8
+--R         + 
+--R                           +-+                %pi 11
+--R               ((16x + 32)\|2  + 16x + 48)cos(---)
+--R                                               8
+--R             + 
+--R                      2             +-+      2            4+-+2    %pi 9
+--R               ((- 16x  - 48x - 32)\|2  - 16x  - 64x - 48)\|8  cos(---)
+--R                                                                    8
+--R             + 
+--R                      3       2               +-+      3       2
+--R                 ((80x  + 320x  + 400x + 160)\|2  + 80x  + 400x  + 560x + 240)
+--R              *
+--R                     %pi 7
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         4       3       2              +-+      4       3
+--R                   (- 28x  - 140x  - 252x  - 196x - 56)\|2  - 28x  - 168x
+--R                 + 
+--R                         2
+--R                   - 336x  - 280x - 84
+--R              *
+--R                 4+-+2    %pi 5
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                       5       4       3       2              +-+      5       4
+--R                   (36x  + 216x  + 504x  + 576x  + 324x + 72)\|2  + 36x  + 252x
+--R                 + 
+--R                       3       2
+--R                   648x  + 792x  + 468x + 108
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         6      5       4       3       2              +-+
+--R                   (- 10x  - 70x  - 200x  - 300x  - 250x  - 110x - 20)\|2
+--R                 + 
+--R                        6      5       4       3       2
+--R                   - 10x  - 80x  - 250x  - 400x  - 350x  - 160x - 30
+--R              *
+--R                 4+-+2    %pi
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  8
+--R         + 
+--R                       +-+               %pi 12
+--R           ((- 4x - 8)\|2  - 4x - 12)cos(---)
+--R                                          8
+--R         + 
+--R               2            +-+     2            4+-+2    %pi 10
+--R           ((4x  + 12x + 8)\|2  + 4x  + 16x + 12)\|8  cos(---)
+--R                                                           8
+--R         + 
+--R                  3      2             +-+      3      2                %pi 8
+--R           ((- 12x  - 48x  - 60x - 24)\|2  - 12x  - 60x  - 84x - 36)cos(---)
+--R                                                                         8
+--R         + 
+--R                 4      3      2            +-+     4      3      2
+--R             ((4x  + 20x  + 36x  + 28x + 8)\|2  + 4x  + 24x  + 48x  + 40x + 12)
+--R          *
+--R             4+-+2    %pi 6
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                    5      4       3       2             +-+     5      4
+--R               (- 9x  - 54x  - 126x  - 144x  - 81x - 18)\|2  - 9x  - 63x
+--R             + 
+--R                     3       2
+--R               - 162x  - 198x  - 117x - 27
+--R          *
+--R                 %pi 4
+--R             cos(---)
+--R                  8
+--R         + 
+--R                 6     5      4      3      2            +-+    6     5      4
+--R               (x  + 7x  + 20x  + 30x  + 25x  + 11x + 2)\|2  + x  + 8x  + 25x
+--R             + 
+--R                  3      2
+--R               40x  + 35x  + 16x + 3
+--R          *
+--R             4+-+2    %pi 2
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                7      6      5       4       3      2            +-+     7
+--R           (- 2x  - 16x  - 54x  - 100x  - 110x  - 72x  - 26x - 4)\|2  - 2x
+--R         + 
+--R                6      5       4       3       2
+--R           - 18x  - 66x  - 130x  - 150x  - 102x  - 38x - 6
+--R      *
+--R                  +--------+ +---------+
+--R          +-----+ | +-+      |  +-+
+--R         \|x + 1 \|\|2  + 1 \|2\|2  - 2
+--R     + 
+--R               2      +-+     2         %pi 12
+--R           ((8x  + 8)\|2  + 8x  + 8)sin(---)
+--R                                         8
+--R         + 
+--R                  2       +-+      2          %pi     %pi 11
+--R           ((- 32x  - 32)\|2  - 32x  - 32)cos(---)sin(---)
+--R                                               8       8
+--R         + 
+--R                    2       +-+      2          %pi 2
+--R               ((80x  + 80)\|2  + 80x  + 80)cos(---)
+--R                                                 8
+--R             + 
+--R                     3     2           +-+     3     2          4+-+2
+--R               ((- 6x  - 6x  - 6x - 6)\|2  - 6x  - 6x  - 6x - 6)\|8
+--R          *
+--R                 %pi 10
+--R             sin(---)
+--R                  8
+--R         + 
+--R                       2        +-+       2           %pi 3
+--R               ((- 160x  - 160)\|2  - 160x  - 160)cos(---)
+--R                                                       8
+--R             + 
+--R                      3      2             +-+      3      2            4+-+2
+--R                 ((20x  + 20x  + 20x + 20)\|2  + 20x  + 20x  + 20x + 20)\|8
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      8
+--R          *
+--R                 %pi 9
+--R             sin(---)
+--R                  8
+--R         + 
+--R                     2        +-+       2           %pi 4
+--R               ((248x  + 248)\|2  + 248x  + 248)cos(---)
+--R                                                     8
+--R             + 
+--R                        3      2             +-+      3      2            4+-+2
+--R                 ((- 74x  - 74x  - 74x - 74)\|2  - 74x  - 74x  - 74x - 74)\|8
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                  4     3     2           +-+     4     3     2
+--R               (4x  + 8x  + 8x  + 8x + 4)\|2  + 4x  + 8x  + 8x  + 8x + 4
+--R          *
+--R                 %pi 8
+--R             sin(---)
+--R                  8
+--R         + 
+--R                       2        +-+       2           %pi 5
+--R               ((- 320x  - 320)\|2  - 320x  - 320)cos(---)
+--R                                                       8
+--R             + 
+--R                       3       2               +-+       3       2
+--R                 ((144x  + 144x  + 144x + 144)\|2  + 144x  + 144x  + 144x + 144)
+--R              *
+--R                 4+-+2    %pi 3
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                         4       3       2              +-+      4       3
+--R                   (- 64x  - 128x  - 128x  - 128x - 64)\|2  - 64x  - 128x
+--R                 + 
+--R                         2
+--R                   - 128x  - 128x - 64
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      8
+--R          *
+--R                 %pi 7
+--R             sin(---)
+--R                  8
+--R         + 
+--R                     2        +-+       2           %pi 6
+--R               ((352x  + 352)\|2  + 352x  + 352)cos(---)
+--R                                                     8
+--R             + 
+--R                            3       2               +-+       3       2
+--R                     (- 212x  - 212x  - 212x - 212)\|2  - 212x  - 212x  - 212x
+--R                   + 
+--R                     - 212
+--R              *
+--R                 4+-+2    %pi 4
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                        4       3       2               +-+       4       3
+--R                   (224x  + 448x  + 448x  + 448x + 224)\|2  + 224x  + 448x
+--R                 + 
+--R                       2
+--R                   448x  + 448x + 224
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                     5     4     3     2           +-+    5     4     3     2
+--R                   (x  + 3x  + 4x  + 4x  + 3x + 1)\|2  + x  + 3x  + 4x  + 4x
+--R                 + 
+--R                   3x + 1
+--R              *
+--R                 4+-+2
+--R                 \|8
+--R          *
+--R                 %pi 6
+--R             sin(---)
+--R                  8
+--R         + 
+--R                       2        +-+       2           %pi 7
+--R               ((- 320x  - 320)\|2  - 320x  - 320)cos(---)
+--R                                                       8
+--R             + 
+--R                       3       2               +-+       3       2
+--R                 ((264x  + 264x  + 264x + 264)\|2  + 264x  + 264x  + 264x + 264)
+--R              *
+--R                 4+-+2    %pi 5
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                          4       3       2               +-+       4       3
+--R                   (- 352x  - 704x  - 704x  - 704x - 352)\|2  - 352x  - 704x
+--R                 + 
+--R                         2
+--R                   - 704x  - 704x - 352
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                       5      4      3      2             +-+      5      4
+--R                   (14x  + 42x  + 56x  + 56x  + 42x + 14)\|2  + 14x  + 42x
+--R                 + 
+--R                      3      2
+--R                   56x  + 56x  + 42x + 14
+--R              *
+--R                 4+-+2    %pi
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi 5
+--R             sin(---)
+--R                  8
+--R         + 
+--R                     2        +-+       2           %pi 8
+--R               ((248x  + 248)\|2  + 248x  + 248)cos(---)
+--R                                                     8
+--R             + 
+--R                            3       2               +-+       3       2
+--R                     (- 236x  - 236x  - 236x - 236)\|2  - 236x  - 236x  - 236x
+--R                   + 
+--R                     - 236
+--R              *
+--R                 4+-+2    %pi 6
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                        4        3        2                +-+       4        3
+--R                   (728x  + 1456x  + 1456x  + 1456x + 728)\|2  + 728x  + 1456x
+--R                 + 
+--R                        2
+--R                   1456x  + 1456x + 728
+--R              *
+--R                     %pi 4
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         5      4      3      2             +-+      5      4
+--R                   (- 11x  - 33x  - 44x  - 44x  - 33x - 11)\|2  - 11x  - 33x
+--R                 + 
+--R                        3      2
+--R                   - 44x  - 44x  - 33x - 11
+--R              *
+--R                 4+-+2    %pi 2
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi 4
+--R             sin(---)
+--R                  8
+--R         + 
+--R                       2        +-+       2           %pi 9
+--R               ((- 160x  - 160)\|2  - 160x  - 160)cos(---)
+--R                                                       8
+--R             + 
+--R                       3       2               +-+       3       2
+--R                 ((176x  + 176x  + 176x + 176)\|2  + 176x  + 176x  + 176x + 176)
+--R              *
+--R                 4+-+2    %pi 7
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                          4        3        2                +-+       4
+--R                   (- 576x  - 1152x  - 1152x  - 1152x - 576)\|2  - 576x
+--R                 + 
+--R                          3        2
+--R                   - 1152x  - 1152x  - 1152x - 576
+--R              *
+--R                     %pi 5
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                        5       4       3       2               +-+       5
+--R                   (140x  + 420x  + 560x  + 560x  + 420x + 140)\|2  + 140x
+--R                 + 
+--R                       4       3       2
+--R                   420x  + 560x  + 560x  + 420x + 140
+--R              *
+--R                 4+-+2    %pi 3
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                       6       5       4       3       2              +-+      6
+--R                   (32x  + 128x  + 224x  + 256x  + 224x  + 128x + 32)\|2  + 32x
+--R                 + 
+--R                       5       4       3       2
+--R                   128x  + 224x  + 256x  + 224x  + 128x + 32
+--R              *
+--R                     %pi
+--R                 cos(---)
+--R                      8
+--R          *
+--R                 %pi 3
+--R             sin(---)
+--R                  8
+--R         + 
+--R                    2       +-+      2          %pi 10
+--R               ((80x  + 80)\|2  + 80x  + 80)cos(---)
+--R                                                 8
+--R             + 
+--R                            3       2               +-+       3       2
+--R                     (- 102x  - 102x  - 102x - 102)\|2  - 102x  - 102x  - 102x
+--R                   + 
+--R                     - 102
+--R              *
+--R                 4+-+2    %pi 8
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                        4       3       2               +-+       4       3
+--R                   (416x  + 832x  + 832x  + 832x + 416)\|2  + 416x  + 832x
+--R                 + 
+--R                       2
+--R                   832x  + 832x + 416
+--R              *
+--R                     %pi 6
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                         5       4       3       2              +-+      5
+--R                   (- 93x  - 279x  - 372x  - 372x  - 279x - 93)\|2  - 93x
+--R                 + 
+--R                         4       3       2
+--R                   - 279x  - 372x  - 372x  - 279x - 93
+--R              *
+--R                 4+-+2    %pi 4
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                        6       5       4       3       2               +-+
+--R                   (112x  + 448x  + 784x  + 896x  + 784x  + 448x + 112)\|2
+--R                 + 
+--R                       6       5       4       3       2
+--R                   112x  + 448x  + 784x  + 896x  + 784x  + 448x + 112
+--R              *
+--R                     %pi 2
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                      7      6      5      4      3      2            +-+     7
+--R                   (2x  + 10x  + 22x  + 30x  + 30x  + 22x  + 10x + 2)\|2  + 2x
+--R                 + 
+--R                      6      5      4      3      2
+--R                   10x  + 22x  + 30x  + 30x  + 22x  + 10x + 2
+--R              *
+--R                 4+-+2
+--R                 \|8
+--R          *
+--R                 %pi 2
+--R             sin(---)
+--R                  8
+--R         + 
+--R                      2       +-+      2          %pi 11
+--R               ((- 32x  - 32)\|2  - 32x  - 32)cos(---)
+--R                                                   8
+--R             + 
+--R                      3      2             +-+      3      2            4+-+2
+--R                 ((36x  + 36x  + 36x + 36)\|2  + 36x  + 36x  + 36x + 36)\|8
+--R              *
+--R                     %pi 9
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                          4       3       2               +-+       4       3
+--R                   (- 160x  - 320x  - 320x  - 320x - 160)\|2  - 160x  - 320x
+--R                 + 
+--R                         2
+--R                   - 320x  - 320x - 160
+--R              *
+--R                     %pi 7
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                       5       4       3       2              +-+      5       4
+--R                   (54x  + 162x  + 216x  + 216x  + 162x + 54)\|2  + 54x  + 162x
+--R                 + 
+--R                       3       2
+--R                   216x  + 216x  + 162x + 54
+--R              *
+--R                 4+-+2    %pi 5
+--R                 \|8  cos(---)
+--R                           8
+--R             + 
+--R                         6       5       4       3       2              +-+
+--R                   (- 64x  - 256x  - 448x  - 512x  - 448x  - 256x - 64)\|2
+--R                 + 
+--R                        6       5       4       3       2
+--R                   - 64x  - 256x  - 448x  - 512x  - 448x  - 256x - 64
+--R              *
+--R                     %pi 3
+--R                 cos(---)
+--R                      8
+--R             + 
+--R                      7      6      5      4      3      2            +-+     7
+--R                   (4x  + 20x  + 44x  + 60x  + 60x  + 44x  + 20x + 4)\|2  + 4x
+--R                 + 
+--R                      6      5      4      3      2
+--R                   20x  + 44x  + 60x  + 60x  + 44x  + 20x + 4
+--R              *
+--R                 4+-+2    %pi
+--R                 \|8  cos(---)
+--R                           8
+--R          *
+--R                 %pi
+--R             sin(---)
+--R                  8
+--R         + 
+--R               2      +-+     2         %pi 12
+--R           ((8x  + 8)\|2  + 8x  + 8)cos(---)
+--R                                         8
+--R         + 
+--R                    3      2             +-+      3      2            4+-+2
+--R             ((- 10x  - 10x  - 10x - 10)\|2  - 10x  - 10x  - 10x - 10)\|8
+--R          *
+--R                 %pi 10
+--R             cos(---)
+--R                  8
+--R         + 
+--R                     4      3      2             +-+      4      3      2
+--R                 (36x  + 72x  + 72x  + 72x + 36)\|2  + 36x  + 72x  + 72x  + 72x
+--R               + 
+--R                 36
+--R          *
+--R                 %pi 8
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    5      4      3      2            +-+     5      4      3
+--R               (- 9x  - 27x  - 36x  - 36x  - 27x - 9)\|2  - 9x  - 27x  - 36x
+--R             + 
+--R                    2
+--R               - 36x  - 27x - 9
+--R          *
+--R             4+-+2    %pi 6
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                   6      5       4       3       2             +-+      6
+--R               (16x  + 64x  + 112x  + 128x  + 112x  + 64x + 16)\|2  + 16x
+--R             + 
+--R                  5       4       3       2
+--R               64x  + 112x  + 128x  + 112x  + 64x + 16
+--R          *
+--R                 %pi 4
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    7      6      5      4      3      2            +-+     7
+--R               (- 2x  - 10x  - 22x  - 30x  - 30x  - 22x  - 10x - 2)\|2  - 2x
+--R             + 
+--R                    6      5      4      3      2
+--R               - 10x  - 22x  - 30x  - 30x  - 22x  - 10x - 2
+--R          *
+--R             4+-+2    %pi 2
+--R             \|8  cos(---)
+--R                       8
+--R      *
+--R          +-----+
+--R         \|x + 1
+--R  /
+--R           3     2           +-+     3     2              %pi 12
+--R       ((8x  + 8x  + 8x + 8)\|2  + 8x  + 8x  + 8x + 8)sin(---)
+--R                                                           8
+--R     + 
+--R                3      2             +-+      3      2                %pi
+--R         ((- 32x  - 32x  - 32x - 32)\|2  - 32x  - 32x  - 32x - 32)cos(---)
+--R                                                                       8
+--R      *
+--R             %pi 11
+--R         sin(---)
+--R              8
+--R     + 
+--R                3      2             +-+      3      2                %pi 2
+--R           ((80x  + 80x  + 80x + 80)\|2  + 80x  + 80x  + 80x + 80)cos(---)
+--R                                                                       8
+--R         + 
+--R                   4      3      2            +-+     4      3      2
+--R             ((- 8x  - 16x  - 16x  - 16x - 8)\|2  - 8x  - 16x  - 16x  - 16x - 8)
+--R          *
+--R             4+-+2
+--R             \|8
+--R      *
+--R             %pi 10
+--R         sin(---)
+--R              8
+--R     + 
+--R                     3       2               +-+       3       2
+--R             ((- 160x  - 160x  - 160x - 160)\|2  - 160x  - 160x  - 160x - 160)
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  8
+--R         + 
+--R                     4      3      2             +-+      4      3      2
+--R                 (32x  + 64x  + 64x  + 64x + 32)\|2  + 32x  + 64x  + 64x  + 64x
+--R               + 
+--R                 32
+--R          *
+--R             4+-+2    %pi
+--R             \|8  cos(---)
+--R                       8
+--R      *
+--R             %pi 9
+--R         sin(---)
+--R              8
+--R     + 
+--R                   3       2               +-+       3       2
+--R             ((248x  + 248x  + 248x + 248)\|2  + 248x  + 248x  + 248x + 248)
+--R          *
+--R                 %pi 4
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      4       3       2               +-+       4       3
+--R               (- 104x  - 208x  - 208x  - 208x - 104)\|2  - 104x  - 208x
+--R             + 
+--R                     2
+--R               - 208x  - 208x - 104
+--R          *
+--R             4+-+2    %pi 2
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R               5      4      3      2             +-+      5      4      3
+--R           (24x  + 72x  + 96x  + 96x  + 72x + 24)\|2  + 24x  + 72x  + 96x
+--R         + 
+--R              2
+--R           96x  + 72x + 24
+--R      *
+--R             %pi 8
+--R         sin(---)
+--R              8
+--R     + 
+--R                     3       2               +-+       3       2
+--R             ((- 320x  - 320x  - 320x - 320)\|2  - 320x  - 320x  - 320x - 320)
+--R          *
+--R                 %pi 5
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    4       3       2               +-+       4       3       2
+--R               (192x  + 384x  + 384x  + 384x + 192)\|2  + 192x  + 384x  + 384x
+--R             + 
+--R               384x + 192
+--R          *
+--R             4+-+2    %pi 3
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                      5       4       3       2               +-+       5
+--R               (- 160x  - 480x  - 640x  - 640x  - 480x - 160)\|2  - 160x
+--R             + 
+--R                     4       3       2
+--R               - 480x  - 640x  - 640x  - 480x - 160
+--R          *
+--R                 %pi
+--R             cos(---)
+--R                  8
+--R      *
+--R             %pi 7
+--R         sin(---)
+--R              8
+--R     + 
+--R                   3       2               +-+       3       2
+--R             ((352x  + 352x  + 352x + 352)\|2  + 352x  + 352x  + 352x + 352)
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      4       3       2               +-+       4       3
+--R               (- 272x  - 544x  - 544x  - 544x - 272)\|2  - 272x  - 544x
+--R             + 
+--R                     2
+--R               - 544x  - 544x - 272
+--R          *
+--R             4+-+2    %pi 4
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                    5        4        3        2                +-+       5
+--R               (448x  + 1344x  + 1792x  + 1792x  + 1344x + 448)\|2  + 448x
+--R             + 
+--R                    4        3        2
+--R               1344x  + 1792x  + 1792x  + 1344x + 448
+--R          *
+--R                 %pi 2
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    6      5      4      3      2            +-+     6      5
+--R               (- 8x  - 32x  - 56x  - 64x  - 56x  - 32x - 8)\|2  - 8x  - 32x
+--R             + 
+--R                    4      3      2
+--R               - 56x  - 64x  - 56x  - 32x - 8
+--R          *
+--R             4+-+2
+--R             \|8
+--R      *
+--R             %pi 6
+--R         sin(---)
+--R              8
+--R     + 
+--R                     3       2               +-+       3       2
+--R             ((- 320x  - 320x  - 320x - 320)\|2  - 320x  - 320x  - 320x - 320)
+--R          *
+--R                 %pi 7
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    4       3       2               +-+       4       3       2
+--R               (320x  + 640x  + 640x  + 640x + 320)\|2  + 320x  + 640x  + 640x
+--R             + 
+--R               640x + 320
+--R          *
+--R             4+-+2    %pi 5
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                      5        4        3        2                +-+       5
+--R               (- 736x  - 2208x  - 2944x  - 2944x  - 2208x - 736)\|2  - 736x
+--R             + 
+--R                      4        3        2
+--R               - 2208x  - 2944x  - 2944x  - 2208x - 736
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  8
+--R         + 
+--R                   6       5       4       3       2              +-+      6
+--R               (56x  + 224x  + 392x  + 448x  + 392x  + 224x + 56)\|2  + 56x
+--R             + 
+--R                   5       4       3       2
+--R               224x  + 392x  + 448x  + 392x  + 224x + 56
+--R          *
+--R             4+-+2    %pi
+--R             \|8  cos(---)
+--R                       8
+--R      *
+--R             %pi 5
+--R         sin(---)
+--R              8
+--R     + 
+--R                   3       2               +-+       3       2
+--R             ((248x  + 248x  + 248x + 248)\|2  + 248x  + 248x  + 248x + 248)
+--R          *
+--R                 %pi 8
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      4       3       2               +-+       4       3
+--R               (- 272x  - 544x  - 544x  - 544x - 272)\|2  - 272x  - 544x
+--R             + 
+--R                     2
+--R               - 544x  - 544x - 272
+--R          *
+--R             4+-+2    %pi 6
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                     5        4        3        2                 +-+        5
+--R               (1104x  + 3312x  + 4416x  + 4416x  + 3312x + 1104)\|2  + 1104x
+--R             + 
+--R                    4        3        2
+--R               3312x  + 4416x  + 4416x  + 3312x + 1104
+--R          *
+--R                 %pi 4
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      6       5       4       3       2               +-+
+--R               (- 120x  - 480x  - 840x  - 960x  - 840x  - 480x - 120)\|2
+--R             + 
+--R                     6       5       4       3       2
+--R               - 120x  - 480x  - 840x  - 960x  - 840x  - 480x - 120
+--R          *
+--R             4+-+2    %pi 2
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R               7      6       5       4       3       2             +-+      7
+--R           (18x  + 90x  + 198x  + 270x  + 270x  + 198x  + 90x + 18)\|2  + 18x
+--R         + 
+--R              6       5       4       3       2
+--R           90x  + 198x  + 270x  + 270x  + 198x  + 90x + 18
+--R      *
+--R             %pi 4
+--R         sin(---)
+--R              8
+--R     + 
+--R                     3       2               +-+       3       2
+--R             ((- 160x  - 160x  - 160x - 160)\|2  - 160x  - 160x  - 160x - 160)
+--R          *
+--R                 %pi 9
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    4       3       2               +-+       4       3       2
+--R               (192x  + 384x  + 384x  + 384x + 192)\|2  + 192x  + 384x  + 384x
+--R             + 
+--R               384x + 192
+--R          *
+--R             4+-+2    %pi 7
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                      5        4        3        2                +-+       5
+--R               (- 736x  - 2208x  - 2944x  - 2944x  - 2208x - 736)\|2  - 736x
+--R             + 
+--R                      4        3        2
+--R               - 2208x  - 2944x  - 2944x  - 2208x - 736
+--R          *
+--R                 %pi 5
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    6        5        4        3        2                +-+
+--R               (272x  + 1088x  + 1904x  + 2176x  + 1904x  + 1088x + 272)\|2
+--R             + 
+--R                   6        5        4        3        2
+--R               272x  + 1088x  + 1904x  + 2176x  + 1904x  + 1088x + 272
+--R          *
+--R             4+-+2    %pi 3
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                       7       6       5        4        3       2
+--R                 (- 72x  - 360x  - 792x  - 1080x  - 1080x  - 792x  - 360x - 72)
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                    7       6       5        4        3       2
+--R               - 72x  - 360x  - 792x  - 1080x  - 1080x  - 792x  - 360x - 72
+--R          *
+--R                 %pi
+--R             cos(---)
+--R                  8
+--R      *
+--R             %pi 3
+--R         sin(---)
+--R              8
+--R     + 
+--R                3      2             +-+      3      2                %pi 10
+--R           ((80x  + 80x  + 80x + 80)\|2  + 80x  + 80x  + 80x + 80)cos(---)
+--R                                                                       8
+--R         + 
+--R                      4       3       2               +-+       4       3
+--R               (- 104x  - 208x  - 208x  - 208x - 104)\|2  - 104x  - 208x
+--R             + 
+--R                     2
+--R               - 208x  - 208x - 104
+--R          *
+--R             4+-+2    %pi 8
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                    5        4        3        2                +-+       5
+--R               (448x  + 1344x  + 1792x  + 1792x  + 1344x + 448)\|2  + 448x
+--R             + 
+--R                    4        3        2
+--R               1344x  + 1792x  + 1792x  + 1344x + 448
+--R          *
+--R                 %pi 6
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      6       5       4       3       2               +-+
+--R               (- 120x  - 480x  - 840x  - 960x  - 840x  - 480x - 120)\|2
+--R             + 
+--R                     6       5       4       3       2
+--R               - 120x  - 480x  - 840x  - 960x  - 840x  - 480x - 120
+--R          *
+--R             4+-+2    %pi 4
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                       7        6        5        4        3        2
+--R                   300x  + 1500x  + 3300x  + 4500x  + 4500x  + 3300x  + 1500x
+--R                 + 
+--R                   300
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                   7        6        5        4        3        2
+--R               300x  + 1500x  + 3300x  + 4500x  + 4500x  + 3300x  + 1500x + 300
+--R          *
+--R                 %pi 2
+--R             cos(---)
+--R                  8
+--R         + 
+--R                    8      7      6      5      4      3      2            +-+
+--R               (- 2x  - 12x  - 32x  - 52x  - 60x  - 52x  - 32x  - 12x - 2)\|2
+--R             + 
+--R                   8      7      6      5      4      3      2
+--R               - 2x  - 12x  - 32x  - 52x  - 60x  - 52x  - 32x  - 12x - 2
+--R          *
+--R             4+-+2
+--R             \|8
+--R      *
+--R             %pi 2
+--R         sin(---)
+--R              8
+--R     + 
+--R                  3      2             +-+      3      2                %pi 11
+--R           ((- 32x  - 32x  - 32x - 32)\|2  - 32x  - 32x  - 32x - 32)cos(---)
+--R                                                                         8
+--R         + 
+--R                     4      3      2             +-+      4      3      2
+--R                 (32x  + 64x  + 64x  + 64x + 32)\|2  + 32x  + 64x  + 64x  + 64x
+--R               + 
+--R                 32
+--R          *
+--R             4+-+2    %pi 9
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                      5       4       3       2               +-+       5
+--R               (- 160x  - 480x  - 640x  - 640x  - 480x - 160)\|2  - 160x
+--R             + 
+--R                     4       3       2
+--R               - 480x  - 640x  - 640x  - 480x - 160
+--R          *
+--R                 %pi 7
+--R             cos(---)
+--R                  8
+--R         + 
+--R                   6       5       4       3       2              +-+      6
+--R               (56x  + 224x  + 392x  + 448x  + 392x  + 224x + 56)\|2  + 56x
+--R             + 
+--R                   5       4       3       2
+--R               224x  + 392x  + 448x  + 392x  + 224x + 56
+--R          *
+--R             4+-+2    %pi 5
+--R             \|8  cos(---)
+--R                       8
+--R         + 
+--R                       7       6       5        4        3       2
+--R                 (- 72x  - 360x  - 792x  - 1080x  - 1080x  - 792x  - 360x - 72)
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                    7       6       5        4        3       2
+--R               - 72x  - 360x  - 792x  - 1080x  - 1080x  - 792x  - 360x - 72
+--R          *
+--R                 %pi 3
+--R             cos(---)
+--R                  8
+--R         + 
+--R                      8       7       6       5       4       3       2
+--R                   20x  + 120x  + 320x  + 520x  + 600x  + 520x  + 320x  + 120x
+--R                 + 
+--R                   20
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                  8       7       6       5       4       3       2
+--R               20x  + 120x  + 320x  + 520x  + 600x  + 520x  + 320x  + 120x + 20
+--R          *
+--R             4+-+2    %pi
+--R             \|8  cos(---)
+--R                       8
+--R      *
+--R             %pi
+--R         sin(---)
+--R              8
+--R     + 
+--R           3     2           +-+     3     2              %pi 12
+--R       ((8x  + 8x  + 8x + 8)\|2  + 8x  + 8x  + 8x + 8)cos(---)
+--R                                                           8
+--R     + 
+--R               4      3      2            +-+     4      3      2
+--R         ((- 8x  - 16x  - 16x  - 16x - 8)\|2  - 8x  - 16x  - 16x  - 16x - 8)
+--R      *
+--R         4+-+2    %pi 10
+--R         \|8  cos(---)
+--R                   8
+--R     + 
+--R               5      4      3      2             +-+      5      4      3
+--R           (24x  + 72x  + 96x  + 96x  + 72x + 24)\|2  + 24x  + 72x  + 96x
+--R         + 
+--R              2
+--R           96x  + 72x + 24
+--R      *
+--R             %pi 8
+--R         cos(---)
+--R              8
+--R     + 
+--R                6      5      4      3      2            +-+     6      5      4
+--R           (- 8x  - 32x  - 56x  - 64x  - 56x  - 32x - 8)\|2  - 8x  - 32x  - 56x
+--R         + 
+--R                3      2
+--R           - 64x  - 56x  - 32x - 8
+--R      *
+--R         4+-+2    %pi 6
+--R         \|8  cos(---)
+--R                   8
+--R     + 
+--R               7      6       5       4       3       2             +-+      7
+--R           (18x  + 90x  + 198x  + 270x  + 270x  + 198x  + 90x + 18)\|2  + 18x
+--R         + 
+--R              6       5       4       3       2
+--R           90x  + 198x  + 270x  + 270x  + 198x  + 90x + 18
+--R      *
+--R             %pi 4
+--R         cos(---)
+--R              8
+--R     + 
+--R                8      7      6      5      4      3      2            +-+     8
+--R           (- 2x  - 12x  - 32x  - 52x  - 60x  - 52x  - 32x  - 12x - 2)\|2  - 2x
+--R         + 
+--R                7      6      5      4      3      2
+--R           - 12x  - 32x  - 52x  - 60x  - 52x  - 32x  - 12x - 2
+--R      *
+--R         4+-+2    %pi 2
+--R         \|8  cos(---)
+--R                   8
+--R     + 
+--R          9      8      7       6       5       4       3      2            +-+
+--R       (4x  + 28x  + 88x  + 168x  + 224x  + 224x  + 168x  + 88x  + 28x + 4)\|2
+--R     + 
+--R         9      8      7       6       5       4       3      2
+--R       4x  + 28x  + 88x  + 168x  + 224x  + 224x  + 168x  + 88x  + 28x + 4
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 649
+t0:=sqrt(-1+x-sqrt(x))/((-1+x)*sqrt(x))
+--R 
+--R
+--R         +--------------+
+--R         |   +-+
+--R        \|- \|x  + x - 1
+--R   (1)  -----------------
+--R                   +-+
+--R           (x - 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 649
+r0:=atan(1/2*(3-sqrt(x))/sqrt(-1+x-sqrt(x)))-_
+   2*atanh(1/2*(1-2*sqrt(x))/sqrt(-1+x-sqrt(x)))-_
+   atanh(1/2*(1+3*sqrt(x))/sqrt(-1+x-sqrt(x)))
+--R 
+--R
+--R   (2)
+--R                    +-+                          +-+
+--R                  3\|x  + 1                    2\|x  - 1
+--R     - atanh(------------------) + 2atanh(------------------)
+--R               +--------------+             +--------------+
+--R               |   +-+                      |   +-+
+--R             2\|- \|x  + x - 1            2\|- \|x  + x - 1
+--R   + 
+--R                  +-+
+--R                 \|x  - 3
+--R     - atan(------------------)
+--R              +--------------+
+--R              |   +-+
+--R            2\|- \|x  + x - 1
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 649
+--a0:=integrate(t0,x)
+--E 495
+
+--S 496 of 649
+--m0:=a0-r0
+--E 496
+
+--S 497 of 649
+--d0:=D(m0,x)
+--E 497
+
+)clear all
+
+--S 498 of 649
+t0:=1/(sqrt(x)*sqrt(1+x))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         +-+ +-----+
+--R        \|x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 649
+r0:=2*asinh(sqrt(x))
+--R 
+--R
+--R                +-+
+--R   (2)  2asinh(\|x )
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +-+ +-----+
+--R   (3)  - log(2\|x \|x + 1  - 2x - 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 500
+
+--S 501 of 649
+m0:=a0-r0
+--R 
+--R
+--R                +-+ +-----+                     +-+
+--R   (4)  - log(2\|x \|x + 1  - 2x - 1) - 2asinh(\|x )
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 502
+
+)clear all
+
+--S 503 of 649
+t0:=sqrt(x/(1+x))/x
+--R 
+--R
+--R         +-----+
+--R         |  x
+--R         |-----
+--R        \|x + 1
+--R   (1)  --------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 649
+r0a:=2*asinh(sqrt(x))
+--R 
+--R
+--R                +-+
+--R   (2)  2asinh(\|x )
+--R                                                    Type: Expression(Integer)
+--E 504
+
+--S 505 of 649
+r0b:=2*atanh(sqrt(x/(1+x)))
+--R 
+--R
+--R                +-----+
+--R                |  x
+--R   (3)  2atanh( |----- )
+--R               \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +-----+             +-----+
+--R             |  x                |  x
+--R   (4)  log( |-----  + 1) - log( |-----  - 1)
+--R            \|x + 1             \|x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 506
+
+--S 507 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R             +-----+             +-----+
+--R             |  x                |  x                   +-+
+--R   (5)  log( |-----  + 1) - log( |-----  - 1) - 2asinh(\|x )
+--R            \|x + 1             \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R         +-----+
+--R         |  x    +-+ +-----+
+--R         |----- \|x \|x + 1  - x
+--R        \|x + 1
+--R   (6)  ------------------------
+--R                +-+ +-----+
+--R              x\|x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R             +-----+             +-----+                +-----+
+--R             |  x                |  x                   |  x
+--R   (7)  log( |-----  + 1) - log( |-----  - 1) - 2atanh( |----- )
+--R            \|x + 1             \|x + 1                \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 649
+t0:=sqrt(x)/sqrt(1+x)
+--R 
+--R
+--R           +-+
+--R          \|x
+--R   (1)  --------
+--R         +-----+
+--R        \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 649
+r0:=-asinh(sqrt(x))+sqrt(x)*sqrt(1+x)
+--R 
+--R
+--R                 +-+     +-+ +-----+
+--R   (2)  - asinh(\|x ) + \|x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +-+ +-----+               +-----+    +-+             +-+ +-----+
+--R       (- 2\|x \|x + 1  - 2x - 1)log(\|x + 1  + \|x ) + (2x + 1)\|x \|x + 1
+--R     + 
+--R         2
+--R       2x  + 2x
+--R  /
+--R       +-+ +-----+
+--R     2\|x \|x + 1  + 2x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 513
+
+--S 514 of 649
+m0:=a0-r0
+--R 
+--R
+--R               +-----+    +-+           +-+
+--R   (4)  - log(\|x + 1  + \|x ) + asinh(\|x )
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 515
+
+)clear all
+
+--S 516 of 649
+t0:=sqrt(x/(1+x))
+--R 
+--R
+--R         +-----+
+--R         |  x
+--R   (1)   |-----
+--R        \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 649
+r0a:=-asinh(sqrt(x))+sqrt(x)*sqrt(1+x)
+--R 
+--R
+--R                 +-+     +-+ +-----+
+--R   (2)  - asinh(\|x ) + \|x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 649
+r0b:=-atanh(sqrt(x/(1+x)))+sqrt(x/(1+x))/(1-x/(1+x))
+--R 
+--R
+--R                 +-----+            +-----+
+--R                 |  x               |  x
+--R   (3)  - atanh( |----- ) + (x + 1) |-----
+--R                \|x + 1            \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-----+             +-----+                 +-----+
+--R               |  x                |  x                    |  x
+--R        - log( |-----  + 1) + log( |-----  - 1) + (2x + 2) |-----
+--R              \|x + 1             \|x + 1                 \|x + 1
+--R   (4)  ----------------------------------------------------------
+--R                                     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 519
+
+--S 520 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R              +-----+             +-----+
+--R              |  x                |  x                   +-+      +-+ +-----+
+--R       - log( |-----  + 1) + log( |-----  - 1) + 2asinh(\|x ) - 2\|x \|x + 1
+--R             \|x + 1             \|x + 1
+--R     + 
+--R                +-----+
+--R                |  x
+--R       (2x + 2) |-----
+--R               \|x + 1
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R         +-----+
+--R         |  x    +-+ +-----+
+--R         |----- \|x \|x + 1  - x
+--R        \|x + 1
+--R   (6)  ------------------------
+--R               +-+ +-----+
+--R              \|x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R               +-----+             +-----+                +-----+
+--R               |  x                |  x                   |  x
+--R        - log( |-----  + 1) + log( |-----  - 1) + 2atanh( |----- )
+--R              \|x + 1             \|x + 1                \|x + 1
+--R   (7)  ----------------------------------------------------------
+--R                                     2
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 523
+
+)clear all
+
+--S 524 of 649
+t0:=sqrt(-1+x)/(x^2*sqrt(1+x))
+--R 
+--R
+--R          +-----+
+--R         \|x - 1
+--R   (1)  ----------
+--R         2 +-----+
+--R        x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 649
+r0:=2*atan(sqrt(-1+x)/sqrt(1+x))-sqrt(-1+x)*sqrt(1+x)/x
+--R 
+--R
+--R                 +-----+
+--R                \|x - 1      +-----+ +-----+
+--R        2x atan(--------) - \|x - 1 \|x + 1
+--R                 +-----+
+--R                \|x + 1
+--R   (2)  ------------------------------------
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +-----+ +-----+
+--R                16\|x - 1 \|x + 1  - 63      +-----+ +-----+
+--R        8x atan(-----------------------) - 8\|x - 1 \|x + 1  - 7x
+--R                   +-----+ +-----+
+--R                63\|x - 1 \|x + 1  + 16
+--R   (3)  ---------------------------------------------------------
+--R                                    8x
+--R                                         Type: Union(Expression(Integer),...)
+--E 526
+
+--S 527 of 649
+m0:=a0-r0
+--R 
+--R
+--R                 +-----+ +-----+                 +-----+
+--R              16\|x - 1 \|x + 1  - 63           \|x - 1
+--R        8atan(-----------------------) - 16atan(--------) - 7
+--R                 +-----+ +-----+                 +-----+
+--R              63\|x - 1 \|x + 1  + 16           \|x + 1
+--R   (4)  -----------------------------------------------------
+--R                                  8
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 649
+t0:=sqrt((-1+x)/(1+x))/x^2
+--R 
+--R
+--R         +-----+
+--R         |x - 1
+--R         |-----
+--R        \|x + 1
+--R   (1)  --------
+--R            2
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 649
+r0:=2*atan(sqrt((-1+x)/(1+x)))-2*sqrt((-1+x)/(1+x))/(1+(-1+x)/(1+x))
+--R 
+--R
+--R                 +-----+              +-----+
+--R                 |x - 1               |x - 1
+--R        2x atan( |----- ) + (- x - 1) |-----
+--R                \|x + 1              \|x + 1
+--R   (2)  -------------------------------------
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-----+              +-----+
+--R                 |x - 1               |x - 1
+--R        2x atan( |----- ) + (- x - 1) |-----
+--R                \|x + 1              \|x + 1
+--R   (3)  -------------------------------------
+--R                          x
+--R                                         Type: Union(Expression(Integer),...)
+--E 531
+
+--S 532 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 533
+
+)clear all
+
+--S 534 of 649
+t0:=x^3*sqrt(-1+x)/sqrt(1+x)
+--R 
+--R
+--R         3 +-----+
+--R        x \|x - 1
+--R   (1)  ----------
+--R          +-----+
+--R         \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 649
+r0:=3/8*acosh(x)-2/3*sqrt(-1+x)*sqrt(1+x)+3/8*x*sqrt(-1+x)*sqrt(1+x)-_
+   1/3*x^2*sqrt(-1+x)*sqrt(1+x)+1/4*x^3*sqrt(-1+x)*sqrt(1+x)
+--R 
+--R
+--R           3     2            +-----+ +-----+
+--R        (6x  - 8x  + 9x - 16)\|x - 1 \|x + 1  + 9acosh(x)
+--R   (2)  -------------------------------------------------
+--R                                24
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +-----+ +-----+           3     2            +-----+ +-----+
+--R        - 9log(\|x - 1 \|x + 1  - x) + (6x  - 8x  + 9x - 16)\|x - 1 \|x + 1
+--R   (3)  --------------------------------------------------------------------
+--R                                         24
+--R                                         Type: Union(Expression(Integer),...)
+--E 536
+
+--S 537 of 649
+m0:=a0-r0
+--R 
+--R
+--R                +-----+ +-----+
+--R        - 3log(\|x - 1 \|x + 1  - x) - 3acosh(x)
+--R   (4)  ----------------------------------------
+--R                            8
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R          +------+
+--R          | 2          +-----+ +-----+
+--R        3\|x  - 1  - 3\|x - 1 \|x + 1
+--R   (5)  ------------------------------
+--R                            +------+
+--R            +-----+ +-----+ | 2
+--R          8\|x - 1 \|x + 1 \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 538
+
+)clear all
+
+--S 539 of 649
+t0:=x^3*sqrt((-1+x)/(1+x))
+--R 
+--R
+--R           +-----+
+--R         3 |x - 1
+--R   (1)  x  |-----
+--R          \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 649
+r0a:=3/8*acosh(x)-2/3*sqrt(-1+x)*sqrt(1+x)+3/8*x*sqrt(-1+x)*sqrt(1+x)-_
+   1/3*x^2*sqrt(-1+x)*sqrt(1+x)+1/4*x^3*sqrt(-1+x)*sqrt(1+x)
+--R 
+--R
+--R           3     2            +-----+ +-----+
+--R        (6x  - 8x  + 9x - 16)\|x - 1 \|x + 1  + 9acosh(x)
+--R   (2)  -------------------------------------------------
+--R                                24
+--R                                                    Type: Expression(Integer)
+--E 540
+
+--S 541 of 649
+r0b:=3/4*atanh(sqrt((-1+x)/(1+x)))+1/2*(1+(-1+x)/(1+x))^3*_
+   sqrt((-1+x)/(1+x))/(1+(1-x)/(1+x))^4-2/3*(1+(-1+x)/(1+x))^2*_
+   sqrt((-1+x)/(1+x))/(1+(1-x)/(1+x))^3+3/4*(1+(-1+x)/(1+x))*_
+   sqrt((-1+x)/(1+x))/(1+(1-x)/(1+x))^2-4/3*sqrt((-1+x)/(1+x))/_
+   (1+(1-x)/(1+x))
+--R 
+--R
+--R                 +-----+                               +-----+
+--R                 |x - 1        4     3    2            |x - 1
+--R        18atanh( |----- ) + (6x  - 2x  + x  - 7x - 16) |-----
+--R                \|x + 1                               \|x + 1
+--R   (3)  ------------------------------------------------------
+--R                                  24
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R         +-----+              +-----+                                   +-----+
+--R         |x - 1               |x - 1            4     3    2            |x - 1
+--R   9log( |-----  + 1) - 9log( |-----  - 1) + (6x  - 2x  + x  - 7x - 16) |-----
+--R        \|x + 1              \|x + 1                                   \|x + 1
+--R   ----------------------------------------------------------------------------
+--R                                        24
+--R                                         Type: Union(Expression(Integer),...)
+--E 542
+
+--S 543 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R             +-----+              +-----+
+--R             |x - 1               |x - 1
+--R       9log( |-----  + 1) - 9log( |-----  - 1)
+--R            \|x + 1              \|x + 1
+--R     + 
+--R            3     2            +-----+ +-----+
+--R       (- 6x  + 8x  - 9x + 16)\|x - 1 \|x + 1
+--R     + 
+--R                                  +-----+
+--R          4     3    2            |x - 1
+--R       (6x  - 2x  + x  - 7x - 16) |-----  - 9acosh(x)
+--R                                 \|x + 1
+--R  /
+--R     24
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)
+--R                                                             +-----+  +------+
+--R           4     3  +-----+ +-----+        5     3           |x - 1   | 2
+--R       ((8x  - 8x )\|x - 1 \|x + 1  + (- 8x  + 8x  + 3x + 3) |----- )\|x  - 1
+--R                                                            \|x + 1
+--R     + 
+--R                  +-----+
+--R                  |x - 1  +-----+ +-----+
+--R       (- 3x - 3) |----- \|x - 1 \|x + 1
+--R                 \|x + 1
+--R  /
+--R              +-----+                 +------+
+--R              |x - 1  +-----+ +-----+ | 2
+--R     (8x + 8) |----- \|x - 1 \|x + 1 \|x  - 1
+--R             \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R              +-----+              +-----+                +-----+
+--R              |x - 1               |x - 1                 |x - 1
+--R        3log( |-----  + 1) - 3log( |-----  - 1) - 6atanh( |----- )
+--R             \|x + 1              \|x + 1                \|x + 1
+--R   (7)  ----------------------------------------------------------
+--R                                     8
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 546
+
+)clear all
+
+--S 547 of 649
+t0:=sqrt(-x/(1+x))/x
+--R 
+--R
+--R         +-------+
+--R         |    x
+--R         |- -----
+--R        \|  x + 1
+--R   (1)  ----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 649
+r0:=2*atan(sqrt(-x/(1+x)))
+--R 
+--R
+--R               +-------+
+--R               |    x
+--R   (2)  2atan( |- ----- )
+--R              \|  x + 1
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-------+
+--R               |    x
+--R   (3)  2atan( |- ----- )
+--R              \|  x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 549
+
+--S 550 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 551
+
+)clear all
+
+--S 552 of 649
+t0:=sqrt((1-x)/(1+x))/(-1+x)
+--R 
+--R
+--R         +-------+
+--R         |- x + 1
+--R         |-------
+--R        \| x + 1
+--R   (1)  ----------
+--R           x - 1
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 649
+r0:=2*atan(sqrt((1-x)/(1+x)))
+--R 
+--R
+--R               +-------+
+--R               |- x + 1
+--R   (2)  2atan( |------- )
+--R              \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-------+
+--R               |- x + 1
+--R   (3)  2atan( |------- )
+--R              \| x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 554
+
+--S 555 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+--S 556 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 556
+
+)clear all
+
+--S 557 of 649
+t0:=sqrt((a+b*x)/(c-b*x))/(a+b*x)
+--R 
+--R
+--R         +---------+
+--R         |- b x - a
+--R         |---------
+--R        \| b x - c
+--R   (1)  ------------
+--R           b x + a
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 649
+r0:=2*atan(sqrt((a+b*x)/(c-b*x)))/b
+--R 
+--R
+--R               +---------+
+--R               |- b x - a
+--R        2atan( |--------- )
+--R              \| b x - c
+--R   (2)  -------------------
+--R                 b
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +---------+
+--R               |- b x - a
+--R        2atan( |--------- )
+--R              \| b x - c
+--R   (3)  -------------------
+--R                 b
+--R                                         Type: Union(Expression(Integer),...)
+--E 559
+
+--S 560 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 649
+t0:=sqrt((a+b*x)/(c+d*x))/(a+b*x)
+--R 
+--R
+--R         +-------+
+--R         |b x + a
+--R         |-------
+--R        \|d x + c
+--R   (1)  ----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 649
+r0:=2*atanh(sqrt(d)*sqrt((a+b*x)/(c+d*x))/sqrt(b))/(sqrt(b)*sqrt(d))
+--R 
+--R
+--R                +-------+
+--R                |b x + a  +-+
+--R                |------- \|d
+--R               \|d x + c
+--R        2atanh(--------------)
+--R                     +-+
+--R                    \|b
+--R   (2)  ----------------------
+--R                +-+ +-+
+--R               \|b \|d
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                       +-------+
+--R                             +---+        2            |b x + a
+--R    log((2b d x + a d + b c)\|b d  + (2b d x + 2b c d) |------- )
+--R                                                      \|d x + c
+--R   [-------------------------------------------------------------,
+--R                                 +---+
+--R                                \|b d
+--R                   +-------+
+--R           +-----+ |b x + a
+--R          \|- b d  |-------
+--R                  \|d x + c
+--R    2atan(------------------)
+--R                   b
+--R    -------------------------]
+--R              +-----+
+--R             \|- b d
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 564
+
+--S 565 of 649
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                                  +-------+
+--R        +-+ +-+                         +---+        2            |b x + a
+--R       \|b \|d log((2b d x + a d + b c)\|b d  + (2b d x + 2b c d) |------- )
+--R                                                                 \|d x + c
+--R     + 
+--R                       +-------+
+--R                       |b x + a  +-+
+--R                       |------- \|d
+--R           +---+      \|d x + c
+--R       - 2\|b d atanh(--------------)
+--R                            +-+
+--R                           \|b
+--R  /
+--R      +-+ +-+ +---+
+--R     \|b \|d \|b d
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 649
+m0b:=a0.2-r0
+--R 
+--R
+--R                          +-------+                               +-------+
+--R                          |b x + a  +-+                   +-----+ |b x + a
+--R                          |------- \|d                   \|- b d  |-------
+--R            +-----+      \|d x + c           +-+ +-+             \|d x + c
+--R        - 2\|- b d atanh(--------------) + 2\|b \|d atan(------------------)
+--R                               +-+                                b
+--R                              \|b
+--R   (6)  --------------------------------------------------------------------
+--R                                   +-----+ +-+ +-+
+--R                                  \|- b d \|b \|d
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 568
+
+)clear all
+
+--S 569 of 649
+t0:=sqrt(-x/(1+x))
+--R 
+--R
+--R         +-------+
+--R         |    x
+--R   (1)   |- -----
+--R        \|  x + 1
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 649
+r0a:=-atan(sqrt(-x/(1+x)))+(1+x)*sqrt(-x/(1+x))
+--R 
+--R
+--R                +-------+            +-------+
+--R                |    x               |    x
+--R   (2)  - atan( |- ----- ) + (x + 1) |- -----
+--R               \|  x + 1            \|  x + 1
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 649
+r0b:=-atan(sqrt(-x/(1+x)))+sqrt(-x/(1+x))/(1-x/(1+x))
+--R 
+--R
+--R                +-------+            +-------+
+--R                |    x               |    x
+--R   (3)  - atan( |- ----- ) + (x + 1) |- -----
+--R               \|  x + 1            \|  x + 1
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +-------+            +-------+
+--R                |    x               |    x
+--R   (4)  - atan( |- ----- ) + (x + 1) |- -----
+--R               \|  x + 1            \|  x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 572
+
+--S 573 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 649
+t0:=sqrt((1-x)/(1+x))
+--R 
+--R
+--R         +-------+
+--R         |- x + 1
+--R   (1)   |-------
+--R        \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 649
+r0a:=-2*atan(sqrt((1-x)/(1+x)))+(1+x)*sqrt((1-x)/(1+x))
+--R 
+--R
+--R                 +-------+            +-------+
+--R                 |- x + 1             |- x + 1
+--R   (2)  - 2atan( |------- ) + (x + 1) |-------
+--R                \| x + 1             \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 649
+r0b:=-2*atan(sqrt((1-x)/(1+x)))+2*sqrt((1-x)/(1+x))/(1+(1-x)/(1+x))
+--R 
+--R
+--R                 +-------+            +-------+
+--R                 |- x + 1             |- x + 1
+--R   (3)  - 2atan( |------- ) + (x + 1) |-------
+--R                \| x + 1             \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-------+            +-------+
+--R                 |- x + 1             |- x + 1
+--R   (4)  - 2atan( |------- ) + (x + 1) |-------
+--R                \| x + 1             \| x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 580
+
+--S 581 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 584
+
+)clear all
+
+--S 585 of 649
+t0:=sqrt((a+x)/(a-x))
+--R 
+--R
+--R         +-------+
+--R         |- x - a
+--R   (1)   |-------
+--R        \| x - a
+--R                                                    Type: Expression(Integer)
+--E 585
+
+--S 586 of 649
+r0a:=2*a*atan(sqrt((a+x)/(a-x)))-(a-x)*sqrt((a+x)/(a-x))
+--R 
+--R
+--R                 +-------+            +-------+
+--R                 |- x - a             |- x - a
+--R   (2)  2a atan( |------- ) + (x - a) |-------
+--R                \| x - a             \| x - a
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 649
+r0b:=2*a*atan(sqrt((a+x)/(a-x)))-2*a*sqrt((a+x)/(a-x))/(1+(a+x)/(a-x))
+--R 
+--R
+--R                 +-------+            +-------+
+--R                 |- x - a             |- x - a
+--R   (3)  2a atan( |------- ) + (x - a) |-------
+--R                \| x - a             \| x - a
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-------+            +-------+
+--R                 |- x - a             |- x - a
+--R   (4)  2a atan( |------- ) + (x - a) |-------
+--R                \| x - a             \| x - a
+--R                                         Type: Union(Expression(Integer),...)
+--E 588
+
+--S 589 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 592
+
+)clear all
+
+--S 593 of 649
+t0:=sqrt((-a+x)/(a+x))
+--R 
+--R
+--R         +-----+
+--R         |x - a
+--R   (1)   |-----
+--R        \|x + a
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 649
+r0a:=-2*a*atanh(sqrt((-a+x)/(a+x)))+(a+x)*sqrt((-a+x)/(a+x))
+--R 
+--R
+--R                    +-----+            +-----+
+--R                    |x - a             |x - a
+--R   (2)  - 2a atanh( |----- ) + (x + a) |-----
+--R                   \|x + a            \|x + a
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 649
+r0b:=-2*a*atanh(sqrt((-a+x)/(a+x)))+2*a*sqrt((-a+x)/(a+x))/(1+(a-x)/(a+x))
+--R 
+--R
+--R                    +-----+            +-----+
+--R                    |x - a             |x - a
+--R   (3)  - 2a atanh( |----- ) + (x + a) |-----
+--R                   \|x + a            \|x + a
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-----+               +-----+                +-----+
+--R                 |x - a                |x - a                 |x - a
+--R   (4)  - a log( |-----  + 1) + a log( |-----  - 1) + (x + a) |-----
+--R                \|x + a               \|x + a                \|x + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 596
+
+--S 597 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R                 +-----+               +-----+                  +-----+
+--R                 |x - a                |x - a                   |x - a
+--R   (5)  - a log( |-----  + 1) + a log( |-----  - 1) + 2a atanh( |----- )
+--R                \|x + a               \|x + a                  \|x + a
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R                 +-----+               +-----+                  +-----+
+--R                 |x - a                |x - a                   |x - a
+--R   (7)  - a log( |-----  + 1) + a log( |-----  - 1) + 2a atanh( |----- )
+--R                \|x + a               \|x + a                  \|x + a
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)clear all
+
+--S 601 of 649
+t0:=sqrt((a+b*x)/(c+d*x))
+--R 
+--R
+--R         +-------+
+--R         |b x + a
+--R   (1)   |-------
+--R        \|d x + c
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 649
+r0a:=-(b*c-a*d)*atanh(sqrt(d)*sqrt((a+b*x)/(c+d*x))/sqrt(b))/(d^(3/2)*_
+   sqrt(b))+(c+d*x)*sqrt((a+b*x)/(c+d*x))/d
+--R 
+--R
+--R                          +-------+
+--R                          |b x + a  +-+
+--R                          |------- \|d               +-------+
+--R                         \|d x + c                   |b x + a  +-+ +-+
+--R        (a d - b c)atanh(--------------) + (d x + c) |------- \|b \|d
+--R                               +-+                  \|d x + c
+--R                              \|b
+--R   (2)  --------------------------------------------------------------
+--R                                     +-+ +-+
+--R                                   d\|b \|d
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 649
+r0b:=-(b*c-a*d)*atanh(sqrt(d)*sqrt((a+b*x)/(c+d*x))/sqrt(b))/(d^(3/2)*_
+   sqrt(b))+(b*c-a*d)*sqrt((a+b*x)/(c+d*x))/(d*(b-d*(a+b*x)/(c+d*x)))
+--R 
+--R
+--R                          +-------+
+--R                          |b x + a  +-+
+--R                          |------- \|d               +-------+
+--R                         \|d x + c                   |b x + a  +-+ +-+
+--R        (a d - b c)atanh(--------------) + (d x + c) |------- \|b \|d
+--R                               +-+                  \|d x + c
+--R                              \|b
+--R   (3)  --------------------------------------------------------------
+--R                                     +-+ +-+
+--R                                   d\|b \|d
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R   [
+--R           (a d - b c)
+--R        *
+--R                                                              +-------+
+--R                                    +---+        2            |b x + a
+--R           log((2b d x + a d + b c)\|b d  + (2b d x + 2b c d) |------- )
+--R                                                             \|d x + c
+--R       + 
+--R                     +-------+
+--R                     |b x + a  +---+
+--R         (2d x + 2c) |------- \|b d
+--R                    \|d x + c
+--R    /
+--R          +---+
+--R       2d\|b d
+--R     ,
+--R                             +-------+
+--R                     +-----+ |b x + a
+--R                    \|- b d  |-------                       +-------+
+--R                            \|d x + c               +-----+ |b x + a
+--R    (a d - b c)atan(------------------) + (d x + c)\|- b d  |-------
+--R                             b                             \|d x + c
+--R    -----------------------------------------------------------------]
+--R                                  +-----+
+--R                                d\|- b d
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 604
+
+--S 605 of 649
+m0a:=a0.1-r0a
+--R 
+--R
+--R   (5)
+--R                     +-+ +-+
+--R         (a d - b c)\|b \|d
+--R      *
+--R                                                            +-------+
+--R                                  +---+        2            |b x + a
+--R         log((2b d x + a d + b c)\|b d  + (2b d x + 2b c d) |------- )
+--R                                                           \|d x + c
+--R     + 
+--R                                   +-------+
+--R                                   |b x + a  +-+
+--R                                   |------- \|d
+--R                       +---+      \|d x + c
+--R       (- 2a d + 2b c)\|b d atanh(--------------)
+--R                                        +-+
+--R                                       \|b
+--R  /
+--R        +-+ +-+ +---+
+--R     2d\|b \|d \|b d
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 649
+m0b:=a0.2-r0a
+--R 
+--R
+--R   (7)
+--R                                   +-------+
+--R                                   |b x + a  +-+
+--R                                   |------- \|d
+--R                     +-----+      \|d x + c
+--R       (- a d + b c)\|- b d atanh(--------------)
+--R                                        +-+
+--R                                       \|b
+--R     + 
+--R                                        +-------+
+--R                                +-----+ |b x + a
+--R                               \|- b d  |-------
+--R                   +-+ +-+             \|d x + c
+--R       (a d - b c)\|b \|d atan(------------------)
+--R                                        b
+--R  /
+--R       +-----+ +-+ +-+
+--R     d\|- b d \|b \|d
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 649
+m0c:=a0.1-r0b
+--R 
+--R
+--R   (9)
+--R                     +-+ +-+
+--R         (a d - b c)\|b \|d
+--R      *
+--R                                                            +-------+
+--R                                  +---+        2            |b x + a
+--R         log((2b d x + a d + b c)\|b d  + (2b d x + 2b c d) |------- )
+--R                                                           \|d x + c
+--R     + 
+--R                                   +-------+
+--R                                   |b x + a  +-+
+--R                                   |------- \|d
+--R                       +---+      \|d x + c
+--R       (- 2a d + 2b c)\|b d atanh(--------------)
+--R                                        +-+
+--R                                       \|b
+--R  /
+--R        +-+ +-+ +---+
+--R     2d\|b \|d \|b d
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 649
+d0c:=D(m0c,x)
+--R 
+--R
+--R   (10)  0
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 649
+m0d:=a0.2-r0b
+--R 
+--R
+--R   (11)
+--R                                   +-------+
+--R                                   |b x + a  +-+
+--R                                   |------- \|d
+--R                     +-----+      \|d x + c
+--R       (- a d + b c)\|- b d atanh(--------------)
+--R                                        +-+
+--R                                       \|b
+--R     + 
+--R                                        +-------+
+--R                                +-----+ |b x + a
+--R                               \|- b d  |-------
+--R                   +-+ +-+             \|d x + c
+--R       (a d - b c)\|b \|d atan(------------------)
+--R                                        b
+--R  /
+--R       +-----+ +-+ +-+
+--R     d\|- b d \|b \|d
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 649
+d0d:=D(m0d,x)
+--R 
+--R
+--R   (12)  0
+--R                                                    Type: Expression(Integer)
+--E 612
+
+)clear all
+
+--S 613 of 649
+t0:=sqrt((-1+x)/(5+3*x))
+--R 
+--R
+--R         +------+
+--R         | x - 1
+--R   (1)   |------
+--R        \|3x + 5
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 649
+r0a:=-8/3*atanh(sqrt(3)*sqrt((-1+x)/(5+3*x)))/sqrt(3)+1/3*(5+3*x)*_
+   sqrt((-1+x)/(5+3*x))
+--R 
+--R
+--R                      +------+                 +------+
+--R                  +-+ | x - 1              +-+ | x - 1
+--R        - 8atanh(\|3  |------ ) + (3x + 5)\|3  |------
+--R                     \|3x + 5                 \|3x + 5
+--R   (2)  -----------------------------------------------
+--R                               +-+
+--R                             3\|3
+--R                                                    Type: Expression(Integer)
+--E 614
+
+--S 615 of 649
+r0b:=-8/3*atanh(sqrt(3)*sqrt((-1+x)/(5+3*x)))/sqrt(3)+_
+   8/3*sqrt((-1+x)/(5+3*x))/(1+3*(1-x)/(5+3*x))
+--R 
+--R
+--R                      +------+                 +------+
+--R                  +-+ | x - 1              +-+ | x - 1
+--R        - 8atanh(\|3  |------ ) + (3x + 5)\|3  |------
+--R                     \|3x + 5                 \|3x + 5
+--R   (3)  -----------------------------------------------
+--R                               +-+
+--R                             3\|3
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       +------+                                  +------+
+--R                       | x - 1               +-+             +-+ | x - 1
+--R        4log((9x + 15) |------  + (- 3x - 1)\|3 ) + (3x + 5)\|3  |------
+--R                      \|3x + 5                                  \|3x + 5
+--R   (4)  -----------------------------------------------------------------
+--R                                        +-+
+--R                                      3\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 616
+
+--S 617 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R                       +------+                                 +------+
+--R                       | x - 1               +-+            +-+ | x - 1
+--R        4log((9x + 15) |------  + (- 3x - 1)\|3 ) + 8atanh(\|3  |------ )
+--R                      \|3x + 5                                 \|3x + 5
+--R   (5)  -----------------------------------------------------------------
+--R                                        +-+
+--R                                      3\|3
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R                       +------+                                 +------+
+--R                       | x - 1               +-+            +-+ | x - 1
+--R        4log((9x + 15) |------  + (- 3x - 1)\|3 ) + 8atanh(\|3  |------ )
+--R                      \|3x + 5                                 \|3x + 5
+--R   (7)  -----------------------------------------------------------------
+--R                                        +-+
+--R                                      3\|3
+--R                                                    Type: Expression(Integer)
+--E 619
+
+--S 620 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 620
+
+)clear all
+
+--S 621 of 649
+t0:=sqrt((-1+5*x)/(1+7*x))/x^2
+--R 
+--R
+--R         +------+
+--R         |5x - 1
+--R         |------
+--R        \|7x + 1
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 649
+r0a:=12*atan(sqrt((-1+5*x)/(1+7*x)))-(1+7*x)*sqrt((-1+5*x)/(1+7*x))/x
+--R 
+--R
+--R                  +------+               +------+
+--R                  |5x - 1                |5x - 1
+--R        12x atan( |------ ) + (- 7x - 1) |------
+--R                 \|7x + 1               \|7x + 1
+--R   (2)  -----------------------------------------
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 649
+r0b:=12*atan(sqrt((-1+5*x)/(1+7*x)))-12*sqrt((-1+5*x)/(1+7*x))/_
+   (1+(-1+5*x)/(1+7*x))
+--R 
+--R
+--R                  +------+               +------+
+--R                  |5x - 1                |5x - 1
+--R        12x atan( |------ ) + (- 7x - 1) |------
+--R                 \|7x + 1               \|7x + 1
+--R   (3)  -----------------------------------------
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +------+               +------+
+--R                  |5x - 1                |5x - 1
+--R        12x atan( |------ ) + (- 7x - 1) |------
+--R                 \|7x + 1               \|7x + 1
+--R   (4)  -----------------------------------------
+--R                            x
+--R                                         Type: Union(Expression(Integer),...)
+--E 624
+
+--S 625 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 628
+
+)clear all
+
+--S 629 of 649
+t0:=x/((1+x)*sqrt((1-x)/(1+x)))
+--R 
+--R
+--R                x
+--R   (1)  -----------------
+--R                +-------+
+--R                |- x + 1
+--R        (x + 1) |-------
+--R               \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 649
+r0a:=(-1+x)/sqrt((1-x)/(1+x))
+--R 
+--R
+--R           x - 1
+--R   (2)  ----------
+--R         +-------+
+--R         |- x + 1
+--R         |-------
+--R        \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 649
+r0b:=-2*sqrt((1-x)/(1+x))/(1+(1-x)/(1+x))
+--R 
+--R
+--R                  +-------+
+--R                  |- x + 1
+--R   (3)  (- x - 1) |-------
+--R                 \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +-------+
+--R                  |- x + 1
+--R   (4)  (- x - 1) |-------
+--R                 \| x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 632
+
+--S 633 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 633
+
+--S 634 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 634
+
+--S 635 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 636
+
+)clear all
+
+--S 637 of 649
+t0:=x/((1+x)*sqrt(-1+2/(1+x)))
+--R 
+--R
+--R                x
+--R   (1)  -----------------
+--R                +-------+
+--R                |- x + 1
+--R        (x + 1) |-------
+--R               \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 649
+r0:=-(1+x)*sqrt(-1+2/(1+x))
+--R 
+--R
+--R                  +-------+
+--R                  |- x + 1
+--R   (2)  (- x - 1) |-------
+--R                 \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +-------+
+--R                  |- x + 1
+--R   (3)  (- x - 1) |-------
+--R                 \| x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 639
+
+--S 640 of 649
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 649
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 641
+
+)clear all
+
+--S 642 of 649
+t0:=x/((1+x)*sqrt((2+x)/(3+x)))
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R                +-----+
+--R                |x + 2
+--R        (x + 1) |-----
+--R               \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 642
+
+--S 643 of 649
+r0a:=-asinh(sqrt(2+x))+2*atanh(sqrt(2)*sqrt((2+x)/(3+x)))*sqrt(2)+_
+   sqrt(2+x)*sqrt(3+x)
+--R 
+--R
+--R                        +-----+
+--R          +-+       +-+ |x + 2            +-----+     +-----+ +-----+
+--R   (2)  2\|2 atanh(\|2  |----- ) - asinh(\|x + 2 ) + \|x + 2 \|x + 3
+--R                       \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 649
+r0b:=-atanh(sqrt((2+x)/(3+x)))+2*atanh(sqrt(2)*sqrt((2+x)/(3+x)))*_
+   sqrt(2)+sqrt((2+x)/(3+x))/(1+(-2-x)/(3+x))
+--R 
+--R
+--R                        +-----+           +-----+            +-----+
+--R          +-+       +-+ |x + 2            |x + 2             |x + 2
+--R   (3)  2\|2 atanh(\|2  |----- ) - atanh( |----- ) + (x + 3) |-----
+--R                       \|x + 3           \|x + 3            \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 644
+
+--S 645 of 649
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R                             +-----+
+--R                         +-+ |x + 2
+--R                (2x + 6)\|2  |-----  + 3x + 7         +-----+
+--R         +-+                \|x + 3                   |x + 2
+--R       2\|2 log(-----------------------------) - log( |-----  + 1)
+--R                            x + 1                    \|x + 3
+--R     + 
+--R            +-----+                 +-----+
+--R            |x + 2                  |x + 2
+--R       log( |-----  - 1) + (2x + 6) |-----
+--R           \|x + 3                 \|x + 3
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 645
+
+--S 646 of 649
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R                             +-----+
+--R                         +-+ |x + 2
+--R                (2x + 6)\|2  |-----  + 3x + 7         +-----+
+--R         +-+                \|x + 3                   |x + 2
+--R       2\|2 log(-----------------------------) - log( |-----  + 1)
+--R                            x + 1                    \|x + 3
+--R     + 
+--R            +-----+                        +-----+
+--R            |x + 2           +-+       +-+ |x + 2             +-----+
+--R       log( |-----  - 1) - 4\|2 atanh(\|2  |----- ) + 2asinh(\|x + 2 )
+--R           \|x + 3                        \|x + 3
+--R     + 
+--R                                      +-----+
+--R           +-----+ +-----+            |x + 2
+--R       - 2\|x + 2 \|x + 3  + (2x + 6) |-----
+--R                                     \|x + 3
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 649
+d0a:=D(m0a,x)
+--R 
+--R
+--R         +-----+
+--R         |x + 2  +-----+ +-----+
+--R         |----- \|x + 2 \|x + 3  - x - 2
+--R        \|x + 3
+--R   (6)  --------------------------------
+--R                 +-----+ +-----+
+--R                \|x + 2 \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 649
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R                             +-----+
+--R                         +-+ |x + 2
+--R                (2x + 6)\|2  |-----  + 3x + 7         +-----+
+--R         +-+                \|x + 3                   |x + 2
+--R       2\|2 log(-----------------------------) - log( |-----  + 1)
+--R                            x + 1                    \|x + 3
+--R     + 
+--R            +-----+                        +-----+            +-----+
+--R            |x + 2           +-+       +-+ |x + 2             |x + 2
+--R       log( |-----  - 1) - 4\|2 atanh(\|2  |----- ) + 2atanh( |----- )
+--R           \|x + 3                        \|x + 3            \|x + 3
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 649
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 649
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich20c.input.pamphlet b/src/input/rich20c.input.pamphlet
new file mode 100644
index 0000000..65b49b0
--- /dev/null
+++ b/src/input/rich20c.input.pamphlet
@@ -0,0 +1,19679 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich20c.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|y'[x] f[y[x]]|
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich20c.output
+)spool rich20c.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 534
+t0:=1/sqrt(1+sqrt(1/x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         | +-+
+--R         | |1
+--R         | |-  + 1
+--R        \|\|x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 534
+r0:=3/2*atanh(sqrt(1+sqrt(1/x)))+x*sqrt(1+sqrt(1/x))-_
+   3/2*sqrt(1+sqrt(1/x))/sqrt(1/x)
+--R 
+--R
+--R                     +--------+                +--------+
+--R           +-+       | +-+            +-+      | +-+
+--R           |1        | |1             |1       | |1
+--R        3  |- atanh( | |-  + 1  + (2x |-  - 3) | |-  + 1
+--R          \|x       \|\|x            \|x      \|\|x
+--R   (2)  -------------------------------------------------
+--R                                 +-+
+--R                                 |1
+--R                              2  |-
+--R                                \|x
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         +--------+              +--------+                        +--------+
+--R         | +-+                   | +-+                   +-+       | +-+
+--R         | |1                    | |1                    |1        | |1
+--R   3log( | |-  + 1  + 1) - 3log( | |-  + 1  - 1) + (- 6x |-  + 4x) | |-  + 1
+--R        \|\|x                   \|\|x                   \|x       \|\|x
+--R   --------------------------------------------------------------------------
+--R                                        4
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 534
+m0:=a0-r0
+--R 
+--R
+--R              +--------+              +--------+                +--------+
+--R              | +-+                   | +-+                     | +-+
+--R              | |1                    | |1                      | |1
+--R        3log( | |-  + 1  + 1) - 3log( | |-  + 1  - 1) - 6atanh( | |-  + 1 )
+--R             \|\|x                   \|\|x                     \|\|x
+--R   (4)  -------------------------------------------------------------------
+--R                                         4
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 534
+t0:=sqrt(1+1/x)/(1+x)^2
+--R 
+--R
+--R           +-----+
+--R           |x + 1
+--R           |-----
+--R          \|  x
+--R   (1)  -----------
+--R         2
+--R        x  + 2x + 1
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 534
+r0:=2/sqrt(1+1/x)
+--R 
+--R
+--R            2
+--R   (2)  --------
+--R         +-----+
+--R         |x + 1
+--R         |-----
+--R        \|  x
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2
+--R   (3)  --------
+--R         +-----+
+--R         |x + 1
+--R         |-----
+--R        \|  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 534
+t0:=sqrt(1+1/x)/sqrt(1-x^2)
+--R 
+--R
+--R           +-----+
+--R           |x + 1
+--R           |-----
+--R          \|  x
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 534
+r0a:=2*asin(sqrt(x))*sqrt(1+1/x)*sqrt(1-x)*sqrt(x)/sqrt(1-x^2)
+--R 
+--R
+--R                    +-----+
+--R          +-------+ |x + 1  +-+      +-+
+--R        2\|- x + 1  |----- \|x asin(\|x )
+--R                   \|  x
+--R   (2)  ---------------------------------
+--R                    +--------+
+--R                    |   2
+--R                   \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 534
+r0b:=-2*x*atan(sqrt(-1+1/x))*sqrt(-1+1/x^2)*sqrt(-1+1/x)*sqrt(1+1/x)/_
+   (sqrt(-2*(1+1/x)+(1+1/x)^2)*sqrt(1-x^2))
+--R 
+--R
+--R             +-------+ +-----+      +-------+
+--R             |- x + 1  |x + 1       |- x + 1
+--R          2x |-------  |----- atan( |------- )
+--R            \|   x    \|  x        \|   x
+--R   (3)  - ------------------------------------
+--R                        +--------+
+--R                        |   2
+--R                       \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    2
+--R                  2x  + x - 1
+--R   (4)  atan(---------------------)
+--R                +--------+ +-----+
+--R                |   2      |x + 1
+--R             2x\|- x  + 1  |-----
+--R                          \|  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 14
+
+--S 15 of 534
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R    +--------+            2                             +-----+
+--R    |   2               2x  + x - 1           +-------+ |x + 1  +-+      +-+
+--R   \|- x  + 1 atan(---------------------) - 2\|- x + 1  |----- \|x asin(\|x )
+--R                      +--------+ +-----+               \|  x
+--R                      |   2      |x + 1
+--R                   2x\|- x  + 1  |-----
+--R                                \|  x
+--R   --------------------------------------------------------------------------
+--R                                    +--------+
+--R                                    |   2
+--R                                   \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 15
+
+--S 16 of 534
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 534
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R      +-------+ +-----+      +-------+     +--------+            2
+--R      |- x + 1  |x + 1       |- x + 1      |   2               2x  + x - 1
+--R   2x |-------  |----- atan( |------- ) + \|- x  + 1 atan(---------------------)
+--R     \|   x    \|  x        \|   x                           +--------+ +-----+
+--R                                                             |   2      |x + 1
+--R                                                          2x\|- x  + 1  |-----
+--R                                                                       \|  x
+--R   -----------------------------------------------------------------------------
+--R                                     +--------+
+--R                                     |   2
+--R                                    \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 534
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 534
+t0:=1/(x+sqrt(3-2*x-x^2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-------------+
+--R         |   2
+--R        \|- x  - 2x + 3  + x
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 534
+r0:=atan((sqrt(3)-sqrt(3-2*x-x^2))/x)-1/2*log(1+(sqrt(3)-_
+   sqrt(3-2*x-x^2))^2/x^2)+1/14*log(1+sqrt(3)+sqrt(7)-sqrt(3)*(sqrt(3)-_
+   sqrt(3-2*x-x^2))/x)*(7-sqrt(7))+1/14*log(1+sqrt(3)-sqrt(7)-_
+   sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))/x)*(7+sqrt(7))
+--R 
+--R
+--R   (2)
+--R                            +-------------+
+--R                        +-+ |   2               +-+     +-+
+--R           +-+         \|3 \|- x  - 2x + 3  + x\|7  + x\|3  + x - 3
+--R       (- \|7  + 7)log(--------------------------------------------)
+--R                                             x
+--R     + 
+--R                          +-------------+
+--R                      +-+ |   2               +-+     +-+
+--R         +-+         \|3 \|- x  - 2x + 3  - x\|7  + x\|3  + x - 3
+--R       (\|7  + 7)log(--------------------------------------------)
+--R                                           x
+--R     + 
+--R                    +-------------+                     +-------------+
+--R                +-+ |   2                               |   2              +-+
+--R            - 2\|3 \|- x  - 2x + 3  - 2x + 6           \|- x  - 2x + 3  - \|3
+--R     - 7log(--------------------------------) - 14atan(-----------------------)
+--R                            2                                     x
+--R                           x
+--R  /
+--R     14
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-+
+--R         \|7
+--R      *
+--R                                +-------------+
+--R                      +-+       |   2               2       +-+     2
+--R             ((x - 3)\|3  + 3x)\|- x  - 2x + 3  + (x  - 3x)\|3  - 3x  - 6x + 9
+--R         log(-----------------------------------------------------------------)
+--R                                              2
+--R                                             x
+--R     + 
+--R       -
+--R             +-+
+--R            \|7
+--R         *
+--R            log
+--R                                      +-------------+
+--R                            +-+       |   2                 2       +-+     2
+--R                   ((x - 3)\|3  - 3x)\|- x  - 2x + 3  + (- x  + 3x)\|3  - 3x
+--R                 + 
+--R                   - 6x + 9
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R       log
+--R                                                +-------------+
+--R                        +-+       +-+      +-+  |   2
+--R              (((x - 3)\|3  - 3x)\|7  + 7x\|3 )\|- x  - 2x + 3
+--R            + 
+--R                   2       +-+     2           +-+     2 +-+     2
+--R              ((- x  + 3x)\|3  + 4x  - 6x + 9)\|7  - 7x \|3  + 7x  - 21x
+--R         /
+--R                               +-------------+
+--R                     +-+       |   2                 2       +-+     2
+--R            ((x - 3)\|3  - 3x)\|- x  - 2x + 3  + (- x  + 3x)\|3  - 3x  - 6x + 9
+--R     + 
+--R       log
+--R                                                +-------------+
+--R                        +-+       +-+      +-+  |   2
+--R              (((x - 3)\|3  + 3x)\|7  - 7x\|3 )\|- x  - 2x + 3
+--R            + 
+--R                 2       +-+     2           +-+     2 +-+     2
+--R              ((x  - 3x)\|3  + 4x  - 6x + 9)\|7  - 7x \|3  - 7x  + 21x
+--R         /
+--R                               +-------------+
+--R                     +-+       |   2               2       +-+     2
+--R            ((x - 3)\|3  + 3x)\|- x  - 2x + 3  + (x  - 3x)\|3  - 3x  - 6x + 9
+--R     + 
+--R                    +-------------+
+--R                    |   2              +-+           2           +-+
+--R           +-+     \|- x  - 2x + 3  - \|3         (2x  + 2x + 4)\|7  + 14x + 7
+--R       - 4\|7 atan(-----------------------) + log(----------------------------)
+--R                              x                             2
+--R                                                          2x  + 2x - 3
+--R     + 
+--R        +-+      2
+--R       \|7 log(2x  + 2x - 3)
+--R  /
+--R       +-+
+--R     4\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 21
+
+--S 22 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +-------------+
+--R                         +-+ |   2               +-+     +-+
+--R            +-+         \|3 \|- x  - 2x + 3  + x\|7  + x\|3  + x - 3
+--R       (- 2\|7  + 2)log(--------------------------------------------)
+--R                                              x
+--R     + 
+--R                             +-------------+
+--R                         +-+ |   2               +-+     +-+
+--R            +-+         \|3 \|- x  - 2x + 3  - x\|7  + x\|3  + x - 3
+--R       (- 2\|7  - 2)log(--------------------------------------------)
+--R                                              x
+--R     + 
+--R          +-+
+--R         \|7
+--R      *
+--R                                +-------------+
+--R                      +-+       |   2               2       +-+     2
+--R             ((x - 3)\|3  + 3x)\|- x  - 2x + 3  + (x  - 3x)\|3  - 3x  - 6x + 9
+--R         log(-----------------------------------------------------------------)
+--R                                              2
+--R                                             x
+--R     + 
+--R       -
+--R             +-+
+--R            \|7
+--R         *
+--R            log
+--R                                      +-------------+
+--R                            +-+       |   2                 2       +-+     2
+--R                   ((x - 3)\|3  - 3x)\|- x  - 2x + 3  + (- x  + 3x)\|3  - 3x
+--R                 + 
+--R                   - 6x + 9
+--R              /
+--R                  2
+--R                 x
+--R     + 
+--R       log
+--R                                                +-------------+
+--R                        +-+       +-+      +-+  |   2
+--R              (((x - 3)\|3  - 3x)\|7  + 7x\|3 )\|- x  - 2x + 3
+--R            + 
+--R                   2       +-+     2           +-+     2 +-+     2
+--R              ((- x  + 3x)\|3  + 4x  - 6x + 9)\|7  - 7x \|3  + 7x  - 21x
+--R         /
+--R                               +-------------+
+--R                     +-+       |   2                 2       +-+     2
+--R            ((x - 3)\|3  - 3x)\|- x  - 2x + 3  + (- x  + 3x)\|3  - 3x  - 6x + 9
+--R     + 
+--R       log
+--R                                                +-------------+
+--R                        +-+       +-+      +-+  |   2
+--R              (((x - 3)\|3  + 3x)\|7  - 7x\|3 )\|- x  - 2x + 3
+--R            + 
+--R                 2       +-+     2           +-+     2 +-+     2
+--R              ((x  - 3x)\|3  + 4x  - 6x + 9)\|7  - 7x \|3  - 7x  + 21x
+--R         /
+--R                               +-------------+
+--R                     +-+       |   2               2       +-+     2
+--R            ((x - 3)\|3  + 3x)\|- x  - 2x + 3  + (x  - 3x)\|3  - 3x  - 6x + 9
+--R     + 
+--R                        +-------------+
+--R                    +-+ |   2
+--R         +-+    - 2\|3 \|- x  - 2x + 3  - 2x + 6
+--R       2\|7 log(--------------------------------)
+--R                                2
+--R                               x
+--R     + 
+--R              2           +-+
+--R           (2x  + 2x + 4)\|7  + 14x + 7     +-+      2
+--R       log(----------------------------) + \|7 log(2x  + 2x - 3)
+--R                     2
+--R                   2x  + 2x - 3
+--R  /
+--R       +-+
+--R     4\|7
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 23
+
+)clear all
+
+--S 24 of 534
+t0:=1/(x+sqrt(3-2*x-x^2))^2
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R           +-------------+
+--R           |   2
+--R        2x\|- x  - 2x + 3  - 2x + 3
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 534
+r0:=-8/7*atanh((1+sqrt(3)-sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))/x)/sqrt(7))/_
+   sqrt(7)+2/7*(4-sqrt(3)+3*(sqrt(3)-sqrt(3-2*x-x^2))/x)/(2-sqrt(3)-_
+   2*(1+sqrt(3))*(sqrt(3)-sqrt(3-2*x-x^2))/x+sqrt(3)*(sqrt(3)-_
+   sqrt(3-2*x-x^2))^2/x^2)
+--R 
+--R
+--R   (2)
+--R                                  +-------------+
+--R                   +-+            |   2                2             +-+     2
+--R             (- 8x\|3  - 8x + 24)\|- x  - 2x + 3  + (8x  + 16x - 24)\|3  - 8x
+--R           + 
+--R             24x
+--R      *
+--R                    +-------------+
+--R                +-+ |   2               +-+
+--R               \|3 \|- x  - 2x + 3  + x\|3  + x - 3
+--R         atanh(------------------------------------)
+--R                                 +-+
+--R                               x\|7
+--R     + 
+--R                +-------------+
+--R            +-+ |   2                  2       +-+     2  +-+
+--R       - 3x\|7 \|- x  - 2x + 3  + ((- x  + 3x)\|3  + 4x )\|7
+--R  /
+--R                              +-------------+
+--R           +-+            +-+ |   2
+--R       (7x\|3  + 7x - 21)\|7 \|- x  - 2x + 3
+--R     + 
+--R             2             +-+     2        +-+
+--R       ((- 7x  - 14x + 21)\|3  + 7x  - 21x)\|7
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                       +-------------+
+--R              3      2             +-+ |   2               4      3      2
+--R           (8x  - 16x  - 36x + 36)\|3 \|- x  - 2x + 3  - 8x  - 56x  + 36x
+--R         + 
+--R           144x - 108
+--R      *
+--R         log
+--R                                                            +-------------+
+--R                    3     2           +-+ +-+     3      2  |   2
+--R                ((2x  - 4x  - 9x + 9)\|3 \|7  - 7x  + 21x )\|- x  - 2x + 3
+--R              + 
+--R                     4      3     2             +-+       4      3      2  +-+
+--R                (- 9x  - 14x  + 9x  + 36x - 27)\|7  + (14x  + 14x  - 21x )\|3
+--R           /
+--R                                         +-------------+
+--R                   3     2           +-+ |   2               4      3     2
+--R                (2x  - 4x  - 9x + 9)\|3 \|- x  - 2x + 3  - 2x  - 14x  + 9x
+--R              + 
+--R                36x - 27
+--R     + 
+--R                                             2           +-+
+--R              3      2             +-+    (2x  + 2x + 4)\|7  + 14x + 7
+--R           (8x  - 16x  - 36x + 36)\|3 log(----------------------------)
+--R                                                    2
+--R                                                  2x  + 2x - 3
+--R         + 
+--R                 2            +-+      3      2  +-+
+--R           ((- 8x  + 27x - 9)\|3  - 10x  + 30x )\|7
+--R      *
+--R          +-------------+
+--R          |   2
+--R         \|- x  - 2x + 3
+--R     + 
+--R                                                2           +-+
+--R            4      3      2                  (2x  + 2x + 4)\|7  + 14x + 7
+--R       (- 8x  - 56x  + 36x  + 144x - 108)log(----------------------------)
+--R                                                       2
+--R                                                     2x  + 2x - 3
+--R     + 
+--R           4      3      2  +-+     3      2             +-+
+--R       ((6x  + 20x  - 30x )\|3  + 8x  + 45x  - 90x + 27)\|7
+--R  /
+--R                                          +-------------+
+--R           3      2               +-+ +-+ |   2
+--R       (28x  - 56x  - 126x + 126)\|3 \|7 \|- x  - 2x + 3
+--R     + 
+--R             4       3       2               +-+
+--R       (- 28x  - 196x  + 126x  + 504x - 378)\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 26
+
+--S 27 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         4
+--R      *
+--R         log
+--R                                                            +-------------+
+--R                    3     2           +-+ +-+     3      2  |   2
+--R                ((2x  - 4x  - 9x + 9)\|3 \|7  - 7x  + 21x )\|- x  - 2x + 3
+--R              + 
+--R                     4      3     2             +-+       4      3      2  +-+
+--R                (- 9x  - 14x  + 9x  + 36x - 27)\|7  + (14x  + 14x  - 21x )\|3
+--R           /
+--R                                         +-------------+
+--R                   3     2           +-+ |   2               4      3     2
+--R                (2x  - 4x  - 9x + 9)\|3 \|- x  - 2x + 3  - 2x  - 14x  + 9x
+--R              + 
+--R                36x - 27
+--R     + 
+--R                    +-------------+
+--R                +-+ |   2               +-+
+--R               \|3 \|- x  - 2x + 3  + x\|3  + x - 3
+--R       16atanh(------------------------------------)
+--R                                 +-+
+--R                               x\|7
+--R     + 
+--R               2           +-+
+--R            (2x  + 2x + 4)\|7  + 14x + 7     +-+
+--R       4log(----------------------------) - \|7
+--R                      2
+--R                    2x  + 2x - 3
+--R  /
+--R        +-+
+--R     14\|7
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 28
+
+)clear all
+
+--S 29 of 534
+t0:=1/(x+sqrt(3-2*x-x^2))^3
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R                       +-------------+
+--R           2           |   2               3     2
+--R        (2x  - 2x + 3)\|- x  - 2x + 3  - 2x  - 6x  + 9x
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 534
+r0:=-12/49*atanh((1+sqrt(3)-sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))/x)/sqrt(7))/_
+   sqrt(7)-2/7*(4-sqrt(3)+(10-7*sqrt(3))*(sqrt(3)-sqrt(3-2*x-x^2))/x)/_
+   (sqrt(3)*(2-sqrt(3)-2*(1+sqrt(3))*(sqrt(3)-sqrt(3-2*x-x^2))/x+sqrt(3)*_
+   (sqrt(3)-sqrt(3-2*x-x^2))^2/x^2)^2)+4/49*sqrt(3)*(1+sqrt(3)-sqrt(3)*_
+   (sqrt(3)-sqrt(3-2*x-x^2))/x)/(2-sqrt(3)-2*(1+sqrt(3))*(sqrt(3)-_
+   sqrt(3-2*x-x^2))/x+sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))^2/x^2)+2/3*(3+_
+   2*sqrt(3))*(sqrt(3)-sqrt(3-2*x-x^2))^2/(x^2*(2-sqrt(3)-2*(1+sqrt(3))*_
+   (sqrt(3)-sqrt(3-2*x-x^2))/x+sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))^2/x^2)^2)-_
+   2*(sqrt(3)-sqrt(3-2*x-x^2))^3/(x^3*(2-sqrt(3)-2*(1+sqrt(3))*(sqrt(3)-_
+   sqrt(3-2*x-x^2))/x+sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))^2/x^2)^2)
+--R 
+--R
+--R   (2)
+--R                         13        12        11          10          9
+--R                   - 192x   + 4224x   + 9504x   - 156576x   + 135792x
+--R                 + 
+--R                           8           7          6            5            4
+--R                   1707264x  - 4952664x  - 736776x  + 24441912x  - 46381896x
+--R                 + 
+--R                            3            2
+--R                   40415760x  - 19210608x  + 6141096x - 1417176
+--R              *
+--R                  +-+
+--R                 \|3
+--R             + 
+--R                   13        12         11          10          9           8
+--R               576x   + 7488x   - 24480x   - 354816x   + 560304x  + 3868560x
+--R             + 
+--R                         7           6            5            4            3
+--R               - 9445896x  - 4898880x  + 42987672x  - 73483200x  + 70543872x
+--R             + 
+--R                          2
+--R               - 39680928x  + 9920232x
+--R          *
+--R              +-------------+
+--R              |   2
+--R             \|- x  - 2x + 3
+--R         + 
+--R                   14        13         12         11          10          9
+--R               192x   - 2688x   - 40992x   + 32928x   + 926352x   - 895104x
+--R             + 
+--R                         8            7           6            5            4
+--R               - 7017192x  + 14344776x  + 6491016x  - 54255096x  + 88914672x
+--R             + 
+--R                          3            2
+--R               - 81566352x  + 42987672x  - 9920232x
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R               14        13         12         11           10           9
+--R           576x   + 4032x   - 50400x   - 80640x   + 1136016x   - 1006992x
+--R         + 
+--R                     8            7           6            5             4
+--R           - 9149112x  + 24572160x  + 2367792x  - 96262992x  + 167909112x
+--R         + 
+--R                       3            2
+--R           - 136678752x  + 62828136x  - 19840464x + 4251528
+--R      *
+--R                    +-------------+
+--R                +-+ |   2               +-+
+--R               \|3 \|- x  - 2x + 3  + x\|3  + x - 3
+--R         atanh(------------------------------------)
+--R                                 +-+
+--R                               x\|7
+--R     + 
+--R                   13        12         11          10          9           8
+--R               152x   - 4268x   - 17488x   + 141320x   + 149490x  - 1662165x
+--R             + 
+--R                       7           6            5            4            3
+--R               1899396x  + 4498821x  - 16351956x  + 22205340x  - 15103422x
+--R             + 
+--R                       2
+--R               4481163x  - 236196x
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R                 13        12        11          10         9           8
+--R           - 128x   - 4204x   - 2904x   + 228256x   - 52200x  - 3006117x
+--R         + 
+--R                   7           6            5            4            3
+--R           4641084x  + 8676801x  - 31196826x  + 36705150x  - 22989744x
+--R         + 
+--R                   2
+--R           8929521x  - 1928934x
+--R      *
+--R              +-------------+
+--R          +-+ |   2
+--R         \|7 \|- x  - 2x + 3
+--R     + 
+--R                    14       13         12         11          10         9
+--R               - 96x   + 124x   + 23028x   + 30888x   - 589744x   - 34095x
+--R             + 
+--R                       8           7            6            5            4
+--R               5409621x  - 6851493x  - 12244527x  + 38889234x  - 42526944x
+--R             + 
+--R                        3           2
+--R               25537599x  - 9572499x  + 1928934x
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R                 14        13         12          11          10          9
+--R           - 616x   - 4900x   + 46580x   + 179176x   - 934470x   - 945639x
+--R         + 
+--R                   8           7            6            5            4
+--R           8367651x  - 8978607x  - 17760627x  + 62153082x  - 78784488x
+--R         + 
+--R                    3            2
+--R           49633965x  - 13679685x  + 708588x
+--R      *
+--R          +-+
+--R         \|7
+--R  /
+--R                   13         12         11          10          9           8
+--R               784x   - 17248x   - 38808x   + 639352x   - 554484x  - 6971328x
+--R             + 
+--R                        7           6            5             4             3
+--R               20223378x  + 3008502x  - 99804474x  + 189392742x  - 165031020x
+--R             + 
+--R                        2
+--R               78443316x  - 25076142x + 5786802
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R                  13         12         11           10           9            8
+--R           - 2352x   - 30576x   + 99960x   + 1448832x   - 2287908x  - 15796620x
+--R         + 
+--R                    7            6             5             4             3
+--R           38570742x  + 20003760x  - 175532994x  + 300056400x  - 288054144x
+--R         + 
+--R                     2
+--R           162030456x  - 40507614x
+--R      *
+--R              +-------------+
+--R          +-+ |   2
+--R         \|7 \|- x  - 2x + 3
+--R     + 
+--R                     14         13          12          11           10
+--R               - 784x   + 10976x   + 167384x   - 134456x   - 3782604x
+--R             + 
+--R                       9            8            7            6             5
+--R               3655008x  + 28653534x  - 58574502x  - 26504982x  + 221541642x
+--R             + 
+--R                           4             3             2
+--R               - 363068244x  + 333062604x  - 175532994x  + 40507614x
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R                  14         13          12          11           10           9
+--R           - 2352x   - 16464x   + 205800x   + 329280x   - 4638732x   + 4111884x
+--R         + 
+--R                    8             7           6             5             4
+--R           37358874x  - 100336320x  - 9668484x  + 393073884x  - 685628874x
+--R         + 
+--R                     3             2
+--R           558104904x  - 256548222x  + 81015228x - 17360406
+--R      *
+--R          +-+
+--R         \|7
+--R                                                    Type: Expression(Integer)
+--E 30
+
+--S 31 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     7       6        5        4         3        2
+--R                 144x  + 720x  - 3312x  - 5184x  + 14580x  + 4860x  - 20412x
+--R               + 
+--R                 8748
+--R          *
+--R                  +-------------+
+--R              +-+ |   2
+--R             \|3 \|- x  - 2x + 3
+--R         + 
+--R               8        7        6         5         4         3         2
+--R           144x  - 1440x  - 6336x  + 13392x  + 30132x  - 50544x  - 29160x
+--R         + 
+--R           69984x - 26244
+--R      *
+--R         log
+--R                                                            +-------------+
+--R                    3     2           +-+ +-+     3      2  |   2
+--R                ((2x  - 4x  - 9x + 9)\|3 \|7  - 7x  + 21x )\|- x  - 2x + 3
+--R              + 
+--R                     4      3     2             +-+       4      3      2  +-+
+--R                (- 9x  - 14x  + 9x  + 36x - 27)\|7  + (14x  + 14x  - 21x )\|3
+--R           /
+--R                                         +-------------+
+--R                   3     2           +-+ |   2               4      3     2
+--R                (2x  - 4x  - 9x + 9)\|3 \|- x  - 2x + 3  - 2x  - 14x  + 9x
+--R              + 
+--R                36x - 27
+--R     + 
+--R                     7       6        5        4         3        2
+--R                 144x  + 720x  - 3312x  - 5184x  + 14580x  + 4860x  - 20412x
+--R               + 
+--R                 8748
+--R          *
+--R                        2           +-+
+--R              +-+    (2x  + 2x + 4)\|7  + 14x + 7
+--R             \|3 log(----------------------------)
+--R                               2
+--R                             2x  + 2x - 3
+--R         + 
+--R                        6       5        4        3         2
+--R                 (- 144x  - 354x  + 5022x  - 4131x  - 24705x  + 46899x - 22599)
+--R              *
+--R                  +-+
+--R                 \|3
+--R             + 
+--R                    7        6        5         4         3         2
+--R               - 84x  + 2700x  + 5586x  - 25974x  - 18954x  + 84402x  - 47628x
+--R          *
+--R              +-+
+--R             \|7
+--R      *
+--R          +-------------+
+--R          |   2
+--R         \|- x  - 2x + 3
+--R     + 
+--R               8        7        6         5         4         3         2
+--R           144x  - 1440x  - 6336x  + 13392x  + 30132x  - 50544x  - 29160x
+--R         + 
+--R           69984x - 26244
+--R      *
+--R                2           +-+
+--R             (2x  + 2x + 4)\|7  + 14x + 7
+--R         log(----------------------------)
+--R                       2
+--R                     2x  + 2x - 3
+--R     + 
+--R                   8       7        6         5         4         3          2
+--R               244x  + 968x  - 5414x  - 14556x  + 34884x  + 36504x  - 100278x
+--R             + 
+--R               47628x
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R                 7        6        5         4         3          2
+--R           - 144x  + 1806x  + 2556x  - 28593x  + 13932x  + 105948x  - 163296x
+--R         + 
+--R           67797
+--R      *
+--R          +-+
+--R         \|7
+--R  /
+--R                7         6         5         4          3         2
+--R           2352x  + 11760x  - 54096x  - 84672x  + 238140x  + 79380x  - 333396x
+--R         + 
+--R           142884
+--R      *
+--R                  +-------------+
+--R          +-+ +-+ |   2
+--R         \|3 \|7 \|- x  - 2x + 3
+--R     + 
+--R                8         7          6          5          4          3
+--R           2352x  - 23520x  - 103488x  + 218736x  + 492156x  - 825552x
+--R         + 
+--R                    2
+--R           - 476280x  + 1143072x - 428652
+--R      *
+--R          +-+
+--R         \|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 31
+
+--S 32 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         12
+--R      *
+--R         log
+--R                                                            +-------------+
+--R                    3     2           +-+ +-+     3      2  |   2
+--R                ((2x  - 4x  - 9x + 9)\|3 \|7  - 7x  + 21x )\|- x  - 2x + 3
+--R              + 
+--R                     4      3     2             +-+       4      3      2  +-+
+--R                (- 9x  - 14x  + 9x  + 36x - 27)\|7  + (14x  + 14x  - 21x )\|3
+--R           /
+--R                                         +-------------+
+--R                   3     2           +-+ |   2               4      3     2
+--R                (2x  - 4x  - 9x + 9)\|3 \|- x  - 2x + 3  - 2x  - 14x  + 9x
+--R              + 
+--R                36x - 27
+--R     + 
+--R                    +-------------+
+--R                +-+ |   2               +-+
+--R               \|3 \|- x  - 2x + 3  + x\|3  + x - 3
+--R       48atanh(------------------------------------)
+--R                                 +-+
+--R                               x\|7
+--R     + 
+--R                2           +-+
+--R             (2x  + 2x + 4)\|7  + 14x + 7       +-+
+--R       12log(----------------------------) - 31\|7
+--R                       2
+--R                     2x  + 2x - 3
+--R  /
+--R         +-+
+--R     196\|7
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 534
+t0:=1/(x+sqrt(-3-2*x+x^2))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +-----------+
+--R         | 2
+--R        \|x  - 2x - 3  + x
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 534
+r0:=2*log(1-x-sqrt(-3-2*x+x^2))-3/2*log(x+sqrt(-3-2*x+x^2))+(-2)/(1-x-_
+   sqrt(-3-2*x+x^2))
+--R 
+--R
+--R   (2)
+--R            +-----------+               +-----------+
+--R            | 2                         | 2
+--R       (- 3\|x  - 2x - 3  - 3x + 3)log(\|x  - 2x - 3  + x)
+--R     + 
+--R          +-----------+                 +-----------+
+--R          | 2                           | 2
+--R       (4\|x  - 2x - 3  + 4x - 4)log(- \|x  - 2x - 3  - x + 1) + 4
+--R  /
+--R       +-----------+
+--R       | 2
+--R     2\|x  - 2x - 3  + 2x - 2
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +-----------+               +-----------+
+--R            | 2                         | 2
+--R       (- 5\|x  - 2x - 3  + 5x - 5)log(\|x  - 2x - 3  - x + 1)
+--R     + 
+--R          +-----------+               +-----------+
+--R          | 2                         | 2
+--R       (3\|x  - 2x - 3  - 3x + 3)log(\|x  - 2x - 3  - x)
+--R     + 
+--R            +-----------+               +-----------+
+--R            | 2                         | 2
+--R       (- 3\|x  - 2x - 3  + 3x - 3)log(\|x  - 2x - 3  - x - 3)
+--R     + 
+--R                                 +-----------+
+--R                                 | 2                                     2
+--R       (- 3log(2x + 3) + 4x - 1)\|x  - 2x - 3  + (3x - 3)log(2x + 3) - 4x  + 5x
+--R     + 
+--R       7
+--R  /
+--R       +-----------+
+--R       | 2
+--R     4\|x  - 2x - 3  - 4x + 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 36
+
+--S 37 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             +-----------+              +-----------+
+--R             | 2                        | 2
+--R       6log(\|x  - 2x - 3  + x) - 5log(\|x  - 2x - 3  - x + 1)
+--R     + 
+--R             +-----------+              +-----------+
+--R             | 2                        | 2
+--R       3log(\|x  - 2x - 3  - x) - 3log(\|x  - 2x - 3  - x - 3)
+--R     + 
+--R                 +-----------+
+--R                 | 2
+--R       - 8log(- \|x  - 2x - 3  - x + 1) - 3log(2x + 3) + 3
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 38
+
+)clear all
+
+--S 39 of 534
+t0:=1/(x+sqrt(-3-2*x+x^2))^2
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R           +-----------+
+--R           | 2               2
+--R        2x\|x  - 2x - 3  + 2x  - 2x - 3
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 534
+r0:=4*log(1-x-sqrt(-3-2*x+x^2))-4*log(x+sqrt(-3-2*x+x^2))+(-2)/(1-x-_
+   sqrt(-3-2*x+x^2))+3/2/(x+sqrt(-3-2*x+x^2))
+--R 
+--R
+--R   (2)
+--R                    +-----------+                        +-----------+
+--R                    | 2                2                 | 2
+--R       ((- 16x + 8)\|x  - 2x - 3  - 16x  + 24x + 24)log(\|x  - 2x - 3  + x)
+--R     + 
+--R                  +-----------+                          +-----------+
+--R                  | 2                2                   | 2
+--R       ((16x - 8)\|x  - 2x - 3  + 16x  - 24x - 24)log(- \|x  - 2x - 3  - x + 1)
+--R     + 
+--R         +-----------+
+--R         | 2
+--R       7\|x  - 2x - 3  + 7x - 3
+--R  /
+--R              +-----------+
+--R              | 2               2
+--R     (4x - 2)\|x  - 2x - 3  + 4x  - 6x - 6
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                           +-----------+
+--R              2            | 2                3     2
+--R         ((16x  + 8x - 24)\|x  - 2x - 3  - 16x  + 8x  + 64x + 24)
+--R      *
+--R              +-----------+
+--R              | 2
+--R         log(\|x  - 2x - 3  - x)
+--R     + 
+--R                             +-----------+
+--R                2            | 2                3     2
+--R         ((- 16x  - 8x + 24)\|x  - 2x - 3  + 16x  - 8x  - 64x - 24)
+--R      *
+--R                       +-----------+
+--R                       | 2              2
+--R         log((- x - 1)\|x  - 2x - 3  + x  - 3)
+--R     + 
+--R                                                             +-----------+
+--R              2                           3     2            | 2
+--R       ((- 16x  - 8x + 24)log(2x + 3) + 8x  + 2x  - 45x + 3)\|x  - 2x - 3
+--R     + 
+--R           3     2                            4     3      2
+--R       (16x  - 8x  - 64x - 24)log(2x + 3) - 8x  + 6x  + 63x  - 28x - 51
+--R  /
+--R                     +-----------+
+--R        2            | 2               3     2
+--R     (8x  + 4x - 12)\|x  - 2x - 3  - 8x  + 4x  + 32x + 12
+--R                                         Type: Union(Expression(Integer),...)
+--E 41
+
+--S 42 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-----------+              +-----------+
+--R              | 2                        | 2
+--R       16log(\|x  - 2x - 3  + x) + 8log(\|x  - 2x - 3  - x)
+--R     + 
+--R                  +-----------+
+--R                  | 2
+--R       - 16log(- \|x  - 2x - 3  - x + 1)
+--R     + 
+--R                        +-----------+
+--R                        | 2              2
+--R       - 8log((- x - 1)\|x  - 2x - 3  + x  - 3) - 8log(2x + 3) - 3
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 43
+
+)clear all
+
+--S 44 of 534
+t0:=1/(x+sqrt(-3-2*x+x^2))^3
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                       +-----------+
+--R           2           | 2               3     2
+--R        (4x  - 2x - 3)\|x  - 2x - 3  + 4x  - 6x  - 9x
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 534
+r0:=6*log(1-x-sqrt(-3-2*x+x^2))-6*log(x+sqrt(-3-2*x+x^2))+(-2)/(1-x-_
+   sqrt(-3-2*x+x^2))+3/4/(x+sqrt(-3-2*x+x^2))^2+4/(x+sqrt(-3-2*x+x^2))
+--R 
+--R
+--R   (2)
+--R                                         +-----------+
+--R                  3       2              | 2                 4       3       2
+--R           (- 192x  + 288x  + 240x - 72)\|x  - 2x - 3  - 192x  + 480x  + 336x
+--R         + 
+--R           - 504x - 216
+--R      *
+--R              +-----------+
+--R              | 2
+--R         log(\|x  - 2x - 3  + x)
+--R     + 
+--R                                       +-----------+
+--R                3       2              | 2                 4       3       2
+--R           (192x  - 288x  - 240x + 72)\|x  - 2x - 3  + 192x  - 480x  - 336x
+--R         + 
+--R           504x + 216
+--R      *
+--R                +-----------+
+--R                | 2
+--R         log(- \|x  - 2x - 3  - x + 1)
+--R     + 
+--R                         +-----------+
+--R           2             | 2                3       2
+--R       (96x  - 74x - 75)\|x  - 2x - 3  + 96x  - 170x  - 193x + 39
+--R  /
+--R                              +-----------+
+--R         3      2             | 2                4      3      2
+--R     (32x  - 48x  - 40x + 12)\|x  - 2x - 3  + 32x  - 80x  - 56x  + 84x + 36
+--R                                                    Type: Expression(Integer)
+--E 45
+
+--S 46 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                        +-----------+
+--R               4      3       2         | 2                5       3       2
+--R           (48x  + 48x  - 180x  - 216x)\|x  - 2x - 3  - 48x  + 324x  + 228x
+--R         + 
+--R           - 288x - 216
+--R      *
+--R              +-----------+
+--R              | 2
+--R         log(\|x  - 2x - 3  - x)
+--R     + 
+--R                                          +-----------+
+--R                 4      3       2         | 2                5       3       2
+--R           (- 48x  - 48x  + 180x  + 216x)\|x  - 2x - 3  + 48x  - 324x  - 228x
+--R         + 
+--R           288x + 216
+--R      *
+--R                       +-----------+
+--R                       | 2              2
+--R         log((- x - 1)\|x  - 2x - 3  + x  - 3)
+--R     + 
+--R                 4      3       2                         5      4       3
+--R           (- 48x  - 48x  + 180x  + 216x)log(2x + 3) + 16x  + 12x  - 256x
+--R         + 
+--R                2
+--R           - 41x  + 466x + 132
+--R      *
+--R          +-----------+
+--R          | 2
+--R         \|x  - 2x - 3
+--R     + 
+--R           5       3       2                               6     5       4
+--R       (48x  - 324x  - 228x  + 288x + 216)log(2x + 3) - 16x  + 4x  + 300x
+--R     + 
+--R             3       2
+--R       - 159x  - 931x  - 84x + 342
+--R  /
+--R                                +-----------+
+--R         4      3      2        | 2                5       3      2
+--R     (16x  + 16x  - 60x  - 72x)\|x  - 2x - 3  - 16x  + 108x  + 76x  - 96x - 72
+--R                                         Type: Union(Expression(Integer),...)
+--E 46
+
+--S 47 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           +-----------+              +-----------+
+--R           | 2                        | 2
+--R     6log(\|x  - 2x - 3  + x) + 3log(\|x  - 2x - 3  - x)
+--R   + 
+--R               +-----------+                           +-----------+
+--R               | 2                                     | 2              2
+--R     - 6log(- \|x  - 2x - 3  - x + 1) - 3log((- x - 1)\|x  - 2x - 3  + x  - 3)
+--R   + 
+--R     - 3log(2x + 3) - 4
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 534
+t0:=1/(x+sqrt(-3-4*x-x^2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-------------+
+--R         |   2
+--R        \|- x  - 4x - 3  + x
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 534
+r0:=-atan(sqrt(-1-x)/sqrt(3+x))-1/2*log(1+(-1-x)/(3+x))+_
+   1/2*log(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/sqrt(3+x))-_
+   atan((1-3*sqrt(-1-x)/sqrt(3+x))/sqrt(2))*sqrt(2)
+--R 
+--R
+--R   (2)
+--R                +-----+              +-------+
+--R           - 2x\|x + 3  + (- 2x - 6)\|- x - 1
+--R       log(-----------------------------------)
+--R                             +-----+
+--R                     (x + 3)\|x + 3
+--R     + 
+--R                    +-----+     +-------+           +-------+
+--R           +-+     \|x + 3  - 3\|- x - 1           \|- x - 1           2
+--R       - 2\|2 atan(----------------------) - 2atan(----------) - log(-----)
+--R                         +-+ +-----+                 +-----+         x + 3
+--R                        \|2 \|x + 3                 \|x + 3
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  +-------------+
+--R                  |   2
+--R        +-+    2x\|- x  - 4x - 3  - 4x - 3
+--R       \|2 log(---------------------------)
+--R                             2
+--R                            x
+--R     + 
+--R                      +-------------+                        +-------------+
+--R                      |   2                                  |   2
+--R          +-+    - 2x\|- x  - 4x - 3  - 4x - 3      +-+     \|- x  - 4x - 3
+--R       - \|2 log(-----------------------------) - 4\|2 atan(----------------)
+--R                                2                                 x + 2
+--R                               x
+--R     + 
+--R                             +-+                            +-+
+--R                    (2x + 3)\|2                    (2x + 3)\|2
+--R       - 4atan(---------------------) - 4atan(---------------------)
+--R                 +-------------+                +-------------+
+--R                 |   2                          |   2
+--R               3\|- x  - 4x - 3  - x          3\|- x  - 4x - 3  + x
+--R     + 
+--R                                               +-+
+--R         +-+      2                   (2x + 2)\|2
+--R       2\|2 log(2x  + 4x + 3) + 4atan(------------)
+--R                                        2
+--R                                      2x  + 4x + 1
+--R  /
+--R       +-+
+--R     8\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 51
+
+--S 52 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +-------------+
+--R                  |   2
+--R        +-+    2x\|- x  - 4x - 3  - 4x - 3
+--R       \|2 log(---------------------------)
+--R                             2
+--R                            x
+--R     + 
+--R                       +-----+              +-------+
+--R           +-+    - 2x\|x + 3  + (- 2x - 6)\|- x - 1
+--R       - 4\|2 log(-----------------------------------)
+--R                                    +-----+
+--R                            (x + 3)\|x + 3
+--R     + 
+--R                      +-------------+                        +-------------+
+--R                      |   2                                  |   2
+--R          +-+    - 2x\|- x  - 4x - 3  - 4x - 3      +-+     \|- x  - 4x - 3
+--R       - \|2 log(-----------------------------) - 4\|2 atan(----------------)
+--R                                2                                 x + 2
+--R                               x
+--R     + 
+--R               +-----+     +-------+                        +-+
+--R              \|x + 3  - 3\|- x - 1                (2x + 3)\|2
+--R       16atan(----------------------) - 4atan(---------------------)
+--R                    +-+ +-----+                 +-------------+
+--R                   \|2 \|x + 3                  |   2
+--R                                              3\|- x  - 4x - 3  - x
+--R     + 
+--R                             +-+                   +-------+
+--R                    (2x + 3)\|2           +-+     \|- x - 1
+--R       - 4atan(---------------------) + 8\|2 atan(----------)
+--R                 +-------------+                    +-----+
+--R                 |   2                             \|x + 3
+--R               3\|- x  - 4x - 3  + x
+--R     + 
+--R                                                                 +-+
+--R         +-+      2               +-+      2            (2x + 2)\|2
+--R       2\|2 log(2x  + 4x + 3) + 4\|2 log(-----) + 4atan(------------)
+--R                                         x + 3            2
+--R                                                        2x  + 4x + 1
+--R  /
+--R       +-+
+--R     8\|2
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R          +-------------+
+--R          |   2              2           +-------+ +-----+
+--R       (x\|- x  - 4x - 3  + x  + 4x + 3)\|- x - 1 \|x + 3
+--R     + 
+--R                       +-------------+
+--R           2           |   2              3     2
+--R       (- x  - 4x - 3)\|- x  - 4x - 3  + x  + 4x  + 3x
+--R  /
+--R                      +-------------+
+--R          2           |   2           +-------+ +-----+
+--R       (2x  + 4x + 3)\|- x  - 4x - 3 \|- x - 1 \|x + 3
+--R     + 
+--R                        +-------------+
+--R          3     2       |   2
+--R       (2x  + 4x  + 3x)\|- x  - 4x - 3
+--R                                                    Type: Expression(Integer)
+--E 53
+
+)clear all
+
+--S 54 of 534
+t0:=1/(x+sqrt(-3-4*x-x^2))^2
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R           +-------------+
+--R           |   2
+--R        2x\|- x  - 4x - 3  - 4x - 3
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 534
+r0:=atan((1-3*sqrt(-1-x)/sqrt(3+x))/sqrt(2))/sqrt(2)+_
+   (1-sqrt(-1-x)/sqrt(3+x))/(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/sqrt(3+x))
+--R 
+--R
+--R   (2)
+--R                                              +-----+     +-------+
+--R           +-----+            +-------+      \|x + 3  - 3\|- x - 1
+--R       (2x\|x + 3  + (2x + 6)\|- x - 1 )atan(----------------------)
+--R                                                   +-+ +-----+
+--R                                                  \|2 \|x + 3
+--R     + 
+--R                 +-+ +-----+           +-+ +-------+
+--R       (- x - 3)\|2 \|x + 3  + (x + 3)\|2 \|- x - 1
+--R  /
+--R        +-+ +-----+            +-+ +-------+
+--R     2x\|2 \|x + 3  + (2x + 6)\|2 \|- x - 1
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                             +-------------+
+--R                                         +-+ |   2
+--R            2           +-+     (4x + 6)\|2 \|- x  - 4x - 3
+--R       (- 2x  - 4x - 3)\|2 atan(----------------------------)
+--R                                         2
+--R                                       6x  + 20x + 15
+--R     + 
+--R                 +-------------+                                     +-+
+--R                 |   2                  2           +-+     (2x + 2)\|2
+--R       (8x + 12)\|- x  - 4x - 3  + (- 2x  - 4x - 3)\|2 atan(------------) + 4x
+--R                                                              2
+--R                                                            2x  + 4x + 1
+--R     + 
+--R       12
+--R  /
+--R        2
+--R     16x  + 32x + 24
+--R                                         Type: Union(Expression(Integer),...)
+--E 56
+
+--S 57 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               3     2       +-----+        3      2            +-------+
+--R         ((- 2x  - 4x  - 3x)\|x + 3  + (- 2x  - 10x  - 15x - 9)\|- x - 1 )
+--R      *
+--R                           +-------------+
+--R                       +-+ |   2
+--R              (4x + 6)\|2 \|- x  - 4x - 3
+--R         atan(----------------------------)
+--R                       2
+--R                     6x  + 20x + 15
+--R     + 
+--R               3      2        +-----+        3      2             +-------+
+--R         ((- 8x  - 16x  - 12x)\|x + 3  + (- 8x  - 40x  - 60x - 36)\|- x - 1 )
+--R      *
+--R               +-----+     +-------+
+--R              \|x + 3  - 3\|- x - 1
+--R         atan(----------------------)
+--R                    +-+ +-----+
+--R                   \|2 \|x + 3
+--R     + 
+--R                          +-------------+                                   +-+
+--R              2       +-+ |   2                  3     2           (2x + 2)\|2
+--R           (4x  + 6x)\|2 \|- x  - 4x - 3  + (- 2x  - 4x  - 3x)atan(------------)
+--R                                                                     2
+--R                                                                   2x  + 4x + 1
+--R         + 
+--R              3      2             +-+
+--R           (4x  + 22x  + 36x + 18)\|2
+--R      *
+--R          +-----+
+--R         \|x + 3
+--R     + 
+--R                                +-------------+
+--R              2             +-+ |   2
+--R           (4x  + 18x + 18)\|2 \|- x  - 4x - 3
+--R         + 
+--R                                               +-+
+--R              3      2                (2x + 2)\|2          3      2        +-+
+--R         (- 2x  - 10x  - 15x - 9)atan(------------) + (- 4x  - 18x  - 18x)\|2
+--R                                        2
+--R                                      2x  + 4x + 1
+--R      *
+--R          +-------+
+--R         \|- x - 1
+--R  /
+--R        3      2        +-+ +-----+      3      2             +-+ +-------+
+--R     (8x  + 16x  + 12x)\|2 \|x + 3  + (8x  + 40x  + 60x + 36)\|2 \|- x - 1
+--R                                                    Type: Expression(Integer)
+--E 57
+
+--S 58 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                           +-------------+
+--R              5     4      3      2        |   2               6      5       4
+--R           (4x  + 8x  - 26x  - 48x  - 18x)\|- x  - 4x - 3  + 4x  + 40x  + 126x
+--R         + 
+--R               3      2
+--R           144x  + 54x
+--R      *
+--R          +-------+ +-----+
+--R         \|- x - 1 \|x + 3
+--R     + 
+--R                                             +-------------+
+--R            6      5       4       3      2  |   2               7      6      5
+--R       (- 4x  - 40x  - 126x  - 144x  - 54x )\|- x  - 4x - 3  + 4x  + 24x  + 18x
+--R     + 
+--R             4       3       2
+--R       - 128x  - 288x  - 216x  - 54x
+--R  /
+--R                                                            +-------------+
+--R            7      6       5       4       3       2        |   2
+--R         (8x  + 80x  + 284x  + 528x  + 558x  + 324x  + 81x)\|- x  - 4x - 3
+--R      *
+--R          +-------+ +-----+
+--R         \|- x - 1 \|x + 3
+--R     + 
+--R            8      7      6       5       4        3       2
+--R         (8x  + 48x  + 68x  - 144x  - 670x  - 1092x  - 945x  - 432x - 81)
+--R      *
+--R          +-------------+
+--R          |   2
+--R         \|- x  - 4x - 3
+--R                                                    Type: Expression(Integer)
+--E 58
+
+)clear all
+
+--S 59 of 534
+t0:=1/(x+sqrt(-3-4*x-x^2))^3
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R                       +-------------+
+--R           2           |   2               3      2
+--R        (2x  - 4x - 3)\|- x  - 4x - 3  - 2x  - 12x  - 9x
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 534
+r0:=-3/2*atan((1-3*sqrt(-1-x)/sqrt(3+x))/sqrt(2))/sqrt(2)+_
+   1/9*(-5+9*sqrt(-1-x)/sqrt(3+x))/(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/sqrt(3+x))+_
+   1/6*(-1+3*sqrt(-1-x)/sqrt(3+x))/(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/sqrt(3+x))-_
+   2/9*(2-sqrt(-1-x)/sqrt(3+x))/(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/sqrt(3+x))^2
+--R 
+--R
+--R   (2)
+--R                2             +-------+ +-----+      3       2
+--R         ((- 36x  + 72x + 54)\|- x - 1 \|x + 3  + 36x  + 216x  + 162x)
+--R      *
+--R               +-----+     +-------+
+--R              \|x + 3  - 3\|- x - 1
+--R         atan(----------------------)
+--R                    +-+ +-----+
+--R                   \|2 \|x + 3
+--R     + 
+--R          2             +-+ +-------+ +-----+       3      2             +-+
+--R       (8x  + 56x + 15)\|2 \|- x - 1 \|x + 3  + (16x  + 42x  - 33x - 45)\|2
+--R  /
+--R         2             +-+ +-------+ +-----+         3       2         +-+
+--R     (24x  - 48x - 36)\|2 \|- x - 1 \|x + 3  + (- 24x  - 144x  - 108x)\|2
+--R                                                    Type: Expression(Integer)
+--E 60
+
+--S 61 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                            +-------------+
+--R                                                        +-+ |   2
+--R           4      3      2             +-+     (4x + 6)\|2 \|- x  - 4x - 3
+--R       (12x  + 48x  + 84x  + 72x + 27)\|2 atan(----------------------------)
+--R                                                        2
+--R                                                      6x  + 20x + 15
+--R     + 
+--R                                   +-------------+
+--R             3      2              |   2
+--R       (- 32x  - 88x  - 104x - 60)\|- x  - 4x - 3
+--R     + 
+--R                                                        +-+
+--R           4      3      2             +-+     (2x + 2)\|2        3      2
+--R       (12x  + 48x  + 84x  + 72x + 27)\|2 atan(------------) - 24x  - 64x  - 60x
+--R                                                 2
+--R                                               2x  + 4x + 1
+--R     + 
+--R       - 36
+--R  /
+--R        4       3       2
+--R     64x  + 256x  + 448x  + 384x + 144
+--R                                         Type: Union(Expression(Integer),...)
+--E 61
+
+--S 62 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 6       5       4        3        2               +-------+
+--R             (72x  + 144x  - 180x  - 1008x  - 1458x  - 972x - 243)\|- x - 1
+--R          *
+--R              +-----+
+--R             \|x + 3
+--R         + 
+--R                7       6        5        4        3        2
+--R           - 72x  - 720x  - 2556x  - 4752x  - 5022x  - 2916x  - 729x
+--R      *
+--R                           +-------------+
+--R                       +-+ |   2
+--R              (4x + 6)\|2 \|- x  - 4x - 3
+--R         atan(----------------------------)
+--R                       2
+--R                     6x  + 20x + 15
+--R     + 
+--R                  6       5       4        3        2                +-------+
+--R             (288x  + 576x  - 720x  - 4032x  - 5832x  - 3888x - 972)\|- x - 1
+--R          *
+--R              +-----+
+--R             \|x + 3
+--R         + 
+--R                 7        6         5         4         3         2
+--R           - 288x  - 2880x  - 10224x  - 19008x  - 20088x  - 11664x  - 2916x
+--R      *
+--R               +-----+     +-------+
+--R              \|x + 3  - 3\|- x - 1
+--R         atan(----------------------)
+--R                    +-+ +-----+
+--R                   \|2 \|x + 3
+--R     + 
+--R                                                            +-------------+
+--R                 5      4       3       2               +-+ |   2
+--R           (- 96x  - 72x  + 360x  + 840x  + 828x + 270)\|2 \|- x  - 4x - 3
+--R         + 
+--R                 6       5       4        3        2
+--R             (72x  + 144x  - 180x  - 1008x  - 1458x  - 972x - 243)
+--R          *
+--R                           +-+
+--R                  (2x + 2)\|2
+--R             atan(------------)
+--R                    2
+--R                  2x  + 4x + 1
+--R         + 
+--R                 6       5        4        3        2                +-+
+--R           (- 64x  - 776x  - 2408x  - 3688x  - 3132x  - 1242x - 108)\|2
+--R      *
+--R          +-------+ +-----+
+--R         \|- x - 1 \|x + 3
+--R     + 
+--R                                                            +-------------+
+--R           6       5        4        3        2         +-+ |   2
+--R       (96x  + 840x  + 2328x  + 3240x  + 2484x  + 810x)\|2 \|- x  - 4x - 3
+--R     + 
+--R               7       6        5        4        3        2
+--R         (- 72x  - 720x  - 2556x  - 4752x  - 5022x  - 2916x  - 729x)
+--R      *
+--R                       +-+
+--R              (2x + 2)\|2
+--R         atan(------------)
+--R                2
+--R              2x  + 4x + 1
+--R     + 
+--R              7       6        5      4        3        2                +-+
+--R       (- 128x  - 776x  - 1352x  - 48x  + 3036x  + 4806x  + 3240x + 810)\|2
+--R  /
+--R              6       5       4        3        2                +-+ +-------+
+--R         (192x  + 384x  - 480x  - 2688x  - 3888x  - 2592x - 648)\|2 \|- x - 1
+--R      *
+--R          +-----+
+--R         \|x + 3
+--R     + 
+--R              7        6        5         4         3        2          +-+
+--R       (- 192x  - 1920x  - 6816x  - 12672x  - 13392x  - 7776x  - 1944x)\|2
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  10       8        7        6         5         4        3
+--R               16x   - 768x  - 1920x  + 2704x  + 12272x  + 12252x  + 2448x
+--R             + 
+--R                      2
+--R               - 2781x  - 1620x - 243
+--R          *
+--R              +-------------+
+--R              |   2
+--R             \|- x  - 4x - 3
+--R         + 
+--R              11       10       9       8        7         6        5         4
+--R           16x   + 256x   + 960x  - 640x  - 8976x  - 11984x  + 7980x  + 31248x
+--R         + 
+--R                 3         2
+--R           28539x  + 11340x  + 1701x
+--R      *
+--R          +-------+ +-----+
+--R         \|- x - 1 \|x + 3
+--R     + 
+--R                11       10       9       8        7         6        5
+--R           - 16x   - 256x   - 960x  + 640x  + 8976x  + 11984x  - 7980x
+--R         + 
+--R                   4         3         2
+--R           - 31248x  - 28539x  - 11340x  - 1701x
+--R      *
+--R          +-------------+
+--R          |   2
+--R         \|- x  - 4x - 3
+--R     + 
+--R          12      11       10        9        8         7         6         5
+--R       16x   + 64x   - 720x   - 4992x  - 7280x  + 17328x  + 69452x  + 88272x
+--R     + 
+--R             4        3         2
+--R       43767x  - 5400x  - 15066x  - 5832x - 729
+--R  /
+--R              13        12        11         10         9         8          7
+--R           64x   + 1280x   + 8896x   + 30336x   + 53104x  + 23936x  - 104224x
+--R         + 
+--R                    6          5          4          3         2
+--R           - 278208x  - 360612x  - 287280x  - 142884x  - 40824x  - 5103x
+--R      *
+--R          +-------------+
+--R          |   2           +-------+ +-----+
+--R         \|- x  - 4x - 3 \|- x - 1 \|x + 3
+--R     + 
+--R              14       13       12         11          10          9          8
+--R           64x   + 512x   - 896x   - 25472x   - 136656x   - 403264x  - 765008x
+--R         + 
+--R                    7          6          5       4          3         2
+--R           - 971456x  - 804228x  - 368064x  + 864x  + 117288x  + 73629x
+--R         + 
+--R           20412x + 2187
+--R      *
+--R          +-------------+
+--R          |   2
+--R         \|- x  - 4x - 3
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 534
+t0:=x^3*(1+x)^3*(1+2*x)*sqrt(1-x^2-2*x^3-x^4)
+--R 
+--R
+--R                                     +-------------------+
+--R           7     6     5     4    3  |   4     3    2
+--R   (1)  (2x  + 7x  + 9x  + 5x  + x )\|- x  - 2x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 534
+r0a:=-1/15*(1-x^2-2*x^3-x^4)^(3/2)*(2+3*x^2+6*x^3+3*x^4)
+--R 
+--R
+--R                                                        +-------------------+
+--R           8      7      6      5     4     3    2      |   4     3    2
+--R        (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- x  - 2x  - x  + 1
+--R   (2)  ---------------------------------------------------------------------
+--R                                          15
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 534
+r0b:=-1/480*(15+8*(1/2+x)^2-16*(1/2+x)^4)^(3/2)-1/5120*(1-4*(1/2+x)^2)^2*_
+   (15+8*(1/2+x)^2-16*(1/2+x)^4)^(3/2)
+--R 
+--R
+--R   (3)
+--R                                                   +-------------------------+
+--R      8      7      6      5     4     3    2      |     4      3      2
+--R   (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- 16x  - 32x  - 16x  + 16
+--R   ---------------------------------------------------------------------------
+--R                                        60
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        +-------------------+
+--R           8      7      6      5     4     3    2      |   4     3    2
+--R        (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- x  - 2x  - x  + 1
+--R   (4)  ---------------------------------------------------------------------
+--R                                          15
+--R                                         Type: Union(Expression(Integer),...)
+--E 67
+
+--S 68 of 534
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 534
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 534
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R                                                         +-------------------+
+--R           8      7      6      5     4     3     2      |   4     3    2
+--R       (12x  + 48x  + 72x  + 48x  + 8x  - 8x  - 4x  - 8)\|- x  - 2x  - x  + 1
+--R     + 
+--R              8      7      6      5     4     3    2
+--R         (- 3x  - 12x  - 18x  - 12x  - 2x  + 2x  + x  + 2)
+--R      *
+--R          +-------------------------+
+--R          |     4      3      2
+--R         \|- 16x  - 32x  - 16x  + 16
+--R  /
+--R     60
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 534
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)
+--R            11      10       9       8      7      5      4     3
+--R         (8x   + 44x   + 100x  + 120x  + 72x  - 32x  - 20x  - 4x )
+--R      *
+--R          +-------------------+
+--R          |   4     3    2
+--R         \|- x  - 2x  - x  + 1
+--R     + 
+--R              11      10      9      8      7     5     4    3
+--R         (- 2x   - 11x   - 25x  - 30x  - 18x  + 8x  + 5x  + x )
+--R      *
+--R          +-------------------------+
+--R          |     4      3      2
+--R         \|- 16x  - 32x  - 16x  + 16
+--R  /
+--R      +-------------------------+ +-------------------+
+--R      |     4      3      2       |   4     3    2
+--R     \|- 16x  - 32x  - 16x  + 16 \|- x  - 2x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 71
+
+)clear all
+
+--S 72 of 534
+t0:=(1+2*x)*(x+x^2)^3*sqrt(1-(x+x^2)^2)
+--R 
+--R
+--R                                     +-------------------+
+--R           7     6     5     4    3  |   4     3    2
+--R   (1)  (2x  + 7x  + 9x  + 5x  + x )\|- x  - 2x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 534
+r0:=-1/15*(1-x^2-2*x^3-x^4)^(3/2)*(2+3*x^2+6*x^3+3*x^4)
+--R 
+--R
+--R                                                        +-------------------+
+--R           8      7      6      5     4     3    2      |   4     3    2
+--R        (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- x  - 2x  - x  + 1
+--R   (2)  ---------------------------------------------------------------------
+--R                                          15
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 534
+r0b:=-1/480*(15+8*(1/2+x)^2-16*(1/2+x)^4)^(3/2)-1/5120*(1-4*(1/2+x)^2)^2*_
+   (15+8*(1/2+x)^2-16*(1/2+x)^4)^(3/2)
+--R 
+--R
+--R   (3)
+--R                                                   +-------------------------+
+--R      8      7      6      5     4     3    2      |     4      3      2
+--R   (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- 16x  - 32x  - 16x  + 16
+--R   ---------------------------------------------------------------------------
+--R                                        60
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        +-------------------+
+--R           8      7      6      5     4     3    2      |   4     3    2
+--R        (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- x  - 2x  - x  + 1
+--R   (4)  ---------------------------------------------------------------------
+--R                                          15
+--R                                         Type: Union(Expression(Integer),...)
+--E 75
+
+--S 76 of 534
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R                                                   +-------------------+
+--R      8      7      6      5     4     3    2      |   4     3    2
+--R   (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- x  - 2x  - x  + 1  - 15r0a
+--R   -----------------------------------------------------------------------------
+--R                                         15
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 534
+d0a:=D(m0a,x)
+--R 
+--R
+--R            11      10      9      8      7     5     4    3
+--R        - 2x   - 11x   - 25x  - 30x  - 18x  + 8x  + 5x  + x
+--R   (6)  ----------------------------------------------------
+--R                        +-------------------+
+--R                        |   4     3    2
+--R                       \|- x  - 2x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 534
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R                                                         +-------------------+
+--R           8      7      6      5     4     3     2      |   4     3    2
+--R       (12x  + 48x  + 72x  + 48x  + 8x  - 8x  - 4x  - 8)\|- x  - 2x  - x  + 1
+--R     + 
+--R              8      7      6      5     4     3    2
+--R         (- 3x  - 12x  - 18x  - 12x  - 2x  + 2x  + x  + 2)
+--R      *
+--R          +-------------------------+
+--R          |     4      3      2
+--R         \|- 16x  - 32x  - 16x  + 16
+--R  /
+--R     60
+--R                                                    Type: Expression(Integer)
+--E 78
+
+--S 79 of 534
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)
+--R            11      10       9       8      7      5      4     3
+--R         (8x   + 44x   + 100x  + 120x  + 72x  - 32x  - 20x  - 4x )
+--R      *
+--R          +-------------------+
+--R          |   4     3    2
+--R         \|- x  - 2x  - x  + 1
+--R     + 
+--R              11      10      9      8      7     5     4    3
+--R         (- 2x   - 11x   - 25x  - 30x  - 18x  + 8x  + 5x  + x )
+--R      *
+--R          +-------------------------+
+--R          |     4      3      2
+--R         \|- 16x  - 32x  - 16x  + 16
+--R  /
+--R      +-------------------------+ +-------------------+
+--R      |     4      3      2       |   4     3    2
+--R     \|- 16x  - 32x  - 16x  + 16 \|- x  - 2x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 79
+
+)clear all
+
+--S 80 of 534
+t0:=(3*x+3*x^2+x^3)/(1+4*x+6*x^2+4*x^3+x^4)
+--R 
+--R
+--R              3     2
+--R             x  + 3x  + 3x
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  + 4x  + 6x  + 4x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 80
+
+--S 81 of 534
+r0:=1/3/(1+x)^3+log(1+x)
+--R 
+--R
+--R           3     2
+--R        (3x  + 9x  + 9x + 3)log(x + 1) + 1
+--R   (2)  ----------------------------------
+--R                  3     2
+--R                3x  + 9x  + 9x + 3
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3     2
+--R        (3x  + 9x  + 9x + 3)log(x + 1) + 1
+--R   (3)  ----------------------------------
+--R                  3     2
+--R                3x  + 9x  + 9x + 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 82
+
+--S 83 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 534
+t0:=(-1+3*x-3*x^2+x^3)/(1+4*x+6*x^2+4*x^3+x^4)
+--R 
+--R
+--R            3     2
+--R           x  - 3x  + 3x - 1
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  + 4x  + 6x  + 4x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 85
+
+--S 86 of 534
+r0:=8/3/(1+x)^3+(-6)/(1+x)^2+6/(1+x)+log(1+x)
+--R 
+--R
+--R           3     2                          2
+--R        (3x  + 9x  + 9x + 3)log(x + 1) + 18x  + 18x + 8
+--R   (2)  -----------------------------------------------
+--R                         3     2
+--R                       3x  + 9x  + 9x + 3
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3     2                          2
+--R        (3x  + 9x  + 9x + 3)log(x + 1) + 18x  + 18x + 8
+--R   (3)  -----------------------------------------------
+--R                         3     2
+--R                       3x  + 9x  + 9x + 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 87
+
+--S 88 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 89
+
+)clear all
+
+--S 90 of 534
+t0:=(8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                +---------------------+
+--R            4     3     2       |   4     3     2
+--R   (1)  (- x  + 4x  - 8x  + 8x)\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 90
+
+--S 91 of 534
+--r0:=1/7*(3-2*(-1+x)^2-(-1+x)^4)^(3/2)*(-1+x)+_
+--   16/5*elliptic_e(asin(1-x),-1/3)*sqrt(3)-_
+--   176/35*elliptic_f(asin(1-x),-1/3)*sqrt(3)+2/35*(13-3*(-1+x)^2)*_
+--   (-1+x)*sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 91
+
+--S 92 of 534
+--a0:=integrate(t0,x)
+--E 92
+
+--S 93 of 534
+--m0:=a0-r0
+--E 93
+
+--S 94 of 534
+--d0:=D(m0,x)
+--E 94
+
+)clear all
+
+--S 95 of 534
+t0:=(8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R         +---------------------+
+--R         |   4     3     2
+--R   (1)  \|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 534
+--r0:=2*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   4*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/3*(-1+x)*_
+--   sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 96
+
+--S 97 of 534
+--a0:=integrate(t0,x)
+--E 97
+
+--S 98 of 534
+--m0:=a0-r0
+--E 98
+
+--S 99 of 534
+--d0:=D(m0,x)
+--E 99
+
+)clear all
+
+--S 100 of 534
+t0:=1/(8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R         +---------------------+
+--R         |   4     3     2
+--R        \|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 534
+--r0:=-elliptic_f(asin(1-x),-1/3)/sqrt(3)
+--E 101
+
+--S 102 of 534
+--a0:=integrate(t0,x)
+--E 102
+
+--S 103 of 534
+--m0:=a0-r0
+--E 103
+
+--S 104 of 534
+--d0:=D(m0,x)
+--E 104
+
+)clear all
+
+--S 105 of 534
+t0:=1/(8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                1
+--R   (1)  - ---------------------------------------------
+--R                                +---------------------+
+--R            4     3     2       |   4     3     2
+--R          (x  - 4x  + 8x  - 8x)\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 105
+
+--S 106 of 534
+--r0:=1/8*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   1/4*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/24*(5+(-1+x)^2)*_
+--   (-1+x)/sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 106
+
+--S 107 of 534
+--a0:=integrate(t0,x)
+--E 107
+
+--S 108 of 534
+--m0:=a0-r0
+--E 108
+
+--S 109 of 534
+--d0:=D(m0,x)
+--E 109
+
+)clear all
+
+--S 110 of 534
+t0:=1/(8*x-8*x^2+4*x^3-x^4)^(5/2)
+--R 
+--R
+--R   (1)
+--R                                      1
+--R   -----------------------------------------------------------------------
+--R                                                   +---------------------+
+--R     8     7      6      5       4       3      2  |   4     3     2
+--R   (x  - 8x  + 32x  - 80x  + 128x  - 128x  + 64x )\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 534
+--r0:=1/72*(5+(-1+x)^2)*(-1+x)/(3-2*(-1+x)^2-(-1+x)^4)^(3/2)+_
+--   7/144*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   11/144*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/432*(26+7*(-1+x)^2)*_
+--   (-1+x)/sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 111
+
+--S 112 of 534
+--a0:=integrate(t0,x)
+--E 112
+
+--S 113 of 534
+--m0:=a0-r0
+--E 113
+
+--S 114 of 534
+--d0:=D(m0,x)
+--E 114
+
+)clear all
+
+--S 115 of 534
+t0:=((2-x)*x*(4-2*x+x^2))^(3/2)
+--R 
+--R
+--R                                +---------------------+
+--R            4     3     2       |   4     3     2
+--R   (1)  (- x  + 4x  - 8x  + 8x)\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 534
+--r0:=1/7*(3-2*(-1+x)^2-(-1+x)^4)^(3/2)*(-1+x)+_
+--   16/5*elliptic_e(asin(1-x),-1/3)*sqrt(3)-_
+--   176/35*elliptic_f(asin(1-x),-1/3)*sqrt(3)+2/35*(13-3*(-1+x)^2)*_
+--   (-1+x)*sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 116
+
+--S 117 of 534
+--a0:=integrate(t0,x)
+--E 117
+
+--S 118 of 534
+--m0:=a0-r0
+--E 118
+
+--S 119 of 534
+--d0:=D(m0,x)
+--E 119
+
+)clear all
+
+--S 120 of 534
+t0:=((2-x)*x*(4-2*x+x^2))^(1/2)
+--R 
+--R
+--R         +---------------------+
+--R         |   4     3     2
+--R   (1)  \|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 120
+
+--S 121 of 534
+--r0:=2*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   4*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/3*(-1+x)*_
+--   sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 121
+
+--S 122 of 534
+--a0:=integrate(t0,x)
+--E 122
+
+--S 123 of 534
+--m0:=a0-r0
+--E 123
+
+--S 124 of 534
+--d0:=D(m0,x)
+--E 124
+
+)clear all
+
+--S 125 of 534
+t0:=1/((2-x)*x*(4-2*x+x^2))^(1/2)
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R         +---------------------+
+--R         |   4     3     2
+--R        \|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 534
+--r0:=-elliptic_f(asin(1-x),-1/3)/sqrt(3)
+--E 126
+
+--S 127 of 534
+--a0:=integrate(t0,x)
+--E 127
+
+--S 128 of 534
+--m0:=a0-r0
+--E 128
+
+--S 129 of 534
+--d0:=D(m0,x)
+--E 129
+
+)clear all
+
+--S 130 of 534
+t0:=1/((2-x)*x*(4-2*x+x^2))^(3/2)
+--R 
+--R
+--R                                1
+--R   (1)  - ---------------------------------------------
+--R                                +---------------------+
+--R            4     3     2       |   4     3     2
+--R          (x  - 4x  + 8x  - 8x)\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 534
+--r0:=1/8*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   1/4*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/24*(5+(-1+x)^2)*_
+--   (-1+x)/sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 131
+
+--S 132 of 534
+--a0:=integrate(t0,x)
+--E 132
+
+--S 133 of 534
+--m0:=a0-r0
+--E 133
+
+--S 134 of 534
+--d0:=D(m0,x)
+--E 134
+
+)clear all
+
+--S 135 of 534
+t0:=1/((2-x)*x*(4-2*x+x^2))^(5/2)
+--R 
+--R
+--R   (1)
+--R                                      1
+--R   -----------------------------------------------------------------------
+--R                                                   +---------------------+
+--R     8     7      6      5       4       3      2  |   4     3     2
+--R   (x  - 8x  + 32x  - 80x  + 128x  - 128x  + 64x )\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 135
+
+--S 136 of 534
+--r0:=1/72*(5+(-1+x)^2)*(-1+x)/(3-2*(-1+x)^2-(-1+x)^4)^(3/2)+_
+--   7/144*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   11/144*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/432*_
+--   (26+7*(-1+x)^2)*(-1+x)/sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 136
+
+--S 137 of 534
+--a0:=integrate(t0,x)
+--E 137
+
+--S 138 of 534
+--m0:=a0-r0
+--E 138
+
+--S 139 of 534
+--d0:=D(m0,x)
+--E 139
+
+)clear all
+
+--S 140 of 534
+t0:=(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^4
+--R 
+--R
+--R   (1)
+--R      8 16        7 15       2 6 14       3 5 13           6        4 4  12
+--R     d x   + 16c d x   + 112c d x   + 448c d x   + (16a c d  + 1120c d )x
+--R   + 
+--R            2 5        5 3  11          3 4        6 2  10
+--R     (192a c d  + 1792c d )x   + (960a c d  + 1792c d )x
+--R   + 
+--R             4 3        7   9       2 2 4          5 2       8  8
+--R     (2560a c d  + 1024c d)x  + (96a c d  + 3840a c d  + 256c )x
+--R   + 
+--R          2 3 3          6   7         2 4 2          7  6        2 5   5
+--R     (768a c d  + 3072a c d)x  + (2304a c d  + 1024a c )x  + 3072a c d x
+--R   + 
+--R          3 3 2        2 6  4        3 4   3        3 5 2       4 4
+--R     (256a c d  + 1536a c )x  + 1024a c d x  + 1024a c x  + 256a c
+--R                                                    Type: Polynomial(Integer)
+--E 140
+
+--S 141 of 534
+r0:=c^4*(c^3+4*a*d^2)^4*x/d^8-8/3*c^5*(c^3+4*a*d^2)^3*(c/d+x)^3/d^6+_
+   4/5*c^3*(c^3+4*a*d^2)^2*(7*c^3+4*a*d^2)*(c/d+x)^5/d^4-8/7*c^4*_
+   (c^3+4*a*d^2)*(7*c^3+12*a*d^2)*(c/d+x)^7/d^2+2/9*c^2*(35*c^6+_
+   120*a*c^3*d^2+48*a^2*d^4)*(c/d+x)^9-8/11*c^3*d^2*(7*c^3+12*a*d^2)*_
+   (c/d+x)^11+4/13*c*d^4*(7*c^3+4*a*d^2)*(c/d+x)^13-8/15*c^2*_
+   d^6*(c/d+x)^15+1/17*d^8*(c/d+x)^17
+--R 
+--R
+--R   (2)
+--R        1  17 17      16 16   112  2 15 15      3 14 14
+--R       -- d  x   + c d  x   + --- c d  x   + 32c d  x
+--R       17                      15
+--R     + 
+--R        16      15   1120  4 13  13         2 14   448  5 12  12
+--R       (-- a c d   + ---- c d  )x   + (16a c d   + --- c d  )x
+--R        13            13                            3
+--R     + 
+--R        960    3 13   1792  6 11  11          4 12   512  7 10  10
+--R       (--- a c d   + ---- c d  )x   + (256a c d   + --- c d  )x
+--R         11            11                             5
+--R     + 
+--R        32  2 2 13   1280    5 11   256  8 9  9       2 3 12         6 10  8
+--R       (-- a c d   + ---- a c d   + --- c d )x  + (96a c d   + 384a c d  )x
+--R         3             3             9
+--R     + 
+--R        2304  2 4 11   1024    7 9  7       2 5 10 6
+--R       (---- a c d   + ---- a c d )x  + 512a c d  x
+--R          7              7
+--R     + 
+--R        256  3 3 11   1536  2 6 9  5       3 4 10 4   1024  3 5 9 3       4 4 9
+--R       (--- a c d   + ---- a c d )x  + 256a c d  x  + ---- a c d x  + 256a c d x
+--R         5              5                               3
+--R     + 
+--R         1792  3 8 6   5984  2 11 4   31664    14 2    76627  17
+--R       - ---- a c d  - ---- a c  d  - ----- a c  d  - ------ c
+--R          15            105            3003           109395
+--R  /
+--R      9
+--R     d
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 141
+
+--S 142 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  8 17      7 16   112  2 6 15      3 5 14    16      6   1120  4 4  13
+--R     -- d x   + c d x   + --- c d x   + 32c d x   + (-- a c d  + ---- c d )x
+--R     17                    15                        13           13
+--R   + 
+--R           2 5   448  5 3  12    960    3 4   1792  6 2  11
+--R     (16a c d  + --- c d )x   + (--- a c d  + ---- c d )x
+--R                  3               11           11
+--R   + 
+--R            4 3   512  7   10    32  2 2 4   1280    5 2   256  8  9
+--R     (256a c d  + --- c d)x   + (-- a c d  + ---- a c d  + --- c )x
+--R                   5              3            3            9
+--R   + 
+--R         2 3 3         6   8    2304  2 4 2   1024    7  7       2 5   6
+--R     (96a c d  + 384a c d)x  + (---- a c d  + ---- a c )x  + 512a c d x
+--R                                  7             7
+--R   + 
+--R      256  3 3 2   1536  2 6  5       3 4   4   1024  3 5 3       4 4
+--R     (--- a c d  + ---- a c )x  + 256a c d x  + ---- a c x  + 256a c x
+--R       5             5                            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 142
+
+--S 143 of 534
+m0:=a0-r0
+--R 
+--R
+--R        1792  3 8 6   5984  2 11 4   31664    14 2    76627  17
+--R        ---- a c d  + ---- a c  d  + ----- a c  d  + ------ c
+--R         15            105            3003           109395
+--R   (4)  -------------------------------------------------------
+--R                                    9
+--R                                   d
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 143
+
+--S 144 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 144
+
+)clear all
+
+--S 145 of 534
+t0:=(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^3
+--R 
+--R
+--R   (1)
+--R      6 12        5 11      2 4 10       3 3 9           4       4 2  8
+--R     d x   + 12c d x   + 60c d x   + 160c d x  + (12a c d  + 240c d )x
+--R   + 
+--R           2 3       5   7          3 2      6  6         4   5
+--R     (96a c d  + 192c d)x  + (288a c d  + 64c )x  + 384a c d x
+--R   + 
+--R         2 2 2         5  4       2 3   3       2 4 2      3 3
+--R     (48a c d  + 192a c )x  + 192a c d x  + 192a c x  + 64a c
+--R                                                    Type: Polynomial(Integer)
+--E 145
+
+--S 146 of 534
+r0:=64*a^3*c^3*x+64*a^2*c^4*x^3+48*a^2*c^3*d*x^4+48/5*a*c^2*(4*c^3+a*d^2)*_
+   x^5+64*a*c^4*d*x^6+32/7*c^3*(2*c^3+9*a*d^2)*x^7+12*c^2*d*(2*c^3+a*d^2)*_
+   x^8+4/3*c*d^2*(20*c^3+a*d^2)*x^9+16*c^3*d^3*x^10+60/11*c^2*d^4*x^11+_
+   c*d^5*x^12+1/13*d^6*x^13
+--R 
+--R
+--R   (2)
+--R      1  6 13      5 12   60  2 4 11      3 3 10    4      4   80  4 2  9
+--R     -- d x   + c d x   + -- c d x   + 16c d x   + (- a c d  + -- c d )x
+--R     13                   11                        3           3
+--R   + 
+--R           2 3      5   8    288    3 2   64  6  7        4   6
+--R     (12a c d  + 24c d)x  + (--- a c d  + -- c )x  + 64a c d x
+--R                              7            7
+--R   + 
+--R      48  2 2 2   192    5  5      2 3   4      2 4 3      3 3
+--R     (-- a c d  + --- a c )x  + 48a c d x  + 64a c x  + 64a c x
+--R       5           5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 146
+
+--S 147 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  6 13      5 12   60  2 4 11      3 3 10    4      4   80  4 2  9
+--R     -- d x   + c d x   + -- c d x   + 16c d x   + (- a c d  + -- c d )x
+--R     13                   11                        3           3
+--R   + 
+--R           2 3      5   8    288    3 2   64  6  7        4   6
+--R     (12a c d  + 24c d)x  + (--- a c d  + -- c )x  + 64a c d x
+--R                              7            7
+--R   + 
+--R      48  2 2 2   192    5  5      2 3   4      2 4 3      3 3
+--R     (-- a c d  + --- a c )x  + 48a c d x  + 64a c x  + 64a c x
+--R       5           5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 147
+
+--S 148 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 148
+
+--S 149 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 149
+
+)clear all
+
+--S 150 of 534
+t0:=(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^2
+--R 
+--R
+--R   (1)
+--R      4 8       3 7      2 2 6      3   5          2      4  4        2   3
+--R     d x  + 8c d x  + 24c d x  + 32c d x  + (8a c d  + 16c )x  + 32a c d x
+--R   + 
+--R          3 2      2 2
+--R     32a c x  + 16a c
+--R                                                    Type: Polynomial(Integer)
+--E 150
+
+--S 151 of 534
+r0:=16*a^2*c^2*x+32/3*a*c^3*x^3+8*a*c^2*d*x^4+8/5*c*(2*c^3+a*d^2)*x^5+_
+   16/3*c^3*d*x^6+24/7*c^2*d^2*x^7+c*d^3*x^8+1/9*d^4*x^9
+--R 
+--R
+--R   (2)
+--R     1  4 9      3 8   24  2 2 7   16  3   6    8      2   16  4  5       2   4
+--R     - d x  + c d x  + -- c d x  + -- c d x  + (- a c d  + -- c )x  + 8a c d x
+--R     9                  7           3           5           5
+--R   + 
+--R     32    3 3      2 2
+--R     -- a c x  + 16a c x
+--R      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 151
+
+--S 152 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  4 9      3 8   24  2 2 7   16  3   6    8      2   16  4  5       2   4
+--R     - d x  + c d x  + -- c d x  + -- c d x  + (- a c d  + -- c )x  + 8a c d x
+--R     9                  7           3           5           5
+--R   + 
+--R     32    3 3      2 2
+--R     -- a c x  + 16a c x
+--R      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 152
+
+--S 153 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 153
+
+--S 154 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 154
+
+)clear all
+
+--S 155 of 534
+t0:=4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4
+--R 
+--R
+--R         2 4         3     2 2
+--R   (1)  d x  + 4c d x  + 4c x  + 4a c
+--R                                                    Type: Polynomial(Integer)
+--E 155
+
+--S 156 of 534
+r0:=4*a*c*x+4/3*c^2*x^3+c*d*x^4+1/5*d^2*x^5
+--R 
+--R
+--R        1  2 5        4   4  2 3
+--R   (2)  - d x  + c d x  + - c x  + 4a c x
+--R        5                 3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 156
+
+--S 157 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1  2 5        4   4  2 3
+--R   (3)  - d x  + c d x  + - c x  + 4a c x
+--R        5                 3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 157
+
+--S 158 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 158
+
+--S 159 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 159
+
+)clear all
+
+--S 160 of 534
+t0:=1/(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R         2 4         3     2 2
+--R        d x  + 4c d x  + 4c x  + 4a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 160
+
+--S 161 of 534
+r0:=1/4*atanh(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)-2*d*sqrt(-a))))/(c^(3/4)*_
+   sqrt(-a)*sqrt(c^(3/2)-2*d*sqrt(-a)))-1/4*atanh(d*(c/d+x)/(c^(1/4)*_
+   sqrt(c^(3/2)+2*d*sqrt(-a))))/(c^(3/4)*sqrt(-a)*sqrt(c^(3/2)+2*d*sqrt(-a)))
+--R 
+--R
+--R   (2)
+--R        +----------------+
+--R        |  +-+      +---+               d x + c
+--R       \|c\|c  + 2d\|- a  atanh(-----------------------)
+--R                                     +----------------+
+--R                                4+-+ |  +-+      +---+
+--R                                \|c \|c\|c  - 2d\|- a
+--R     + 
+--R          +----------------+
+--R          |  +-+      +---+               d x + c
+--R       - \|c\|c  - 2d\|- a  atanh(-----------------------)
+--R                                       +----------------+
+--R                                  4+-+ |  +-+      +---+
+--R                                  \|c \|c\|c  + 2d\|- a
+--R  /
+--R                  +----------------+ +----------------+
+--R       +---+4+-+3 |  +-+      +---+  |  +-+      +---+
+--R     4\|- a \|c  \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +------------------------------------------------------------+
+--R             |                   +-----------------------------------+
+--R             |                   |                   2
+--R             |     2 2        3  |                  d
+--R             |(128a d  + 32a c ) |- ---------------------------------  - 1
+--R             |                   |       3 3 4        2 6 2         9
+--R             |                  \|  4096a c d  + 2048a c d  + 256a c
+--R             |------------------------------------------------------------
+--R             |                          2 2        3
+--R            \|                       64a d  + 16a c
+--R         *
+--R            log
+--R                                          +-----------------------------------+
+--R                                          |                   2
+--R                          2 4 2        7  |                  d
+--R                     (256a c d  + 64a c ) |- ---------------------------------
+--R                                          |       3 3 4        2 6 2         9
+--R                                         \|  4096a c d  + 2048a c d  + 256a c
+--R                   + 
+--R                             2
+--R                     - 8a c d
+--R                *
+--R                  +------------------------------------------------------------+
+--R                  |                   +-----------------------------------+
+--R                  |                   |                   2
+--R                  |     2 2        3  |                  d
+--R                  |(128a d  + 32a c ) |- ---------------------------------  - 1
+--R                  |                   |       3 3 4        2 6 2         9
+--R                  |                  \|  4096a c d  + 2048a c d  + 256a c
+--R                  |------------------------------------------------------------
+--R                  |                          2 2        3
+--R                 \|                       64a d  + 16a c
+--R               + 
+--R                  2
+--R                 d x + c d
+--R     + 
+--R          +--------------------------------------------------------------+
+--R          |                     +-----------------------------------+
+--R          |                     |                   2
+--R          |       2 2        3  |                  d
+--R          |(- 128a d  - 32a c ) |- ---------------------------------  - 1
+--R          |                     |       3 3 4        2 6 2         9
+--R          |                    \|  4096a c d  + 2048a c d  + 256a c
+--R          |--------------------------------------------------------------
+--R          |                           2 2        3
+--R         \|                        64a d  + 16a c
+--R      *
+--R         log
+--R                                       +-----------------------------------+
+--R                                       |                   2
+--R                       2 4 2        7  |                  d
+--R                  (256a c d  + 64a c ) |- ---------------------------------
+--R                                       |       3 3 4        2 6 2         9
+--R                                      \|  4096a c d  + 2048a c d  + 256a c
+--R                + 
+--R                        2
+--R                  8a c d
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |                     +-----------------------------------+
+--R               |                     |                   2
+--R               |       2 2        3  |                  d
+--R               |(- 128a d  - 32a c ) |- ---------------------------------  - 1
+--R               |                     |       3 3 4        2 6 2         9
+--R               |                    \|  4096a c d  + 2048a c d  + 256a c
+--R               |--------------------------------------------------------------
+--R               |                           2 2        3
+--R              \|                        64a d  + 16a c
+--R            + 
+--R               2
+--R              d x + c d
+--R     + 
+--R       -
+--R             +--------------------------------------------------------------+
+--R             |                     +-----------------------------------+
+--R             |                     |                   2
+--R             |       2 2        3  |                  d
+--R             |(- 128a d  - 32a c ) |- ---------------------------------  - 1
+--R             |                     |       3 3 4        2 6 2         9
+--R             |                    \|  4096a c d  + 2048a c d  + 256a c
+--R             |--------------------------------------------------------------
+--R             |                           2 2        3
+--R            \|                        64a d  + 16a c
+--R         *
+--R            log
+--R                              2 4 2        7
+--R                       (- 256a c d  - 64a c )
+--R                    *
+--R                        +-----------------------------------+
+--R                        |                   2
+--R                        |                  d
+--R                        |- ---------------------------------
+--R                        |       3 3 4        2 6 2         9
+--R                       \|  4096a c d  + 2048a c d  + 256a c
+--R                   + 
+--R                             2
+--R                     - 8a c d
+--R                *
+--R                   ROOT
+--R                                   2 2        3
+--R                            (- 128a d  - 32a c )
+--R                         *
+--R                             +-----------------------------------+
+--R                             |                   2
+--R                             |                  d
+--R                             |- ---------------------------------
+--R                             |       3 3 4        2 6 2         9
+--R                            \|  4096a c d  + 2048a c d  + 256a c
+--R                        + 
+--R                          - 1
+--R                     /
+--R                           2 2        3
+--R                        64a d  + 16a c
+--R               + 
+--R                  2
+--R                 d x + c d
+--R     + 
+--R          +------------------------------------------------------------+
+--R          |                   +-----------------------------------+
+--R          |                   |                   2
+--R          |     2 2        3  |                  d
+--R          |(128a d  + 32a c ) |- ---------------------------------  - 1
+--R          |                   |       3 3 4        2 6 2         9
+--R          |                  \|  4096a c d  + 2048a c d  + 256a c
+--R          |------------------------------------------------------------
+--R          |                          2 2        3
+--R         \|                       64a d  + 16a c
+--R      *
+--R         log
+--R                                         +-----------------------------------+
+--R                                         |                   2
+--R                         2 4 2        7  |                  d
+--R                  (- 256a c d  - 64a c ) |- ---------------------------------
+--R                                         |       3 3 4        2 6 2         9
+--R                                        \|  4096a c d  + 2048a c d  + 256a c
+--R                + 
+--R                        2
+--R                  8a c d
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |                   +-----------------------------------+
+--R                 |                   |                   2
+--R                 |     2 2        3  |                  d
+--R                 |(128a d  + 32a c ) |- ---------------------------------  - 1
+--R                 |                   |       3 3 4        2 6 2         9
+--R                 |                  \|  4096a c d  + 2048a c d  + 256a c
+--R                 |------------------------------------------------------------
+--R                 |                          2 2        3
+--R                \|                       64a d  + 16a c
+--R            + 
+--R               2
+--R              d x + c d
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 162
+
+--S 163 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R              +---+4+-+3
+--R            2\|- a \|c
+--R         *
+--R             +------------------------------------------------------------+
+--R             |                   +-----------------------------------+
+--R             |                   |                   2
+--R             |     2 2        3  |                  d
+--R             |(128a d  + 32a c ) |- ---------------------------------  - 1
+--R             |                   |       3 3 4        2 6 2         9
+--R             |                  \|  4096a c d  + 2048a c d  + 256a c
+--R             |------------------------------------------------------------
+--R             |                          2 2        3
+--R            \|                       64a d  + 16a c
+--R         *
+--R             +----------------+ +----------------+
+--R             |  +-+      +---+  |  +-+      +---+
+--R            \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R         *
+--R            log
+--R                                          +-----------------------------------+
+--R                                          |                   2
+--R                          2 4 2        7  |                  d
+--R                     (256a c d  + 64a c ) |- ---------------------------------
+--R                                          |       3 3 4        2 6 2         9
+--R                                         \|  4096a c d  + 2048a c d  + 256a c
+--R                   + 
+--R                             2
+--R                     - 8a c d
+--R                *
+--R                  +------------------------------------------------------------+
+--R                  |                   +-----------------------------------+
+--R                  |                   |                   2
+--R                  |     2 2        3  |                  d
+--R                  |(128a d  + 32a c ) |- ---------------------------------  - 1
+--R                  |                   |       3 3 4        2 6 2         9
+--R                  |                  \|  4096a c d  + 2048a c d  + 256a c
+--R                  |------------------------------------------------------------
+--R                  |                          2 2        3
+--R                 \|                       64a d  + 16a c
+--R               + 
+--R                  2
+--R                 d x + c d
+--R     + 
+--R           +---+4+-+3
+--R         2\|- a \|c
+--R      *
+--R          +--------------------------------------------------------------+
+--R          |                     +-----------------------------------+
+--R          |                     |                   2
+--R          |       2 2        3  |                  d
+--R          |(- 128a d  - 32a c ) |- ---------------------------------  - 1
+--R          |                     |       3 3 4        2 6 2         9
+--R          |                    \|  4096a c d  + 2048a c d  + 256a c
+--R          |--------------------------------------------------------------
+--R          |                           2 2        3
+--R         \|                        64a d  + 16a c
+--R      *
+--R          +----------------+ +----------------+
+--R          |  +-+      +---+  |  +-+      +---+
+--R         \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R      *
+--R         log
+--R                                       +-----------------------------------+
+--R                                       |                   2
+--R                       2 4 2        7  |                  d
+--R                  (256a c d  + 64a c ) |- ---------------------------------
+--R                                       |       3 3 4        2 6 2         9
+--R                                      \|  4096a c d  + 2048a c d  + 256a c
+--R                + 
+--R                        2
+--R                  8a c d
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |                     +-----------------------------------+
+--R               |                     |                   2
+--R               |       2 2        3  |                  d
+--R               |(- 128a d  - 32a c ) |- ---------------------------------  - 1
+--R               |                     |       3 3 4        2 6 2         9
+--R               |                    \|  4096a c d  + 2048a c d  + 256a c
+--R               |--------------------------------------------------------------
+--R               |                           2 2        3
+--R              \|                        64a d  + 16a c
+--R            + 
+--R               2
+--R              d x + c d
+--R     + 
+--R       -
+--R              +---+4+-+3
+--R            2\|- a \|c
+--R         *
+--R             +--------------------------------------------------------------+
+--R             |                     +-----------------------------------+
+--R             |                     |                   2
+--R             |       2 2        3  |                  d
+--R             |(- 128a d  - 32a c ) |- ---------------------------------  - 1
+--R             |                     |       3 3 4        2 6 2         9
+--R             |                    \|  4096a c d  + 2048a c d  + 256a c
+--R             |--------------------------------------------------------------
+--R             |                           2 2        3
+--R            \|                        64a d  + 16a c
+--R         *
+--R             +----------------+ +----------------+
+--R             |  +-+      +---+  |  +-+      +---+
+--R            \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R         *
+--R            log
+--R                              2 4 2        7
+--R                       (- 256a c d  - 64a c )
+--R                    *
+--R                        +-----------------------------------+
+--R                        |                   2
+--R                        |                  d
+--R                        |- ---------------------------------
+--R                        |       3 3 4        2 6 2         9
+--R                       \|  4096a c d  + 2048a c d  + 256a c
+--R                   + 
+--R                             2
+--R                     - 8a c d
+--R                *
+--R                   ROOT
+--R                                   2 2        3
+--R                            (- 128a d  - 32a c )
+--R                         *
+--R                             +-----------------------------------+
+--R                             |                   2
+--R                             |                  d
+--R                             |- ---------------------------------
+--R                             |       3 3 4        2 6 2         9
+--R                            \|  4096a c d  + 2048a c d  + 256a c
+--R                        + 
+--R                          - 1
+--R                     /
+--R                           2 2        3
+--R                        64a d  + 16a c
+--R               + 
+--R                  2
+--R                 d x + c d
+--R     + 
+--R           +---+4+-+3
+--R         2\|- a \|c
+--R      *
+--R          +------------------------------------------------------------+
+--R          |                   +-----------------------------------+
+--R          |                   |                   2
+--R          |     2 2        3  |                  d
+--R          |(128a d  + 32a c ) |- ---------------------------------  - 1
+--R          |                   |       3 3 4        2 6 2         9
+--R          |                  \|  4096a c d  + 2048a c d  + 256a c
+--R          |------------------------------------------------------------
+--R          |                          2 2        3
+--R         \|                       64a d  + 16a c
+--R      *
+--R          +----------------+ +----------------+
+--R          |  +-+      +---+  |  +-+      +---+
+--R         \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R      *
+--R         log
+--R                                         +-----------------------------------+
+--R                                         |                   2
+--R                         2 4 2        7  |                  d
+--R                  (- 256a c d  - 64a c ) |- ---------------------------------
+--R                                         |       3 3 4        2 6 2         9
+--R                                        \|  4096a c d  + 2048a c d  + 256a c
+--R                + 
+--R                        2
+--R                  8a c d
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |                   +-----------------------------------+
+--R                 |                   |                   2
+--R                 |     2 2        3  |                  d
+--R                 |(128a d  + 32a c ) |- ---------------------------------  - 1
+--R                 |                   |       3 3 4        2 6 2         9
+--R                 |                  \|  4096a c d  + 2048a c d  + 256a c
+--R                 |------------------------------------------------------------
+--R                 |                          2 2        3
+--R                \|                       64a d  + 16a c
+--R            + 
+--R               2
+--R              d x + c d
+--R     + 
+--R          +----------------+
+--R          |  +-+      +---+               d x + c
+--R       - \|c\|c  + 2d\|- a  atanh(-----------------------)
+--R                                       +----------------+
+--R                                  4+-+ |  +-+      +---+
+--R                                  \|c \|c\|c  - 2d\|- a
+--R     + 
+--R        +----------------+
+--R        |  +-+      +---+               d x + c
+--R       \|c\|c  - 2d\|- a  atanh(-----------------------)
+--R                                     +----------------+
+--R                                4+-+ |  +-+      +---+
+--R                                \|c \|c\|c  + 2d\|- a
+--R  /
+--R                  +----------------+ +----------------+
+--R       +---+4+-+3 |  +-+      +---+  |  +-+      +---+
+--R     4\|- a \|c  \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R        2 2 2     3        4 4+-+2        2 2 2     3        4  +-+
+--R     (2c d x  + 4c d x + 2c )\|c   + (- 2c d x  - 4c d x - 2c )\|c
+--R  /
+--R            6 8       5 7      2 4 6      3 3 5          4      4 2  4
+--R           d x  + 8c d x  + 26c d x  + 44c d x  + (8a c d  + 42c d )x
+--R         + 
+--R                 2 3      5   3         3 2     6  2        4         2 2 2
+--R           (32a c d  + 24c d)x  + (40a c d  + 8c )x  + 16a c d x + 16a c d
+--R         + 
+--R               5
+--R           8a c
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R               2 4 6      3 3 5      4 2 4      5   3          3 2     6  2
+--R           - 2c d x  - 12c d x  - 26c d x  - 24c d x  + (- 8a c d  - 8c )x
+--R         + 
+--R                  4          5
+--R           - 16a c d x - 8a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 164
+
+)clear all
+
+--S 165 of 534
+t0:=1/(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        4 8       3 7      2 2 6      3   5          2      4  4        2   3
+--R       d x  + 8c d x  + 24c d x  + 32c d x  + (8a c d  + 16c )x  + 32a c d x
+--R     + 
+--R            3 2      2 2
+--R       32a c x  + 16a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 165
+
+--S 166 of 534
+r0:=-1/16*(c/d+x)*(c^3-4*a*d^2-c*d^2*(c/d+x)^2)/(a*c*(c^3+4*a*d^2)*(c*_
+   (4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))-1/32*atanh(d*(c/d+x)/_
+   (c^(1/4)*sqrt(c^(3/2)-2*d*sqrt(-a))))*(c^3+6*a*d^2-c^(3/2)*d*sqrt(-a))/_
+   ((-a)^(3/2)*c^(7/4)*(c^3+4*a*d^2)*sqrt(c^(3/2)-2*d*sqrt(-a)))+_
+   1/32*atanh(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+2*d*sqrt(-a))))*(c^3+_
+   6*a*d^2+c^(3/2)*d*sqrt(-a))/((-a)^(3/2)*c^(7/4)*(c^3+4*a*d^2)*_
+   sqrt(c^(3/2)+2*d*sqrt(-a)))
+--R 
+--R
+--R   (2)
+--R                 3 4     2 2 3     3   2       2   +---+ +-+        4    3 2  4
+--R           (- c d x  - 4c d x  - 4c d x  - 4a c d)\|- a \|c  + (6a d  + c d )x
+--R         + 
+--R                   3     4   3         2 2     5  2      2   2       4
+--R           (24a c d  + 4c d)x  + (24a c d  + 4c )x  + 24a c d  + 4a c
+--R      *
+--R          +----------------+
+--R          |  +-+      +---+               d x + c
+--R         \|c\|c  + 2d\|- a  atanh(-----------------------)
+--R                                       +----------------+
+--R                                  4+-+ |  +-+      +---+
+--R                                  \|c \|c\|c  - 2d\|- a
+--R     + 
+--R                 3 4     2 2 3     3   2       2   +---+ +-+
+--R           (- c d x  - 4c d x  - 4c d x  - 4a c d)\|- a \|c
+--R         + 
+--R                  4    3 2  4             3     4   3           2 2     5  2
+--R           (- 6a d  - c d )x  + (- 24a c d  - 4c d)x  + (- 24a c d  - 4c )x
+--R         + 
+--R                2   2       4
+--R           - 24a c d  - 4a c
+--R      *
+--R          +----------------+
+--R          |  +-+      +---+               d x + c
+--R         \|c\|c  - 2d\|- a  atanh(-----------------------)
+--R                                       +----------------+
+--R                                  4+-+ |  +-+      +---+
+--R                                  \|c \|c\|c  + 2d\|- a
+--R     + 
+--R              2 3     2   2        2     3             +---+4+-+3
+--R         (2c d x  + 6c d x  + (8a d  + 4c )x + 8a c d)\|- a \|c
+--R      *
+--R          +----------------+ +----------------+
+--R          |  +-+      +---+  |  +-+      +---+
+--R         \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R  /
+--R              2   4        4 2  4        2 2 3         5   3
+--R         (128a c d  + 32a c d )x  + (512a c d  + 128a c d)x
+--R       + 
+--R              2 3 2         6  2       3 2 2       2 5
+--R         (512a c d  + 128a c )x  + 512a c d  + 128a c
+--R    *
+--R                   +----------------+ +----------------+
+--R        +---+4+-+3 |  +-+      +---+  |  +-+      +---+
+--R       \|- a \|c  \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2   4       4 2  4          2 2 3        5   3
+--R           (- 32a c d  - 8a c d )x  + (- 128a c d  - 32a c d)x
+--R         + 
+--R                  2 3 2        6  2       3 2 2      2 5
+--R           (- 128a c d  - 32a c )x  - 128a c d  - 32a c
+--R      *
+--R         ROOT
+--R                          6 2 6         5 5 4         4 8 2        3 11
+--R                  (131072a c d  + 98304a c d  + 24576a c d  + 2048a c  )
+--R               *
+--R                  ROOT
+--R                              2 10         3 8      6 6
+--R                       - 1296a d   - 360a c d  - 25c d
+--R                    /
+--R                                    9 7 12              8 10 10
+--R                         4294967296a c d   + 6442450944a c  d
+--R                       + 
+--R                                    7 13 8              6 16 6
+--R                         4026531840a c  d  + 1342177280a c  d
+--R                       + 
+--R                                   5 19 4            4 22 2           3 25
+--R                         251658240a c  d  + 25165824a c  d  + 1048576a c
+--R              + 
+--R                     2 4        3 2    6
+--R                - 60a d  - 15a c d  - c
+--R           /
+--R                    6 2 6         5 5 4         4 8 2        3 11
+--R              65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R      *
+--R         log
+--R                               7 7 8            6 10 6           5 13 4
+--R                      16777216a c d  + 14680064a c  d  + 4718592a c  d
+--R                    + 
+--R                             4 16 2         3 19
+--R                      655360a c  d  + 32768a c
+--R                 *
+--R                    ROOT
+--R                                2 10         3 8      6 6
+--R                         - 1296a d   - 360a c d  - 25c d
+--R                      /
+--R                                      9 7 12              8 10 10
+--R                           4294967296a c d   + 6442450944a c  d
+--R                         + 
+--R                                      7 13 8              6 16 6
+--R                           4026531840a c  d  + 1342177280a c  d
+--R                         + 
+--R                                     5 19 4            4 22 2           3 25
+--R                           251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                + 
+--R                          4 2 8        3 5 6       2 8 4
+--R                  - 13824a c d  - 3072a c d  - 160a c d
+--R             *
+--R                ROOT
+--R                                 6 2 6         5 5 4         4 8 2        3 11
+--R                         (131072a c d  + 98304a c d  + 24576a c d  + 2048a c  )
+--R                      *
+--R                         ROOT
+--R                                     2 10         3 8      6 6
+--R                              - 1296a d   - 360a c d  - 25c d
+--R                           /
+--R                                           9 7 12              8 10 10
+--R                                4294967296a c d   + 6442450944a c  d
+--R                              + 
+--R                                           7 13 8              6 16 6
+--R                                4026531840a c  d  + 1342177280a c  d
+--R                              + 
+--R                                        5 19 4            4 22 2           3 25
+--R                              251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                     + 
+--R                            2 4        3 2    6
+--R                       - 60a d  - 15a c d  - c
+--R                  /
+--R                           6 2 6         5 5 4         4 8 2        3 11
+--R                     65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R            + 
+--R                   2 8        3 6     6 4         2   7        4 5     7 3
+--R              (324a d  + 81a c d  + 5c d )x + 324a c d  + 81a c d  + 5c d
+--R     + 
+--R               2   4       4 2  4        2 2 3        5   3
+--R           (32a c d  + 8a c d )x  + (128a c d  + 32a c d)x
+--R         + 
+--R                2 3 2        6  2       3 2 2      2 5
+--R           (128a c d  + 32a c )x  + 128a c d  + 32a c
+--R      *
+--R         ROOT
+--R                            6 2 6         5 5 4         4 8 2        3 11
+--R                  (- 131072a c d  - 98304a c d  - 24576a c d  - 2048a c  )
+--R               *
+--R                  ROOT
+--R                              2 10         3 8      6 6
+--R                       - 1296a d   - 360a c d  - 25c d
+--R                    /
+--R                                    9 7 12              8 10 10
+--R                         4294967296a c d   + 6442450944a c  d
+--R                       + 
+--R                                    7 13 8              6 16 6
+--R                         4026531840a c  d  + 1342177280a c  d
+--R                       + 
+--R                                   5 19 4            4 22 2           3 25
+--R                         251658240a c  d  + 25165824a c  d  + 1048576a c
+--R              + 
+--R                     2 4        3 2    6
+--R                - 60a d  - 15a c d  - c
+--R           /
+--R                    6 2 6         5 5 4         4 8 2        3 11
+--R              65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R      *
+--R         log
+--R                               7 7 8            6 10 6           5 13 4
+--R                      16777216a c d  + 14680064a c  d  + 4718592a c  d
+--R                    + 
+--R                             4 16 2         3 19
+--R                      655360a c  d  + 32768a c
+--R                 *
+--R                    ROOT
+--R                                2 10         3 8      6 6
+--R                         - 1296a d   - 360a c d  - 25c d
+--R                      /
+--R                                      9 7 12              8 10 10
+--R                           4294967296a c d   + 6442450944a c  d
+--R                         + 
+--R                                      7 13 8              6 16 6
+--R                           4026531840a c  d  + 1342177280a c  d
+--R                         + 
+--R                                     5 19 4            4 22 2           3 25
+--R                           251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                + 
+--R                        4 2 8        3 5 6       2 8 4
+--R                  13824a c d  + 3072a c d  + 160a c d
+--R             *
+--R                ROOT
+--R                                      6 2 6         5 5 4         4 8 2
+--R                             - 131072a c d  - 98304a c d  - 24576a c d
+--R                           + 
+--R                                    3 11
+--R                             - 2048a c
+--R                      *
+--R                         ROOT
+--R                                     2 10         3 8      6 6
+--R                              - 1296a d   - 360a c d  - 25c d
+--R                           /
+--R                                           9 7 12              8 10 10
+--R                                4294967296a c d   + 6442450944a c  d
+--R                              + 
+--R                                           7 13 8              6 16 6
+--R                                4026531840a c  d  + 1342177280a c  d
+--R                              + 
+--R                                        5 19 4            4 22 2           3 25
+--R                              251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                     + 
+--R                            2 4        3 2    6
+--R                       - 60a d  - 15a c d  - c
+--R                  /
+--R                           6 2 6         5 5 4         4 8 2        3 11
+--R                     65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R            + 
+--R                   2 8        3 6     6 4         2   7        4 5     7 3
+--R              (324a d  + 81a c d  + 5c d )x + 324a c d  + 81a c d  + 5c d
+--R     + 
+--R                 2   4       4 2  4          2 2 3        5   3
+--R           (- 32a c d  - 8a c d )x  + (- 128a c d  - 32a c d)x
+--R         + 
+--R                  2 3 2        6  2       3 2 2      2 5
+--R           (- 128a c d  - 32a c )x  - 128a c d  - 32a c
+--R      *
+--R         ROOT
+--R                            6 2 6         5 5 4         4 8 2        3 11
+--R                  (- 131072a c d  - 98304a c d  - 24576a c d  - 2048a c  )
+--R               *
+--R                  ROOT
+--R                              2 10         3 8      6 6
+--R                       - 1296a d   - 360a c d  - 25c d
+--R                    /
+--R                                    9 7 12              8 10 10
+--R                         4294967296a c d   + 6442450944a c  d
+--R                       + 
+--R                                    7 13 8              6 16 6
+--R                         4026531840a c  d  + 1342177280a c  d
+--R                       + 
+--R                                   5 19 4            4 22 2           3 25
+--R                         251658240a c  d  + 25165824a c  d  + 1048576a c
+--R              + 
+--R                     2 4        3 2    6
+--R                - 60a d  - 15a c d  - c
+--R           /
+--R                    6 2 6         5 5 4         4 8 2        3 11
+--R              65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R      *
+--R         log
+--R                                 7 7 8            6 10 6           5 13 4
+--R                      - 16777216a c d  - 14680064a c  d  - 4718592a c  d
+--R                    + 
+--R                               4 16 2         3 19
+--R                      - 655360a c  d  - 32768a c
+--R                 *
+--R                    ROOT
+--R                                2 10         3 8      6 6
+--R                         - 1296a d   - 360a c d  - 25c d
+--R                      /
+--R                                      9 7 12              8 10 10
+--R                           4294967296a c d   + 6442450944a c  d
+--R                         + 
+--R                                      7 13 8              6 16 6
+--R                           4026531840a c  d  + 1342177280a c  d
+--R                         + 
+--R                                     5 19 4            4 22 2           3 25
+--R                           251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                + 
+--R                          4 2 8        3 5 6       2 8 4
+--R                  - 13824a c d  - 3072a c d  - 160a c d
+--R             *
+--R                ROOT
+--R                                      6 2 6         5 5 4         4 8 2
+--R                             - 131072a c d  - 98304a c d  - 24576a c d
+--R                           + 
+--R                                    3 11
+--R                             - 2048a c
+--R                      *
+--R                         ROOT
+--R                                     2 10         3 8      6 6
+--R                              - 1296a d   - 360a c d  - 25c d
+--R                           /
+--R                                           9 7 12              8 10 10
+--R                                4294967296a c d   + 6442450944a c  d
+--R                              + 
+--R                                           7 13 8              6 16 6
+--R                                4026531840a c  d  + 1342177280a c  d
+--R                              + 
+--R                                        5 19 4            4 22 2           3 25
+--R                              251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                     + 
+--R                            2 4        3 2    6
+--R                       - 60a d  - 15a c d  - c
+--R                  /
+--R                           6 2 6         5 5 4         4 8 2        3 11
+--R                     65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R            + 
+--R                   2 8        3 6     6 4         2   7        4 5     7 3
+--R              (324a d  + 81a c d  + 5c d )x + 324a c d  + 81a c d  + 5c d
+--R     + 
+--R               2   4       4 2  4        2 2 3        5   3
+--R           (32a c d  + 8a c d )x  + (128a c d  + 32a c d)x
+--R         + 
+--R                2 3 2        6  2       3 2 2      2 5
+--R           (128a c d  + 32a c )x  + 128a c d  + 32a c
+--R      *
+--R         ROOT
+--R                          6 2 6         5 5 4         4 8 2        3 11
+--R                  (131072a c d  + 98304a c d  + 24576a c d  + 2048a c  )
+--R               *
+--R                  ROOT
+--R                              2 10         3 8      6 6
+--R                       - 1296a d   - 360a c d  - 25c d
+--R                    /
+--R                                    9 7 12              8 10 10
+--R                         4294967296a c d   + 6442450944a c  d
+--R                       + 
+--R                                    7 13 8              6 16 6
+--R                         4026531840a c  d  + 1342177280a c  d
+--R                       + 
+--R                                   5 19 4            4 22 2           3 25
+--R                         251658240a c  d  + 25165824a c  d  + 1048576a c
+--R              + 
+--R                     2 4        3 2    6
+--R                - 60a d  - 15a c d  - c
+--R           /
+--R                    6 2 6         5 5 4         4 8 2        3 11
+--R              65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R      *
+--R         log
+--R                                 7 7 8            6 10 6           5 13 4
+--R                      - 16777216a c d  - 14680064a c  d  - 4718592a c  d
+--R                    + 
+--R                               4 16 2         3 19
+--R                      - 655360a c  d  - 32768a c
+--R                 *
+--R                    ROOT
+--R                                2 10         3 8      6 6
+--R                         - 1296a d   - 360a c d  - 25c d
+--R                      /
+--R                                      9 7 12              8 10 10
+--R                           4294967296a c d   + 6442450944a c  d
+--R                         + 
+--R                                      7 13 8              6 16 6
+--R                           4026531840a c  d  + 1342177280a c  d
+--R                         + 
+--R                                     5 19 4            4 22 2           3 25
+--R                           251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                + 
+--R                        4 2 8        3 5 6       2 8 4
+--R                  13824a c d  + 3072a c d  + 160a c d
+--R             *
+--R                ROOT
+--R                                 6 2 6         5 5 4         4 8 2        3 11
+--R                         (131072a c d  + 98304a c d  + 24576a c d  + 2048a c  )
+--R                      *
+--R                         ROOT
+--R                                     2 10         3 8      6 6
+--R                              - 1296a d   - 360a c d  - 25c d
+--R                           /
+--R                                           9 7 12              8 10 10
+--R                                4294967296a c d   + 6442450944a c  d
+--R                              + 
+--R                                           7 13 8              6 16 6
+--R                                4026531840a c  d  + 1342177280a c  d
+--R                              + 
+--R                                        5 19 4            4 22 2           3 25
+--R                              251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                     + 
+--R                            2 4        3 2    6
+--R                       - 60a d  - 15a c d  - c
+--R                  /
+--R                           6 2 6         5 5 4         4 8 2        3 11
+--R                     65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R            + 
+--R                   2 8        3 6     6 4         2   7        4 5     7 3
+--R              (324a d  + 81a c d  + 5c d )x + 324a c d  + 81a c d  + 5c d
+--R     + 
+--R          2 3     2   2        2     3
+--R       c d x  + 3c d x  + (4a d  + 2c )x + 4a c d
+--R  /
+--R           2   4        4 2  4        2 2 3        5   3
+--R       (64a c d  + 16a c d )x  + (256a c d  + 64a c d)x
+--R     + 
+--R            2 3 2        6  2       3 2 2      2 5
+--R       (256a c d  + 64a c )x  + 256a c d  + 64a c
+--R                                         Type: Union(Expression(Integer),...)
+--E 167
+
+--S 168 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               2   2        4  +---+4+-+3
+--R         (- 64a c d  - 16a c )\|- a \|c
+--R      *
+--R         ROOT
+--R                          6 2 6         5 5 4         4 8 2        3 11
+--R                  (131072a c d  + 98304a c d  + 24576a c d  + 2048a c  )
+--R               *
+--R                  ROOT
+--R                              2 10         3 8      6 6
+--R                       - 1296a d   - 360a c d  - 25c d
+--R                    /
+--R                                    9 7 12              8 10 10
+--R                         4294967296a c d   + 6442450944a c  d
+--R                       + 
+--R                                    7 13 8              6 16 6
+--R                         4026531840a c  d  + 1342177280a c  d
+--R                       + 
+--R                                   5 19 4            4 22 2           3 25
+--R                         251658240a c  d  + 25165824a c  d  + 1048576a c
+--R              + 
+--R                     2 4        3 2    6
+--R                - 60a d  - 15a c d  - c
+--R           /
+--R                    6 2 6         5 5 4         4 8 2        3 11
+--R              65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R      *
+--R          +----------------+ +----------------+
+--R          |  +-+      +---+  |  +-+      +---+
+--R         \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R      *
+--R         log
+--R                               7 7 8            6 10 6           5 13 4
+--R                      16777216a c d  + 14680064a c  d  + 4718592a c  d
+--R                    + 
+--R                             4 16 2         3 19
+--R                      655360a c  d  + 32768a c
+--R                 *
+--R                    ROOT
+--R                                2 10         3 8      6 6
+--R                         - 1296a d   - 360a c d  - 25c d
+--R                      /
+--R                                      9 7 12              8 10 10
+--R                           4294967296a c d   + 6442450944a c  d
+--R                         + 
+--R                                      7 13 8              6 16 6
+--R                           4026531840a c  d  + 1342177280a c  d
+--R                         + 
+--R                                     5 19 4            4 22 2           3 25
+--R                           251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                + 
+--R                          4 2 8        3 5 6       2 8 4
+--R                  - 13824a c d  - 3072a c d  - 160a c d
+--R             *
+--R                ROOT
+--R                                 6 2 6         5 5 4         4 8 2        3 11
+--R                         (131072a c d  + 98304a c d  + 24576a c d  + 2048a c  )
+--R                      *
+--R                         ROOT
+--R                                     2 10         3 8      6 6
+--R                              - 1296a d   - 360a c d  - 25c d
+--R                           /
+--R                                           9 7 12              8 10 10
+--R                                4294967296a c d   + 6442450944a c  d
+--R                              + 
+--R                                           7 13 8              6 16 6
+--R                                4026531840a c  d  + 1342177280a c  d
+--R                              + 
+--R                                        5 19 4            4 22 2           3 25
+--R                              251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                     + 
+--R                            2 4        3 2    6
+--R                       - 60a d  - 15a c d  - c
+--R                  /
+--R                           6 2 6         5 5 4         4 8 2        3 11
+--R                     65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R            + 
+--R                   2 8        3 6     6 4         2   7        4 5     7 3
+--R              (324a d  + 81a c d  + 5c d )x + 324a c d  + 81a c d  + 5c d
+--R     + 
+--R             2   2        4  +---+4+-+3
+--R         (64a c d  + 16a c )\|- a \|c
+--R      *
+--R         ROOT
+--R                            6 2 6         5 5 4         4 8 2        3 11
+--R                  (- 131072a c d  - 98304a c d  - 24576a c d  - 2048a c  )
+--R               *
+--R                  ROOT
+--R                              2 10         3 8      6 6
+--R                       - 1296a d   - 360a c d  - 25c d
+--R                    /
+--R                                    9 7 12              8 10 10
+--R                         4294967296a c d   + 6442450944a c  d
+--R                       + 
+--R                                    7 13 8              6 16 6
+--R                         4026531840a c  d  + 1342177280a c  d
+--R                       + 
+--R                                   5 19 4            4 22 2           3 25
+--R                         251658240a c  d  + 25165824a c  d  + 1048576a c
+--R              + 
+--R                     2 4        3 2    6
+--R                - 60a d  - 15a c d  - c
+--R           /
+--R                    6 2 6         5 5 4         4 8 2        3 11
+--R              65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R      *
+--R          +----------------+ +----------------+
+--R          |  +-+      +---+  |  +-+      +---+
+--R         \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R      *
+--R         log
+--R                               7 7 8            6 10 6           5 13 4
+--R                      16777216a c d  + 14680064a c  d  + 4718592a c  d
+--R                    + 
+--R                             4 16 2         3 19
+--R                      655360a c  d  + 32768a c
+--R                 *
+--R                    ROOT
+--R                                2 10         3 8      6 6
+--R                         - 1296a d   - 360a c d  - 25c d
+--R                      /
+--R                                      9 7 12              8 10 10
+--R                           4294967296a c d   + 6442450944a c  d
+--R                         + 
+--R                                      7 13 8              6 16 6
+--R                           4026531840a c  d  + 1342177280a c  d
+--R                         + 
+--R                                     5 19 4            4 22 2           3 25
+--R                           251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                + 
+--R                        4 2 8        3 5 6       2 8 4
+--R                  13824a c d  + 3072a c d  + 160a c d
+--R             *
+--R                ROOT
+--R                                      6 2 6         5 5 4         4 8 2
+--R                             - 131072a c d  - 98304a c d  - 24576a c d
+--R                           + 
+--R                                    3 11
+--R                             - 2048a c
+--R                      *
+--R                         ROOT
+--R                                     2 10         3 8      6 6
+--R                              - 1296a d   - 360a c d  - 25c d
+--R                           /
+--R                                           9 7 12              8 10 10
+--R                                4294967296a c d   + 6442450944a c  d
+--R                              + 
+--R                                           7 13 8              6 16 6
+--R                                4026531840a c  d  + 1342177280a c  d
+--R                              + 
+--R                                        5 19 4            4 22 2           3 25
+--R                              251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                     + 
+--R                            2 4        3 2    6
+--R                       - 60a d  - 15a c d  - c
+--R                  /
+--R                           6 2 6         5 5 4         4 8 2        3 11
+--R                     65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R            + 
+--R                   2 8        3 6     6 4         2   7        4 5     7 3
+--R              (324a d  + 81a c d  + 5c d )x + 324a c d  + 81a c d  + 5c d
+--R     + 
+--R               2   2        4  +---+4+-+3
+--R         (- 64a c d  - 16a c )\|- a \|c
+--R      *
+--R         ROOT
+--R                            6 2 6         5 5 4         4 8 2        3 11
+--R                  (- 131072a c d  - 98304a c d  - 24576a c d  - 2048a c  )
+--R               *
+--R                  ROOT
+--R                              2 10         3 8      6 6
+--R                       - 1296a d   - 360a c d  - 25c d
+--R                    /
+--R                                    9 7 12              8 10 10
+--R                         4294967296a c d   + 6442450944a c  d
+--R                       + 
+--R                                    7 13 8              6 16 6
+--R                         4026531840a c  d  + 1342177280a c  d
+--R                       + 
+--R                                   5 19 4            4 22 2           3 25
+--R                         251658240a c  d  + 25165824a c  d  + 1048576a c
+--R              + 
+--R                     2 4        3 2    6
+--R                - 60a d  - 15a c d  - c
+--R           /
+--R                    6 2 6         5 5 4         4 8 2        3 11
+--R              65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R      *
+--R          +----------------+ +----------------+
+--R          |  +-+      +---+  |  +-+      +---+
+--R         \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R      *
+--R         log
+--R                                 7 7 8            6 10 6           5 13 4
+--R                      - 16777216a c d  - 14680064a c  d  - 4718592a c  d
+--R                    + 
+--R                               4 16 2         3 19
+--R                      - 655360a c  d  - 32768a c
+--R                 *
+--R                    ROOT
+--R                                2 10         3 8      6 6
+--R                         - 1296a d   - 360a c d  - 25c d
+--R                      /
+--R                                      9 7 12              8 10 10
+--R                           4294967296a c d   + 6442450944a c  d
+--R                         + 
+--R                                      7 13 8              6 16 6
+--R                           4026531840a c  d  + 1342177280a c  d
+--R                         + 
+--R                                     5 19 4            4 22 2           3 25
+--R                           251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                + 
+--R                          4 2 8        3 5 6       2 8 4
+--R                  - 13824a c d  - 3072a c d  - 160a c d
+--R             *
+--R                ROOT
+--R                                      6 2 6         5 5 4         4 8 2
+--R                             - 131072a c d  - 98304a c d  - 24576a c d
+--R                           + 
+--R                                    3 11
+--R                             - 2048a c
+--R                      *
+--R                         ROOT
+--R                                     2 10         3 8      6 6
+--R                              - 1296a d   - 360a c d  - 25c d
+--R                           /
+--R                                           9 7 12              8 10 10
+--R                                4294967296a c d   + 6442450944a c  d
+--R                              + 
+--R                                           7 13 8              6 16 6
+--R                                4026531840a c  d  + 1342177280a c  d
+--R                              + 
+--R                                        5 19 4            4 22 2           3 25
+--R                              251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                     + 
+--R                            2 4        3 2    6
+--R                       - 60a d  - 15a c d  - c
+--R                  /
+--R                           6 2 6         5 5 4         4 8 2        3 11
+--R                     65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R            + 
+--R                   2 8        3 6     6 4         2   7        4 5     7 3
+--R              (324a d  + 81a c d  + 5c d )x + 324a c d  + 81a c d  + 5c d
+--R     + 
+--R             2   2        4  +---+4+-+3
+--R         (64a c d  + 16a c )\|- a \|c
+--R      *
+--R         ROOT
+--R                          6 2 6         5 5 4         4 8 2        3 11
+--R                  (131072a c d  + 98304a c d  + 24576a c d  + 2048a c  )
+--R               *
+--R                  ROOT
+--R                              2 10         3 8      6 6
+--R                       - 1296a d   - 360a c d  - 25c d
+--R                    /
+--R                                    9 7 12              8 10 10
+--R                         4294967296a c d   + 6442450944a c  d
+--R                       + 
+--R                                    7 13 8              6 16 6
+--R                         4026531840a c  d  + 1342177280a c  d
+--R                       + 
+--R                                   5 19 4            4 22 2           3 25
+--R                         251658240a c  d  + 25165824a c  d  + 1048576a c
+--R              + 
+--R                     2 4        3 2    6
+--R                - 60a d  - 15a c d  - c
+--R           /
+--R                    6 2 6         5 5 4         4 8 2        3 11
+--R              65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R      *
+--R          +----------------+ +----------------+
+--R          |  +-+      +---+  |  +-+      +---+
+--R         \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R      *
+--R         log
+--R                                 7 7 8            6 10 6           5 13 4
+--R                      - 16777216a c d  - 14680064a c  d  - 4718592a c  d
+--R                    + 
+--R                               4 16 2         3 19
+--R                      - 655360a c  d  - 32768a c
+--R                 *
+--R                    ROOT
+--R                                2 10         3 8      6 6
+--R                         - 1296a d   - 360a c d  - 25c d
+--R                      /
+--R                                      9 7 12              8 10 10
+--R                           4294967296a c d   + 6442450944a c  d
+--R                         + 
+--R                                      7 13 8              6 16 6
+--R                           4026531840a c  d  + 1342177280a c  d
+--R                         + 
+--R                                     5 19 4            4 22 2           3 25
+--R                           251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                + 
+--R                        4 2 8        3 5 6       2 8 4
+--R                  13824a c d  + 3072a c d  + 160a c d
+--R             *
+--R                ROOT
+--R                                 6 2 6         5 5 4         4 8 2        3 11
+--R                         (131072a c d  + 98304a c d  + 24576a c d  + 2048a c  )
+--R                      *
+--R                         ROOT
+--R                                     2 10         3 8      6 6
+--R                              - 1296a d   - 360a c d  - 25c d
+--R                           /
+--R                                           9 7 12              8 10 10
+--R                                4294967296a c d   + 6442450944a c  d
+--R                              + 
+--R                                           7 13 8              6 16 6
+--R                                4026531840a c  d  + 1342177280a c  d
+--R                              + 
+--R                                        5 19 4            4 22 2           3 25
+--R                              251658240a c  d  + 25165824a c  d  + 1048576a c
+--R                     + 
+--R                            2 4        3 2    6
+--R                       - 60a d  - 15a c d  - c
+--R                  /
+--R                           6 2 6         5 5 4         4 8 2        3 11
+--R                     65536a c d  + 49152a c d  + 12288a c d  + 1024a c
+--R            + 
+--R                   2 8        3 6     6 4         2   7        4 5     7 3
+--R              (324a d  + 81a c d  + 5c d )x + 324a c d  + 81a c d  + 5c d
+--R     + 
+--R                                      +----------------+
+--R              +---+ +-+       2    3  |  +-+      +---+
+--R         (c d\|- a \|c  - 6a d  - c )\|c\|c  + 2d\|- a
+--R      *
+--R                       d x + c
+--R         atanh(-----------------------)
+--R                    +----------------+
+--R               4+-+ |  +-+      +---+
+--R               \|c \|c\|c  - 2d\|- a
+--R     + 
+--R                                      +----------------+
+--R              +---+ +-+       2    3  |  +-+      +---+
+--R         (c d\|- a \|c  + 6a d  + c )\|c\|c  - 2d\|- a
+--R      *
+--R                       d x + c
+--R         atanh(-----------------------)
+--R                    +----------------+
+--R               4+-+ |  +-+      +---+
+--R               \|c \|c\|c  + 2d\|- a
+--R  /
+--R                                     +----------------+ +----------------+
+--R          2   2        4  +---+4+-+3 |  +-+      +---+  |  +-+      +---+
+--R     (128a c d  + 32a c )\|- a \|c  \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R                                                    Type: Expression(Integer)
+--E 168
+
+--S 169 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            6 6       5 5      2 4 4      3 3 3           4      4 2  2
+--R           d x  + 6c d x  + 15c d x  + 20c d x  + (28a c d  + 18c d )x
+--R         + 
+--R                 2 3      5           3 2     6
+--R           (56a c d  + 12c d)x + 28a c d  + 4c
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R              6 6       5 5      2 4 4      3 3 3             4      4 2  2
+--R           - d x  - 6c d x  - 15c d x  - 20c d x  + (- 28a c d  - 18c d )x
+--R         + 
+--R                   2 3      5           3 2     6
+--R           (- 56a c d  - 12c d)x - 28a c d  - 4c
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R               2 8        3 6  8        2   7         4 5  7
+--R           (64a d  + 16a c d )x  + (512a c d  + 128a c d )x
+--R         + 
+--R                 2 2 6         5 4  6         2 3 5         6 3  5
+--R           (1664a c d  + 416a c d )x  + (2816a c d  + 704a c d )x
+--R         + 
+--R                3   6        2 4 4         7 2  4
+--R           (512a c d  + 2816a c d  + 672a c d )x
+--R         + 
+--R                 3 2 5        2 5 3         8   3
+--R           (2048a c d  + 2048a c d  + 384a c d)x
+--R         + 
+--R                 3 3 4        2 6 2         9  2         3 4 3       2 7
+--R           (2560a c d  + 1152a c d  + 128a c )x  + (1024a c d  + 256a c d)x
+--R         + 
+--R                4 2 4       3 5 2       2 8
+--R           1024a c d  + 768a c d  + 128a c
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R                  2 2 6        5 4  6          2 3 5         6 3  5
+--R           (- 128a c d  - 32a c d )x  + (- 768a c d  - 192a c d )x
+--R         + 
+--R                   2 4 4         7 2  4           2 5 3         8   3
+--R           (- 1664a c d  - 416a c d )x  + (- 1536a c d  - 384a c d)x
+--R         + 
+--R                  3 3 4       2 6 2         9  2           3 4 3       2 7
+--R           (- 512a c d  - 640a c d  - 128a c )x  + (- 1024a c d  - 256a c d)x
+--R         + 
+--R                 3 5 2       2 8
+--R           - 512a c d  - 128a c
+--R      *
+--R          +-+
+--R         \|c
+--R                                                    Type: Expression(Integer)
+--E 169
+
+)clear all
+
+--S 170 of 534
+t0:=(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^(3/2)
+--R 
+--R
+--R                                        +-----------------------------+
+--R          2 4         3     2 2         | 2 4         3     2 2
+--R   (1)  (d x  + 4c d x  + 4c x  + 4a c)\|d x  + 4c d x  + 4c x  + 4a c
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 534
+--r0:=1/7*(c/d+x)*(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4)^(3/2)+_
+--   2/35*c*(c/d+x)*(7*c^3+20*a*d^2-3*c*d^2*(c/d+x)^2)*sqrt(c*(4*a+c^3/d^2)-_
+--   2*c^2*(c/d+x)^2+d^2*(c/d+x)^4)/d^2+16/35*c^(15/4)*(c^3+8*a*d^2)*_
+--   elliptic_e(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+2*d*sqrt(-a)))),_
+--   (c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*(c^(3/2)-2*d*sqrt(-a))*_
+--   sqrt(c^(3/2)+2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)-2*d*_
+--   sqrt(-a))*sqrt(c)))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+2*d*sqrt(-a))*_
+--   sqrt(c)))/(d^5*sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))+_
+--   16/35*c^(9/4)*elliptic_f(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+2*d*_
+--   sqrt(-a)))),(c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*(a*c^3*d+_
+--   20*a^2*d^3+2*c^(9/2)*sqrt(-a)+16*a*c^(3/2)*d^2*sqrt(-a))*sqrt(c^(3/2)+_
+--   2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)-2*d*sqrt(-a))*sqrt(c)))*_
+--   sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+2*d*sqrt(-a))*sqrt(c)))/(d^4*sqrt(c*_
+--   (4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))
+--E 171
+
+--S 172 of 534
+--a0:=integrate(t0,x)
+--E 172
+
+--S 173 of 534
+--m0:=a0-r0
+--E 173
+
+--S 174 of 534
+--d0:=D(m0,x)
+--E 174
+
+)clear all
+
+--S 175 of 534
+t0:=(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^(1/2)
+--R 
+--R
+--R         +-----------------------------+
+--R         | 2 4         3     2 2
+--R   (1)  \|d x  + 4c d x  + 4c x  + 4a c
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 534
+--r0:=1/3*(c/d+x)*sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4)+_
+--   2/3*c^(11/4)*elliptic_e(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+2*d*_
+--   sqrt(-a)))),(c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*(c^(3/2)-_
+--   2*d*sqrt(-a))*sqrt(c^(3/2)+2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/_
+--   ((c^(3/2)-2*d*sqrt(-a))*sqrt(c)))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+_
+--   2*d*sqrt(-a))*sqrt(c)))/(d^3*sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+_
+--   d^2*(c/d+x)^4))+4/3*c^(5/4)*elliptic_f(asin(d*(c/d+x)/(c^(1/4)*_
+--   sqrt(c^(3/2)+2*d*sqrt(-a)))),(c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-_
+--   2*d*sqrt(-a)))*sqrt(-a)*(c^(3/2)-2*d*sqrt(-a))*sqrt(c^(3/2)+_
+--   2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)-2*d*sqrt(-a))*sqrt(c)))*_
+--   sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+2*d*sqrt(-a))*sqrt(c)))/(d^2*_
+--   sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))
+--E 176
+
+--S 177 of 534
+--a0:=integrate(t0,x)
+--E 177
+
+--S 178 of 534
+--m0:=a0-r0
+--E 178
+
+--S 179 of 534
+--d0:=D(m0,x)
+--E 179
+
+)clear all
+
+--S 180 of 534
+t0:=1/(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^(1/2)
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R         +-----------------------------+
+--R         | 2 4         3     2 2
+--R        \|d x  + 4c d x  + 4c x  + 4a c
+--R                                                    Type: Expression(Integer)
+--E 180
+
+--S 181 of 534
+--r0:=c^(1/4)*elliptic_f(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+_
+--   2*d*sqrt(-a)))),(c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*_
+--   sqrt(c^(3/2)+2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)-_
+--   2*d*sqrt(-a))*sqrt(c)))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+_
+--   2*d*sqrt(-a))*sqrt(c)))/(d*sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+_
+--   d^2*(c/d+x)^4))
+--E 181
+
+--S 182 of 534
+--a0:=integrate(t0,x)
+--E 182
+
+--S 183 of 534
+--m0:=a0-r0
+--E 183
+
+--S 184 of 534
+--d0:=D(m0,x)
+--E 184
+
+)clear all
+
+--S 185 of 534
+t0:=1/(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^(3/2)
+--R 
+--R
+--R                                       1
+--R   (1)  ---------------------------------------------------------------
+--R                                        +-----------------------------+
+--R          2 4         3     2 2         | 2 4         3     2 2
+--R        (d x  + 4c d x  + 4c x  + 4a c)\|d x  + 4c d x  + 4c x  + 4a c
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 534
+--r0:=-1/8*(c/d+x)*(c^3-4*a*d^2-c*d^2*(c/d+x)^2)/(a*c*(c^3+4*a*d^2)*_
+--   sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))+1/8*c^(3/4)*_
+--   elliptic_e(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+2*d*sqrt(-a)))),_
+--   (c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*(c^(3/2)-2*d*sqrt(-a))*_
+--   sqrt(c^(3/2)+2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)-2*d*_
+--   sqrt(-a))*sqrt(c)))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+2*d*sqrt(-a))*_
+--   sqrt(c)))/(a*d*(c^3+4*a*d^2)*sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+_
+--   d^2*(c/d+x)^4))-1/4*elliptic_f(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+_
+--   2*d*sqrt(-a)))),(c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*_
+--   (c^(3/2)-2*d*sqrt(-a))*sqrt(c^(3/2)+2*d*sqrt(-a))*sqrt(1-d^2*(c/d+_
+--   x)^2/((c^(3/2)-2*d*sqrt(-a))*sqrt(c)))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+_
+--   2*d*sqrt(-a))*sqrt(c)))/(c^(3/4)*(c^3+4*a*d^2)*sqrt(-a)*sqrt(c*(4*a+_
+--   c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))
+--E 186
+
+--S 187 of 534
+--a0:=integrate(t0,x)
+--E 187
+
+--S 188 of 534
+--m0:=a0-r0
+--E 188
+
+--S 189 of 534
+--d0:=D(m0,x)
+--E 189
+
+)clear all
+
+--S 190 of 534
+t0:=(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^4
+--R 
+--R
+--R   (1)
+--R          12 16           11 15         2 10 14         3 9 13
+--R     4096e  x   + 16384d e  x   + 24576d e  x   + 14336d e x
+--R   + 
+--R              11        4 8  12              10        5 7  11
+--R     (16384a e   - 2048d e )x   + (49152a d e   - 6144d e )x
+--R   + 
+--R              2 9        6 6  10            3 8       7 5  9
+--R     (49152a d e  - 1664d e )x   + (10240a d e  + 768d e )x
+--R   + 
+--R            2 10           4 7       8 4  8
+--R     (24576a e   - 12288a d e  + 384d e )x
+--R   + 
+--R            2   9          5 6      9 3  7
+--R     (49152a d e  - 6144a d e  - 32d e )x
+--R   + 
+--R            2 2 8         6 5      10 2  6           2 3 7         7 4  5
+--R     (24576a d e  + 768a d e  - 32d  e )x  + (- 6144a d e  + 768a d e )x
+--R   + 
+--R            3 9        2 4 6    12  4          3   8        9 2  3       2 6 4 2
+--R     (16384a e  - 6144a d e  + d  )x  + (16384a d e  - 32a d e )x  + 384a d e x
+--R   + 
+--R            3 3 6         4 8
+--R     - 2048a d e x + 4096a e
+--R                                                    Type: Polynomial(Integer)
+--E 190
+
+--S 191 of 534
+r0:=1/1048576*(5*d^4+256*a*e^3)^4*x/e^4-1/8192*d^2*(5*d^4+256*a*e^3)^3*_
+   (1/4*d/e+x)^3/e^2+1/5120*(5*d^4+256*a*e^3)^2*(59*d^4+256*a*e^3)*_
+   (1/4*d/e+x)^5-9/224*d^2*e^2*(85*d^8+5632*a*d^4*e^3+65536*a^2*e^6)*_
+   (1/4*d/e+x)^7+1/24*e^4*(601*d^8+20992*a*d^4*e^3+65536*a^2*e^6)*_
+   (1/4*d/e+x)^9-72/11*d^2*e^6*(17*d^4+256*a*e^3)*(1/4*d/e+x)^11+_
+   64/13*e^8*(59*d^4+256*a*e^3)*(1/4*d/e+x)^13-2048/5*d^2*e^10*_
+   (1/4*d/e+x)^15+4096/17*e^12*(1/4*d/e+x)^17
+--R 
+--R
+--R   (2)
+--R       4096  17 17          16 16   8192  2 15 15        3 14 14
+--R       ---- e  x   + 1024d e  x   + ---- d e  x   + 1024d e  x
+--R        17                            5
+--R     + 
+--R        16384    16   2048  4 13  13             15       5 12  12
+--R       (----- a e   - ---- d e  )x   + (4096a d e   - 512d e  )x
+--R          13           13
+--R     + 
+--R        49152    2 14   1664  6 11  11           3 13   384  7 10  10
+--R       (----- a d e   - ---- d e  )x   + (1024a d e   + --- d e  )x
+--R          11             11                              5
+--R     + 
+--R        8192  2 15   4096    4 12   128  8 9  9
+--R       (---- a e   - ---- a d e   + --- d e )x
+--R          3            3             3
+--R     + 
+--R             2   14         5 11     9 8  8
+--R       (6144a d e   - 768a d e   - 4d e )x
+--R     + 
+--R        24576  2 2 13   768    6 10   32  10 7  7
+--R       (----- a d e   + --- a d e   - -- d  e )x
+--R          7              7             7
+--R     + 
+--R               2 3 12         7 9  6    16384  3 14   6144  2 4 11   1  12 5  5
+--R       (- 1024a d e   + 128a d e )x  + (----- a e   - ---- a d e   + - d  e )x
+--R                                          5             5            5
+--R     + 
+--R             3   13       9 7  4       2 6 9 3        3 3 11 2        4 13
+--R       (4096a d e   - 8a d e )x  + 128a d e x  - 1024a d e  x  + 4096a e  x
+--R     + 
+--R         144  3 5 9   3907  2 9 6    214607     13 3      99110183    17
+--R       - --- a d e  - ---- a d e  - -------- a d  e  - ------------- d
+--R          5           3360          12300288           1070617067520
+--R  /
+--R      5
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 191
+
+--S 192 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     4096  12 17          11 16   8192  2 10 15        3 9 14
+--R     ---- e  x   + 1024d e  x   + ---- d e  x   + 1024d e x
+--R      17                            5
+--R   + 
+--R      16384    11   2048  4 8  13             10       5 7  12
+--R     (----- a e   - ---- d e )x   + (4096a d e   - 512d e )x
+--R        13           13
+--R   + 
+--R      49152    2 9   1664  6 6  11           3 8   384  7 5  10
+--R     (----- a d e  - ---- d e )x   + (1024a d e  + --- d e )x
+--R        11            11                            5
+--R   + 
+--R      8192  2 10   4096    4 7   128  8 4  9
+--R     (---- a e   - ---- a d e  + --- d e )x
+--R        3            3            3
+--R   + 
+--R           2   9         5 6     9 3  8
+--R     (6144a d e  - 768a d e  - 4d e )x
+--R   + 
+--R      24576  2 2 8   768    6 5   32  10 2  7           2 3 7         7 4  6
+--R     (----- a d e  + --- a d e  - -- d  e )x  + (- 1024a d e  + 128a d e )x
+--R        7             7            7
+--R   + 
+--R      16384  3 9   6144  2 4 6   1  12  5         3   8       9 2  4
+--R     (----- a e  - ---- a d e  + - d  )x  + (4096a d e  - 8a d e )x
+--R        5            5           5
+--R   + 
+--R         2 6 4 3        3 3 6 2        4 8
+--R     128a d e x  - 1024a d e x  + 4096a e x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 192
+
+--S 193 of 534
+m0:=a0-r0
+--R 
+--R
+--R        144  3 5 9   3907  2 9 6    214607     13 3      99110183    17
+--R        --- a d e  + ---- a d e  + -------- a d  e  + ------------- d
+--R         5           3360          12300288           1070617067520
+--R   (4)  ---------------------------------------------------------------
+--R                                        5
+--R                                       e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 193
+
+--S 194 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 194
+
+)clear all
+
+--S 195 of 534
+t0:=(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^3
+--R 
+--R
+--R   (1)
+--R         9 12          8 11        2 7 10       3 6 9           8       4 5  8
+--R     512e x   + 1536d e x   + 1536d e x   + 320d e x  + (1536a e  - 384d e )x
+--R   + 
+--R               7       5 4  7           2 6      6 3  6
+--R     (3072a d e  - 192d e )x  + (1536a d e  + 24d e )x
+--R   + 
+--R              3 5      7 2  5         2 7         4 4  4         2   6    9  3
+--R     (- 384a d e  + 24d e )x  + (1536a e  - 384a d e )x  + (1536a d e  - d )x
+--R   + 
+--R          6 2 2       2 3 4        3 6
+--R     24a d e x  - 192a d e x + 512a e
+--R                                                    Type: Polynomial(Integer)
+--E 195
+
+--S 196 of 534
+r0:=512*a^3*e^6*x-96*a^2*d^3*e^4*x^2+8*a*d^6*e^2*x^3-1/4*d*(d^8-_
+   1536*a^2*e^6)*x^4-384/5*a*e^4*(d^4-4*a*e^3)*x^5+4*d^3*e^2*(d^4-_
+   16*a*e^3)*x^6+24/7*d^2*e^3*(d^4+64*a*e^3)*x^7-24*d*e^4*(d^4-16*a*e^3)*_
+   x^8-128/3*e^5*(d^4-4*a*e^3)*x^9+32*d^3*e^6*x^10+1536/11*d^2*e^7*x^11+_
+   128*d*e^8*x^12+512/13*e^9*x^13
+--R 
+--R
+--R   (2)
+--R     512  9 13         8 12   1536  2 7 11      3 6 10    512    8   128  4 5  9
+--R     --- e x   + 128d e x   + ---- d e x   + 32d e x   + (--- a e  - --- d e )x
+--R      13                       11                          3          3
+--R   + 
+--R              7      5 4  8    1536    2 6   24  6 3  7           3 5     7 2  6
+--R     (384a d e  - 24d e )x  + (---- a d e  + -- d e )x  + (- 64a d e  + 4d e )x
+--R                                 7            7
+--R   + 
+--R      1536  2 7   384    4 4  5        2   6   1  9  4       6 2 3      2 3 4 2
+--R     (---- a e  - --- a d e )x  + (384a d e  - - d )x  + 8a d e x  - 96a d e x
+--R        5          5                           4
+--R   + 
+--R         3 6
+--R     512a e x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 196
+
+--S 197 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     512  9 13         8 12   1536  2 7 11      3 6 10    512    8   128  4 5  9
+--R     --- e x   + 128d e x   + ---- d e x   + 32d e x   + (--- a e  - --- d e )x
+--R      13                       11                          3          3
+--R   + 
+--R              7      5 4  8    1536    2 6   24  6 3  7           3 5     7 2  6
+--R     (384a d e  - 24d e )x  + (---- a d e  + -- d e )x  + (- 64a d e  + 4d e )x
+--R                                 7            7
+--R   + 
+--R      1536  2 7   384    4 4  5        2   6   1  9  4       6 2 3      2 3 4 2
+--R     (---- a e  - --- a d e )x  + (384a d e  - - d )x  + 8a d e x  - 96a d e x
+--R        5          5                           4
+--R   + 
+--R         3 6
+--R     512a e x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 197
+
+--S 198 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 198
+
+--S 199 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 199
+
+)clear all
+
+--S 200 of 534
+t0:=(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^2
+--R 
+--R
+--R   (1)
+--R        6 8         5 7      2 4 6      3 3 5          5      4 2  4
+--R     64e x  + 128d e x  + 64d e x  - 16d e x  + (128a e  - 16d e )x
+--R   + 
+--R             4 3    6 2        3 2       2 4
+--R     128a d e x  + d x  - 16a d e x + 64a e
+--R                                                    Type: Polynomial(Integer)
+--E 200
+
+--S 201 of 534
+r0:=64*a^2*e^4*x-8*a*d^3*e^2*x^2+1/3*d^6*x^3+32*a*d*e^4*x^4-_
+   16/5*e^2*(d^4-8*a*e^3)*x^5-8/3*d^3*e^3*x^6+64/7*d^2*e^4*x^7+_
+   16*d*e^5*x^8+64/9*e^6*x^9
+--R 
+--R
+--R   (2)
+--R     64  6 9        5 8   64  2 4 7   8  3 3 6    128    5   16  4 2  5
+--R     -- e x  + 16d e x  + -- d e x  - - d e x  + (--- a e  - -- d e )x
+--R      9                    7          3            5          5
+--R   + 
+--R            4 4   1  6 3       3 2 2      2 4
+--R     32a d e x  + - d x  - 8a d e x  + 64a e x
+--R                  3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 201
+
+--S 202 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     64  6 9        5 8   64  2 4 7   8  3 3 6    128    5   16  4 2  5
+--R     -- e x  + 16d e x  + -- d e x  - - d e x  + (--- a e  - -- d e )x
+--R      9                    7          3            5          5
+--R   + 
+--R            4 4   1  6 3       3 2 2      2 4
+--R     32a d e x  + - d x  - 8a d e x  + 64a e x
+--R                  3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 202
+
+--S 203 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 203
+
+--S 204 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 204
+
+)clear all
+
+--S 205 of 534
+t0:=8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4
+--R 
+--R
+--R          3 4       2 3    3        2
+--R   (1)  8e x  + 8d e x  - d x + 8a e
+--R                                                    Type: Polynomial(Integer)
+--E 205
+
+--S 206 of 534
+r0:=8*a*e^2*x-1/2*d^3*x^2+2*d*e^2*x^4+8/5*e^3*x^5
+--R 
+--R
+--R        8  3 5       2 4   1  3 2       2
+--R   (2)  - e x  + 2d e x  - - d x  + 8a e x
+--R        5                  2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 206
+
+--S 207 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R        8  3 5       2 4   1  3 2       2
+--R   (3)  - e x  + 2d e x  - - d x  + 8a e x
+--R        5                  2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 207
+
+--S 208 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 208
+
+--S 209 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 209
+
+)clear all
+
+--S 210 of 534
+t0:=1/(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R          3 4       2 3    3        2
+--R        8e x  + 8d e x  - d x + 8a e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 210
+
+--S 211 of 534
+r0:=2*atanh(4*e*(1/4*d/e+x)/sqrt(3*d^2-2*sqrt(d^4-64*a*e^3)))/_
+   (sqrt(d^4-64*a*e^3)*sqrt(3*d^2-2*sqrt(d^4-64*a*e^3)))-_
+   2*atanh(4*e*(1/4*d/e+x)/sqrt(3*d^2+2*sqrt(d^4-64*a*e^3)))/_
+   (sqrt(d^4-64*a*e^3)*sqrt(3*d^2+2*sqrt(d^4-64*a*e^3)))
+--R 
+--R
+--R   (2)
+--R         +-----------------------+
+--R         |  +-------------+
+--R         |  |       3    4      2                 4e x + d
+--R       2\|2\|- 64a e  + d   + 3d  atanh(----------------------------)
+--R                                         +-------------------------+
+--R                                         |    +-------------+
+--R                                         |    |       3    4      2
+--R                                        \|- 2\|- 64a e  + d   + 3d
+--R     + 
+--R           +-------------------------+
+--R           |    +-------------+
+--R           |    |       3    4      2                4e x + d
+--R       - 2\|- 2\|- 64a e  + d   + 3d  atanh(--------------------------)
+--R                                             +-----------------------+
+--R                                             |  +-------------+
+--R                                             |  |       3    4      2
+--R                                            \|2\|- 64a e  + d   + 3d
+--R  /
+--R                      +-------------------------+ +-----------------------+
+--R      +-------------+ |    +-------------+        |  +-------------+
+--R      |       3    4  |    |       3    4      2  |  |       3    4      2
+--R     \|- 64a e  + d  \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R            ROOT
+--R                             2 6         4 3      8
+--R                     (131072a e  + 512a d e  - 40d )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                        1
+--R                      |- ---------------------------------------------
+--R                      |          3 9         2 4 6         8 3      12
+--R                     \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                 + 
+--R                        2
+--R                   - 12d
+--R              /
+--R                       2 6        4 3     8
+--R                 16384a e  + 64a d e  - 5d
+--R         *
+--R            log
+--R                              2 2 6         6 3      10
+--R                       (49152a d e  + 192a d e  - 15d  )
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                        1
+--R                        |- ---------------------------------------------
+--R                        |          3 9         2 4 6         8 3      12
+--R                       \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                   + 
+--R                             3     4
+--R                     - 128a e  + 2d
+--R                *
+--R                   ROOT
+--R                                    2 6         4 3      8
+--R                            (131072a e  + 512a d e  - 40d )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |                        1
+--R                             |- ---------------------------------------------
+--R                             |          3 9         2 4 6         8 3      12
+--R                            \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                        + 
+--R                               2
+--R                          - 12d
+--R                     /
+--R                              2 6        4 3     8
+--R                        16384a e  + 64a d e  - 5d
+--R               + 
+--R                 8e x + 2d
+--R     + 
+--R         ROOT
+--R                            2 6         4 3      8
+--R                  (- 131072a e  - 512a d e  + 40d )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |          3 9         2 4 6         8 3      12
+--R                  \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R              + 
+--R                     2
+--R                - 12d
+--R           /
+--R                    2 6        4 3     8
+--R              16384a e  + 64a d e  - 5d
+--R      *
+--R         log
+--R                           2 2 6         6 3      10
+--R                    (49152a d e  + 192a d e  - 15d  )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |          3 9         2 4 6         8 3      12
+--R                    \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                + 
+--R                        3     4
+--R                  128a e  - 2d
+--R             *
+--R                ROOT
+--R                                   2 6         4 3      8
+--R                         (- 131072a e  - 512a d e  + 40d )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |          3 9         2 4 6         8 3      12
+--R                         \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                     + 
+--R                            2
+--R                       - 12d
+--R                  /
+--R                           2 6        4 3     8
+--R                     16384a e  + 64a d e  - 5d
+--R            + 
+--R              8e x + 2d
+--R     + 
+--R       -
+--R            ROOT
+--R                               2 6         4 3      8
+--R                     (- 131072a e  - 512a d e  + 40d )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                        1
+--R                      |- ---------------------------------------------
+--R                      |          3 9         2 4 6         8 3      12
+--R                     \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                 + 
+--R                        2
+--R                   - 12d
+--R              /
+--R                       2 6        4 3     8
+--R                 16384a e  + 64a d e  - 5d
+--R         *
+--R            log
+--R                                2 2 6         6 3      10
+--R                       (- 49152a d e  - 192a d e  + 15d  )
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                        1
+--R                        |- ---------------------------------------------
+--R                        |          3 9         2 4 6         8 3      12
+--R                       \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                   + 
+--R                             3     4
+--R                     - 128a e  + 2d
+--R                *
+--R                   ROOT
+--R                                      2 6         4 3      8
+--R                            (- 131072a e  - 512a d e  + 40d )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |                        1
+--R                             |- ---------------------------------------------
+--R                             |          3 9         2 4 6         8 3      12
+--R                            \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                        + 
+--R                               2
+--R                          - 12d
+--R                     /
+--R                              2 6        4 3     8
+--R                        16384a e  + 64a d e  - 5d
+--R               + 
+--R                 8e x + 2d
+--R     + 
+--R         ROOT
+--R                          2 6         4 3      8
+--R                  (131072a e  + 512a d e  - 40d )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |          3 9         2 4 6         8 3      12
+--R                  \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R              + 
+--R                     2
+--R                - 12d
+--R           /
+--R                    2 6        4 3     8
+--R              16384a e  + 64a d e  - 5d
+--R      *
+--R         log
+--R                             2 2 6         6 3      10
+--R                    (- 49152a d e  - 192a d e  + 15d  )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |          3 9         2 4 6         8 3      12
+--R                    \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                + 
+--R                        3     4
+--R                  128a e  - 2d
+--R             *
+--R                ROOT
+--R                                 2 6         4 3      8
+--R                         (131072a e  + 512a d e  - 40d )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |          3 9         2 4 6         8 3      12
+--R                         \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                     + 
+--R                            2
+--R                       - 12d
+--R                  /
+--R                           2 6        4 3     8
+--R                     16384a e  + 64a d e  - 5d
+--R            + 
+--R              8e x + 2d
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 212
+
+--S 213 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                             +-------------------------+
+--R             +-------------+ |    +-------------+
+--R             |       3    4  |    |       3    4      2
+--R            \|- 64a e  + d  \|- 2\|- 64a e  + d   + 3d
+--R         *
+--R             +-----------------------+
+--R             |  +-------------+
+--R             |  |       3    4      2
+--R            \|2\|- 64a e  + d   + 3d
+--R         *
+--R            ROOT
+--R                             2 6         4 3      8
+--R                     (131072a e  + 512a d e  - 40d )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                        1
+--R                      |- ---------------------------------------------
+--R                      |          3 9         2 4 6         8 3      12
+--R                     \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                 + 
+--R                        2
+--R                   - 12d
+--R              /
+--R                       2 6        4 3     8
+--R                 16384a e  + 64a d e  - 5d
+--R         *
+--R            log
+--R                              2 2 6         6 3      10
+--R                       (49152a d e  + 192a d e  - 15d  )
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                        1
+--R                        |- ---------------------------------------------
+--R                        |          3 9         2 4 6         8 3      12
+--R                       \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                   + 
+--R                             3     4
+--R                     - 128a e  + 2d
+--R                *
+--R                   ROOT
+--R                                    2 6         4 3      8
+--R                            (131072a e  + 512a d e  - 40d )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |                        1
+--R                             |- ---------------------------------------------
+--R                             |          3 9         2 4 6         8 3      12
+--R                            \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                        + 
+--R                               2
+--R                          - 12d
+--R                     /
+--R                              2 6        4 3     8
+--R                        16384a e  + 64a d e  - 5d
+--R               + 
+--R                 8e x + 2d
+--R     + 
+--R          +-------------+
+--R          |       3    4
+--R         \|- 64a e  + d
+--R      *
+--R         ROOT
+--R                            2 6         4 3      8
+--R                  (- 131072a e  - 512a d e  + 40d )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |          3 9         2 4 6         8 3      12
+--R                  \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R              + 
+--R                     2
+--R                - 12d
+--R           /
+--R                    2 6        4 3     8
+--R              16384a e  + 64a d e  - 5d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +-------------+        |  +-------------+
+--R          |    |       3    4      2  |  |       3    4      2
+--R         \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R      *
+--R         log
+--R                           2 2 6         6 3      10
+--R                    (49152a d e  + 192a d e  - 15d  )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |          3 9         2 4 6         8 3      12
+--R                    \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                + 
+--R                        3     4
+--R                  128a e  - 2d
+--R             *
+--R                ROOT
+--R                                   2 6         4 3      8
+--R                         (- 131072a e  - 512a d e  + 40d )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |          3 9         2 4 6         8 3      12
+--R                         \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                     + 
+--R                            2
+--R                       - 12d
+--R                  /
+--R                           2 6        4 3     8
+--R                     16384a e  + 64a d e  - 5d
+--R            + 
+--R              8e x + 2d
+--R     + 
+--R       -
+--R             +-------------+
+--R             |       3    4
+--R            \|- 64a e  + d
+--R         *
+--R            ROOT
+--R                               2 6         4 3      8
+--R                     (- 131072a e  - 512a d e  + 40d )
+--R                  *
+--R                      +-----------------------------------------------+
+--R                      |                        1
+--R                      |- ---------------------------------------------
+--R                      |          3 9         2 4 6         8 3      12
+--R                     \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                 + 
+--R                        2
+--R                   - 12d
+--R              /
+--R                       2 6        4 3     8
+--R                 16384a e  + 64a d e  - 5d
+--R         *
+--R             +-------------------------+ +-----------------------+
+--R             |    +-------------+        |  +-------------+
+--R             |    |       3    4      2  |  |       3    4      2
+--R            \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R         *
+--R            log
+--R                                2 2 6         6 3      10
+--R                       (- 49152a d e  - 192a d e  + 15d  )
+--R                    *
+--R                        +-----------------------------------------------+
+--R                        |                        1
+--R                        |- ---------------------------------------------
+--R                        |          3 9         2 4 6         8 3      12
+--R                       \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                   + 
+--R                             3     4
+--R                     - 128a e  + 2d
+--R                *
+--R                   ROOT
+--R                                      2 6         4 3      8
+--R                            (- 131072a e  - 512a d e  + 40d )
+--R                         *
+--R                             +-----------------------------------------------+
+--R                             |                        1
+--R                             |- ---------------------------------------------
+--R                             |          3 9         2 4 6         8 3      12
+--R                            \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                        + 
+--R                               2
+--R                          - 12d
+--R                     /
+--R                              2 6        4 3     8
+--R                        16384a e  + 64a d e  - 5d
+--R               + 
+--R                 8e x + 2d
+--R     + 
+--R                          +-------------------------+ +-----------------------+
+--R          +-------------+ |    +-------------+        |  +-------------+
+--R          |       3    4  |    |       3    4      2  |  |       3    4      2
+--R         \|- 64a e  + d  \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R      *
+--R         ROOT
+--R                          2 6         4 3      8
+--R                  (131072a e  + 512a d e  - 40d )
+--R               *
+--R                   +-----------------------------------------------+
+--R                   |                        1
+--R                   |- ---------------------------------------------
+--R                   |          3 9         2 4 6         8 3      12
+--R                  \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R              + 
+--R                     2
+--R                - 12d
+--R           /
+--R                    2 6        4 3     8
+--R              16384a e  + 64a d e  - 5d
+--R      *
+--R         log
+--R                             2 2 6         6 3      10
+--R                    (- 49152a d e  - 192a d e  + 15d  )
+--R                 *
+--R                     +-----------------------------------------------+
+--R                     |                        1
+--R                     |- ---------------------------------------------
+--R                     |          3 9         2 4 6         8 3      12
+--R                    \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                + 
+--R                        3     4
+--R                  128a e  - 2d
+--R             *
+--R                ROOT
+--R                                 2 6         4 3      8
+--R                         (131072a e  + 512a d e  - 40d )
+--R                      *
+--R                          +-----------------------------------------------+
+--R                          |                        1
+--R                          |- ---------------------------------------------
+--R                          |          3 9         2 4 6         8 3      12
+--R                         \|  4194304a e  + 98304a d e  - 960a d e  - 25d
+--R                     + 
+--R                            2
+--R                       - 12d
+--R                  /
+--R                           2 6        4 3     8
+--R                     16384a e  + 64a d e  - 5d
+--R            + 
+--R              8e x + 2d
+--R     + 
+--R           +-----------------------+
+--R           |  +-------------+
+--R           |  |       3    4      2                 4e x + d
+--R       - 4\|2\|- 64a e  + d   + 3d  atanh(----------------------------)
+--R                                           +-------------------------+
+--R                                           |    +-------------+
+--R                                           |    |       3    4      2
+--R                                          \|- 2\|- 64a e  + d   + 3d
+--R     + 
+--R         +-------------------------+
+--R         |    +-------------+
+--R         |    |       3    4      2                4e x + d
+--R       4\|- 2\|- 64a e  + d   + 3d  atanh(--------------------------)
+--R                                           +-----------------------+
+--R                                           |  +-------------+
+--R                                           |  |       3    4      2
+--R                                          \|2\|- 64a e  + d   + 3d
+--R  /
+--R                       +-------------------------+ +-----------------------+
+--R       +-------------+ |    +-------------+        |  +-------------+
+--R       |       3    4  |    |       3    4      2  |  |       3    4      2
+--R     2\|- 64a e  + d  \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R                                                    Type: Expression(Integer)
+--E 213
+
+--S 214 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 214
+
+)clear all
+
+--S 215 of 534
+t0:=1/(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          6 8         5 7      2 4 6      3 3 5          5      4 2  4
+--R       64e x  + 128d e x  + 64d e x  - 16d e x  + (128a e  - 16d e )x
+--R     + 
+--R               4 3    6 2        3 2       2 4
+--R       128a d e x  + d x  - 16a d e x + 64a e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 215
+
+--S 216 of 534
+r0:=64*e*(1/4*d/e+x)*(13*d^4-256*a*e^3-48*d^2*e^2*(1/4*d/e+x)^2)/_
+   ((5*d^8-64*a*d^4*e^3-16384*a^2*e^6)*(5*d^4/e+256*a*e^2-96*d^2*_
+   e*(1/4*d/e+x)^2+256*e^3*(1/4*d/e+x)^4))-24*e*atanh(4*e*(1/4*d/e+x)/_
+   sqrt(3*d^2-2*sqrt(d^4-64*a*e^3)))*(d^4+128*a*e^3-d^2*sqrt(d^4-_
+   64*a*e^3))/((d^4-64*a*e^3)^(3/2)*(5*d^4+256*a*e^3)*sqrt(3*d^2-_
+   2*sqrt(d^4-64*a*e^3)))+24*e*atanh(4*e*(1/4*d/e+x)/sqrt(3*d^2+_
+   2*sqrt(d^4-64*a*e^3)))*(d^4+128*a*e^3+d^2*sqrt(d^4-64*a*e^3))/_
+   ((d^4-64*a*e^3)^(3/2)*(5*d^4+256*a*e^3)*sqrt(3*d^2+2*sqrt(d^4-64*a*e^3)))
+--R 
+--R
+--R   (2)
+--R                                                           +-------------+
+--R                  2 4 4       3 3 3      5            2 3  |       3    4
+--R           (- 192d e x  - 192d e x  + 24d e x - 192a d e )\|- 64a e  + d
+--R         + 
+--R                    7       4 4  4              6       5 3  3
+--R           (24576a e  + 192d e )x  + (24576a d e  + 192d e )x
+--R         + 
+--R                     3 4      7            2 6         4 3
+--R           (- 3072a d e  - 24d e)x + 24576a e  + 192a d e
+--R      *
+--R          +-----------------------+
+--R          |  +-------------+
+--R          |  |       3    4      2                 4e x + d
+--R         \|2\|- 64a e  + d   + 3d  atanh(----------------------------)
+--R                                          +-------------------------+
+--R                                          |    +-------------+
+--R                                          |    |       3    4      2
+--R                                         \|- 2\|- 64a e  + d   + 3d
+--R     + 
+--R                                                           +-------------+
+--R                  2 4 4       3 3 3      5            2 3  |       3    4
+--R           (- 192d e x  - 192d e x  + 24d e x - 192a d e )\|- 64a e  + d
+--R         + 
+--R                      7       4 4  4                6       5 3  3
+--R           (- 24576a e  - 192d e )x  + (- 24576a d e  - 192d e )x
+--R         + 
+--R                   3 4      7            2 6         4 3
+--R           (3072a d e  + 24d e)x - 24576a e  - 192a d e
+--R      *
+--R          +-------------------------+
+--R          |    +-------------+
+--R          |    |       3    4      2                4e x + d
+--R         \|- 2\|- 64a e  + d   + 3d  atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            |  +-------------+
+--R                                            |  |       3    4      2
+--R                                           \|2\|- 64a e  + d   + 3d
+--R     + 
+--R             2 3 3      3 2 2          4     4              3     5
+--R         (96d e x  + 72d e x  + (512a e  - 8d e)x + 128a d e  - 5d )
+--R      *
+--R                          +-------------------------+ +-----------------------+
+--R          +-------------+ |    +-------------+        |  +-------------+
+--R          |       3    4  |    |       3    4      2  |  |       3    4      2
+--R         \|- 64a e  + d  \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R  /
+--R                 2 9         4 6      8 3  4
+--R         (131072a e  + 512a d e  - 40d e )x
+--R       + 
+--R                 2   8         5 5      9 2  3
+--R         (131072a d e  + 512a d e  - 40d e )x
+--R       + 
+--R                  2 3 6        7 3     11            3 8       2 4 5        8 2
+--R         (- 16384a d e  - 64a d e  + 5d  )x + 131072a e  + 512a d e  - 40a d e
+--R    *
+--R                        +-------------------------+ +-----------------------+
+--R        +-------------+ |    +-------------+        |  +-------------+
+--R        |       3    4  |    |       3    4      2  |  |       3    4      2
+--R       \|- 64a e  + d  \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     2 9         4 6      8 3  4
+--R           (- 131072a e  - 512a d e  + 40d e )x
+--R         + 
+--R                     2   8         5 5      9 2  3
+--R           (- 131072a d e  - 512a d e  + 40d e )x
+--R         + 
+--R                  2 3 6        7 3     11            3 8       2 4 5        8 2
+--R           (16384a d e  + 64a d e  - 5d  )x - 131072a e  - 512a d e  + 40a d e
+--R      *
+--R         ROOT
+--R                                  6 18                5 4 15              4 8 12
+--R                    8796093022208a e   + 103079215104a d e   - 7650410496a d e
+--R                  + 
+--R                               3 12 9           2 16 6          20 3       24
+--R                    - 62390272a d  e  + 2334720a d  e  + 9600a d  e  - 250d
+--R               *
+--R                  ROOT
+--R                                     2 10               4 7          8 4
+--R                       - 21743271936a e   - 169869312a d e  - 331776d e
+--R                    /
+--R                                              9 27                       8 4 24
+--R                         73786976294838206464a e   + 5188146770730811392a d e
+--R                       + 
+--R                                           7 8 21                    6 12 18
+--R                         70931694131085312a d e   - 2744381022928896a d  e
+--R                       + 
+--R                                          5 16 15                4 20 12
+--R                         - 78082505441280a d  e   + 150994944000a d  e
+--R                       + 
+--R                                     3 24 9             2 28 6             32 3
+--R                         21135360000a d  e  + 115200000a d  e  - 1800000a d  e
+--R                       + 
+--R                                 36
+--R                         - 15625d
+--R              + 
+--R                           2 2 8            6 5        10 2
+--R                - 47185920a d e  - 184320a d e  - 1152d  e
+--R           /
+--R                              6 18               5 4 15              4 8 12
+--R                4398046511104a e   + 51539607552a d e   - 3825205248a d e
+--R              + 
+--R                           3 12 9           2 16 6          20 3       24
+--R                - 31195136a d  e  + 1167360a d  e  + 4800a d  e  - 125d
+--R      *
+--R         log
+--R                                       7 2 21                  6 6 18
+--R                      2251799813685248a d e   + 30786325577728a d e
+--R                    + 
+--R                                      5 10 15               4 14 12
+--R                      - 1906965479424a d  e   - 19797114880a d  e
+--R                    + 
+--R                                3 18 9           2 22 6           26 3       30
+--R                      566493184a d  e  + 3624960a d  e  - 59200a d  e  - 125d
+--R                 *
+--R                    ROOT
+--R                                       2 10               4 7          8 4
+--R                         - 21743271936a e   - 169869312a d e  - 331776d e
+--R                      /
+--R                                                9 27
+--R                           73786976294838206464a e
+--R                         + 
+--R                                               8 4 24                     7 8 21
+--R                           5188146770730811392a d e   + 70931694131085312a d e
+--R                         + 
+--R                                              6 12 18                  5 16 15
+--R                           - 2744381022928896a d  e   - 78082505441280a d  e
+--R                         + 
+--R                                        4 20 12               3 24 9
+--R                           150994944000a d  e   + 21135360000a d  e
+--R                         + 
+--R                                     2 28 6             32 3         36
+--R                           115200000a d  e  - 1800000a d  e  - 15625d
+--R                + 
+--R                                 4 14              3 4 11            2 8 8
+--R                  - 154618822656a e   + 4831838208a d e   - 35389440a d e
+--R                + 
+--R                            12 5       16 2
+--R                  - 73728a d  e  + 576d  e
+--R             *
+--R                ROOT
+--R                                         6 18                5 4 15
+--R                           8796093022208a e   + 103079215104a d e
+--R                         + 
+--R                                        4 8 12            3 12 9
+--R                           - 7650410496a d e   - 62390272a d  e
+--R                         + 
+--R                                   2 16 6          20 3       24
+--R                           2334720a d  e  + 9600a d  e  - 250d
+--R                      *
+--R                         ROOT
+--R                                            2 10               4 7          8 4
+--R                              - 21743271936a e   - 169869312a d e  - 331776d e
+--R                           /
+--R                                                     9 27
+--R                                73786976294838206464a e
+--R                              + 
+--R                                                    8 4 24
+--R                                5188146770730811392a d e
+--R                              + 
+--R                                                  7 8 21
+--R                                70931694131085312a d e
+--R                              + 
+--R                                                   6 12 18
+--R                                - 2744381022928896a d  e
+--R                              + 
+--R                                                 5 16 15                4 20 12
+--R                                - 78082505441280a d  e   + 150994944000a d  e
+--R                              + 
+--R                                            3 24 9             2 28 6
+--R                                21135360000a d  e  + 115200000a d  e
+--R                              + 
+--R                                            32 3         36
+--R                                - 1800000a d  e  - 15625d
+--R                     + 
+--R                                  2 2 8            6 5        10 2
+--R                       - 47185920a d e  - 184320a d e  - 1152d  e
+--R                  /
+--R                                     6 18               5 4 15
+--R                       4398046511104a e   + 51539607552a d e
+--R                     + 
+--R                                    4 8 12            3 12 9           2 16 6
+--R                       - 3825205248a d e   - 31195136a d  e  + 1167360a d  e
+--R                     + 
+--R                              20 3       24
+--R                       4800a d  e  - 125d
+--R            + 
+--R                       2 10             4 7               2   9            5 6
+--R            (905969664a e   + 3538944a d e )x + 226492416a d e  + 884736a d e
+--R     + 
+--R                   2 9         4 6      8 3  4
+--R           (131072a e  + 512a d e  - 40d e )x
+--R         + 
+--R                   2   8         5 5      9 2  3
+--R           (131072a d e  + 512a d e  - 40d e )x
+--R         + 
+--R                  2 3 6        7 3     11            3 8       2 4 5        8 2
+--R         (- 16384a d e  - 64a d e  + 5d  )x + 131072a e  + 512a d e  - 40a d e
+--R      *
+--R         ROOT
+--R                                    6 18                5 4 15
+--R                    - 8796093022208a e   - 103079215104a d e
+--R                  + 
+--R                               4 8 12            3 12 9           2 16 6
+--R                    7650410496a d e   + 62390272a d  e  - 2334720a d  e
+--R                  + 
+--R                             20 3       24
+--R                    - 9600a d  e  + 250d
+--R               *
+--R                  ROOT
+--R                                     2 10               4 7          8 4
+--R                       - 21743271936a e   - 169869312a d e  - 331776d e
+--R                    /
+--R                                              9 27                       8 4 24
+--R                         73786976294838206464a e   + 5188146770730811392a d e
+--R                       + 
+--R                                           7 8 21                    6 12 18
+--R                         70931694131085312a d e   - 2744381022928896a d  e
+--R                       + 
+--R                                          5 16 15                4 20 12
+--R                         - 78082505441280a d  e   + 150994944000a d  e
+--R                       + 
+--R                                     3 24 9             2 28 6             32 3
+--R                         21135360000a d  e  + 115200000a d  e  - 1800000a d  e
+--R                       + 
+--R                                 36
+--R                         - 15625d
+--R              + 
+--R                           2 2 8            6 5        10 2
+--R                - 47185920a d e  - 184320a d e  - 1152d  e
+--R           /
+--R                              6 18               5 4 15              4 8 12
+--R                4398046511104a e   + 51539607552a d e   - 3825205248a d e
+--R              + 
+--R                           3 12 9           2 16 6          20 3       24
+--R                - 31195136a d  e  + 1167360a d  e  + 4800a d  e  - 125d
+--R      *
+--R         log
+--R                                       7 2 21                  6 6 18
+--R                      2251799813685248a d e   + 30786325577728a d e
+--R                    + 
+--R                                      5 10 15               4 14 12
+--R                      - 1906965479424a d  e   - 19797114880a d  e
+--R                    + 
+--R                                3 18 9           2 22 6           26 3       30
+--R                      566493184a d  e  + 3624960a d  e  - 59200a d  e  - 125d
+--R                 *
+--R                    ROOT
+--R                                       2 10               4 7          8 4
+--R                         - 21743271936a e   - 169869312a d e  - 331776d e
+--R                      /
+--R                                                9 27
+--R                           73786976294838206464a e
+--R                         + 
+--R                                               8 4 24                     7 8 21
+--R                           5188146770730811392a d e   + 70931694131085312a d e
+--R                         + 
+--R                                              6 12 18                  5 16 15
+--R                           - 2744381022928896a d  e   - 78082505441280a d  e
+--R                         + 
+--R                                        4 20 12               3 24 9
+--R                           150994944000a d  e   + 21135360000a d  e
+--R                         + 
+--R                                     2 28 6             32 3         36
+--R                           115200000a d  e  - 1800000a d  e  - 15625d
+--R                + 
+--R                               4 14              3 4 11            2 8 8
+--R                  154618822656a e   - 4831838208a d e   + 35389440a d e
+--R                + 
+--R                          12 5       16 2
+--R                  73728a d  e  - 576d  e
+--R             *
+--R                ROOT
+--R                                           6 18                5 4 15
+--R                           - 8796093022208a e   - 103079215104a d e
+--R                         + 
+--R                                      4 8 12            3 12 9           2 16 6
+--R                           7650410496a d e   + 62390272a d  e  - 2334720a d  e
+--R                         + 
+--R                                    20 3       24
+--R                           - 9600a d  e  + 250d
+--R                      *
+--R                         ROOT
+--R                                            2 10               4 7          8 4
+--R                              - 21743271936a e   - 169869312a d e  - 331776d e
+--R                           /
+--R                                                     9 27
+--R                                73786976294838206464a e
+--R                              + 
+--R                                                    8 4 24
+--R                                5188146770730811392a d e
+--R                              + 
+--R                                                  7 8 21
+--R                                70931694131085312a d e
+--R                              + 
+--R                                                   6 12 18
+--R                                - 2744381022928896a d  e
+--R                              + 
+--R                                                 5 16 15                4 20 12
+--R                                - 78082505441280a d  e   + 150994944000a d  e
+--R                              + 
+--R                                            3 24 9             2 28 6
+--R                                21135360000a d  e  + 115200000a d  e
+--R                              + 
+--R                                            32 3         36
+--R                                - 1800000a d  e  - 15625d
+--R                     + 
+--R                                  2 2 8            6 5        10 2
+--R                       - 47185920a d e  - 184320a d e  - 1152d  e
+--R                  /
+--R                                     6 18               5 4 15
+--R                       4398046511104a e   + 51539607552a d e
+--R                     + 
+--R                                    4 8 12            3 12 9           2 16 6
+--R                       - 3825205248a d e   - 31195136a d  e  + 1167360a d  e
+--R                     + 
+--R                              20 3       24
+--R                       4800a d  e  - 125d
+--R            + 
+--R                       2 10             4 7               2   9            5 6
+--R            (905969664a e   + 3538944a d e )x + 226492416a d e  + 884736a d e
+--R     + 
+--R                     2 9         4 6      8 3  4
+--R           (- 131072a e  - 512a d e  + 40d e )x
+--R         + 
+--R                     2   8         5 5      9 2  3
+--R           (- 131072a d e  - 512a d e  + 40d e )x
+--R         + 
+--R                  2 3 6        7 3     11            3 8       2 4 5        8 2
+--R           (16384a d e  + 64a d e  - 5d  )x - 131072a e  - 512a d e  + 40a d e
+--R      *
+--R         ROOT
+--R                                    6 18                5 4 15
+--R                    - 8796093022208a e   - 103079215104a d e
+--R                  + 
+--R                               4 8 12            3 12 9           2 16 6
+--R                    7650410496a d e   + 62390272a d  e  - 2334720a d  e
+--R                  + 
+--R                             20 3       24
+--R                    - 9600a d  e  + 250d
+--R               *
+--R                  ROOT
+--R                                     2 10               4 7          8 4
+--R                       - 21743271936a e   - 169869312a d e  - 331776d e
+--R                    /
+--R                                              9 27                       8 4 24
+--R                         73786976294838206464a e   + 5188146770730811392a d e
+--R                       + 
+--R                                           7 8 21                    6 12 18
+--R                         70931694131085312a d e   - 2744381022928896a d  e
+--R                       + 
+--R                                          5 16 15                4 20 12
+--R                         - 78082505441280a d  e   + 150994944000a d  e
+--R                       + 
+--R                                     3 24 9             2 28 6             32 3
+--R                         21135360000a d  e  + 115200000a d  e  - 1800000a d  e
+--R                       + 
+--R                                 36
+--R                         - 15625d
+--R              + 
+--R                           2 2 8            6 5        10 2
+--R                - 47185920a d e  - 184320a d e  - 1152d  e
+--R           /
+--R                              6 18               5 4 15              4 8 12
+--R                4398046511104a e   + 51539607552a d e   - 3825205248a d e
+--R              + 
+--R                           3 12 9           2 16 6          20 3       24
+--R                - 31195136a d  e  + 1167360a d  e  + 4800a d  e  - 125d
+--R      *
+--R         log
+--R                                         7 2 21                  6 6 18
+--R                      - 2251799813685248a d e   - 30786325577728a d e
+--R                    + 
+--R                                    5 10 15               4 14 12
+--R                      1906965479424a d  e   + 19797114880a d  e
+--R                    + 
+--R                                3 18 9           2 22 6           26 3       30
+--R                    - 566493184a d  e  - 3624960a d  e  + 59200a d  e  + 125d
+--R                 *
+--R                    ROOT
+--R                                       2 10               4 7          8 4
+--R                         - 21743271936a e   - 169869312a d e  - 331776d e
+--R                      /
+--R                                                9 27
+--R                           73786976294838206464a e
+--R                         + 
+--R                                               8 4 24                     7 8 21
+--R                           5188146770730811392a d e   + 70931694131085312a d e
+--R                         + 
+--R                                              6 12 18                  5 16 15
+--R                           - 2744381022928896a d  e   - 78082505441280a d  e
+--R                         + 
+--R                                        4 20 12               3 24 9
+--R                           150994944000a d  e   + 21135360000a d  e
+--R                         + 
+--R                                     2 28 6             32 3         36
+--R                           115200000a d  e  - 1800000a d  e  - 15625d
+--R                + 
+--R                                 4 14              3 4 11            2 8 8
+--R                  - 154618822656a e   + 4831838208a d e   - 35389440a d e
+--R                + 
+--R                            12 5       16 2
+--R                  - 73728a d  e  + 576d  e
+--R             *
+--R                ROOT
+--R                                           6 18                5 4 15
+--R                           - 8796093022208a e   - 103079215104a d e
+--R                         + 
+--R                                      4 8 12            3 12 9           2 16 6
+--R                           7650410496a d e   + 62390272a d  e  - 2334720a d  e
+--R                         + 
+--R                                    20 3       24
+--R                           - 9600a d  e  + 250d
+--R                      *
+--R                         ROOT
+--R                                            2 10               4 7          8 4
+--R                              - 21743271936a e   - 169869312a d e  - 331776d e
+--R                           /
+--R                                                     9 27
+--R                                73786976294838206464a e
+--R                              + 
+--R                                                    8 4 24
+--R                                5188146770730811392a d e
+--R                              + 
+--R                                                  7 8 21
+--R                                70931694131085312a d e
+--R                              + 
+--R                                                   6 12 18
+--R                                - 2744381022928896a d  e
+--R                              + 
+--R                                                 5 16 15                4 20 12
+--R                                - 78082505441280a d  e   + 150994944000a d  e
+--R                              + 
+--R                                            3 24 9             2 28 6
+--R                                21135360000a d  e  + 115200000a d  e
+--R                              + 
+--R                                            32 3         36
+--R                                - 1800000a d  e  - 15625d
+--R                     + 
+--R                                  2 2 8            6 5        10 2
+--R                       - 47185920a d e  - 184320a d e  - 1152d  e
+--R                  /
+--R                                     6 18               5 4 15
+--R                       4398046511104a e   + 51539607552a d e
+--R                     + 
+--R                                    4 8 12            3 12 9           2 16 6
+--R                       - 3825205248a d e   - 31195136a d  e  + 1167360a d  e
+--R                     + 
+--R                              20 3       24
+--R                       4800a d  e  - 125d
+--R            + 
+--R                       2 10             4 7               2   9            5 6
+--R            (905969664a e   + 3538944a d e )x + 226492416a d e  + 884736a d e
+--R     + 
+--R                   2 9         4 6      8 3  4
+--R           (131072a e  + 512a d e  - 40d e )x
+--R         + 
+--R                   2   8         5 5      9 2  3
+--R           (131072a d e  + 512a d e  - 40d e )x
+--R         + 
+--R                  2 3 6        7 3     11            3 8       2 4 5        8 2
+--R         (- 16384a d e  - 64a d e  + 5d  )x + 131072a e  + 512a d e  - 40a d e
+--R      *
+--R         ROOT
+--R                                  6 18                5 4 15              4 8 12
+--R                    8796093022208a e   + 103079215104a d e   - 7650410496a d e
+--R                  + 
+--R                               3 12 9           2 16 6          20 3       24
+--R                    - 62390272a d  e  + 2334720a d  e  + 9600a d  e  - 250d
+--R               *
+--R                  ROOT
+--R                                     2 10               4 7          8 4
+--R                       - 21743271936a e   - 169869312a d e  - 331776d e
+--R                    /
+--R                                              9 27                       8 4 24
+--R                         73786976294838206464a e   + 5188146770730811392a d e
+--R                       + 
+--R                                           7 8 21                    6 12 18
+--R                         70931694131085312a d e   - 2744381022928896a d  e
+--R                       + 
+--R                                          5 16 15                4 20 12
+--R                         - 78082505441280a d  e   + 150994944000a d  e
+--R                       + 
+--R                                     3 24 9             2 28 6             32 3
+--R                         21135360000a d  e  + 115200000a d  e  - 1800000a d  e
+--R                       + 
+--R                                 36
+--R                         - 15625d
+--R              + 
+--R                           2 2 8            6 5        10 2
+--R                - 47185920a d e  - 184320a d e  - 1152d  e
+--R           /
+--R                              6 18               5 4 15              4 8 12
+--R                4398046511104a e   + 51539607552a d e   - 3825205248a d e
+--R              + 
+--R                           3 12 9           2 16 6          20 3       24
+--R                - 31195136a d  e  + 1167360a d  e  + 4800a d  e  - 125d
+--R      *
+--R         log
+--R                                         7 2 21                  6 6 18
+--R                      - 2251799813685248a d e   - 30786325577728a d e
+--R                    + 
+--R                                    5 10 15               4 14 12
+--R                      1906965479424a d  e   + 19797114880a d  e
+--R                    + 
+--R                                3 18 9           2 22 6           26 3       30
+--R                    - 566493184a d  e  - 3624960a d  e  + 59200a d  e  + 125d
+--R                 *
+--R                    ROOT
+--R                                       2 10               4 7          8 4
+--R                         - 21743271936a e   - 169869312a d e  - 331776d e
+--R                      /
+--R                                                9 27
+--R                           73786976294838206464a e
+--R                         + 
+--R                                               8 4 24                     7 8 21
+--R                           5188146770730811392a d e   + 70931694131085312a d e
+--R                         + 
+--R                                              6 12 18                  5 16 15
+--R                           - 2744381022928896a d  e   - 78082505441280a d  e
+--R                         + 
+--R                                        4 20 12               3 24 9
+--R                           150994944000a d  e   + 21135360000a d  e
+--R                         + 
+--R                                     2 28 6             32 3         36
+--R                           115200000a d  e  - 1800000a d  e  - 15625d
+--R                + 
+--R                               4 14              3 4 11            2 8 8
+--R                  154618822656a e   - 4831838208a d e   + 35389440a d e
+--R                + 
+--R                          12 5       16 2
+--R                  73728a d  e  - 576d  e
+--R             *
+--R                ROOT
+--R                                         6 18                5 4 15
+--R                           8796093022208a e   + 103079215104a d e
+--R                         + 
+--R                                        4 8 12            3 12 9
+--R                           - 7650410496a d e   - 62390272a d  e
+--R                         + 
+--R                                   2 16 6          20 3       24
+--R                           2334720a d  e  + 9600a d  e  - 250d
+--R                      *
+--R                         ROOT
+--R                                            2 10               4 7          8 4
+--R                              - 21743271936a e   - 169869312a d e  - 331776d e
+--R                           /
+--R                                                     9 27
+--R                                73786976294838206464a e
+--R                              + 
+--R                                                    8 4 24
+--R                                5188146770730811392a d e
+--R                              + 
+--R                                                  7 8 21
+--R                                70931694131085312a d e
+--R                              + 
+--R                                                   6 12 18
+--R                                - 2744381022928896a d  e
+--R                              + 
+--R                                                 5 16 15                4 20 12
+--R                                - 78082505441280a d  e   + 150994944000a d  e
+--R                              + 
+--R                                            3 24 9             2 28 6
+--R                                21135360000a d  e  + 115200000a d  e
+--R                              + 
+--R                                            32 3         36
+--R                                - 1800000a d  e  - 15625d
+--R                     + 
+--R                                  2 2 8            6 5        10 2
+--R                       - 47185920a d e  - 184320a d e  - 1152d  e
+--R                  /
+--R                                     6 18               5 4 15
+--R                       4398046511104a e   + 51539607552a d e
+--R                     + 
+--R                                    4 8 12            3 12 9           2 16 6
+--R                       - 3825205248a d e   - 31195136a d  e  + 1167360a d  e
+--R                     + 
+--R                              20 3       24
+--R                       4800a d  e  - 125d
+--R            + 
+--R                       2 10             4 7               2   9            5 6
+--R            (905969664a e   + 3538944a d e )x + 226492416a d e  + 884736a d e
+--R     + 
+--R           2 3 3       3 2 2           4      4              3      5
+--R       192d e x  + 144d e x  + (1024a e  - 16d e)x + 256a d e  - 10d
+--R  /
+--R               2 9          4 6      8 3  4
+--R       (262144a e  + 1024a d e  - 80d e )x
+--R     + 
+--R               2   8          5 5      9 2  3
+--R       (262144a d e  + 1024a d e  - 80d e )x
+--R     + 
+--R              2 3 6         7 3      11            3 8        2 4 5        8 2
+--R     (- 32768a d e  - 128a d e  + 10d  )x + 262144a e  + 1024a d e  - 80a d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 217
+
+--S 218 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                        +-------------+
+--R                  2 6        4 3     8  |       3    4
+--R         (- 16384a e  - 64a d e  + 5d )\|- 64a e  + d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +-------------+        |  +-------------+
+--R          |    |       3    4      2  |  |       3    4      2
+--R         \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R      *
+--R         ROOT
+--R                                  6 18                5 4 15              4 8 12
+--R                    8796093022208a e   + 103079215104a d e   - 7650410496a d e
+--R                  + 
+--R                               3 12 9           2 16 6          20 3       24
+--R                    - 62390272a d  e  + 2334720a d  e  + 9600a d  e  - 250d
+--R               *
+--R                  ROOT
+--R                                     2 10               4 7          8 4
+--R                       - 21743271936a e   - 169869312a d e  - 331776d e
+--R                    /
+--R                                              9 27                       8 4 24
+--R                         73786976294838206464a e   + 5188146770730811392a d e
+--R                       + 
+--R                                           7 8 21                    6 12 18
+--R                         70931694131085312a d e   - 2744381022928896a d  e
+--R                       + 
+--R                                          5 16 15                4 20 12
+--R                         - 78082505441280a d  e   + 150994944000a d  e
+--R                       + 
+--R                                     3 24 9             2 28 6             32 3
+--R                         21135360000a d  e  + 115200000a d  e  - 1800000a d  e
+--R                       + 
+--R                                 36
+--R                         - 15625d
+--R              + 
+--R                           2 2 8            6 5        10 2
+--R                - 47185920a d e  - 184320a d e  - 1152d  e
+--R           /
+--R                              6 18               5 4 15              4 8 12
+--R                4398046511104a e   + 51539607552a d e   - 3825205248a d e
+--R              + 
+--R                           3 12 9           2 16 6          20 3       24
+--R                - 31195136a d  e  + 1167360a d  e  + 4800a d  e  - 125d
+--R      *
+--R         log
+--R                                       7 2 21                  6 6 18
+--R                      2251799813685248a d e   + 30786325577728a d e
+--R                    + 
+--R                                      5 10 15               4 14 12
+--R                      - 1906965479424a d  e   - 19797114880a d  e
+--R                    + 
+--R                                3 18 9           2 22 6           26 3       30
+--R                      566493184a d  e  + 3624960a d  e  - 59200a d  e  - 125d
+--R                 *
+--R                    ROOT
+--R                                       2 10               4 7          8 4
+--R                         - 21743271936a e   - 169869312a d e  - 331776d e
+--R                      /
+--R                                                9 27
+--R                           73786976294838206464a e
+--R                         + 
+--R                                               8 4 24                     7 8 21
+--R                           5188146770730811392a d e   + 70931694131085312a d e
+--R                         + 
+--R                                              6 12 18                  5 16 15
+--R                           - 2744381022928896a d  e   - 78082505441280a d  e
+--R                         + 
+--R                                        4 20 12               3 24 9
+--R                           150994944000a d  e   + 21135360000a d  e
+--R                         + 
+--R                                     2 28 6             32 3         36
+--R                           115200000a d  e  - 1800000a d  e  - 15625d
+--R                + 
+--R                                 4 14              3 4 11            2 8 8
+--R                  - 154618822656a e   + 4831838208a d e   - 35389440a d e
+--R                + 
+--R                            12 5       16 2
+--R                  - 73728a d  e  + 576d  e
+--R             *
+--R                ROOT
+--R                                         6 18                5 4 15
+--R                           8796093022208a e   + 103079215104a d e
+--R                         + 
+--R                                        4 8 12            3 12 9
+--R                           - 7650410496a d e   - 62390272a d  e
+--R                         + 
+--R                                   2 16 6          20 3       24
+--R                           2334720a d  e  + 9600a d  e  - 250d
+--R                      *
+--R                         ROOT
+--R                                            2 10               4 7          8 4
+--R                              - 21743271936a e   - 169869312a d e  - 331776d e
+--R                           /
+--R                                                     9 27
+--R                                73786976294838206464a e
+--R                              + 
+--R                                                    8 4 24
+--R                                5188146770730811392a d e
+--R                              + 
+--R                                                  7 8 21
+--R                                70931694131085312a d e
+--R                              + 
+--R                                                   6 12 18
+--R                                - 2744381022928896a d  e
+--R                              + 
+--R                                                 5 16 15                4 20 12
+--R                                - 78082505441280a d  e   + 150994944000a d  e
+--R                              + 
+--R                                            3 24 9             2 28 6
+--R                                21135360000a d  e  + 115200000a d  e
+--R                              + 
+--R                                            32 3         36
+--R                                - 1800000a d  e  - 15625d
+--R                     + 
+--R                                  2 2 8            6 5        10 2
+--R                       - 47185920a d e  - 184320a d e  - 1152d  e
+--R                  /
+--R                                     6 18               5 4 15
+--R                       4398046511104a e   + 51539607552a d e
+--R                     + 
+--R                                    4 8 12            3 12 9           2 16 6
+--R                       - 3825205248a d e   - 31195136a d  e  + 1167360a d  e
+--R                     + 
+--R                              20 3       24
+--R                       4800a d  e  - 125d
+--R            + 
+--R                       2 10             4 7               2   9            5 6
+--R            (905969664a e   + 3538944a d e )x + 226492416a d e  + 884736a d e
+--R     + 
+--R                                      +-------------+
+--R                2 6        4 3     8  |       3    4
+--R         (16384a e  + 64a d e  - 5d )\|- 64a e  + d
+--R      *
+--R         ROOT
+--R                                    6 18                5 4 15
+--R                    - 8796093022208a e   - 103079215104a d e
+--R                  + 
+--R                               4 8 12            3 12 9           2 16 6
+--R                    7650410496a d e   + 62390272a d  e  - 2334720a d  e
+--R                  + 
+--R                             20 3       24
+--R                    - 9600a d  e  + 250d
+--R               *
+--R                  ROOT
+--R                                     2 10               4 7          8 4
+--R                       - 21743271936a e   - 169869312a d e  - 331776d e
+--R                    /
+--R                                              9 27                       8 4 24
+--R                         73786976294838206464a e   + 5188146770730811392a d e
+--R                       + 
+--R                                           7 8 21                    6 12 18
+--R                         70931694131085312a d e   - 2744381022928896a d  e
+--R                       + 
+--R                                          5 16 15                4 20 12
+--R                         - 78082505441280a d  e   + 150994944000a d  e
+--R                       + 
+--R                                     3 24 9             2 28 6             32 3
+--R                         21135360000a d  e  + 115200000a d  e  - 1800000a d  e
+--R                       + 
+--R                                 36
+--R                         - 15625d
+--R              + 
+--R                           2 2 8            6 5        10 2
+--R                - 47185920a d e  - 184320a d e  - 1152d  e
+--R           /
+--R                              6 18               5 4 15              4 8 12
+--R                4398046511104a e   + 51539607552a d e   - 3825205248a d e
+--R              + 
+--R                           3 12 9           2 16 6          20 3       24
+--R                - 31195136a d  e  + 1167360a d  e  + 4800a d  e  - 125d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +-------------+        |  +-------------+
+--R          |    |       3    4      2  |  |       3    4      2
+--R         \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R      *
+--R         log
+--R                                       7 2 21                  6 6 18
+--R                      2251799813685248a d e   + 30786325577728a d e
+--R                    + 
+--R                                      5 10 15               4 14 12
+--R                      - 1906965479424a d  e   - 19797114880a d  e
+--R                    + 
+--R                                3 18 9           2 22 6           26 3       30
+--R                      566493184a d  e  + 3624960a d  e  - 59200a d  e  - 125d
+--R                 *
+--R                    ROOT
+--R                                       2 10               4 7          8 4
+--R                         - 21743271936a e   - 169869312a d e  - 331776d e
+--R                      /
+--R                                                9 27
+--R                           73786976294838206464a e
+--R                         + 
+--R                                               8 4 24                     7 8 21
+--R                           5188146770730811392a d e   + 70931694131085312a d e
+--R                         + 
+--R                                              6 12 18                  5 16 15
+--R                           - 2744381022928896a d  e   - 78082505441280a d  e
+--R                         + 
+--R                                        4 20 12               3 24 9
+--R                           150994944000a d  e   + 21135360000a d  e
+--R                         + 
+--R                                     2 28 6             32 3         36
+--R                           115200000a d  e  - 1800000a d  e  - 15625d
+--R                + 
+--R                               4 14              3 4 11            2 8 8
+--R                  154618822656a e   - 4831838208a d e   + 35389440a d e
+--R                + 
+--R                          12 5       16 2
+--R                  73728a d  e  - 576d  e
+--R             *
+--R                ROOT
+--R                                           6 18                5 4 15
+--R                           - 8796093022208a e   - 103079215104a d e
+--R                         + 
+--R                                      4 8 12            3 12 9           2 16 6
+--R                           7650410496a d e   + 62390272a d  e  - 2334720a d  e
+--R                         + 
+--R                                    20 3       24
+--R                           - 9600a d  e  + 250d
+--R                      *
+--R                         ROOT
+--R                                            2 10               4 7          8 4
+--R                              - 21743271936a e   - 169869312a d e  - 331776d e
+--R                           /
+--R                                                     9 27
+--R                                73786976294838206464a e
+--R                              + 
+--R                                                    8 4 24
+--R                                5188146770730811392a d e
+--R                              + 
+--R                                                  7 8 21
+--R                                70931694131085312a d e
+--R                              + 
+--R                                                   6 12 18
+--R                                - 2744381022928896a d  e
+--R                              + 
+--R                                                 5 16 15                4 20 12
+--R                                - 78082505441280a d  e   + 150994944000a d  e
+--R                              + 
+--R                                            3 24 9             2 28 6
+--R                                21135360000a d  e  + 115200000a d  e
+--R                              + 
+--R                                            32 3         36
+--R                                - 1800000a d  e  - 15625d
+--R                     + 
+--R                                  2 2 8            6 5        10 2
+--R                       - 47185920a d e  - 184320a d e  - 1152d  e
+--R                  /
+--R                                     6 18               5 4 15
+--R                       4398046511104a e   + 51539607552a d e
+--R                     + 
+--R                                    4 8 12            3 12 9           2 16 6
+--R                       - 3825205248a d e   - 31195136a d  e  + 1167360a d  e
+--R                     + 
+--R                              20 3       24
+--R                       4800a d  e  - 125d
+--R            + 
+--R                       2 10             4 7               2   9            5 6
+--R            (905969664a e   + 3538944a d e )x + 226492416a d e  + 884736a d e
+--R     + 
+--R                                        +-------------+
+--R                  2 6        4 3     8  |       3    4
+--R         (- 16384a e  - 64a d e  + 5d )\|- 64a e  + d
+--R      *
+--R         ROOT
+--R                                    6 18                5 4 15
+--R                    - 8796093022208a e   - 103079215104a d e
+--R                  + 
+--R                               4 8 12            3 12 9           2 16 6
+--R                    7650410496a d e   + 62390272a d  e  - 2334720a d  e
+--R                  + 
+--R                             20 3       24
+--R                    - 9600a d  e  + 250d
+--R               *
+--R                  ROOT
+--R                                     2 10               4 7          8 4
+--R                       - 21743271936a e   - 169869312a d e  - 331776d e
+--R                    /
+--R                                              9 27                       8 4 24
+--R                         73786976294838206464a e   + 5188146770730811392a d e
+--R                       + 
+--R                                           7 8 21                    6 12 18
+--R                         70931694131085312a d e   - 2744381022928896a d  e
+--R                       + 
+--R                                          5 16 15                4 20 12
+--R                         - 78082505441280a d  e   + 150994944000a d  e
+--R                       + 
+--R                                     3 24 9             2 28 6             32 3
+--R                         21135360000a d  e  + 115200000a d  e  - 1800000a d  e
+--R                       + 
+--R                                 36
+--R                         - 15625d
+--R              + 
+--R                           2 2 8            6 5        10 2
+--R                - 47185920a d e  - 184320a d e  - 1152d  e
+--R           /
+--R                              6 18               5 4 15              4 8 12
+--R                4398046511104a e   + 51539607552a d e   - 3825205248a d e
+--R              + 
+--R                           3 12 9           2 16 6          20 3       24
+--R                - 31195136a d  e  + 1167360a d  e  + 4800a d  e  - 125d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +-------------+        |  +-------------+
+--R          |    |       3    4      2  |  |       3    4      2
+--R         \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R      *
+--R         log
+--R                                         7 2 21                  6 6 18
+--R                      - 2251799813685248a d e   - 30786325577728a d e
+--R                    + 
+--R                                    5 10 15               4 14 12
+--R                      1906965479424a d  e   + 19797114880a d  e
+--R                    + 
+--R                                3 18 9           2 22 6           26 3       30
+--R                    - 566493184a d  e  - 3624960a d  e  + 59200a d  e  + 125d
+--R                 *
+--R                    ROOT
+--R                                       2 10               4 7          8 4
+--R                         - 21743271936a e   - 169869312a d e  - 331776d e
+--R                      /
+--R                                                9 27
+--R                           73786976294838206464a e
+--R                         + 
+--R                                               8 4 24                     7 8 21
+--R                           5188146770730811392a d e   + 70931694131085312a d e
+--R                         + 
+--R                                              6 12 18                  5 16 15
+--R                           - 2744381022928896a d  e   - 78082505441280a d  e
+--R                         + 
+--R                                        4 20 12               3 24 9
+--R                           150994944000a d  e   + 21135360000a d  e
+--R                         + 
+--R                                     2 28 6             32 3         36
+--R                           115200000a d  e  - 1800000a d  e  - 15625d
+--R                + 
+--R                                 4 14              3 4 11            2 8 8
+--R                  - 154618822656a e   + 4831838208a d e   - 35389440a d e
+--R                + 
+--R                            12 5       16 2
+--R                  - 73728a d  e  + 576d  e
+--R             *
+--R                ROOT
+--R                                           6 18                5 4 15
+--R                           - 8796093022208a e   - 103079215104a d e
+--R                         + 
+--R                                      4 8 12            3 12 9           2 16 6
+--R                           7650410496a d e   + 62390272a d  e  - 2334720a d  e
+--R                         + 
+--R                                    20 3       24
+--R                           - 9600a d  e  + 250d
+--R                      *
+--R                         ROOT
+--R                                            2 10               4 7          8 4
+--R                              - 21743271936a e   - 169869312a d e  - 331776d e
+--R                           /
+--R                                                     9 27
+--R                                73786976294838206464a e
+--R                              + 
+--R                                                    8 4 24
+--R                                5188146770730811392a d e
+--R                              + 
+--R                                                  7 8 21
+--R                                70931694131085312a d e
+--R                              + 
+--R                                                   6 12 18
+--R                                - 2744381022928896a d  e
+--R                              + 
+--R                                                 5 16 15                4 20 12
+--R                                - 78082505441280a d  e   + 150994944000a d  e
+--R                              + 
+--R                                            3 24 9             2 28 6
+--R                                21135360000a d  e  + 115200000a d  e
+--R                              + 
+--R                                            32 3         36
+--R                                - 1800000a d  e  - 15625d
+--R                     + 
+--R                                  2 2 8            6 5        10 2
+--R                       - 47185920a d e  - 184320a d e  - 1152d  e
+--R                  /
+--R                                     6 18               5 4 15
+--R                       4398046511104a e   + 51539607552a d e
+--R                     + 
+--R                                    4 8 12            3 12 9           2 16 6
+--R                       - 3825205248a d e   - 31195136a d  e  + 1167360a d  e
+--R                     + 
+--R                              20 3       24
+--R                       4800a d  e  - 125d
+--R            + 
+--R                       2 10             4 7               2   9            5 6
+--R            (905969664a e   + 3538944a d e )x + 226492416a d e  + 884736a d e
+--R     + 
+--R                                      +-------------+
+--R                2 6        4 3     8  |       3    4
+--R         (16384a e  + 64a d e  - 5d )\|- 64a e  + d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +-------------+        |  +-------------+
+--R          |    |       3    4      2  |  |       3    4      2
+--R         \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R      *
+--R         ROOT
+--R                                  6 18                5 4 15              4 8 12
+--R                    8796093022208a e   + 103079215104a d e   - 7650410496a d e
+--R                  + 
+--R                               3 12 9           2 16 6          20 3       24
+--R                    - 62390272a d  e  + 2334720a d  e  + 9600a d  e  - 250d
+--R               *
+--R                  ROOT
+--R                                     2 10               4 7          8 4
+--R                       - 21743271936a e   - 169869312a d e  - 331776d e
+--R                    /
+--R                                              9 27                       8 4 24
+--R                         73786976294838206464a e   + 5188146770730811392a d e
+--R                       + 
+--R                                           7 8 21                    6 12 18
+--R                         70931694131085312a d e   - 2744381022928896a d  e
+--R                       + 
+--R                                          5 16 15                4 20 12
+--R                         - 78082505441280a d  e   + 150994944000a d  e
+--R                       + 
+--R                                     3 24 9             2 28 6             32 3
+--R                         21135360000a d  e  + 115200000a d  e  - 1800000a d  e
+--R                       + 
+--R                                 36
+--R                         - 15625d
+--R              + 
+--R                           2 2 8            6 5        10 2
+--R                - 47185920a d e  - 184320a d e  - 1152d  e
+--R           /
+--R                              6 18               5 4 15              4 8 12
+--R                4398046511104a e   + 51539607552a d e   - 3825205248a d e
+--R              + 
+--R                           3 12 9           2 16 6          20 3       24
+--R                - 31195136a d  e  + 1167360a d  e  + 4800a d  e  - 125d
+--R      *
+--R         log
+--R                                         7 2 21                  6 6 18
+--R                      - 2251799813685248a d e   - 30786325577728a d e
+--R                    + 
+--R                                    5 10 15               4 14 12
+--R                      1906965479424a d  e   + 19797114880a d  e
+--R                    + 
+--R                                3 18 9           2 22 6           26 3       30
+--R                    - 566493184a d  e  - 3624960a d  e  + 59200a d  e  + 125d
+--R                 *
+--R                    ROOT
+--R                                       2 10               4 7          8 4
+--R                         - 21743271936a e   - 169869312a d e  - 331776d e
+--R                      /
+--R                                                9 27
+--R                           73786976294838206464a e
+--R                         + 
+--R                                               8 4 24                     7 8 21
+--R                           5188146770730811392a d e   + 70931694131085312a d e
+--R                         + 
+--R                                              6 12 18                  5 16 15
+--R                           - 2744381022928896a d  e   - 78082505441280a d  e
+--R                         + 
+--R                                        4 20 12               3 24 9
+--R                           150994944000a d  e   + 21135360000a d  e
+--R                         + 
+--R                                     2 28 6             32 3         36
+--R                           115200000a d  e  - 1800000a d  e  - 15625d
+--R                + 
+--R                               4 14              3 4 11            2 8 8
+--R                  154618822656a e   - 4831838208a d e   + 35389440a d e
+--R                + 
+--R                          12 5       16 2
+--R                  73728a d  e  - 576d  e
+--R             *
+--R                ROOT
+--R                                         6 18                5 4 15
+--R                           8796093022208a e   + 103079215104a d e
+--R                         + 
+--R                                        4 8 12            3 12 9
+--R                           - 7650410496a d e   - 62390272a d  e
+--R                         + 
+--R                                   2 16 6          20 3       24
+--R                           2334720a d  e  + 9600a d  e  - 250d
+--R                      *
+--R                         ROOT
+--R                                            2 10               4 7          8 4
+--R                              - 21743271936a e   - 169869312a d e  - 331776d e
+--R                           /
+--R                                                     9 27
+--R                                73786976294838206464a e
+--R                              + 
+--R                                                    8 4 24
+--R                                5188146770730811392a d e
+--R                              + 
+--R                                                  7 8 21
+--R                                70931694131085312a d e
+--R                              + 
+--R                                                   6 12 18
+--R                                - 2744381022928896a d  e
+--R                              + 
+--R                                                 5 16 15                4 20 12
+--R                                - 78082505441280a d  e   + 150994944000a d  e
+--R                              + 
+--R                                            3 24 9             2 28 6
+--R                                21135360000a d  e  + 115200000a d  e
+--R                              + 
+--R                                            32 3         36
+--R                                - 1800000a d  e  - 15625d
+--R                     + 
+--R                                  2 2 8            6 5        10 2
+--R                       - 47185920a d e  - 184320a d e  - 1152d  e
+--R                  /
+--R                                     6 18               5 4 15
+--R                       4398046511104a e   + 51539607552a d e
+--R                     + 
+--R                                    4 8 12            3 12 9           2 16 6
+--R                       - 3825205248a d e   - 31195136a d  e  + 1167360a d  e
+--R                     + 
+--R                              20 3       24
+--R                       4800a d  e  - 125d
+--R            + 
+--R                       2 10             4 7               2   9            5 6
+--R            (905969664a e   + 3538944a d e )x + 226492416a d e  + 884736a d e
+--R     + 
+--R                                                    +-----------------------+
+--R                +-------------+                     |  +-------------+
+--R             2  |       3    4           4      4   |  |       3    4      2
+--R         (48d e\|- 64a e  + d   - 6144a e  - 48d e)\|2\|- 64a e  + d   + 3d
+--R      *
+--R                         4e x + d
+--R         atanh(----------------------------)
+--R                +-------------------------+
+--R                |    +-------------+
+--R                |    |       3    4      2
+--R               \|- 2\|- 64a e  + d   + 3d
+--R     + 
+--R                                                    +-------------------------+
+--R                +-------------+                     |    +-------------+
+--R             2  |       3    4           4      4   |    |       3    4      2
+--R         (48d e\|- 64a e  + d   + 6144a e  + 48d e)\|- 2\|- 64a e  + d   + 3d
+--R      *
+--R                        4e x + d
+--R         atanh(--------------------------)
+--R                +-----------------------+
+--R                |  +-------------+
+--R                |  |       3    4      2
+--R               \|2\|- 64a e  + d   + 3d
+--R  /
+--R                                      +-------------+
+--R              2 6         4 3      8  |       3    4
+--R       (32768a e  + 128a d e  - 10d )\|- 64a e  + d
+--R    *
+--R        +-------------------------+ +-----------------------+
+--R        |    +-------------+        |  +-------------+
+--R        |    |       3    4      2  |  |       3    4      2
+--R       \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 534
+t0:=(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^(1/2)
+--R 
+--R
+--R         +-----------------------------+
+--R         |  3 4       2 3    3        2
+--R   (1)  \|8e x  + 8d e x  - d x + 8a e
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 534
+--r0:=1/12*(1/4*d/e+x)*sqrt(5*d^4/e+256*a*e^2-96*d^2*e*(1/4*d/e+x)^2+_
+--   256*e^3*(1/4*d/e+x)^4)/sqrt(2)+1/8*d^2*elliptic_e(asin(4*e*(1/4*d/e+x)/_
+--   sqrt(3*d^2+2*sqrt(d^4-64*a*e^3))),(3*d^2+2*sqrt(d^4-64*a*e^3))/(3*d^2-_
+--   2*sqrt(d^4-64*a*e^3)))*(3*d^2-2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*_
+--   (1/4*d/e+x)^2/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(3*d^2+2*sqrt(d^4-_
+--   64*a*e^3))*sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2+2*sqrt(d^4-64*a*e^3)))/_
+--   (e^2*sqrt(2)*sqrt(5*d^4/e+256*a*e^2-96*d^2*e*(1/4*d/e+x)^2+256*e^3*_
+--   (1/4*d/e+x)^4))-1/12*elliptic_f(asin(4*e*(1/4*d/e+x)/sqrt(3*d^2+_
+--   2*sqrt(d^4-64*a*e^3))),(3*d^2+2*sqrt(d^4-64*a*e^3))/(3*d^2-_
+--   2*sqrt(d^4-64*a*e^3)))*(2*d^4-128*a*e^3-3*d^2*sqrt(d^4-64*a*e^3))*_
+--   sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(3*d^2+_
+--   2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2+2*sqrt(d^4-_
+--   64*a*e^3)))/(e^2*sqrt(2)*sqrt(5*d^4/e+256*a*e^2-96*d^2*e*(1/4*d/e+x)^2+_
+--   256*e^3*(1/4*d/e+x)^4))
+--E 221
+
+--S 222 of 534
+--a0:=integrate(t0,x)
+--E 222
+
+--S 223 of 534
+--m0:=a0-r0
+--E 223
+
+--S 224 of 534
+--d0:=D(m0,x)
+--E 224
+
+)clear all
+
+--S 225 of 534
+t0:=1/(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^(1/2)
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R         +-----------------------------+
+--R         |  3 4       2 3    3        2
+--R        \|8e x  + 8d e x  - d x + 8a e
+--R                                                    Type: Expression(Integer)
+--E 225
+
+--S 226 of 534
+--r0:=elliptic_f(asin(4*e*(1/4*d/e+x)/sqrt(3*d^2+2*sqrt(d^4-64*a*e^3))),_
+--   (3*d^2+2*sqrt(d^4-64*a*e^3))/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(2)*_
+--   sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(3*d^2+_
+--   2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2+2*sqrt(d^4-_
+--   64*a*e^3)))/(e*sqrt(5*d^4/e+256*a*e^2-96*d^2*e*(1/4*d/e+x)^2+_
+--   256*e^3*(1/4*d/e+x)^4))
+--E 226
+
+--S 227 of 534
+--a0:=integrate(t0,x)
+--E 227
+
+--S 228 of 534
+--m0:=a0-r0
+--E 228
+
+--S 229 of 534
+--d0:=D(m0,x)
+--E 229
+
+)clear all
+
+--S 230 of 534
+t0:=1/(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^(3/2)
+--R 
+--R
+--R                                       1
+--R   (1)  ---------------------------------------------------------------
+--R                                        +-----------------------------+
+--R           3 4       2 3    3        2  |  3 4       2 3    3        2
+--R        (8e x  + 8d e x  - d x + 8a e )\|8e x  + 8d e x  - d x + 8a e
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 534
+--r0:=16*e*(1/4*d/e+x)*(13*d^4-256*a*e^3-48*d^2*e^2*(1/4*d/e+x)^2)*_
+--   sqrt(2)/((5*d^8-64*a*d^4*e^3-16384*a^2*e^6)*sqrt(5*d^4/e+256*a*e^2-_
+--   96*d^2*e*(1/4*d/e+x)^2+256*e^3*(1/4*d/e+x)^4))-12*d^2*_
+--   elliptic_e(asin(4*e*(1/4*d/e+x)/sqrt(3*d^2+2*sqrt(d^4-64*a*e^3))),_
+--   (3*d^2+2*sqrt(d^4-64*a*e^3))/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(2)*_
+--   (3*d^2-2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2-2*_
+--   sqrt(d^4-64*a*e^3)))*sqrt(3*d^2+2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*_
+--   (1/4*d/e+x)^2/(3*d^2+2*sqrt(d^4-64*a*e^3)))/((d^4-64*a*e^3)*(5*d^4+_
+--   256*a*e^3)*sqrt(5*d^4/e+256*a*e^2-96*d^2*e*(1/4*d/e+x)^2+256*e^3*_
+--   (1/4*d/e+x)^4))+8*elliptic_f(asin(4*e*(1/4*d/e+x)/sqrt(3*d^2+2*_
+--   sqrt(d^4-64*a*e^3))),(3*d^2+2*sqrt(d^4-64*a*e^3))/(3*d^2-2*sqrt(d^4-_
+--   64*a*e^3)))*sqrt(2)*(2*d^4-128*a*e^3-3*d^2*sqrt(d^4-64*a*e^3))*_
+--   sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(3*d^2+_
+--   2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2+2*sqrt(d^4-_
+--   64*a*e^3)))/((d^4-64*a*e^3)*(5*d^4+256*a*e^3)*sqrt(5*d^4/e+256*a*e^2-_
+--   96*d^2*e*(1/4*d/e+x)^2+256*e^3*(1/4*d/e+x)^4))
+--E 231
+
+--S 232 of 534
+--a0:=integrate(t0,x)
+--E 232
+
+--S 233 of 534
+--m0:=a0-r0
+--E 233
+
+--S 234 of 534
+--d0:=D(m0,x)
+--E 234
+
+)clear all
+
+--S 235 of 534
+t0:=(a+8*x-8*x^2+4*x^3-x^4)^4
+--R 
+--R
+--R   (1)
+--R      16      15       14       13                 12                11
+--R     x   - 16x   + 128x   - 672x   + (- 4a + 2560)x   + (48a - 7424)x
+--R   + 
+--R                      10                   9      2                  8
+--R     (- 288a + 16768)x   + (1120a - 29696)x  + (6a  - 3072a + 40960)x
+--R   + 
+--R           2                  7        2                  6
+--R     (- 48a  + 6144a - 43008)x  + (192a  - 8960a + 32768)x
+--R   + 
+--R            2                  5        3       2                 4
+--R     (- 480a  + 9216a - 16384)x  + (- 4a  + 768a  - 6144a + 4096)x
+--R   + 
+--R         3       2          3         3       2  2      3     4
+--R     (16a  - 768a  + 2048a)x  + (- 32a  + 384a )x  + 32a x + a
+--R                                                    Type: Polynomial(Integer)
+--E 235
+
+--S 236 of 534
+r0:=-8/3*(3+a)^3*(-1+x)^3+4/5*(3-a)*(3+a)^2*(-1+x)^5+8/7*(3+a)*(5+3*a)*_
+   (-1+x)^7-2/9*(37+6*a-3*a^2)*(-1+x)^9-8/11*(5+3*a)*(-1+x)^11+4/13*(3-a)*_
+   (-1+x)^13+8/15*(-1+x)^15+1/17*(-1+x)^17+(3+a)^4*x
+--R 
+--R
+--R   (2)
+--R      1  17    16   128  15      14       4     2560  13         1856  12
+--R     -- x   - x   + --- x   - 48x   + (- -- a + ----)x   + (4a - ----)x
+--R     17              15                  13      13                3
+--R   + 
+--R        288     16768  11           14848  10    2  2   1024     40960  9
+--R     (- --- a + -----)x   + (112a - -----)x   + (- a  - ---- a + -----)x
+--R         11       11                  5          3        3        9
+--R   + 
+--R          2                8    192  2           32768  7
+--R     (- 6a  + 768a - 5376)x  + (--- a  - 1280a + -----)x
+--R                                 7                 7
+--R   + 
+--R           2           8192  6      4  3   768  2   6144     4096  5
+--R     (- 80a  + 1536a - ----)x  + (- - a  + --- a  - ---- a + ----)x
+--R                         3          5       5         5        5
+--R   + 
+--R        3       2         4      32  3       2  3      3 2    4    52  3
+--R     (4a  - 192a  + 512a)x  + (- -- a  + 128a )x  + 16a x  + a x + -- a
+--R                                  3                                15
+--R   + 
+--R     2342  2   112876     33387733
+--R     ---- a  + ------ a + --------
+--R      105       2145       765765
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 236
+
+--S 237 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  17    16   128  15      14       4     2560  13         1856  12
+--R     -- x   - x   + --- x   - 48x   + (- -- a + ----)x   + (4a - ----)x
+--R     17              15                  13      13                3
+--R   + 
+--R        288     16768  11           14848  10    2  2   1024     40960  9
+--R     (- --- a + -----)x   + (112a - -----)x   + (- a  - ---- a + -----)x
+--R         11       11                  5          3        3        9
+--R   + 
+--R          2                8    192  2           32768  7
+--R     (- 6a  + 768a - 5376)x  + (--- a  - 1280a + -----)x
+--R                                 7                 7
+--R   + 
+--R           2           8192  6      4  3   768  2   6144     4096  5
+--R     (- 80a  + 1536a - ----)x  + (- - a  + --- a  - ---- a + ----)x
+--R                         3          5       5         5        5
+--R   + 
+--R        3       2         4      32  3       2  3      3 2    4
+--R     (4a  - 192a  + 512a)x  + (- -- a  + 128a )x  + 16a x  + a x
+--R                                  3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 237
+
+--S 238 of 534
+m0:=a0-r0
+--R 
+--R
+--R          52  3   2342  2   112876     33387733
+--R   (4)  - -- a  - ---- a  - ------ a - --------
+--R          15       105       2145       765765
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 238
+
+--S 239 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 239
+
+)clear all
+
+--S 240 of 534
+t0:=(a+8*x-8*x^2+4*x^3-x^4)^3
+--R 
+--R
+--R   (1)
+--R        12      11      10       9              8                  7
+--R     - x   + 12x   - 72x   + 280x  + (3a - 768)x  + (- 24a + 1536)x
+--R   + 
+--R                  6                   5        2                4
+--R     (96a - 2240)x  + (- 240a + 2304)x  + (- 3a  + 384a - 1536)x
+--R   + 
+--R         2               3         2         2      2     3
+--R     (12a  - 384a + 512)x  + (- 24a  + 192a)x  + 24a x + a
+--R                                                    Type: Polynomial(Integer)
+--E 240
+
+--S 241 of 534
+r0:=a^3*x+12*a^2*x^2+8*(8-a)*a*x^3+(128-96*a+3*a^2)*x^4-3/5*(512-128*a+a^2)*_
+   x^5+8*(48-5*a)*x^6-32/7*(70-3*a)*x^7+3*(64-a)*x^8-1/3*(256-a)*x^9+_
+   28*x^10-72/11*x^11+x^12-1/13*x^13
+--R 
+--R
+--R   (2)
+--R        1  13    12   72  11      10    1     256  9                8
+--R     - -- x   + x   - -- x   + 28x   + (- a - ---)x  + (- 3a + 192)x
+--R       13             11                3      3
+--R   + 
+--R      96          7                 6      3  2   384     1536  5
+--R     (-- a - 320)x  + (- 40a + 384)x  + (- - a  + --- a - ----)x
+--R       7                                   5       5        5
+--R   + 
+--R        2              4        2        3      2 2    3
+--R     (3a  - 96a + 128)x  + (- 8a  + 64a)x  + 12a x  + a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 241
+
+--S 242 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        1  13    12   72  11      10    1     256  9                8
+--R     - -- x   + x   - -- x   + 28x   + (- a - ---)x  + (- 3a + 192)x
+--R       13             11                3      3
+--R   + 
+--R      96          7                 6      3  2   384     1536  5
+--R     (-- a - 320)x  + (- 40a + 384)x  + (- - a  + --- a - ----)x
+--R       7                                   5       5        5
+--R   + 
+--R        2              4        2        3      2 2    3
+--R     (3a  - 96a + 128)x  + (- 8a  + 64a)x  + 12a x  + a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 242
+
+--S 243 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 243
+
+--S 244 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 244
+
+)clear all
+
+--S 245 of 534
+t0:=(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R      8     7      6      5                4              3                2
+--R     x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R   + 
+--R              2
+--R     16a x + a
+--R                                                    Type: Polynomial(Integer)
+--E 245
+
+--S 246 of 534
+r0:=a^2*x+8*a*x^2+16/3*(4-a)*x^3-2*(16-a)*x^4+2/5*(64-a)*x^5-40/3*x^6+_
+   32/7*x^7-x^8+1/9*x^9
+--R 
+--R
+--R   (2)
+--R     1  9    8   32  7   40  6      2     128  5             4      16     64  3
+--R     - x  - x  + -- x  - -- x  + (- - a + ---)x  + (2a - 32)x  + (- -- a + --)x
+--R     9            7       3         5      5                         3      3
+--R   + 
+--R         2    2
+--R     8a x  + a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 246
+
+--S 247 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  9    8   32  7   40  6      2     128  5             4      16     64  3
+--R     - x  - x  + -- x  - -- x  + (- - a + ---)x  + (2a - 32)x  + (- -- a + --)x
+--R     9            7       3         5      5                         3      3
+--R   + 
+--R         2    2
+--R     8a x  + a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 247
+
+--S 248 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 248
+
+--S 249 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 249
+
+)clear all
+
+--S 250 of 534
+t0:=a+8*x-8*x^2+4*x^3-x^4
+--R 
+--R
+--R           4     3     2
+--R   (1)  - x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Polynomial(Integer)
+--E 250
+
+--S 251 of 534
+r0:=a*x+4*x^2-8/3*x^3+x^4-1/5*x^5
+--R 
+--R
+--R          1  5    4   8  3     2
+--R   (2)  - - x  + x  - - x  + 4x  + a x
+--R          5           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 251
+
+--S 252 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R          1  5    4   8  3     2
+--R   (3)  - - x  + x  - - x  + 4x  + a x
+--R          5           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 252
+
+--S 253 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 253
+
+--S 254 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 254
+
+)clear all
+
+--S 255 of 534
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)
+--R 
+--R
+--R                     1
+--R   (1)  - -----------------------
+--R           4     3     2
+--R          x  - 4x  + 8x  - 8x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 255
+
+--S 256 of 534
+r0:=-1/2*atan((-1+x)/sqrt(1-sqrt(4+a)))/(sqrt(4+a)*sqrt(1-sqrt(4+a)))+_
+   1/2*atan((-1+x)/sqrt(1+sqrt(4+a)))/(sqrt(4+a)*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R          +------------+
+--R          | +-----+                x - 1
+--R       - \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R        +--------------+
+--R        |   +-----+               x - 1
+--R       \|- \|a + 4  + 1 atan(---------------)
+--R                              +------------+
+--R                              | +-----+
+--R                             \|\|a + 4  + 1
+--R  /
+--R               +--------------+ +------------+
+--R       +-----+ |   +-----+      | +-----+
+--R     2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +--------------------------------------------------+
+--R             |                 +---------------------------+
+--R             |   2             |             1
+--R             |(8a  + 56a + 96) |---------------------------  + 1
+--R             |                 |   3       2
+--R             |                \|64a  + 640a  + 2112a + 2304
+--R             |--------------------------------------------------
+--R             |                    2
+--R            \|                  4a  + 28a + 48
+--R         *
+--R            log
+--R                                        +---------------------------+
+--R                        2               |             1
+--R                   ((16a  + 112a + 192) |---------------------------  - 2a - 8)
+--R                                        |   3       2
+--R                                       \|64a  + 640a  + 2112a + 2304
+--R                *
+--R                    +--------------------------------------------------+
+--R                    |                 +---------------------------+
+--R                    |   2             |             1
+--R                    |(8a  + 56a + 96) |---------------------------  + 1
+--R                    |                 |   3       2
+--R                    |                \|64a  + 640a  + 2112a + 2304
+--R                    |--------------------------------------------------
+--R                    |                    2
+--R                   \|                  4a  + 28a + 48
+--R               + 
+--R                 x - 1
+--R     + 
+--R          +----------------------------------------------------+
+--R          |                   +---------------------------+
+--R          |     2             |             1
+--R          |(- 8a  - 56a - 96) |---------------------------  + 1
+--R          |                   |   3       2
+--R          |                  \|64a  + 640a  + 2112a + 2304
+--R          |----------------------------------------------------
+--R          |                     2
+--R         \|                   4a  + 28a + 48
+--R      *
+--R         log
+--R                                     +---------------------------+
+--R                     2               |             1
+--R                ((16a  + 112a + 192) |---------------------------  + 2a + 8)
+--R                                     |   3       2
+--R                                    \|64a  + 640a  + 2112a + 2304
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |                   +---------------------------+
+--R                 |     2             |             1
+--R                 |(- 8a  - 56a - 96) |---------------------------  + 1
+--R                 |                   |   3       2
+--R                 |                  \|64a  + 640a  + 2112a + 2304
+--R                 |----------------------------------------------------
+--R                 |                     2
+--R                \|                   4a  + 28a + 48
+--R            + 
+--R              x - 1
+--R     + 
+--R       -
+--R             +----------------------------------------------------+
+--R             |                   +---------------------------+
+--R             |     2             |             1
+--R             |(- 8a  - 56a - 96) |---------------------------  + 1
+--R             |                   |   3       2
+--R             |                  \|64a  + 640a  + 2112a + 2304
+--R             |----------------------------------------------------
+--R             |                     2
+--R            \|                   4a  + 28a + 48
+--R         *
+--R            log
+--R                                             +---------------------------+
+--R                             2               |             1
+--R                       (- 16a  - 112a - 192) |---------------------------  - 2a
+--R                                             |   3       2
+--R                                            \|64a  + 640a  + 2112a + 2304
+--R                     + 
+--R                       - 8
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |                   +---------------------------+
+--R                    |     2             |             1
+--R                    |(- 8a  - 56a - 96) |---------------------------  + 1
+--R                    |                   |   3       2
+--R                    |                  \|64a  + 640a  + 2112a + 2304
+--R                    |----------------------------------------------------
+--R                    |                     2
+--R                   \|                   4a  + 28a + 48
+--R               + 
+--R                 x - 1
+--R     + 
+--R          +--------------------------------------------------+
+--R          |                 +---------------------------+
+--R          |   2             |             1
+--R          |(8a  + 56a + 96) |---------------------------  + 1
+--R          |                 |   3       2
+--R          |                \|64a  + 640a  + 2112a + 2304
+--R          |--------------------------------------------------
+--R          |                    2
+--R         \|                  4a  + 28a + 48
+--R      *
+--R         log
+--R                                       +---------------------------+
+--R                       2               |             1
+--R                ((- 16a  - 112a - 192) |---------------------------  + 2a + 8)
+--R                                       |   3       2
+--R                                      \|64a  + 640a  + 2112a + 2304
+--R             *
+--R                 +--------------------------------------------------+
+--R                 |                 +---------------------------+
+--R                 |   2             |             1
+--R                 |(8a  + 56a + 96) |---------------------------  + 1
+--R                 |                 |   3       2
+--R                 |                \|64a  + 640a  + 2112a + 2304
+--R                 |--------------------------------------------------
+--R                 |                    2
+--R                \|                  4a  + 28a + 48
+--R            + 
+--R              x - 1
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 257
+
+--S 258 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                     +--------------+
+--R             +-----+ |   +-----+
+--R            \|a + 4 \|- \|a + 4  + 1
+--R         *
+--R             +--------------------------------------------------+
+--R             |                 +---------------------------+
+--R             |   2             |             1
+--R             |(8a  + 56a + 96) |---------------------------  + 1
+--R             |                 |   3       2                      +------------+
+--R             |                \|64a  + 640a  + 2112a + 2304       | +-----+
+--R             |-------------------------------------------------- \|\|a + 4  + 1
+--R             |                    2
+--R            \|                  4a  + 28a + 48
+--R         *
+--R            log
+--R                                        +---------------------------+
+--R                        2               |             1
+--R                   ((16a  + 112a + 192) |---------------------------  - 2a - 8)
+--R                                        |   3       2
+--R                                       \|64a  + 640a  + 2112a + 2304
+--R                *
+--R                    +--------------------------------------------------+
+--R                    |                 +---------------------------+
+--R                    |   2             |             1
+--R                    |(8a  + 56a + 96) |---------------------------  + 1
+--R                    |                 |   3       2
+--R                    |                \|64a  + 640a  + 2112a + 2304
+--R                    |--------------------------------------------------
+--R                    |                    2
+--R                   \|                  4a  + 28a + 48
+--R               + 
+--R                 x - 1
+--R     + 
+--R                  +--------------+
+--R          +-----+ |   +-----+
+--R         \|a + 4 \|- \|a + 4  + 1
+--R      *
+--R          +----------------------------------------------------+
+--R          |                   +---------------------------+
+--R          |     2             |             1
+--R          |(- 8a  - 56a - 96) |---------------------------  + 1
+--R          |                   |   3       2                      +------------+
+--R          |                  \|64a  + 640a  + 2112a + 2304       | +-----+
+--R          |---------------------------------------------------- \|\|a + 4  + 1
+--R          |                     2
+--R         \|                   4a  + 28a + 48
+--R      *
+--R         log
+--R                                     +---------------------------+
+--R                     2               |             1
+--R                ((16a  + 112a + 192) |---------------------------  + 2a + 8)
+--R                                     |   3       2
+--R                                    \|64a  + 640a  + 2112a + 2304
+--R             *
+--R                 +----------------------------------------------------+
+--R                 |                   +---------------------------+
+--R                 |     2             |             1
+--R                 |(- 8a  - 56a - 96) |---------------------------  + 1
+--R                 |                   |   3       2
+--R                 |                  \|64a  + 640a  + 2112a + 2304
+--R                 |----------------------------------------------------
+--R                 |                     2
+--R                \|                   4a  + 28a + 48
+--R            + 
+--R              x - 1
+--R     + 
+--R       -
+--R                     +--------------+
+--R             +-----+ |   +-----+
+--R            \|a + 4 \|- \|a + 4  + 1
+--R         *
+--R             +----------------------------------------------------+
+--R             |                   +---------------------------+
+--R             |     2             |             1
+--R             |(- 8a  - 56a - 96) |---------------------------  + 1
+--R             |                   |   3       2
+--R             |                  \|64a  + 640a  + 2112a + 2304
+--R             |----------------------------------------------------
+--R             |                     2
+--R            \|                   4a  + 28a + 48
+--R         *
+--R             +------------+
+--R             | +-----+
+--R            \|\|a + 4  + 1
+--R         *
+--R            log
+--R                                             +---------------------------+
+--R                             2               |             1
+--R                       (- 16a  - 112a - 192) |---------------------------  - 2a
+--R                                             |   3       2
+--R                                            \|64a  + 640a  + 2112a + 2304
+--R                     + 
+--R                       - 8
+--R                *
+--R                    +----------------------------------------------------+
+--R                    |                   +---------------------------+
+--R                    |     2             |             1
+--R                    |(- 8a  - 56a - 96) |---------------------------  + 1
+--R                    |                   |   3       2
+--R                    |                  \|64a  + 640a  + 2112a + 2304
+--R                    |----------------------------------------------------
+--R                    |                     2
+--R                   \|                   4a  + 28a + 48
+--R               + 
+--R                 x - 1
+--R     + 
+--R                  +--------------+
+--R          +-----+ |   +-----+
+--R         \|a + 4 \|- \|a + 4  + 1
+--R      *
+--R          +--------------------------------------------------+
+--R          |                 +---------------------------+
+--R          |   2             |             1
+--R          |(8a  + 56a + 96) |---------------------------  + 1
+--R          |                 |   3       2                      +------------+
+--R          |                \|64a  + 640a  + 2112a + 2304       | +-----+
+--R          |-------------------------------------------------- \|\|a + 4  + 1
+--R          |                    2
+--R         \|                  4a  + 28a + 48
+--R      *
+--R         log
+--R                                       +---------------------------+
+--R                       2               |             1
+--R                ((- 16a  - 112a - 192) |---------------------------  + 2a + 8)
+--R                                       |   3       2
+--R                                      \|64a  + 640a  + 2112a + 2304
+--R             *
+--R                 +--------------------------------------------------+
+--R                 |                 +---------------------------+
+--R                 |   2             |             1
+--R                 |(8a  + 56a + 96) |---------------------------  + 1
+--R                 |                 |   3       2
+--R                 |                \|64a  + 640a  + 2112a + 2304
+--R                 |--------------------------------------------------
+--R                 |                    2
+--R                \|                  4a  + 28a + 48
+--R            + 
+--R              x - 1
+--R     + 
+--R        +------------+
+--R        | +-----+                x - 1
+--R       \|\|a + 4  + 1 atan(-----------------)
+--R                            +--------------+
+--R                            |   +-----+
+--R                           \|- \|a + 4  + 1
+--R     + 
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R       - \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R  /
+--R               +--------------+ +------------+
+--R       +-----+ |   +-----+      | +-----+
+--R     2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 258
+
+--S 259 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 259
+
+)clear all
+
+--S 260 of 534
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        8     7      6      5                4              3                2
+--R       x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R     + 
+--R                2
+--R       16a x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 260
+
+--S 261 of 534
+r0:=1/4*(5+a+(-1+x)^2)*(-1+x)/((12+7*a+a^2)*(3+a-2*(-1+x)^2-(-1+x)^4))-_
+   1/8*atan((-1+x)/sqrt(1-sqrt(4+a)))*(10+3*a+sqrt(4+a))/((3+a)*(4+a)^(3/2)*_
+   sqrt(1-sqrt(4+a)))+1/8*atan((-1+x)/sqrt(1+sqrt(4+a)))*(10+3*a-_
+   sqrt(4+a))/((3+a)*(4+a)^(3/2)*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R               4     3     2           +-----+               4              3
+--R           (- x  + 4x  - 8x  + 8x + a)\|a + 4  + (- 3a - 10)x  + (12a + 40)x
+--R         + 
+--R                        2                   2
+--R           (- 24a - 80)x  + (24a + 80)x + 3a  + 10a
+--R      *
+--R          +------------+
+--R          | +-----+                x - 1
+--R         \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R               4     3     2           +-----+             4                3
+--R           (- x  + 4x  - 8x  + 8x + a)\|a + 4  + (3a + 10)x  + (- 12a - 40)x
+--R         + 
+--R                      2                     2
+--R           (24a + 80)x  + (- 24a - 80)x - 3a  - 10a
+--R      *
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R         \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R                                                        +--------------+
+--R              3     2                           +-----+ |   +-----+
+--R         (- 2x  + 6x  + (- 2a - 16)x + 2a + 12)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1
+--R  /
+--R            2             4         2               3       2               2
+--R         (8a  + 56a + 96)x  + (- 32a  - 224a - 384)x  + (64a  + 448a + 768)x
+--R       + 
+--R               2                    3      2
+--R         (- 64a  - 448a - 768)x - 8a  - 56a  - 96a
+--R    *
+--R                +--------------+ +------------+
+--R        +-----+ |   +-----+      | +-----+
+--R       \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2             4      2             3         2               2
+--R           (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x  + (- 16a  - 112a - 192)x
+--R         + 
+--R               2                    3      2
+--R           (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R      *
+--R         ROOT
+--R                        6        5         4          3          2
+--R                    128a  + 2688a  + 23424a  + 108416a  + 281088a  + 387072a
+--R                  + 
+--R                    221184
+--R               *
+--R                  ROOT
+--R                          2
+--R                       81a  + 558a + 961
+--R                    /
+--R                               9          8           7            6
+--R                         16384a  + 491520a  + 6537216a  + 50593792a
+--R                       + 
+--R                                   5             4              3              2
+--R                         251117568a  + 828997632a  + 1820344320a  + 2563964928a
+--R                       + 
+--R                         2102132736a + 764411904
+--R              + 
+--R                   2
+--R                15a  + 105a + 184
+--R           /
+--R                 6        5         4         3          2
+--R              64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a + 110592
+--R      *
+--R         log
+--R                           7          6           5           4            3
+--R                      4096a  + 100352a  + 1050624a  + 6092800a  + 21137408a
+--R                    + 
+--R                               2
+--R                      43868160a  + 50429952a + 24772608
+--R                 *
+--R                    ROOT
+--R                            2
+--R                         81a  + 558a + 961
+--R                      /
+--R                                 9          8           7            6
+--R                           16384a  + 491520a  + 6537216a  + 50593792a
+--R                         + 
+--R                                     5             4              3
+--R                           251117568a  + 828997632a  + 1820344320a
+--R                         + 
+--R                                      2
+--R                           2563964928a  + 2102132736a + 764411904
+--R                + 
+--R                        4        3         2
+--R                  - 216a  - 3264a  - 18472a  - 46400a - 43648
+--R             *
+--R                ROOT
+--R                               6        5         4          3          2
+--R                           128a  + 2688a  + 23424a  + 108416a  + 281088a
+--R                         + 
+--R                           387072a + 221184
+--R                      *
+--R                         ROOT
+--R                                 2
+--R                              81a  + 558a + 961
+--R                           /
+--R                                      9          8           7            6
+--R                                16384a  + 491520a  + 6537216a  + 50593792a
+--R                              + 
+--R                                          5             4              3
+--R                                251117568a  + 828997632a  + 1820344320a
+--R                              + 
+--R                                           2
+--R                                2563964928a  + 2102132736a + 764411904
+--R                     + 
+--R                          2
+--R                       15a  + 105a + 184
+--R                  /
+--R                          6        5         4         3          2
+--R                       64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a
+--R                     + 
+--R                       110592
+--R            + 
+--R                  2                     2
+--R              (81a  + 567a + 992)x - 81a  - 567a - 992
+--R     + 
+--R              2             4        2             3       2               2
+--R           (2a  + 14a + 24)x  + (- 8a  - 56a - 96)x  + (16a  + 112a + 192)x
+--R         + 
+--R                 2                    3      2
+--R           (- 16a  - 112a - 192)x - 2a  - 14a  - 24a
+--R      *
+--R         ROOT
+--R                          6        5         4          3          2
+--R                    - 128a  - 2688a  - 23424a  - 108416a  - 281088a  - 387072a
+--R                  + 
+--R                    - 221184
+--R               *
+--R                  ROOT
+--R                          2
+--R                       81a  + 558a + 961
+--R                    /
+--R                               9          8           7            6
+--R                         16384a  + 491520a  + 6537216a  + 50593792a
+--R                       + 
+--R                                   5             4              3              2
+--R                         251117568a  + 828997632a  + 1820344320a  + 2563964928a
+--R                       + 
+--R                         2102132736a + 764411904
+--R              + 
+--R                   2
+--R                15a  + 105a + 184
+--R           /
+--R                 6        5         4         3          2
+--R              64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a + 110592
+--R      *
+--R         log
+--R                           7          6           5           4            3
+--R                      4096a  + 100352a  + 1050624a  + 6092800a  + 21137408a
+--R                    + 
+--R                               2
+--R                      43868160a  + 50429952a + 24772608
+--R                 *
+--R                    ROOT
+--R                            2
+--R                         81a  + 558a + 961
+--R                      /
+--R                                 9          8           7            6
+--R                           16384a  + 491520a  + 6537216a  + 50593792a
+--R                         + 
+--R                                     5             4              3
+--R                           251117568a  + 828997632a  + 1820344320a
+--R                         + 
+--R                                      2
+--R                           2563964928a  + 2102132736a + 764411904
+--R                + 
+--R                      4        3         2
+--R                  216a  + 3264a  + 18472a  + 46400a + 43648
+--R             *
+--R                ROOT
+--R                                 6        5         4          3          2
+--R                           - 128a  - 2688a  - 23424a  - 108416a  - 281088a
+--R                         + 
+--R                           - 387072a - 221184
+--R                      *
+--R                         ROOT
+--R                                 2
+--R                              81a  + 558a + 961
+--R                           /
+--R                                      9          8           7            6
+--R                                16384a  + 491520a  + 6537216a  + 50593792a
+--R                              + 
+--R                                          5             4              3
+--R                                251117568a  + 828997632a  + 1820344320a
+--R                              + 
+--R                                           2
+--R                                2563964928a  + 2102132736a + 764411904
+--R                     + 
+--R                          2
+--R                       15a  + 105a + 184
+--R                  /
+--R                          6        5         4         3          2
+--R                       64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a
+--R                     + 
+--R                       110592
+--R            + 
+--R                  2                     2
+--R              (81a  + 567a + 992)x - 81a  - 567a - 992
+--R     + 
+--R                2             4      2             3         2               2
+--R           (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x  + (- 16a  - 112a - 192)x
+--R         + 
+--R               2                    3      2
+--R           (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R      *
+--R         ROOT
+--R                          6        5         4          3          2
+--R                    - 128a  - 2688a  - 23424a  - 108416a  - 281088a  - 387072a
+--R                  + 
+--R                    - 221184
+--R               *
+--R                  ROOT
+--R                          2
+--R                       81a  + 558a + 961
+--R                    /
+--R                               9          8           7            6
+--R                         16384a  + 491520a  + 6537216a  + 50593792a
+--R                       + 
+--R                                   5             4              3              2
+--R                         251117568a  + 828997632a  + 1820344320a  + 2563964928a
+--R                       + 
+--R                         2102132736a + 764411904
+--R              + 
+--R                   2
+--R                15a  + 105a + 184
+--R           /
+--R                 6        5         4         3          2
+--R              64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a + 110592
+--R      *
+--R         log
+--R                             7          6           5           4            3
+--R                      - 4096a  - 100352a  - 1050624a  - 6092800a  - 21137408a
+--R                    + 
+--R                                 2
+--R                      - 43868160a  - 50429952a - 24772608
+--R                 *
+--R                    ROOT
+--R                            2
+--R                         81a  + 558a + 961
+--R                      /
+--R                                 9          8           7            6
+--R                           16384a  + 491520a  + 6537216a  + 50593792a
+--R                         + 
+--R                                     5             4              3
+--R                           251117568a  + 828997632a  + 1820344320a
+--R                         + 
+--R                                      2
+--R                           2563964928a  + 2102132736a + 764411904
+--R                + 
+--R                        4        3         2
+--R                  - 216a  - 3264a  - 18472a  - 46400a - 43648
+--R             *
+--R                ROOT
+--R                                 6        5         4          3          2
+--R                           - 128a  - 2688a  - 23424a  - 108416a  - 281088a
+--R                         + 
+--R                           - 387072a - 221184
+--R                      *
+--R                         ROOT
+--R                                 2
+--R                              81a  + 558a + 961
+--R                           /
+--R                                      9          8           7            6
+--R                                16384a  + 491520a  + 6537216a  + 50593792a
+--R                              + 
+--R                                          5             4              3
+--R                                251117568a  + 828997632a  + 1820344320a
+--R                              + 
+--R                                           2
+--R                                2563964928a  + 2102132736a + 764411904
+--R                     + 
+--R                          2
+--R                       15a  + 105a + 184
+--R                  /
+--R                          6        5         4         3          2
+--R                       64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a
+--R                     + 
+--R                       110592
+--R            + 
+--R                  2                     2
+--R              (81a  + 567a + 992)x - 81a  - 567a - 992
+--R     + 
+--R              2             4        2             3       2               2
+--R           (2a  + 14a + 24)x  + (- 8a  - 56a - 96)x  + (16a  + 112a + 192)x
+--R         + 
+--R                 2                    3      2
+--R           (- 16a  - 112a - 192)x - 2a  - 14a  - 24a
+--R      *
+--R         ROOT
+--R                        6        5         4          3          2
+--R                    128a  + 2688a  + 23424a  + 108416a  + 281088a  + 387072a
+--R                  + 
+--R                    221184
+--R               *
+--R                  ROOT
+--R                          2
+--R                       81a  + 558a + 961
+--R                    /
+--R                               9          8           7            6
+--R                         16384a  + 491520a  + 6537216a  + 50593792a
+--R                       + 
+--R                                   5             4              3              2
+--R                         251117568a  + 828997632a  + 1820344320a  + 2563964928a
+--R                       + 
+--R                         2102132736a + 764411904
+--R              + 
+--R                   2
+--R                15a  + 105a + 184
+--R           /
+--R                 6        5         4         3          2
+--R              64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a + 110592
+--R      *
+--R         log
+--R                             7          6           5           4            3
+--R                      - 4096a  - 100352a  - 1050624a  - 6092800a  - 21137408a
+--R                    + 
+--R                                 2
+--R                      - 43868160a  - 50429952a - 24772608
+--R                 *
+--R                    ROOT
+--R                            2
+--R                         81a  + 558a + 961
+--R                      /
+--R                                 9          8           7            6
+--R                           16384a  + 491520a  + 6537216a  + 50593792a
+--R                         + 
+--R                                     5             4              3
+--R                           251117568a  + 828997632a  + 1820344320a
+--R                         + 
+--R                                      2
+--R                           2563964928a  + 2102132736a + 764411904
+--R                + 
+--R                      4        3         2
+--R                  216a  + 3264a  + 18472a  + 46400a + 43648
+--R             *
+--R                ROOT
+--R                               6        5         4          3          2
+--R                           128a  + 2688a  + 23424a  + 108416a  + 281088a
+--R                         + 
+--R                           387072a + 221184
+--R                      *
+--R                         ROOT
+--R                                 2
+--R                              81a  + 558a + 961
+--R                           /
+--R                                      9          8           7            6
+--R                                16384a  + 491520a  + 6537216a  + 50593792a
+--R                              + 
+--R                                          5             4              3
+--R                                251117568a  + 828997632a  + 1820344320a
+--R                              + 
+--R                                           2
+--R                                2563964928a  + 2102132736a + 764411904
+--R                     + 
+--R                          2
+--R                       15a  + 105a + 184
+--R                  /
+--R                          6        5         4         3          2
+--R                       64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a
+--R                     + 
+--R                       110592
+--R            + 
+--R                  2                     2
+--R              (81a  + 567a + 992)x - 81a  - 567a - 992
+--R     + 
+--R          3     2
+--R       - x  + 3x  + (- a - 8)x + a + 6
+--R  /
+--R          2             4         2               3       2               2
+--R       (4a  + 28a + 48)x  + (- 16a  - 112a - 192)x  + (32a  + 224a + 384)x
+--R     + 
+--R             2                    3      2
+--R       (- 32a  - 224a - 384)x - 4a  - 28a  - 48a
+--R                                         Type: Union(Expression(Integer),...)
+--E 262
+
+--S 263 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    +--------------+
+--R              2             +-----+ |   +-----+
+--R         (- 4a  - 28a - 48)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R         ROOT
+--R                        6        5         4          3          2
+--R                    128a  + 2688a  + 23424a  + 108416a  + 281088a  + 387072a
+--R                  + 
+--R                    221184
+--R               *
+--R                  ROOT
+--R                          2
+--R                       81a  + 558a + 961
+--R                    /
+--R                               9          8           7            6
+--R                         16384a  + 491520a  + 6537216a  + 50593792a
+--R                       + 
+--R                                   5             4              3              2
+--R                         251117568a  + 828997632a  + 1820344320a  + 2563964928a
+--R                       + 
+--R                         2102132736a + 764411904
+--R              + 
+--R                   2
+--R                15a  + 105a + 184
+--R           /
+--R                 6        5         4         3          2
+--R              64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a + 110592
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1
+--R      *
+--R         log
+--R                           7          6           5           4            3
+--R                      4096a  + 100352a  + 1050624a  + 6092800a  + 21137408a
+--R                    + 
+--R                               2
+--R                      43868160a  + 50429952a + 24772608
+--R                 *
+--R                    ROOT
+--R                            2
+--R                         81a  + 558a + 961
+--R                      /
+--R                                 9          8           7            6
+--R                           16384a  + 491520a  + 6537216a  + 50593792a
+--R                         + 
+--R                                     5             4              3
+--R                           251117568a  + 828997632a  + 1820344320a
+--R                         + 
+--R                                      2
+--R                           2563964928a  + 2102132736a + 764411904
+--R                + 
+--R                        4        3         2
+--R                  - 216a  - 3264a  - 18472a  - 46400a - 43648
+--R             *
+--R                ROOT
+--R                               6        5         4          3          2
+--R                           128a  + 2688a  + 23424a  + 108416a  + 281088a
+--R                         + 
+--R                           387072a + 221184
+--R                      *
+--R                         ROOT
+--R                                 2
+--R                              81a  + 558a + 961
+--R                           /
+--R                                      9          8           7            6
+--R                                16384a  + 491520a  + 6537216a  + 50593792a
+--R                              + 
+--R                                          5             4              3
+--R                                251117568a  + 828997632a  + 1820344320a
+--R                              + 
+--R                                           2
+--R                                2563964928a  + 2102132736a + 764411904
+--R                     + 
+--R                          2
+--R                       15a  + 105a + 184
+--R                  /
+--R                          6        5         4         3          2
+--R                       64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a
+--R                     + 
+--R                       110592
+--R            + 
+--R                  2                     2
+--R              (81a  + 567a + 992)x - 81a  - 567a - 992
+--R     + 
+--R                                  +--------------+
+--R            2             +-----+ |   +-----+
+--R         (4a  + 28a + 48)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R         ROOT
+--R                          6        5         4          3          2
+--R                    - 128a  - 2688a  - 23424a  - 108416a  - 281088a  - 387072a
+--R                  + 
+--R                    - 221184
+--R               *
+--R                  ROOT
+--R                          2
+--R                       81a  + 558a + 961
+--R                    /
+--R                               9          8           7            6
+--R                         16384a  + 491520a  + 6537216a  + 50593792a
+--R                       + 
+--R                                   5             4              3              2
+--R                         251117568a  + 828997632a  + 1820344320a  + 2563964928a
+--R                       + 
+--R                         2102132736a + 764411904
+--R              + 
+--R                   2
+--R                15a  + 105a + 184
+--R           /
+--R                 6        5         4         3          2
+--R              64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a + 110592
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1
+--R      *
+--R         log
+--R                           7          6           5           4            3
+--R                      4096a  + 100352a  + 1050624a  + 6092800a  + 21137408a
+--R                    + 
+--R                               2
+--R                      43868160a  + 50429952a + 24772608
+--R                 *
+--R                    ROOT
+--R                            2
+--R                         81a  + 558a + 961
+--R                      /
+--R                                 9          8           7            6
+--R                           16384a  + 491520a  + 6537216a  + 50593792a
+--R                         + 
+--R                                     5             4              3
+--R                           251117568a  + 828997632a  + 1820344320a
+--R                         + 
+--R                                      2
+--R                           2563964928a  + 2102132736a + 764411904
+--R                + 
+--R                      4        3         2
+--R                  216a  + 3264a  + 18472a  + 46400a + 43648
+--R             *
+--R                ROOT
+--R                                 6        5         4          3          2
+--R                           - 128a  - 2688a  - 23424a  - 108416a  - 281088a
+--R                         + 
+--R                           - 387072a - 221184
+--R                      *
+--R                         ROOT
+--R                                 2
+--R                              81a  + 558a + 961
+--R                           /
+--R                                      9          8           7            6
+--R                                16384a  + 491520a  + 6537216a  + 50593792a
+--R                              + 
+--R                                          5             4              3
+--R                                251117568a  + 828997632a  + 1820344320a
+--R                              + 
+--R                                           2
+--R                                2563964928a  + 2102132736a + 764411904
+--R                     + 
+--R                          2
+--R                       15a  + 105a + 184
+--R                  /
+--R                          6        5         4         3          2
+--R                       64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a
+--R                     + 
+--R                       110592
+--R            + 
+--R                  2                     2
+--R              (81a  + 567a + 992)x - 81a  - 567a - 992
+--R     + 
+--R                                    +--------------+
+--R              2             +-----+ |   +-----+
+--R         (- 4a  - 28a - 48)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R         ROOT
+--R                          6        5         4          3          2
+--R                    - 128a  - 2688a  - 23424a  - 108416a  - 281088a  - 387072a
+--R                  + 
+--R                    - 221184
+--R               *
+--R                  ROOT
+--R                          2
+--R                       81a  + 558a + 961
+--R                    /
+--R                               9          8           7            6
+--R                         16384a  + 491520a  + 6537216a  + 50593792a
+--R                       + 
+--R                                   5             4              3              2
+--R                         251117568a  + 828997632a  + 1820344320a  + 2563964928a
+--R                       + 
+--R                         2102132736a + 764411904
+--R              + 
+--R                   2
+--R                15a  + 105a + 184
+--R           /
+--R                 6        5         4         3          2
+--R              64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a + 110592
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1
+--R      *
+--R         log
+--R                             7          6           5           4            3
+--R                      - 4096a  - 100352a  - 1050624a  - 6092800a  - 21137408a
+--R                    + 
+--R                                 2
+--R                      - 43868160a  - 50429952a - 24772608
+--R                 *
+--R                    ROOT
+--R                            2
+--R                         81a  + 558a + 961
+--R                      /
+--R                                 9          8           7            6
+--R                           16384a  + 491520a  + 6537216a  + 50593792a
+--R                         + 
+--R                                     5             4              3
+--R                           251117568a  + 828997632a  + 1820344320a
+--R                         + 
+--R                                      2
+--R                           2563964928a  + 2102132736a + 764411904
+--R                + 
+--R                        4        3         2
+--R                  - 216a  - 3264a  - 18472a  - 46400a - 43648
+--R             *
+--R                ROOT
+--R                                 6        5         4          3          2
+--R                           - 128a  - 2688a  - 23424a  - 108416a  - 281088a
+--R                         + 
+--R                           - 387072a - 221184
+--R                      *
+--R                         ROOT
+--R                                 2
+--R                              81a  + 558a + 961
+--R                           /
+--R                                      9          8           7            6
+--R                                16384a  + 491520a  + 6537216a  + 50593792a
+--R                              + 
+--R                                          5             4              3
+--R                                251117568a  + 828997632a  + 1820344320a
+--R                              + 
+--R                                           2
+--R                                2563964928a  + 2102132736a + 764411904
+--R                     + 
+--R                          2
+--R                       15a  + 105a + 184
+--R                  /
+--R                          6        5         4         3          2
+--R                       64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a
+--R                     + 
+--R                       110592
+--R            + 
+--R                  2                     2
+--R              (81a  + 567a + 992)x - 81a  - 567a - 992
+--R     + 
+--R                                  +--------------+
+--R            2             +-----+ |   +-----+
+--R         (4a  + 28a + 48)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R         ROOT
+--R                        6        5         4          3          2
+--R                    128a  + 2688a  + 23424a  + 108416a  + 281088a  + 387072a
+--R                  + 
+--R                    221184
+--R               *
+--R                  ROOT
+--R                          2
+--R                       81a  + 558a + 961
+--R                    /
+--R                               9          8           7            6
+--R                         16384a  + 491520a  + 6537216a  + 50593792a
+--R                       + 
+--R                                   5             4              3              2
+--R                         251117568a  + 828997632a  + 1820344320a  + 2563964928a
+--R                       + 
+--R                         2102132736a + 764411904
+--R              + 
+--R                   2
+--R                15a  + 105a + 184
+--R           /
+--R                 6        5         4         3          2
+--R              64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a + 110592
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1
+--R      *
+--R         log
+--R                             7          6           5           4            3
+--R                      - 4096a  - 100352a  - 1050624a  - 6092800a  - 21137408a
+--R                    + 
+--R                                 2
+--R                      - 43868160a  - 50429952a - 24772608
+--R                 *
+--R                    ROOT
+--R                            2
+--R                         81a  + 558a + 961
+--R                      /
+--R                                 9          8           7            6
+--R                           16384a  + 491520a  + 6537216a  + 50593792a
+--R                         + 
+--R                                     5             4              3
+--R                           251117568a  + 828997632a  + 1820344320a
+--R                         + 
+--R                                      2
+--R                           2563964928a  + 2102132736a + 764411904
+--R                + 
+--R                      4        3         2
+--R                  216a  + 3264a  + 18472a  + 46400a + 43648
+--R             *
+--R                ROOT
+--R                               6        5         4          3          2
+--R                           128a  + 2688a  + 23424a  + 108416a  + 281088a
+--R                         + 
+--R                           387072a + 221184
+--R                      *
+--R                         ROOT
+--R                                 2
+--R                              81a  + 558a + 961
+--R                           /
+--R                                      9          8           7            6
+--R                                16384a  + 491520a  + 6537216a  + 50593792a
+--R                              + 
+--R                                          5             4              3
+--R                                251117568a  + 828997632a  + 1820344320a
+--R                              + 
+--R                                           2
+--R                                2563964928a  + 2102132736a + 764411904
+--R                     + 
+--R                          2
+--R                       15a  + 105a + 184
+--R                  /
+--R                          6        5         4         3          2
+--R                       64a  + 1344a  + 11712a  + 54208a  + 140544a  + 193536a
+--R                     + 
+--R                       110592
+--R            + 
+--R                  2                     2
+--R              (81a  + 567a + 992)x - 81a  - 567a - 992
+--R     + 
+--R                            +------------+
+--R         +-----+            | +-----+                x - 1
+--R       (\|a + 4  + 3a + 10)\|\|a + 4  + 1 atan(-----------------)
+--R                                                +--------------+
+--R                                                |   +-----+
+--R                                               \|- \|a + 4  + 1
+--R     + 
+--R                            +--------------+
+--R         +-----+            |   +-----+               x - 1
+--R       (\|a + 4  - 3a - 10)\|- \|a + 4  + 1 atan(---------------)
+--R                                                  +------------+
+--R                                                  | +-----+
+--R                                                 \|\|a + 4  + 1
+--R  /
+--R                              +--------------+ +------------+
+--R        2             +-----+ |   +-----+      | +-----+
+--R     (8a  + 56a + 96)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 534
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)^3
+--R 
+--R
+--R   (1)
+--R   -
+--R        1
+--R     /
+--R           12      11      10       9                8                7
+--R          x   - 12x   + 72x   - 280x  + (- 3a + 768)x  + (24a - 1536)x
+--R        + 
+--R                         6                 5      2                4
+--R          (- 96a + 2240)x  + (240a - 2304)x  + (3a  - 384a + 1536)x
+--R        + 
+--R                2               3       2         2      2     3
+--R          (- 12a  + 384a - 512)x  + (24a  - 192a)x  - 24a x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 265
+
+--S 266 of 534
+r0:=1/8*(5+a+(-1+x)^2)*(-1+x)/((12+7*a+a^2)*(3+a-2*(-1+x)^2-(-1+x)^4)^2)+_
+   1/32*((6+a)*(25+7*a)+6*(7+2*a)*(-1+x)^2)*(-1+x)/((3+a)^2*(4+a)^2*_
+   (3+a-2*(-1+x)^2-(-1+x)^4))-3/64*atan((-1+x)/sqrt(1-sqrt(4+a)))*_
+   (80+7*a^2+14*sqrt(4+a)+a*(47+4*sqrt(4+a)))/((3+a)^2*(4+a)^(5/2)*_
+   sqrt(1-sqrt(4+a)))-3/64*atan((-1+x)/sqrt(1+sqrt(4+a)))*(14+4*a+_
+   (-80-47*a-7*a^2)/sqrt(4+a))/((3+a)^2*(4+a)^2*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R                            8               7                   6
+--R               (- 12a - 42)x  + (96a + 336)x  + (- 384a - 1344)x
+--R             + 
+--R                             5       2                 4
+--R               (960a + 3360)x  + (24a  - 1452a - 5376)x
+--R             + 
+--R                     2                 3        2               2
+--R               (- 96a  + 1200a + 5376)x  + (192a  - 96a - 2688)x
+--R             + 
+--R                      2               3      2
+--R               (- 192a  - 672a)x - 12a  - 42a
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R                 2               8        2                 7
+--R           (- 21a  - 141a - 240)x  + (168a  + 1128a + 1920)x
+--R         + 
+--R                  2                 6         2                   5
+--R           (- 672a  - 4512a - 7680)x  + (1680a  + 11280a + 19200)x
+--R         + 
+--R               3        2                   4
+--R           (42a  - 2406a  - 17568a - 30720)x
+--R         + 
+--R                  3        2                   3
+--R           (- 168a  + 1560a  + 16128a + 30720)x
+--R         + 
+--R                3       2                  2          3        2
+--R           (336a  + 912a  - 5184a - 15360)x  + (- 336a  - 2256a  - 3840a)x
+--R         + 
+--R                4       3       2
+--R           - 21a  - 141a  - 240a
+--R      *
+--R          +------------+
+--R          | +-----+                x - 1
+--R         \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R                            8               7                   6
+--R               (- 12a - 42)x  + (96a + 336)x  + (- 384a - 1344)x
+--R             + 
+--R                             5       2                 4
+--R               (960a + 3360)x  + (24a  - 1452a - 5376)x
+--R             + 
+--R                     2                 3        2               2
+--R               (- 96a  + 1200a + 5376)x  + (192a  - 96a - 2688)x
+--R             + 
+--R                      2               3      2
+--R               (- 192a  - 672a)x - 12a  - 42a
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R               2               8          2                 7
+--R           (21a  + 141a + 240)x  + (- 168a  - 1128a - 1920)x
+--R         + 
+--R                2                 6           2                   5
+--R           (672a  + 4512a + 7680)x  + (- 1680a  - 11280a - 19200)x
+--R         + 
+--R                 3        2                   4
+--R           (- 42a  + 2406a  + 17568a + 30720)x
+--R         + 
+--R                3        2                   3
+--R           (168a  - 1560a  - 16128a - 30720)x
+--R         + 
+--R                  3       2                  2        3        2
+--R           (- 336a  - 912a  + 5184a + 15360)x  + (336a  + 2256a  + 3840a)x
+--R         + 
+--R              4       3       2
+--R           21a  + 141a  + 240a
+--R      *
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R         \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R                        7                6         2                5
+--R           (- 24a - 84)x  + (168a + 588)x  + (- 14a  - 686a - 2232)x
+--R         + 
+--R               2                 4          2                 3
+--R           (70a  + 1750a + 5280)x  + (- 136a  - 2716a - 7872)x
+--R         + 
+--R                2                 2       3       2                      3
+--R           (128a  + 2492a + 7200)x  + (22a  + 214a  - 168a - 2304)x - 22a
+--R         + 
+--R                 2
+--R           - 262a  - 816a - 576
+--R      *
+--R                  +--------------+ +------------+
+--R          +-----+ |   +-----+      | +-----+
+--R         \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R             4       3        2                  8
+--R         (64a  + 896a  + 4672a  + 10752a + 9216)x
+--R       + 
+--R                4        3         2                   7
+--R         (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R       + 
+--R               4         3          2                     6
+--R         (2048a  + 28672a  + 149504a  + 344064a + 294912)x
+--R       + 
+--R                 4         3          2                     5
+--R         (- 5120a  - 71680a  - 373760a  - 860160a - 737280)x
+--R       + 
+--R                5        4          3          2                       4
+--R         (- 128a  + 6400a  + 105344a  + 576512a  + 1357824a + 1179648)x
+--R       + 
+--R              5        4         3          2                       3
+--R         (512a  - 1024a  - 77312a  - 512000a  - 1302528a - 1179648)x
+--R       + 
+--R                 5         4         3          2                     2
+--R         (- 1024a  - 10240a  - 17408a  + 126976a  + 540672a + 589824)x
+--R       + 
+--R               5         4         3          2                  6       5
+--R         (1024a  + 14336a  + 74752a  + 172032a  + 147456a)x + 64a  + 896a
+--R       + 
+--R              4         3        2
+--R         4672a  + 10752a  + 9216a
+--R    *
+--R                +--------------+ +------------+
+--R        +-----+ |   +-----+      | +-----+
+--R       \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 4       3        2                 8
+--R           (- 16a  - 224a  - 1168a  - 2688a - 2304)x
+--R         + 
+--R                4        3        2                   7
+--R           (128a  + 1792a  + 9344a  + 21504a + 18432)x
+--R         + 
+--R                  4        3         2                   6
+--R           (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R         + 
+--R                 4         3         2                     5
+--R           (1280a  + 17920a  + 93440a  + 215040a + 184320)x
+--R         + 
+--R               5        4         3          2                     4
+--R           (32a  - 1600a  - 26336a  - 144128a  - 339456a - 294912)x
+--R         + 
+--R                  5       4         3          2                     3
+--R           (- 128a  + 256a  + 19328a  + 128000a  + 325632a + 294912)x
+--R         + 
+--R                5        4        3         2                     2
+--R           (256a  + 2560a  + 4352a  - 31744a  - 135168a - 147456)x
+--R         + 
+--R                  5        4         3         2                 6       5
+--R           (- 256a  - 3584a  - 18688a  - 43008a  - 36864a)x - 16a  - 224a
+--R         + 
+--R                  4        3        2
+--R           - 1168a  - 2688a  - 2304a
+--R      *
+--R         ROOT
+--R                         10          9           8            7             6
+--R                    8192a   + 286720a  + 4505600a  + 41861120a  + 254648320a
+--R                  + 
+--R                               5              4              3              2
+--R                    1059774464a  + 3055779840a  + 6028001280a  + 7785676800a
+--R                  + 
+--R                    5945425920a + 2038431744
+--R               *
+--R                  ROOT
+--R                              4           3            2
+--R                       194481a  + 2683044a  + 13929246a  + 32251284a + 28100601
+--R                    /
+--R                                  15              14               13
+--R                         67108864a   + 3355443200a   + 78181826560a
+--R                       + 
+--R                                       12                  11
+--R                         1126086737920a   + 11213220085760a
+--R                       + 
+--R                                        10                   9
+--R                         81769466429440a   + 451114507960320a
+--R                       + 
+--R                                          8                    7
+--R                         1917321719316480a  + 6329711072378880a
+--R                       + 
+--R                                           6                     5
+--R                         16231624291123200a  + 32068461429522432a
+--R                       + 
+--R                                           4                     3
+--R                         47937065488220160a  + 52483909799116800a
+--R                       + 
+--R                                           2
+--R                         39732785404968960a  + 18598325083176960a
+--R                       + 
+--R                         4057816381784064
+--R              + 
+--R                    4         3         2
+--R                945a  + 13230a  + 69741a  + 164052a + 145296
+--R           /
+--R                     10          9           8            7             6
+--R                4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R              + 
+--R                          5              4              3              2
+--R                529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R              + 
+--R                2972712960a + 1019215872
+--R      *
+--R         log
+--R                              12             11              10               9
+--R                      5767168a   + 242221056a   + 4656201728a   + 54169436160a
+--R                    + 
+--R                                   8                 7                 6
+--R                      424780759040a  + 2365347332096a  + 9590296543232a
+--R                    + 
+--R                                     5                  4                  3
+--R                      28526872887296a  + 61784614502400a  + 95021118259200a
+--R                    + 
+--R                                     2
+--R                      98500645748736a  + 61794378842112a + 17742509899776
+--R                 *
+--R                    ROOT
+--R                                  4           3            2
+--R                           194481a  + 2683044a  + 13929246a  + 32251284a
+--R                         + 
+--R                           28100601
+--R                      /
+--R                                    15              14               13
+--R                           67108864a   + 3355443200a   + 78181826560a
+--R                         + 
+--R                                         12                  11
+--R                           1126086737920a   + 11213220085760a
+--R                         + 
+--R                                          10                   9
+--R                           81769466429440a   + 451114507960320a
+--R                         + 
+--R                                            8                    7
+--R                           1917321719316480a  + 6329711072378880a
+--R                         + 
+--R                                             6                     5
+--R                           16231624291123200a  + 32068461429522432a
+--R                         + 
+--R                                             4                     3
+--R                           47937065488220160a  + 52483909799116800a
+--R                         + 
+--R                                             2
+--R                           39732785404968960a  + 18598325083176960a
+--R                         + 
+--R                           4057816381784064
+--R                + 
+--R                           7           6            5             4
+--R                  - 197568a  - 5173056a  - 58067136a  - 362238912a
+--R                + 
+--R                               3              2
+--R                  - 1356407424a  - 3048887808a  - 3809359872a - 2041012224
+--R             *
+--R                ROOT
+--R                                10          9           8            7
+--R                           8192a   + 286720a  + 4505600a  + 41861120a
+--R                         + 
+--R                                     6              5              4
+--R                           254648320a  + 1059774464a  + 3055779840a
+--R                         + 
+--R                                    3              2
+--R                         6028001280a  + 7785676800a  + 5945425920a + 2038431744
+--R                      *
+--R                         ROOT
+--R                                       4           3            2
+--R                                194481a  + 2683044a  + 13929246a  + 32251284a
+--R                              + 
+--R                                28100601
+--R                           /
+--R                                         15              14               13
+--R                                67108864a   + 3355443200a   + 78181826560a
+--R                              + 
+--R                                              12                  11
+--R                                1126086737920a   + 11213220085760a
+--R                              + 
+--R                                               10                   9
+--R                                81769466429440a   + 451114507960320a
+--R                              + 
+--R                                                 8                    7
+--R                                1917321719316480a  + 6329711072378880a
+--R                              + 
+--R                                                  6                     5
+--R                                16231624291123200a  + 32068461429522432a
+--R                              + 
+--R                                                  4                     3
+--R                                47937065488220160a  + 52483909799116800a
+--R                              + 
+--R                                                  2
+--R                                39732785404968960a  + 18598325083176960a
+--R                              + 
+--R                                4057816381784064
+--R                     + 
+--R                           4         3         2
+--R                       945a  + 13230a  + 69741a  + 164052a + 145296
+--R                  /
+--R                            10          9           8            7             6
+--R                       4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R                     + 
+--R                                 5              4              3              2
+--R                       529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R                     + 
+--R                       2972712960a + 1019215872
+--R            + 
+--R                     4          3           2                                 4
+--R              (64827a  + 907578a  + 4780647a  + 11228868a + 9923472)x - 64827a
+--R            + 
+--R                       3           2
+--R              - 907578a  - 4780647a  - 11228868a - 9923472
+--R     + 
+--R               4       3        2                 8
+--R           (16a  + 224a  + 1168a  + 2688a + 2304)x
+--R         + 
+--R                  4        3        2                   7
+--R           (- 128a  - 1792a  - 9344a  - 21504a - 18432)x
+--R         + 
+--R                4        3         2                   6
+--R           (512a  + 7168a  + 37376a  + 86016a + 73728)x
+--R         + 
+--R                   4         3         2                     5
+--R           (- 1280a  - 17920a  - 93440a  - 215040a - 184320)x
+--R         + 
+--R                 5        4         3          2                     4
+--R           (- 32a  + 1600a  + 26336a  + 144128a  + 339456a + 294912)x
+--R         + 
+--R                5       4         3          2                     3
+--R           (128a  - 256a  - 19328a  - 128000a  - 325632a - 294912)x
+--R         + 
+--R                  5        4        3         2                     2
+--R           (- 256a  - 2560a  - 4352a  + 31744a  + 135168a + 147456)x
+--R         + 
+--R                5        4         3         2                 6       5
+--R           (256a  + 3584a  + 18688a  + 43008a  + 36864a)x + 16a  + 224a
+--R         + 
+--R                4        3        2
+--R           1168a  + 2688a  + 2304a
+--R      *
+--R         ROOT
+--R                           10          9           8            7             6
+--R                    - 8192a   - 286720a  - 4505600a  - 41861120a  - 254648320a
+--R                  + 
+--R                                 5              4              3              2
+--R                    - 1059774464a  - 3055779840a  - 6028001280a  - 7785676800a
+--R                  + 
+--R                    - 5945425920a - 2038431744
+--R               *
+--R                  ROOT
+--R                              4           3            2
+--R                       194481a  + 2683044a  + 13929246a  + 32251284a + 28100601
+--R                    /
+--R                                  15              14               13
+--R                         67108864a   + 3355443200a   + 78181826560a
+--R                       + 
+--R                                       12                  11
+--R                         1126086737920a   + 11213220085760a
+--R                       + 
+--R                                        10                   9
+--R                         81769466429440a   + 451114507960320a
+--R                       + 
+--R                                          8                    7
+--R                         1917321719316480a  + 6329711072378880a
+--R                       + 
+--R                                           6                     5
+--R                         16231624291123200a  + 32068461429522432a
+--R                       + 
+--R                                           4                     3
+--R                         47937065488220160a  + 52483909799116800a
+--R                       + 
+--R                                           2
+--R                         39732785404968960a  + 18598325083176960a
+--R                       + 
+--R                         4057816381784064
+--R              + 
+--R                    4         3         2
+--R                945a  + 13230a  + 69741a  + 164052a + 145296
+--R           /
+--R                     10          9           8            7             6
+--R                4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R              + 
+--R                          5              4              3              2
+--R                529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R              + 
+--R                2972712960a + 1019215872
+--R      *
+--R         log
+--R                              12             11              10               9
+--R                      5767168a   + 242221056a   + 4656201728a   + 54169436160a
+--R                    + 
+--R                                   8                 7                 6
+--R                      424780759040a  + 2365347332096a  + 9590296543232a
+--R                    + 
+--R                                     5                  4                  3
+--R                      28526872887296a  + 61784614502400a  + 95021118259200a
+--R                    + 
+--R                                     2
+--R                      98500645748736a  + 61794378842112a + 17742509899776
+--R                 *
+--R                    ROOT
+--R                                  4           3            2
+--R                           194481a  + 2683044a  + 13929246a  + 32251284a
+--R                         + 
+--R                           28100601
+--R                      /
+--R                                    15              14               13
+--R                           67108864a   + 3355443200a   + 78181826560a
+--R                         + 
+--R                                         12                  11
+--R                           1126086737920a   + 11213220085760a
+--R                         + 
+--R                                          10                   9
+--R                           81769466429440a   + 451114507960320a
+--R                         + 
+--R                                            8                    7
+--R                           1917321719316480a  + 6329711072378880a
+--R                         + 
+--R                                             6                     5
+--R                           16231624291123200a  + 32068461429522432a
+--R                         + 
+--R                                             4                     3
+--R                           47937065488220160a  + 52483909799116800a
+--R                         + 
+--R                                             2
+--R                           39732785404968960a  + 18598325083176960a
+--R                         + 
+--R                           4057816381784064
+--R                + 
+--R                         7           6            5             4              3
+--R                  197568a  + 5173056a  + 58067136a  + 362238912a  + 1356407424a
+--R                + 
+--R                             2
+--R                  3048887808a  + 3809359872a + 2041012224
+--R             *
+--R                ROOT
+--R                                  10          9           8            7
+--R                           - 8192a   - 286720a  - 4505600a  - 41861120a
+--R                         + 
+--R                                       6              5              4
+--R                           - 254648320a  - 1059774464a  - 3055779840a
+--R                         + 
+--R                                        3              2
+--R                           - 6028001280a  - 7785676800a  - 5945425920a
+--R                         + 
+--R                           - 2038431744
+--R                      *
+--R                         ROOT
+--R                                       4           3            2
+--R                                194481a  + 2683044a  + 13929246a  + 32251284a
+--R                              + 
+--R                                28100601
+--R                           /
+--R                                         15              14               13
+--R                                67108864a   + 3355443200a   + 78181826560a
+--R                              + 
+--R                                              12                  11
+--R                                1126086737920a   + 11213220085760a
+--R                              + 
+--R                                               10                   9
+--R                                81769466429440a   + 451114507960320a
+--R                              + 
+--R                                                 8                    7
+--R                                1917321719316480a  + 6329711072378880a
+--R                              + 
+--R                                                  6                     5
+--R                                16231624291123200a  + 32068461429522432a
+--R                              + 
+--R                                                  4                     3
+--R                                47937065488220160a  + 52483909799116800a
+--R                              + 
+--R                                                  2
+--R                                39732785404968960a  + 18598325083176960a
+--R                              + 
+--R                                4057816381784064
+--R                     + 
+--R                           4         3         2
+--R                       945a  + 13230a  + 69741a  + 164052a + 145296
+--R                  /
+--R                            10          9           8            7             6
+--R                       4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R                     + 
+--R                                 5              4              3              2
+--R                       529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R                     + 
+--R                       2972712960a + 1019215872
+--R            + 
+--R                     4          3           2                                 4
+--R              (64827a  + 907578a  + 4780647a  + 11228868a + 9923472)x - 64827a
+--R            + 
+--R                       3           2
+--R              - 907578a  - 4780647a  - 11228868a - 9923472
+--R     + 
+--R                 4       3        2                 8
+--R           (- 16a  - 224a  - 1168a  - 2688a - 2304)x
+--R         + 
+--R                4        3        2                   7
+--R           (128a  + 1792a  + 9344a  + 21504a + 18432)x
+--R         + 
+--R                  4        3         2                   6
+--R           (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R         + 
+--R                 4         3         2                     5
+--R           (1280a  + 17920a  + 93440a  + 215040a + 184320)x
+--R         + 
+--R               5        4         3          2                     4
+--R           (32a  - 1600a  - 26336a  - 144128a  - 339456a - 294912)x
+--R         + 
+--R                  5       4         3          2                     3
+--R           (- 128a  + 256a  + 19328a  + 128000a  + 325632a + 294912)x
+--R         + 
+--R                5        4        3         2                     2
+--R           (256a  + 2560a  + 4352a  - 31744a  - 135168a - 147456)x
+--R         + 
+--R                  5        4         3         2                 6       5
+--R           (- 256a  - 3584a  - 18688a  - 43008a  - 36864a)x - 16a  - 224a
+--R         + 
+--R                  4        3        2
+--R           - 1168a  - 2688a  - 2304a
+--R      *
+--R         ROOT
+--R                           10          9           8            7             6
+--R                    - 8192a   - 286720a  - 4505600a  - 41861120a  - 254648320a
+--R                  + 
+--R                                 5              4              3              2
+--R                    - 1059774464a  - 3055779840a  - 6028001280a  - 7785676800a
+--R                  + 
+--R                    - 5945425920a - 2038431744
+--R               *
+--R                  ROOT
+--R                              4           3            2
+--R                       194481a  + 2683044a  + 13929246a  + 32251284a + 28100601
+--R                    /
+--R                                  15              14               13
+--R                         67108864a   + 3355443200a   + 78181826560a
+--R                       + 
+--R                                       12                  11
+--R                         1126086737920a   + 11213220085760a
+--R                       + 
+--R                                        10                   9
+--R                         81769466429440a   + 451114507960320a
+--R                       + 
+--R                                          8                    7
+--R                         1917321719316480a  + 6329711072378880a
+--R                       + 
+--R                                           6                     5
+--R                         16231624291123200a  + 32068461429522432a
+--R                       + 
+--R                                           4                     3
+--R                         47937065488220160a  + 52483909799116800a
+--R                       + 
+--R                                           2
+--R                         39732785404968960a  + 18598325083176960a
+--R                       + 
+--R                         4057816381784064
+--R              + 
+--R                    4         3         2
+--R                945a  + 13230a  + 69741a  + 164052a + 145296
+--R           /
+--R                     10          9           8            7             6
+--R                4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R              + 
+--R                          5              4              3              2
+--R                529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R              + 
+--R                2972712960a + 1019215872
+--R      *
+--R         log
+--R                                12             11              10
+--R                      - 5767168a   - 242221056a   - 4656201728a
+--R                    + 
+--R                                    9                8                 7
+--R                      - 54169436160a  - 424780759040a  - 2365347332096a
+--R                    + 
+--R                                      6                  5                  4
+--R                      - 9590296543232a  - 28526872887296a  - 61784614502400a
+--R                    + 
+--R                                       3                  2
+--R                      - 95021118259200a  - 98500645748736a  - 61794378842112a
+--R                    + 
+--R                      - 17742509899776
+--R                 *
+--R                    ROOT
+--R                                  4           3            2
+--R                           194481a  + 2683044a  + 13929246a  + 32251284a
+--R                         + 
+--R                           28100601
+--R                      /
+--R                                    15              14               13
+--R                           67108864a   + 3355443200a   + 78181826560a
+--R                         + 
+--R                                         12                  11
+--R                           1126086737920a   + 11213220085760a
+--R                         + 
+--R                                          10                   9
+--R                           81769466429440a   + 451114507960320a
+--R                         + 
+--R                                            8                    7
+--R                           1917321719316480a  + 6329711072378880a
+--R                         + 
+--R                                             6                     5
+--R                           16231624291123200a  + 32068461429522432a
+--R                         + 
+--R                                             4                     3
+--R                           47937065488220160a  + 52483909799116800a
+--R                         + 
+--R                                             2
+--R                           39732785404968960a  + 18598325083176960a
+--R                         + 
+--R                           4057816381784064
+--R                + 
+--R                           7           6            5             4
+--R                  - 197568a  - 5173056a  - 58067136a  - 362238912a
+--R                + 
+--R                               3              2
+--R                  - 1356407424a  - 3048887808a  - 3809359872a - 2041012224
+--R             *
+--R                ROOT
+--R                                  10          9           8            7
+--R                           - 8192a   - 286720a  - 4505600a  - 41861120a
+--R                         + 
+--R                                       6              5              4
+--R                           - 254648320a  - 1059774464a  - 3055779840a
+--R                         + 
+--R                                        3              2
+--R                           - 6028001280a  - 7785676800a  - 5945425920a
+--R                         + 
+--R                           - 2038431744
+--R                      *
+--R                         ROOT
+--R                                       4           3            2
+--R                                194481a  + 2683044a  + 13929246a  + 32251284a
+--R                              + 
+--R                                28100601
+--R                           /
+--R                                         15              14               13
+--R                                67108864a   + 3355443200a   + 78181826560a
+--R                              + 
+--R                                              12                  11
+--R                                1126086737920a   + 11213220085760a
+--R                              + 
+--R                                               10                   9
+--R                                81769466429440a   + 451114507960320a
+--R                              + 
+--R                                                 8                    7
+--R                                1917321719316480a  + 6329711072378880a
+--R                              + 
+--R                                                  6                     5
+--R                                16231624291123200a  + 32068461429522432a
+--R                              + 
+--R                                                  4                     3
+--R                                47937065488220160a  + 52483909799116800a
+--R                              + 
+--R                                                  2
+--R                                39732785404968960a  + 18598325083176960a
+--R                              + 
+--R                                4057816381784064
+--R                     + 
+--R                           4         3         2
+--R                       945a  + 13230a  + 69741a  + 164052a + 145296
+--R                  /
+--R                            10          9           8            7             6
+--R                       4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R                     + 
+--R                                 5              4              3              2
+--R                       529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R                     + 
+--R                       2972712960a + 1019215872
+--R            + 
+--R                     4          3           2                                 4
+--R              (64827a  + 907578a  + 4780647a  + 11228868a + 9923472)x - 64827a
+--R            + 
+--R                       3           2
+--R              - 907578a  - 4780647a  - 11228868a - 9923472
+--R     + 
+--R               4       3        2                 8
+--R           (16a  + 224a  + 1168a  + 2688a + 2304)x
+--R         + 
+--R                  4        3        2                   7
+--R           (- 128a  - 1792a  - 9344a  - 21504a - 18432)x
+--R         + 
+--R                4        3         2                   6
+--R           (512a  + 7168a  + 37376a  + 86016a + 73728)x
+--R         + 
+--R                   4         3         2                     5
+--R           (- 1280a  - 17920a  - 93440a  - 215040a - 184320)x
+--R         + 
+--R                 5        4         3          2                     4
+--R           (- 32a  + 1600a  + 26336a  + 144128a  + 339456a + 294912)x
+--R         + 
+--R                5       4         3          2                     3
+--R           (128a  - 256a  - 19328a  - 128000a  - 325632a - 294912)x
+--R         + 
+--R                  5        4        3         2                     2
+--R           (- 256a  - 2560a  - 4352a  + 31744a  + 135168a + 147456)x
+--R         + 
+--R                5        4         3         2                 6       5
+--R           (256a  + 3584a  + 18688a  + 43008a  + 36864a)x + 16a  + 224a
+--R         + 
+--R                4        3        2
+--R           1168a  + 2688a  + 2304a
+--R      *
+--R         ROOT
+--R                         10          9           8            7             6
+--R                    8192a   + 286720a  + 4505600a  + 41861120a  + 254648320a
+--R                  + 
+--R                               5              4              3              2
+--R                    1059774464a  + 3055779840a  + 6028001280a  + 7785676800a
+--R                  + 
+--R                    5945425920a + 2038431744
+--R               *
+--R                  ROOT
+--R                              4           3            2
+--R                       194481a  + 2683044a  + 13929246a  + 32251284a + 28100601
+--R                    /
+--R                                  15              14               13
+--R                         67108864a   + 3355443200a   + 78181826560a
+--R                       + 
+--R                                       12                  11
+--R                         1126086737920a   + 11213220085760a
+--R                       + 
+--R                                        10                   9
+--R                         81769466429440a   + 451114507960320a
+--R                       + 
+--R                                          8                    7
+--R                         1917321719316480a  + 6329711072378880a
+--R                       + 
+--R                                           6                     5
+--R                         16231624291123200a  + 32068461429522432a
+--R                       + 
+--R                                           4                     3
+--R                         47937065488220160a  + 52483909799116800a
+--R                       + 
+--R                                           2
+--R                         39732785404968960a  + 18598325083176960a
+--R                       + 
+--R                         4057816381784064
+--R              + 
+--R                    4         3         2
+--R                945a  + 13230a  + 69741a  + 164052a + 145296
+--R           /
+--R                     10          9           8            7             6
+--R                4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R              + 
+--R                          5              4              3              2
+--R                529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R              + 
+--R                2972712960a + 1019215872
+--R      *
+--R         log
+--R                                12             11              10
+--R                      - 5767168a   - 242221056a   - 4656201728a
+--R                    + 
+--R                                    9                8                 7
+--R                      - 54169436160a  - 424780759040a  - 2365347332096a
+--R                    + 
+--R                                      6                  5                  4
+--R                      - 9590296543232a  - 28526872887296a  - 61784614502400a
+--R                    + 
+--R                                       3                  2
+--R                      - 95021118259200a  - 98500645748736a  - 61794378842112a
+--R                    + 
+--R                      - 17742509899776
+--R                 *
+--R                    ROOT
+--R                                  4           3            2
+--R                           194481a  + 2683044a  + 13929246a  + 32251284a
+--R                         + 
+--R                           28100601
+--R                      /
+--R                                    15              14               13
+--R                           67108864a   + 3355443200a   + 78181826560a
+--R                         + 
+--R                                         12                  11
+--R                           1126086737920a   + 11213220085760a
+--R                         + 
+--R                                          10                   9
+--R                           81769466429440a   + 451114507960320a
+--R                         + 
+--R                                            8                    7
+--R                           1917321719316480a  + 6329711072378880a
+--R                         + 
+--R                                             6                     5
+--R                           16231624291123200a  + 32068461429522432a
+--R                         + 
+--R                                             4                     3
+--R                           47937065488220160a  + 52483909799116800a
+--R                         + 
+--R                                             2
+--R                           39732785404968960a  + 18598325083176960a
+--R                         + 
+--R                           4057816381784064
+--R                + 
+--R                         7           6            5             4              3
+--R                  197568a  + 5173056a  + 58067136a  + 362238912a  + 1356407424a
+--R                + 
+--R                             2
+--R                  3048887808a  + 3809359872a + 2041012224
+--R             *
+--R                ROOT
+--R                                10          9           8            7
+--R                           8192a   + 286720a  + 4505600a  + 41861120a
+--R                         + 
+--R                                     6              5              4
+--R                           254648320a  + 1059774464a  + 3055779840a
+--R                         + 
+--R                                    3              2
+--R                         6028001280a  + 7785676800a  + 5945425920a + 2038431744
+--R                      *
+--R                         ROOT
+--R                                       4           3            2
+--R                                194481a  + 2683044a  + 13929246a  + 32251284a
+--R                              + 
+--R                                28100601
+--R                           /
+--R                                         15              14               13
+--R                                67108864a   + 3355443200a   + 78181826560a
+--R                              + 
+--R                                              12                  11
+--R                                1126086737920a   + 11213220085760a
+--R                              + 
+--R                                               10                   9
+--R                                81769466429440a   + 451114507960320a
+--R                              + 
+--R                                                 8                    7
+--R                                1917321719316480a  + 6329711072378880a
+--R                              + 
+--R                                                  6                     5
+--R                                16231624291123200a  + 32068461429522432a
+--R                              + 
+--R                                                  4                     3
+--R                                47937065488220160a  + 52483909799116800a
+--R                              + 
+--R                                                  2
+--R                                39732785404968960a  + 18598325083176960a
+--R                              + 
+--R                                4057816381784064
+--R                     + 
+--R                           4         3         2
+--R                       945a  + 13230a  + 69741a  + 164052a + 145296
+--R                  /
+--R                            10          9           8            7             6
+--R                       4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R                     + 
+--R                                 5              4              3              2
+--R                       529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R                     + 
+--R                       2972712960a + 1019215872
+--R            + 
+--R                     4          3           2                                 4
+--R              (64827a  + 907578a  + 4780647a  + 11228868a + 9923472)x - 64827a
+--R            + 
+--R                       3           2
+--R              - 907578a  - 4780647a  - 11228868a - 9923472
+--R     + 
+--R                    7               6        2                5
+--R       (- 12a - 42)x  + (84a + 294)x  + (- 7a  - 343a - 1116)x
+--R     + 
+--R           2                4         2                 3
+--R       (35a  + 875a + 2640)x  + (- 68a  - 1358a - 3936)x
+--R     + 
+--R           2                 2       3       2                     3       2
+--R       (64a  + 1246a + 3600)x  + (11a  + 107a  - 84a - 1152)x - 11a  - 131a
+--R     + 
+--R       - 408a - 288
+--R  /
+--R           4       3        2                 8
+--R       (32a  + 448a  + 2336a  + 5376a + 4608)x
+--R     + 
+--R              4        3         2                   7
+--R       (- 256a  - 3584a  - 18688a  - 43008a - 36864)x
+--R     + 
+--R             4         3         2                     6
+--R       (1024a  + 14336a  + 74752a  + 172032a + 147456)x
+--R     + 
+--R               4         3          2                     5
+--R       (- 2560a  - 35840a  - 186880a  - 430080a - 368640)x
+--R     + 
+--R             5        4         3          2                     4
+--R       (- 64a  + 3200a  + 52672a  + 288256a  + 678912a + 589824)x
+--R     + 
+--R            5       4         3          2                     3
+--R       (256a  - 512a  - 38656a  - 256000a  - 651264a - 589824)x
+--R     + 
+--R              5        4        3         2                     2
+--R       (- 512a  - 5120a  - 8704a  + 63488a  + 270336a + 294912)x
+--R     + 
+--R            5        4         3         2                 6       5        4
+--R       (512a  + 7168a  + 37376a  + 86016a  + 73728a)x + 32a  + 448a  + 2336a
+--R     + 
+--R            3        2
+--R       5376a  + 4608a
+--R                                         Type: Union(Expression(Integer),...)
+--E 267
+
+--S 268 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +--------------+
+--R               4       3        2                 +-----+ |   +-----+
+--R         (- 32a  - 448a  - 2336a  - 5376a - 4608)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R         ROOT
+--R                         10          9           8            7             6
+--R                    8192a   + 286720a  + 4505600a  + 41861120a  + 254648320a
+--R                  + 
+--R                               5              4              3              2
+--R                    1059774464a  + 3055779840a  + 6028001280a  + 7785676800a
+--R                  + 
+--R                    5945425920a + 2038431744
+--R               *
+--R                  ROOT
+--R                              4           3            2
+--R                       194481a  + 2683044a  + 13929246a  + 32251284a + 28100601
+--R                    /
+--R                                  15              14               13
+--R                         67108864a   + 3355443200a   + 78181826560a
+--R                       + 
+--R                                       12                  11
+--R                         1126086737920a   + 11213220085760a
+--R                       + 
+--R                                        10                   9
+--R                         81769466429440a   + 451114507960320a
+--R                       + 
+--R                                          8                    7
+--R                         1917321719316480a  + 6329711072378880a
+--R                       + 
+--R                                           6                     5
+--R                         16231624291123200a  + 32068461429522432a
+--R                       + 
+--R                                           4                     3
+--R                         47937065488220160a  + 52483909799116800a
+--R                       + 
+--R                                           2
+--R                         39732785404968960a  + 18598325083176960a
+--R                       + 
+--R                         4057816381784064
+--R              + 
+--R                    4         3         2
+--R                945a  + 13230a  + 69741a  + 164052a + 145296
+--R           /
+--R                     10          9           8            7             6
+--R                4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R              + 
+--R                          5              4              3              2
+--R                529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R              + 
+--R                2972712960a + 1019215872
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1
+--R      *
+--R         log
+--R                              12             11              10               9
+--R                      5767168a   + 242221056a   + 4656201728a   + 54169436160a
+--R                    + 
+--R                                   8                 7                 6
+--R                      424780759040a  + 2365347332096a  + 9590296543232a
+--R                    + 
+--R                                     5                  4                  3
+--R                      28526872887296a  + 61784614502400a  + 95021118259200a
+--R                    + 
+--R                                     2
+--R                      98500645748736a  + 61794378842112a + 17742509899776
+--R                 *
+--R                    ROOT
+--R                                  4           3            2
+--R                           194481a  + 2683044a  + 13929246a  + 32251284a
+--R                         + 
+--R                           28100601
+--R                      /
+--R                                    15              14               13
+--R                           67108864a   + 3355443200a   + 78181826560a
+--R                         + 
+--R                                         12                  11
+--R                           1126086737920a   + 11213220085760a
+--R                         + 
+--R                                          10                   9
+--R                           81769466429440a   + 451114507960320a
+--R                         + 
+--R                                            8                    7
+--R                           1917321719316480a  + 6329711072378880a
+--R                         + 
+--R                                             6                     5
+--R                           16231624291123200a  + 32068461429522432a
+--R                         + 
+--R                                             4                     3
+--R                           47937065488220160a  + 52483909799116800a
+--R                         + 
+--R                                             2
+--R                           39732785404968960a  + 18598325083176960a
+--R                         + 
+--R                           4057816381784064
+--R                + 
+--R                           7           6            5             4
+--R                  - 197568a  - 5173056a  - 58067136a  - 362238912a
+--R                + 
+--R                               3              2
+--R                  - 1356407424a  - 3048887808a  - 3809359872a - 2041012224
+--R             *
+--R                ROOT
+--R                                10          9           8            7
+--R                           8192a   + 286720a  + 4505600a  + 41861120a
+--R                         + 
+--R                                     6              5              4
+--R                           254648320a  + 1059774464a  + 3055779840a
+--R                         + 
+--R                                    3              2
+--R                         6028001280a  + 7785676800a  + 5945425920a + 2038431744
+--R                      *
+--R                         ROOT
+--R                                       4           3            2
+--R                                194481a  + 2683044a  + 13929246a  + 32251284a
+--R                              + 
+--R                                28100601
+--R                           /
+--R                                         15              14               13
+--R                                67108864a   + 3355443200a   + 78181826560a
+--R                              + 
+--R                                              12                  11
+--R                                1126086737920a   + 11213220085760a
+--R                              + 
+--R                                               10                   9
+--R                                81769466429440a   + 451114507960320a
+--R                              + 
+--R                                                 8                    7
+--R                                1917321719316480a  + 6329711072378880a
+--R                              + 
+--R                                                  6                     5
+--R                                16231624291123200a  + 32068461429522432a
+--R                              + 
+--R                                                  4                     3
+--R                                47937065488220160a  + 52483909799116800a
+--R                              + 
+--R                                                  2
+--R                                39732785404968960a  + 18598325083176960a
+--R                              + 
+--R                                4057816381784064
+--R                     + 
+--R                           4         3         2
+--R                       945a  + 13230a  + 69741a  + 164052a + 145296
+--R                  /
+--R                            10          9           8            7             6
+--R                       4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R                     + 
+--R                                 5              4              3              2
+--R                       529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R                     + 
+--R                       2972712960a + 1019215872
+--R            + 
+--R                     4          3           2                                 4
+--R              (64827a  + 907578a  + 4780647a  + 11228868a + 9923472)x - 64827a
+--R            + 
+--R                       3           2
+--R              - 907578a  - 4780647a  - 11228868a - 9923472
+--R     + 
+--R                                                        +--------------+
+--R             4       3        2                 +-----+ |   +-----+
+--R         (32a  + 448a  + 2336a  + 5376a + 4608)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R         ROOT
+--R                           10          9           8            7             6
+--R                    - 8192a   - 286720a  - 4505600a  - 41861120a  - 254648320a
+--R                  + 
+--R                                 5              4              3              2
+--R                    - 1059774464a  - 3055779840a  - 6028001280a  - 7785676800a
+--R                  + 
+--R                    - 5945425920a - 2038431744
+--R               *
+--R                  ROOT
+--R                              4           3            2
+--R                       194481a  + 2683044a  + 13929246a  + 32251284a + 28100601
+--R                    /
+--R                                  15              14               13
+--R                         67108864a   + 3355443200a   + 78181826560a
+--R                       + 
+--R                                       12                  11
+--R                         1126086737920a   + 11213220085760a
+--R                       + 
+--R                                        10                   9
+--R                         81769466429440a   + 451114507960320a
+--R                       + 
+--R                                          8                    7
+--R                         1917321719316480a  + 6329711072378880a
+--R                       + 
+--R                                           6                     5
+--R                         16231624291123200a  + 32068461429522432a
+--R                       + 
+--R                                           4                     3
+--R                         47937065488220160a  + 52483909799116800a
+--R                       + 
+--R                                           2
+--R                         39732785404968960a  + 18598325083176960a
+--R                       + 
+--R                         4057816381784064
+--R              + 
+--R                    4         3         2
+--R                945a  + 13230a  + 69741a  + 164052a + 145296
+--R           /
+--R                     10          9           8            7             6
+--R                4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R              + 
+--R                          5              4              3              2
+--R                529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R              + 
+--R                2972712960a + 1019215872
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1
+--R      *
+--R         log
+--R                              12             11              10               9
+--R                      5767168a   + 242221056a   + 4656201728a   + 54169436160a
+--R                    + 
+--R                                   8                 7                 6
+--R                      424780759040a  + 2365347332096a  + 9590296543232a
+--R                    + 
+--R                                     5                  4                  3
+--R                      28526872887296a  + 61784614502400a  + 95021118259200a
+--R                    + 
+--R                                     2
+--R                      98500645748736a  + 61794378842112a + 17742509899776
+--R                 *
+--R                    ROOT
+--R                                  4           3            2
+--R                           194481a  + 2683044a  + 13929246a  + 32251284a
+--R                         + 
+--R                           28100601
+--R                      /
+--R                                    15              14               13
+--R                           67108864a   + 3355443200a   + 78181826560a
+--R                         + 
+--R                                         12                  11
+--R                           1126086737920a   + 11213220085760a
+--R                         + 
+--R                                          10                   9
+--R                           81769466429440a   + 451114507960320a
+--R                         + 
+--R                                            8                    7
+--R                           1917321719316480a  + 6329711072378880a
+--R                         + 
+--R                                             6                     5
+--R                           16231624291123200a  + 32068461429522432a
+--R                         + 
+--R                                             4                     3
+--R                           47937065488220160a  + 52483909799116800a
+--R                         + 
+--R                                             2
+--R                           39732785404968960a  + 18598325083176960a
+--R                         + 
+--R                           4057816381784064
+--R                + 
+--R                         7           6            5             4              3
+--R                  197568a  + 5173056a  + 58067136a  + 362238912a  + 1356407424a
+--R                + 
+--R                             2
+--R                  3048887808a  + 3809359872a + 2041012224
+--R             *
+--R                ROOT
+--R                                  10          9           8            7
+--R                           - 8192a   - 286720a  - 4505600a  - 41861120a
+--R                         + 
+--R                                       6              5              4
+--R                           - 254648320a  - 1059774464a  - 3055779840a
+--R                         + 
+--R                                        3              2
+--R                           - 6028001280a  - 7785676800a  - 5945425920a
+--R                         + 
+--R                           - 2038431744
+--R                      *
+--R                         ROOT
+--R                                       4           3            2
+--R                                194481a  + 2683044a  + 13929246a  + 32251284a
+--R                              + 
+--R                                28100601
+--R                           /
+--R                                         15              14               13
+--R                                67108864a   + 3355443200a   + 78181826560a
+--R                              + 
+--R                                              12                  11
+--R                                1126086737920a   + 11213220085760a
+--R                              + 
+--R                                               10                   9
+--R                                81769466429440a   + 451114507960320a
+--R                              + 
+--R                                                 8                    7
+--R                                1917321719316480a  + 6329711072378880a
+--R                              + 
+--R                                                  6                     5
+--R                                16231624291123200a  + 32068461429522432a
+--R                              + 
+--R                                                  4                     3
+--R                                47937065488220160a  + 52483909799116800a
+--R                              + 
+--R                                                  2
+--R                                39732785404968960a  + 18598325083176960a
+--R                              + 
+--R                                4057816381784064
+--R                     + 
+--R                           4         3         2
+--R                       945a  + 13230a  + 69741a  + 164052a + 145296
+--R                  /
+--R                            10          9           8            7             6
+--R                       4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R                     + 
+--R                                 5              4              3              2
+--R                       529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R                     + 
+--R                       2972712960a + 1019215872
+--R            + 
+--R                     4          3           2                                 4
+--R              (64827a  + 907578a  + 4780647a  + 11228868a + 9923472)x - 64827a
+--R            + 
+--R                       3           2
+--R              - 907578a  - 4780647a  - 11228868a - 9923472
+--R     + 
+--R                                                          +--------------+
+--R               4       3        2                 +-----+ |   +-----+
+--R         (- 32a  - 448a  - 2336a  - 5376a - 4608)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R         ROOT
+--R                           10          9           8            7             6
+--R                    - 8192a   - 286720a  - 4505600a  - 41861120a  - 254648320a
+--R                  + 
+--R                                 5              4              3              2
+--R                    - 1059774464a  - 3055779840a  - 6028001280a  - 7785676800a
+--R                  + 
+--R                    - 5945425920a - 2038431744
+--R               *
+--R                  ROOT
+--R                              4           3            2
+--R                       194481a  + 2683044a  + 13929246a  + 32251284a + 28100601
+--R                    /
+--R                                  15              14               13
+--R                         67108864a   + 3355443200a   + 78181826560a
+--R                       + 
+--R                                       12                  11
+--R                         1126086737920a   + 11213220085760a
+--R                       + 
+--R                                        10                   9
+--R                         81769466429440a   + 451114507960320a
+--R                       + 
+--R                                          8                    7
+--R                         1917321719316480a  + 6329711072378880a
+--R                       + 
+--R                                           6                     5
+--R                         16231624291123200a  + 32068461429522432a
+--R                       + 
+--R                                           4                     3
+--R                         47937065488220160a  + 52483909799116800a
+--R                       + 
+--R                                           2
+--R                         39732785404968960a  + 18598325083176960a
+--R                       + 
+--R                         4057816381784064
+--R              + 
+--R                    4         3         2
+--R                945a  + 13230a  + 69741a  + 164052a + 145296
+--R           /
+--R                     10          9           8            7             6
+--R                4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R              + 
+--R                          5              4              3              2
+--R                529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R              + 
+--R                2972712960a + 1019215872
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1
+--R      *
+--R         log
+--R                                12             11              10
+--R                      - 5767168a   - 242221056a   - 4656201728a
+--R                    + 
+--R                                    9                8                 7
+--R                      - 54169436160a  - 424780759040a  - 2365347332096a
+--R                    + 
+--R                                      6                  5                  4
+--R                      - 9590296543232a  - 28526872887296a  - 61784614502400a
+--R                    + 
+--R                                       3                  2
+--R                      - 95021118259200a  - 98500645748736a  - 61794378842112a
+--R                    + 
+--R                      - 17742509899776
+--R                 *
+--R                    ROOT
+--R                                  4           3            2
+--R                           194481a  + 2683044a  + 13929246a  + 32251284a
+--R                         + 
+--R                           28100601
+--R                      /
+--R                                    15              14               13
+--R                           67108864a   + 3355443200a   + 78181826560a
+--R                         + 
+--R                                         12                  11
+--R                           1126086737920a   + 11213220085760a
+--R                         + 
+--R                                          10                   9
+--R                           81769466429440a   + 451114507960320a
+--R                         + 
+--R                                            8                    7
+--R                           1917321719316480a  + 6329711072378880a
+--R                         + 
+--R                                             6                     5
+--R                           16231624291123200a  + 32068461429522432a
+--R                         + 
+--R                                             4                     3
+--R                           47937065488220160a  + 52483909799116800a
+--R                         + 
+--R                                             2
+--R                           39732785404968960a  + 18598325083176960a
+--R                         + 
+--R                           4057816381784064
+--R                + 
+--R                           7           6            5             4
+--R                  - 197568a  - 5173056a  - 58067136a  - 362238912a
+--R                + 
+--R                               3              2
+--R                  - 1356407424a  - 3048887808a  - 3809359872a - 2041012224
+--R             *
+--R                ROOT
+--R                                  10          9           8            7
+--R                           - 8192a   - 286720a  - 4505600a  - 41861120a
+--R                         + 
+--R                                       6              5              4
+--R                           - 254648320a  - 1059774464a  - 3055779840a
+--R                         + 
+--R                                        3              2
+--R                           - 6028001280a  - 7785676800a  - 5945425920a
+--R                         + 
+--R                           - 2038431744
+--R                      *
+--R                         ROOT
+--R                                       4           3            2
+--R                                194481a  + 2683044a  + 13929246a  + 32251284a
+--R                              + 
+--R                                28100601
+--R                           /
+--R                                         15              14               13
+--R                                67108864a   + 3355443200a   + 78181826560a
+--R                              + 
+--R                                              12                  11
+--R                                1126086737920a   + 11213220085760a
+--R                              + 
+--R                                               10                   9
+--R                                81769466429440a   + 451114507960320a
+--R                              + 
+--R                                                 8                    7
+--R                                1917321719316480a  + 6329711072378880a
+--R                              + 
+--R                                                  6                     5
+--R                                16231624291123200a  + 32068461429522432a
+--R                              + 
+--R                                                  4                     3
+--R                                47937065488220160a  + 52483909799116800a
+--R                              + 
+--R                                                  2
+--R                                39732785404968960a  + 18598325083176960a
+--R                              + 
+--R                                4057816381784064
+--R                     + 
+--R                           4         3         2
+--R                       945a  + 13230a  + 69741a  + 164052a + 145296
+--R                  /
+--R                            10          9           8            7             6
+--R                       4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R                     + 
+--R                                 5              4              3              2
+--R                       529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R                     + 
+--R                       2972712960a + 1019215872
+--R            + 
+--R                     4          3           2                                 4
+--R              (64827a  + 907578a  + 4780647a  + 11228868a + 9923472)x - 64827a
+--R            + 
+--R                       3           2
+--R              - 907578a  - 4780647a  - 11228868a - 9923472
+--R     + 
+--R                                                        +--------------+
+--R             4       3        2                 +-----+ |   +-----+
+--R         (32a  + 448a  + 2336a  + 5376a + 4608)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R         ROOT
+--R                         10          9           8            7             6
+--R                    8192a   + 286720a  + 4505600a  + 41861120a  + 254648320a
+--R                  + 
+--R                               5              4              3              2
+--R                    1059774464a  + 3055779840a  + 6028001280a  + 7785676800a
+--R                  + 
+--R                    5945425920a + 2038431744
+--R               *
+--R                  ROOT
+--R                              4           3            2
+--R                       194481a  + 2683044a  + 13929246a  + 32251284a + 28100601
+--R                    /
+--R                                  15              14               13
+--R                         67108864a   + 3355443200a   + 78181826560a
+--R                       + 
+--R                                       12                  11
+--R                         1126086737920a   + 11213220085760a
+--R                       + 
+--R                                        10                   9
+--R                         81769466429440a   + 451114507960320a
+--R                       + 
+--R                                          8                    7
+--R                         1917321719316480a  + 6329711072378880a
+--R                       + 
+--R                                           6                     5
+--R                         16231624291123200a  + 32068461429522432a
+--R                       + 
+--R                                           4                     3
+--R                         47937065488220160a  + 52483909799116800a
+--R                       + 
+--R                                           2
+--R                         39732785404968960a  + 18598325083176960a
+--R                       + 
+--R                         4057816381784064
+--R              + 
+--R                    4         3         2
+--R                945a  + 13230a  + 69741a  + 164052a + 145296
+--R           /
+--R                     10          9           8            7             6
+--R                4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R              + 
+--R                          5              4              3              2
+--R                529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R              + 
+--R                2972712960a + 1019215872
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1
+--R      *
+--R         log
+--R                                12             11              10
+--R                      - 5767168a   - 242221056a   - 4656201728a
+--R                    + 
+--R                                    9                8                 7
+--R                      - 54169436160a  - 424780759040a  - 2365347332096a
+--R                    + 
+--R                                      6                  5                  4
+--R                      - 9590296543232a  - 28526872887296a  - 61784614502400a
+--R                    + 
+--R                                       3                  2
+--R                      - 95021118259200a  - 98500645748736a  - 61794378842112a
+--R                    + 
+--R                      - 17742509899776
+--R                 *
+--R                    ROOT
+--R                                  4           3            2
+--R                           194481a  + 2683044a  + 13929246a  + 32251284a
+--R                         + 
+--R                           28100601
+--R                      /
+--R                                    15              14               13
+--R                           67108864a   + 3355443200a   + 78181826560a
+--R                         + 
+--R                                         12                  11
+--R                           1126086737920a   + 11213220085760a
+--R                         + 
+--R                                          10                   9
+--R                           81769466429440a   + 451114507960320a
+--R                         + 
+--R                                            8                    7
+--R                           1917321719316480a  + 6329711072378880a
+--R                         + 
+--R                                             6                     5
+--R                           16231624291123200a  + 32068461429522432a
+--R                         + 
+--R                                             4                     3
+--R                           47937065488220160a  + 52483909799116800a
+--R                         + 
+--R                                             2
+--R                           39732785404968960a  + 18598325083176960a
+--R                         + 
+--R                           4057816381784064
+--R                + 
+--R                         7           6            5             4              3
+--R                  197568a  + 5173056a  + 58067136a  + 362238912a  + 1356407424a
+--R                + 
+--R                             2
+--R                  3048887808a  + 3809359872a + 2041012224
+--R             *
+--R                ROOT
+--R                                10          9           8            7
+--R                           8192a   + 286720a  + 4505600a  + 41861120a
+--R                         + 
+--R                                     6              5              4
+--R                           254648320a  + 1059774464a  + 3055779840a
+--R                         + 
+--R                                    3              2
+--R                         6028001280a  + 7785676800a  + 5945425920a + 2038431744
+--R                      *
+--R                         ROOT
+--R                                       4           3            2
+--R                                194481a  + 2683044a  + 13929246a  + 32251284a
+--R                              + 
+--R                                28100601
+--R                           /
+--R                                         15              14               13
+--R                                67108864a   + 3355443200a   + 78181826560a
+--R                              + 
+--R                                              12                  11
+--R                                1126086737920a   + 11213220085760a
+--R                              + 
+--R                                               10                   9
+--R                                81769466429440a   + 451114507960320a
+--R                              + 
+--R                                                 8                    7
+--R                                1917321719316480a  + 6329711072378880a
+--R                              + 
+--R                                                  6                     5
+--R                                16231624291123200a  + 32068461429522432a
+--R                              + 
+--R                                                  4                     3
+--R                                47937065488220160a  + 52483909799116800a
+--R                              + 
+--R                                                  2
+--R                                39732785404968960a  + 18598325083176960a
+--R                              + 
+--R                                4057816381784064
+--R                     + 
+--R                           4         3         2
+--R                       945a  + 13230a  + 69741a  + 164052a + 145296
+--R                  /
+--R                            10          9           8            7             6
+--R                       4096a   + 143360a  + 2252800a  + 20930560a  + 127324160a
+--R                     + 
+--R                                 5              4              3              2
+--R                       529887232a  + 1527889920a  + 3014000640a  + 3892838400a
+--R                     + 
+--R                       2972712960a + 1019215872
+--R            + 
+--R                     4          3           2                                 4
+--R              (64827a  + 907578a  + 4780647a  + 11228868a + 9923472)x - 64827a
+--R            + 
+--R                       3           2
+--R              - 907578a  - 4780647a  - 11228868a - 9923472
+--R     + 
+--R                                                  +------------+
+--R                     +-----+      2               | +-----+
+--R         ((12a + 42)\|a + 4  + 21a  + 141a + 240)\|\|a + 4  + 1
+--R      *
+--R                    x - 1
+--R         atan(-----------------)
+--R               +--------------+
+--R               |   +-----+
+--R              \|- \|a + 4  + 1
+--R     + 
+--R                                                  +--------------+
+--R                     +-----+      2               |   +-----+
+--R         ((12a + 42)\|a + 4  - 21a  - 141a - 240)\|- \|a + 4  + 1
+--R      *
+--R                   x - 1
+--R         atan(---------------)
+--R               +------------+
+--R               | +-----+
+--R              \|\|a + 4  + 1
+--R  /
+--R                                                       +--------------+
+--R           4       3        2                  +-----+ |   +-----+
+--R       (64a  + 896a  + 4672a  + 10752a + 9216)\|a + 4 \|- \|a + 4  + 1
+--R    *
+--R        +------------+
+--R        | +-----+
+--R       \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 269
+
+)clear all
+
+--S 270 of 534
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)^4
+--R 
+--R
+--R   (1)
+--R      17      16       15       14                 13                12
+--R     x   - 16x   + 128x   - 672x   + (- 4a + 2560)x   + (48a - 7424)x
+--R   + 
+--R                      11                   10      2                  9
+--R     (- 288a + 16768)x   + (1120a - 29696)x   + (6a  - 3072a + 40960)x
+--R   + 
+--R           2                  8        2                  7
+--R     (- 48a  + 6144a - 43008)x  + (192a  - 8960a + 32768)x
+--R   + 
+--R            2                  6        3       2                 5
+--R     (- 480a  + 9216a - 16384)x  + (- 4a  + 768a  - 6144a + 4096)x
+--R   + 
+--R         3       2          4         3       2  3      3 2    4
+--R     (16a  - 768a  + 2048a)x  + (- 32a  + 384a )x  + 32a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 270
+
+--S 271 of 534
+r0:=1/2*a^4*x^2+32/3*a^3*x^3+8*(12-a)*a^2*x^4+16/5*a*(128-48*a+a^2)*x^5+_
+   2/3*(1024-1536*a+192*a^2-a^3)*x^6-32/7*(512-288*a+15*a^2)*x^7+_
+   8*(128-3*a)*(4-a)*x^8-16/3*(896-128*a+a^2)*x^9+1/5*(20480-1536*a+_
+   3*a^2)*x^10-32/11*(928-35*a)*x^11+8/3*(524-9*a)*x^12-16/13*_
+   (464-3*a)*x^13+2/7*(640-a)*x^14-224/5*x^15+8*x^16-16/17*x^17+1/18*x^18
+--R 
+--R
+--R   (2)
+--R      1  18   16  17     16   224  15      2     1280  14    48     7424  13
+--R     -- x   - -- x   + 8x   - --- x   + (- - a + ----)x   + (-- a - ----)x
+--R     18       17               5           7       7         13      13
+--R   + 
+--R              4192  12    1120     29696  11    3  2   1536           10
+--R     (- 24a + ----)x   + (---- a - -----)x   + (- a  - ---- a + 4096)x
+--R                3          11        11         5        5
+--R   + 
+--R        16  2   2048     14336  9       2                 8
+--R     (- -- a  + ---- a - -----)x  + (24a  - 1120a + 4096)x
+--R         3        3        3
+--R   + 
+--R        480  2   9216     16384  7      2  3       2           2048  6
+--R     (- --- a  + ---- a - -----)x  + (- - a  + 128a  - 1024a + ----)x
+--R         7         7        7           3                        3
+--R   + 
+--R      16  3   768  2   2048    5        3      2  4   32  3 3   1  4 2
+--R     (-- a  - --- a  + ---- a)x  + (- 8a  + 96a )x  + -- a x  + - a x
+--R       5       5         5                             3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 271
+
+--S 272 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  18   16  17     16   224  15      2     1280  14    48     7424  13
+--R     -- x   - -- x   + 8x   - --- x   + (- - a + ----)x   + (-- a - ----)x
+--R     18       17               5           7       7         13      13
+--R   + 
+--R              4192  12    1120     29696  11    3  2   1536           10
+--R     (- 24a + ----)x   + (---- a - -----)x   + (- a  - ---- a + 4096)x
+--R                3          11        11         5        5
+--R   + 
+--R        16  2   2048     14336  9       2                 8
+--R     (- -- a  + ---- a - -----)x  + (24a  - 1120a + 4096)x
+--R         3        3        3
+--R   + 
+--R        480  2   9216     16384  7      2  3       2           2048  6
+--R     (- --- a  + ---- a - -----)x  + (- - a  + 128a  - 1024a + ----)x
+--R         7         7        7           3                        3
+--R   + 
+--R      16  3   768  2   2048    5        3      2  4   32  3 3   1  4 2
+--R     (-- a  - --- a  + ---- a)x  + (- 8a  + 96a )x  + -- a x  + - a x
+--R       5       5         5                             3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 272
+
+--S 273 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 273
+
+--S 274 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 274
+
+)clear all
+
+--S 275 of 534
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)^3
+--R 
+--R
+--R   (1)
+--R        13      12      11       10              9                  8
+--R     - x   + 12x   - 72x   + 280x   + (3a - 768)x  + (- 24a + 1536)x
+--R   + 
+--R                  7                   6        2                5
+--R     (96a - 2240)x  + (- 240a + 2304)x  + (- 3a  + 384a - 1536)x
+--R   + 
+--R         2               4         2         3      2 2    3
+--R     (12a  - 384a + 512)x  + (- 24a  + 192a)x  + 24a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 275
+
+--S 276 of 534
+r0:=1/2*a^3*x^2+8*a^2*x^3+6*(8-a)*a*x^4+4/5*(128-96*a+3*a^2)*x^5-_
+   1/2*(512-128*a+a^2)*x^6+48/7*(48-5*a)*x^7-4*(70-3*a)*x^8+8/3*(64-a)*x^9-_
+   3/10*(256-a)*x^10+280/11*x^11-6*x^12+12/13*x^13-1/14*x^14
+--R 
+--R
+--R   (2)
+--R        1  14   12  13     12   280  11     3     384  10      8     512  9
+--R     - -- x   + -- x   - 6x   + --- x   + (-- a - ---)x   + (- - a + ---)x
+--R       14       13               11        10      5           3      3
+--R   + 
+--R                 8      240     2304  7      1  2              6
+--R     (12a - 280)x  + (- --- a + ----)x  + (- - a  + 64a - 256)x
+--R                         7        7          2
+--R   + 
+--R      12  2   384     512  5        2        4     2 3   1  3 2
+--R     (-- a  - --- a + ---)x  + (- 6a  + 48a)x  + 8a x  + - a x
+--R       5       5       5                                 2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 276
+
+--S 277 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        1  14   12  13     12   280  11     3     384  10      8     512  9
+--R     - -- x   + -- x   - 6x   + --- x   + (-- a - ---)x   + (- - a + ---)x
+--R       14       13               11        10      5           3      3
+--R   + 
+--R                 8      240     2304  7      1  2              6
+--R     (12a - 280)x  + (- --- a + ----)x  + (- - a  + 64a - 256)x
+--R                         7        7          2
+--R   + 
+--R      12  2   384     512  5        2        4     2 3   1  3 2
+--R     (-- a  - --- a + ---)x  + (- 6a  + 48a)x  + 8a x  + - a x
+--R       5       5       5                                 2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 277
+
+--S 278 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 278
+
+--S 279 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 279
+
+)clear all
+
+--S 280 of 534
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R      9     8      7      6                5              4                3
+--R     x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R   + 
+--R          2    2
+--R     16a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 280
+
+--S 281 of 534
+r0:=1/2*a^2*x^2+16/3*a*x^3+4*(4-a)*x^4-8/5*(16-a)*x^5+1/3*(64-a)*x^6-_
+   80/7*x^7+4*x^8-8/9*x^9+1/10*x^10
+--R 
+--R
+--R   (2)
+--R      1  10   8  9     8   80  7      1     64  6    8     128  5
+--R     -- x   - - x  + 4x  - -- x  + (- - a + --)x  + (- a - ---)x
+--R     10       9             7         3      3       5      5
+--R   + 
+--R                 4   16    3   1  2 2
+--R     (- 4a + 16)x  + -- a x  + - a x
+--R                      3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 281
+
+--S 282 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  10   8  9     8   80  7      1     64  6    8     128  5
+--R     -- x   - - x  + 4x  - -- x  + (- - a + --)x  + (- a - ---)x
+--R     10       9             7         3      3       5      5
+--R   + 
+--R                 4   16    3   1  2 2
+--R     (- 4a + 16)x  + -- a x  + - a x
+--R                      3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 282
+
+--S 283 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 283
+
+--S 284 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 284
+
+)clear all
+
+--S 285 of 534
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)
+--R 
+--R
+--R           5     4     3     2
+--R   (1)  - x  + 4x  - 8x  + 8x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 285
+
+--S 286 of 534
+r0:=1/2*a*x^2+8/3*x^3-2*x^4+4/5*x^5-1/6*x^6
+--R 
+--R
+--R          1  6   4  5     4   8  3   1    2
+--R   (2)  - - x  + - x  - 2x  + - x  + - a x
+--R          6      5            3      2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 286
+
+--S 287 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R          1  6   4  5     4   8  3   1    2
+--R   (3)  - - x  + - x  - 2x  + - x  + - a x
+--R          6      5            3      2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 287
+
+--S 288 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 288
+
+--S 289 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 289
+
+)clear all
+
+--S 290 of 534
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)
+--R 
+--R
+--R                     x
+--R   (1)  - -----------------------
+--R           4     3     2
+--R          x  - 4x  + 8x  - 8x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 290
+
+--S 291 of 534
+r0:=1/2*atanh((1+(-1+x)^2)/sqrt(4+a))/sqrt(4+a)-1/2*atan((-1+x)/_
+   sqrt(1-sqrt(4+a)))/(sqrt(4+a)*sqrt(1-sqrt(4+a)))+1/2*atan((-1+x)/_
+   sqrt(1+sqrt(4+a)))/(sqrt(4+a)*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R          +------------+
+--R          | +-----+                x - 1
+--R       - \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R        +--------------+
+--R        |   +-----+               x - 1
+--R       \|- \|a + 4  + 1 atan(---------------)
+--R                              +------------+
+--R                              | +-----+
+--R                             \|\|a + 4  + 1
+--R     + 
+--R              2           +--------------+ +------------+
+--R             x  - 2x + 2  |   +-----+      | +-----+
+--R       atanh(-----------)\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                +-----+
+--R               \|a + 4
+--R  /
+--R               +--------------+ +------------+
+--R       +-----+ |   +-----+      | +-----+
+--R     2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +------------------------------------------------------------------+
+--R            |                2                                            2
+--R            |(- 6a - 18)%%BL1  + (- 4a - 12)%%BL0 %%BL1 + (- 6a - 18)%%BL0  + 1
+--R            |------------------------------------------------------------------
+--R           \|                              2a + 6
+--R         + 
+--R           - %%BL1 - %%BL0
+--R      *
+--R         log
+--R                          4       3        2                           3       2
+--R                      (64a  + 864a  + 4320a  + 9472a + 7680)%%BL0 - 24a  - 232a
+--R                    + 
+--R                      - 736a - 768
+--R                 *
+--R                    %%BL1
+--R                + 
+--R                        3       2                        3      2
+--R                  (- 24a  - 232a  - 736a - 768)%%BL0 + 4a  + 40a  + 132a + 144
+--R             *
+--R                ROOT
+--R                                       2
+--R                       (- 6a - 18)%%BL1  + (- 4a - 12)%%BL0 %%BL1
+--R                     + 
+--R                                       2
+--R                       (- 6a - 18)%%BL0  + 1
+--R                  /
+--R                     2a + 6
+--R            + 
+--R                      4       3        2                           3       2
+--R                  (64a  + 864a  + 4320a  + 9472a + 7680)%%BL0 - 24a  - 232a
+--R                + 
+--R                  - 736a - 768
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                      4       3        2                     2     3      2
+--R                  (64a  + 864a  + 4320a  + 9472a + 7680)%%BL0  - 4a  - 40a
+--R                + 
+--R                  - 132a - 144
+--R             *
+--R                %%BL1
+--R            + 
+--R                    3       2                   2
+--R              (- 24a  - 232a  - 736a - 768)%%BL0
+--R            + 
+--R                   3      2                         2                  2
+--R              (- 4a  - 40a  - 132a - 144)%%BL0 + (4a  + 21a + 28)x - 3a  - 14a
+--R            + 
+--R              - 16
+--R     + 
+--R           -
+--R              ROOT
+--R                                     2
+--R                     (- 6a - 18)%%BL1  + (- 4a - 12)%%BL0 %%BL1
+--R                   + 
+--R                                     2
+--R                     (- 6a - 18)%%BL0  + 1
+--R                /
+--R                   2a + 6
+--R         + 
+--R           - %%BL1 - %%BL0
+--R      *
+--R         log
+--R                            4       3        2                           3
+--R                      (- 64a  - 864a  - 4320a  - 9472a - 7680)%%BL0 + 24a
+--R                    + 
+--R                          2
+--R                      232a  + 736a + 768
+--R                 *
+--R                    %%BL1
+--R                + 
+--R                      3       2                        3      2
+--R                  (24a  + 232a  + 736a + 768)%%BL0 - 4a  - 40a  - 132a - 144
+--R             *
+--R                ROOT
+--R                                       2
+--R                       (- 6a - 18)%%BL1  + (- 4a - 12)%%BL0 %%BL1
+--R                     + 
+--R                                       2
+--R                       (- 6a - 18)%%BL0  + 1
+--R                  /
+--R                     2a + 6
+--R            + 
+--R                      4       3        2                           3       2
+--R                  (64a  + 864a  + 4320a  + 9472a + 7680)%%BL0 - 24a  - 232a
+--R                + 
+--R                  - 736a - 768
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                      4       3        2                     2     3      2
+--R                  (64a  + 864a  + 4320a  + 9472a + 7680)%%BL0  - 4a  - 40a
+--R                + 
+--R                  - 132a - 144
+--R             *
+--R                %%BL1
+--R            + 
+--R                    3       2                   2
+--R              (- 24a  - 232a  - 736a - 768)%%BL0
+--R            + 
+--R                   3      2                         2                  2
+--R              (- 4a  - 40a  - 132a - 144)%%BL0 + (4a  + 21a + 28)x - 3a  - 14a
+--R            + 
+--R              - 16
+--R     + 
+--R         2%%BL1
+--R      *
+--R         log
+--R                         4        3        2                             3
+--R                  (- 128a  - 1728a  - 8640a  - 18944a - 15360)%%BL0 + 48a
+--R                + 
+--R                      2
+--R                  464a  + 1472a + 1536
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                         4        3        2                       2     3
+--R                  (- 128a  - 1728a  - 8640a  - 18944a - 15360)%%BL0  + 8a
+--R                + 
+--R                     2
+--R                  80a  + 264a + 288
+--R             *
+--R                %%BL1
+--R            + 
+--R                     4        3        2                       3
+--R              (- 128a  - 1728a  - 8640a  - 18944a - 15360)%%BL0
+--R            + 
+--R                  3       2                         2                  2
+--R              (16a  + 168a  + 576a + 640)%%BL0 + (4a  + 21a + 28)x - 9a  - 54a
+--R            + 
+--R              - 80
+--R     + 
+--R         2%%BL0
+--R      *
+--R         log
+--R                   4        3        2                       3
+--R              (128a  + 1728a  + 8640a  + 18944a + 15360)%%BL0
+--R            + 
+--R                  3       2                     2
+--R              (48a  + 464a  + 1472a + 1536)%%BL0
+--R            + 
+--R                   3      2                         2                 2
+--R              (- 8a  - 88a  - 312a - 352)%%BL0 + (4a  + 21a + 28)x - a  - 2a
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 292
+
+--S 293 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +--------------+ +------------+
+--R              +-----+ |   +-----+      | +-----+
+--R             \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R          *
+--R            +------------------------------------------------------------------+
+--R            |                2                                            2
+--R            |(- 6a - 18)%%BL1  + (- 4a - 12)%%BL0 %%BL1 + (- 6a - 18)%%BL0  + 1
+--R            |------------------------------------------------------------------
+--R           \|                              2a + 6
+--R         + 
+--R                      +--------------+ +------------+
+--R              +-----+ |   +-----+      | +-----+
+--R           - \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BL1
+--R         + 
+--R                           +--------------+ +------------+
+--R              +-----+      |   +-----+      | +-----+
+--R           - \|a + 4 %%BL0\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R      *
+--R         log
+--R                          4       3        2                           3       2
+--R                      (64a  + 864a  + 4320a  + 9472a + 7680)%%BL0 - 24a  - 232a
+--R                    + 
+--R                      - 736a - 768
+--R                 *
+--R                    %%BL1
+--R                + 
+--R                        3       2                        3      2
+--R                  (- 24a  - 232a  - 736a - 768)%%BL0 + 4a  + 40a  + 132a + 144
+--R             *
+--R                ROOT
+--R                                       2
+--R                       (- 6a - 18)%%BL1  + (- 4a - 12)%%BL0 %%BL1
+--R                     + 
+--R                                       2
+--R                       (- 6a - 18)%%BL0  + 1
+--R                  /
+--R                     2a + 6
+--R            + 
+--R                      4       3        2                           3       2
+--R                  (64a  + 864a  + 4320a  + 9472a + 7680)%%BL0 - 24a  - 232a
+--R                + 
+--R                  - 736a - 768
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                      4       3        2                     2     3      2
+--R                  (64a  + 864a  + 4320a  + 9472a + 7680)%%BL0  - 4a  - 40a
+--R                + 
+--R                  - 132a - 144
+--R             *
+--R                %%BL1
+--R            + 
+--R                    3       2                   2
+--R              (- 24a  - 232a  - 736a - 768)%%BL0
+--R            + 
+--R                   3      2                         2                  2
+--R              (- 4a  - 40a  - 132a - 144)%%BL0 + (4a  + 21a + 28)x - 3a  - 14a
+--R            + 
+--R              - 16
+--R     + 
+--R           -
+--R                         +--------------+ +------------+
+--R                 +-----+ |   +-----+      | +-----+
+--R                \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R             *
+--R                ROOT
+--R                                       2
+--R                       (- 6a - 18)%%BL1  + (- 4a - 12)%%BL0 %%BL1
+--R                     + 
+--R                                       2
+--R                       (- 6a - 18)%%BL0  + 1
+--R                  /
+--R                     2a + 6
+--R         + 
+--R                      +--------------+ +------------+
+--R              +-----+ |   +-----+      | +-----+
+--R           - \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BL1
+--R         + 
+--R                           +--------------+ +------------+
+--R              +-----+      |   +-----+      | +-----+
+--R           - \|a + 4 %%BL0\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R      *
+--R         log
+--R                            4       3        2                           3
+--R                      (- 64a  - 864a  - 4320a  - 9472a - 7680)%%BL0 + 24a
+--R                    + 
+--R                          2
+--R                      232a  + 736a + 768
+--R                 *
+--R                    %%BL1
+--R                + 
+--R                      3       2                        3      2
+--R                  (24a  + 232a  + 736a + 768)%%BL0 - 4a  - 40a  - 132a - 144
+--R             *
+--R                ROOT
+--R                                       2
+--R                       (- 6a - 18)%%BL1  + (- 4a - 12)%%BL0 %%BL1
+--R                     + 
+--R                                       2
+--R                       (- 6a - 18)%%BL0  + 1
+--R                  /
+--R                     2a + 6
+--R            + 
+--R                      4       3        2                           3       2
+--R                  (64a  + 864a  + 4320a  + 9472a + 7680)%%BL0 - 24a  - 232a
+--R                + 
+--R                  - 736a - 768
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                      4       3        2                     2     3      2
+--R                  (64a  + 864a  + 4320a  + 9472a + 7680)%%BL0  - 4a  - 40a
+--R                + 
+--R                  - 132a - 144
+--R             *
+--R                %%BL1
+--R            + 
+--R                    3       2                   2
+--R              (- 24a  - 232a  - 736a - 768)%%BL0
+--R            + 
+--R                   3      2                         2                  2
+--R              (- 4a  - 40a  - 132a - 144)%%BL0 + (4a  + 21a + 28)x - 3a  - 14a
+--R            + 
+--R              - 16
+--R     + 
+--R                   +--------------+ +------------+
+--R           +-----+ |   +-----+      | +-----+
+--R         2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BL1
+--R      *
+--R         log
+--R                         4        3        2                             3
+--R                  (- 128a  - 1728a  - 8640a  - 18944a - 15360)%%BL0 + 48a
+--R                + 
+--R                      2
+--R                  464a  + 1472a + 1536
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                         4        3        2                       2     3
+--R                  (- 128a  - 1728a  - 8640a  - 18944a - 15360)%%BL0  + 8a
+--R                + 
+--R                     2
+--R                  80a  + 264a + 288
+--R             *
+--R                %%BL1
+--R            + 
+--R                     4        3        2                       3
+--R              (- 128a  - 1728a  - 8640a  - 18944a - 15360)%%BL0
+--R            + 
+--R                  3       2                         2                  2
+--R              (16a  + 168a  + 576a + 640)%%BL0 + (4a  + 21a + 28)x - 9a  - 54a
+--R            + 
+--R              - 80
+--R     + 
+--R        +------------+
+--R        | +-----+                x - 1
+--R       \|\|a + 4  + 1 atan(-----------------)
+--R                            +--------------+
+--R                            |   +-----+
+--R                           \|- \|a + 4  + 1
+--R     + 
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R       - \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R               +-----+
+--R             2\|a + 4 %%BL0
+--R          *
+--R             log
+--R                       4        3        2                       3
+--R                  (128a  + 1728a  + 8640a  + 18944a + 15360)%%BL0
+--R                + 
+--R                      3       2                     2
+--R                  (48a  + 464a  + 1472a + 1536)%%BL0
+--R                + 
+--R                     3      2                         2                 2
+--R                (- 8a  - 88a  - 312a - 352)%%BL0 + (4a  + 21a + 28)x - a  - 2a
+--R         + 
+--R                    2
+--R                   x  - 2x + 2
+--R           - atanh(-----------)
+--R                      +-----+
+--R                     \|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R               +--------------+ +------------+
+--R       +-----+ |   +-----+      | +-----+
+--R     2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 534
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R     x
+--R  /
+--R        8     7      6      5                4              3                2
+--R       x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R     + 
+--R                2
+--R       16a x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 295
+
+--S 296 of 534
+r0:=1/4*(1+(-1+x)^2)/((4+a)*(3+a-2*(-1+x)^2-(-1+x)^4))+1/4*(5+a+(-1+x)^2)*_
+   (-1+x)/((12+7*a+a^2)*(3+a-2*(-1+x)^2-(-1+x)^4))+1/4*atanh((1+(-1+x)^2)/_
+   sqrt(4+a))/(4+a)^(3/2)-1/8*atan((-1+x)/sqrt(1-sqrt(4+a)))*(10+3*a+_
+   sqrt(4+a))/((3+a)*(4+a)^(3/2)*sqrt(1-sqrt(4+a)))+1/8*atan((-1+x)/_
+   sqrt(1+sqrt(4+a)))*(10+3*a-sqrt(4+a))/((3+a)*(4+a)^(3/2)*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R               4     3     2           +-----+               4              3
+--R           (- x  + 4x  - 8x  + 8x + a)\|a + 4  + (- 3a - 10)x  + (12a + 40)x
+--R         + 
+--R                        2                   2
+--R           (- 24a - 80)x  + (24a + 80)x + 3a  + 10a
+--R      *
+--R          +------------+
+--R          | +-----+                x - 1
+--R         \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R               4     3     2           +-----+             4                3
+--R           (- x  + 4x  - 8x  + 8x + a)\|a + 4  + (3a + 10)x  + (- 12a - 40)x
+--R         + 
+--R                      2                     2
+--R           (24a + 80)x  + (- 24a - 80)x - 3a  - 10a
+--R      *
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R         \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R                        4               3              2                     2
+--R               (2a + 6)x  + (- 8a - 24)x  + (16a + 48)x  + (- 16a - 48)x - 2a
+--R             + 
+--R               - 6a
+--R          *
+--R                    2
+--R                   x  - 2x + 2
+--R             atanh(-----------)
+--R                      +-----+
+--R                     \|a + 4
+--R         + 
+--R                3       2                   +-----+
+--R           (- 2x  - 2a x  + (2a - 4)x - 2a)\|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R            2             4         2               3       2               2
+--R         (8a  + 56a + 96)x  + (- 32a  - 224a - 384)x  + (64a  + 448a + 768)x
+--R       + 
+--R               2                    3      2
+--R         (- 64a  - 448a - 768)x - 8a  - 56a  - 96a
+--R    *
+--R                +--------------+ +------------+
+--R        +-----+ |   +-----+      | +-----+
+--R       \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2             4        2             3       2               2
+--R               (2a  + 14a + 24)x  + (- 8a  - 56a - 96)x  + (16a  + 112a + 192)x
+--R             + 
+--R                     2                    3      2
+--R               (- 16a  - 112a - 192)x - 2a  - 14a  - 24a
+--R          *
+--R             ROOT
+--R                          5        4         3         2                       2
+--R                    (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)%%BM1
+--R                  + 
+--R                            5        4        3         2
+--R                      (- 64a  - 1088a  - 7360a  - 24768a  - 41472a - 27648)%%BM0
+--R                   *
+--R                      %%BM1
+--R                  + 
+--R                          5        4         3         2                       2
+--R                    (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)%%BM0
+--R                  + 
+--R                      2
+--R                    4a  + 35a + 73
+--R               /
+--R                     5       4        3         2
+--R                  32a  + 544a  + 3680a  + 12384a  + 20736a + 13824
+--R         + 
+--R                    2             4      2             3
+--R               (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x
+--R             + 
+--R                   2               2       2                    3      2
+--R             (- 16a  - 112a - 192)x  + (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R          *
+--R             %%BM1
+--R         + 
+--R                    2             4      2             3
+--R               (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x
+--R             + 
+--R                   2               2       2                    3      2
+--R             (- 16a  - 112a - 192)x  + (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R          *
+--R             %%BM0
+--R      *
+--R         log
+--R                                12           11            10             9
+--R                          49152a   + 1974272a   + 36098048a   + 396918784a
+--R                        + 
+--R                                     8               7               6
+--R                          2919686144a  + 15113232384a  + 56334225408a
+--R                        + 
+--R                                       5                4                3
+--R                          151932321792a  + 293078695936a  + 392008564736a
+--R                        + 
+--R                                       2
+--R                          341824241664a  + 171568005120a + 36238786560
+--R                     *
+--R                        %%BM0
+--R                    + 
+--R                              10          9           8            7
+--R                      - 15104a   - 493312a  - 7210496a  - 62078464a
+--R                    + 
+--R                                  6              5              4              3
+--R                      - 348407552a  - 1330879232a  - 3500742656a  - 6253281280a
+--R                    + 
+--R                                   2
+--R                      - 7247462400a  - 4910284800a - 1472200704
+--R                 *
+--R                    %%BM1
+--R                + 
+--R                              10          9           8            7
+--R                      - 15104a   - 493312a  - 7210496a  - 62078464a
+--R                    + 
+--R                                  6              5              4              3
+--R                      - 348407552a  - 1330879232a  - 3500742656a  - 6253281280a
+--R                    + 
+--R                                   2
+--R                      - 7247462400a  - 4910284800a - 1472200704
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                      9         8          7           6            5
+--R                  768a  + 23000a  + 307368a  + 2407608a  + 12189944a
+--R                + 
+--R                           4            3             2
+--R                  41394064a  + 94309952a  + 139040512a  + 120357888a + 46596096
+--R             *
+--R                ROOT
+--R                               5        4         3         2
+--R                         (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)
+--R                      *
+--R                              2
+--R                         %%BM1
+--R                     + 
+--R                               5        4        3         2
+--R                         (- 64a  - 1088a  - 7360a  - 24768a  - 41472a - 27648)
+--R                      *
+--R                         %%BM0 %%BM1
+--R                     + 
+--R                               5        4         3         2
+--R                         (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)
+--R                      *
+--R                              2
+--R                         %%BM0
+--R                     + 
+--R                         2
+--R                       4a  + 35a + 73
+--R                  /
+--R                        5       4        3         2
+--R                     32a  + 544a  + 3680a  + 12384a  + 20736a + 13824
+--R            + 
+--R                            12           11            10             9
+--R                      49152a   + 1974272a   + 36098048a   + 396918784a
+--R                    + 
+--R                                 8               7               6
+--R                      2919686144a  + 15113232384a  + 56334225408a
+--R                    + 
+--R                                   5                4                3
+--R                      151932321792a  + 293078695936a  + 392008564736a
+--R                    + 
+--R                                   2
+--R                      341824241664a  + 171568005120a + 36238786560
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                          10          9           8            7             6
+--R                  - 15104a   - 493312a  - 7210496a  - 62078464a  - 348407552a
+--R                + 
+--R                               5              4              3              2
+--R                  - 1330879232a  - 3500742656a  - 6253281280a  - 7247462400a
+--R                + 
+--R                  - 4910284800a - 1472200704
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                            12           11            10             9
+--R                      49152a   + 1974272a   + 36098048a   + 396918784a
+--R                    + 
+--R                                 8               7               6
+--R                      2919686144a  + 15113232384a  + 56334225408a
+--R                    + 
+--R                                   5                4                3
+--R                      151932321792a  + 293078695936a  + 392008564736a
+--R                    + 
+--R                                   2
+--R                      341824241664a  + 171568005120a + 36238786560
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                        9         8          7           6            5
+--R                  - 768a  - 23000a  - 307368a  - 2407608a  - 12189944a
+--R                + 
+--R                           4            3             2
+--R                - 41394064a  - 94309952a  - 139040512a  - 120357888a - 46596096
+--R             *
+--R                %%BM1
+--R            + 
+--R                          10          9           8            7             6
+--R                  - 15104a   - 493312a  - 7210496a  - 62078464a  - 348407552a
+--R                + 
+--R                               5              4              3              2
+--R                  - 1330879232a  - 3500742656a  - 6253281280a  - 7247462400a
+--R                + 
+--R                  - 4910284800a - 1472200704
+--R             *
+--R                     2
+--R                %%BM0
+--R            + 
+--R                        9         8          7           6            5
+--R                  - 768a  - 23000a  - 307368a  - 2407608a  - 12189944a
+--R                + 
+--R                           4            3             2
+--R                - 41394064a  - 94309952a  - 139040512a  - 120357888a - 46596096
+--R             *
+--R                %%BM0
+--R            + 
+--R                      7         6         5          4           3           2
+--R                  576a  + 10985a  + 88746a  + 396609a  + 1076268a  + 1826304a
+--R                + 
+--R                  1867776a + 917504
+--R             *
+--R                x
+--R            + 
+--R                    7        6         5          4          3         2
+--R              - 536a  - 9231a  - 62920a  - 206931a  - 290334a  + 50560a
+--R            + 
+--R              552096a + 391168
+--R     + 
+--R                    2             4      2             3
+--R               (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x
+--R             + 
+--R                   2               2       2                    3      2
+--R             (- 16a  - 112a - 192)x  + (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R          *
+--R             ROOT
+--R                          5        4         3         2                       2
+--R                    (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)%%BM1
+--R                  + 
+--R                            5        4        3         2
+--R                      (- 64a  - 1088a  - 7360a  - 24768a  - 41472a - 27648)%%BM0
+--R                   *
+--R                      %%BM1
+--R                  + 
+--R                          5        4         3         2                       2
+--R                    (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)%%BM0
+--R                  + 
+--R                      2
+--R                    4a  + 35a + 73
+--R               /
+--R                     5       4        3         2
+--R                  32a  + 544a  + 3680a  + 12384a  + 20736a + 13824
+--R         + 
+--R                    2             4      2             3
+--R               (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x
+--R             + 
+--R                   2               2       2                    3      2
+--R             (- 16a  - 112a - 192)x  + (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R          *
+--R             %%BM1
+--R         + 
+--R                    2             4      2             3
+--R               (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x
+--R             + 
+--R                   2               2       2                    3      2
+--R             (- 16a  - 112a - 192)x  + (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R          *
+--R             %%BM0
+--R      *
+--R         log
+--R                                  12           11            10             9
+--R                          - 49152a   - 1974272a   - 36098048a   - 396918784a
+--R                        + 
+--R                                       8               7               6
+--R                          - 2919686144a  - 15113232384a  - 56334225408a
+--R                        + 
+--R                                         5                4                3
+--R                          - 151932321792a  - 293078695936a  - 392008564736a
+--R                        + 
+--R                                         2
+--R                          - 341824241664a  - 171568005120a - 36238786560
+--R                     *
+--R                        %%BM0
+--R                    + 
+--R                            10          9           8            7             6
+--R                      15104a   + 493312a  + 7210496a  + 62078464a  + 348407552a
+--R                    + 
+--R                                 5              4              3              2
+--R                      1330879232a  + 3500742656a  + 6253281280a  + 7247462400a
+--R                    + 
+--R                      4910284800a + 1472200704
+--R                 *
+--R                    %%BM1
+--R                + 
+--R                            10          9           8            7             6
+--R                      15104a   + 493312a  + 7210496a  + 62078464a  + 348407552a
+--R                    + 
+--R                                 5              4              3              2
+--R                      1330879232a  + 3500742656a  + 6253281280a  + 7247462400a
+--R                    + 
+--R                      4910284800a + 1472200704
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                        9         8          7           6            5
+--R                  - 768a  - 23000a  - 307368a  - 2407608a  - 12189944a
+--R                + 
+--R                           4            3             2
+--R                - 41394064a  - 94309952a  - 139040512a  - 120357888a - 46596096
+--R             *
+--R                ROOT
+--R                               5        4         3         2
+--R                         (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)
+--R                      *
+--R                              2
+--R                         %%BM1
+--R                     + 
+--R                               5        4        3         2
+--R                         (- 64a  - 1088a  - 7360a  - 24768a  - 41472a - 27648)
+--R                      *
+--R                         %%BM0 %%BM1
+--R                     + 
+--R                               5        4         3         2
+--R                         (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)
+--R                      *
+--R                              2
+--R                         %%BM0
+--R                     + 
+--R                         2
+--R                       4a  + 35a + 73
+--R                  /
+--R                        5       4        3         2
+--R                     32a  + 544a  + 3680a  + 12384a  + 20736a + 13824
+--R            + 
+--R                            12           11            10             9
+--R                      49152a   + 1974272a   + 36098048a   + 396918784a
+--R                    + 
+--R                                 8               7               6
+--R                      2919686144a  + 15113232384a  + 56334225408a
+--R                    + 
+--R                                   5                4                3
+--R                      151932321792a  + 293078695936a  + 392008564736a
+--R                    + 
+--R                                   2
+--R                      341824241664a  + 171568005120a + 36238786560
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                          10          9           8            7             6
+--R                  - 15104a   - 493312a  - 7210496a  - 62078464a  - 348407552a
+--R                + 
+--R                               5              4              3              2
+--R                  - 1330879232a  - 3500742656a  - 6253281280a  - 7247462400a
+--R                + 
+--R                  - 4910284800a - 1472200704
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                            12           11            10             9
+--R                      49152a   + 1974272a   + 36098048a   + 396918784a
+--R                    + 
+--R                                 8               7               6
+--R                      2919686144a  + 15113232384a  + 56334225408a
+--R                    + 
+--R                                   5                4                3
+--R                      151932321792a  + 293078695936a  + 392008564736a
+--R                    + 
+--R                                   2
+--R                      341824241664a  + 171568005120a + 36238786560
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                        9         8          7           6            5
+--R                  - 768a  - 23000a  - 307368a  - 2407608a  - 12189944a
+--R                + 
+--R                           4            3             2
+--R                - 41394064a  - 94309952a  - 139040512a  - 120357888a - 46596096
+--R             *
+--R                %%BM1
+--R            + 
+--R                          10          9           8            7             6
+--R                  - 15104a   - 493312a  - 7210496a  - 62078464a  - 348407552a
+--R                + 
+--R                               5              4              3              2
+--R                  - 1330879232a  - 3500742656a  - 6253281280a  - 7247462400a
+--R                + 
+--R                  - 4910284800a - 1472200704
+--R             *
+--R                     2
+--R                %%BM0
+--R            + 
+--R                        9         8          7           6            5
+--R                  - 768a  - 23000a  - 307368a  - 2407608a  - 12189944a
+--R                + 
+--R                           4            3             2
+--R                - 41394064a  - 94309952a  - 139040512a  - 120357888a - 46596096
+--R             *
+--R                %%BM0
+--R            + 
+--R                      7         6         5          4           3           2
+--R                  576a  + 10985a  + 88746a  + 396609a  + 1076268a  + 1826304a
+--R                + 
+--R                  1867776a + 917504
+--R             *
+--R                x
+--R            + 
+--R                    7        6         5          4          3         2
+--R              - 536a  - 9231a  - 62920a  - 206931a  - 290334a  + 50560a
+--R            + 
+--R              552096a + 391168
+--R     + 
+--R              2             4         2               3       2               2
+--R           (4a  + 28a + 48)x  + (- 16a  - 112a - 192)x  + (32a  + 224a + 384)x
+--R         + 
+--R                 2                    3      2
+--R           (- 32a  - 224a - 384)x - 4a  - 28a  - 48a
+--R      *
+--R         %%BM1
+--R      *
+--R         log
+--R                              12           11            10             9
+--R                      - 98304a   - 3948544a   - 72196096a   - 793837568a
+--R                    + 
+--R                                   8               7                6
+--R                      - 5839372288a  - 30226464768a  - 112668450816a
+--R                    + 
+--R                                     5                4                3
+--R                      - 303864643584a  - 586157391872a  - 784017129472a
+--R                    + 
+--R                                     2
+--R                      - 683648483328a  - 343136010240a - 72477573120
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                        10          9            8             7             6
+--R                  30208a   + 986624a  + 14420992a  + 124156928a  + 696815104a
+--R                + 
+--R                             5              4               3               2
+--R                  2661758464a  + 7001485312a  + 12506562560a  + 14494924800a
+--R                + 
+--R                  9820569600a + 2944401408
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                              12           11            10             9
+--R                      - 98304a   - 3948544a   - 72196096a   - 793837568a
+--R                    + 
+--R                                   8               7                6
+--R                      - 5839372288a  - 30226464768a  - 112668450816a
+--R                    + 
+--R                                     5                4                3
+--R                      - 303864643584a  - 586157391872a  - 784017129472a
+--R                    + 
+--R                                     2
+--R                      - 683648483328a  - 343136010240a - 72477573120
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                       9         8          7           6            5
+--R                  1536a  + 46000a  + 614736a  + 4815216a  + 24379888a
+--R                + 
+--R                         4             3             2
+--R                82788128a  + 188619904a  + 278081024a  + 240715776a + 93192192
+--R             *
+--R                %%BM1
+--R            + 
+--R                          12           11            10             9
+--R                  - 98304a   - 3948544a   - 72196096a   - 793837568a
+--R                + 
+--R                               8               7                6
+--R                  - 5839372288a  - 30226464768a  - 112668450816a
+--R                + 
+--R                                 5                4                3
+--R                  - 303864643584a  - 586157391872a  - 784017129472a
+--R                + 
+--R                                 2
+--R                  - 683648483328a  - 343136010240a - 72477573120
+--R             *
+--R                     3
+--R                %%BM0
+--R            + 
+--R                       9         8           7            6            5
+--R                  3072a  + 98048a  + 1371776a  + 11015872a  + 55760384a
+--R                + 
+--R                          4             3             2
+--R                183524544a  + 389433600a  + 506225664a  + 355348480a + 95682560
+--R             *
+--R                %%BM0
+--R            + 
+--R                      7         6         5          4           3           2
+--R                  576a  + 10985a  + 88746a  + 396609a  + 1076268a  + 1826304a
+--R                + 
+--R                  1867776a + 917504
+--R             *
+--R                x
+--R            + 
+--R                     7         6          5           4           3           2
+--R              - 1480a  - 32275a  - 300276a  - 1542319a  - 4712162a  - 8535232a
+--R            + 
+--R              - 8445728a - 3495936
+--R     + 
+--R              2             4         2               3       2               2
+--R           (4a  + 28a + 48)x  + (- 16a  - 112a - 192)x  + (32a  + 224a + 384)x
+--R         + 
+--R                 2                    3      2
+--R           (- 32a  - 224a - 384)x - 4a  - 28a  - 48a
+--R      *
+--R         %%BM0
+--R      *
+--R         log
+--R                        12           11            10             9
+--R                  98304a   + 3948544a   + 72196096a   + 793837568a
+--R                + 
+--R                             8               7                6                5
+--R                  5839372288a  + 30226464768a  + 112668450816a  + 303864643584a
+--R                + 
+--R                               4                3                2
+--R                  586157391872a  + 784017129472a  + 683648483328a
+--R                + 
+--R                  343136010240a + 72477573120
+--R             *
+--R                     3
+--R                %%BM0
+--R            + 
+--R                        10          9            8             7             6
+--R                  30208a   + 986624a  + 14420992a  + 124156928a  + 696815104a
+--R                + 
+--R                             5              4               3               2
+--R                  2661758464a  + 7001485312a  + 12506562560a  + 14494924800a
+--R                + 
+--R                  9820569600a + 2944401408
+--R             *
+--R                     2
+--R                %%BM0
+--R            + 
+--R                         9         8          7           6            5
+--R                  - 1536a  - 52048a  - 757040a  - 6200656a  - 31380496a
+--R                + 
+--R                            4             3             2
+--R                - 100736416a  - 200813696a  - 228144640a  - 114632704a - 2490368
+--R             *
+--R                %%BM0
+--R            + 
+--R                      7         6         5          4           3           2
+--R                  576a  + 10985a  + 88746a  + 396609a  + 1076268a  + 1826304a
+--R                + 
+--R                  1867776a + 917504
+--R             *
+--R                x
+--R            + 
+--R                  7        6         5          4          3           2
+--R              248a  + 6797a  + 71132a  + 369745a  + 987758a  + 1128896a
+--R            + 
+--R              - 129568a - 956416
+--R     + 
+--R          3      2
+--R       - x  - a x  + (a - 2)x - a
+--R  /
+--R          2             4         2               3       2               2
+--R       (4a  + 28a + 48)x  + (- 16a  - 112a - 192)x  + (32a  + 224a + 384)x
+--R     + 
+--R             2                    3      2
+--R       (- 32a  - 224a - 384)x - 4a  - 28a  - 48a
+--R                                         Type: Union(Expression(Integer),...)
+--E 297
+
+--S 298 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +--------------+ +------------+
+--R                2             +-----+ |   +-----+      | +-----+
+--R             (4a  + 28a + 48)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R          *
+--R             ROOT
+--R                          5        4         3         2                       2
+--R                    (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)%%BM1
+--R                  + 
+--R                            5        4        3         2
+--R                      (- 64a  - 1088a  - 7360a  - 24768a  - 41472a - 27648)%%BM0
+--R                   *
+--R                      %%BM1
+--R                  + 
+--R                          5        4         3         2                       2
+--R                    (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)%%BM0
+--R                  + 
+--R                      2
+--R                    4a  + 35a + 73
+--R               /
+--R                     5       4        3         2
+--R                  32a  + 544a  + 3680a  + 12384a  + 20736a + 13824
+--R         + 
+--R                                      +--------------+ +------------+
+--R                2             +-----+ |   +-----+      | +-----+
+--R           (- 4a  - 28a - 48)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BM1
+--R         + 
+--R                                           +--------------+ +------------+
+--R                2             +-----+      |   +-----+      | +-----+
+--R           (- 4a  - 28a - 48)\|a + 4 %%BM0\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R      *
+--R         log
+--R                                12           11            10             9
+--R                          49152a   + 1974272a   + 36098048a   + 396918784a
+--R                        + 
+--R                                     8               7               6
+--R                          2919686144a  + 15113232384a  + 56334225408a
+--R                        + 
+--R                                       5                4                3
+--R                          151932321792a  + 293078695936a  + 392008564736a
+--R                        + 
+--R                                       2
+--R                          341824241664a  + 171568005120a + 36238786560
+--R                     *
+--R                        %%BM0
+--R                    + 
+--R                              10          9           8            7
+--R                      - 15104a   - 493312a  - 7210496a  - 62078464a
+--R                    + 
+--R                                  6              5              4              3
+--R                      - 348407552a  - 1330879232a  - 3500742656a  - 6253281280a
+--R                    + 
+--R                                   2
+--R                      - 7247462400a  - 4910284800a - 1472200704
+--R                 *
+--R                    %%BM1
+--R                + 
+--R                              10          9           8            7
+--R                      - 15104a   - 493312a  - 7210496a  - 62078464a
+--R                    + 
+--R                                  6              5              4              3
+--R                      - 348407552a  - 1330879232a  - 3500742656a  - 6253281280a
+--R                    + 
+--R                                   2
+--R                      - 7247462400a  - 4910284800a - 1472200704
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                      9         8          7           6            5
+--R                  768a  + 23000a  + 307368a  + 2407608a  + 12189944a
+--R                + 
+--R                           4            3             2
+--R                  41394064a  + 94309952a  + 139040512a  + 120357888a + 46596096
+--R             *
+--R                ROOT
+--R                               5        4         3         2
+--R                         (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)
+--R                      *
+--R                              2
+--R                         %%BM1
+--R                     + 
+--R                               5        4        3         2
+--R                         (- 64a  - 1088a  - 7360a  - 24768a  - 41472a - 27648)
+--R                      *
+--R                         %%BM0 %%BM1
+--R                     + 
+--R                               5        4         3         2
+--R                         (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)
+--R                      *
+--R                              2
+--R                         %%BM0
+--R                     + 
+--R                         2
+--R                       4a  + 35a + 73
+--R                  /
+--R                        5       4        3         2
+--R                     32a  + 544a  + 3680a  + 12384a  + 20736a + 13824
+--R            + 
+--R                            12           11            10             9
+--R                      49152a   + 1974272a   + 36098048a   + 396918784a
+--R                    + 
+--R                                 8               7               6
+--R                      2919686144a  + 15113232384a  + 56334225408a
+--R                    + 
+--R                                   5                4                3
+--R                      151932321792a  + 293078695936a  + 392008564736a
+--R                    + 
+--R                                   2
+--R                      341824241664a  + 171568005120a + 36238786560
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                          10          9           8            7             6
+--R                  - 15104a   - 493312a  - 7210496a  - 62078464a  - 348407552a
+--R                + 
+--R                               5              4              3              2
+--R                  - 1330879232a  - 3500742656a  - 6253281280a  - 7247462400a
+--R                + 
+--R                  - 4910284800a - 1472200704
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                            12           11            10             9
+--R                      49152a   + 1974272a   + 36098048a   + 396918784a
+--R                    + 
+--R                                 8               7               6
+--R                      2919686144a  + 15113232384a  + 56334225408a
+--R                    + 
+--R                                   5                4                3
+--R                      151932321792a  + 293078695936a  + 392008564736a
+--R                    + 
+--R                                   2
+--R                      341824241664a  + 171568005120a + 36238786560
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                        9         8          7           6            5
+--R                  - 768a  - 23000a  - 307368a  - 2407608a  - 12189944a
+--R                + 
+--R                           4            3             2
+--R                - 41394064a  - 94309952a  - 139040512a  - 120357888a - 46596096
+--R             *
+--R                %%BM1
+--R            + 
+--R                          10          9           8            7             6
+--R                  - 15104a   - 493312a  - 7210496a  - 62078464a  - 348407552a
+--R                + 
+--R                               5              4              3              2
+--R                  - 1330879232a  - 3500742656a  - 6253281280a  - 7247462400a
+--R                + 
+--R                  - 4910284800a - 1472200704
+--R             *
+--R                     2
+--R                %%BM0
+--R            + 
+--R                        9         8          7           6            5
+--R                  - 768a  - 23000a  - 307368a  - 2407608a  - 12189944a
+--R                + 
+--R                           4            3             2
+--R                - 41394064a  - 94309952a  - 139040512a  - 120357888a - 46596096
+--R             *
+--R                %%BM0
+--R            + 
+--R                      7         6         5          4           3           2
+--R                  576a  + 10985a  + 88746a  + 396609a  + 1076268a  + 1826304a
+--R                + 
+--R                  1867776a + 917504
+--R             *
+--R                x
+--R            + 
+--R                    7        6         5          4          3         2
+--R              - 536a  - 9231a  - 62920a  - 206931a  - 290334a  + 50560a
+--R            + 
+--R              552096a + 391168
+--R     + 
+--R                                        +--------------+ +------------+
+--R                  2             +-----+ |   +-----+      | +-----+
+--R             (- 4a  - 28a - 48)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R          *
+--R             ROOT
+--R                          5        4         3         2                       2
+--R                    (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)%%BM1
+--R                  + 
+--R                            5        4        3         2
+--R                      (- 64a  - 1088a  - 7360a  - 24768a  - 41472a - 27648)%%BM0
+--R                   *
+--R                      %%BM1
+--R                  + 
+--R                          5        4         3         2                       2
+--R                    (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)%%BM0
+--R                  + 
+--R                      2
+--R                    4a  + 35a + 73
+--R               /
+--R                     5       4        3         2
+--R                  32a  + 544a  + 3680a  + 12384a  + 20736a + 13824
+--R         + 
+--R                                      +--------------+ +------------+
+--R                2             +-----+ |   +-----+      | +-----+
+--R           (- 4a  - 28a - 48)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BM1
+--R         + 
+--R                                           +--------------+ +------------+
+--R                2             +-----+      |   +-----+      | +-----+
+--R           (- 4a  - 28a - 48)\|a + 4 %%BM0\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R      *
+--R         log
+--R                                  12           11            10             9
+--R                          - 49152a   - 1974272a   - 36098048a   - 396918784a
+--R                        + 
+--R                                       8               7               6
+--R                          - 2919686144a  - 15113232384a  - 56334225408a
+--R                        + 
+--R                                         5                4                3
+--R                          - 151932321792a  - 293078695936a  - 392008564736a
+--R                        + 
+--R                                         2
+--R                          - 341824241664a  - 171568005120a - 36238786560
+--R                     *
+--R                        %%BM0
+--R                    + 
+--R                            10          9           8            7             6
+--R                      15104a   + 493312a  + 7210496a  + 62078464a  + 348407552a
+--R                    + 
+--R                                 5              4              3              2
+--R                      1330879232a  + 3500742656a  + 6253281280a  + 7247462400a
+--R                    + 
+--R                      4910284800a + 1472200704
+--R                 *
+--R                    %%BM1
+--R                + 
+--R                            10          9           8            7             6
+--R                      15104a   + 493312a  + 7210496a  + 62078464a  + 348407552a
+--R                    + 
+--R                                 5              4              3              2
+--R                      1330879232a  + 3500742656a  + 6253281280a  + 7247462400a
+--R                    + 
+--R                      4910284800a + 1472200704
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                        9         8          7           6            5
+--R                  - 768a  - 23000a  - 307368a  - 2407608a  - 12189944a
+--R                + 
+--R                           4            3             2
+--R                - 41394064a  - 94309952a  - 139040512a  - 120357888a - 46596096
+--R             *
+--R                ROOT
+--R                               5        4         3         2
+--R                         (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)
+--R                      *
+--R                              2
+--R                         %%BM1
+--R                     + 
+--R                               5        4        3         2
+--R                         (- 64a  - 1088a  - 7360a  - 24768a  - 41472a - 27648)
+--R                      *
+--R                         %%BM0 %%BM1
+--R                     + 
+--R                               5        4         3         2
+--R                         (- 96a  - 1632a  - 11040a  - 37152a  - 62208a - 41472)
+--R                      *
+--R                              2
+--R                         %%BM0
+--R                     + 
+--R                         2
+--R                       4a  + 35a + 73
+--R                  /
+--R                        5       4        3         2
+--R                     32a  + 544a  + 3680a  + 12384a  + 20736a + 13824
+--R            + 
+--R                            12           11            10             9
+--R                      49152a   + 1974272a   + 36098048a   + 396918784a
+--R                    + 
+--R                                 8               7               6
+--R                      2919686144a  + 15113232384a  + 56334225408a
+--R                    + 
+--R                                   5                4                3
+--R                      151932321792a  + 293078695936a  + 392008564736a
+--R                    + 
+--R                                   2
+--R                      341824241664a  + 171568005120a + 36238786560
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                          10          9           8            7             6
+--R                  - 15104a   - 493312a  - 7210496a  - 62078464a  - 348407552a
+--R                + 
+--R                               5              4              3              2
+--R                  - 1330879232a  - 3500742656a  - 6253281280a  - 7247462400a
+--R                + 
+--R                  - 4910284800a - 1472200704
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                            12           11            10             9
+--R                      49152a   + 1974272a   + 36098048a   + 396918784a
+--R                    + 
+--R                                 8               7               6
+--R                      2919686144a  + 15113232384a  + 56334225408a
+--R                    + 
+--R                                   5                4                3
+--R                      151932321792a  + 293078695936a  + 392008564736a
+--R                    + 
+--R                                   2
+--R                      341824241664a  + 171568005120a + 36238786560
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                        9         8          7           6            5
+--R                  - 768a  - 23000a  - 307368a  - 2407608a  - 12189944a
+--R                + 
+--R                           4            3             2
+--R                - 41394064a  - 94309952a  - 139040512a  - 120357888a - 46596096
+--R             *
+--R                %%BM1
+--R            + 
+--R                          10          9           8            7             6
+--R                  - 15104a   - 493312a  - 7210496a  - 62078464a  - 348407552a
+--R                + 
+--R                               5              4              3              2
+--R                  - 1330879232a  - 3500742656a  - 6253281280a  - 7247462400a
+--R                + 
+--R                  - 4910284800a - 1472200704
+--R             *
+--R                     2
+--R                %%BM0
+--R            + 
+--R                        9         8          7           6            5
+--R                  - 768a  - 23000a  - 307368a  - 2407608a  - 12189944a
+--R                + 
+--R                           4            3             2
+--R                - 41394064a  - 94309952a  - 139040512a  - 120357888a - 46596096
+--R             *
+--R                %%BM0
+--R            + 
+--R                      7         6         5          4           3           2
+--R                  576a  + 10985a  + 88746a  + 396609a  + 1076268a  + 1826304a
+--R                + 
+--R                  1867776a + 917504
+--R             *
+--R                x
+--R            + 
+--R                    7        6         5          4          3         2
+--R              - 536a  - 9231a  - 62920a  - 206931a  - 290334a  + 50560a
+--R            + 
+--R              552096a + 391168
+--R     + 
+--R                                  +--------------+ +------------+
+--R            2             +-----+ |   +-----+      | +-----+
+--R         (8a  + 56a + 96)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BM1
+--R      *
+--R         log
+--R                              12           11            10             9
+--R                      - 98304a   - 3948544a   - 72196096a   - 793837568a
+--R                    + 
+--R                                   8               7                6
+--R                      - 5839372288a  - 30226464768a  - 112668450816a
+--R                    + 
+--R                                     5                4                3
+--R                      - 303864643584a  - 586157391872a  - 784017129472a
+--R                    + 
+--R                                     2
+--R                      - 683648483328a  - 343136010240a - 72477573120
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                        10          9            8             7             6
+--R                  30208a   + 986624a  + 14420992a  + 124156928a  + 696815104a
+--R                + 
+--R                             5              4               3               2
+--R                  2661758464a  + 7001485312a  + 12506562560a  + 14494924800a
+--R                + 
+--R                  9820569600a + 2944401408
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                              12           11            10             9
+--R                      - 98304a   - 3948544a   - 72196096a   - 793837568a
+--R                    + 
+--R                                   8               7                6
+--R                      - 5839372288a  - 30226464768a  - 112668450816a
+--R                    + 
+--R                                     5                4                3
+--R                      - 303864643584a  - 586157391872a  - 784017129472a
+--R                    + 
+--R                                     2
+--R                      - 683648483328a  - 343136010240a - 72477573120
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                       9         8          7           6            5
+--R                  1536a  + 46000a  + 614736a  + 4815216a  + 24379888a
+--R                + 
+--R                         4             3             2
+--R                82788128a  + 188619904a  + 278081024a  + 240715776a + 93192192
+--R             *
+--R                %%BM1
+--R            + 
+--R                          12           11            10             9
+--R                  - 98304a   - 3948544a   - 72196096a   - 793837568a
+--R                + 
+--R                               8               7                6
+--R                  - 5839372288a  - 30226464768a  - 112668450816a
+--R                + 
+--R                                 5                4                3
+--R                  - 303864643584a  - 586157391872a  - 784017129472a
+--R                + 
+--R                                 2
+--R                  - 683648483328a  - 343136010240a - 72477573120
+--R             *
+--R                     3
+--R                %%BM0
+--R            + 
+--R                       9         8           7            6            5
+--R                  3072a  + 98048a  + 1371776a  + 11015872a  + 55760384a
+--R                + 
+--R                          4             3             2
+--R                183524544a  + 389433600a  + 506225664a  + 355348480a + 95682560
+--R             *
+--R                %%BM0
+--R            + 
+--R                      7         6         5          4           3           2
+--R                  576a  + 10985a  + 88746a  + 396609a  + 1076268a  + 1826304a
+--R                + 
+--R                  1867776a + 917504
+--R             *
+--R                x
+--R            + 
+--R                     7         6          5           4           3           2
+--R              - 1480a  - 32275a  - 300276a  - 1542319a  - 4712162a  - 8535232a
+--R            + 
+--R              - 8445728a - 3495936
+--R     + 
+--R                            +------------+
+--R         +-----+            | +-----+                x - 1
+--R       (\|a + 4  + 3a + 10)\|\|a + 4  + 1 atan(-----------------)
+--R                                                +--------------+
+--R                                                |   +-----+
+--R                                               \|- \|a + 4  + 1
+--R     + 
+--R                            +--------------+
+--R         +-----+            |   +-----+               x - 1
+--R       (\|a + 4  - 3a - 10)\|- \|a + 4  + 1 atan(---------------)
+--R                                                  +------------+
+--R                                                  | +-----+
+--R                                                 \|\|a + 4  + 1
+--R     + 
+--R                2             +-----+
+--R             (8a  + 56a + 96)\|a + 4 %%BM0
+--R          *
+--R             log
+--R                            12           11            10             9
+--R                      98304a   + 3948544a   + 72196096a   + 793837568a
+--R                    + 
+--R                                 8               7                6
+--R                      5839372288a  + 30226464768a  + 112668450816a
+--R                    + 
+--R                                   5                4                3
+--R                      303864643584a  + 586157391872a  + 784017129472a
+--R                    + 
+--R                                   2
+--R                      683648483328a  + 343136010240a + 72477573120
+--R                 *
+--R                         3
+--R                    %%BM0
+--R                + 
+--R                            10          9            8             7
+--R                      30208a   + 986624a  + 14420992a  + 124156928a
+--R                    + 
+--R                                6              5              4               3
+--R                      696815104a  + 2661758464a  + 7001485312a  + 12506562560a
+--R                    + 
+--R                                  2
+--R                      14494924800a  + 9820569600a + 2944401408
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                             9         8          7           6            5
+--R                      - 1536a  - 52048a  - 757040a  - 6200656a  - 31380496a
+--R                    + 
+--R                                  4             3             2
+--R                      - 100736416a  - 200813696a  - 228144640a  - 114632704a
+--R                    + 
+--R                      - 2490368
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                          7         6         5          4           3
+--R                      576a  + 10985a  + 88746a  + 396609a  + 1076268a
+--R                    + 
+--R                              2
+--R                      1826304a  + 1867776a + 917504
+--R                 *
+--R                    x
+--R                + 
+--R                      7        6         5          4          3           2
+--R                  248a  + 6797a  + 71132a  + 369745a  + 987758a  + 1128896a
+--R                + 
+--R                  - 129568a - 956416
+--R         + 
+--R                            2
+--R                           x  - 2x + 2
+--R           (- 2a - 6)atanh(-----------)
+--R                              +-----+
+--R                             \|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R                              +--------------+ +------------+
+--R        2             +-----+ |   +-----+      | +-----+
+--R     (8a  + 56a + 96)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 299
+
+)clear all
+
+--S 300 of 534
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)^3
+--R 
+--R
+--R   (1)
+--R   -
+--R        x
+--R     /
+--R           12      11      10       9                8                7
+--R          x   - 12x   + 72x   - 280x  + (- 3a + 768)x  + (24a - 1536)x
+--R        + 
+--R                         6                 5      2                4
+--R          (- 96a + 2240)x  + (240a - 2304)x  + (3a  - 384a + 1536)x
+--R        + 
+--R                2               3       2         2      2     3
+--R          (- 12a  + 384a - 512)x  + (24a  - 192a)x  - 24a x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 300
+
+--S 301 of 534
+r0:=1/8*(1+(-1+x)^2)/((4+a)*(3+a-2*(-1+x)^2-(-1+x)^4)^2)+3/16*(1+(-1+x)^2)/_
+   ((4+a)^2*(3+a-2*(-1+x)^2-(-1+x)^4))+1/8*(5+a+(-1+x)^2)*(-1+x)/_
+   ((12+7*a+a^2)*(3+a-2*(-1+x)^2-(-1+x)^4)^2)+1/32*((6+a)*(25+7*a)+_
+   6*(7+2*a)*(-1+x)^2)*(-1+x)/((3+a)^2*(4+a)^2*(3+a-2*(-1+x)^2-(-1+x)^4))+_
+   3/16*atanh((1+(-1+x)^2)/sqrt(4+a))/(4+a)^(5/2)-3/64*atan((-1+x)/_
+   sqrt(1-sqrt(4+a)))*(80+7*a^2+14*sqrt(4+a)+a*(47+4*sqrt(4+a)))/((3+a)^2*_
+   (4+a)^(5/2)*sqrt(1-sqrt(4+a)))-3/64*atan((-1+x)/sqrt(1+sqrt(4+a)))*_
+   (14+4*a+(-80-47*a-7*a^2)/sqrt(4+a))/((3+a)^2*(4+a)^2*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R                            8               7                   6
+--R               (- 12a - 42)x  + (96a + 336)x  + (- 384a - 1344)x
+--R             + 
+--R                             5       2                 4
+--R               (960a + 3360)x  + (24a  - 1452a - 5376)x
+--R             + 
+--R                     2                 3        2               2
+--R               (- 96a  + 1200a + 5376)x  + (192a  - 96a - 2688)x
+--R             + 
+--R                      2               3      2
+--R               (- 192a  - 672a)x - 12a  - 42a
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R                 2               8        2                 7
+--R           (- 21a  - 141a - 240)x  + (168a  + 1128a + 1920)x
+--R         + 
+--R                  2                 6         2                   5
+--R           (- 672a  - 4512a - 7680)x  + (1680a  + 11280a + 19200)x
+--R         + 
+--R               3        2                   4
+--R           (42a  - 2406a  - 17568a - 30720)x
+--R         + 
+--R                  3        2                   3
+--R           (- 168a  + 1560a  + 16128a + 30720)x
+--R         + 
+--R                3       2                  2          3        2
+--R           (336a  + 912a  - 5184a - 15360)x  + (- 336a  - 2256a  - 3840a)x
+--R         + 
+--R                4       3       2
+--R           - 21a  - 141a  - 240a
+--R      *
+--R          +------------+
+--R          | +-----+                x - 1
+--R         \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R                            8               7                   6
+--R               (- 12a - 42)x  + (96a + 336)x  + (- 384a - 1344)x
+--R             + 
+--R                             5       2                 4
+--R               (960a + 3360)x  + (24a  - 1452a - 5376)x
+--R             + 
+--R                     2                 3        2               2
+--R               (- 96a  + 1200a + 5376)x  + (192a  - 96a - 2688)x
+--R             + 
+--R                      2               3      2
+--R               (- 192a  - 672a)x - 12a  - 42a
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R               2               8          2                 7
+--R           (21a  + 141a + 240)x  + (- 168a  - 1128a - 1920)x
+--R         + 
+--R                2                 6           2                   5
+--R           (672a  + 4512a + 7680)x  + (- 1680a  - 11280a - 19200)x
+--R         + 
+--R                 3        2                   4
+--R           (- 42a  + 2406a  + 17568a + 30720)x
+--R         + 
+--R                3        2                   3
+--R           (168a  - 1560a  - 16128a - 30720)x
+--R         + 
+--R                  3       2                  2        3        2
+--R           (- 336a  - 912a  + 5184a + 15360)x  + (336a  + 2256a  + 3840a)x
+--R         + 
+--R              4       3       2
+--R           21a  + 141a  + 240a
+--R      *
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R         \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R                   2              8         2               7
+--R               (12a  + 72a + 108)x  + (- 96a  - 576a - 864)x
+--R             + 
+--R                    2                 6          2                 5
+--R               (384a  + 2304a + 3456)x  + (- 960a  - 5760a - 8640)x
+--R             + 
+--R                     3        2                  4
+--R               (- 24a  + 1392a  + 9000a + 13824)x
+--R             + 
+--R                   3       2                  3
+--R               (96a  - 960a  - 8352a - 13824)x
+--R             + 
+--R                      3       2                 2        3        2
+--R               (- 192a  - 384a  + 2880a + 6912)x  + (192a  + 1152a  + 1728a)x
+--R             + 
+--R                  4      3       2
+--R               12a  + 72a  + 108a
+--R          *
+--R                    2
+--R                   x  - 2x + 2
+--R             atanh(-----------)
+--R                      +-----+
+--R                     \|a + 4
+--R         + 
+--R                            7         2              6       2                5
+--R               (- 24a - 84)x  + (- 12a  + 96a + 480)x  + (58a  - 254a - 1584)x
+--R             + 
+--R                      2                4        2                3
+--R               (- 146a  + 454a + 3336)x  + (248a  - 412a - 4416)x
+--R             + 
+--R                   3       2                2         3       2
+--R               (20a  - 104a  + 560a + 4032)x  + (- 18a  + 102a  + 240a - 1152)x
+--R             + 
+--R                  3      2
+--R               18a  + 42a  - 72a
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R             4       3        2                  8
+--R         (64a  + 896a  + 4672a  + 10752a + 9216)x
+--R       + 
+--R                4        3         2                   7
+--R         (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R       + 
+--R               4         3          2                     6
+--R         (2048a  + 28672a  + 149504a  + 344064a + 294912)x
+--R       + 
+--R                 4         3          2                     5
+--R         (- 5120a  - 71680a  - 373760a  - 860160a - 737280)x
+--R       + 
+--R                5        4          3          2                       4
+--R         (- 128a  + 6400a  + 105344a  + 576512a  + 1357824a + 1179648)x
+--R       + 
+--R              5        4         3          2                       3
+--R         (512a  - 1024a  - 77312a  - 512000a  - 1302528a - 1179648)x
+--R       + 
+--R                 5         4         3          2                     2
+--R         (- 1024a  - 10240a  - 17408a  + 126976a  + 540672a + 589824)x
+--R       + 
+--R               5         4         3          2                  6       5
+--R         (1024a  + 14336a  + 74752a  + 172032a  + 147456a)x + 64a  + 896a
+--R       + 
+--R              4         3        2
+--R         4672a  + 10752a  + 9216a
+--R    *
+--R                +--------------+ +------------+
+--R        +-----+ |   +-----+      | +-----+
+--R       \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   4       3        2                 8
+--R               (16a  + 224a  + 1168a  + 2688a + 2304)x
+--R             + 
+--R                      4        3        2                   7
+--R               (- 128a  - 1792a  - 9344a  - 21504a - 18432)x
+--R             + 
+--R                    4        3         2                   6
+--R               (512a  + 7168a  + 37376a  + 86016a + 73728)x
+--R             + 
+--R                       4         3         2                     5
+--R               (- 1280a  - 17920a  - 93440a  - 215040a - 184320)x
+--R             + 
+--R                     5        4         3          2                     4
+--R               (- 32a  + 1600a  + 26336a  + 144128a  + 339456a + 294912)x
+--R             + 
+--R                    5       4         3          2                     3
+--R               (128a  - 256a  - 19328a  - 128000a  - 325632a - 294912)x
+--R             + 
+--R                      5        4        3         2                     2
+--R               (- 256a  - 2560a  - 4352a  + 31744a  + 135168a + 147456)x
+--R             + 
+--R                    5        4         3         2                 6       5
+--R               (256a  + 3584a  + 18688a  + 43008a  + 36864a)x + 16a  + 224a
+--R             + 
+--R                    4        3        2
+--R               1168a  + 2688a  + 2304a
+--R          *
+--R             ROOT
+--R                               9          8           7            6
+--R                        - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                      + 
+--R                                    5             4             3              2
+--R                        - 107280384a  - 365709312a  - 828997632a  - 1205010432a
+--R                      + 
+--R                        - 1019215872a - 382205952
+--R                   *
+--R                           2
+--R                      %%BN1
+--R                  + 
+--R                               9          8           7            6
+--R                        - 4096a  - 126976a  - 1744896a  - 13950976a
+--R                      + 
+--R                                   5             4             3             2
+--R                        - 71520256a  - 243806208a  - 552665088a  - 803340288a
+--R                      + 
+--R                        - 679477248a - 254803968
+--R                   *
+--R                      %%BN0 %%BN1
+--R                  + 
+--R                               9          8           7            6
+--R                        - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                      + 
+--R                                    5             4             3              2
+--R                        - 107280384a  - 365709312a  - 828997632a  - 1205010432a
+--R                      + 
+--R                        - 1019215872a - 382205952
+--R                   *
+--R                           2
+--R                      %%BN0
+--R                  + 
+--R                        4        3         2
+--R                    144a  + 2529a  + 16074a  + 44325a + 45072
+--R               /
+--R                         9         8          7           6            5
+--R                    2048a  + 63488a  + 872448a  + 6975488a  + 35760128a
+--R                  + 
+--R                              4             3             2
+--R                    121903104a  + 276332544a  + 401670144a  + 339738624a
+--R                  + 
+--R                    127401984
+--R         + 
+--R                     4       3        2                 8
+--R               (- 16a  - 224a  - 1168a  - 2688a - 2304)x
+--R             + 
+--R                    4        3        2                   7
+--R               (128a  + 1792a  + 9344a  + 21504a + 18432)x
+--R             + 
+--R                      4        3         2                   6
+--R               (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R             + 
+--R                     4         3         2                     5
+--R               (1280a  + 17920a  + 93440a  + 215040a + 184320)x
+--R             + 
+--R                   5        4         3          2                     4
+--R               (32a  - 1600a  - 26336a  - 144128a  - 339456a - 294912)x
+--R             + 
+--R                      5       4         3          2                     3
+--R               (- 128a  + 256a  + 19328a  + 128000a  + 325632a + 294912)x
+--R             + 
+--R                    5        4        3         2                     2
+--R               (256a  + 2560a  + 4352a  - 31744a  - 135168a - 147456)x
+--R             + 
+--R                      5        4         3         2                 6       5
+--R               (- 256a  - 3584a  - 18688a  - 43008a  - 36864a)x - 16a  - 224a
+--R             + 
+--R                      4        3        2
+--R               - 1168a  - 2688a  - 2304a
+--R          *
+--R             %%BN1
+--R         + 
+--R                     4       3        2                 8
+--R               (- 16a  - 224a  - 1168a  - 2688a - 2304)x
+--R             + 
+--R                    4        3        2                   7
+--R               (128a  + 1792a  + 9344a  + 21504a + 18432)x
+--R             + 
+--R                      4        3         2                   6
+--R               (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R             + 
+--R                     4         3         2                     5
+--R               (1280a  + 17920a  + 93440a  + 215040a + 184320)x
+--R             + 
+--R                   5        4         3          2                     4
+--R               (32a  - 1600a  - 26336a  - 144128a  - 339456a - 294912)x
+--R             + 
+--R                      5       4         3          2                     3
+--R               (- 128a  + 256a  + 19328a  + 128000a  + 325632a + 294912)x
+--R             + 
+--R                    5        4        3         2                     2
+--R               (256a  + 2560a  + 4352a  - 31744a  - 135168a - 147456)x
+--R             + 
+--R                      5        4         3         2                 6       5
+--R               (- 256a  - 3584a  - 18688a  - 43008a  - 36864a)x - 16a  - 224a
+--R             + 
+--R                      4        3        2
+--R               - 1168a  - 2688a  - 2304a
+--R          *
+--R             %%BN0
+--R      *
+--R         log
+--R                                    20               19                18
+--R                          234881024a   + 15708717056a   + 496152608768a
+--R                        + 
+--R                                        17                   16
+--R                          9831788314624a   + 136940015845376a
+--R                        + 
+--R                                           15                     14
+--R                          1423058097143808a   + 11426991446163456a
+--R                        + 
+--R                                            13                      12
+--R                          72420208802791424a   + 366596577386561536a
+--R                        + 
+--R                                              11                       10
+--R                          1488970734852112384a   + 4838598686558650368a
+--R                        + 
+--R                                               9                        8
+--R                          12425210726207979520a  + 24492354465884536832a
+--R                        + 
+--R                                               7                        6
+--R                          34562341164971720704a  + 27460753621868609536a
+--R                        + 
+--R                                                5                        4
+--R                          - 9416711544462376960a  - 64383511022222180352a
+--R                        + 
+--R                                                 3                        2
+--R                          - 98946912238272774144a  - 85288494643002998784a
+--R                        + 
+--R                          - 41854934312200175616a - 9196381225416130560
+--R                     *
+--R                        %%BN0
+--R                    + 
+--R                                 17              16               15
+--R                      - 68321280a   - 3808296960a   - 99490332672a
+--R                    + 
+--R                                      14                  13
+--R                      - 1617150345216a   - 18307181641728a
+--R                    + 
+--R                                        12                   11
+--R                      - 153077802860544a   - 978169828343808a
+--R                    + 
+--R                                         10                     9
+--R                      - 4873947387789312a   - 19145920722665472a
+--R                    + 
+--R                                          8                      7
+--R                      - 59525244286795776a  - 146118386094440448a
+--R                    + 
+--R                                           6                      5
+--R                      - 280630860186648576a  - 414449290539171840a
+--R                    + 
+--R                                           4                      3
+--R                      - 457219727249375232a  - 359127846104334336a
+--R                    + 
+--R                                           2
+--R                      - 184613707362336768a  - 52407721374253056a
+--R                    + 
+--R                      - 5131760069246976
+--R                 *
+--R                    %%BN1
+--R                + 
+--R                                 17              16               15
+--R                      - 68321280a   - 3808296960a   - 99490332672a
+--R                    + 
+--R                                      14                  13
+--R                      - 1617150345216a   - 18307181641728a
+--R                    + 
+--R                                        12                   11
+--R                      - 153077802860544a   - 978169828343808a
+--R                    + 
+--R                                         10                     9
+--R                      - 4873947387789312a   - 19145920722665472a
+--R                    + 
+--R                                          8                      7
+--R                      - 59525244286795776a  - 146118386094440448a
+--R                    + 
+--R                                           6                      5
+--R                      - 280630860186648576a  - 414449290539171840a
+--R                    + 
+--R                                           4                      3
+--R                      - 457219727249375232a  - 359127846104334336a
+--R                    + 
+--R                                           2
+--R                      - 184613707362336768a  - 52407721374253056a
+--R                    + 
+--R                      - 5131760069246976
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                          15             14              13               12
+--R                  2064384a   + 102845376a   + 2407788288a   + 35173137600a
+--R                + 
+--R                               11                 10                  9
+--R                  358820305920a   + 2709351482688a   + 15647114329344a
+--R                + 
+--R                                 8                   7                   6
+--R                  70381874875968a  + 248533968955392a  + 688612316857344a
+--R                + 
+--R                                   5                    4                    3
+--R                  1483679290355712a  + 2439030084747264a  + 2958346595598336a
+--R                + 
+--R                                   2
+--R                  2496835484909568a  + 1309881714868224a + 321701220974592
+--R             *
+--R                ROOT
+--R                                  9          8           7            6
+--R                           - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                         + 
+--R                                       5             4             3
+--R                           - 107280384a  - 365709312a  - 828997632a
+--R                         + 
+--R                                        2
+--R                           - 1205010432a  - 1019215872a - 382205952
+--R                      *
+--R                              2
+--R                         %%BN1
+--R                     + 
+--R                                  9          8           7            6
+--R                           - 4096a  - 126976a  - 1744896a  - 13950976a
+--R                         + 
+--R                                      5             4             3
+--R                           - 71520256a  - 243806208a  - 552665088a
+--R                         + 
+--R                                       2
+--R                           - 803340288a  - 679477248a - 254803968
+--R                      *
+--R                         %%BN0 %%BN1
+--R                     + 
+--R                                  9          8           7            6
+--R                           - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                         + 
+--R                                       5             4             3
+--R                           - 107280384a  - 365709312a  - 828997632a
+--R                         + 
+--R                                        2
+--R                           - 1205010432a  - 1019215872a - 382205952
+--R                      *
+--R                              2
+--R                         %%BN0
+--R                     + 
+--R                           4        3         2
+--R                       144a  + 2529a  + 16074a  + 44325a + 45072
+--R                  /
+--R                            9         8          7           6            5
+--R                       2048a  + 63488a  + 872448a  + 6975488a  + 35760128a
+--R                     + 
+--R                                 4             3             2
+--R                       121903104a  + 276332544a  + 401670144a  + 339738624a
+--R                     + 
+--R                       127401984
+--R            + 
+--R                                20               19                18
+--R                      234881024a   + 15708717056a   + 496152608768a
+--R                    + 
+--R                                    17                   16
+--R                      9831788314624a   + 136940015845376a
+--R                    + 
+--R                                       15                     14
+--R                      1423058097143808a   + 11426991446163456a
+--R                    + 
+--R                                        13                      12
+--R                      72420208802791424a   + 366596577386561536a
+--R                    + 
+--R                                          11                       10
+--R                      1488970734852112384a   + 4838598686558650368a
+--R                    + 
+--R                                           9                        8
+--R                      12425210726207979520a  + 24492354465884536832a
+--R                    + 
+--R                                           7                        6
+--R                      34562341164971720704a  + 27460753621868609536a
+--R                    + 
+--R                                            5                        4
+--R                      - 9416711544462376960a  - 64383511022222180352a
+--R                    + 
+--R                                             3                        2
+--R                      - 98946912238272774144a  - 85288494643002998784a
+--R                    + 
+--R                      - 41854934312200175616a - 9196381225416130560
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                             17              16               15
+--R                  - 68321280a   - 3808296960a   - 99490332672a
+--R                + 
+--R                                  14                  13                   12
+--R                  - 1617150345216a   - 18307181641728a   - 153077802860544a
+--R                + 
+--R                                    11                    10
+--R                  - 978169828343808a   - 4873947387789312a
+--R                + 
+--R                                      9                     8
+--R                  - 19145920722665472a  - 59525244286795776a
+--R                + 
+--R                                       7                      6
+--R                  - 146118386094440448a  - 280630860186648576a
+--R                + 
+--R                                       5                      4
+--R                  - 414449290539171840a  - 457219727249375232a
+--R                + 
+--R                                       3                      2
+--R                  - 359127846104334336a  - 184613707362336768a
+--R                + 
+--R                  - 52407721374253056a - 5131760069246976
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                                20               19                18
+--R                      234881024a   + 15708717056a   + 496152608768a
+--R                    + 
+--R                                    17                   16
+--R                      9831788314624a   + 136940015845376a
+--R                    + 
+--R                                       15                     14
+--R                      1423058097143808a   + 11426991446163456a
+--R                    + 
+--R                                        13                      12
+--R                      72420208802791424a   + 366596577386561536a
+--R                    + 
+--R                                          11                       10
+--R                      1488970734852112384a   + 4838598686558650368a
+--R                    + 
+--R                                           9                        8
+--R                      12425210726207979520a  + 24492354465884536832a
+--R                    + 
+--R                                           7                        6
+--R                      34562341164971720704a  + 27460753621868609536a
+--R                    + 
+--R                                            5                        4
+--R                      - 9416711544462376960a  - 64383511022222180352a
+--R                    + 
+--R                                             3                        2
+--R                      - 98946912238272774144a  - 85288494643002998784a
+--R                    + 
+--R                      - 41854934312200175616a - 9196381225416130560
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                            15             14              13               12
+--R                  - 2064384a   - 102845376a   - 2407788288a   - 35173137600a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 358820305920a   - 2709351482688a   - 15647114329344a
+--R                + 
+--R                                   8                   7                   6
+--R                  - 70381874875968a  - 248533968955392a  - 688612316857344a
+--R                + 
+--R                                     5                    4                    3
+--R                  - 1483679290355712a  - 2439030084747264a  - 2958346595598336a
+--R                + 
+--R                                     2
+--R                  - 2496835484909568a  - 1309881714868224a - 321701220974592
+--R             *
+--R                %%BN1
+--R            + 
+--R                             17              16               15
+--R                  - 68321280a   - 3808296960a   - 99490332672a
+--R                + 
+--R                                  14                  13                   12
+--R                  - 1617150345216a   - 18307181641728a   - 153077802860544a
+--R                + 
+--R                                    11                    10
+--R                  - 978169828343808a   - 4873947387789312a
+--R                + 
+--R                                      9                     8
+--R                  - 19145920722665472a  - 59525244286795776a
+--R                + 
+--R                                       7                      6
+--R                  - 146118386094440448a  - 280630860186648576a
+--R                + 
+--R                                       5                      4
+--R                  - 414449290539171840a  - 457219727249375232a
+--R                + 
+--R                                       3                      2
+--R                  - 359127846104334336a  - 184613707362336768a
+--R                + 
+--R                  - 52407721374253056a - 5131760069246976
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                            15             14              13               12
+--R                  - 2064384a   - 102845376a   - 2407788288a   - 35173137600a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 358820305920a   - 2709351482688a   - 15647114329344a
+--R                + 
+--R                                   8                   7                   6
+--R                  - 70381874875968a  - 248533968955392a  - 688612316857344a
+--R                + 
+--R                                     5                    4                    3
+--R                  - 1483679290355712a  - 2439030084747264a  - 2958346595598336a
+--R                + 
+--R                                     2
+--R                  - 2496835484909568a  - 1309881714868224a - 321701220974592
+--R             *
+--R                %%BN0
+--R            + 
+--R                          12            11             10              9
+--R                  1354752a   + 44550027a   + 663517980a   + 5951170602a
+--R                + 
+--R                              8                7                6
+--R                  36270700668a  + 162289912419a  + 567868212432a
+--R                + 
+--R                                5                 4                 3
+--R                  1626099007104a  + 3825839091456a  + 7035734732544a
+--R                + 
+--R                                2
+--R                  9216760449024a  + 7467334520832a + 2773884911616
+--R             *
+--R                x
+--R            + 
+--R                        12            11             10              9
+--R              - 1339200a   - 39712275a   - 495782964a   - 3189902202a
+--R            + 
+--R                           8               7                6                 5
+--R              - 8686407276a  + 22247807733a  + 298217053944a  + 1280770679808a
+--R            + 
+--R                            4                 3                 2
+--R              3147806126592a  + 4679916891264a  + 3907698508800a
+--R            + 
+--R              1355312093184a - 77935509504
+--R     + 
+--R                     4       3        2                 8
+--R               (- 16a  - 224a  - 1168a  - 2688a - 2304)x
+--R             + 
+--R                    4        3        2                   7
+--R               (128a  + 1792a  + 9344a  + 21504a + 18432)x
+--R             + 
+--R                      4        3         2                   6
+--R               (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R             + 
+--R                     4         3         2                     5
+--R               (1280a  + 17920a  + 93440a  + 215040a + 184320)x
+--R             + 
+--R                   5        4         3          2                     4
+--R               (32a  - 1600a  - 26336a  - 144128a  - 339456a - 294912)x
+--R             + 
+--R                      5       4         3          2                     3
+--R               (- 128a  + 256a  + 19328a  + 128000a  + 325632a + 294912)x
+--R             + 
+--R                    5        4        3         2                     2
+--R               (256a  + 2560a  + 4352a  - 31744a  - 135168a - 147456)x
+--R             + 
+--R                      5        4         3         2                 6       5
+--R               (- 256a  - 3584a  - 18688a  - 43008a  - 36864a)x - 16a  - 224a
+--R             + 
+--R                      4        3        2
+--R               - 1168a  - 2688a  - 2304a
+--R          *
+--R             ROOT
+--R                               9          8           7            6
+--R                        - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                      + 
+--R                                    5             4             3              2
+--R                        - 107280384a  - 365709312a  - 828997632a  - 1205010432a
+--R                      + 
+--R                        - 1019215872a - 382205952
+--R                   *
+--R                           2
+--R                      %%BN1
+--R                  + 
+--R                               9          8           7            6
+--R                        - 4096a  - 126976a  - 1744896a  - 13950976a
+--R                      + 
+--R                                   5             4             3             2
+--R                        - 71520256a  - 243806208a  - 552665088a  - 803340288a
+--R                      + 
+--R                        - 679477248a - 254803968
+--R                   *
+--R                      %%BN0 %%BN1
+--R                  + 
+--R                               9          8           7            6
+--R                        - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                      + 
+--R                                    5             4             3              2
+--R                        - 107280384a  - 365709312a  - 828997632a  - 1205010432a
+--R                      + 
+--R                        - 1019215872a - 382205952
+--R                   *
+--R                           2
+--R                      %%BN0
+--R                  + 
+--R                        4        3         2
+--R                    144a  + 2529a  + 16074a  + 44325a + 45072
+--R               /
+--R                         9         8          7           6            5
+--R                    2048a  + 63488a  + 872448a  + 6975488a  + 35760128a
+--R                  + 
+--R                              4             3             2
+--R                    121903104a  + 276332544a  + 401670144a  + 339738624a
+--R                  + 
+--R                    127401984
+--R         + 
+--R                     4       3        2                 8
+--R               (- 16a  - 224a  - 1168a  - 2688a - 2304)x
+--R             + 
+--R                    4        3        2                   7
+--R               (128a  + 1792a  + 9344a  + 21504a + 18432)x
+--R             + 
+--R                      4        3         2                   6
+--R               (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R             + 
+--R                     4         3         2                     5
+--R               (1280a  + 17920a  + 93440a  + 215040a + 184320)x
+--R             + 
+--R                   5        4         3          2                     4
+--R               (32a  - 1600a  - 26336a  - 144128a  - 339456a - 294912)x
+--R             + 
+--R                      5       4         3          2                     3
+--R               (- 128a  + 256a  + 19328a  + 128000a  + 325632a + 294912)x
+--R             + 
+--R                    5        4        3         2                     2
+--R               (256a  + 2560a  + 4352a  - 31744a  - 135168a - 147456)x
+--R             + 
+--R                      5        4         3         2                 6       5
+--R               (- 256a  - 3584a  - 18688a  - 43008a  - 36864a)x - 16a  - 224a
+--R             + 
+--R                      4        3        2
+--R               - 1168a  - 2688a  - 2304a
+--R          *
+--R             %%BN1
+--R         + 
+--R                     4       3        2                 8
+--R               (- 16a  - 224a  - 1168a  - 2688a - 2304)x
+--R             + 
+--R                    4        3        2                   7
+--R               (128a  + 1792a  + 9344a  + 21504a + 18432)x
+--R             + 
+--R                      4        3         2                   6
+--R               (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R             + 
+--R                     4         3         2                     5
+--R               (1280a  + 17920a  + 93440a  + 215040a + 184320)x
+--R             + 
+--R                   5        4         3          2                     4
+--R               (32a  - 1600a  - 26336a  - 144128a  - 339456a - 294912)x
+--R             + 
+--R                      5       4         3          2                     3
+--R               (- 128a  + 256a  + 19328a  + 128000a  + 325632a + 294912)x
+--R             + 
+--R                    5        4        3         2                     2
+--R               (256a  + 2560a  + 4352a  - 31744a  - 135168a - 147456)x
+--R             + 
+--R                      5        4         3         2                 6       5
+--R               (- 256a  - 3584a  - 18688a  - 43008a  - 36864a)x - 16a  - 224a
+--R             + 
+--R                      4        3        2
+--R               - 1168a  - 2688a  - 2304a
+--R          *
+--R             %%BN0
+--R      *
+--R         log
+--R                                      20               19                18
+--R                          - 234881024a   - 15708717056a   - 496152608768a
+--R                        + 
+--R                                          17                   16
+--R                          - 9831788314624a   - 136940015845376a
+--R                        + 
+--R                                             15                     14
+--R                          - 1423058097143808a   - 11426991446163456a
+--R                        + 
+--R                                              13                      12
+--R                          - 72420208802791424a   - 366596577386561536a
+--R                        + 
+--R                                                11                       10
+--R                          - 1488970734852112384a   - 4838598686558650368a
+--R                        + 
+--R                                                 9                        8
+--R                          - 12425210726207979520a  - 24492354465884536832a
+--R                        + 
+--R                                                 7                        6
+--R                          - 34562341164971720704a  - 27460753621868609536a
+--R                        + 
+--R                                              5                        4
+--R                          9416711544462376960a  + 64383511022222180352a
+--R                        + 
+--R                                               3                        2
+--R                          98946912238272774144a  + 85288494643002998784a
+--R                        + 
+--R                          41854934312200175616a + 9196381225416130560
+--R                     *
+--R                        %%BN0
+--R                    + 
+--R                               17              16               15
+--R                      68321280a   + 3808296960a   + 99490332672a
+--R                    + 
+--R                                    14                  13                   12
+--R                      1617150345216a   + 18307181641728a   + 153077802860544a
+--R                    + 
+--R                                      11                    10
+--R                      978169828343808a   + 4873947387789312a
+--R                    + 
+--R                                        9                     8
+--R                      19145920722665472a  + 59525244286795776a
+--R                    + 
+--R                                         7                      6
+--R                      146118386094440448a  + 280630860186648576a
+--R                    + 
+--R                                         5                      4
+--R                      414449290539171840a  + 457219727249375232a
+--R                    + 
+--R                                         3                      2
+--R                      359127846104334336a  + 184613707362336768a
+--R                    + 
+--R                      52407721374253056a + 5131760069246976
+--R                 *
+--R                    %%BN1
+--R                + 
+--R                               17              16               15
+--R                      68321280a   + 3808296960a   + 99490332672a
+--R                    + 
+--R                                    14                  13                   12
+--R                      1617150345216a   + 18307181641728a   + 153077802860544a
+--R                    + 
+--R                                      11                    10
+--R                      978169828343808a   + 4873947387789312a
+--R                    + 
+--R                                        9                     8
+--R                      19145920722665472a  + 59525244286795776a
+--R                    + 
+--R                                         7                      6
+--R                      146118386094440448a  + 280630860186648576a
+--R                    + 
+--R                                         5                      4
+--R                      414449290539171840a  + 457219727249375232a
+--R                    + 
+--R                                         3                      2
+--R                      359127846104334336a  + 184613707362336768a
+--R                    + 
+--R                      52407721374253056a + 5131760069246976
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                            15             14              13               12
+--R                  - 2064384a   - 102845376a   - 2407788288a   - 35173137600a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 358820305920a   - 2709351482688a   - 15647114329344a
+--R                + 
+--R                                   8                   7                   6
+--R                  - 70381874875968a  - 248533968955392a  - 688612316857344a
+--R                + 
+--R                                     5                    4                    3
+--R                  - 1483679290355712a  - 2439030084747264a  - 2958346595598336a
+--R                + 
+--R                                     2
+--R                  - 2496835484909568a  - 1309881714868224a - 321701220974592
+--R             *
+--R                ROOT
+--R                                  9          8           7            6
+--R                           - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                         + 
+--R                                       5             4             3
+--R                           - 107280384a  - 365709312a  - 828997632a
+--R                         + 
+--R                                        2
+--R                           - 1205010432a  - 1019215872a - 382205952
+--R                      *
+--R                              2
+--R                         %%BN1
+--R                     + 
+--R                                  9          8           7            6
+--R                           - 4096a  - 126976a  - 1744896a  - 13950976a
+--R                         + 
+--R                                      5             4             3
+--R                           - 71520256a  - 243806208a  - 552665088a
+--R                         + 
+--R                                       2
+--R                           - 803340288a  - 679477248a - 254803968
+--R                      *
+--R                         %%BN0 %%BN1
+--R                     + 
+--R                                  9          8           7            6
+--R                           - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                         + 
+--R                                       5             4             3
+--R                           - 107280384a  - 365709312a  - 828997632a
+--R                         + 
+--R                                        2
+--R                           - 1205010432a  - 1019215872a - 382205952
+--R                      *
+--R                              2
+--R                         %%BN0
+--R                     + 
+--R                           4        3         2
+--R                       144a  + 2529a  + 16074a  + 44325a + 45072
+--R                  /
+--R                            9         8          7           6            5
+--R                       2048a  + 63488a  + 872448a  + 6975488a  + 35760128a
+--R                     + 
+--R                                 4             3             2
+--R                       121903104a  + 276332544a  + 401670144a  + 339738624a
+--R                     + 
+--R                       127401984
+--R            + 
+--R                                20               19                18
+--R                      234881024a   + 15708717056a   + 496152608768a
+--R                    + 
+--R                                    17                   16
+--R                      9831788314624a   + 136940015845376a
+--R                    + 
+--R                                       15                     14
+--R                      1423058097143808a   + 11426991446163456a
+--R                    + 
+--R                                        13                      12
+--R                      72420208802791424a   + 366596577386561536a
+--R                    + 
+--R                                          11                       10
+--R                      1488970734852112384a   + 4838598686558650368a
+--R                    + 
+--R                                           9                        8
+--R                      12425210726207979520a  + 24492354465884536832a
+--R                    + 
+--R                                           7                        6
+--R                      34562341164971720704a  + 27460753621868609536a
+--R                    + 
+--R                                            5                        4
+--R                      - 9416711544462376960a  - 64383511022222180352a
+--R                    + 
+--R                                             3                        2
+--R                      - 98946912238272774144a  - 85288494643002998784a
+--R                    + 
+--R                      - 41854934312200175616a - 9196381225416130560
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                             17              16               15
+--R                  - 68321280a   - 3808296960a   - 99490332672a
+--R                + 
+--R                                  14                  13                   12
+--R                  - 1617150345216a   - 18307181641728a   - 153077802860544a
+--R                + 
+--R                                    11                    10
+--R                  - 978169828343808a   - 4873947387789312a
+--R                + 
+--R                                      9                     8
+--R                  - 19145920722665472a  - 59525244286795776a
+--R                + 
+--R                                       7                      6
+--R                  - 146118386094440448a  - 280630860186648576a
+--R                + 
+--R                                       5                      4
+--R                  - 414449290539171840a  - 457219727249375232a
+--R                + 
+--R                                       3                      2
+--R                  - 359127846104334336a  - 184613707362336768a
+--R                + 
+--R                  - 52407721374253056a - 5131760069246976
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                                20               19                18
+--R                      234881024a   + 15708717056a   + 496152608768a
+--R                    + 
+--R                                    17                   16
+--R                      9831788314624a   + 136940015845376a
+--R                    + 
+--R                                       15                     14
+--R                      1423058097143808a   + 11426991446163456a
+--R                    + 
+--R                                        13                      12
+--R                      72420208802791424a   + 366596577386561536a
+--R                    + 
+--R                                          11                       10
+--R                      1488970734852112384a   + 4838598686558650368a
+--R                    + 
+--R                                           9                        8
+--R                      12425210726207979520a  + 24492354465884536832a
+--R                    + 
+--R                                           7                        6
+--R                      34562341164971720704a  + 27460753621868609536a
+--R                    + 
+--R                                            5                        4
+--R                      - 9416711544462376960a  - 64383511022222180352a
+--R                    + 
+--R                                             3                        2
+--R                      - 98946912238272774144a  - 85288494643002998784a
+--R                    + 
+--R                      - 41854934312200175616a - 9196381225416130560
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                            15             14              13               12
+--R                  - 2064384a   - 102845376a   - 2407788288a   - 35173137600a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 358820305920a   - 2709351482688a   - 15647114329344a
+--R                + 
+--R                                   8                   7                   6
+--R                  - 70381874875968a  - 248533968955392a  - 688612316857344a
+--R                + 
+--R                                     5                    4                    3
+--R                  - 1483679290355712a  - 2439030084747264a  - 2958346595598336a
+--R                + 
+--R                                     2
+--R                  - 2496835484909568a  - 1309881714868224a - 321701220974592
+--R             *
+--R                %%BN1
+--R            + 
+--R                             17              16               15
+--R                  - 68321280a   - 3808296960a   - 99490332672a
+--R                + 
+--R                                  14                  13                   12
+--R                  - 1617150345216a   - 18307181641728a   - 153077802860544a
+--R                + 
+--R                                    11                    10
+--R                  - 978169828343808a   - 4873947387789312a
+--R                + 
+--R                                      9                     8
+--R                  - 19145920722665472a  - 59525244286795776a
+--R                + 
+--R                                       7                      6
+--R                  - 146118386094440448a  - 280630860186648576a
+--R                + 
+--R                                       5                      4
+--R                  - 414449290539171840a  - 457219727249375232a
+--R                + 
+--R                                       3                      2
+--R                  - 359127846104334336a  - 184613707362336768a
+--R                + 
+--R                  - 52407721374253056a - 5131760069246976
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                            15             14              13               12
+--R                  - 2064384a   - 102845376a   - 2407788288a   - 35173137600a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 358820305920a   - 2709351482688a   - 15647114329344a
+--R                + 
+--R                                   8                   7                   6
+--R                  - 70381874875968a  - 248533968955392a  - 688612316857344a
+--R                + 
+--R                                     5                    4                    3
+--R                  - 1483679290355712a  - 2439030084747264a  - 2958346595598336a
+--R                + 
+--R                                     2
+--R                  - 2496835484909568a  - 1309881714868224a - 321701220974592
+--R             *
+--R                %%BN0
+--R            + 
+--R                          12            11             10              9
+--R                  1354752a   + 44550027a   + 663517980a   + 5951170602a
+--R                + 
+--R                              8                7                6
+--R                  36270700668a  + 162289912419a  + 567868212432a
+--R                + 
+--R                                5                 4                 3
+--R                  1626099007104a  + 3825839091456a  + 7035734732544a
+--R                + 
+--R                                2
+--R                  9216760449024a  + 7467334520832a + 2773884911616
+--R             *
+--R                x
+--R            + 
+--R                        12            11             10              9
+--R              - 1339200a   - 39712275a   - 495782964a   - 3189902202a
+--R            + 
+--R                           8               7                6                 5
+--R              - 8686407276a  + 22247807733a  + 298217053944a  + 1280770679808a
+--R            + 
+--R                            4                 3                 2
+--R              3147806126592a  + 4679916891264a  + 3907698508800a
+--R            + 
+--R              1355312093184a - 77935509504
+--R     + 
+--R               4       3        2                 8
+--R           (32a  + 448a  + 2336a  + 5376a + 4608)x
+--R         + 
+--R                  4        3         2                   7
+--R           (- 256a  - 3584a  - 18688a  - 43008a - 36864)x
+--R         + 
+--R                 4         3         2                     6
+--R           (1024a  + 14336a  + 74752a  + 172032a + 147456)x
+--R         + 
+--R                   4         3          2                     5
+--R           (- 2560a  - 35840a  - 186880a  - 430080a - 368640)x
+--R         + 
+--R                 5        4         3          2                     4
+--R           (- 64a  + 3200a  + 52672a  + 288256a  + 678912a + 589824)x
+--R         + 
+--R                5       4         3          2                     3
+--R           (256a  - 512a  - 38656a  - 256000a  - 651264a - 589824)x
+--R         + 
+--R                  5        4        3         2                     2
+--R           (- 512a  - 5120a  - 8704a  + 63488a  + 270336a + 294912)x
+--R         + 
+--R                5        4         3         2                 6       5
+--R           (512a  + 7168a  + 37376a  + 86016a  + 73728a)x + 32a  + 448a
+--R         + 
+--R                4        3        2
+--R           2336a  + 5376a  + 4608a
+--R      *
+--R         %%BN1
+--R      *
+--R         log
+--R                                  20               19                18
+--R                      - 469762048a   - 31417434112a   - 992305217536a
+--R                    + 
+--R                                       17                   16
+--R                      - 19663576629248a   - 273880031690752a
+--R                    + 
+--R                                         15                     14
+--R                      - 2846116194287616a   - 22853982892326912a
+--R                    + 
+--R                                           13                      12
+--R                      - 144840417605582848a   - 733193154773123072a
+--R                    + 
+--R                                            11                       10
+--R                      - 2977941469704224768a   - 9677197373117300736a
+--R                    + 
+--R                                             9                        8
+--R                      - 24850421452415959040a  - 48984708931769073664a
+--R                    + 
+--R                                             7                        6
+--R                      - 69124682329943441408a  - 54921507243737219072a
+--R                    + 
+--R                                           5                         4
+--R                      18833423088924753920a  + 128767022044444360704a
+--R                    + 
+--R                                            3                         2
+--R                      197893824476545548288a  + 170576989286005997568a
+--R                    + 
+--R                      83709868624400351232a + 18392762450832261120
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                            17              16                15
+--R                  136642560a   + 7616593920a   + 198980665344a
+--R                + 
+--R                                14                  13                   12
+--R                  3234300690432a   + 36614363283456a   + 306155605721088a
+--R                + 
+--R                                   11                    10
+--R                  1956339656687616a   + 9747894775578624a
+--R                + 
+--R                                    9                      8
+--R                  38291841445330944a  + 119050488573591552a
+--R                + 
+--R                                     7                      6
+--R                  292236772188880896a  + 561261720373297152a
+--R                + 
+--R                                     5                      4
+--R                  828898581078343680a  + 914439454498750464a
+--R                + 
+--R                                     3                      2
+--R                  718255692208668672a  + 369227414724673536a
+--R                + 
+--R                  104815442748506112a + 10263520138493952
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                                  20               19                18
+--R                      - 469762048a   - 31417434112a   - 992305217536a
+--R                    + 
+--R                                       17                   16
+--R                      - 19663576629248a   - 273880031690752a
+--R                    + 
+--R                                         15                     14
+--R                      - 2846116194287616a   - 22853982892326912a
+--R                    + 
+--R                                           13                      12
+--R                      - 144840417605582848a   - 733193154773123072a
+--R                    + 
+--R                                            11                       10
+--R                      - 2977941469704224768a   - 9677197373117300736a
+--R                    + 
+--R                                             9                        8
+--R                      - 24850421452415959040a  - 48984708931769073664a
+--R                    + 
+--R                                             7                        6
+--R                      - 69124682329943441408a  - 54921507243737219072a
+--R                    + 
+--R                                           5                         4
+--R                      18833423088924753920a  + 128767022044444360704a
+--R                    + 
+--R                                            3                         2
+--R                      197893824476545548288a  + 170576989286005997568a
+--R                    + 
+--R                      83709868624400351232a + 18392762450832261120
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                          15             14              13               12
+--R                  4128768a   + 205690752a   + 4815576576a   + 70346275200a
+--R                + 
+--R                               11                 10                  9
+--R                  717640611840a   + 5418702965376a   + 31294228658688a
+--R                + 
+--R                                  8                   7                    6
+--R                  140763749751936a  + 497067937910784a  + 1377224633714688a
+--R                + 
+--R                                   5                    4                    3
+--R                  2967358580711424a  + 4878060169494528a  + 5916693191196672a
+--R                + 
+--R                                   2
+--R                  4993670969819136a  + 2619763429736448a + 643402441949184
+--R             *
+--R                %%BN1
+--R            + 
+--R                              20               19                18
+--R                  - 469762048a   - 31417434112a   - 992305217536a
+--R                + 
+--R                                   17                   16                    15
+--R                  - 19663576629248a   - 273880031690752a   - 2846116194287616a
+--R                + 
+--R                                      14                      13
+--R                  - 22853982892326912a   - 144840417605582848a
+--R                + 
+--R                                       12                       11
+--R                  - 733193154773123072a   - 2977941469704224768a
+--R                + 
+--R                                        10                        9
+--R                  - 9677197373117300736a   - 24850421452415959040a
+--R                + 
+--R                                         8                        7
+--R                  - 48984708931769073664a  - 69124682329943441408a
+--R                + 
+--R                                         6                        5
+--R                  - 54921507243737219072a  + 18833423088924753920a
+--R                + 
+--R                                        4                         3
+--R                  128767022044444360704a  + 197893824476545548288a
+--R                + 
+--R                                        2
+--R                  170576989286005997568a  + 83709868624400351232a
+--R                + 
+--R                  18392762450832261120
+--R             *
+--R                     3
+--R                %%BN0
+--R            + 
+--R                          15             14               13                12
+--R                  8257536a   + 441298944a   + 10865693952a   + 163221845760a
+--R                + 
+--R                                11                  10                  9
+--R                  1668479574528a   + 12244561362432a   + 66227055393024a
+--R                + 
+--R                                  8                   7                    6
+--R                  266026528316160a  + 785057799315456a  + 1634909318737920a
+--R                + 
+--R                                   5                   4                    3
+--R                  2131094791766016a  + 875627754356736a  - 2492761086885888a
+--R                + 
+--R                                     2
+--R                  - 5377669293146112a  - 4665483643060224a - 1626737989386240
+--R             *
+--R                %%BN0
+--R            + 
+--R                          12            11             10              9
+--R                  1354752a   + 44550027a   + 663517980a   + 5951170602a
+--R                + 
+--R                              8                7                6
+--R                  36270700668a  + 162289912419a  + 567868212432a
+--R                + 
+--R                                5                 4                 3
+--R                  1626099007104a  + 3825839091456a  + 7035734732544a
+--R                + 
+--R                                2
+--R                  9216760449024a  + 7467334520832a + 2773884911616
+--R             *
+--R                x
+--R            + 
+--R                        12             11              10               9
+--R              - 3741120a   - 141321915a   - 2439850572a   - 25422884586a
+--R            + 
+--R                             8                7                 6
+--R              - 177755396508a  - 876521764755a  - 3115301128128a
+--R            + 
+--R                              5                  4                  3
+--R              - 8002632319200a  - 14638310274816a  - 18370117132416a
+--R            + 
+--R                               2
+--R              - 14680566199296a  - 6387069597696a - 985687031808
+--R     + 
+--R               4       3        2                 8
+--R           (32a  + 448a  + 2336a  + 5376a + 4608)x
+--R         + 
+--R                  4        3         2                   7
+--R           (- 256a  - 3584a  - 18688a  - 43008a - 36864)x
+--R         + 
+--R                 4         3         2                     6
+--R           (1024a  + 14336a  + 74752a  + 172032a + 147456)x
+--R         + 
+--R                   4         3          2                     5
+--R           (- 2560a  - 35840a  - 186880a  - 430080a - 368640)x
+--R         + 
+--R                 5        4         3          2                     4
+--R           (- 64a  + 3200a  + 52672a  + 288256a  + 678912a + 589824)x
+--R         + 
+--R                5       4         3          2                     3
+--R           (256a  - 512a  - 38656a  - 256000a  - 651264a - 589824)x
+--R         + 
+--R                  5        4        3         2                     2
+--R           (- 512a  - 5120a  - 8704a  + 63488a  + 270336a + 294912)x
+--R         + 
+--R                5        4         3         2                 6       5
+--R           (512a  + 7168a  + 37376a  + 86016a  + 73728a)x + 32a  + 448a
+--R         + 
+--R                4        3        2
+--R           2336a  + 5376a  + 4608a
+--R      *
+--R         %%BN0
+--R      *
+--R         log
+--R                            20               19                18
+--R                  469762048a   + 31417434112a   + 992305217536a
+--R                + 
+--R                                 17                   16                    15
+--R                  19663576629248a   + 273880031690752a   + 2846116194287616a
+--R                + 
+--R                                    14                      13
+--R                  22853982892326912a   + 144840417605582848a
+--R                + 
+--R                                     12                       11
+--R                  733193154773123072a   + 2977941469704224768a
+--R                + 
+--R                                      10                        9
+--R                  9677197373117300736a   + 24850421452415959040a
+--R                + 
+--R                                       8                        7
+--R                  48984708931769073664a  + 69124682329943441408a
+--R                + 
+--R                                       6                        5
+--R                  54921507243737219072a  - 18833423088924753920a
+--R                + 
+--R                                          4                         3
+--R                  - 128767022044444360704a  - 197893824476545548288a
+--R                + 
+--R                                          2
+--R                  - 170576989286005997568a  - 83709868624400351232a
+--R                + 
+--R                  - 18392762450832261120
+--R             *
+--R                     3
+--R                %%BN0
+--R            + 
+--R                            17              16                15
+--R                  136642560a   + 7616593920a   + 198980665344a
+--R                + 
+--R                                14                  13                   12
+--R                  3234300690432a   + 36614363283456a   + 306155605721088a
+--R                + 
+--R                                   11                    10
+--R                  1956339656687616a   + 9747894775578624a
+--R                + 
+--R                                    9                      8
+--R                  38291841445330944a  + 119050488573591552a
+--R                + 
+--R                                     7                      6
+--R                  292236772188880896a  + 561261720373297152a
+--R                + 
+--R                                     5                      4
+--R                  828898581078343680a  + 914439454498750464a
+--R                + 
+--R                                     3                      2
+--R                  718255692208668672a  + 369227414724673536a
+--R                + 
+--R                  104815442748506112a + 10263520138493952
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                            15             14              13               12
+--R                  - 4128768a   - 235608192a   - 6050117376a   - 92875570560a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 950838962688a   - 6825858397056a   - 34932826734336a
+--R                + 
+--R                                    8                   7                   6
+--R                  - 125262778564224a  - 287989861404672a  - 257684685023232a
+--R                + 
+--R                                  5                    4                    3
+--R                  836263788945408a  + 4002432415137792a  + 8409454278082560a
+--R                + 
+--R                                    2
+--R                  10371340262965248a  + 7285247072796672a + 2270140431335424
+--R             *
+--R                %%BN0
+--R            + 
+--R                          12            11             10              9
+--R                  1354752a   + 44550027a   + 663517980a   + 5951170602a
+--R                + 
+--R                              8                7                6
+--R                  36270700668a  + 162289912419a  + 567868212432a
+--R                + 
+--R                                5                 4                 3
+--R                  1626099007104a  + 3825839091456a  + 7035734732544a
+--R                + 
+--R                                2
+--R                  9216760449024a  + 7467334520832a + 2773884911616
+--R             *
+--R                x
+--R            + 
+--R                      12            11             10              9
+--R              1000512a   + 42546357a   + 777344580a   + 7998006582a
+--R            + 
+--R                          8                7                6                 5
+--R              50045408388a  + 182866499613a  + 247394170512a  - 1063305068832a
+--R            + 
+--R                              4                  3                  2
+--R              - 6960658344192a  - 19132655580288a  - 30001872614400a
+--R            + 
+--R              - 26192892672000a - 9953981595648
+--R     + 
+--R                    7        2              6       2               5
+--R       (- 12a - 42)x  + (- 6a  + 48a + 240)x  + (29a  - 127a - 792)x
+--R     + 
+--R             2                4        2                3
+--R       (- 73a  + 227a + 1668)x  + (124a  - 206a - 2208)x
+--R     + 
+--R           3      2                2        3      2                    3      2
+--R       (10a  - 52a  + 280a + 2016)x  + (- 9a  + 51a  + 120a - 576)x + 9a  + 21a
+--R     + 
+--R       - 36a
+--R  /
+--R           4       3        2                 8
+--R       (32a  + 448a  + 2336a  + 5376a + 4608)x
+--R     + 
+--R              4        3         2                   7
+--R       (- 256a  - 3584a  - 18688a  - 43008a - 36864)x
+--R     + 
+--R             4         3         2                     6
+--R       (1024a  + 14336a  + 74752a  + 172032a + 147456)x
+--R     + 
+--R               4         3          2                     5
+--R       (- 2560a  - 35840a  - 186880a  - 430080a - 368640)x
+--R     + 
+--R             5        4         3          2                     4
+--R       (- 64a  + 3200a  + 52672a  + 288256a  + 678912a + 589824)x
+--R     + 
+--R            5       4         3          2                     3
+--R       (256a  - 512a  - 38656a  - 256000a  - 651264a - 589824)x
+--R     + 
+--R              5        4        3         2                     2
+--R       (- 512a  - 5120a  - 8704a  + 63488a  + 270336a + 294912)x
+--R     + 
+--R            5        4         3         2                 6       5        4
+--R       (512a  + 7168a  + 37376a  + 86016a  + 73728a)x + 32a  + 448a  + 2336a
+--R     + 
+--R            3        2
+--R       5376a  + 4608a
+--R                                         Type: Union(Expression(Integer),...)
+--E 302
+
+--S 303 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                            +--------------+
+--R                 4       3        2                 +-----+ |   +-----+
+--R             (32a  + 448a  + 2336a  + 5376a + 4608)\|a + 4 \|- \|a + 4  + 1
+--R          *
+--R              +------------+
+--R              | +-----+
+--R             \|\|a + 4  + 1
+--R          *
+--R             ROOT
+--R                               9          8           7            6
+--R                        - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                      + 
+--R                                    5             4             3              2
+--R                        - 107280384a  - 365709312a  - 828997632a  - 1205010432a
+--R                      + 
+--R                        - 1019215872a - 382205952
+--R                   *
+--R                           2
+--R                      %%BN1
+--R                  + 
+--R                               9          8           7            6
+--R                        - 4096a  - 126976a  - 1744896a  - 13950976a
+--R                      + 
+--R                                   5             4             3             2
+--R                        - 71520256a  - 243806208a  - 552665088a  - 803340288a
+--R                      + 
+--R                        - 679477248a - 254803968
+--R                   *
+--R                      %%BN0 %%BN1
+--R                  + 
+--R                               9          8           7            6
+--R                        - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                      + 
+--R                                    5             4             3              2
+--R                        - 107280384a  - 365709312a  - 828997632a  - 1205010432a
+--R                      + 
+--R                        - 1019215872a - 382205952
+--R                   *
+--R                           2
+--R                      %%BN0
+--R                  + 
+--R                        4        3         2
+--R                    144a  + 2529a  + 16074a  + 44325a + 45072
+--R               /
+--R                         9         8          7           6            5
+--R                    2048a  + 63488a  + 872448a  + 6975488a  + 35760128a
+--R                  + 
+--R                              4             3             2
+--R                    121903104a  + 276332544a  + 401670144a  + 339738624a
+--R                  + 
+--R                    127401984
+--R         + 
+--R                                                              +--------------+
+--R                   4       3        2                 +-----+ |   +-----+
+--R             (- 32a  - 448a  - 2336a  - 5376a - 4608)\|a + 4 \|- \|a + 4  + 1
+--R          *
+--R              +------------+
+--R              | +-----+
+--R             \|\|a + 4  + 1 %%BN1
+--R         + 
+--R                   4       3        2                 +-----+
+--R             (- 32a  - 448a  - 2336a  - 5376a - 4608)\|a + 4 %%BN0
+--R          *
+--R              +--------------+ +------------+
+--R              |   +-----+      | +-----+
+--R             \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R      *
+--R         log
+--R                                    20               19                18
+--R                          234881024a   + 15708717056a   + 496152608768a
+--R                        + 
+--R                                        17                   16
+--R                          9831788314624a   + 136940015845376a
+--R                        + 
+--R                                           15                     14
+--R                          1423058097143808a   + 11426991446163456a
+--R                        + 
+--R                                            13                      12
+--R                          72420208802791424a   + 366596577386561536a
+--R                        + 
+--R                                              11                       10
+--R                          1488970734852112384a   + 4838598686558650368a
+--R                        + 
+--R                                               9                        8
+--R                          12425210726207979520a  + 24492354465884536832a
+--R                        + 
+--R                                               7                        6
+--R                          34562341164971720704a  + 27460753621868609536a
+--R                        + 
+--R                                                5                        4
+--R                          - 9416711544462376960a  - 64383511022222180352a
+--R                        + 
+--R                                                 3                        2
+--R                          - 98946912238272774144a  - 85288494643002998784a
+--R                        + 
+--R                          - 41854934312200175616a - 9196381225416130560
+--R                     *
+--R                        %%BN0
+--R                    + 
+--R                                 17              16               15
+--R                      - 68321280a   - 3808296960a   - 99490332672a
+--R                    + 
+--R                                      14                  13
+--R                      - 1617150345216a   - 18307181641728a
+--R                    + 
+--R                                        12                   11
+--R                      - 153077802860544a   - 978169828343808a
+--R                    + 
+--R                                         10                     9
+--R                      - 4873947387789312a   - 19145920722665472a
+--R                    + 
+--R                                          8                      7
+--R                      - 59525244286795776a  - 146118386094440448a
+--R                    + 
+--R                                           6                      5
+--R                      - 280630860186648576a  - 414449290539171840a
+--R                    + 
+--R                                           4                      3
+--R                      - 457219727249375232a  - 359127846104334336a
+--R                    + 
+--R                                           2
+--R                      - 184613707362336768a  - 52407721374253056a
+--R                    + 
+--R                      - 5131760069246976
+--R                 *
+--R                    %%BN1
+--R                + 
+--R                                 17              16               15
+--R                      - 68321280a   - 3808296960a   - 99490332672a
+--R                    + 
+--R                                      14                  13
+--R                      - 1617150345216a   - 18307181641728a
+--R                    + 
+--R                                        12                   11
+--R                      - 153077802860544a   - 978169828343808a
+--R                    + 
+--R                                         10                     9
+--R                      - 4873947387789312a   - 19145920722665472a
+--R                    + 
+--R                                          8                      7
+--R                      - 59525244286795776a  - 146118386094440448a
+--R                    + 
+--R                                           6                      5
+--R                      - 280630860186648576a  - 414449290539171840a
+--R                    + 
+--R                                           4                      3
+--R                      - 457219727249375232a  - 359127846104334336a
+--R                    + 
+--R                                           2
+--R                      - 184613707362336768a  - 52407721374253056a
+--R                    + 
+--R                      - 5131760069246976
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                          15             14              13               12
+--R                  2064384a   + 102845376a   + 2407788288a   + 35173137600a
+--R                + 
+--R                               11                 10                  9
+--R                  358820305920a   + 2709351482688a   + 15647114329344a
+--R                + 
+--R                                 8                   7                   6
+--R                  70381874875968a  + 248533968955392a  + 688612316857344a
+--R                + 
+--R                                   5                    4                    3
+--R                  1483679290355712a  + 2439030084747264a  + 2958346595598336a
+--R                + 
+--R                                   2
+--R                  2496835484909568a  + 1309881714868224a + 321701220974592
+--R             *
+--R                ROOT
+--R                                  9          8           7            6
+--R                           - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                         + 
+--R                                       5             4             3
+--R                           - 107280384a  - 365709312a  - 828997632a
+--R                         + 
+--R                                        2
+--R                           - 1205010432a  - 1019215872a - 382205952
+--R                      *
+--R                              2
+--R                         %%BN1
+--R                     + 
+--R                                  9          8           7            6
+--R                           - 4096a  - 126976a  - 1744896a  - 13950976a
+--R                         + 
+--R                                      5             4             3
+--R                           - 71520256a  - 243806208a  - 552665088a
+--R                         + 
+--R                                       2
+--R                           - 803340288a  - 679477248a - 254803968
+--R                      *
+--R                         %%BN0 %%BN1
+--R                     + 
+--R                                  9          8           7            6
+--R                           - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                         + 
+--R                                       5             4             3
+--R                           - 107280384a  - 365709312a  - 828997632a
+--R                         + 
+--R                                        2
+--R                           - 1205010432a  - 1019215872a - 382205952
+--R                      *
+--R                              2
+--R                         %%BN0
+--R                     + 
+--R                           4        3         2
+--R                       144a  + 2529a  + 16074a  + 44325a + 45072
+--R                  /
+--R                            9         8          7           6            5
+--R                       2048a  + 63488a  + 872448a  + 6975488a  + 35760128a
+--R                     + 
+--R                                 4             3             2
+--R                       121903104a  + 276332544a  + 401670144a  + 339738624a
+--R                     + 
+--R                       127401984
+--R            + 
+--R                                20               19                18
+--R                      234881024a   + 15708717056a   + 496152608768a
+--R                    + 
+--R                                    17                   16
+--R                      9831788314624a   + 136940015845376a
+--R                    + 
+--R                                       15                     14
+--R                      1423058097143808a   + 11426991446163456a
+--R                    + 
+--R                                        13                      12
+--R                      72420208802791424a   + 366596577386561536a
+--R                    + 
+--R                                          11                       10
+--R                      1488970734852112384a   + 4838598686558650368a
+--R                    + 
+--R                                           9                        8
+--R                      12425210726207979520a  + 24492354465884536832a
+--R                    + 
+--R                                           7                        6
+--R                      34562341164971720704a  + 27460753621868609536a
+--R                    + 
+--R                                            5                        4
+--R                      - 9416711544462376960a  - 64383511022222180352a
+--R                    + 
+--R                                             3                        2
+--R                      - 98946912238272774144a  - 85288494643002998784a
+--R                    + 
+--R                      - 41854934312200175616a - 9196381225416130560
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                             17              16               15
+--R                  - 68321280a   - 3808296960a   - 99490332672a
+--R                + 
+--R                                  14                  13                   12
+--R                  - 1617150345216a   - 18307181641728a   - 153077802860544a
+--R                + 
+--R                                    11                    10
+--R                  - 978169828343808a   - 4873947387789312a
+--R                + 
+--R                                      9                     8
+--R                  - 19145920722665472a  - 59525244286795776a
+--R                + 
+--R                                       7                      6
+--R                  - 146118386094440448a  - 280630860186648576a
+--R                + 
+--R                                       5                      4
+--R                  - 414449290539171840a  - 457219727249375232a
+--R                + 
+--R                                       3                      2
+--R                  - 359127846104334336a  - 184613707362336768a
+--R                + 
+--R                  - 52407721374253056a - 5131760069246976
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                                20               19                18
+--R                      234881024a   + 15708717056a   + 496152608768a
+--R                    + 
+--R                                    17                   16
+--R                      9831788314624a   + 136940015845376a
+--R                    + 
+--R                                       15                     14
+--R                      1423058097143808a   + 11426991446163456a
+--R                    + 
+--R                                        13                      12
+--R                      72420208802791424a   + 366596577386561536a
+--R                    + 
+--R                                          11                       10
+--R                      1488970734852112384a   + 4838598686558650368a
+--R                    + 
+--R                                           9                        8
+--R                      12425210726207979520a  + 24492354465884536832a
+--R                    + 
+--R                                           7                        6
+--R                      34562341164971720704a  + 27460753621868609536a
+--R                    + 
+--R                                            5                        4
+--R                      - 9416711544462376960a  - 64383511022222180352a
+--R                    + 
+--R                                             3                        2
+--R                      - 98946912238272774144a  - 85288494643002998784a
+--R                    + 
+--R                      - 41854934312200175616a - 9196381225416130560
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                            15             14              13               12
+--R                  - 2064384a   - 102845376a   - 2407788288a   - 35173137600a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 358820305920a   - 2709351482688a   - 15647114329344a
+--R                + 
+--R                                   8                   7                   6
+--R                  - 70381874875968a  - 248533968955392a  - 688612316857344a
+--R                + 
+--R                                     5                    4                    3
+--R                  - 1483679290355712a  - 2439030084747264a  - 2958346595598336a
+--R                + 
+--R                                     2
+--R                  - 2496835484909568a  - 1309881714868224a - 321701220974592
+--R             *
+--R                %%BN1
+--R            + 
+--R                             17              16               15
+--R                  - 68321280a   - 3808296960a   - 99490332672a
+--R                + 
+--R                                  14                  13                   12
+--R                  - 1617150345216a   - 18307181641728a   - 153077802860544a
+--R                + 
+--R                                    11                    10
+--R                  - 978169828343808a   - 4873947387789312a
+--R                + 
+--R                                      9                     8
+--R                  - 19145920722665472a  - 59525244286795776a
+--R                + 
+--R                                       7                      6
+--R                  - 146118386094440448a  - 280630860186648576a
+--R                + 
+--R                                       5                      4
+--R                  - 414449290539171840a  - 457219727249375232a
+--R                + 
+--R                                       3                      2
+--R                  - 359127846104334336a  - 184613707362336768a
+--R                + 
+--R                  - 52407721374253056a - 5131760069246976
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                            15             14              13               12
+--R                  - 2064384a   - 102845376a   - 2407788288a   - 35173137600a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 358820305920a   - 2709351482688a   - 15647114329344a
+--R                + 
+--R                                   8                   7                   6
+--R                  - 70381874875968a  - 248533968955392a  - 688612316857344a
+--R                + 
+--R                                     5                    4                    3
+--R                  - 1483679290355712a  - 2439030084747264a  - 2958346595598336a
+--R                + 
+--R                                     2
+--R                  - 2496835484909568a  - 1309881714868224a - 321701220974592
+--R             *
+--R                %%BN0
+--R            + 
+--R                          12            11             10              9
+--R                  1354752a   + 44550027a   + 663517980a   + 5951170602a
+--R                + 
+--R                              8                7                6
+--R                  36270700668a  + 162289912419a  + 567868212432a
+--R                + 
+--R                                5                 4                 3
+--R                  1626099007104a  + 3825839091456a  + 7035734732544a
+--R                + 
+--R                                2
+--R                  9216760449024a  + 7467334520832a + 2773884911616
+--R             *
+--R                x
+--R            + 
+--R                        12            11             10              9
+--R              - 1339200a   - 39712275a   - 495782964a   - 3189902202a
+--R            + 
+--R                           8               7                6                 5
+--R              - 8686407276a  + 22247807733a  + 298217053944a  + 1280770679808a
+--R            + 
+--R                            4                 3                 2
+--R              3147806126592a  + 4679916891264a  + 3907698508800a
+--R            + 
+--R              1355312093184a - 77935509504
+--R     + 
+--R                                                              +--------------+
+--R                   4       3        2                 +-----+ |   +-----+
+--R             (- 32a  - 448a  - 2336a  - 5376a - 4608)\|a + 4 \|- \|a + 4  + 1
+--R          *
+--R              +------------+
+--R              | +-----+
+--R             \|\|a + 4  + 1
+--R          *
+--R             ROOT
+--R                               9          8           7            6
+--R                        - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                      + 
+--R                                    5             4             3              2
+--R                        - 107280384a  - 365709312a  - 828997632a  - 1205010432a
+--R                      + 
+--R                        - 1019215872a - 382205952
+--R                   *
+--R                           2
+--R                      %%BN1
+--R                  + 
+--R                               9          8           7            6
+--R                        - 4096a  - 126976a  - 1744896a  - 13950976a
+--R                      + 
+--R                                   5             4             3             2
+--R                        - 71520256a  - 243806208a  - 552665088a  - 803340288a
+--R                      + 
+--R                        - 679477248a - 254803968
+--R                   *
+--R                      %%BN0 %%BN1
+--R                  + 
+--R                               9          8           7            6
+--R                        - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                      + 
+--R                                    5             4             3              2
+--R                        - 107280384a  - 365709312a  - 828997632a  - 1205010432a
+--R                      + 
+--R                        - 1019215872a - 382205952
+--R                   *
+--R                           2
+--R                      %%BN0
+--R                  + 
+--R                        4        3         2
+--R                    144a  + 2529a  + 16074a  + 44325a + 45072
+--R               /
+--R                         9         8          7           6            5
+--R                    2048a  + 63488a  + 872448a  + 6975488a  + 35760128a
+--R                  + 
+--R                              4             3             2
+--R                    121903104a  + 276332544a  + 401670144a  + 339738624a
+--R                  + 
+--R                    127401984
+--R         + 
+--R                                                              +--------------+
+--R                   4       3        2                 +-----+ |   +-----+
+--R             (- 32a  - 448a  - 2336a  - 5376a - 4608)\|a + 4 \|- \|a + 4  + 1
+--R          *
+--R              +------------+
+--R              | +-----+
+--R             \|\|a + 4  + 1 %%BN1
+--R         + 
+--R                   4       3        2                 +-----+
+--R             (- 32a  - 448a  - 2336a  - 5376a - 4608)\|a + 4 %%BN0
+--R          *
+--R              +--------------+ +------------+
+--R              |   +-----+      | +-----+
+--R             \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R      *
+--R         log
+--R                                      20               19                18
+--R                          - 234881024a   - 15708717056a   - 496152608768a
+--R                        + 
+--R                                          17                   16
+--R                          - 9831788314624a   - 136940015845376a
+--R                        + 
+--R                                             15                     14
+--R                          - 1423058097143808a   - 11426991446163456a
+--R                        + 
+--R                                              13                      12
+--R                          - 72420208802791424a   - 366596577386561536a
+--R                        + 
+--R                                                11                       10
+--R                          - 1488970734852112384a   - 4838598686558650368a
+--R                        + 
+--R                                                 9                        8
+--R                          - 12425210726207979520a  - 24492354465884536832a
+--R                        + 
+--R                                                 7                        6
+--R                          - 34562341164971720704a  - 27460753621868609536a
+--R                        + 
+--R                                              5                        4
+--R                          9416711544462376960a  + 64383511022222180352a
+--R                        + 
+--R                                               3                        2
+--R                          98946912238272774144a  + 85288494643002998784a
+--R                        + 
+--R                          41854934312200175616a + 9196381225416130560
+--R                     *
+--R                        %%BN0
+--R                    + 
+--R                               17              16               15
+--R                      68321280a   + 3808296960a   + 99490332672a
+--R                    + 
+--R                                    14                  13                   12
+--R                      1617150345216a   + 18307181641728a   + 153077802860544a
+--R                    + 
+--R                                      11                    10
+--R                      978169828343808a   + 4873947387789312a
+--R                    + 
+--R                                        9                     8
+--R                      19145920722665472a  + 59525244286795776a
+--R                    + 
+--R                                         7                      6
+--R                      146118386094440448a  + 280630860186648576a
+--R                    + 
+--R                                         5                      4
+--R                      414449290539171840a  + 457219727249375232a
+--R                    + 
+--R                                         3                      2
+--R                      359127846104334336a  + 184613707362336768a
+--R                    + 
+--R                      52407721374253056a + 5131760069246976
+--R                 *
+--R                    %%BN1
+--R                + 
+--R                               17              16               15
+--R                      68321280a   + 3808296960a   + 99490332672a
+--R                    + 
+--R                                    14                  13                   12
+--R                      1617150345216a   + 18307181641728a   + 153077802860544a
+--R                    + 
+--R                                      11                    10
+--R                      978169828343808a   + 4873947387789312a
+--R                    + 
+--R                                        9                     8
+--R                      19145920722665472a  + 59525244286795776a
+--R                    + 
+--R                                         7                      6
+--R                      146118386094440448a  + 280630860186648576a
+--R                    + 
+--R                                         5                      4
+--R                      414449290539171840a  + 457219727249375232a
+--R                    + 
+--R                                         3                      2
+--R                      359127846104334336a  + 184613707362336768a
+--R                    + 
+--R                      52407721374253056a + 5131760069246976
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                            15             14              13               12
+--R                  - 2064384a   - 102845376a   - 2407788288a   - 35173137600a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 358820305920a   - 2709351482688a   - 15647114329344a
+--R                + 
+--R                                   8                   7                   6
+--R                  - 70381874875968a  - 248533968955392a  - 688612316857344a
+--R                + 
+--R                                     5                    4                    3
+--R                  - 1483679290355712a  - 2439030084747264a  - 2958346595598336a
+--R                + 
+--R                                     2
+--R                  - 2496835484909568a  - 1309881714868224a - 321701220974592
+--R             *
+--R                ROOT
+--R                                  9          8           7            6
+--R                           - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                         + 
+--R                                       5             4             3
+--R                           - 107280384a  - 365709312a  - 828997632a
+--R                         + 
+--R                                        2
+--R                           - 1205010432a  - 1019215872a - 382205952
+--R                      *
+--R                              2
+--R                         %%BN1
+--R                     + 
+--R                                  9          8           7            6
+--R                           - 4096a  - 126976a  - 1744896a  - 13950976a
+--R                         + 
+--R                                      5             4             3
+--R                           - 71520256a  - 243806208a  - 552665088a
+--R                         + 
+--R                                       2
+--R                           - 803340288a  - 679477248a - 254803968
+--R                      *
+--R                         %%BN0 %%BN1
+--R                     + 
+--R                                  9          8           7            6
+--R                           - 6144a  - 190464a  - 2617344a  - 20926464a
+--R                         + 
+--R                                       5             4             3
+--R                           - 107280384a  - 365709312a  - 828997632a
+--R                         + 
+--R                                        2
+--R                           - 1205010432a  - 1019215872a - 382205952
+--R                      *
+--R                              2
+--R                         %%BN0
+--R                     + 
+--R                           4        3         2
+--R                       144a  + 2529a  + 16074a  + 44325a + 45072
+--R                  /
+--R                            9         8          7           6            5
+--R                       2048a  + 63488a  + 872448a  + 6975488a  + 35760128a
+--R                     + 
+--R                                 4             3             2
+--R                       121903104a  + 276332544a  + 401670144a  + 339738624a
+--R                     + 
+--R                       127401984
+--R            + 
+--R                                20               19                18
+--R                      234881024a   + 15708717056a   + 496152608768a
+--R                    + 
+--R                                    17                   16
+--R                      9831788314624a   + 136940015845376a
+--R                    + 
+--R                                       15                     14
+--R                      1423058097143808a   + 11426991446163456a
+--R                    + 
+--R                                        13                      12
+--R                      72420208802791424a   + 366596577386561536a
+--R                    + 
+--R                                          11                       10
+--R                      1488970734852112384a   + 4838598686558650368a
+--R                    + 
+--R                                           9                        8
+--R                      12425210726207979520a  + 24492354465884536832a
+--R                    + 
+--R                                           7                        6
+--R                      34562341164971720704a  + 27460753621868609536a
+--R                    + 
+--R                                            5                        4
+--R                      - 9416711544462376960a  - 64383511022222180352a
+--R                    + 
+--R                                             3                        2
+--R                      - 98946912238272774144a  - 85288494643002998784a
+--R                    + 
+--R                      - 41854934312200175616a - 9196381225416130560
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                             17              16               15
+--R                  - 68321280a   - 3808296960a   - 99490332672a
+--R                + 
+--R                                  14                  13                   12
+--R                  - 1617150345216a   - 18307181641728a   - 153077802860544a
+--R                + 
+--R                                    11                    10
+--R                  - 978169828343808a   - 4873947387789312a
+--R                + 
+--R                                      9                     8
+--R                  - 19145920722665472a  - 59525244286795776a
+--R                + 
+--R                                       7                      6
+--R                  - 146118386094440448a  - 280630860186648576a
+--R                + 
+--R                                       5                      4
+--R                  - 414449290539171840a  - 457219727249375232a
+--R                + 
+--R                                       3                      2
+--R                  - 359127846104334336a  - 184613707362336768a
+--R                + 
+--R                  - 52407721374253056a - 5131760069246976
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                                20               19                18
+--R                      234881024a   + 15708717056a   + 496152608768a
+--R                    + 
+--R                                    17                   16
+--R                      9831788314624a   + 136940015845376a
+--R                    + 
+--R                                       15                     14
+--R                      1423058097143808a   + 11426991446163456a
+--R                    + 
+--R                                        13                      12
+--R                      72420208802791424a   + 366596577386561536a
+--R                    + 
+--R                                          11                       10
+--R                      1488970734852112384a   + 4838598686558650368a
+--R                    + 
+--R                                           9                        8
+--R                      12425210726207979520a  + 24492354465884536832a
+--R                    + 
+--R                                           7                        6
+--R                      34562341164971720704a  + 27460753621868609536a
+--R                    + 
+--R                                            5                        4
+--R                      - 9416711544462376960a  - 64383511022222180352a
+--R                    + 
+--R                                             3                        2
+--R                      - 98946912238272774144a  - 85288494643002998784a
+--R                    + 
+--R                      - 41854934312200175616a - 9196381225416130560
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                            15             14              13               12
+--R                  - 2064384a   - 102845376a   - 2407788288a   - 35173137600a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 358820305920a   - 2709351482688a   - 15647114329344a
+--R                + 
+--R                                   8                   7                   6
+--R                  - 70381874875968a  - 248533968955392a  - 688612316857344a
+--R                + 
+--R                                     5                    4                    3
+--R                  - 1483679290355712a  - 2439030084747264a  - 2958346595598336a
+--R                + 
+--R                                     2
+--R                  - 2496835484909568a  - 1309881714868224a - 321701220974592
+--R             *
+--R                %%BN1
+--R            + 
+--R                             17              16               15
+--R                  - 68321280a   - 3808296960a   - 99490332672a
+--R                + 
+--R                                  14                  13                   12
+--R                  - 1617150345216a   - 18307181641728a   - 153077802860544a
+--R                + 
+--R                                    11                    10
+--R                  - 978169828343808a   - 4873947387789312a
+--R                + 
+--R                                      9                     8
+--R                  - 19145920722665472a  - 59525244286795776a
+--R                + 
+--R                                       7                      6
+--R                  - 146118386094440448a  - 280630860186648576a
+--R                + 
+--R                                       5                      4
+--R                  - 414449290539171840a  - 457219727249375232a
+--R                + 
+--R                                       3                      2
+--R                  - 359127846104334336a  - 184613707362336768a
+--R                + 
+--R                  - 52407721374253056a - 5131760069246976
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                            15             14              13               12
+--R                  - 2064384a   - 102845376a   - 2407788288a   - 35173137600a
+--R                + 
+--R                                 11                 10                  9
+--R                  - 358820305920a   - 2709351482688a   - 15647114329344a
+--R                + 
+--R                                   8                   7                   6
+--R                  - 70381874875968a  - 248533968955392a  - 688612316857344a
+--R                + 
+--R                                     5                    4                    3
+--R                  - 1483679290355712a  - 2439030084747264a  - 2958346595598336a
+--R                + 
+--R                                     2
+--R                  - 2496835484909568a  - 1309881714868224a - 321701220974592
+--R             *
+--R                %%BN0
+--R            + 
+--R                          12            11             10              9
+--R                  1354752a   + 44550027a   + 663517980a   + 5951170602a
+--R                + 
+--R                              8                7                6
+--R                  36270700668a  + 162289912419a  + 567868212432a
+--R                + 
+--R                                5                 4                 3
+--R                  1626099007104a  + 3825839091456a  + 7035734732544a
+--R                + 
+--R                                2
+--R                  9216760449024a  + 7467334520832a + 2773884911616
+--R             *
+--R                x
+--R            + 
+--R                        12            11             10              9
+--R              - 1339200a   - 39712275a   - 495782964a   - 3189902202a
+--R            + 
+--R                           8               7                6                 5
+--R              - 8686407276a  + 22247807733a  + 298217053944a  + 1280770679808a
+--R            + 
+--R                            4                 3                 2
+--R              3147806126592a  + 4679916891264a  + 3907698508800a
+--R            + 
+--R              1355312093184a - 77935509504
+--R     + 
+--R                                                         +--------------+
+--R             4       3        2                  +-----+ |   +-----+
+--R         (64a  + 896a  + 4672a  + 10752a + 9216)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1 %%BN1
+--R      *
+--R         log
+--R                                  20               19                18
+--R                      - 469762048a   - 31417434112a   - 992305217536a
+--R                    + 
+--R                                       17                   16
+--R                      - 19663576629248a   - 273880031690752a
+--R                    + 
+--R                                         15                     14
+--R                      - 2846116194287616a   - 22853982892326912a
+--R                    + 
+--R                                           13                      12
+--R                      - 144840417605582848a   - 733193154773123072a
+--R                    + 
+--R                                            11                       10
+--R                      - 2977941469704224768a   - 9677197373117300736a
+--R                    + 
+--R                                             9                        8
+--R                      - 24850421452415959040a  - 48984708931769073664a
+--R                    + 
+--R                                             7                        6
+--R                      - 69124682329943441408a  - 54921507243737219072a
+--R                    + 
+--R                                           5                         4
+--R                      18833423088924753920a  + 128767022044444360704a
+--R                    + 
+--R                                            3                         2
+--R                      197893824476545548288a  + 170576989286005997568a
+--R                    + 
+--R                      83709868624400351232a + 18392762450832261120
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                            17              16                15
+--R                  136642560a   + 7616593920a   + 198980665344a
+--R                + 
+--R                                14                  13                   12
+--R                  3234300690432a   + 36614363283456a   + 306155605721088a
+--R                + 
+--R                                   11                    10
+--R                  1956339656687616a   + 9747894775578624a
+--R                + 
+--R                                    9                      8
+--R                  38291841445330944a  + 119050488573591552a
+--R                + 
+--R                                     7                      6
+--R                  292236772188880896a  + 561261720373297152a
+--R                + 
+--R                                     5                      4
+--R                  828898581078343680a  + 914439454498750464a
+--R                + 
+--R                                     3                      2
+--R                  718255692208668672a  + 369227414724673536a
+--R                + 
+--R                  104815442748506112a + 10263520138493952
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                                  20               19                18
+--R                      - 469762048a   - 31417434112a   - 992305217536a
+--R                    + 
+--R                                       17                   16
+--R                      - 19663576629248a   - 273880031690752a
+--R                    + 
+--R                                         15                     14
+--R                      - 2846116194287616a   - 22853982892326912a
+--R                    + 
+--R                                           13                      12
+--R                      - 144840417605582848a   - 733193154773123072a
+--R                    + 
+--R                                            11                       10
+--R                      - 2977941469704224768a   - 9677197373117300736a
+--R                    + 
+--R                                             9                        8
+--R                      - 24850421452415959040a  - 48984708931769073664a
+--R                    + 
+--R                                             7                        6
+--R                      - 69124682329943441408a  - 54921507243737219072a
+--R                    + 
+--R                                           5                         4
+--R                      18833423088924753920a  + 128767022044444360704a
+--R                    + 
+--R                                            3                         2
+--R                      197893824476545548288a  + 170576989286005997568a
+--R                    + 
+--R                      83709868624400351232a + 18392762450832261120
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                          15             14              13               12
+--R                  4128768a   + 205690752a   + 4815576576a   + 70346275200a
+--R                + 
+--R                               11                 10                  9
+--R                  717640611840a   + 5418702965376a   + 31294228658688a
+--R                + 
+--R                                  8                   7                    6
+--R                  140763749751936a  + 497067937910784a  + 1377224633714688a
+--R                + 
+--R                                   5                    4                    3
+--R                  2967358580711424a  + 4878060169494528a  + 5916693191196672a
+--R                + 
+--R                                   2
+--R                  4993670969819136a  + 2619763429736448a + 643402441949184
+--R             *
+--R                %%BN1
+--R            + 
+--R                              20               19                18
+--R                  - 469762048a   - 31417434112a   - 992305217536a
+--R                + 
+--R                                   17                   16                    15
+--R                  - 19663576629248a   - 273880031690752a   - 2846116194287616a
+--R                + 
+--R                                      14                      13
+--R                  - 22853982892326912a   - 144840417605582848a
+--R                + 
+--R                                       12                       11
+--R                  - 733193154773123072a   - 2977941469704224768a
+--R                + 
+--R                                        10                        9
+--R                  - 9677197373117300736a   - 24850421452415959040a
+--R                + 
+--R                                         8                        7
+--R                  - 48984708931769073664a  - 69124682329943441408a
+--R                + 
+--R                                         6                        5
+--R                  - 54921507243737219072a  + 18833423088924753920a
+--R                + 
+--R                                        4                         3
+--R                  128767022044444360704a  + 197893824476545548288a
+--R                + 
+--R                                        2
+--R                  170576989286005997568a  + 83709868624400351232a
+--R                + 
+--R                  18392762450832261120
+--R             *
+--R                     3
+--R                %%BN0
+--R            + 
+--R                          15             14               13                12
+--R                  8257536a   + 441298944a   + 10865693952a   + 163221845760a
+--R                + 
+--R                                11                  10                  9
+--R                  1668479574528a   + 12244561362432a   + 66227055393024a
+--R                + 
+--R                                  8                   7                    6
+--R                  266026528316160a  + 785057799315456a  + 1634909318737920a
+--R                + 
+--R                                   5                   4                    3
+--R                  2131094791766016a  + 875627754356736a  - 2492761086885888a
+--R                + 
+--R                                     2
+--R                  - 5377669293146112a  - 4665483643060224a - 1626737989386240
+--R             *
+--R                %%BN0
+--R            + 
+--R                          12            11             10              9
+--R                  1354752a   + 44550027a   + 663517980a   + 5951170602a
+--R                + 
+--R                              8                7                6
+--R                  36270700668a  + 162289912419a  + 567868212432a
+--R                + 
+--R                                5                 4                 3
+--R                  1626099007104a  + 3825839091456a  + 7035734732544a
+--R                + 
+--R                                2
+--R                  9216760449024a  + 7467334520832a + 2773884911616
+--R             *
+--R                x
+--R            + 
+--R                        12             11              10               9
+--R              - 3741120a   - 141321915a   - 2439850572a   - 25422884586a
+--R            + 
+--R                             8                7                 6
+--R              - 177755396508a  - 876521764755a  - 3115301128128a
+--R            + 
+--R                              5                  4                  3
+--R              - 8002632319200a  - 14638310274816a  - 18370117132416a
+--R            + 
+--R                               2
+--R              - 14680566199296a  - 6387069597696a - 985687031808
+--R     + 
+--R                                                  +------------+
+--R                     +-----+      2               | +-----+
+--R         ((12a + 42)\|a + 4  + 21a  + 141a + 240)\|\|a + 4  + 1
+--R      *
+--R                    x - 1
+--R         atan(-----------------)
+--R               +--------------+
+--R               |   +-----+
+--R              \|- \|a + 4  + 1
+--R     + 
+--R                                                  +--------------+
+--R                     +-----+      2               |   +-----+
+--R         ((12a + 42)\|a + 4  - 21a  - 141a - 240)\|- \|a + 4  + 1
+--R      *
+--R                   x - 1
+--R         atan(---------------)
+--R               +------------+
+--R               | +-----+
+--R              \|\|a + 4  + 1
+--R     + 
+--R                 4       3        2                  +-----+
+--R             (64a  + 896a  + 4672a  + 10752a + 9216)\|a + 4 %%BN0
+--R          *
+--R             log
+--R                                20               19                18
+--R                      469762048a   + 31417434112a   + 992305217536a
+--R                    + 
+--R                                     17                   16
+--R                      19663576629248a   + 273880031690752a
+--R                    + 
+--R                                       15                     14
+--R                      2846116194287616a   + 22853982892326912a
+--R                    + 
+--R                                         13                      12
+--R                      144840417605582848a   + 733193154773123072a
+--R                    + 
+--R                                          11                       10
+--R                      2977941469704224768a   + 9677197373117300736a
+--R                    + 
+--R                                           9                        8
+--R                      24850421452415959040a  + 48984708931769073664a
+--R                    + 
+--R                                           7                        6
+--R                      69124682329943441408a  + 54921507243737219072a
+--R                    + 
+--R                                             5                         4
+--R                      - 18833423088924753920a  - 128767022044444360704a
+--R                    + 
+--R                                              3                         2
+--R                      - 197893824476545548288a  - 170576989286005997568a
+--R                    + 
+--R                      - 83709868624400351232a - 18392762450832261120
+--R                 *
+--R                         3
+--R                    %%BN0
+--R                + 
+--R                                17              16                15
+--R                      136642560a   + 7616593920a   + 198980665344a
+--R                    + 
+--R                                    14                  13                   12
+--R                      3234300690432a   + 36614363283456a   + 306155605721088a
+--R                    + 
+--R                                       11                    10
+--R                      1956339656687616a   + 9747894775578624a
+--R                    + 
+--R                                        9                      8
+--R                      38291841445330944a  + 119050488573591552a
+--R                    + 
+--R                                         7                      6
+--R                      292236772188880896a  + 561261720373297152a
+--R                    + 
+--R                                         5                      4
+--R                      828898581078343680a  + 914439454498750464a
+--R                    + 
+--R                                         3                      2
+--R                      718255692208668672a  + 369227414724673536a
+--R                    + 
+--R                      104815442748506112a + 10263520138493952
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                                15             14              13
+--R                      - 4128768a   - 235608192a   - 6050117376a
+--R                    + 
+--R                                    12                11                 10
+--R                      - 92875570560a   - 950838962688a   - 6825858397056a
+--R                    + 
+--R                                       9                   8                   7
+--R                      - 34932826734336a  - 125262778564224a  - 287989861404672a
+--R                    + 
+--R                                        6                   5
+--R                      - 257684685023232a  + 836263788945408a
+--R                    + 
+--R                                       4                    3
+--R                      4002432415137792a  + 8409454278082560a
+--R                    + 
+--R                                      2
+--R                    10371340262965248a  + 7285247072796672a + 2270140431335424
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                              12            11             10              9
+--R                      1354752a   + 44550027a   + 663517980a   + 5951170602a
+--R                    + 
+--R                                  8                7                6
+--R                      36270700668a  + 162289912419a  + 567868212432a
+--R                    + 
+--R                                    5                 4                 3
+--R                      1626099007104a  + 3825839091456a  + 7035734732544a
+--R                    + 
+--R                                    2
+--R                      9216760449024a  + 7467334520832a + 2773884911616
+--R                 *
+--R                    x
+--R                + 
+--R                          12            11             10              9
+--R                  1000512a   + 42546357a   + 777344580a   + 7998006582a
+--R                + 
+--R                              8                7                6
+--R                  50045408388a  + 182866499613a  + 247394170512a
+--R                + 
+--R                                  5                 4                  3
+--R                  - 1063305068832a  - 6960658344192a  - 19132655580288a
+--R                + 
+--R                                   2
+--R                  - 30001872614400a  - 26192892672000a - 9953981595648
+--R         + 
+--R                                      2
+--R                 2                   x  - 2x + 2
+--R           (- 12a  - 72a - 108)atanh(-----------)
+--R                                        +-----+
+--R                                       \|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R                                                       +--------------+
+--R           4       3        2                  +-----+ |   +-----+
+--R       (64a  + 896a  + 4672a  + 10752a + 9216)\|a + 4 \|- \|a + 4  + 1
+--R    *
+--R        +------------+
+--R        | +-----+
+--R       \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 303
+
+--S 304 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 304
+
+)clear all
+
+--S 305 of 534
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)^4
+--R 
+--R
+--R   (1)
+--R      18      17       16       15                 14                13
+--R     x   - 16x   + 128x   - 672x   + (- 4a + 2560)x   + (48a - 7424)x
+--R   + 
+--R                      12                   11      2                  10
+--R     (- 288a + 16768)x   + (1120a - 29696)x   + (6a  - 3072a + 40960)x
+--R   + 
+--R           2                  9        2                  8
+--R     (- 48a  + 6144a - 43008)x  + (192a  - 8960a + 32768)x
+--R   + 
+--R            2                  7        3       2                 6
+--R     (- 480a  + 9216a - 16384)x  + (- 4a  + 768a  - 6144a + 4096)x
+--R   + 
+--R         3       2          5         3       2  4      3 3    4 2
+--R     (16a  - 768a  + 2048a)x  + (- 32a  + 384a )x  + 32a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 305
+
+--S 306 of 534
+r0:=1/3*a^4*x^3+8*a^3*x^4+32/5*(12-a)*a^2*x^5+8/3*a*(128-48*a+a^2)*x^6+_
+   4/7*(1024-1536*a+192*a^2-a^3)*x^7-4*(512-288*a+15*a^2)*x^8+64/9*_
+   (128-3*a)*(4-a)*x^9-24/5*(896-128*a+a^2)*x^10+2/11*(20480-1536*a+3*a^2)*_
+   x^11-8/3*(928-35*a)*x^12+32/13*(524-9*a)*x^13-8/7*(464-3*a)*x^14+_
+   4/15*(640-a)*x^15-42*x^16+128/17*x^17-8/9*x^18+1/19*x^19
+--R 
+--R
+--R   (2)
+--R      1  19   8  18   128  17      16       4     512  15    24     3712  14
+--R     -- x   - - x   + --- x   - 42x   + (- -- a + ---)x   + (-- a - ----)x
+--R     19       9        17                  15      3          7       7
+--R   + 
+--R        288     16768  13    280     7424  12     6  2   3072     40960  11
+--R     (- --- a + -----)x   + (--- a - ----)x   + (-- a  - ---- a + -----)x
+--R         13       13          3        3         11       11        11
+--R   + 
+--R        24  2   3072     21504  10    64  2   8960     32768  9
+--R     (- -- a  + ---- a - -----)x   + (-- a  - ---- a + -----)x
+--R         5        5        5           3        9        9
+--R   + 
+--R           2                 8      4  3   768  2   6144     4096  7
+--R     (- 60a  + 1152a - 2048)x  + (- - a  + --- a  - ---- a + ----)x
+--R                                    7       7         7        7
+--R   + 
+--R      8  3       2   1024    6      32  3   384  2  5     3 4   1  4 3
+--R     (- a  - 128a  + ---- a)x  + (- -- a  + --- a )x  + 8a x  + - a x
+--R      3                3             5       5                  3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 306
+
+--S 307 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  19   8  18   128  17      16       4     512  15    24     3712  14
+--R     -- x   - - x   + --- x   - 42x   + (- -- a + ---)x   + (-- a - ----)x
+--R     19       9        17                  15      3          7       7
+--R   + 
+--R        288     16768  13    280     7424  12     6  2   3072     40960  11
+--R     (- --- a + -----)x   + (--- a - ----)x   + (-- a  - ---- a + -----)x
+--R         13       13          3        3         11       11        11
+--R   + 
+--R        24  2   3072     21504  10    64  2   8960     32768  9
+--R     (- -- a  + ---- a - -----)x   + (-- a  - ---- a + -----)x
+--R         5        5        5           3        9        9
+--R   + 
+--R           2                 8      4  3   768  2   6144     4096  7
+--R     (- 60a  + 1152a - 2048)x  + (- - a  + --- a  - ---- a + ----)x
+--R                                    7       7         7        7
+--R   + 
+--R      8  3       2   1024    6      32  3   384  2  5     3 4   1  4 3
+--R     (- a  - 128a  + ---- a)x  + (- -- a  + --- a )x  + 8a x  + - a x
+--R      3                3             5       5                  3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 307
+
+--S 308 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 308
+
+--S 309 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 309
+
+)clear all
+
+--S 310 of 534
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)^3
+--R 
+--R
+--R   (1)
+--R        14      13      12       11              10                  9
+--R     - x   + 12x   - 72x   + 280x   + (3a - 768)x   + (- 24a + 1536)x
+--R   + 
+--R                  8                   7        2                6
+--R     (96a - 2240)x  + (- 240a + 2304)x  + (- 3a  + 384a - 1536)x
+--R   + 
+--R         2               5         2         4      2 3    3 2
+--R     (12a  - 384a + 512)x  + (- 24a  + 192a)x  + 24a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 310
+
+--S 311 of 534
+r0:=1/3*a^3*x^3+6*a^2*x^4+24/5*(8-a)*a*x^5+2/3*(128-96*a+3*a^2)*x^6-_
+   3/7*(512-128*a+a^2)*x^7+6*(48-5*a)*x^8-32/9*(70-3*a)*x^9+12/5*(64-a)*_
+   x^10-3/11*(256-a)*x^11+70/3*x^12-72/13*x^13+6/7*x^14-1/15*x^15
+--R 
+--R
+--R   (2)
+--R        1  15   6  14   72  13   70  12     3     768  11      12     768  10
+--R     - -- x   + - x   - -- x   + -- x   + (-- a - ---)x   + (- -- a + ---)x
+--R       15       7       13        3        11      11           5      5
+--R   + 
+--R      32     2240  9                 8      3  2   384     1536  7
+--R     (-- a - ----)x  + (- 30a + 288)x  + (- - a  + --- a - ----)x
+--R       3       9                            7       7        7
+--R   + 
+--R        2         256  6      24  2   192    5     2 4   1  3 3
+--R     (2a  - 64a + ---)x  + (- -- a  + --- a)x  + 6a x  + - a x
+--R                   3           5       5                 3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 311
+
+--S 312 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        1  15   6  14   72  13   70  12     3     768  11      12     768  10
+--R     - -- x   + - x   - -- x   + -- x   + (-- a - ---)x   + (- -- a + ---)x
+--R       15       7       13        3        11      11           5      5
+--R   + 
+--R      32     2240  9                 8      3  2   384     1536  7
+--R     (-- a - ----)x  + (- 30a + 288)x  + (- - a  + --- a - ----)x
+--R       3       9                            7       7        7
+--R   + 
+--R        2         256  6      24  2   192    5     2 4   1  3 3
+--R     (2a  - 64a + ---)x  + (- -- a  + --- a)x  + 6a x  + - a x
+--R                   3           5       5                 3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 312
+
+--S 313 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 313
+
+--S 314 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 314
+
+)clear all
+
+--S 315 of 534
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R      10     9      8      7                6              5                4
+--R     x   - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R   + 
+--R          3    2 2
+--R     16a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 315
+
+--S 316 of 534
+r0:=1/3*a^2*x^3+4*a*x^4+16/5*(4-a)*x^5-4/3*(16-a)*x^6+2/7*(64-a)*x^7-10*x^8+_
+   32/9*x^9-4/5*x^10+1/11*x^11
+--R 
+--R
+--R   (2)
+--R      1  11   4  10   32  9      8      2     128  7    4     64  6
+--R     -- x   - - x   + -- x  - 10x  + (- - a + ---)x  + (- a - --)x
+--R     11       5        9                7      7        3      3
+--R   + 
+--R        16     64  5       4   1  2 3
+--R     (- -- a + --)x  + 4a x  + - a x
+--R         5      5              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 316
+
+--S 317 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  11   4  10   32  9      8      2     128  7    4     64  6
+--R     -- x   - - x   + -- x  - 10x  + (- - a + ---)x  + (- a - --)x
+--R     11       5        9                7      7        3      3
+--R   + 
+--R        16     64  5       4   1  2 3
+--R     (- -- a + --)x  + 4a x  + - a x
+--R         5      5              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 317
+
+--S 318 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 318
+
+--S 319 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 319
+
+)clear all
+
+--S 320 of 534
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)
+--R 
+--R
+--R           6     5     4     3      2
+--R   (1)  - x  + 4x  - 8x  + 8x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 320
+
+--S 321 of 534
+r0:=1/3*a*x^3+2*x^4-8/5*x^5+2/3*x^6-1/7*x^7
+--R 
+--R
+--R          1  7   2  6   8  5     4   1    3
+--R   (2)  - - x  + - x  - - x  + 2x  + - a x
+--R          7      3      5            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 321
+
+--S 322 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R          1  7   2  6   8  5     4   1    3
+--R   (3)  - - x  + - x  - - x  + 2x  + - a x
+--R          7      3      5            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 322
+
+--S 323 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 323
+
+--S 324 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 324
+
+)clear all
+
+--S 325 of 534
+t0:=x^2/(a+8*x-8*x^2+4*x^3-x^4)
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  - -----------------------
+--R           4     3     2
+--R          x  - 4x  + 8x  - 8x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 325
+
+--S 326 of 534
+r0:=atanh((1+(-1+x)^2)/sqrt(4+a))/sqrt(4+a)-1/2*atan((-1+x)/_
+   sqrt(1-sqrt(4+a)))/sqrt(1-sqrt(4+a))-1/2*atan((-1+x)/sqrt(1+sqrt(4+a)))/_
+   sqrt(1+sqrt(4+a))
+--R 
+--R
+--R   (2)
+--R                  +------------+
+--R          +-----+ | +-----+                x - 1
+--R       - \|a + 4 \|\|a + 4  + 1 atan(-----------------)
+--R                                      +--------------+
+--R                                      |   +-----+
+--R                                     \|- \|a + 4  + 1
+--R     + 
+--R                  +--------------+
+--R          +-----+ |   +-----+               x - 1
+--R       - \|a + 4 \|- \|a + 4  + 1 atan(---------------)
+--R                                        +------------+
+--R                                        | +-----+
+--R                                       \|\|a + 4  + 1
+--R     + 
+--R               2           +--------------+ +------------+
+--R              x  - 2x + 2  |   +-----+      | +-----+
+--R       2atanh(-----------)\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                 +-----+
+--R                \|a + 4
+--R  /
+--R               +--------------+ +------------+
+--R       +-----+ |   +-----+      | +-----+
+--R     2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           ROOT
+--R                       2                 2        2
+--R                  (- 6a  - 42a - 72)%%BO1  + (- 4a  - 28a - 48)%%BO0 %%BO1
+--R                + 
+--R                       2                 2
+--R                  (- 6a  - 42a - 72)%%BO0  + 5a + 16
+--R             /
+--R                  2
+--R                2a  + 14a + 24
+--R         + 
+--R           - %%BO1 - %%BO0
+--R      *
+--R         log
+--R                          4       3       2                            3
+--R                      (32a  + 224a  + 128a  - 1792a - 3072)%%BO0 + 112a
+--R                    + 
+--R                           2
+--R                      1104a  + 3584a + 3840
+--R                 *
+--R                    %%BO1
+--R                + 
+--R                     3        2                          3       2
+--R                (112a  + 1104a  + 3584a + 3840)%%BO0 - 8a  - 136a  - 592a - 768
+--R             *
+--R                ROOT
+--R                            2                 2        2
+--R                       (- 6a  - 42a - 72)%%BO1  + (- 4a  - 28a - 48)%%BO0 %%BO1
+--R                     + 
+--R                            2                 2
+--R                       (- 6a  - 42a - 72)%%BO0  + 5a + 16
+--R                  /
+--R                       2
+--R                     2a  + 14a + 24
+--R            + 
+--R                      4       3       2                            3        2
+--R                  (32a  + 224a  + 128a  - 1792a - 3072)%%BO0 + 112a  + 1104a
+--R                + 
+--R                  3584a + 3840
+--R             *
+--R                     2
+--R                %%BO1
+--R            + 
+--R                      4       3       2                     2     3       2
+--R                  (32a  + 224a  + 128a  - 1792a - 3072)%%BO0  + 8a  + 136a
+--R                + 
+--R                  592a + 768
+--R             *
+--R                %%BO1
+--R            + 
+--R                   3        2                     2
+--R              (112a  + 1104a  + 3584a + 3840)%%BO0
+--R            + 
+--R                 3       2                        3      2                    3
+--R              (8a  + 136a  + 592a + 768)%%BO0 + (a  + 60a  + 320a + 448)x - 3a
+--R            + 
+--R                    2
+--R              - 138a  - 728a - 1024
+--R     + 
+--R           -
+--R              ROOT
+--R                          2                 2        2
+--R                     (- 6a  - 42a - 72)%%BO1  + (- 4a  - 28a - 48)%%BO0 %%BO1
+--R                   + 
+--R                          2                 2
+--R                     (- 6a  - 42a - 72)%%BO0  + 5a + 16
+--R                /
+--R                     2
+--R                   2a  + 14a + 24
+--R         + 
+--R           - %%BO1 - %%BO0
+--R      *
+--R         log
+--R                            4       3       2                            3
+--R                      (- 32a  - 224a  - 128a  + 1792a + 3072)%%BO0 - 112a
+--R                    + 
+--R                             2
+--R                      - 1104a  - 3584a - 3840
+--R                 *
+--R                    %%BO1
+--R                + 
+--R                         3        2                          3       2
+--R                  (- 112a  - 1104a  - 3584a - 3840)%%BO0 + 8a  + 136a  + 592a
+--R                + 
+--R                  768
+--R             *
+--R                ROOT
+--R                            2                 2        2
+--R                       (- 6a  - 42a - 72)%%BO1  + (- 4a  - 28a - 48)%%BO0 %%BO1
+--R                     + 
+--R                            2                 2
+--R                       (- 6a  - 42a - 72)%%BO0  + 5a + 16
+--R                  /
+--R                       2
+--R                     2a  + 14a + 24
+--R            + 
+--R                      4       3       2                            3        2
+--R                  (32a  + 224a  + 128a  - 1792a - 3072)%%BO0 + 112a  + 1104a
+--R                + 
+--R                  3584a + 3840
+--R             *
+--R                     2
+--R                %%BO1
+--R            + 
+--R                      4       3       2                     2     3       2
+--R                  (32a  + 224a  + 128a  - 1792a - 3072)%%BO0  + 8a  + 136a
+--R                + 
+--R                  592a + 768
+--R             *
+--R                %%BO1
+--R            + 
+--R                   3        2                     2
+--R              (112a  + 1104a  + 3584a + 3840)%%BO0
+--R            + 
+--R                 3       2                        3      2                    3
+--R              (8a  + 136a  + 592a + 768)%%BO0 + (a  + 60a  + 320a + 448)x - 3a
+--R            + 
+--R                    2
+--R              - 138a  - 728a - 1024
+--R     + 
+--R         2%%BO1
+--R      *
+--R         log
+--R                        4       3       2                            3        2
+--R                  (- 64a  - 448a  - 256a  + 3584a + 6144)%%BO0 - 224a  - 2208a
+--R                + 
+--R                  - 7168a - 7680
+--R             *
+--R                     2
+--R                %%BO1
+--R            + 
+--R                        4       3       2                     2      3       2
+--R                  (- 64a  - 448a  - 256a  + 3584a + 6144)%%BO0  - 16a  - 272a
+--R                + 
+--R                  - 1184a - 1536
+--R             *
+--R                %%BO1
+--R            + 
+--R                    4       3       2                     3
+--R              (- 64a  - 448a  - 256a  + 3584a + 6144)%%BO0
+--R            + 
+--R                  3       2                         3      2
+--R              (40a  + 128a  - 320a - 1024)%%BO0 + (a  + 60a  + 320a + 448)x
+--R            + 
+--R                  3     2
+--R              - 3a  + 2a  + 120a + 256
+--R     + 
+--R         2%%BO0
+--R      *
+--R         log
+--R                  4       3       2                     3
+--R              (64a  + 448a  + 256a  - 3584a - 6144)%%BO0
+--R            + 
+--R                     3        2                     2
+--R              (- 224a  - 2208a  - 7168a - 7680)%%BO0
+--R            + 
+--R                    3       2                        3      2
+--R              (- 56a  - 400a  - 864a - 512)%%BO0 + (a  + 60a  + 320a + 448)x
+--R            + 
+--R                3      2
+--R              5a  + 34a  + 56a
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 327
+
+--S 328 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      +--------------+ +------------+
+--R              +-----+ |   +-----+      | +-----+
+--R             \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R          *
+--R             ROOT
+--R                         2                 2        2
+--R                    (- 6a  - 42a - 72)%%BO1  + (- 4a  - 28a - 48)%%BO0 %%BO1
+--R                  + 
+--R                         2                 2
+--R                    (- 6a  - 42a - 72)%%BO0  + 5a + 16
+--R               /
+--R                    2
+--R                  2a  + 14a + 24
+--R         + 
+--R                      +--------------+ +------------+
+--R              +-----+ |   +-----+      | +-----+
+--R           - \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BO1
+--R         + 
+--R                           +--------------+ +------------+
+--R              +-----+      |   +-----+      | +-----+
+--R           - \|a + 4 %%BO0\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R      *
+--R         log
+--R                          4       3       2                            3
+--R                      (32a  + 224a  + 128a  - 1792a - 3072)%%BO0 + 112a
+--R                    + 
+--R                           2
+--R                      1104a  + 3584a + 3840
+--R                 *
+--R                    %%BO1
+--R                + 
+--R                     3        2                          3       2
+--R                (112a  + 1104a  + 3584a + 3840)%%BO0 - 8a  - 136a  - 592a - 768
+--R             *
+--R                ROOT
+--R                            2                 2        2
+--R                       (- 6a  - 42a - 72)%%BO1  + (- 4a  - 28a - 48)%%BO0 %%BO1
+--R                     + 
+--R                            2                 2
+--R                       (- 6a  - 42a - 72)%%BO0  + 5a + 16
+--R                  /
+--R                       2
+--R                     2a  + 14a + 24
+--R            + 
+--R                      4       3       2                            3        2
+--R                  (32a  + 224a  + 128a  - 1792a - 3072)%%BO0 + 112a  + 1104a
+--R                + 
+--R                  3584a + 3840
+--R             *
+--R                     2
+--R                %%BO1
+--R            + 
+--R                      4       3       2                     2     3       2
+--R                  (32a  + 224a  + 128a  - 1792a - 3072)%%BO0  + 8a  + 136a
+--R                + 
+--R                  592a + 768
+--R             *
+--R                %%BO1
+--R            + 
+--R                   3        2                     2
+--R              (112a  + 1104a  + 3584a + 3840)%%BO0
+--R            + 
+--R                 3       2                        3      2                    3
+--R              (8a  + 136a  + 592a + 768)%%BO0 + (a  + 60a  + 320a + 448)x - 3a
+--R            + 
+--R                    2
+--R              - 138a  - 728a - 1024
+--R     + 
+--R           -
+--R                         +--------------+ +------------+
+--R                 +-----+ |   +-----+      | +-----+
+--R                \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R             *
+--R                ROOT
+--R                            2                 2        2
+--R                       (- 6a  - 42a - 72)%%BO1  + (- 4a  - 28a - 48)%%BO0 %%BO1
+--R                     + 
+--R                            2                 2
+--R                       (- 6a  - 42a - 72)%%BO0  + 5a + 16
+--R                  /
+--R                       2
+--R                     2a  + 14a + 24
+--R         + 
+--R                      +--------------+ +------------+
+--R              +-----+ |   +-----+      | +-----+
+--R           - \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BO1
+--R         + 
+--R                           +--------------+ +------------+
+--R              +-----+      |   +-----+      | +-----+
+--R           - \|a + 4 %%BO0\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R      *
+--R         log
+--R                            4       3       2                            3
+--R                      (- 32a  - 224a  - 128a  + 1792a + 3072)%%BO0 - 112a
+--R                    + 
+--R                             2
+--R                      - 1104a  - 3584a - 3840
+--R                 *
+--R                    %%BO1
+--R                + 
+--R                         3        2                          3       2
+--R                  (- 112a  - 1104a  - 3584a - 3840)%%BO0 + 8a  + 136a  + 592a
+--R                + 
+--R                  768
+--R             *
+--R                ROOT
+--R                            2                 2        2
+--R                       (- 6a  - 42a - 72)%%BO1  + (- 4a  - 28a - 48)%%BO0 %%BO1
+--R                     + 
+--R                            2                 2
+--R                       (- 6a  - 42a - 72)%%BO0  + 5a + 16
+--R                  /
+--R                       2
+--R                     2a  + 14a + 24
+--R            + 
+--R                      4       3       2                            3        2
+--R                  (32a  + 224a  + 128a  - 1792a - 3072)%%BO0 + 112a  + 1104a
+--R                + 
+--R                  3584a + 3840
+--R             *
+--R                     2
+--R                %%BO1
+--R            + 
+--R                      4       3       2                     2     3       2
+--R                  (32a  + 224a  + 128a  - 1792a - 3072)%%BO0  + 8a  + 136a
+--R                + 
+--R                  592a + 768
+--R             *
+--R                %%BO1
+--R            + 
+--R                   3        2                     2
+--R              (112a  + 1104a  + 3584a + 3840)%%BO0
+--R            + 
+--R                 3       2                        3      2                    3
+--R              (8a  + 136a  + 592a + 768)%%BO0 + (a  + 60a  + 320a + 448)x - 3a
+--R            + 
+--R                    2
+--R              - 138a  - 728a - 1024
+--R     + 
+--R                   +--------------+ +------------+
+--R           +-----+ |   +-----+      | +-----+
+--R         2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BO1
+--R      *
+--R         log
+--R                        4       3       2                            3        2
+--R                  (- 64a  - 448a  - 256a  + 3584a + 6144)%%BO0 - 224a  - 2208a
+--R                + 
+--R                  - 7168a - 7680
+--R             *
+--R                     2
+--R                %%BO1
+--R            + 
+--R                        4       3       2                     2      3       2
+--R                  (- 64a  - 448a  - 256a  + 3584a + 6144)%%BO0  - 16a  - 272a
+--R                + 
+--R                  - 1184a - 1536
+--R             *
+--R                %%BO1
+--R            + 
+--R                    4       3       2                     3
+--R              (- 64a  - 448a  - 256a  + 3584a + 6144)%%BO0
+--R            + 
+--R                  3       2                         3      2
+--R              (40a  + 128a  - 320a - 1024)%%BO0 + (a  + 60a  + 320a + 448)x
+--R            + 
+--R                  3     2
+--R              - 3a  + 2a  + 120a + 256
+--R     + 
+--R                +------------+
+--R        +-----+ | +-----+                x - 1
+--R       \|a + 4 \|\|a + 4  + 1 atan(-----------------)
+--R                                    +--------------+
+--R                                    |   +-----+
+--R                                   \|- \|a + 4  + 1
+--R     + 
+--R                +--------------+
+--R        +-----+ |   +-----+               x - 1
+--R       \|a + 4 \|- \|a + 4  + 1 atan(---------------)
+--R                                      +------------+
+--R                                      | +-----+
+--R                                     \|\|a + 4  + 1
+--R     + 
+--R               +-----+
+--R             2\|a + 4 %%BO0
+--R          *
+--R             log
+--R                      4       3       2                     3
+--R                  (64a  + 448a  + 256a  - 3584a - 6144)%%BO0
+--R                + 
+--R                         3        2                     2
+--R                  (- 224a  - 2208a  - 7168a - 7680)%%BO0
+--R                + 
+--R                        3       2                        3      2
+--R                  (- 56a  - 400a  - 864a - 512)%%BO0 + (a  + 60a  + 320a + 448)x
+--R                + 
+--R                    3      2
+--R                  5a  + 34a  + 56a
+--R         + 
+--R                     2
+--R                    x  - 2x + 2
+--R           - 2atanh(-----------)
+--R                       +-----+
+--R                      \|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R               +--------------+ +------------+
+--R       +-----+ |   +-----+      | +-----+
+--R     2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 329
+
+)clear all
+
+--S 330 of 534
+t0:=x^2/(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R      2
+--R     x
+--R  /
+--R        8     7      6      5                4              3                2
+--R       x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R     + 
+--R                2
+--R       16a x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 330
+
+--S 331 of 534
+r0:=1/2*(1+(-1+x)^2)/((4+a)*(3+a-2*(-1+x)^2-(-1+x)^4))+1/4*(2+(-1+x)^2)*_
+   (-1+x)/((3+a)*(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*atanh((1+(-1+x)^2)/_
+   sqrt(4+a))/(4+a)^(3/2)-1/8*atan((-1+x)/sqrt(1-sqrt(4+a)))*(1+_
+   sqrt(4+a))/((3+a)*sqrt(4+a)*sqrt(1-sqrt(4+a)))+1/8*atan((-1+x)/_
+   sqrt(1+sqrt(4+a)))*(1-sqrt(4+a))/((3+a)*sqrt(4+a)*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R                        4             3               2                 2
+--R             ((- a - 4)x  + (4a + 16)x  + (- 8a - 32)x  + (8a + 32)x + a  + 4a)
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R                     4             3               2                 2
+--R           (- a - 4)x  + (4a + 16)x  + (- 8a - 32)x  + (8a + 32)x + a  + 4a
+--R      *
+--R          +------------+
+--R          | +-----+                x - 1
+--R         \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R                        4             3               2                 2
+--R             ((- a - 4)x  + (4a + 16)x  + (- 8a - 32)x  + (8a + 32)x + a  + 4a)
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R                   4               3             2                   2
+--R           (a + 4)x  + (- 4a - 16)x  + (8a + 32)x  + (- 8a - 32)x - a  - 4a
+--R      *
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R         \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R                         4                3              2                     2
+--R               (4a + 12)x  + (- 16a - 48)x  + (32a + 96)x  + (- 32a - 96)x - 4a
+--R             + 
+--R               - 12a
+--R          *
+--R                    2
+--R                   x  - 2x + 2
+--R             atanh(-----------)
+--R                      +-----+
+--R                     \|a + 4
+--R         + 
+--R                       3             2                      +-----+
+--R           ((- 2a - 8)x  + (2a + 12)x  + (- 2a - 16)x - 2a)\|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R            2             4         2               3       2               2
+--R         (8a  + 56a + 96)x  + (- 32a  - 224a - 384)x  + (64a  + 448a + 768)x
+--R       + 
+--R               2                    3      2
+--R         (- 64a  - 448a - 768)x - 8a  - 56a  - 96a
+--R    *
+--R                +--------------+ +------------+
+--R        +-----+ |   +-----+      | +-----+
+--R       \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2             4        2             3       2               2
+--R               (2a  + 14a + 24)x  + (- 8a  - 56a - 96)x  + (16a  + 112a + 192)x
+--R             + 
+--R                     2                    3      2
+--R               (- 16a  - 112a - 192)x - 2a  - 14a  - 24a
+--R          *
+--R             ROOT
+--R                             6        5         4         3          2
+--R                        - 96a  - 2016a  - 17568a  - 81312a  - 210816a  - 290304a
+--R                      + 
+--R                        - 165888
+--R                   *
+--R                           2
+--R                      %%BP1
+--R                  + 
+--R                             6        5         4         3          2
+--R                        - 64a  - 1344a  - 11712a  - 54208a  - 140544a  - 193536a
+--R                      + 
+--R                        - 110592
+--R                   *
+--R                      %%BP0 %%BP1
+--R                  + 
+--R                             6        5         4         3          2
+--R                        - 96a  - 2016a  - 17568a  - 81312a  - 210816a  - 290304a
+--R                      + 
+--R                        - 165888
+--R                   *
+--R                           2
+--R                      %%BP0
+--R                  + 
+--R                       3       2
+--R                    19a  + 181a  + 584a + 640
+--R               /
+--R                     6       5        4         3         2
+--R                  32a  + 672a  + 5856a  + 27104a  + 70272a  + 96768a + 55296
+--R         + 
+--R                    2             4      2             3
+--R               (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x
+--R             + 
+--R                   2               2       2                    3      2
+--R             (- 16a  - 112a - 192)x  + (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R          *
+--R             %%BP1
+--R         + 
+--R                    2             4      2             3
+--R               (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x
+--R             + 
+--R                   2               2       2                    3      2
+--R             (- 16a  - 112a - 192)x  + (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R          *
+--R             %%BP0
+--R      *
+--R         log
+--R                               12         11           10            9
+--R                          2048a   - 30720a   - 2740224a   - 55701504a
+--R                        + 
+--R                                      8              7               6
+--R                          - 613586944a  - 4341438464a  - 21093720064a
+--R                        + 
+--R                                        5                4                3
+--R                          - 72315142144a  - 175486140416a  - 295875117056a
+--R                        + 
+--R                                         2
+--R                          - 330358063104a  - 219924135936a - 66135785472
+--R                     *
+--R                        %%BP0
+--R                    + 
+--R                            10          9           8            7             6
+--R                      14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                    + 
+--R                                 5              4              3               2
+--R                      1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                    + 
+--R                      8436842496a + 2774532096
+--R                 *
+--R                    %%BP1
+--R                + 
+--R                            10          9           8            7             6
+--R                      14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                    + 
+--R                                 5              4              3               2
+--R                      1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                    + 
+--R                      8436842496a + 2774532096
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                        9         8          7           6            5
+--R                  - 120a  - 11096a  - 240168a  - 2518856a  - 15490240a
+--R                + 
+--R                           4             3             2
+--R                - 60021248a  - 149084160a  - 231098368a  - 204029952a - 78446592
+--R             *
+--R                ROOT
+--R                                6        5         4         3          2
+--R                           - 96a  - 2016a  - 17568a  - 81312a  - 210816a
+--R                         + 
+--R                           - 290304a - 165888
+--R                      *
+--R                              2
+--R                         %%BP1
+--R                     + 
+--R                                6        5         4         3          2
+--R                           - 64a  - 1344a  - 11712a  - 54208a  - 140544a
+--R                         + 
+--R                           - 193536a - 110592
+--R                      *
+--R                         %%BP0 %%BP1
+--R                     + 
+--R                                6        5         4         3          2
+--R                           - 96a  - 2016a  - 17568a  - 81312a  - 210816a
+--R                         + 
+--R                           - 290304a - 165888
+--R                      *
+--R                              2
+--R                         %%BP0
+--R                     + 
+--R                          3       2
+--R                       19a  + 181a  + 584a + 640
+--R                  /
+--R                        6       5        4         3         2
+--R                     32a  + 672a  + 5856a  + 27104a  + 70272a  + 96768a + 55296
+--R            + 
+--R                           12         11           10            9             8
+--R                      2048a   - 30720a   - 2740224a   - 55701504a  - 613586944a
+--R                    + 
+--R                                   7               6               5
+--R                      - 4341438464a  - 21093720064a  - 72315142144a
+--R                    + 
+--R                                     4                3                2
+--R                      - 175486140416a  - 295875117056a  - 330358063104a
+--R                    + 
+--R                      - 219924135936a - 66135785472
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                        10          9           8            7             6
+--R                  14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                + 
+--R                             5              4              3               2
+--R                  1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                + 
+--R                  8436842496a + 2774532096
+--R             *
+--R                     2
+--R                %%BP1
+--R            + 
+--R                           12         11           10            9             8
+--R                      2048a   - 30720a   - 2740224a   - 55701504a  - 613586944a
+--R                    + 
+--R                                   7               6               5
+--R                      - 4341438464a  - 21093720064a  - 72315142144a
+--R                    + 
+--R                                     4                3                2
+--R                      - 175486140416a  - 295875117056a  - 330358063104a
+--R                    + 
+--R                      - 219924135936a - 66135785472
+--R                 *
+--R                         2
+--R                    %%BP0
+--R                + 
+--R                      9         8          7           6            5
+--R                  120a  + 11096a  + 240168a  + 2518856a  + 15490240a
+--R                + 
+--R                         4             3             2
+--R                60021248a  + 149084160a  + 231098368a  + 204029952a + 78446592
+--R             *
+--R                %%BP1
+--R            + 
+--R                        10          9           8            7             6
+--R                  14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                + 
+--R                             5              4              3               2
+--R                  1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                + 
+--R                  8436842496a + 2774532096
+--R             *
+--R                     2
+--R                %%BP0
+--R            + 
+--R                      9         8          7           6            5
+--R                  120a  + 11096a  + 240168a  + 2518856a  + 15490240a
+--R                + 
+--R                         4             3             2
+--R                60021248a  + 149084160a  + 231098368a  + 204029952a + 78446592
+--R             *
+--R                %%BP0
+--R            + 
+--R                   8       7         6          5          4           3
+--R                  a  + 870a  + 18289a  + 165176a  + 824560a  + 2452288a
+--R                + 
+--R                          2
+--R                  4340224a  + 4229120a + 1748992
+--R             *
+--R                x
+--R            + 
+--R                  8        7         6          5           4           3
+--R              - 5a  - 2898a  - 63061a  - 591836a  - 3072248a  - 9506496a
+--R            + 
+--R                         2
+--R              - 17520384a  - 17798144a - 7684096
+--R     + 
+--R                    2             4      2             3
+--R               (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x
+--R             + 
+--R                   2               2       2                    3      2
+--R             (- 16a  - 112a - 192)x  + (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R          *
+--R             ROOT
+--R                             6        5         4         3          2
+--R                        - 96a  - 2016a  - 17568a  - 81312a  - 210816a  - 290304a
+--R                      + 
+--R                        - 165888
+--R                   *
+--R                           2
+--R                      %%BP1
+--R                  + 
+--R                             6        5         4         3          2
+--R                        - 64a  - 1344a  - 11712a  - 54208a  - 140544a  - 193536a
+--R                      + 
+--R                        - 110592
+--R                   *
+--R                      %%BP0 %%BP1
+--R                  + 
+--R                             6        5         4         3          2
+--R                        - 96a  - 2016a  - 17568a  - 81312a  - 210816a  - 290304a
+--R                      + 
+--R                        - 165888
+--R                   *
+--R                           2
+--R                      %%BP0
+--R                  + 
+--R                       3       2
+--R                    19a  + 181a  + 584a + 640
+--R               /
+--R                     6       5        4         3         2
+--R                  32a  + 672a  + 5856a  + 27104a  + 70272a  + 96768a + 55296
+--R         + 
+--R                    2             4      2             3
+--R               (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x
+--R             + 
+--R                   2               2       2                    3      2
+--R             (- 16a  - 112a - 192)x  + (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R          *
+--R             %%BP1
+--R         + 
+--R                    2             4      2             3
+--R               (- 2a  - 14a - 24)x  + (8a  + 56a + 96)x
+--R             + 
+--R                   2               2       2                    3      2
+--R             (- 16a  - 112a - 192)x  + (16a  + 112a + 192)x + 2a  + 14a  + 24a
+--R          *
+--R             %%BP0
+--R      *
+--R         log
+--R                                 12         11           10            9
+--R                          - 2048a   + 30720a   + 2740224a   + 55701504a
+--R                        + 
+--R                                    8              7               6
+--R                          613586944a  + 4341438464a  + 21093720064a
+--R                        + 
+--R                                      5                4                3
+--R                          72315142144a  + 175486140416a  + 295875117056a
+--R                        + 
+--R                                       2
+--R                          330358063104a  + 219924135936a + 66135785472
+--R                     *
+--R                        %%BP0
+--R                    + 
+--R                              10          9           8            7
+--R                      - 14336a   - 496640a  - 7700480a  - 70371328a
+--R                    + 
+--R                                  6              5              4              3
+--R                      - 419731456a  - 1707213824a  - 4795043840a  - 9181773824a
+--R                    + 
+--R                                    2
+--R                      - 11469127680a  - 8436842496a - 2774532096
+--R                 *
+--R                    %%BP1
+--R                + 
+--R                              10          9           8            7
+--R                      - 14336a   - 496640a  - 7700480a  - 70371328a
+--R                    + 
+--R                                  6              5              4              3
+--R                      - 419731456a  - 1707213824a  - 4795043840a  - 9181773824a
+--R                    + 
+--R                                    2
+--R                      - 11469127680a  - 8436842496a - 2774532096
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                      9         8          7           6            5
+--R                  120a  + 11096a  + 240168a  + 2518856a  + 15490240a
+--R                + 
+--R                         4             3             2
+--R                60021248a  + 149084160a  + 231098368a  + 204029952a + 78446592
+--R             *
+--R                ROOT
+--R                                6        5         4         3          2
+--R                           - 96a  - 2016a  - 17568a  - 81312a  - 210816a
+--R                         + 
+--R                           - 290304a - 165888
+--R                      *
+--R                              2
+--R                         %%BP1
+--R                     + 
+--R                                6        5         4         3          2
+--R                           - 64a  - 1344a  - 11712a  - 54208a  - 140544a
+--R                         + 
+--R                           - 193536a - 110592
+--R                      *
+--R                         %%BP0 %%BP1
+--R                     + 
+--R                                6        5         4         3          2
+--R                           - 96a  - 2016a  - 17568a  - 81312a  - 210816a
+--R                         + 
+--R                           - 290304a - 165888
+--R                      *
+--R                              2
+--R                         %%BP0
+--R                     + 
+--R                          3       2
+--R                       19a  + 181a  + 584a + 640
+--R                  /
+--R                        6       5        4         3         2
+--R                     32a  + 672a  + 5856a  + 27104a  + 70272a  + 96768a + 55296
+--R            + 
+--R                           12         11           10            9             8
+--R                      2048a   - 30720a   - 2740224a   - 55701504a  - 613586944a
+--R                    + 
+--R                                   7               6               5
+--R                      - 4341438464a  - 21093720064a  - 72315142144a
+--R                    + 
+--R                                     4                3                2
+--R                      - 175486140416a  - 295875117056a  - 330358063104a
+--R                    + 
+--R                      - 219924135936a - 66135785472
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                        10          9           8            7             6
+--R                  14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                + 
+--R                             5              4              3               2
+--R                  1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                + 
+--R                  8436842496a + 2774532096
+--R             *
+--R                     2
+--R                %%BP1
+--R            + 
+--R                           12         11           10            9             8
+--R                      2048a   - 30720a   - 2740224a   - 55701504a  - 613586944a
+--R                    + 
+--R                                   7               6               5
+--R                      - 4341438464a  - 21093720064a  - 72315142144a
+--R                    + 
+--R                                     4                3                2
+--R                      - 175486140416a  - 295875117056a  - 330358063104a
+--R                    + 
+--R                      - 219924135936a - 66135785472
+--R                 *
+--R                         2
+--R                    %%BP0
+--R                + 
+--R                      9         8          7           6            5
+--R                  120a  + 11096a  + 240168a  + 2518856a  + 15490240a
+--R                + 
+--R                         4             3             2
+--R                60021248a  + 149084160a  + 231098368a  + 204029952a + 78446592
+--R             *
+--R                %%BP1
+--R            + 
+--R                        10          9           8            7             6
+--R                  14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                + 
+--R                             5              4              3               2
+--R                  1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                + 
+--R                  8436842496a + 2774532096
+--R             *
+--R                     2
+--R                %%BP0
+--R            + 
+--R                      9         8          7           6            5
+--R                  120a  + 11096a  + 240168a  + 2518856a  + 15490240a
+--R                + 
+--R                         4             3             2
+--R                60021248a  + 149084160a  + 231098368a  + 204029952a + 78446592
+--R             *
+--R                %%BP0
+--R            + 
+--R                   8       7         6          5          4           3
+--R                  a  + 870a  + 18289a  + 165176a  + 824560a  + 2452288a
+--R                + 
+--R                          2
+--R                  4340224a  + 4229120a + 1748992
+--R             *
+--R                x
+--R            + 
+--R                  8        7         6          5           4           3
+--R              - 5a  - 2898a  - 63061a  - 591836a  - 3072248a  - 9506496a
+--R            + 
+--R                         2
+--R              - 17520384a  - 17798144a - 7684096
+--R     + 
+--R              2             4         2               3       2               2
+--R           (4a  + 28a + 48)x  + (- 16a  - 112a - 192)x  + (32a  + 224a + 384)x
+--R         + 
+--R                 2                    3      2
+--R           (- 32a  - 224a - 384)x - 4a  - 28a  - 48a
+--R      *
+--R         %%BP1
+--R      *
+--R         log
+--R                             12         11           10             9
+--R                      - 4096a   + 61440a   + 5480448a   + 111403008a
+--R                    + 
+--R                                 8              7               6
+--R                      1227173888a  + 8682876928a  + 42187440128a
+--R                    + 
+--R                                   5                4                3
+--R                      144630284288a  + 350972280832a  + 591750234112a
+--R                    + 
+--R                                   2
+--R                      660716126208a  + 439848271872a + 132271570944
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                          10          9            8             7             6
+--R                  - 28672a   - 993280a  - 15400960a  - 140742656a  - 839462912a
+--R                + 
+--R                               5              4               3               2
+--R                  - 3414427648a  - 9590087680a  - 18363547648a  - 22938255360a
+--R                + 
+--R                  - 16873684992a - 5549064192
+--R             *
+--R                     2
+--R                %%BP1
+--R            + 
+--R                             12         11           10             9
+--R                      - 4096a   + 61440a   + 5480448a   + 111403008a
+--R                    + 
+--R                                 8              7               6
+--R                      1227173888a  + 8682876928a  + 42187440128a
+--R                    + 
+--R                                   5                4                3
+--R                      144630284288a  + 350972280832a  + 591750234112a
+--R                    + 
+--R                                   2
+--R                      660716126208a  + 439848271872a + 132271570944
+--R                 *
+--R                         2
+--R                    %%BP0
+--R                + 
+--R                        9         8          7           6            5
+--R                  - 240a  - 22192a  - 480336a  - 5037712a  - 30980480a
+--R                + 
+--R                              4             3             2
+--R                  - 120042496a  - 298168320a  - 462196736a  - 408059904a
+--R                + 
+--R                  - 156893184
+--R             *
+--R                %%BP1
+--R            + 
+--R                         12         11           10             9              8
+--R                  - 4096a   + 61440a   + 5480448a   + 111403008a  + 1227173888a
+--R                + 
+--R                             7               6                5                4
+--R                  8682876928a  + 42187440128a  + 144630284288a  + 350972280832a
+--R                + 
+--R                             3                2
+--R                591750234112a  + 660716126208a  + 439848271872a + 132271570944
+--R             *
+--R                     3
+--R                %%BP0
+--R            + 
+--R                      9         8          7           6            5
+--R                  608a  - 16096a  - 654944a  - 8361504a  - 57256704a
+--R                + 
+--R                              4             3              2
+--R                  - 239051776a  - 630185984a  - 1028694016a  - 952172544a
+--R                + 
+--R                  - 382730240
+--R             *
+--R                %%BP0
+--R            + 
+--R                   8       7         6          5          4           3
+--R                  a  + 870a  + 18289a  + 165176a  + 824560a  + 2452288a
+--R                + 
+--R                          2
+--R                  4340224a  + 4229120a + 1748992
+--R             *
+--R                x
+--R            + 
+--R                  8        7         6          5           4           3
+--R              - 5a  + 1358a  + 35547a  + 380004a  + 2213624a  + 7636288a
+--R            + 
+--R                       2
+--R              15630080a  + 17579008a + 8372224
+--R     + 
+--R              2             4         2               3       2               2
+--R           (4a  + 28a + 48)x  + (- 16a  - 112a - 192)x  + (32a  + 224a + 384)x
+--R         + 
+--R                 2                    3      2
+--R           (- 32a  - 224a - 384)x - 4a  - 28a  - 48a
+--R      *
+--R         %%BP0
+--R      *
+--R         log
+--R                       12         11           10             9              8
+--R                  4096a   - 61440a   - 5480448a   - 111403008a  - 1227173888a
+--R                + 
+--R                               7               6                5
+--R                  - 8682876928a  - 42187440128a  - 144630284288a
+--R                + 
+--R                                 4                3                2
+--R                  - 350972280832a  - 591750234112a  - 660716126208a
+--R                + 
+--R                  - 439848271872a - 132271570944
+--R             *
+--R                     3
+--R                %%BP0
+--R            + 
+--R                          10          9            8             7             6
+--R                  - 28672a   - 993280a  - 15400960a  - 140742656a  - 839462912a
+--R                + 
+--R                               5              4               3               2
+--R                  - 3414427648a  - 9590087680a  - 18363547648a  - 22938255360a
+--R                + 
+--R                  - 16873684992a - 5549064192
+--R             *
+--R                     2
+--R                %%BP0
+--R            + 
+--R                        9        8          7           6            5
+--R                  - 848a  - 6096a  + 174608a  + 3323792a  + 26276224a
+--R                + 
+--R                          4             3             2
+--R                119009280a  + 332017664a  + 566497280a  + 544112640a + 225837056
+--R             *
+--R                %%BP0
+--R            + 
+--R                   8       7         6          5          4           3
+--R                  a  + 870a  + 18289a  + 165176a  + 824560a  + 2452288a
+--R                + 
+--R                          2
+--R                  4340224a  + 4229120a + 1748992
+--R             *
+--R                x
+--R            + 
+--R                 8       7         6          5          4           3
+--R              11a  + 958a  + 17419a  + 142964a  + 632632a  + 1567552a
+--R            + 
+--R                      2
+--R              2049792a  + 1100800a
+--R     + 
+--R                 3           2
+--R       (- a - 4)x  + (a + 6)x  + (- a - 8)x - a
+--R  /
+--R          2             4         2               3       2               2
+--R       (4a  + 28a + 48)x  + (- 16a  - 112a - 192)x  + (32a  + 224a + 384)x
+--R     + 
+--R             2                    3      2
+--R       (- 32a  - 224a - 384)x - 4a  - 28a  - 48a
+--R                                         Type: Union(Expression(Integer),...)
+--E 332
+
+--S 333 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +--------------+ +------------+
+--R                2             +-----+ |   +-----+      | +-----+
+--R             (4a  + 28a + 48)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R          *
+--R             ROOT
+--R                             6        5         4         3          2
+--R                        - 96a  - 2016a  - 17568a  - 81312a  - 210816a  - 290304a
+--R                      + 
+--R                        - 165888
+--R                   *
+--R                           2
+--R                      %%BP1
+--R                  + 
+--R                             6        5         4         3          2
+--R                        - 64a  - 1344a  - 11712a  - 54208a  - 140544a  - 193536a
+--R                      + 
+--R                        - 110592
+--R                   *
+--R                      %%BP0 %%BP1
+--R                  + 
+--R                             6        5         4         3          2
+--R                        - 96a  - 2016a  - 17568a  - 81312a  - 210816a  - 290304a
+--R                      + 
+--R                        - 165888
+--R                   *
+--R                           2
+--R                      %%BP0
+--R                  + 
+--R                       3       2
+--R                    19a  + 181a  + 584a + 640
+--R               /
+--R                     6       5        4         3         2
+--R                  32a  + 672a  + 5856a  + 27104a  + 70272a  + 96768a + 55296
+--R         + 
+--R                                      +--------------+ +------------+
+--R                2             +-----+ |   +-----+      | +-----+
+--R           (- 4a  - 28a - 48)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BP1
+--R         + 
+--R                                           +--------------+ +------------+
+--R                2             +-----+      |   +-----+      | +-----+
+--R           (- 4a  - 28a - 48)\|a + 4 %%BP0\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R      *
+--R         log
+--R                               12         11           10            9
+--R                          2048a   - 30720a   - 2740224a   - 55701504a
+--R                        + 
+--R                                      8              7               6
+--R                          - 613586944a  - 4341438464a  - 21093720064a
+--R                        + 
+--R                                        5                4                3
+--R                          - 72315142144a  - 175486140416a  - 295875117056a
+--R                        + 
+--R                                         2
+--R                          - 330358063104a  - 219924135936a - 66135785472
+--R                     *
+--R                        %%BP0
+--R                    + 
+--R                            10          9           8            7             6
+--R                      14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                    + 
+--R                                 5              4              3               2
+--R                      1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                    + 
+--R                      8436842496a + 2774532096
+--R                 *
+--R                    %%BP1
+--R                + 
+--R                            10          9           8            7             6
+--R                      14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                    + 
+--R                                 5              4              3               2
+--R                      1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                    + 
+--R                      8436842496a + 2774532096
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                        9         8          7           6            5
+--R                  - 120a  - 11096a  - 240168a  - 2518856a  - 15490240a
+--R                + 
+--R                           4             3             2
+--R                - 60021248a  - 149084160a  - 231098368a  - 204029952a - 78446592
+--R             *
+--R                ROOT
+--R                                6        5         4         3          2
+--R                           - 96a  - 2016a  - 17568a  - 81312a  - 210816a
+--R                         + 
+--R                           - 290304a - 165888
+--R                      *
+--R                              2
+--R                         %%BP1
+--R                     + 
+--R                                6        5         4         3          2
+--R                           - 64a  - 1344a  - 11712a  - 54208a  - 140544a
+--R                         + 
+--R                           - 193536a - 110592
+--R                      *
+--R                         %%BP0 %%BP1
+--R                     + 
+--R                                6        5         4         3          2
+--R                           - 96a  - 2016a  - 17568a  - 81312a  - 210816a
+--R                         + 
+--R                           - 290304a - 165888
+--R                      *
+--R                              2
+--R                         %%BP0
+--R                     + 
+--R                          3       2
+--R                       19a  + 181a  + 584a + 640
+--R                  /
+--R                        6       5        4         3         2
+--R                     32a  + 672a  + 5856a  + 27104a  + 70272a  + 96768a + 55296
+--R            + 
+--R                           12         11           10            9             8
+--R                      2048a   - 30720a   - 2740224a   - 55701504a  - 613586944a
+--R                    + 
+--R                                   7               6               5
+--R                      - 4341438464a  - 21093720064a  - 72315142144a
+--R                    + 
+--R                                     4                3                2
+--R                      - 175486140416a  - 295875117056a  - 330358063104a
+--R                    + 
+--R                      - 219924135936a - 66135785472
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                        10          9           8            7             6
+--R                  14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                + 
+--R                             5              4              3               2
+--R                  1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                + 
+--R                  8436842496a + 2774532096
+--R             *
+--R                     2
+--R                %%BP1
+--R            + 
+--R                           12         11           10            9             8
+--R                      2048a   - 30720a   - 2740224a   - 55701504a  - 613586944a
+--R                    + 
+--R                                   7               6               5
+--R                      - 4341438464a  - 21093720064a  - 72315142144a
+--R                    + 
+--R                                     4                3                2
+--R                      - 175486140416a  - 295875117056a  - 330358063104a
+--R                    + 
+--R                      - 219924135936a - 66135785472
+--R                 *
+--R                         2
+--R                    %%BP0
+--R                + 
+--R                      9         8          7           6            5
+--R                  120a  + 11096a  + 240168a  + 2518856a  + 15490240a
+--R                + 
+--R                         4             3             2
+--R                60021248a  + 149084160a  + 231098368a  + 204029952a + 78446592
+--R             *
+--R                %%BP1
+--R            + 
+--R                        10          9           8            7             6
+--R                  14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                + 
+--R                             5              4              3               2
+--R                  1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                + 
+--R                  8436842496a + 2774532096
+--R             *
+--R                     2
+--R                %%BP0
+--R            + 
+--R                      9         8          7           6            5
+--R                  120a  + 11096a  + 240168a  + 2518856a  + 15490240a
+--R                + 
+--R                         4             3             2
+--R                60021248a  + 149084160a  + 231098368a  + 204029952a + 78446592
+--R             *
+--R                %%BP0
+--R            + 
+--R                   8       7         6          5          4           3
+--R                  a  + 870a  + 18289a  + 165176a  + 824560a  + 2452288a
+--R                + 
+--R                          2
+--R                  4340224a  + 4229120a + 1748992
+--R             *
+--R                x
+--R            + 
+--R                  8        7         6          5           4           3
+--R              - 5a  - 2898a  - 63061a  - 591836a  - 3072248a  - 9506496a
+--R            + 
+--R                         2
+--R              - 17520384a  - 17798144a - 7684096
+--R     + 
+--R                                        +--------------+ +------------+
+--R                  2             +-----+ |   +-----+      | +-----+
+--R             (- 4a  - 28a - 48)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R          *
+--R             ROOT
+--R                             6        5         4         3          2
+--R                        - 96a  - 2016a  - 17568a  - 81312a  - 210816a  - 290304a
+--R                      + 
+--R                        - 165888
+--R                   *
+--R                           2
+--R                      %%BP1
+--R                  + 
+--R                             6        5         4         3          2
+--R                        - 64a  - 1344a  - 11712a  - 54208a  - 140544a  - 193536a
+--R                      + 
+--R                        - 110592
+--R                   *
+--R                      %%BP0 %%BP1
+--R                  + 
+--R                             6        5         4         3          2
+--R                        - 96a  - 2016a  - 17568a  - 81312a  - 210816a  - 290304a
+--R                      + 
+--R                        - 165888
+--R                   *
+--R                           2
+--R                      %%BP0
+--R                  + 
+--R                       3       2
+--R                    19a  + 181a  + 584a + 640
+--R               /
+--R                     6       5        4         3         2
+--R                  32a  + 672a  + 5856a  + 27104a  + 70272a  + 96768a + 55296
+--R         + 
+--R                                      +--------------+ +------------+
+--R                2             +-----+ |   +-----+      | +-----+
+--R           (- 4a  - 28a - 48)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BP1
+--R         + 
+--R                                           +--------------+ +------------+
+--R                2             +-----+      |   +-----+      | +-----+
+--R           (- 4a  - 28a - 48)\|a + 4 %%BP0\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R      *
+--R         log
+--R                                 12         11           10            9
+--R                          - 2048a   + 30720a   + 2740224a   + 55701504a
+--R                        + 
+--R                                    8              7               6
+--R                          613586944a  + 4341438464a  + 21093720064a
+--R                        + 
+--R                                      5                4                3
+--R                          72315142144a  + 175486140416a  + 295875117056a
+--R                        + 
+--R                                       2
+--R                          330358063104a  + 219924135936a + 66135785472
+--R                     *
+--R                        %%BP0
+--R                    + 
+--R                              10          9           8            7
+--R                      - 14336a   - 496640a  - 7700480a  - 70371328a
+--R                    + 
+--R                                  6              5              4              3
+--R                      - 419731456a  - 1707213824a  - 4795043840a  - 9181773824a
+--R                    + 
+--R                                    2
+--R                      - 11469127680a  - 8436842496a - 2774532096
+--R                 *
+--R                    %%BP1
+--R                + 
+--R                              10          9           8            7
+--R                      - 14336a   - 496640a  - 7700480a  - 70371328a
+--R                    + 
+--R                                  6              5              4              3
+--R                      - 419731456a  - 1707213824a  - 4795043840a  - 9181773824a
+--R                    + 
+--R                                    2
+--R                      - 11469127680a  - 8436842496a - 2774532096
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                      9         8          7           6            5
+--R                  120a  + 11096a  + 240168a  + 2518856a  + 15490240a
+--R                + 
+--R                         4             3             2
+--R                60021248a  + 149084160a  + 231098368a  + 204029952a + 78446592
+--R             *
+--R                ROOT
+--R                                6        5         4         3          2
+--R                           - 96a  - 2016a  - 17568a  - 81312a  - 210816a
+--R                         + 
+--R                           - 290304a - 165888
+--R                      *
+--R                              2
+--R                         %%BP1
+--R                     + 
+--R                                6        5         4         3          2
+--R                           - 64a  - 1344a  - 11712a  - 54208a  - 140544a
+--R                         + 
+--R                           - 193536a - 110592
+--R                      *
+--R                         %%BP0 %%BP1
+--R                     + 
+--R                                6        5         4         3          2
+--R                           - 96a  - 2016a  - 17568a  - 81312a  - 210816a
+--R                         + 
+--R                           - 290304a - 165888
+--R                      *
+--R                              2
+--R                         %%BP0
+--R                     + 
+--R                          3       2
+--R                       19a  + 181a  + 584a + 640
+--R                  /
+--R                        6       5        4         3         2
+--R                     32a  + 672a  + 5856a  + 27104a  + 70272a  + 96768a + 55296
+--R            + 
+--R                           12         11           10            9             8
+--R                      2048a   - 30720a   - 2740224a   - 55701504a  - 613586944a
+--R                    + 
+--R                                   7               6               5
+--R                      - 4341438464a  - 21093720064a  - 72315142144a
+--R                    + 
+--R                                     4                3                2
+--R                      - 175486140416a  - 295875117056a  - 330358063104a
+--R                    + 
+--R                      - 219924135936a - 66135785472
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                        10          9           8            7             6
+--R                  14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                + 
+--R                             5              4              3               2
+--R                  1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                + 
+--R                  8436842496a + 2774532096
+--R             *
+--R                     2
+--R                %%BP1
+--R            + 
+--R                           12         11           10            9             8
+--R                      2048a   - 30720a   - 2740224a   - 55701504a  - 613586944a
+--R                    + 
+--R                                   7               6               5
+--R                      - 4341438464a  - 21093720064a  - 72315142144a
+--R                    + 
+--R                                     4                3                2
+--R                      - 175486140416a  - 295875117056a  - 330358063104a
+--R                    + 
+--R                      - 219924135936a - 66135785472
+--R                 *
+--R                         2
+--R                    %%BP0
+--R                + 
+--R                      9         8          7           6            5
+--R                  120a  + 11096a  + 240168a  + 2518856a  + 15490240a
+--R                + 
+--R                         4             3             2
+--R                60021248a  + 149084160a  + 231098368a  + 204029952a + 78446592
+--R             *
+--R                %%BP1
+--R            + 
+--R                        10          9           8            7             6
+--R                  14336a   + 496640a  + 7700480a  + 70371328a  + 419731456a
+--R                + 
+--R                             5              4              3               2
+--R                  1707213824a  + 4795043840a  + 9181773824a  + 11469127680a
+--R                + 
+--R                  8436842496a + 2774532096
+--R             *
+--R                     2
+--R                %%BP0
+--R            + 
+--R                      9         8          7           6            5
+--R                  120a  + 11096a  + 240168a  + 2518856a  + 15490240a
+--R                + 
+--R                         4             3             2
+--R                60021248a  + 149084160a  + 231098368a  + 204029952a + 78446592
+--R             *
+--R                %%BP0
+--R            + 
+--R                   8       7         6          5          4           3
+--R                  a  + 870a  + 18289a  + 165176a  + 824560a  + 2452288a
+--R                + 
+--R                          2
+--R                  4340224a  + 4229120a + 1748992
+--R             *
+--R                x
+--R            + 
+--R                  8        7         6          5           4           3
+--R              - 5a  - 2898a  - 63061a  - 591836a  - 3072248a  - 9506496a
+--R            + 
+--R                         2
+--R              - 17520384a  - 17798144a - 7684096
+--R     + 
+--R                                  +--------------+ +------------+
+--R            2             +-----+ |   +-----+      | +-----+
+--R         (8a  + 56a + 96)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1 %%BP1
+--R      *
+--R         log
+--R                             12         11           10             9
+--R                      - 4096a   + 61440a   + 5480448a   + 111403008a
+--R                    + 
+--R                                 8              7               6
+--R                      1227173888a  + 8682876928a  + 42187440128a
+--R                    + 
+--R                                   5                4                3
+--R                      144630284288a  + 350972280832a  + 591750234112a
+--R                    + 
+--R                                   2
+--R                      660716126208a  + 439848271872a + 132271570944
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                          10          9            8             7             6
+--R                  - 28672a   - 993280a  - 15400960a  - 140742656a  - 839462912a
+--R                + 
+--R                               5              4               3               2
+--R                  - 3414427648a  - 9590087680a  - 18363547648a  - 22938255360a
+--R                + 
+--R                  - 16873684992a - 5549064192
+--R             *
+--R                     2
+--R                %%BP1
+--R            + 
+--R                             12         11           10             9
+--R                      - 4096a   + 61440a   + 5480448a   + 111403008a
+--R                    + 
+--R                                 8              7               6
+--R                      1227173888a  + 8682876928a  + 42187440128a
+--R                    + 
+--R                                   5                4                3
+--R                      144630284288a  + 350972280832a  + 591750234112a
+--R                    + 
+--R                                   2
+--R                      660716126208a  + 439848271872a + 132271570944
+--R                 *
+--R                         2
+--R                    %%BP0
+--R                + 
+--R                        9         8          7           6            5
+--R                  - 240a  - 22192a  - 480336a  - 5037712a  - 30980480a
+--R                + 
+--R                              4             3             2
+--R                  - 120042496a  - 298168320a  - 462196736a  - 408059904a
+--R                + 
+--R                  - 156893184
+--R             *
+--R                %%BP1
+--R            + 
+--R                         12         11           10             9              8
+--R                  - 4096a   + 61440a   + 5480448a   + 111403008a  + 1227173888a
+--R                + 
+--R                             7               6                5                4
+--R                  8682876928a  + 42187440128a  + 144630284288a  + 350972280832a
+--R                + 
+--R                             3                2
+--R                591750234112a  + 660716126208a  + 439848271872a + 132271570944
+--R             *
+--R                     3
+--R                %%BP0
+--R            + 
+--R                      9         8          7           6            5
+--R                  608a  - 16096a  - 654944a  - 8361504a  - 57256704a
+--R                + 
+--R                              4             3              2
+--R                  - 239051776a  - 630185984a  - 1028694016a  - 952172544a
+--R                + 
+--R                  - 382730240
+--R             *
+--R                %%BP0
+--R            + 
+--R                   8       7         6          5          4           3
+--R                  a  + 870a  + 18289a  + 165176a  + 824560a  + 2452288a
+--R                + 
+--R                          2
+--R                  4340224a  + 4229120a + 1748992
+--R             *
+--R                x
+--R            + 
+--R                  8        7         6          5           4           3
+--R              - 5a  + 1358a  + 35547a  + 380004a  + 2213624a  + 7636288a
+--R            + 
+--R                       2
+--R              15630080a  + 17579008a + 8372224
+--R     + 
+--R                                 +------------+
+--R                +-----+          | +-----+                x - 1
+--R       ((a + 4)\|a + 4  + a + 4)\|\|a + 4  + 1 atan(-----------------)
+--R                                                     +--------------+
+--R                                                     |   +-----+
+--R                                                    \|- \|a + 4  + 1
+--R     + 
+--R                                 +--------------+
+--R                +-----+          |   +-----+               x - 1
+--R       ((a + 4)\|a + 4  - a - 4)\|- \|a + 4  + 1 atan(---------------)
+--R                                                       +------------+
+--R                                                       | +-----+
+--R                                                      \|\|a + 4  + 1
+--R     + 
+--R                2             +-----+
+--R             (8a  + 56a + 96)\|a + 4 %%BP0
+--R          *
+--R             log
+--R                           12         11           10             9
+--R                      4096a   - 61440a   - 5480448a   - 111403008a
+--R                    + 
+--R                                   8              7               6
+--R                      - 1227173888a  - 8682876928a  - 42187440128a
+--R                    + 
+--R                                     5                4                3
+--R                      - 144630284288a  - 350972280832a  - 591750234112a
+--R                    + 
+--R                                     2
+--R                      - 660716126208a  - 439848271872a - 132271570944
+--R                 *
+--R                         3
+--R                    %%BP0
+--R                + 
+--R                              10          9            8             7
+--R                      - 28672a   - 993280a  - 15400960a  - 140742656a
+--R                    + 
+--R                                  6              5              4
+--R                      - 839462912a  - 3414427648a  - 9590087680a
+--R                    + 
+--R                                  3               2
+--R                    - 18363547648a  - 22938255360a  - 16873684992a - 5549064192
+--R                 *
+--R                         2
+--R                    %%BP0
+--R                + 
+--R                            9        8          7           6            5
+--R                      - 848a  - 6096a  + 174608a  + 3323792a  + 26276224a
+--R                    + 
+--R                                4             3             2
+--R                      119009280a  + 332017664a  + 566497280a  + 544112640a
+--R                    + 
+--R                      225837056
+--R                 *
+--R                    %%BP0
+--R                + 
+--R                       8       7         6          5          4           3
+--R                      a  + 870a  + 18289a  + 165176a  + 824560a  + 2452288a
+--R                    + 
+--R                              2
+--R                      4340224a  + 4229120a + 1748992
+--R                 *
+--R                    x
+--R                + 
+--R                     8       7         6          5          4           3
+--R                  11a  + 958a  + 17419a  + 142964a  + 632632a  + 1567552a
+--R                + 
+--R                          2
+--R                  2049792a  + 1100800a
+--R         + 
+--R                             2
+--R                            x  - 2x + 2
+--R           (- 4a - 12)atanh(-----------)
+--R                               +-----+
+--R                              \|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R                              +--------------+ +------------+
+--R        2             +-----+ |   +-----+      | +-----+
+--R     (8a  + 56a + 96)\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 333
+
+--S 334 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 334
+
+)clear all
+
+--S 335 of 534
+t0:=(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                    +-------------------------+
+--R            4     3     2           |   4     3     2
+--R   (1)  (- x  + 4x  - 8x  + 8x + a)\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 534
+--r0:=1/7*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2)*(-1+x)+2/35*(13+5*a-3*(-1+x)^2)*_
+--   (-1+x)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4)-16/35*(7+2*a)*_
+--   elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*_
+--   (1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+4/35*_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*_
+--   (76+5*a^2+28*sqrt(4+a)+a*(39+8*sqrt(4+a)))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 336
+
+--S 337 of 534
+--a0:=integrate(t0,x)
+--E 337
+
+--S 338 of 534
+--m0:=a0-r0
+--E 338
+
+--S 339 of 534
+--d0:=D(m0,x)
+--E 339
+
+)clear all
+
+--S 340 of 534
+t0:=(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R         +-------------------------+
+--R         |   4     3     2
+--R   (1)  \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 534
+--r0:=1/3*(-1+x)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4)-2/3*elliptic_e(asin((-1+x)/_
+--   sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+2/3*_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*_
+--   (4+a+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 341
+
+--S 342 of 534
+--a0:=integrate(t0,x)
+--E 342
+
+--S 343 of 534
+--m0:=a0-r0
+--E 343
+
+--S 344 of 534
+--d0:=D(m0,x)
+--E 344
+
+)clear all
+
+--S 345 of 534
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R         +-------------------------+
+--R         |   4     3     2
+--R        \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 345
+
+--S 346 of 534
+--r0:=elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+_
+--   sqrt(4+a)))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 346
+
+--S 347 of 534
+--a0:=integrate(t0,x)
+--E 347
+
+--S 348 of 534
+--m0:=a0-r0
+--E 348
+
+--S 349 of 534
+--d0:=D(m0,x)
+--E 349
+
+)clear all
+
+--S 350 of 534
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                    1
+--R   (1)  - -----------------------------------------------------
+--R                                    +-------------------------+
+--R            4     3     2           |   4     3     2
+--R          (x  - 4x  + 8x  - 8x - a)\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 534
+--r0:=1/2*(5+a+(-1+x)^2)*(-1+x)/((12+7*a+a^2)*sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4))-1/2*elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   ((3+a)*(4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*elliptic_f(asin((-1+x)/_
+--   sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(4+a+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/((3+a)*(4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 351
+
+--S 352 of 534
+--a0:=integrate(t0,x)
+--E 352
+
+--S 353 of 534
+--m0:=a0-r0
+--E 353
+
+--S 354 of 534
+--d0:=D(m0,x)
+--E 354
+
+)clear all
+
+--S 355 of 534
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)^(5/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          8     7      6      5                4              3                2
+--R         x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R       + 
+--R                  2
+--R         16a x + a
+--R    *
+--R        +-------------------------+
+--R        |   4     3     2
+--R       \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 534
+--r0:=1/6*(5+a+(-1+x)^2)*(-1+x)/((12+7*a+a^2)*(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)^(3/2))+1/12*(104+47*a+5*a^2+4*(7+2*a)*(-1+x)^2)*(-1+x)/_
+--   ((3+a)^2*(4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))-1/3*(7+2*a)*_
+--   elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*_
+--   (1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/((3+a)^2*(4+a)^2*sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4))+1/12*elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(76+5*a^2+28*sqrt(4+a)+a*(39+8*sqrt(4+a)))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/((3+a)^2*(4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 356
+
+--S 357 of 534
+--a0:=integrate(t0,x)
+--E 357
+
+--S 358 of 534
+--m0:=a0-r0
+--E 358
+
+--S 359 of 534
+--d0:=D(m0,x)
+--E 359
+
+)clear all
+
+--S 360 of 534
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                       +-------------------------+
+--R            5     4     3     2        |   4     3     2
+--R   (1)  (- x  + 4x  - 8x  + 8x  + a x)\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 360
+
+--S 361 of 534
+--r0:=1/8*(1+(-1+x)^2)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2)+1/7*(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)^(3/2)*(-1+x)+3/16*(4+a)^2*atan((1+(-1+x)^2)/sqrt(3+a-2*_
+--   (-1+x)^2-(-1+x)^4))+3/16*(4+a)*(1+(-1+x)^2)*sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)+2/35*(13+5*a-3*(-1+x)^2)*(-1+x)*sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)-16/35*(7+2*a)*elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+4/35*elliptic_f(asin((-1+x)/_
+--   sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(76+5*a^2+_
+--   28*sqrt(4+a)+a*(39+8*sqrt(4+a)))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)
+--E 361
+
+--S 362 of 534
+--a0:=integrate(t0,x)
+--E 362
+
+--S 363 of 534
+--m0:=a0-r0
+--E 363
+
+--S 364 of 534
+--d0:=D(m0,x)
+--E 364
+
+)clear all
+
+--S 365 of 534
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R          +-------------------------+
+--R          |   4     3     2
+--R   (1)  x\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 534
+--r0:=1/4*(4+a)*atan((1+(-1+x)^2)/sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+_
+--   1/4*(1+(-1+x)^2)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+1/3*(-1+x)*sqrt(3+a-_
+--   2*(-1+x)^2-(-1+x)^4)-2/3*elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-_
+--   sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+2/3*elliptic_f(asin((-1+x)/sqrt(-1+_
+--   sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(4+a+sqrt(4+a))*sqrt(1+_
+--   (-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+_
+--   sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 366
+
+--S 367 of 534
+--a0:=integrate(t0,x)
+--E 367
+
+--S 368 of 534
+--m0:=a0-r0
+--E 368
+
+--S 369 of 534
+--d0:=D(m0,x)
+--E 369
+
+)clear all
+
+--S 370 of 534
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R                      x
+--R   (1)  ----------------------------
+--R         +-------------------------+
+--R         |   4     3     2
+--R        \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 534
+--r0:=1/2*atan((1+(-1+x)^2)/sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 371
+
+--S 372 of 534
+--a0:=integrate(t0,x)
+--E 372
+
+--S 373 of 534
+--m0:=a0-r0
+--E 373
+
+--S 374 of 534
+--d0:=D(m0,x)
+--E 374
+
+)clear all
+
+--S 375 of 534
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                    x
+--R   (1)  - -----------------------------------------------------
+--R                                    +-------------------------+
+--R            4     3     2           |   4     3     2
+--R          (x  - 4x  + 8x  - 8x - a)\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 375
+
+--S 376 of 534
+--r0:=1/2*(1+(-1+x)^2)/((4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*(5+a+_
+--   (-1+x)^2)*(-1+x)/((12+7*a+a^2)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))-_
+--   1/2*elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/_
+--   (1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/((3+a)*(4+a)*_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*elliptic_f(asin((-1+x)/_
+--   sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(4+a+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/((3+a)*(4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 376
+
+--S 377 of 534
+--a0:=integrate(t0,x)
+--E 377
+
+--S 378 of 534
+--m0:=a0-r0
+--E 378
+
+--S 379 of 534
+--d0:=D(m0,x)
+--E 379
+
+)clear all
+
+--S 380 of 534
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)^(5/2)
+--R 
+--R
+--R   (1)
+--R     x
+--R  /
+--R          8     7      6      5                4              3                2
+--R         x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R       + 
+--R                  2
+--R         16a x + a
+--R    *
+--R        +-------------------------+
+--R        |   4     3     2
+--R       \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 534
+--r0:=1/6*(1+(-1+x)^2)/((4+a)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2))+1/6*(5+_
+--   a+(-1+x)^2)*(-1+x)/((12+7*a+a^2)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2))+_
+--   1/3*(1+(-1+x)^2)/((4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/12*(104+_
+--   47*a+5*a^2+4*(7+2*a)*(-1+x)^2)*(-1+x)/((3+a)^2*(4+a)^2*sqrt(3+a-_
+--   2*(-1+x)^2-(-1+x)^4))-1/3*(7+2*a)*elliptic_e(asin((-1+x)/sqrt(-1+_
+--   sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+_
+--   (-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+_
+--   sqrt(4+a)))/((3+a)^2*(4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/12*_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+_
+--   sqrt(4+a)))*(76+5*a^2+28*sqrt(4+a)+a*(39+8*sqrt(4+a)))*sqrt(1+_
+--   (-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+_
+--   sqrt(4+a)))/((3+a)^2*(4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 381
+
+--S 382 of 534
+--a0:=integrate(t0,x)
+--E 382
+
+--S 383 of 534
+--m0:=a0-r0
+--E 383
+
+--S 384 of 534
+--d0:=D(m0,x)
+--E 384
+
+)clear all
+
+--S 385 of 534
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                        +-------------------------+
+--R            6     5     4     3      2  |   4     3     2
+--R   (1)  (- x  + 4x  - 8x  + 8x  + a x )\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 534
+--r0:=1/4*(1+(-1+x)^2)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2)+1/63*(15+7*(-1+x)^2)*_
+--   (3+a-2*(-1+x)^2-(-1+x)^4)^(3/2)*(-1+x)+3/8*(4+a)^2*atan((1+(-1+x)^2)/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+3/8*(4+a)*(1+(-1+x)^2)*sqrt(3+a-2*_
+--   (-1+x)^2-(-1+x)^4)+2/315*(2*(80+27*a)+3*(20+7*a)*(-1+x)^2)*(-1+x)*_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+4/315*(140+111*a+21*a^2)*_
+--   elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/_
+--   (1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)+4/315*elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(160+88*a+12*a^2-(140+111*a+21*a^2)*_
+--   sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 386
+
+--S 387 of 534
+--a0:=integrate(t0,x)
+--E 387
+
+--S 388 of 534
+--m0:=a0-r0
+--E 388
+
+--S 389 of 534
+--d0:=D(m0,x)
+--E 389
+
+)clear all
+
+--S 390 of 534
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R           +-------------------------+
+--R         2 |   4     3     2
+--R   (1)  x \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 390
+
+--S 391 of 534
+--r0:=1/2*(4+a)*atan((1+(-1+x)^2)/sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+_
+--   1/2*(1+(-1+x)^2)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+1/15*(7+3*(-1+x)^2)*_
+--   (-1+x)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+2/15*(8+3*a)*_
+--   elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+_
+--   sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)+2/15*elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(4+a-(8+3*a)*sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 391
+
+--S 392 of 534
+--a0:=integrate(t0,x)
+--E 392
+
+--S 393 of 534
+--m0:=a0-r0
+--E 393
+
+--S 394 of 534
+--d0:=D(m0,x)
+--E 394
+
+)clear all
+
+--S 395 of 534
+t0:=x^2/(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ----------------------------
+--R         +-------------------------+
+--R         |   4     3     2
+--R        \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 534
+--r0:=atan((1+(-1+x)^2)/sqrt(3+a-2*(-1+x)^2-(-1+x)^4))-_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/_
+--   (1+sqrt(4+a)))*sqrt(4+a)*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)+elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/_
+--   (1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 396
+
+--S 397 of 534
+--a0:=integrate(t0,x)
+--E 397
+
+--S 398 of 534
+--m0:=a0-r0
+--E 398
+
+--S 399 of 534
+--d0:=D(m0,x)
+--E 399
+
+)clear all
+
+--S 400 of 534
+t0:=x^2/(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                     2
+--R                                    x
+--R   (1)  - -----------------------------------------------------
+--R                                    +-------------------------+
+--R            4     3     2           |   4     3     2
+--R          (x  - 4x  + 8x  - 8x - a)\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 534
+--r0:=(1+(-1+x)^2)/((4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*(2+(-1+x)^2)*_
+--   (-1+x)/((3+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))-1/2*_
+--   elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/_
+--   (1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/((3+a)*_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*elliptic_f(asin((-1+x)/_
+--   sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/((3+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 401
+
+--S 402 of 534
+--a0:=integrate(t0,x)
+--E 402
+
+--S 403 of 534
+--m0:=a0-r0
+--E 403
+
+--S 404 of 534
+--d0:=D(m0,x)
+--E 404
+
+)clear all
+
+--S 405 of 534
+t0:=x^2/(a+8*x-8*x^2+4*x^3-x^4)^(5/2)
+--R 
+--R
+--R   (1)
+--R      2
+--R     x
+--R  /
+--R          8     7      6      5                4              3                2
+--R         x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R       + 
+--R                  2
+--R         16a x + a
+--R    *
+--R        +-------------------------+
+--R        |   4     3     2
+--R       \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 405
+
+--S 406 of 534
+--r0:=1/3*(1+(-1+x)^2)/((4+a)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2))+_
+--   1/6*(2+(-1+x)^2)*(-1+x)/((3+a)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2))+_
+--   2/3*(1+(-1+x)^2)/((4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/12*(29+_
+--   7*a+(13+3*a)*(-1+x)^2)*(-1+x)/((3+a)^2*(4+a)*sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4))-1/12*(13+3*a)*elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   ((3+a)^2*(4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/12*_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+_
+--   sqrt(4+a)))*(16+13*sqrt(4+a)+a*(4+3*sqrt(4+a)))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   ((3+a)^2*(4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 406
+
+--S 407 of 534
+--a0:=integrate(t0,x)
+--E 407
+
+--S 408 of 534
+--m0:=a0-r0
+--E 408
+
+--S 409 of 534
+--d0:=D(m0,x)
+--E 409
+
+)clear all
+
+--S 410 of 534
+t0:=(8+8*x-x^3+8*x^4)^4
+--R 
+--R
+--R   (1)
+--R          16        15       14         13         12        11         10
+--R     4096x   - 2048x   + 384x   + 16352x   + 10241x   - 5376x   + 25312x
+--R   + 
+--R           9         8         7         6         5         4         3
+--R     42976x  + 12672x  + 11008x  + 47488x  + 43008x  + 14336x  + 14336x
+--R   + 
+--R           2
+--R     24576x  + 16384x + 4096
+--R                                                    Type: Polynomial(Integer)
+--E 410
+
+--S 411 of 534
+r0:=4096*x+8192*x^2+8192*x^3+3584*x^4+14336/5*x^5+7168*x^6+6784*x^7+_
+   1376*x^8+1408*x^9+21488/5*x^10+25312/11*x^11-448*x^12+10241/13*x^13+_
+   1168*x^14+128/5*x^15-128*x^16+4096/17*x^17
+--R 
+--R
+--R   (2)
+--R     4096  17       16   128  15        14   10241  13       12   25312  11
+--R     ---- x   - 128x   + --- x   + 1168x   + ----- x   - 448x   + ----- x
+--R      17                  5                    13                   11
+--R   + 
+--R     21488  10        9        8        7        6   14336  5        4        3
+--R     ----- x   + 1408x  + 1376x  + 6784x  + 7168x  + ----- x  + 3584x  + 8192x
+--R       5                                               5
+--R   + 
+--R          2
+--R     8192x  + 4096x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 411
+
+--S 412 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     4096  17       16   128  15        14   10241  13       12   25312  11
+--R     ---- x   - 128x   + --- x   + 1168x   + ----- x   - 448x   + ----- x
+--R      17                  5                    13                   11
+--R   + 
+--R     21488  10        9        8        7        6   14336  5        4        3
+--R     ----- x   + 1408x  + 1376x  + 6784x  + 7168x  + ----- x  + 3584x  + 8192x
+--R       5                                               5
+--R   + 
+--R          2
+--R     8192x  + 4096x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 412
+
+--S 413 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 413
+
+--S 414 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 414
+
+)clear all
+
+--S 415 of 534
+t0:=(8+8*x-x^3+8*x^4)^3
+--R 
+--R
+--R   (1)
+--R         12       11      10        9        8       7        6        5
+--R     512x   - 192x   + 24x   + 1535x  + 1152x  - 360x  + 1560x  + 2880x
+--R   + 
+--R          4       3        2
+--R     1152x  + 320x  + 1536x  + 1536x + 512
+--R                                                    Type: Polynomial(Integer)
+--E 415
+
+--S 416 of 534
+r0:=512*x+768*x^2+512*x^3+80*x^4+1152/5*x^5+480*x^6+1560/7*x^7-45*x^8+_
+   128*x^9+307/2*x^10+24/11*x^11-16*x^12+512/13*x^13
+--R 
+--R
+--R   (2)
+--R     512  13      12   24  11   307  10       9      8   1560  7       6
+--R     --- x   - 16x   + -- x   + --- x   + 128x  - 45x  + ---- x  + 480x
+--R      13               11        2                         7
+--R   + 
+--R     1152  5      4       3       2
+--R     ---- x  + 80x  + 512x  + 768x  + 512x
+--R       5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 416
+
+--S 417 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     512  13      12   24  11   307  10       9      8   1560  7       6
+--R     --- x   - 16x   + -- x   + --- x   + 128x  - 45x  + ---- x  + 480x
+--R      13               11        2                         7
+--R   + 
+--R     1152  5      4       3       2
+--R     ---- x  + 80x  + 512x  + 768x  + 512x
+--R       5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 417
+
+--S 418 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 418
+
+--S 419 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 419
+
+)clear all
+
+--S 420 of 534
+t0:=(8+8*x-x^3+8*x^4)^2
+--R 
+--R
+--R           8      7    6       5       4      3      2
+--R   (1)  64x  - 16x  + x  + 128x  + 112x  - 16x  + 64x  + 128x + 64
+--R                                                    Type: Polynomial(Integer)
+--E 420
+
+--S 421 of 534
+r0:=64*x+64*x^2+64/3*x^3-4*x^4+112/5*x^5+64/3*x^6+1/7*x^7-2*x^8+64/9*x^9
+--R 
+--R
+--R        64  9     8   1  7   64  6   112  5     4   64  3      2
+--R   (2)  -- x  - 2x  + - x  + -- x  + --- x  - 4x  + -- x  + 64x  + 64x
+--R         9            7       3       5              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 421
+
+--S 422 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R        64  9     8   1  7   64  6   112  5     4   64  3      2
+--R   (3)  -- x  - 2x  + - x  + -- x  + --- x  - 4x  + -- x  + 64x  + 64x
+--R         9            7       3       5              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 422
+
+--S 423 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 423
+
+--S 424 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 424
+
+)clear all
+
+--S 425 of 534
+t0:=8+8*x-x^3+8*x^4
+--R 
+--R
+--R          4    3
+--R   (1)  8x  - x  + 8x + 8
+--R                                                    Type: Polynomial(Integer)
+--E 425
+
+--S 426 of 534
+r0:=8*x+4*x^2-1/4*x^4+8/5*x^5
+--R 
+--R
+--R        8  5   1  4     2
+--R   (2)  - x  - - x  + 4x  + 8x
+--R        5      4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 426
+
+--S 427 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R        8  5   1  4     2
+--R   (3)  - x  - - x  + 4x  + 8x
+--R        5      4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 427
+
+--S 428 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 428
+
+--S 429 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 429
+
+)clear all
+
+--S 430 of 534
+t0:=1/(8+8*x-x^3+8*x^4)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R          4    3
+--R        8x  - x  + 8x + 8
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 430
+
+--S 431 of 534
+r0:=-1/12*atan(1/6*(3-(1+4/x)^2)/sqrt(7))/sqrt(7)-1/24*log((1+4/x)^2+_
+   3*sqrt(29)-(1+4/x)*sqrt(6*(1+sqrt(29))))*sqrt(1/1218*(-109+_
+   67*sqrt(29)))+1/24*log((1+4/x)^2+3*sqrt(29)+(1+4/x)*sqrt(6*(1+_
+   sqrt(29))))*sqrt(1/1218*(-109+67*sqrt(29)))+1/12*atan((-2*(1+4/x)+_
+   sqrt(6*(1+sqrt(29))))/sqrt(6*(-1+sqrt(29))))*sqrt(1/1218*(109+67*_
+   sqrt(29)))-1/12*atan((2*(1+4/x)+sqrt(6*(1+sqrt(29))))/sqrt(6*(-1+_
+   sqrt(29))))*sqrt(1/1218*(109+67*sqrt(29)))
+--R 
+--R
+--R   (2)
+--R                                         +----------+
+--R            +-------------+      2       |  +--+          2 +--+    2
+--R        +-+ |   +--+           (x  + 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R       \|7 \|67\|29  - 109 log(------------------------------------------------)
+--R                                                       2
+--R                                                      x
+--R     + 
+--R       -
+--R                 +-------------+
+--R             +-+ |   +--+
+--R            \|7 \|67\|29  - 109
+--R         *
+--R                            +----------+
+--R                    2       |  +--+          2 +--+    2
+--R                (- x  - 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R            log(--------------------------------------------------)
+--R                                         2
+--R                                        x
+--R     + 
+--R       -
+--R                  +-------------+
+--R              +-+ |   +--+
+--R            2\|7 \|67\|29  + 109
+--R         *
+--R            atan
+--R                                +----------+ +----------+
+--R                      +--+      |  +--+      |  +--+
+--R                   (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R                 + 
+--R                                            +----------+
+--R                             +--+           |  +--+
+--R                   ((2x + 8)\|29  + 2x + 8)\|6\|29  - 6
+--R              /
+--R                 168x
+--R     + 
+--R               +-------------+
+--R           +-+ |   +--+
+--R         2\|7 \|67\|29  + 109
+--R      *
+--R         atan
+--R                             +----------+ +----------+
+--R                   +--+      |  +--+      |  +--+
+--R                (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R              + 
+--R                                           +----------+
+--R                            +--+           |  +--+
+--R                ((- 2x - 8)\|29  - 2x - 8)\|6\|29  - 6
+--R           /
+--R              168x
+--R     + 
+--R                        2           +-+
+--R           +----+     (x  - 4x - 8)\|7
+--R       - 2\|1218 atan(-----------------)
+--R                                2
+--R                             21x
+--R  /
+--R        +-+ +----+
+--R     24\|7 \|1218
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +-----------------------------------------------+
+--R            |           2                              2          +---+
+--R           \|- 4698%%BQ1  - 3132%%BQ0 %%BQ1 - 4698%%BQ0  - 7  - 3\|174 %%BQ1
+--R         + 
+--R               +---+
+--R           - 3\|174 %%BQ0
+--R      *
+--R         log
+--R                ((5985712404%%BQ0 + 250810560)%%BQ1 + 250810560%%BQ0 + 10452876)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |           2                              2
+--R                \|- 4698%%BQ1  - 3132%%BQ0 %%BQ1 - 4698%%BQ0  - 7
+--R            + 
+--R                           +---+                  +---+      2
+--R              (17957137212\|174 %%BQ0 + 752431680\|174 )%%BQ1
+--R            + 
+--R                           +---+     2            +---+
+--R              (17957137212\|174 %%BQ0  - 31358628\|174 )%%BQ1
+--R            + 
+--R                        +---+     2            +---+
+--R              752431680\|174 %%BQ0  - 31358628\|174 %%BQ0
+--R            + 
+--R                                  +---+
+--R              (2109763x + 220336)\|174
+--R     + 
+--R              +-----------------------------------------------+
+--R              |           2                              2          +---+
+--R           - \|- 4698%%BQ1  - 3132%%BQ0 %%BQ1 - 4698%%BQ0  - 7  - 3\|174 %%BQ1
+--R         + 
+--R               +---+
+--R           - 3\|174 %%BQ0
+--R      *
+--R         log
+--R                    (- 5985712404%%BQ0 - 250810560)%%BQ1 - 250810560%%BQ0
+--R                  + 
+--R                    - 10452876
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |           2                              2
+--R                \|- 4698%%BQ1  - 3132%%BQ0 %%BQ1 - 4698%%BQ0  - 7
+--R            + 
+--R                           +---+                  +---+      2
+--R              (17957137212\|174 %%BQ0 + 752431680\|174 )%%BQ1
+--R            + 
+--R                           +---+     2            +---+
+--R              (17957137212\|174 %%BQ0  - 31358628\|174 )%%BQ1
+--R            + 
+--R                        +---+     2            +---+
+--R              752431680\|174 %%BQ0  - 31358628\|174 %%BQ0
+--R            + 
+--R                                  +---+
+--R              (2109763x + 220336)\|174
+--R     + 
+--R           +---+
+--R         6\|174 %%BQ1
+--R      *
+--R         log
+--R                                                    2
+--R              (- 35914274424%%BQ0 - 1504863360)%%BQ1
+--R            + 
+--R                                 2                                    3
+--R              (- 35914274424%%BQ0  + 62717256)%%BQ1 - 35914274424%%BQ0
+--R            + 
+--R              - 40134087%%BQ0 + 2109763x - 1461344
+--R     + 
+--R           +---+
+--R         6\|174 %%BQ0
+--R      *
+--R         log
+--R                               3                   2
+--R              287314195392%%BQ0  - 12038906880%%BQ0  + 822810744%%BQ0
+--R            + 
+--R              16878104x + 6055613
+--R  /
+--R       +---+
+--R     6\|174
+--R                                         Type: Union(Expression(Integer),...)
+--E 432
+
+--S 433 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        +-----------------------------------------------+
+--R             +-+ +----+ |           2                              2
+--R           4\|7 \|1218 \|- 4698%%BQ1  - 3132%%BQ0 %%BQ1 - 4698%%BQ0  - 7
+--R         + 
+--R                +-+ +---+ +----+           +-+ +---+ +----+
+--R           - 12\|7 \|174 \|1218 %%BQ1 - 12\|7 \|174 \|1218 %%BQ0
+--R      *
+--R         log
+--R                ((5985712404%%BQ0 + 250810560)%%BQ1 + 250810560%%BQ0 + 10452876)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |           2                              2
+--R                \|- 4698%%BQ1  - 3132%%BQ0 %%BQ1 - 4698%%BQ0  - 7
+--R            + 
+--R                           +---+                  +---+      2
+--R              (17957137212\|174 %%BQ0 + 752431680\|174 )%%BQ1
+--R            + 
+--R                           +---+     2            +---+
+--R              (17957137212\|174 %%BQ0  - 31358628\|174 )%%BQ1
+--R            + 
+--R                        +---+     2            +---+
+--R              752431680\|174 %%BQ0  - 31358628\|174 %%BQ0
+--R            + 
+--R                                  +---+
+--R              (2109763x + 220336)\|174
+--R     + 
+--R                          +-----------------------------------------------+
+--R               +-+ +----+ |           2                              2
+--R           - 4\|7 \|1218 \|- 4698%%BQ1  - 3132%%BQ0 %%BQ1 - 4698%%BQ0  - 7
+--R         + 
+--R                +-+ +---+ +----+           +-+ +---+ +----+
+--R           - 12\|7 \|174 \|1218 %%BQ1 - 12\|7 \|174 \|1218 %%BQ0
+--R      *
+--R         log
+--R                    (- 5985712404%%BQ0 - 250810560)%%BQ1 - 250810560%%BQ0
+--R                  + 
+--R                    - 10452876
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |           2                              2
+--R                \|- 4698%%BQ1  - 3132%%BQ0 %%BQ1 - 4698%%BQ0  - 7
+--R            + 
+--R                           +---+                  +---+      2
+--R              (17957137212\|174 %%BQ0 + 752431680\|174 )%%BQ1
+--R            + 
+--R                           +---+     2            +---+
+--R              (17957137212\|174 %%BQ0  - 31358628\|174 )%%BQ1
+--R            + 
+--R                        +---+     2            +---+
+--R              752431680\|174 %%BQ0  - 31358628\|174 %%BQ0
+--R            + 
+--R                                  +---+
+--R              (2109763x + 220336)\|174
+--R     + 
+--R            +-+ +---+ +----+
+--R         24\|7 \|174 \|1218 %%BQ1
+--R      *
+--R         log
+--R                                                    2
+--R              (- 35914274424%%BQ0 - 1504863360)%%BQ1
+--R            + 
+--R                                 2                                    3
+--R              (- 35914274424%%BQ0  + 62717256)%%BQ1 - 35914274424%%BQ0
+--R            + 
+--R              - 40134087%%BQ0 + 2109763x - 1461344
+--R     + 
+--R            +-+ +---+ +----+
+--R         24\|7 \|174 \|1218 %%BQ0
+--R      *
+--R         log
+--R                               3                   2
+--R              287314195392%%BQ0  - 12038906880%%BQ0  + 822810744%%BQ0
+--R            + 
+--R              16878104x + 6055613
+--R     + 
+--R       -
+--R                       +-------------+
+--R             +-+ +---+ |   +--+
+--R            \|7 \|174 \|67\|29  - 109
+--R         *
+--R                          +----------+
+--R                  2       |  +--+          2 +--+    2
+--R                (x  + 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R            log(------------------------------------------------)
+--R                                        2
+--R                                       x
+--R     + 
+--R                    +-------------+
+--R          +-+ +---+ |   +--+
+--R         \|7 \|174 \|67\|29  - 109
+--R      *
+--R                         +----------+
+--R                 2       |  +--+          2 +--+    2
+--R             (- x  - 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R         log(--------------------------------------------------)
+--R                                      2
+--R                                     x
+--R     + 
+--R                     +-------------+
+--R           +-+ +---+ |   +--+
+--R         2\|7 \|174 \|67\|29  + 109
+--R      *
+--R         atan
+--R                             +----------+ +----------+
+--R                   +--+      |  +--+      |  +--+
+--R                (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R              + 
+--R                                         +----------+
+--R                          +--+           |  +--+
+--R                ((2x + 8)\|29  + 2x + 8)\|6\|29  - 6
+--R           /
+--R              168x
+--R     + 
+--R       -
+--R                        +-------------+
+--R              +-+ +---+ |   +--+
+--R            2\|7 \|174 \|67\|29  + 109
+--R         *
+--R            atan
+--R                                +----------+ +----------+
+--R                      +--+      |  +--+      |  +--+
+--R                   (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R                 + 
+--R                                              +----------+
+--R                               +--+           |  +--+
+--R                   ((- 2x - 8)\|29  - 2x - 8)\|6\|29  - 6
+--R              /
+--R                 168x
+--R     + 
+--R                            2           +-+
+--R         +---+ +----+     (x  - 4x - 8)\|7
+--R       2\|174 \|1218 atan(-----------------)
+--R                                    2
+--R                                 21x
+--R  /
+--R        +-+ +---+ +----+
+--R     24\|7 \|174 \|1218
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                            +----------+
+--R                2           +--+      2              +----+ |  +--+
+--R         ((- 23x  - 4x - 8)\|29  - 51x  - 60x - 120)\|1218 \|6\|29  - 6
+--R      *
+--R          +-------------+
+--R          |   +--+
+--R         \|67\|29  + 109
+--R     + 
+--R                                                          +----------+
+--R              2           +--+      2              +----+ |  +--+
+--R         ((22x  - 4x - 8)\|29  + 36x  - 60x - 120)\|1218 \|6\|29  + 6
+--R      *
+--R          +-------------+
+--R          |   +--+
+--R         \|67\|29  - 109
+--R     + 
+--R             2                   +--+          2
+--R       (7308x  + 29232x + 58464)\|29  + 109620x  + 438480x + 876960
+--R  /
+--R               4         3                     +--+           4          3
+--R       (467712x  - 58464x  + 467712x + 467712)\|29  + 7015680x  - 876960x
+--R     + 
+--R       7015680x + 7015680
+--R                                                    Type: Expression(Integer)
+--E 434
+
+)clear all
+
+--S 435 of 534
+t0:=1/(8+8*x-x^3+8*x^4)^2
+--R 
+--R
+--R                                     1
+--R   (1)  ----------------------------------------------------------
+--R           8      7    6       5       4      3      2
+--R        64x  - 16x  + x  + 128x  + 112x  - 16x  + 64x  + 128x + 64
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 435
+
+--S 436 of 534
+r0:=1/336*(-207+34*(1+4/x)^2)/(261-6*(1+4/x)^2+(1+4/x)^4)+3/16*(1+4/x)/_
+   (261-6*(1+4/x)^2+(1+4/x)^4)+1/43848*(4671-2243*(1+4/x)^2)*(1+4/x)/_
+   (261-6*(1+4/x)^2+(1+4/x)^4)-3/16*(1+4/x)^2/(261-6*(1+4/x)^2+(1+4/x)^4)+_
+   1/16*(1+4/x)^3/(261-6*(1+4/x)^2+(1+4/x)^4)-17/1008*atan(1/6*(3-_
+   (1+4/x)^2)/sqrt(7))/sqrt(7)-1/175392*log((1+4/x)^2+3*sqrt(29)-_
+   (1+4/x)*sqrt(6*(1+sqrt(29))))*sqrt(1/1218*(-180983329+45923327*_
+   sqrt(29)))+1/175392*log((1+4/x)^2+3*sqrt(29)+(1+4/x)*sqrt(6*(1+_
+   sqrt(29))))*sqrt(1/1218*(-180983329+45923327*sqrt(29)))+1/87696*_
+   atan((-2*(1+4/x)+sqrt(6*(1+sqrt(29))))/sqrt(6*(-1+sqrt(29))))*_
+   sqrt(1/1218*(180983329+45923327*sqrt(29)))-1/87696*atan((2*(1+4/x)+_
+   sqrt(6*(1+sqrt(29))))/sqrt(6*(-1+sqrt(29))))*sqrt(1/1218*_
+   (180983329+45923327*sqrt(29)))
+--R 
+--R
+--R   (2)
+--R                                 +-------------------------+
+--R            4    3           +-+ |         +--+
+--R         (8x  - x  + 8x + 8)\|7 \|45923327\|29  - 180983329
+--R      *
+--R                       +----------+
+--R               2       |  +--+          2 +--+    2
+--R             (x  + 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R         log(------------------------------------------------)
+--R                                     2
+--R                                    x
+--R     + 
+--R                                   +-------------------------+
+--R              4    3           +-+ |         +--+
+--R         (- 8x  + x  - 8x - 8)\|7 \|45923327\|29  - 180983329
+--R      *
+--R                         +----------+
+--R                 2       |  +--+          2 +--+    2
+--R             (- x  - 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R         log(--------------------------------------------------)
+--R                                      2
+--R                                     x
+--R     + 
+--R                                       +-------------------------+
+--R               4     3             +-+ |         +--+
+--R         (- 16x  + 2x  - 16x - 16)\|7 \|45923327\|29  + 180983329
+--R      *
+--R         atan
+--R                             +----------+ +----------+
+--R                   +--+      |  +--+      |  +--+
+--R                (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R              + 
+--R                                         +----------+
+--R                          +--+           |  +--+
+--R                ((2x + 8)\|29  + 2x + 8)\|6\|29  - 6
+--R           /
+--R              168x
+--R     + 
+--R                                     +-------------------------+
+--R             4     3             +-+ |         +--+
+--R         (16x  - 2x  + 16x + 16)\|7 \|45923327\|29  + 180983329
+--R      *
+--R         atan
+--R                             +----------+ +----------+
+--R                   +--+      |  +--+      |  +--+
+--R                (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R              + 
+--R                                           +----------+
+--R                            +--+           |  +--+
+--R                ((- 2x - 8)\|29  - 2x - 8)\|6\|29  - 6
+--R           /
+--R              168x
+--R     + 
+--R                                                          2           +-+
+--R                4        3                   +----+     (x  - 4x - 8)\|7
+--R       (- 23664x  + 2958x  - 23664x - 23664)\|1218 atan(-----------------)
+--R                                                                  2
+--R                                                               21x
+--R     + 
+--R               4        3        2          +-+ +----+
+--R       (- 2176x  + 3408x  - 4584x  + 3980x)\|7 \|1218
+--R  /
+--R              4          3                       +-+ +----+
+--R     (1403136x  - 175392x  + 1403136x + 1403136)\|7 \|1218
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4    3
+--R             (8x  - x  + 8x + 8)
+--R          *
+--R             ROOT
+--R                                     2
+--R                  - 125452723536%%BR1  - 83635149024%%BR0 %%BR1
+--R                + 
+--R                                     2
+--R                  - 125452723536%%BR0  - 6630191
+--R         + 
+--R                     4         3                     +--+
+--R           (- 175392x  + 21924x  - 175392x - 175392)\|87 %%BR1
+--R         + 
+--R                     4         3                     +--+
+--R           (- 175392x  + 21924x  - 175392x - 175392)\|87 %%BR0
+--R      *
+--R         log
+--R                    (17725582033026208876003392%%BR0 + 28589580035519628827520)
+--R                 *
+--R                    %%BR1
+--R                + 
+--R                  28589580035519628827520%%BR0 + 56903555778449078748
+--R             *
+--R                ROOT
+--R                                        2
+--R                     - 125452723536%%BR1  - 83635149024%%BR0 %%BR1
+--R                   + 
+--R                                        2
+--R                     - 125452723536%%BR0  - 6630191
+--R            + 
+--R                                                 +--+
+--R                  388615660492066603397498366208\|87 %%BR0
+--R                + 
+--R                                              +--+
+--R                  626797952698732342414548480\|87
+--R             *
+--R                     2
+--R                %%BR1
+--R            + 
+--R                                                 +--+     2
+--R                  388615660492066603397498366208\|87 %%BR0
+--R                + 
+--R                                              +--+
+--R                  - 1247553556886717602471152\|87
+--R             *
+--R                %%BR1
+--R            + 
+--R                                          +--+     2
+--R              626797952698732342414548480\|87 %%BR0
+--R            + 
+--R                                          +--+
+--R              - 1247553556886717602471152\|87 %%BR0
+--R            + 
+--R                                                                 +--+
+--R              (8435208206933660878927x + 2295910220839785410704)\|87
+--R     + 
+--R                  4    3
+--R             (- 8x  + x  - 8x - 8)
+--R          *
+--R             ROOT
+--R                                     2
+--R                  - 125452723536%%BR1  - 83635149024%%BR0 %%BR1
+--R                + 
+--R                                     2
+--R                  - 125452723536%%BR0  - 6630191
+--R         + 
+--R                     4         3                     +--+
+--R           (- 175392x  + 21924x  - 175392x - 175392)\|87 %%BR1
+--R         + 
+--R                     4         3                     +--+
+--R           (- 175392x  + 21924x  - 175392x - 175392)\|87 %%BR0
+--R      *
+--R         log
+--R                        - 17725582033026208876003392%%BR0
+--R                      + 
+--R                        - 28589580035519628827520
+--R                 *
+--R                    %%BR1
+--R                + 
+--R                  - 28589580035519628827520%%BR0 - 56903555778449078748
+--R             *
+--R                ROOT
+--R                                        2
+--R                     - 125452723536%%BR1  - 83635149024%%BR0 %%BR1
+--R                   + 
+--R                                        2
+--R                     - 125452723536%%BR0  - 6630191
+--R            + 
+--R                                                 +--+
+--R                  388615660492066603397498366208\|87 %%BR0
+--R                + 
+--R                                              +--+
+--R                  626797952698732342414548480\|87
+--R             *
+--R                     2
+--R                %%BR1
+--R            + 
+--R                                                 +--+     2
+--R                  388615660492066603397498366208\|87 %%BR0
+--R                + 
+--R                                              +--+
+--R                  - 1247553556886717602471152\|87
+--R             *
+--R                %%BR1
+--R            + 
+--R                                          +--+     2
+--R              626797952698732342414548480\|87 %%BR0
+--R            + 
+--R                                          +--+
+--R              - 1247553556886717602471152\|87 %%BR0
+--R            + 
+--R                                                                 +--+
+--R              (8435208206933660878927x + 2295910220839785410704)\|87
+--R     + 
+--R                 4         3                     +--+
+--R         (350784x  - 43848x  + 350784x + 350784)\|87 %%BR1
+--R      *
+--R         log
+--R                  - 777231320984133206794996732416%%BR0
+--R                + 
+--R                  - 1253595905397464684829096960
+--R             *
+--R                     2
+--R                %%BR1
+--R            + 
+--R                                                       2
+--R                  - 777231320984133206794996732416%%BR0
+--R                + 
+--R                  2495107113773435204942304
+--R             *
+--R                %%BR1
+--R            + 
+--R                                                   3
+--R              - 777231320984133206794996732416%%BR0
+--R            + 
+--R              - 30807574144623976048344072%%BR0 + 8435208206933660878927x
+--R            + 
+--R              - 47393606606696595067616
+--R     + 
+--R                 4         3                     +--+
+--R         (350784x  - 43848x  + 350784x + 350784)\|87 %%BR0
+--R      *
+--R         log
+--R                                                  3
+--R              6217850567873065654359973859328%%BR0
+--R            + 
+--R                                                  2
+--R              - 10028767243179717478632775680%%BR0
+--R            + 
+--R              266421450067179290026291008%%BR0 + 67481665655469287031416x
+--R            + 
+--R              333979081113202533090737
+--R     + 
+--R            3        2                +--+
+--R       (784x  - 1146x  + 1539x + 544)\|87
+--R  /
+--R             4         3                     +--+
+--R     (350784x  - 43848x  + 350784x + 350784)\|87
+--R                                         Type: Union(Expression(Integer),...)
+--E 437
+
+--S 438 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+ +----+
+--R             4\|7 \|1218
+--R          *
+--R             ROOT
+--R                                     2
+--R                  - 125452723536%%BR1  - 83635149024%%BR0 %%BR1
+--R                + 
+--R                                     2
+--R                  - 125452723536%%BR0  - 6630191
+--R         + 
+--R                   +-+ +--+ +----+              +-+ +--+ +----+
+--R           - 87696\|7 \|87 \|1218 %%BR1 - 87696\|7 \|87 \|1218 %%BR0
+--R      *
+--R         log
+--R                    (17725582033026208876003392%%BR0 + 28589580035519628827520)
+--R                 *
+--R                    %%BR1
+--R                + 
+--R                  28589580035519628827520%%BR0 + 56903555778449078748
+--R             *
+--R                ROOT
+--R                                        2
+--R                     - 125452723536%%BR1  - 83635149024%%BR0 %%BR1
+--R                   + 
+--R                                        2
+--R                     - 125452723536%%BR0  - 6630191
+--R            + 
+--R                                                 +--+
+--R                  388615660492066603397498366208\|87 %%BR0
+--R                + 
+--R                                              +--+
+--R                  626797952698732342414548480\|87
+--R             *
+--R                     2
+--R                %%BR1
+--R            + 
+--R                                                 +--+     2
+--R                  388615660492066603397498366208\|87 %%BR0
+--R                + 
+--R                                              +--+
+--R                  - 1247553556886717602471152\|87
+--R             *
+--R                %%BR1
+--R            + 
+--R                                          +--+     2
+--R              626797952698732342414548480\|87 %%BR0
+--R            + 
+--R                                          +--+
+--R              - 1247553556886717602471152\|87 %%BR0
+--R            + 
+--R                                                                 +--+
+--R              (8435208206933660878927x + 2295910220839785410704)\|87
+--R     + 
+--R           -
+--R                  +-+ +----+
+--R                4\|7 \|1218
+--R             *
+--R                ROOT
+--R                                        2
+--R                     - 125452723536%%BR1  - 83635149024%%BR0 %%BR1
+--R                   + 
+--R                                        2
+--R                     - 125452723536%%BR0  - 6630191
+--R         + 
+--R                   +-+ +--+ +----+              +-+ +--+ +----+
+--R           - 87696\|7 \|87 \|1218 %%BR1 - 87696\|7 \|87 \|1218 %%BR0
+--R      *
+--R         log
+--R                        - 17725582033026208876003392%%BR0
+--R                      + 
+--R                        - 28589580035519628827520
+--R                 *
+--R                    %%BR1
+--R                + 
+--R                  - 28589580035519628827520%%BR0 - 56903555778449078748
+--R             *
+--R                ROOT
+--R                                        2
+--R                     - 125452723536%%BR1  - 83635149024%%BR0 %%BR1
+--R                   + 
+--R                                        2
+--R                     - 125452723536%%BR0  - 6630191
+--R            + 
+--R                                                 +--+
+--R                  388615660492066603397498366208\|87 %%BR0
+--R                + 
+--R                                              +--+
+--R                  626797952698732342414548480\|87
+--R             *
+--R                     2
+--R                %%BR1
+--R            + 
+--R                                                 +--+     2
+--R                  388615660492066603397498366208\|87 %%BR0
+--R                + 
+--R                                              +--+
+--R                  - 1247553556886717602471152\|87
+--R             *
+--R                %%BR1
+--R            + 
+--R                                          +--+     2
+--R              626797952698732342414548480\|87 %%BR0
+--R            + 
+--R                                          +--+
+--R              - 1247553556886717602471152\|87 %%BR0
+--R            + 
+--R                                                                 +--+
+--R              (8435208206933660878927x + 2295910220839785410704)\|87
+--R     + 
+--R                +-+ +--+ +----+
+--R         175392\|7 \|87 \|1218 %%BR1
+--R      *
+--R         log
+--R                  - 777231320984133206794996732416%%BR0
+--R                + 
+--R                  - 1253595905397464684829096960
+--R             *
+--R                     2
+--R                %%BR1
+--R            + 
+--R                                                       2
+--R                  - 777231320984133206794996732416%%BR0
+--R                + 
+--R                  2495107113773435204942304
+--R             *
+--R                %%BR1
+--R            + 
+--R                                                   3
+--R              - 777231320984133206794996732416%%BR0
+--R            + 
+--R              - 30807574144623976048344072%%BR0 + 8435208206933660878927x
+--R            + 
+--R              - 47393606606696595067616
+--R     + 
+--R                +-+ +--+ +----+
+--R         175392\|7 \|87 \|1218 %%BR0
+--R      *
+--R         log
+--R                                                  3
+--R              6217850567873065654359973859328%%BR0
+--R            + 
+--R                                                  2
+--R              - 10028767243179717478632775680%%BR0
+--R            + 
+--R              266421450067179290026291008%%BR0 + 67481665655469287031416x
+--R            + 
+--R              333979081113202533090737
+--R     + 
+--R       -
+--R                      +-------------------------+
+--R             +-+ +--+ |         +--+
+--R            \|7 \|87 \|45923327\|29  - 180983329
+--R         *
+--R                          +----------+
+--R                  2       |  +--+          2 +--+    2
+--R                (x  + 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R            log(------------------------------------------------)
+--R                                        2
+--R                                       x
+--R     + 
+--R                   +-------------------------+
+--R          +-+ +--+ |         +--+
+--R         \|7 \|87 \|45923327\|29  - 180983329
+--R      *
+--R                         +----------+
+--R                 2       |  +--+          2 +--+    2
+--R             (- x  - 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R         log(--------------------------------------------------)
+--R                                      2
+--R                                     x
+--R     + 
+--R                    +-------------------------+
+--R           +-+ +--+ |         +--+
+--R         2\|7 \|87 \|45923327\|29  + 180983329
+--R      *
+--R         atan
+--R                             +----------+ +----------+
+--R                   +--+      |  +--+      |  +--+
+--R                (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R              + 
+--R                                         +----------+
+--R                          +--+           |  +--+
+--R                ((2x + 8)\|29  + 2x + 8)\|6\|29  - 6
+--R           /
+--R              168x
+--R     + 
+--R       -
+--R                       +-------------------------+
+--R              +-+ +--+ |         +--+
+--R            2\|7 \|87 \|45923327\|29  + 180983329
+--R         *
+--R            atan
+--R                                +----------+ +----------+
+--R                      +--+      |  +--+      |  +--+
+--R                   (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R                 + 
+--R                                              +----------+
+--R                               +--+           |  +--+
+--R                   ((- 2x - 8)\|29  - 2x - 8)\|6\|29  - 6
+--R              /
+--R                 168x
+--R     + 
+--R                              2           +-+
+--R            +--+ +----+     (x  - 4x - 8)\|7         +-+ +--+ +----+
+--R       2958\|87 \|1218 atan(-----------------) + 272\|7 \|87 \|1218
+--R                                      2
+--R                                   21x
+--R  /
+--R            +-+ +--+ +----+
+--R     175392\|7 \|87 \|1218
+--R                                                    Type: Expression(Integer)
+--E 438
+
+--S 439 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                            +----------+
+--R                2           +--+      2              +----+ |  +--+
+--R         ((- 23x  - 4x - 8)\|29  - 51x  - 60x - 120)\|1218 \|6\|29  - 6
+--R      *
+--R          +-------------------------+
+--R          |         +--+
+--R         \|45923327\|29  + 180983329
+--R     + 
+--R                                                          +----------+
+--R              2           +--+      2              +----+ |  +--+
+--R         ((22x  - 4x - 8)\|29  + 36x  - 60x - 120)\|1218 \|6\|29  + 6
+--R      *
+--R          +-------------------------+
+--R          |         +--+
+--R         \|45923327\|29  - 180983329
+--R     + 
+--R                 2                         +--+             2
+--R       (18447828x  + 21855792x + 43711584)\|29  + 276717420x  + 327836880x
+--R     + 
+--R       655673760
+--R  /
+--R                   4             3                             +--+
+--R       (3418039296x  - 427254912x  + 3418039296x + 3418039296)\|29
+--R     + 
+--R                   4              3
+--R       51270589440x  - 6408823680x  + 51270589440x + 51270589440
+--R                                                    Type: Expression(Integer)
+--E 439
+
+)clear all
+
+--S 440 of 534
+t0:=1/(8+8*x-x^3+8*x^4)^(1/2)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-----------------+
+--R         |  4    3
+--R        \|8x  - x  + 8x + 8
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 534
+--r0:=-x^2*elliptic_f(asin((1+4/x)/sqrt(3*(1-2*%i*sqrt(7)))),_
+--   (%i+2*sqrt(7))/(%i-2*sqrt(7)))*sqrt(3-(1+4/x)^2/(1-2*%i*sqrt(7)))*_
+--   sqrt(3-(1+4/x)^2/(1+2*%i*sqrt(7)))*sqrt(2/3*(1-2*%i*sqrt(7)))/_
+--   sqrt((261-6*(1+4/x)^2+(1+4/x)^4)*x^4)
+--E 441
+
+--S 442 of 534
+--a0:=integrate(t0,x)
+--E 442
+
+--S 443 of 534
+--m0:=a0-r0
+--E 443
+
+--S 444 of 534
+--d0:=D(m0,x)
+--E 444
+
+)clear all
+
+--S 445 of 534
+t0:=(1+4*x+4*x^2+4*x^4)^4
+--R 
+--R
+--R   (1)
+--R         16        14        13        12        11        10        9        8
+--R     256x   + 1024x   + 1024x   + 1792x   + 3072x   + 3328x   + 3840x  + 4192x
+--R   + 
+--R          7        6        5        4       3       2
+--R     3584x  + 2752x  + 1984x  + 1136x  + 448x  + 112x  + 16x + 1
+--R                                                    Type: Polynomial(Integer)
+--E 445
+
+--S 446 of 534
+r0:=x+8*x^2+112/3*x^3+112*x^4+1136/5*x^5+992/3*x^6+2752/7*x^7+448*x^8+_
+   4192/9*x^9+384*x^10+3328/11*x^11+256*x^12+1792/13*x^13+512/7*x^14+_
+   1024/15*x^15+256/17*x^17
+--R 
+--R
+--R   (2)
+--R     256  17   1024  15   512  14   1792  13       12   3328  11       10
+--R     --- x   + ---- x   + --- x   + ---- x   + 256x   + ---- x   + 384x
+--R      17        15         7         13                  11
+--R   + 
+--R     4192  9       8   2752  7   992  6   1136  5       4   112  3     2
+--R     ---- x  + 448x  + ---- x  + --- x  + ---- x  + 112x  + --- x  + 8x  + x
+--R       9                 7        3         5                3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 446
+
+--S 447 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     256  17   1024  15   512  14   1792  13       12   3328  11       10
+--R     --- x   + ---- x   + --- x   + ---- x   + 256x   + ---- x   + 384x
+--R      17        15         7         13                  11
+--R   + 
+--R     4192  9       8   2752  7   992  6   1136  5       4   112  3     2
+--R     ---- x  + 448x  + ---- x  + --- x  + ---- x  + 112x  + --- x  + 8x  + x
+--R       9                 7        3         5                3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 447
+
+--S 448 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 448
+
+--S 449 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 449
+
+)clear all
+
+--S 450 of 534
+t0:=(1+4*x+4*x^2+4*x^4)^3
+--R 
+--R
+--R   (1)
+--R        12       10       9       8       7       6       5       4       3
+--R     64x   + 192x   + 192x  + 240x  + 384x  + 352x  + 288x  + 252x  + 160x
+--R   + 
+--R        2
+--R     60x  + 12x + 1
+--R                                                    Type: Polynomial(Integer)
+--E 450
+
+--S 451 of 534
+r0:=x+6*x^2+20*x^3+40*x^4+252/5*x^5+48*x^6+352/7*x^7+48*x^8+80/3*x^9+_
+   96/5*x^10+192/11*x^11+64/13*x^13
+--R 
+--R
+--R   (2)
+--R     64  13   192  11   96  10   80  9      8   352  7      6   252  5      4
+--R     -- x   + --- x   + -- x   + -- x  + 48x  + --- x  + 48x  + --- x  + 40x
+--R     13        11        5        3              7               5
+--R   + 
+--R        3     2
+--R     20x  + 6x  + x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 451
+
+--S 452 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     64  13   192  11   96  10   80  9      8   352  7      6   252  5      4
+--R     -- x   + --- x   + -- x   + -- x  + 48x  + --- x  + 48x  + --- x  + 40x
+--R     13        11        5        3              7               5
+--R   + 
+--R        3     2
+--R     20x  + 6x  + x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 452
+
+--S 453 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 453
+
+--S 454 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 454
+
+)clear all
+
+--S 455 of 534
+t0:=(1+4*x+4*x^2+4*x^4)^2
+--R 
+--R
+--R           8      6      5      4      3      2
+--R   (1)  16x  + 32x  + 32x  + 24x  + 32x  + 24x  + 8x + 1
+--R                                                    Type: Polynomial(Integer)
+--E 455
+
+--S 456 of 534
+r0:=x+4*x^2+8*x^3+8*x^4+24/5*x^5+16/3*x^6+32/7*x^7+16/9*x^9
+--R 
+--R
+--R        16  9   32  7   16  6   24  5     4     3     2
+--R   (2)  -- x  + -- x  + -- x  + -- x  + 8x  + 8x  + 4x  + x
+--R         9       7       3       5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 456
+
+--S 457 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R        16  9   32  7   16  6   24  5     4     3     2
+--R   (3)  -- x  + -- x  + -- x  + -- x  + 8x  + 8x  + 4x  + x
+--R         9       7       3       5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 457
+
+--S 458 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 458
+
+--S 459 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 459
+
+)clear all
+
+--S 460 of 534
+t0:=1+4*x+4*x^2+4*x^4
+--R 
+--R
+--R          4     2
+--R   (1)  4x  + 4x  + 4x + 1
+--R                                                    Type: Polynomial(Integer)
+--E 460
+
+--S 461 of 534
+r0:=x+2*x^2+4/3*x^3+4/5*x^5
+--R 
+--R
+--R        4  5   4  3     2
+--R   (2)  - x  + - x  + 2x  + x
+--R        5      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 461
+
+--S 462 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R        4  5   4  3     2
+--R   (3)  - x  + - x  + 2x  + x
+--R        5      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 462
+
+--S 463 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 463
+
+--S 464 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 464
+
+)clear all
+
+--S 465 of 534
+t0:=1/(1+4*x+4*x^2+4*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R          4     2
+--R        4x  + 4x  + 4x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 465
+
+--S 466 of 534
+r0:=-1/2*atan(1/2-1/2*(1+1/x)^2)+1/4*atan((-2*(1+1/x)+sqrt(2*(1+sqrt(5))))/_
+   sqrt(2*(-1+sqrt(5))))*(1+sqrt(5))^(3/2)/sqrt(10)-1/4*atan((2*(1+1/x)+_
+   sqrt(2*(1+sqrt(5))))/sqrt(2*(-1+sqrt(5))))*(1+sqrt(5))^(3/2)/sqrt(10)-_
+   1/4*log((1+1/x)^2+sqrt(5)-(1+1/x)*sqrt(2*(1+sqrt(5))))*sqrt(1/5*_
+   (-2+sqrt(5)))+1/4*log((1+1/x)^2+sqrt(5)+(1+1/x)*sqrt(2*(1+sqrt(5))))*_
+   sqrt(1/5*(-2+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                    +---------+
+--R             +--------+      2      |  +-+         2 +-+    2
+--R        +--+ | +-+         (x  + x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R       \|10 \|\|5  - 2 log(-------------------------------------------)
+--R                                                 2
+--R                                                x
+--R     + 
+--R                                        +---------+
+--R               +--------+        2      |  +-+         2 +-+    2
+--R          +--+ | +-+         (- x  - x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R       - \|10 \|\|5  - 2 log(---------------------------------------------)
+--R                                                    2
+--R                                                   x
+--R     + 
+--R                      +--------+
+--R             +-+      | +-+
+--R         (- \|5  - 5)\|\|5  + 1
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                        +---------+
+--R                          +-+           |  +-+
+--R                ((2x + 2)\|5  + 2x + 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R                    +--------+
+--R           +-+      | +-+
+--R         (\|5  + 5)\|\|5  + 1
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                          +---------+
+--R                            +-+           |  +-+
+--R                ((- 2x - 2)\|5  - 2x - 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R         +-+ +--+     2x + 1
+--R       2\|5 \|10 atan(------)
+--R                          2
+--R                        2x
+--R  /
+--R       +-+ +--+
+--R     4\|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +-----------------------------------------+
+--R              |         2                          2         +--+
+--R           - \|- 30%%BS1  - 20%%BS0 %%BS1 - 30%%BS0  - 9  - \|10 %%BS1
+--R         + 
+--R              +--+
+--R           - \|10 %%BS0
+--R      *
+--R         log
+--R                ((960%%BS0 + 40)%%BS1 + 40%%BS0)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |         2                          2
+--R                \|- 30%%BS1  - 20%%BS0 %%BS1 - 30%%BS0  - 9
+--R            + 
+--R                     +--+           +--+      2       +--+     2
+--R              (- 960\|10 %%BS0 - 40\|10 )%%BS1  - 960\|10 %%BS0 %%BS1
+--R            + 
+--R                   +--+     2            +--+
+--R              - 40\|10 %%BS0  + (8x + 3)\|10
+--R     + 
+--R              +-----------------------------------------+
+--R              |         2                          2         +--+
+--R             \|- 30%%BS1  - 20%%BS0 %%BS1 - 30%%BS0  - 9  - \|10 %%BS1
+--R           + 
+--R                +--+
+--R             - \|10 %%BS0
+--R      *
+--R         log
+--R                ((- 960%%BS0 - 40)%%BS1 - 40%%BS0)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |         2                          2
+--R                \|- 30%%BS1  - 20%%BS0 %%BS1 - 30%%BS0  - 9
+--R            + 
+--R                     +--+           +--+      2       +--+     2
+--R              (- 960\|10 %%BS0 - 40\|10 )%%BS1  - 960\|10 %%BS0 %%BS1
+--R            + 
+--R                   +--+     2            +--+
+--R              - 40\|10 %%BS0  + (8x + 3)\|10
+--R     + 
+--R           +--+
+--R         2\|10 %%BS1
+--R      *
+--R         log
+--R                                   2            2                 3
+--R              (1920%%BS0 + 80)%%BS1  + 1920%%BS0 %%BS1 + 1920%%BS0  + 432%%BS0
+--R            + 
+--R              8x + 21
+--R     + 
+--R         +--+                     3          2
+--R       2\|10 %%BS0 log(- 1920%%BS0  + 80%%BS0  - 432%%BS0 + 8x - 27)
+--R  /
+--R       +--+
+--R     2\|10
+--R                                         Type: Union(Expression(Integer),...)
+--E 467
+
+--S 468 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +-----------------------------------------+
+--R               +-+ |         2                          2          +-+ +--+
+--R           - 2\|5 \|- 30%%BS1  - 20%%BS0 %%BS1 - 30%%BS0  - 9  - 2\|5 \|10 %%BS1
+--R         + 
+--R               +-+ +--+
+--R           - 2\|5 \|10 %%BS0
+--R      *
+--R         log
+--R                ((960%%BS0 + 40)%%BS1 + 40%%BS0)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |         2                          2
+--R                \|- 30%%BS1  - 20%%BS0 %%BS1 - 30%%BS0  - 9
+--R            + 
+--R                     +--+           +--+      2       +--+     2
+--R              (- 960\|10 %%BS0 - 40\|10 )%%BS1  - 960\|10 %%BS0 %%BS1
+--R            + 
+--R                   +--+     2            +--+
+--R              - 40\|10 %%BS0  + (8x + 3)\|10
+--R     + 
+--R                 +-----------------------------------------+
+--R             +-+ |         2                          2          +-+ +--+
+--R           2\|5 \|- 30%%BS1  - 20%%BS0 %%BS1 - 30%%BS0  - 9  - 2\|5 \|10 %%BS1
+--R         + 
+--R               +-+ +--+
+--R           - 2\|5 \|10 %%BS0
+--R      *
+--R         log
+--R                ((- 960%%BS0 - 40)%%BS1 - 40%%BS0)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |         2                          2
+--R                \|- 30%%BS1  - 20%%BS0 %%BS1 - 30%%BS0  - 9
+--R            + 
+--R                     +--+           +--+      2       +--+     2
+--R              (- 960\|10 %%BS0 - 40\|10 )%%BS1  - 960\|10 %%BS0 %%BS1
+--R            + 
+--R                   +--+     2            +--+
+--R              - 40\|10 %%BS0  + (8x + 3)\|10
+--R     + 
+--R           +-+ +--+
+--R         4\|5 \|10 %%BS1
+--R      *
+--R         log
+--R                                   2            2                 3
+--R              (1920%%BS0 + 80)%%BS1  + 1920%%BS0 %%BS1 + 1920%%BS0  + 432%%BS0
+--R            + 
+--R              8x + 21
+--R     + 
+--R                                      +---------+
+--R               +--------+      2      |  +-+         2 +-+    2
+--R          +--+ | +-+         (x  + x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R       - \|10 \|\|5  - 2 log(-------------------------------------------)
+--R                                                   2
+--R                                                  x
+--R     + 
+--R                                      +---------+
+--R             +--------+        2      |  +-+         2 +-+    2
+--R        +--+ | +-+         (- x  - x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R       \|10 \|\|5  - 2 log(---------------------------------------------)
+--R                                                  2
+--R                                                 x
+--R     + 
+--R         +-+ +--+                     3          2
+--R       4\|5 \|10 %%BS0 log(- 1920%%BS0  + 80%%BS0  - 432%%BS0 + 8x - 27)
+--R     + 
+--R                    +--------+
+--R           +-+      | +-+
+--R         (\|5  + 5)\|\|5  + 1
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                        +---------+
+--R                          +-+           |  +-+
+--R                ((2x + 2)\|5  + 2x + 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R                      +--------+
+--R             +-+      | +-+
+--R         (- \|5  - 5)\|\|5  + 1
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                          +---------+
+--R                            +-+           |  +-+
+--R                ((- 2x - 2)\|5  - 2x - 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R           +-+ +--+     2x + 1
+--R       - 2\|5 \|10 atan(------)
+--R                            2
+--R                          2x
+--R  /
+--R       +-+ +--+
+--R     4\|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 468
+
+--S 469 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                             +--------+ +---------+
+--R           2           +-+      2            | +-+      |  +-+
+--R       ((2x  - 6x - 3)\|5  + 10x  - 10x - 5)\|\|5  - 2 \|2\|5  + 2
+--R     + 
+--R                                                  +--------+ +---------+
+--R             2           +-+     2           +--+ | +-+      |  +-+
+--R       ((- 3x  - 2x - 1)\|5  - 7x  - 4x - 2)\|10 \|\|5  + 1 \|2\|5  - 2
+--R     + 
+--R           2             +-+      2
+--R       (20x  + 20x + 10)\|5  + 60x  + 60x + 30
+--R  /
+--R         4      2             +-+       4       2
+--R     (40x  + 40x  + 40x + 10)\|5  + 120x  + 120x  + 120x + 30
+--R                                                    Type: Expression(Integer)
+--E 469
+
+)clear all
+
+--S 470 of 534
+t0:=1/(1+4*x+4*x^2+4*x^4)^2
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R           8      6      5      4      3      2
+--R        16x  + 32x  + 32x  + 24x  + 32x  + 24x  + 8x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 470
+
+--S 471 of 534
+r0:=1/2*(-17+7*(1+1/x)^2)/(5-2*(1+1/x)^2+(1+1/x)^4)+13/3*(1+1/x)/(5-_
+   2*(1+1/x)^2+(1+1/x)^4)+1/30*(47-81*(1+1/x)^2)*(1+1/x)/(5-2*(1+1/x)^2+_
+   (1+1/x)^4)-3*(1+1/x)^2/(5-2*(1+1/x)^2+(1+1/x)^4)+(1+1/x)^3/(5-2*_
+   (1+1/x)^2+(1+1/x)^4)-7/4*atan(1/2-1/2*(1+1/x)^2)+1/40*log((1+1/x)^2+_
+   sqrt(5)-(1+1/x)*sqrt(2*(1+sqrt(5))))*sqrt(1/10*(-5959+2665*sqrt(5)))-_
+   1/40*log((1+1/x)^2+sqrt(5)+(1+1/x)*sqrt(2*(1+sqrt(5))))*sqrt(1/10*_
+   (-5959+2665*sqrt(5)))+1/20*atan((-2*(1+1/x)+sqrt(2*(1+sqrt(5))))/_
+   sqrt(2*(-1+sqrt(5))))*sqrt(1/10*(5959+2665*sqrt(5)))-1/20*atan((2*_
+   (1+1/x)+sqrt(2*(1+sqrt(5))))/sqrt(2*(-1+sqrt(5))))*sqrt(1/10*(5959+_
+   2665*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                +---------------+
+--R              4     2           |     +-+
+--R         (- 4x  - 4x  - 4x - 1)\|2665\|5  - 5959
+--R      *
+--R                      +---------+
+--R               2      |  +-+         2 +-+    2
+--R             (x  + x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R         log(-------------------------------------------)
+--R                                   2
+--R                                  x
+--R     + 
+--R                              +---------------+
+--R            4     2           |     +-+
+--R         (4x  + 4x  + 4x + 1)\|2665\|5  - 5959
+--R      *
+--R                        +---------+
+--R                 2      |  +-+         2 +-+    2
+--R             (- x  - x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R         log(---------------------------------------------)
+--R                                    2
+--R                                   x
+--R     + 
+--R                                +---------------+
+--R              4     2           |     +-+
+--R         (- 8x  - 8x  - 8x - 2)\|2665\|5  + 5959
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                        +---------+
+--R                          +-+           |  +-+
+--R                ((2x + 2)\|5  + 2x + 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R                              +---------------+
+--R            4     2           |     +-+
+--R         (8x  + 8x  + 8x + 2)\|2665\|5  + 5959
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                          +---------+
+--R                            +-+           |  +-+
+--R                ((- 2x - 2)\|5  - 2x - 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R            4       2              +--+     2x + 1
+--R       (280x  + 280x  + 280x + 70)\|10 atan(------)
+--R                                                2
+--R                                              2x
+--R     + 
+--R              4      3       2        +--+
+--R       (- 152x  + 72x  - 184x  - 68x)\|10
+--R  /
+--R          4       2              +--+
+--R     (160x  + 160x  + 160x + 40)\|10
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  4     2
+--R             (- 8x  - 8x  - 8x - 2)
+--R          *
+--R              +-----------------------------------------------+
+--R              |          2                            2
+--R             \|- 750%%BT1  - 500%%BT0 %%BT1 - 750%%BT0  - 3021
+--R         + 
+--R                 4      2             +--+
+--R           (- 40x  - 40x  - 40x - 10)\|10 %%BT1
+--R         + 
+--R                 4      2             +--+
+--R           (- 40x  - 40x  - 40x - 10)\|10 %%BT0
+--R      *
+--R         log
+--R                ((1708454400%%BT0 - 18808600)%%BT1 - 18808600%%BT0 - 4392020)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |          2                            2
+--R                \|- 750%%BT1  - 500%%BT0 %%BT1 - 750%%BT0  - 3021
+--R            + 
+--R                            +--+                 +--+      2
+--R              (- 8542272000\|10 %%BT0 + 94043000\|10 )%%BT1
+--R            + 
+--R                            +--+     2            +--+
+--R              (- 8542272000\|10 %%BT0  - 21960100\|10 )%%BT1
+--R            + 
+--R                       +--+     2            +--+
+--R              94043000\|10 %%BT0  - 21960100\|10 %%BT0
+--R            + 
+--R                                       +--+
+--R              (541735337x + 213096267)\|10
+--R     + 
+--R                4     2
+--R             (8x  + 8x  + 8x + 2)
+--R          *
+--R              +-----------------------------------------------+
+--R              |          2                            2
+--R             \|- 750%%BT1  - 500%%BT0 %%BT1 - 750%%BT0  - 3021
+--R         + 
+--R                 4      2             +--+
+--R           (- 40x  - 40x  - 40x - 10)\|10 %%BT1
+--R         + 
+--R                 4      2             +--+
+--R           (- 40x  - 40x  - 40x - 10)\|10 %%BT0
+--R      *
+--R         log
+--R                ((- 1708454400%%BT0 + 18808600)%%BT1 + 18808600%%BT0 + 4392020)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |          2                            2
+--R                \|- 750%%BT1  - 500%%BT0 %%BT1 - 750%%BT0  - 3021
+--R            + 
+--R                            +--+                 +--+      2
+--R              (- 8542272000\|10 %%BT0 + 94043000\|10 )%%BT1
+--R            + 
+--R                            +--+     2            +--+
+--R              (- 8542272000\|10 %%BT0  - 21960100\|10 )%%BT1
+--R            + 
+--R                       +--+     2            +--+
+--R              94043000\|10 %%BT0  - 21960100\|10 %%BT0
+--R            + 
+--R                                       +--+
+--R              (541735337x + 213096267)\|10
+--R     + 
+--R             4      2             +--+
+--R         (80x  + 80x  + 80x + 20)\|10 %%BT1
+--R      *
+--R         log
+--R                                                 2
+--R              (17084544000%%BT0 - 188086000)%%BT1
+--R            + 
+--R                               2                                    3
+--R              (17084544000%%BT0  + 43920200)%%BT1 + 17084544000%%BT0
+--R            + 
+--R              51612407424%%BT0 + 541735337x - 355111539
+--R     + 
+--R             4      2             +--+
+--R         (80x  + 80x  + 80x + 20)\|10 %%BT0
+--R      *
+--R         log
+--R                                3                 2
+--R              - 17084544000%%BT0  - 188086000%%BT0  - 51568487224%%BT0
+--R            + 
+--R              541735337x - 71080995
+--R     + 
+--R           3      2             +--+
+--R       (36x  - 16x  + 42x + 19)\|10
+--R  /
+--R         4      2             +--+
+--R     (80x  + 80x  + 80x + 20)\|10
+--R                                         Type: Union(Expression(Integer),...)
+--E 472
+
+--S 473 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-----------------------------------------------+
+--R               |          2                            2              +--+
+--R           - 4\|- 750%%BT1  - 500%%BT0 %%BT1 - 750%%BT0  - 3021  - 20\|10 %%BT1
+--R         + 
+--R                +--+
+--R           - 20\|10 %%BT0
+--R      *
+--R         log
+--R                ((1708454400%%BT0 - 18808600)%%BT1 - 18808600%%BT0 - 4392020)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |          2                            2
+--R                \|- 750%%BT1  - 500%%BT0 %%BT1 - 750%%BT0  - 3021
+--R            + 
+--R                            +--+                 +--+      2
+--R              (- 8542272000\|10 %%BT0 + 94043000\|10 )%%BT1
+--R            + 
+--R                            +--+     2            +--+
+--R              (- 8542272000\|10 %%BT0  - 21960100\|10 )%%BT1
+--R            + 
+--R                       +--+     2            +--+
+--R              94043000\|10 %%BT0  - 21960100\|10 %%BT0
+--R            + 
+--R                                       +--+
+--R              (541735337x + 213096267)\|10
+--R     + 
+--R             +-----------------------------------------------+
+--R             |          2                            2              +--+
+--R           4\|- 750%%BT1  - 500%%BT0 %%BT1 - 750%%BT0  - 3021  - 20\|10 %%BT1
+--R         + 
+--R                +--+
+--R           - 20\|10 %%BT0
+--R      *
+--R         log
+--R                ((- 1708454400%%BT0 + 18808600)%%BT1 + 18808600%%BT0 + 4392020)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |          2                            2
+--R                \|- 750%%BT1  - 500%%BT0 %%BT1 - 750%%BT0  - 3021
+--R            + 
+--R                            +--+                 +--+      2
+--R              (- 8542272000\|10 %%BT0 + 94043000\|10 )%%BT1
+--R            + 
+--R                            +--+     2            +--+
+--R              (- 8542272000\|10 %%BT0  - 21960100\|10 )%%BT1
+--R            + 
+--R                       +--+     2            +--+
+--R              94043000\|10 %%BT0  - 21960100\|10 %%BT0
+--R            + 
+--R                                       +--+
+--R              (541735337x + 213096267)\|10
+--R     + 
+--R            +--+
+--R         40\|10 %%BT1
+--R      *
+--R         log
+--R                                                 2
+--R              (17084544000%%BT0 - 188086000)%%BT1
+--R            + 
+--R                               2                                    3
+--R              (17084544000%%BT0  + 43920200)%%BT1 + 17084544000%%BT0
+--R            + 
+--R              51612407424%%BT0 + 541735337x - 355111539
+--R     + 
+--R                                      +---------+
+--R        +---------------+      2      |  +-+         2 +-+    2
+--R        |     +-+            (x  + x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R       \|2665\|5  - 5959 log(-------------------------------------------)
+--R                                                   2
+--R                                                  x
+--R     + 
+--R                                          +---------+
+--R          +---------------+        2      |  +-+         2 +-+    2
+--R          |     +-+            (- x  - x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R       - \|2665\|5  - 5959 log(---------------------------------------------)
+--R                                                      2
+--R                                                     x
+--R     + 
+--R            +--+
+--R         40\|10 %%BT0
+--R      *
+--R         log
+--R                                3                 2
+--R              - 17084544000%%BT0  - 188086000%%BT0  - 51568487224%%BT0
+--R            + 
+--R              541735337x - 71080995
+--R     + 
+--R           +---------------+
+--R           |     +-+
+--R         2\|2665\|5  + 5959
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                        +---------+
+--R                          +-+           |  +-+
+--R                ((2x + 2)\|5  + 2x + 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R       -
+--R              +---------------+
+--R              |     +-+
+--R            2\|2665\|5  + 5959
+--R         *
+--R            atan
+--R                               +---------+ +---------+
+--R                      +-+      |  +-+      |  +-+
+--R                   (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R                 + 
+--R                                             +---------+
+--R                               +-+           |  +-+
+--R                   ((- 2x - 2)\|5  - 2x - 2)\|2\|5  - 2
+--R              /
+--R                 8x
+--R     + 
+--R            +--+     2x + 1       +--+
+--R       - 70\|10 atan(------) + 38\|10
+--R                         2
+--R                       2x
+--R  /
+--R        +--+
+--R     40\|10
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                  +---------+ +---------------+
+--R             2           +-+     2           +--+ |  +-+      |     +-+
+--R       ((- 4x  - 2x - 1)\|5  - 8x  - 6x - 3)\|10 \|2\|5  - 2 \|2665\|5  + 5959
+--R     + 
+--R                                                  +---------+ +---------------+
+--R             2           +-+     2           +--+ |  +-+      |     +-+
+--R       ((- 2x  + 2x + 1)\|5  - 2x  + 6x + 3)\|10 \|2\|5  + 2 \|2665\|5  - 5959
+--R     + 
+--R             2                +-+        2
+--R       (1760x  + 1080x + 540)\|5  + 5280x  + 3240x + 1620
+--R  /
+--R          4       2               +-+        4        2
+--R     (800x  + 800x  + 800x + 200)\|5  + 2400x  + 2400x  + 2400x + 600
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 534
+t0:=1/(1+4*x+4*x^2+4*x^4)^(1/2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         +------------------+
+--R         |  4     2
+--R        \|4x  + 4x  + 4x + 1
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 534
+--r0:=-x^2*elliptic_f(asin((1+1/x)*sqrt(1/5-2/5*%i)),-3/5+4/5*%i)*sqrt(5)*_
+--   sqrt(1+(-1/5-2/5*%i)*(1+1/x)^2)*sqrt(1+(-1/5+2/5*%i)*(1+1/x)^2)/_
+--   (sqrt(1-2*%i)*sqrt((5-2*(1+1/x)^2+(1+1/x)^4)*x^4))
+--E 476
+
+--S 477 of 534
+--a0:=integrate(t0,x)
+--E 477
+
+--S 478 of 534
+--m0:=a0-r0
+--E 478
+
+--S 479 of 534
+--d0:=D(m0,x)
+--E 479
+
+)clear all
+
+--S 480 of 534
+t0:=1/(1+4*x+4*x^2+4*x^4)^(3/2)
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R                             +------------------+
+--R           4     2           |  4     2
+--R        (4x  + 4x  + 4x + 1)\|4x  + 4x  + 4x + 1
+--R                                                    Type: Expression(Integer)
+--E 480
+
+--S 481 of 534
+--r0:=-(3-(1+1/x)^2)*x^2/sqrt((5-2*(1+1/x)^2+(1+1/x)^4)*x^4)+(1+1/x)*x^2/_
+--   sqrt((5-2*(1+1/x)^2+(1+1/x)^4)*x^4)+3/10*(1-3*(1+1/x)^2)*(1+1/x)*x^2/_
+--   sqrt((5-2*(1+1/x)^2+(1+1/x)^4)*x^4)-9/2*x^2*elliptic_e(asin((1+1/x)*_
+--   sqrt(1/5-2/5*%i)),-3/5+4/5*%i)*sqrt(1/5-2/5*%i)*sqrt(1+(-1/5-2/5*%i)*_
+--   (1+1/x)^2)*sqrt(1+(-1/5+2/5*%i)*(1+1/x)^2)/sqrt((5-2*(1+1/x)^2+_
+--   (1+1/x)^4)*x^4)+(3-3*%i)*x^2*elliptic_f(asin((1+1/x)*sqrt(1/5-2/5*%i)),_
+--   -3/5+4/5*%i)*sqrt(1/5-2/5*%i)*sqrt(1+(-1/5-2/5*%i)*(1+1/x)^2)*_
+--   sqrt(1+(-1/5+2/5*%i)*(1+1/x)^2)/sqrt((5-2*(1+1/x)^2+(1+1/x)^4)*x^4)
+--E 481
+
+--S 482 of 534
+--a0:=integrate(t0,x)
+--E 482
+
+--S 483 of 534
+--m0:=a0-r0
+--E 483
+
+--S 484 of 534
+--d0:=D(m0,x)
+--E 484
+
+)clear all
+
+--S 485 of 534
+t0:=(8+24*x+8*x^2-15*x^3+8*x^4)^4
+--R 
+--R
+--R   (1)
+--R          16         15          14          13         12          11
+--R     4096x   - 30720x   + 102784x   - 151008x   - 12095x   + 373536x
+--R   + 
+--R              10          9          8          7          6          5
+--R     - 331040x   - 339168x  + 641152x  + 291072x  - 566912x  - 184320x
+--R   + 
+--R            4          3          2
+--R     538624x  + 559104x  + 237568x  + 49152x + 4096
+--R                                                    Type: Polynomial(Integer)
+--E 485
+
+--S 486 of 534
+r0:=4096*x+24576*x^2+237568/3*x^3+139776*x^4+538624/5*x^5-30720*x^6-_
+   566912/7*x^7+36384*x^8+641152/9*x^9-169584/5*x^10-331040/11*x^11+_
+   31128*x^12-12095/13*x^13-75504/7*x^14+102784/15*x^15-1920*x^16+_
+   4096/17*x^17
+--R 
+--R
+--R   (2)
+--R     4096  17        16   102784  15   75504  14   12095  13         12
+--R     ---- x   - 1920x   + ------ x   - ----- x   - ----- x   + 31128x
+--R      17                    15           7           13
+--R   + 
+--R       331040  11   169584  10   641152  9         8   566912  7         6
+--R     - ------ x   - ------ x   + ------ x  + 36384x  - ------ x  - 30720x
+--R         11            5            9                     7
+--R   + 
+--R     538624  5          4   237568  3         2
+--R     ------ x  + 139776x  + ------ x  + 24576x  + 4096x
+--R        5                      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 486
+
+--S 487 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     4096  17        16   102784  15   75504  14   12095  13         12
+--R     ---- x   - 1920x   + ------ x   - ----- x   - ----- x   + 31128x
+--R      17                    15           7           13
+--R   + 
+--R       331040  11   169584  10   641152  9         8   566912  7         6
+--R     - ------ x   - ------ x   + ------ x  + 36384x  - ------ x  - 30720x
+--R         11            5            9                     7
+--R   + 
+--R     538624  5          4   237568  3         2
+--R     ------ x  + 139776x  + ------ x  + 24576x  + 4096x
+--R        5                      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 487
+
+--S 488 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 488
+
+--S 489 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 489
+
+)clear all
+
+--S 490 of 534
+t0:=(8+24*x+8*x^2-15*x^3+8*x^4)^3
+--R 
+--R
+--R   (1)
+--R         12        11        10        9        8         7        6         5
+--R     512x   - 2880x   + 6936x   - 4527x  - 8808x  + 16776x  + 5528x  - 17856x
+--R   + 
+--R           4         3         2
+--R     - 384x  + 20160x  + 15360x  + 4608x + 512
+--R                                                    Type: Polynomial(Integer)
+--E 490
+
+--S 491 of 534
+r0:=512*x+2304*x^2+5120*x^3+5040*x^4-384/5*x^5-2976*x^6+5528/7*x^7+_
+   2097*x^8-2936/3*x^9-4527/10*x^10+6936/11*x^11-240*x^12+512/13*x^13
+--R 
+--R
+--R   (2)
+--R     512  13       12   6936  11   4527  10   2936  9        8   5528  7
+--R     --- x   - 240x   + ---- x   - ---- x   - ---- x  + 2097x  + ---- x
+--R      13                 11         10          3                  7
+--R   + 
+--R            6   384  5        4        3        2
+--R     - 2976x  - --- x  + 5040x  + 5120x  + 2304x  + 512x
+--R                 5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 491
+
+--S 492 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     512  13       12   6936  11   4527  10   2936  9        8   5528  7
+--R     --- x   - 240x   + ---- x   - ---- x   - ---- x  + 2097x  + ---- x
+--R      13                 11         10          3                  7
+--R   + 
+--R            6   384  5        4        3        2
+--R     - 2976x  - --- x  + 5040x  + 5120x  + 2304x  + 512x
+--R                 5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 492
+
+--S 493 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 493
+
+--S 494 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 494
+
+)clear all
+
+--S 495 of 534
+t0:=(8+24*x+8*x^2-15*x^3+8*x^4)^2
+--R 
+--R
+--R           8       7       6       5       4       3       2
+--R   (1)  64x  - 240x  + 353x  + 144x  - 528x  + 144x  + 704x  + 384x + 64
+--R                                                    Type: Polynomial(Integer)
+--E 495
+
+--S 496 of 534
+r0:=64*x+192*x^2+704/3*x^3+36*x^4-528/5*x^5+24*x^6+353/7*x^7-30*x^8+64/9*x^9
+--R 
+--R
+--R        64  9      8   353  7      6   528  5      4   704  3       2
+--R   (2)  -- x  - 30x  + --- x  + 24x  - --- x  + 36x  + --- x  + 192x  + 64x
+--R         9              7               5               3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 496
+
+--S 497 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R        64  9      8   353  7      6   528  5      4   704  3       2
+--R   (3)  -- x  - 30x  + --- x  + 24x  - --- x  + 36x  + --- x  + 192x  + 64x
+--R         9              7               5               3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 497
+
+--S 498 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 498
+
+--S 499 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 499
+
+)clear all
+
+--S 500 of 534
+t0:=8+24*x+8*x^2-15*x^3+8*x^4
+--R 
+--R
+--R          4      3     2
+--R   (1)  8x  - 15x  + 8x  + 24x + 8
+--R                                                    Type: Polynomial(Integer)
+--E 500
+
+--S 501 of 534
+r0:=8*x+12*x^2+8/3*x^3-15/4*x^4+8/5*x^5
+--R 
+--R
+--R        8  5   15  4   8  3      2
+--R   (2)  - x  - -- x  + - x  + 12x  + 8x
+--R        5       4      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 501
+
+--S 502 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R        8  5   15  4   8  3      2
+--R   (3)  - x  - -- x  + - x  + 12x  + 8x
+--R        5       4      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 502
+
+--S 503 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 503
+
+--S 504 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 504
+
+)clear all
+
+--S 505 of 534
+t0:=1/(8+24*x+8*x^2-15*x^3+8*x^4)
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R          4      3     2
+--R        8x  - 15x  + 8x  + 24x + 8
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 505
+
+--S 506 of 534
+r0:=-1/4*atan(1/2*(19-(3+4/x)^2)/sqrt(39))*sqrt(3/13)-1/8*log((3+4/x)^2+_
+   sqrt(517)-(3+4/x)*sqrt(2*(19+sqrt(517))))*sqrt(1/40326*(-5167+235*_
+   sqrt(517)))+1/8*log((3+4/x)^2+sqrt(517)+(3+4/x)*sqrt(2*(19+sqrt(517))))*_
+   sqrt(1/40326*(-5167+235*sqrt(517)))+1/4*atan((-2*(3+4/x)+sqrt(2*_
+   (19+sqrt(517))))/sqrt(2*(-19+sqrt(517))))*sqrt(1/40326*(5167+235*_
+   sqrt(517)))-1/4*atan((2*(3+4/x)+sqrt(2*(19+sqrt(517))))/sqrt(2*_
+   (-19+sqrt(517))))*sqrt(1/40326*(5167+235*sqrt(517)))
+--R 
+--R
+--R   (2)
+--R               +----------------+
+--R          +--+ |    +---+
+--R         \|13 \|235\|517  - 5167
+--R      *
+--R                        +------------+
+--R                2       |  +---+          2 +---+     2
+--R             (3x  + 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R         log(-----------------------------------------------------)
+--R                                        2
+--R                                       x
+--R     + 
+--R       -
+--R                  +----------------+
+--R             +--+ |    +---+
+--R            \|13 \|235\|517  - 5167
+--R         *
+--R                             +------------+
+--R                     2       |  +---+          2 +---+     2
+--R                (- 3x  - 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R            log(-------------------------------------------------------)
+--R                                            2
+--R                                           x
+--R     + 
+--R       -
+--R                   +----------------+
+--R              +--+ |    +---+
+--R            2\|13 \|235\|517  + 5167
+--R         *
+--R            atan
+--R                                   +------------+ +------------+
+--R                      +---+        |  +---+       |  +---+
+--R                   (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R                 + 
+--R                                                 +------------+
+--R                             +---+               |  +---+
+--R                   ((6x + 8)\|517  + 114x + 152)\|2\|517  - 38
+--R              /
+--R                 312x
+--R     + 
+--R                +----------------+
+--R           +--+ |    +---+
+--R         2\|13 \|235\|517  + 5167
+--R      *
+--R         atan
+--R                                +------------+ +------------+
+--R                   +---+        |  +---+       |  +---+
+--R                (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R              + 
+--R                                                +------------+
+--R                            +---+               |  +---+
+--R                ((- 6x - 8)\|517  - 114x - 152)\|2\|517  - 38
+--R           /
+--R              312x
+--R     + 
+--R                              2            +--+
+--R           +-+ +-----+     (5x  - 12x - 8)\|39
+--R       - 2\|3 \|40326 atan(--------------------)
+--R                                      2
+--R                                   39x
+--R  /
+--R       +--+ +-----+
+--R     8\|13 \|40326
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +-------------------------------------------------------+
+--R            |             2                                 2
+--R           \|- 120978%%BU1  - 80652%%BU0 %%BU1 - 120978%%BU0  - 2455
+--R         + 
+--R              +-----+         +-----+
+--R           - \|40326 %%BU1 - \|40326 %%BU0
+--R      *
+--R         log
+--R                ((50392946604%%BU0 + 715256256)%%BU1 + 715256256%%BU0 + 9442004)
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |             2                                 2
+--R                \|- 120978%%BU1  - 80652%%BU0 %%BU1 - 120978%%BU0  - 2455
+--R            + 
+--R                           +-----+                  +-----+      2
+--R              (50392946604\|40326 %%BU0 + 715256256\|40326 )%%BU1
+--R            + 
+--R                           +-----+     2           +-----+
+--R              (50392946604\|40326 %%BU0  - 9442004\|40326 )%%BU1
+--R            + 
+--R                        +-----+     2           +-----+
+--R              715256256\|40326 %%BU0  - 9442004\|40326 %%BU0
+--R            + 
+--R                                   +-----+
+--R              (4758335x + 2270648)\|40326
+--R     + 
+--R              +-------------------------------------------------------+
+--R              |             2                                 2
+--R           - \|- 120978%%BU1  - 80652%%BU0 %%BU1 - 120978%%BU0  - 2455
+--R         + 
+--R              +-----+         +-----+
+--R           - \|40326 %%BU1 - \|40326 %%BU0
+--R      *
+--R         log
+--R                    (- 50392946604%%BU0 - 715256256)%%BU1 - 715256256%%BU0
+--R                  + 
+--R                    - 9442004
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |             2                                 2
+--R                \|- 120978%%BU1  - 80652%%BU0 %%BU1 - 120978%%BU0  - 2455
+--R            + 
+--R                           +-----+                  +-----+      2
+--R              (50392946604\|40326 %%BU0 + 715256256\|40326 )%%BU1
+--R            + 
+--R                           +-----+     2           +-----+
+--R              (50392946604\|40326 %%BU0  - 9442004\|40326 )%%BU1
+--R            + 
+--R                        +-----+     2           +-----+
+--R              715256256\|40326 %%BU0  - 9442004\|40326 %%BU0
+--R            + 
+--R                                   +-----+
+--R              (4758335x + 2270648)\|40326
+--R     + 
+--R           +-----+
+--R         2\|40326 %%BU1
+--R      *
+--R         log
+--R                                                       2
+--R              (- 4736936980776%%BU0 - 67234088064)%%BU1
+--R            + 
+--R                                   2                                       3
+--R              (- 4736936980776%%BU0  + 887548376)%%BU1 - 4736936980776%%BU0
+--R            + 
+--R              - 72094804145%%BU0 + 223641745x - 916562824
+--R     + 
+--R           +-----+
+--R         2\|40326 %%BU0
+--R      *
+--R         log
+--R                                 3                    2
+--R              37895495846208%%BU0  - 537872704512%%BU0  + 583858820168%%BU0
+--R            + 
+--R              1789133960x + 2270349121
+--R  /
+--R       +-----+
+--R     2\|40326
+--R                                         Type: Union(Expression(Integer),...)
+--E 507
+
+--S 508 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +-------------------------------------------------------+
+--R             +--+ |             2                                 2
+--R           4\|13 \|- 120978%%BU1  - 80652%%BU0 %%BU1 - 120978%%BU0  - 2455
+--R         + 
+--R               +--+ +-----+          +--+ +-----+
+--R           - 4\|13 \|40326 %%BU1 - 4\|13 \|40326 %%BU0
+--R      *
+--R         log
+--R                ((50392946604%%BU0 + 715256256)%%BU1 + 715256256%%BU0 + 9442004)
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |             2                                 2
+--R                \|- 120978%%BU1  - 80652%%BU0 %%BU1 - 120978%%BU0  - 2455
+--R            + 
+--R                           +-----+                  +-----+      2
+--R              (50392946604\|40326 %%BU0 + 715256256\|40326 )%%BU1
+--R            + 
+--R                           +-----+     2           +-----+
+--R              (50392946604\|40326 %%BU0  - 9442004\|40326 )%%BU1
+--R            + 
+--R                        +-----+     2           +-----+
+--R              715256256\|40326 %%BU0  - 9442004\|40326 %%BU0
+--R            + 
+--R                                   +-----+
+--R              (4758335x + 2270648)\|40326
+--R     + 
+--R                    +-------------------------------------------------------+
+--R               +--+ |             2                                 2
+--R           - 4\|13 \|- 120978%%BU1  - 80652%%BU0 %%BU1 - 120978%%BU0  - 2455
+--R         + 
+--R               +--+ +-----+          +--+ +-----+
+--R           - 4\|13 \|40326 %%BU1 - 4\|13 \|40326 %%BU0
+--R      *
+--R         log
+--R                    (- 50392946604%%BU0 - 715256256)%%BU1 - 715256256%%BU0
+--R                  + 
+--R                    - 9442004
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |             2                                 2
+--R                \|- 120978%%BU1  - 80652%%BU0 %%BU1 - 120978%%BU0  - 2455
+--R            + 
+--R                           +-----+                  +-----+      2
+--R              (50392946604\|40326 %%BU0 + 715256256\|40326 )%%BU1
+--R            + 
+--R                           +-----+     2           +-----+
+--R              (50392946604\|40326 %%BU0  - 9442004\|40326 )%%BU1
+--R            + 
+--R                        +-----+     2           +-----+
+--R              715256256\|40326 %%BU0  - 9442004\|40326 %%BU0
+--R            + 
+--R                                   +-----+
+--R              (4758335x + 2270648)\|40326
+--R     + 
+--R           +--+ +-----+
+--R         8\|13 \|40326 %%BU1
+--R      *
+--R         log
+--R                                                       2
+--R              (- 4736936980776%%BU0 - 67234088064)%%BU1
+--R            + 
+--R                                   2                                       3
+--R              (- 4736936980776%%BU0  + 887548376)%%BU1 - 4736936980776%%BU0
+--R            + 
+--R              - 72094804145%%BU0 + 223641745x - 916562824
+--R     + 
+--R           +--+ +-----+
+--R         8\|13 \|40326 %%BU0
+--R      *
+--R         log
+--R                                 3                    2
+--R              37895495846208%%BU0  - 537872704512%%BU0  + 583858820168%%BU0
+--R            + 
+--R              1789133960x + 2270349121
+--R     + 
+--R       -
+--R                  +----------------+
+--R             +--+ |    +---+
+--R            \|13 \|235\|517  - 5167
+--R         *
+--R                           +------------+
+--R                   2       |  +---+          2 +---+     2
+--R                (3x  + 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R            log(-----------------------------------------------------)
+--R                                           2
+--R                                          x
+--R     + 
+--R               +----------------+
+--R          +--+ |    +---+
+--R         \|13 \|235\|517  - 5167
+--R      *
+--R                          +------------+
+--R                  2       |  +---+          2 +---+     2
+--R             (- 3x  - 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R         log(-------------------------------------------------------)
+--R                                         2
+--R                                        x
+--R     + 
+--R                +----------------+
+--R           +--+ |    +---+
+--R         2\|13 \|235\|517  + 5167
+--R      *
+--R         atan
+--R                                +------------+ +------------+
+--R                   +---+        |  +---+       |  +---+
+--R                (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R              + 
+--R                                              +------------+
+--R                          +---+               |  +---+
+--R                ((6x + 8)\|517  + 114x + 152)\|2\|517  - 38
+--R           /
+--R              312x
+--R     + 
+--R       -
+--R                   +----------------+
+--R              +--+ |    +---+
+--R            2\|13 \|235\|517  + 5167
+--R         *
+--R            atan
+--R                                   +------------+ +------------+
+--R                      +---+        |  +---+       |  +---+
+--R                   (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R                 + 
+--R                                                   +------------+
+--R                               +---+               |  +---+
+--R                   ((- 6x - 8)\|517  - 114x - 152)\|2\|517  - 38
+--R              /
+--R                 312x
+--R     + 
+--R                            2            +--+
+--R         +-+ +-----+     (5x  - 12x - 8)\|39
+--R       2\|3 \|40326 atan(--------------------)
+--R                                    2
+--R                                 39x
+--R  /
+--R       +--+ +-----+
+--R     8\|13 \|40326
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 2               +---+        2                 +-----+
+--R         ((- 305x  - 228x - 152)\|517  - 6887x  - 5268x - 3512)\|40326
+--R      *
+--R          +------------+ +----------------+
+--R          |  +---+       |    +---+
+--R         \|2\|517  - 38 \|235\|517  + 5167
+--R     + 
+--R               2               +---+        2                 +-----+
+--R         ((134x  - 228x - 152)\|517  + 2936x  - 5268x - 3512)\|40326
+--R      *
+--R          +------------+ +----------------+
+--R          |  +---+       |    +---+
+--R         \|2\|517  + 38 \|235\|517  - 5167
+--R     + 
+--R                2            +-+ +--+ +--+             +---+
+--R       ((353628x  + 471504x)\|3 \|13 \|39  + 12259104)\|517
+--R     + 
+--R                2              +-+ +--+ +--+
+--R       (8170668x  + 10894224x)\|3 \|13 \|39  + 283249824
+--R  /
+--R                 4             3            2                          +---+
+--R       (98072832x  - 183886560x  + 98072832x  + 294218496x + 98072832)\|517
+--R     + 
+--R                  4              3              2
+--R       2265998592x  - 4248747360x  + 2265998592x  + 6797995776x + 2265998592
+--R                                                    Type: Expression(Integer)
+--E 509
+
+)clear all
+
+--S 510 of 534
+t0:=1/(8+24*x+8*x^2-15*x^3+8*x^4)^2
+--R 
+--R
+--R                                        1
+--R   (1)  ----------------------------------------------------------------
+--R           8       7       6       5       4       3       2
+--R        64x  - 240x  + 353x  + 144x  - 528x  + 144x  + 704x  + 384x + 64
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 510
+
+--S 511 of 534
+r0:=-3/208*(3359-146*(3+4/x)^2)/(517-38*(3+4/x)^2+(3+4/x)^4)+97/48*(3+4/x)/_
+   (517-38*(3+4/x)^2+(3+4/x)^4)+1/161304*(1337997-74897*(3+4/x)^2)*(3+4/x)/_
+   (517-38*(3+4/x)^2+(3+4/x)^4)-9/16*(3+4/x)^2/(517-38*(3+4/x)^2+(3+4/x)^4)+_
+   1/16*(3+4/x)^3/(517-38*(3+4/x)^2+(3+4/x)^4)-73/208*atan(1/2*(19-_
+   (3+4/x)^2)/sqrt(39))*sqrt(3/13)-1/645216*log((3+4/x)^2+sqrt(517)-_
+   (3+4/x)*sqrt(2*(19+sqrt(517))))*sqrt(1/40326*(-59644114671451+_
+   2623170438295*sqrt(517)))+1/645216*log((3+4/x)^2+sqrt(517)+(3+4/x)*_
+   sqrt(2*(19+sqrt(517))))*sqrt(1/40326*(-59644114671451+2623170438295*_
+   sqrt(517)))+1/322608*atan((-2*(3+4/x)+sqrt(2*(19+sqrt(517))))/_
+   sqrt(2*(-19+sqrt(517))))*sqrt(1/40326*(59644114671451+2623170438295*_
+   sqrt(517)))-1/322608*atan((2*(3+4/x)+sqrt(2*(19+sqrt(517))))/_
+   sqrt(2*(-19+sqrt(517))))*sqrt(1/40326*(59644114671451+2623170438295*_
+   sqrt(517)))
+--R 
+--R
+--R   (2)
+--R            4      3     2            +--+
+--R         (8x  - 15x  + 8x  + 24x + 8)\|13
+--R      *
+--R          +------------------------------------+
+--R          |              +---+
+--R         \|2623170438295\|517  - 59644114671451
+--R      *
+--R                        +------------+
+--R                2       |  +---+          2 +---+     2
+--R             (3x  + 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R         log(-----------------------------------------------------)
+--R                                        2
+--R                                       x
+--R     + 
+--R              4      3     2            +--+
+--R         (- 8x  + 15x  - 8x  - 24x - 8)\|13
+--R      *
+--R          +------------------------------------+
+--R          |              +---+
+--R         \|2623170438295\|517  - 59644114671451
+--R      *
+--R                          +------------+
+--R                  2       |  +---+          2 +---+     2
+--R             (- 3x  - 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R         log(-------------------------------------------------------)
+--R                                         2
+--R                                        x
+--R     + 
+--R               4      3      2             +--+
+--R         (- 16x  + 30x  - 16x  - 48x - 16)\|13
+--R      *
+--R          +------------------------------------+
+--R          |              +---+
+--R         \|2623170438295\|517  + 59644114671451
+--R      *
+--R         atan
+--R                                +------------+ +------------+
+--R                   +---+        |  +---+       |  +---+
+--R                (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R              + 
+--R                                              +------------+
+--R                          +---+               |  +---+
+--R                ((6x + 8)\|517  + 114x + 152)\|2\|517  - 38
+--R           /
+--R              312x
+--R     + 
+--R             4      3      2             +--+
+--R         (16x  - 30x  + 16x  + 48x + 16)\|13
+--R      *
+--R          +------------------------------------+
+--R          |              +---+
+--R         \|2623170438295\|517  + 59644114671451
+--R      *
+--R         atan
+--R                                +------------+ +------------+
+--R                   +---+        |  +---+       |  +---+
+--R                (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R              + 
+--R                                                +------------+
+--R                            +---+               |  +---+
+--R                ((- 6x - 8)\|517  - 114x - 152)\|2\|517  - 38
+--R           /
+--R              312x
+--R     + 
+--R                    4           3           2                       +-+ +-----+
+--R         (- 1811568x  + 3396690x  - 1811568x  - 5434704x - 1811568)\|3 \|40326
+--R      *
+--R                 2            +--+
+--R              (5x  - 12x - 8)\|39
+--R         atan(--------------------)
+--R                         2
+--R                      39x
+--R     + 
+--R                 4          3          2            +--+ +-----+
+--R       (- 291552x  + 703780x  - 668808x  - 518524x)\|13 \|40326
+--R  /
+--R              4           3           2                        +--+ +-----+
+--R     (5161728x  - 9678240x  + 5161728x  + 15485184x + 5161728)\|13 \|40326
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 534
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  4      3     2
+--R             (- 8x  + 15x  - 8x  - 24x - 8)
+--R          *
+--R             ROOT
+--R                                        2
+--R                  - 393465526595856%%BV1  - 262310351063904%%BV0 %%BV1
+--R                + 
+--R                                        2
+--R                  - 393465526595856%%BV0  - 14911625619311
+--R         + 
+--R                     4           3          2                      +-----+
+--R           (- 645216x  + 1209780x  - 645216x  - 1935648x - 645216)\|20163 %%BV1
+--R         + 
+--R                     4           3          2                      +-----+
+--R           (- 645216x  + 1209780x  - 645216x  - 1935648x - 645216)\|20163 %%BV0
+--R      *
+--R         log
+--R                      13113333997804760981499303411513024%%BV0
+--R                    + 
+--R                      2361655181966782198708381712256
+--R                 *
+--R                    %%BV1
+--R                + 
+--R                  2361655181966782198708381712256%%BV0
+--R                + 
+--R                  - 88225425252039290437652716
+--R             *
+--R                ROOT
+--R                                           2
+--R                     - 393465526595856%%BV1  - 262310351063904%%BV0 %%BV1
+--R                   + 
+--R                                           2
+--R                     - 393465526595856%%BV0  - 14911625619311
+--R            + 
+--R                                                             +-----+
+--R                  - 1057616613590949582679881818745348411648\|20163 %%BV0
+--R                + 
+--R                                                         +-----+
+--R                  - 190472213735984917890228401856870912\|20163
+--R             *
+--R                     2
+--R                %%BV1
+--R            + 
+--R                                                             +-----+     2
+--R                  - 1057616613590949582679881818745348411648\|20163 %%BV0
+--R                + 
+--R                                                    +-----+
+--R                  - 7115556997427472852377566850832\|20163
+--R             *
+--R                %%BV1
+--R            + 
+--R                                                     +-----+     2
+--R              - 190472213735984917890228401856870912\|20163 %%BV0
+--R            + 
+--R                                                +-----+
+--R              - 7115556997427472852377566850832\|20163 %%BV0
+--R            + 
+--R                  150930531402994079881533903215265x
+--R                + 
+--R                  77247044665512794234180236919144
+--R             *
+--R                 +-----+
+--R                \|20163
+--R     + 
+--R                4      3     2
+--R             (8x  - 15x  + 8x  + 24x + 8)
+--R          *
+--R             ROOT
+--R                                        2
+--R                  - 393465526595856%%BV1  - 262310351063904%%BV0 %%BV1
+--R                + 
+--R                                        2
+--R                  - 393465526595856%%BV0  - 14911625619311
+--R         + 
+--R                     4           3          2                      +-----+
+--R           (- 645216x  + 1209780x  - 645216x  - 1935648x - 645216)\|20163 %%BV1
+--R         + 
+--R                     4           3          2                      +-----+
+--R           (- 645216x  + 1209780x  - 645216x  - 1935648x - 645216)\|20163 %%BV0
+--R      *
+--R         log
+--R                      - 13113333997804760981499303411513024%%BV0
+--R                    + 
+--R                      - 2361655181966782198708381712256
+--R                 *
+--R                    %%BV1
+--R                + 
+--R                  - 2361655181966782198708381712256%%BV0
+--R                + 
+--R                  88225425252039290437652716
+--R             *
+--R                ROOT
+--R                                           2
+--R                     - 393465526595856%%BV1  - 262310351063904%%BV0 %%BV1
+--R                   + 
+--R                                           2
+--R                     - 393465526595856%%BV0  - 14911625619311
+--R            + 
+--R                                                             +-----+
+--R                  - 1057616613590949582679881818745348411648\|20163 %%BV0
+--R                + 
+--R                                                         +-----+
+--R                  - 190472213735984917890228401856870912\|20163
+--R             *
+--R                     2
+--R                %%BV1
+--R            + 
+--R                                                             +-----+     2
+--R                  - 1057616613590949582679881818745348411648\|20163 %%BV0
+--R                + 
+--R                                                    +-----+
+--R                  - 7115556997427472852377566850832\|20163
+--R             *
+--R                %%BV1
+--R            + 
+--R                                                     +-----+     2
+--R              - 190472213735984917890228401856870912\|20163 %%BV0
+--R            + 
+--R                                                +-----+
+--R              - 7115556997427472852377566850832\|20163 %%BV0
+--R            + 
+--R                  150930531402994079881533903215265x
+--R                + 
+--R                  77247044665512794234180236919144
+--R             *
+--R                 +-----+
+--R                \|20163
+--R     + 
+--R                  4           3           2                       +-----+
+--R         (1290432x  - 2419560x  + 1290432x  + 3871296x + 1290432)\|20163 %%BV1
+--R      *
+--R         log
+--R                  2115233227181899165359763637490696823296%%BV0
+--R                + 
+--R                  380944427471969835780456803713741824
+--R             *
+--R                     2
+--R                %%BV1
+--R            + 
+--R                                                               2
+--R                  2115233227181899165359763637490696823296%%BV0
+--R                + 
+--R                  14231113994854945704755133701664
+--R             *
+--R                %%BV1
+--R            + 
+--R                                                           3
+--R              2115233227181899165359763637490696823296%%BV0
+--R            + 
+--R              60122610208354571824345502731022307432%%BV0
+--R            + 
+--R              150930531402994079881533903215265x
+--R            + 
+--R              10905071149176173110139073138101752
+--R     + 
+--R                  4           3           2                       +-----+
+--R         (1290432x  - 2419560x  + 1290432x  + 3871296x + 1290432)\|20163 %%BV0
+--R      *
+--R         log
+--R                                                              3
+--R              - 16921865817455193322878109099925574586368%%BV0
+--R            + 
+--R                                                        2
+--R              3047555419775758686243654429709934592%%BV0
+--R            + 
+--R              - 480980767817924615755198383807108846144%%BV0
+--R            + 
+--R              1207444251223952639052271225722120x
+--R            + 
+--R              - 90740479879102500787082477443749295
+--R     + 
+--R              3         2                   +-----+
+--R       (39280x  - 94314x  + 89033x + 72888)\|20163
+--R  /
+--R              4           3           2                       +-----+
+--R     (1290432x  - 2419560x  + 1290432x  + 3871296x + 1290432)\|20163
+--R                                         Type: Union(Expression(Integer),...)
+--E 512
+
+--S 513 of 534
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                  +--+ +-----+
+--R                4\|13 \|40326
+--R             *
+--R                ROOT
+--R                                           2
+--R                     - 393465526595856%%BV1  - 262310351063904%%BV0 %%BV1
+--R                   + 
+--R                                           2
+--R                     - 393465526595856%%BV0  - 14911625619311
+--R         + 
+--R                  +--+ +-----+ +-----+               +--+ +-----+ +-----+
+--R         - 322608\|13 \|20163 \|40326 %%BV1 - 322608\|13 \|20163 \|40326 %%BV0
+--R      *
+--R         log
+--R                      13113333997804760981499303411513024%%BV0
+--R                    + 
+--R                      2361655181966782198708381712256
+--R                 *
+--R                    %%BV1
+--R                + 
+--R                  2361655181966782198708381712256%%BV0
+--R                + 
+--R                  - 88225425252039290437652716
+--R             *
+--R                ROOT
+--R                                           2
+--R                     - 393465526595856%%BV1  - 262310351063904%%BV0 %%BV1
+--R                   + 
+--R                                           2
+--R                     - 393465526595856%%BV0  - 14911625619311
+--R            + 
+--R                                                             +-----+
+--R                  - 1057616613590949582679881818745348411648\|20163 %%BV0
+--R                + 
+--R                                                         +-----+
+--R                  - 190472213735984917890228401856870912\|20163
+--R             *
+--R                     2
+--R                %%BV1
+--R            + 
+--R                                                             +-----+     2
+--R                  - 1057616613590949582679881818745348411648\|20163 %%BV0
+--R                + 
+--R                                                    +-----+
+--R                  - 7115556997427472852377566850832\|20163
+--R             *
+--R                %%BV1
+--R            + 
+--R                                                     +-----+     2
+--R              - 190472213735984917890228401856870912\|20163 %%BV0
+--R            + 
+--R                                                +-----+
+--R              - 7115556997427472852377566850832\|20163 %%BV0
+--R            + 
+--R                  150930531402994079881533903215265x
+--R                + 
+--R                  77247044665512794234180236919144
+--R             *
+--R                 +-----+
+--R                \|20163
+--R     + 
+--R               +--+ +-----+
+--R             4\|13 \|40326
+--R          *
+--R             ROOT
+--R                                        2
+--R                  - 393465526595856%%BV1  - 262310351063904%%BV0 %%BV1
+--R                + 
+--R                                        2
+--R                  - 393465526595856%%BV0  - 14911625619311
+--R         + 
+--R                  +--+ +-----+ +-----+               +--+ +-----+ +-----+
+--R         - 322608\|13 \|20163 \|40326 %%BV1 - 322608\|13 \|20163 \|40326 %%BV0
+--R      *
+--R         log
+--R                      - 13113333997804760981499303411513024%%BV0
+--R                    + 
+--R                      - 2361655181966782198708381712256
+--R                 *
+--R                    %%BV1
+--R                + 
+--R                  - 2361655181966782198708381712256%%BV0
+--R                + 
+--R                  88225425252039290437652716
+--R             *
+--R                ROOT
+--R                                           2
+--R                     - 393465526595856%%BV1  - 262310351063904%%BV0 %%BV1
+--R                   + 
+--R                                           2
+--R                     - 393465526595856%%BV0  - 14911625619311
+--R            + 
+--R                                                             +-----+
+--R                  - 1057616613590949582679881818745348411648\|20163 %%BV0
+--R                + 
+--R                                                         +-----+
+--R                  - 190472213735984917890228401856870912\|20163
+--R             *
+--R                     2
+--R                %%BV1
+--R            + 
+--R                                                             +-----+     2
+--R                  - 1057616613590949582679881818745348411648\|20163 %%BV0
+--R                + 
+--R                                                    +-----+
+--R                  - 7115556997427472852377566850832\|20163
+--R             *
+--R                %%BV1
+--R            + 
+--R                                                     +-----+     2
+--R              - 190472213735984917890228401856870912\|20163 %%BV0
+--R            + 
+--R                                                +-----+
+--R              - 7115556997427472852377566850832\|20163 %%BV0
+--R            + 
+--R                  150930531402994079881533903215265x
+--R                + 
+--R                  77247044665512794234180236919144
+--R             *
+--R                 +-----+
+--R                \|20163
+--R     + 
+--R                +--+ +-----+ +-----+
+--R         645216\|13 \|20163 \|40326 %%BV1
+--R      *
+--R         log
+--R                  2115233227181899165359763637490696823296%%BV0
+--R                + 
+--R                  380944427471969835780456803713741824
+--R             *
+--R                     2
+--R                %%BV1
+--R            + 
+--R                                                               2
+--R                  2115233227181899165359763637490696823296%%BV0
+--R                + 
+--R                  14231113994854945704755133701664
+--R             *
+--R                %%BV1
+--R            + 
+--R                                                           3
+--R              2115233227181899165359763637490696823296%%BV0
+--R            + 
+--R              60122610208354571824345502731022307432%%BV0
+--R            + 
+--R              150930531402994079881533903215265x
+--R            + 
+--R              10905071149176173110139073138101752
+--R     + 
+--R       -
+--R                          +------------------------------------+
+--R             +--+ +-----+ |              +---+
+--R            \|13 \|20163 \|2623170438295\|517  - 59644114671451
+--R         *
+--R                           +------------+
+--R                   2       |  +---+          2 +---+     2
+--R                (3x  + 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R            log(-----------------------------------------------------)
+--R                                           2
+--R                                          x
+--R     + 
+--R                       +------------------------------------+
+--R          +--+ +-----+ |              +---+
+--R         \|13 \|20163 \|2623170438295\|517  - 59644114671451
+--R      *
+--R                          +------------+
+--R                  2       |  +---+          2 +---+     2
+--R             (- 3x  - 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R         log(-------------------------------------------------------)
+--R                                         2
+--R                                        x
+--R     + 
+--R                +--+ +-----+ +-----+
+--R         645216\|13 \|20163 \|40326 %%BV0
+--R      *
+--R         log
+--R                                                              3
+--R              - 16921865817455193322878109099925574586368%%BV0
+--R            + 
+--R                                                        2
+--R              3047555419775758686243654429709934592%%BV0
+--R            + 
+--R              - 480980767817924615755198383807108846144%%BV0
+--R            + 
+--R              1207444251223952639052271225722120x
+--R            + 
+--R              - 90740479879102500787082477443749295
+--R     + 
+--R                        +------------------------------------+
+--R           +--+ +-----+ |              +---+
+--R         2\|13 \|20163 \|2623170438295\|517  + 59644114671451
+--R      *
+--R         atan
+--R                                +------------+ +------------+
+--R                   +---+        |  +---+       |  +---+
+--R                (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R              + 
+--R                                              +------------+
+--R                          +---+               |  +---+
+--R                ((6x + 8)\|517  + 114x + 152)\|2\|517  - 38
+--R           /
+--R              312x
+--R     + 
+--R       -
+--R                           +------------------------------------+
+--R              +--+ +-----+ |              +---+
+--R            2\|13 \|20163 \|2623170438295\|517  + 59644114671451
+--R         *
+--R            atan
+--R                                   +------------+ +------------+
+--R                      +---+        |  +---+       |  +---+
+--R                   (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R                 + 
+--R                                                   +------------+
+--R                               +---+               |  +---+
+--R                   ((- 6x - 8)\|517  - 114x - 152)\|2\|517  - 38
+--R              /
+--R                 312x
+--R     + 
+--R                                         2            +--+
+--R              +-+ +-----+ +-----+     (5x  - 12x - 8)\|39
+--R       226446\|3 \|20163 \|40326 atan(--------------------)
+--R                                                 2
+--R                                              39x
+--R     + 
+--R             +--+ +-----+ +-----+
+--R       36444\|13 \|20163 \|40326
+--R  /
+--R            +--+ +-----+ +-----+
+--R     645216\|13 \|20163 \|40326
+--R                                                    Type: Expression(Integer)
+--E 513
+
+--S 514 of 534
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 2               +---+        2                 +-----+
+--R         ((- 305x  - 228x - 152)\|517  - 6887x  - 5268x - 3512)\|40326
+--R      *
+--R          +------------+ +------------------------------------+
+--R          |  +---+       |              +---+
+--R         \|2\|517  - 38 \|2623170438295\|517  + 59644114671451
+--R     + 
+--R               2               +---+        2                 +-----+
+--R         ((134x  - 228x - 152)\|517  + 2936x  - 5268x - 3512)\|40326
+--R      *
+--R          +------------+ +------------------------------------+
+--R          |  +---+       |              +---+
+--R         \|2\|517  + 38 \|2623170438295\|517  - 59644114671451
+--R     + 
+--R                        2                 +-+ +--+ +--+                2
+--R           (40038823044x  + 53385097392x)\|3 \|13 \|39  + 240768802560x
+--R         + 
+--R           - 704763629856x + 918170112288
+--R      *
+--R          +---+
+--R         \|517
+--R     + 
+--R                     2                   +-+ +--+ +--+                 2
+--R       (925107542964x  + 1233476723952x)\|3 \|13 \|39  + 5563026543360x
+--R     + 
+--R       - 16283749131936x + 21214562068128
+--R  /
+--R                         4                  3                 2
+--R           7909770046464x  - 14830818837120x  + 7909770046464x
+--R         + 
+--R           23729310139392x + 7909770046464
+--R      *
+--R          +---+
+--R         \|517
+--R     + 
+--R                       4                   3                   2
+--R       182757318441984x  - 342669972078720x  + 182757318441984x
+--R     + 
+--R       548271955325952x + 182757318441984
+--R                                                    Type: Expression(Integer)
+--E 514
+
+)clear all
+
+--S 515 of 534
+t0:=1/(8+24*x+8*x^2-15*x^3+8*x^4)^(1/2)
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R         +--------------------------+
+--R         |  4      3     2
+--R        \|8x  - 15x  + 8x  + 24x + 8
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 534
+--r0:=-x^2*elliptic_f(asin((3+4/x)/sqrt(19-2*%i*sqrt(39))),_
+--   (19*%i+2*sqrt(39))/(19*%i-2*sqrt(39)))*sqrt(1-(3+4/x)^2/(19-2*%i*_
+--   sqrt(39)))*sqrt(1-(3+4/x)^2/(19+2*%i*sqrt(39)))*sqrt(2*(19-2*%i*_
+--   sqrt(39)))/sqrt((517-38*(3+4/x)^2+(3+4/x)^4)*x^4)
+--E 516
+
+--S 517 of 534
+--a0:=integrate(t0,x)
+--E 517
+
+--S 518 of 534
+--m0:=a0-r0
+--E 518
+
+--S 519 of 534
+--d0:=D(m0,x)
+--E 519
+
+)clear all
+
+--S 520 of 534
+t0:=1/(8+24*x+8*x^2-15*x^3+8*x^4)^(3/2)
+--R 
+--R
+--R                                    1
+--R   (1)  ---------------------------------------------------------
+--R                                     +--------------------------+
+--R           4      3     2            |  4      3     2
+--R        (8x  - 15x  + 8x  + 24x + 8)\|8x  - 15x  + 8x  + 24x + 8
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 534
+--r0:=-1/26*(172-7*(3+4/x)^2)*x^2/(sqrt(2)*sqrt((517-38*(3+4/x)^2+_
+--   (3+4/x)^4)*x^4))+1/4*(3+4/x)*x^2/(sqrt(2)*sqrt((517-38*(3+4/x)^2+_
+--   (3+4/x)^4)*x^4))+1/80652*(81629-4910*(3+4/x)^2)*(3+4/x)*x^2/(sqrt(2)*_
+--   sqrt((517-38*(3+4/x)^2+(3+4/x)^4)*x^4))+1/2068*x^2*_
+--   elliptic_f(asin((3+4/x)/sqrt(19-2*%i*sqrt(39))),(19*%i+2*sqrt(39))/_
+--   (19*%i-2*sqrt(39)))*(9820*%i-299*sqrt(39))*sqrt(1-(3+4/x)^2/(19-2*%i*_
+--   sqrt(39)))*sqrt(1-(3+4/x)^2/(19+2*%i*sqrt(39)))*sqrt(1/78*(19-2*%i*_
+--   sqrt(39)))/sqrt((517-38*(3+4/x)^2+(3+4/x)^4)*x^4)-2455/40326*x^2*_
+--   elliptic_e(asin((3+4/x)/sqrt(19-2*%i*sqrt(39))),(19*%i+2*sqrt(39))/_
+--   (19*%i-2*sqrt(39)))*(19+2*%i*sqrt(39))*sqrt(1-(3+4/x)^2/(19-2*%i*_
+--   sqrt(39)))*sqrt(1-(3+4/x)^2/(19+2*%i*sqrt(39)))*sqrt(1/2*(19-2*%i*_
+--   sqrt(39)))/sqrt((517-38*(3+4/x)^2+(3+4/x)^4)*x^4)
+--E 521
+
+--S 522 of 534
+--a0:=integrate(t0,x)
+--E 522
+
+--S 523 of 534
+--m0:=a0-r0
+--E 523
+
+--S 524 of 534
+--d0:=D(m0,x)
+--E 524
+
+)clear all
+
+--S 525 of 534
+t0:=1/(9-6*x-44*x^2+15*x^3+3*x^4)^(1/2)
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R         +--------------------------+
+--R         |  4      3      2
+--R        \|3x  + 15x  - 44x  - 6x + 9
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 534
+--r0:=2*x^2*elliptic_f(asin((1+(-6)/x)/sqrt(91-6*sqrt(213))),_
+--   1/613*(15949-1092*sqrt(213)))*sqrt(1-(1+(-6)/x)^2/(91-6*sqrt(213)))*_
+--   sqrt(91-6*sqrt(213))*sqrt(1-(1+(-6)/x)^2/(91+6*sqrt(213)))/_
+--   sqrt((613-182*(1+(-6)/x)^2+(-1+6/x)^4)*x^4)
+--E 526
+
+--S 527 of 534
+--a0:=integrate(t0,x)
+--E 527
+
+--S 528 of 534
+--m0:=a0-r0
+--E 528
+
+--S 529 of 534
+--d0:=D(m0,x)
+--E 529
+
+)clear all
+
+--S 530 of 534
+t0:=1/(9-6*x-44*x^2+15*x^3+3*x^4)^(3/2)
+--R 
+--R
+--R                                    1
+--R   (1)  ---------------------------------------------------------
+--R                                     +--------------------------+
+--R           4      3      2           |  4      3      2
+--R        (3x  + 15x  - 44x  - 6x + 9)\|3x  + 15x  - 44x  - 6x + 9
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 534
+--r0:=-4/17253*(176-23*(1+(-6)/x)^2)*x^2/sqrt((613-182*(1+(-6)/x)^2+_
+--   (-1+6/x)^4)*x^4)-2/9*(1+(-6)/x)*x^2/sqrt((613-182*(1+(-6)/x)^2+_
+--   (-1+6/x)^4)*x^4)+2/10576089*(1265923-7444*(1+(-6)/x)^2)*(1+(-6)/x)*_
+--   x^2/sqrt((613-182*(1+(-6)/x)^2+(-1+6/x)^4)*x^4)-14888/17253*x^2*_
+--   elliptic_e(asin((1+(-6)/x)/sqrt(91-6*sqrt(213))),1/613*(15949-1092*_
+--   sqrt(213)))*sqrt(1-(1+(-6)/x)^2/(91-6*sqrt(213)))*sqrt(1/613*(91+6*_
+--   sqrt(213)))*sqrt(1-(1+(-6)/x)^2/(91+6*sqrt(213)))/sqrt((613-182*(1+_
+--   (-6)/x)^2+(-1+6/x)^4)*x^4)+2/27*x^2*elliptic_f(asin((1+(-6)/x)/_
+--   sqrt(91-6*sqrt(213))),1/613*(15949-1092*sqrt(213)))*_
+--   sqrt(1-(1+(-6)/x)^2/(91-6*sqrt(213)))*sqrt(1/130569*(2551963+_
+--   133098*sqrt(213)))*sqrt(1-(1+(-6)/x)^2/(91+6*sqrt(213)))/sqrt((613-_
+--   182*(1+(-6)/x)^2+(-1+6/x)^4)*x^4)
+--E 531
+
+--S 532 of 534
+--a0:=integrate(t0,x)
+--E 532
+
+--S 533 of 534
+--m0:=a0-r0
+--E 533
+
+--S 534 of 534
+--d0:=D(m0,x)
+--E 534
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich21.input.pamphlet b/src/input/rich21.input.pamphlet
new file mode 100644
index 0000000..80923f5
--- /dev/null
+++ b/src/input/rich21.input.pamphlet
@@ -0,0 +1,4047 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich21.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Piecewise constant extraction problems.input
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich21.output
+)spool rich21.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 248
+t0:=x^m*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R           +-------+
+--R         m |b x - a
+--R        x  |-------
+--R          \|   x
+--R   (1)  ------------
+--R         +---------+
+--R        \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 248
+r0:=2*x^(1+m)*sqrt(b-a/x)/((1+2*m)*sqrt(a-b*x))
+--R 
+--R
+--R                  +-------+
+--R            m + 1 |b x - a
+--R          2x      |-------
+--R                 \|   x
+--R   (2)  --------------------
+--R                 +---------+
+--R        (2m + 1)\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         +-------+
+--R             +---------+ |b x - a   m log(x)
+--R          2x\|- b x + a  |------- %e
+--R                        \|   x
+--R   (3)  - ----------------------------------
+--R                (2b m + b)x - 2a m - a
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 248
+m0:=a0-r0
+--R 
+--R
+--R           +-------+                     +-------+
+--R           |b x - a   m log(x)     m + 1 |b x - a
+--R        2x |------- %e         - 2x      |-------
+--R          \|   x                        \|   x
+--R   (4)  ------------------------------------------
+--R                            +---------+
+--R                   (2m + 1)\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                   2                   m log(x)             m + 1
+--R       ((2b m + b)x  + (- 2a m - a)x)%e         + (b x - a)x
+--R     + 
+--R                      2                 m
+--R       ((- 2b m - 2b)x  + (2a m + 2a)x)x
+--R  /
+--R                            +-------+
+--R              2 +---------+ |b x - a
+--R     (2m + 1)x \|- b x + a  |-------
+--R                           \|   x
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 248
+t0:=x^2*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R           +-------+
+--R         2 |b x - a
+--R        x  |-------
+--R          \|   x
+--R   (1)  ------------
+--R         +---------+
+--R        \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 248
+r0:=2/5*x^3*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R            +-------+
+--R          3 |b x - a
+--R        2x  |-------
+--R           \|   x
+--R   (2)  -------------
+--R          +---------+
+--R        5\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          +-------+
+--R            3 +---------+ |b x - a
+--R          2x \|- b x + a  |-------
+--R                         \|   x
+--R   (3)  - -------------------------
+--R                  5b x - 5a
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 248
+t0:=x*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R           +-------+
+--R           |b x - a
+--R         x |-------
+--R          \|   x
+--R   (1)  ------------
+--R         +---------+
+--R        \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 248
+r0:=2/3*x^2*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R            +-------+
+--R          2 |b x - a
+--R        2x  |-------
+--R           \|   x
+--R   (2)  -------------
+--R          +---------+
+--R        3\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           +-------+
+--R             2 +---------+ |b x - a
+--R        - 10x \|- b x + a  |-------  + 24b x - 24a
+--R                          \|   x
+--R   (3)  ------------------------------------------
+--R                        15b x - 15a
+--R                                         Type: Union(Expression(Integer),...)
+--E 13
+
+--S 14 of 248
+m0:=a0-r0
+--R 
+--R
+--R        8
+--R   (4)  -
+--R        5
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 248
+t0:=sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R          +-------+
+--R          |b x - a
+--R          |-------
+--R         \|   x
+--R   (1)  ------------
+--R         +---------+
+--R        \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 248
+r0:=2*x*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R           +-------+
+--R           |b x - a
+--R        2x |-------
+--R          \|   x
+--R   (2)  ------------
+--R         +---------+
+--R        \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         +-------+
+--R             +---------+ |b x - a
+--R          2x\|- b x + a  |-------
+--R                        \|   x
+--R   (3)  - ------------------------
+--R                   b x - a
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 248
+t0:=sqrt(b-a/x)/(x*sqrt(a-b*x))
+--R 
+--R
+--R           +-------+
+--R           |b x - a
+--R           |-------
+--R          \|   x
+--R   (1)  -------------
+--R          +---------+
+--R        x\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 248
+r0:=-2*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R              +-------+
+--R              |b x - a
+--R           2  |-------
+--R             \|   x
+--R   (2)  - ------------
+--R           +---------+
+--R          \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +-------+
+--R          +---------+ |b x - a
+--R        6\|- b x + a  |-------  - 8b x + 8a
+--R                     \|   x
+--R   (3)  -----------------------------------
+--R                     3b x - 3a
+--R                                         Type: Union(Expression(Integer),...)
+--E 23
+
+--S 24 of 248
+m0:=a0-r0
+--R 
+--R
+--R          8
+--R   (4)  - -
+--R          3
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 25
+
+)clear all
+
+--S 26 of 248
+t0:=sqrt(b-a/x)/(x^2*sqrt(a-b*x))
+--R 
+--R
+--R           +-------+
+--R           |b x - a
+--R           |-------
+--R          \|   x
+--R   (1)  --------------
+--R         2 +---------+
+--R        x \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 248
+r0:=-2/3*sqrt(b-a/x)/(x*sqrt(a-b*x))
+--R 
+--R
+--R               +-------+
+--R               |b x - a
+--R            2  |-------
+--R              \|   x
+--R   (2)  - --------------
+--R             +---------+
+--R          3x\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       +-------+
+--R           +---------+ |b x - a         2
+--R        10\|- b x + a  |-------  + 24b x  - 24a x
+--R                      \|   x
+--R   (3)  -----------------------------------------
+--R                           2
+--R                      15b x  - 15a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 28
+
+--S 29 of 248
+m0:=a0-r0
+--R 
+--R
+--R        8
+--R   (4)  -
+--R        5
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 248
+t0:=(a+b/x)^m*(c+d*x)^n
+--R 
+--R
+--R         a x + b m         n
+--R   (1)  (-------) (d x + c)
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 248
+--r0:=(a+b/x)^m*x*(c+d*x)^n*AppellF1(1-m,-m,-n,2-m,-a*x/b,-d*x/c)/((1-m)*((b+a*x)/b)^m*((c+d*x)/c)^n)
+--E 32
+
+--S 33 of 248
+--a0:=integrate(t0,x)
+--E 33
+
+--S 34 of 248
+--m0:=a0-r0
+--E 34
+
+--S 35 of 248
+--d0:=D(m0,x)
+--E 35
+
+)clear all
+
+--S 36 of 248
+t0:=(a+b/x)^m*(c+d*x)^2
+--R 
+--R
+--R          2 2             2  a x + b m
+--R   (1)  (d x  + 2c d x + c )(-------)
+--R                                x
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 248
+--r0:=1/6*(6*a^2*c^2-6*a*b*c*d*(1-m)+b^2*d^2*(2-3*m+m^2))*(a+b/x)^(1+m)*x/a^3+1/6*d*(6*a*c-b*d*(2-m))*(a+b/x)^(1+m)*x^2/a^2+1/3*d^2*(a+b/x)^(1+m)*x^3/a+1/6*b*m*(6*a^2*c^2-6*a*b*c*d*(1-m)+b^2*d^2*(2-3*m+m^2))*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,(a+b/x)/a)/(a^4*(1+m))
+--E 37
+
+--S 38 of 248
+--a0:=integrate(t0,x)
+--E 38
+
+--S 39 of 248
+--m0:=a0-r0
+--E 39
+
+--S 40 of 248
+--d0:=D(m0,x)
+--E 40
+
+)clear all
+
+--S 41 of 248
+t0:=(a+b/x)^m*(c+d*x)
+--R 
+--R
+--R                  a x + b m
+--R   (1)  (d x + c)(-------)
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 248
+--r0:=1/2*(2*a*c-b*d*(1-m))*(a+b/x)^(1+m)*x/a^2+1/2*d*(a+b/x)^(1+m)*x^2/a+1/2*b*(2*a*c-b*d*(1-m))*m*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,(a+b/x)/a)/(a^3*(1+m))
+--E 42
+
+--S 43 of 248
+--a0:=integrate(t0,x)
+--E 43
+
+--S 44 of 248
+--m0:=a0-r0
+--E 44
+
+--S 45 of 248
+--d0:=D(m0,x)
+--E 45
+
+)clear all
+
+--S 46 of 248
+t0:=(a+b/x)^m
+--R 
+--R
+--R         a x + b m
+--R   (1)  (-------)
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 248
+--r0:=(a+b/x)^(1+m)*x/a+b*m*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,(a+b/x)/a)/(a^2*(1+m))
+--E 47
+
+--S 48 of 248
+--a0:=integrate(t0,x)
+--E 48
+
+--S 49 of 248
+--m0:=a0-r0
+--E 49
+
+--S 50 of 248
+--d0:=D(m0,x)
+--E 50
+
+)clear all
+
+--S 51 of 248
+t0:=(a+b/x)^m/(c+d*x)
+--R 
+--R
+--R         a x + b m
+--R        (-------)
+--R            x
+--R   (1)  ----------
+--R          d x + c
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 248
+--r0:=(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,(a+b/x)/a)/(a*d*(1+m))-c*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,c*(a+b/x)/(a*c-b*d))/(d*(a*c-b*d)*(1+m))
+--E 52
+
+--S 53 of 248
+--a0:=integrate(t0,x)
+--E 53
+
+--S 54 of 248
+--m0:=a0-r0
+--E 54
+
+--S 55 of 248
+--d0:=D(m0,x)
+--E 55
+
+)clear all
+
+--S 56 of 248
+t0:=(a+b/x)^m/(c+d*x)^2
+--R 
+--R
+--R             a x + b m
+--R            (-------)
+--R                x
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 248
+--r0:=(a+b/x)^(1+m)/((a*c-b*d)*(d+c/x))+b*m*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,c*(a+b/x)/(a*c-b*d))/((a*c-b*d)^2*(1+m))
+--E 57
+
+--S 58 of 248
+--a0:=integrate(t0,x)
+--E 58
+
+--S 59 of 248
+--m0:=a0-r0
+--E 59
+
+--S 60 of 248
+--d0:=D(m0,x)
+--E 60
+
+)clear all
+
+--S 61 of 248
+t0:=(a+b/x)^m/(c+d*x)^3
+--R 
+--R
+--R                  a x + b m
+--R                 (-------)
+--R                     x
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 248
+--r0:=-1/2*d*(a+b/x)^(1+m)/(c*(a*c-b*d)*(d+c/x)^2)+1/2*(2*a*c-b*d*(1+m))*(a+b/x)^(1+m)/(c*(a*c-b*d)^2*(d+c/x))+1/2*b*m*(2*a*c-b*d*(1+m))*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,c*(a+b/x)/(a*c-b*d))/(c*(a*c-b*d)^3*(1+m))
+--E 62
+
+--S 63 of 248
+--a0:=integrate(t0,x)
+--E 63
+
+--S 64 of 248
+--m0:=a0-r0
+--E 64
+
+--S 65 of 248
+--d0:=D(m0,x)
+--E 65
+
+)clear all
+
+--S 66 of 248
+t0:=(a+b/x)^m/(c+d*x)^4
+--R 
+--R
+--R                       a x + b m
+--R                      (-------)
+--R                          x
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        d x  + 4c d x  + 6c d x  + 4c d x + c
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 248
+--r0:=1/3*d^2*(a+b/x)^(1+m)/(c^2*(a*c-b*d)*(d+c/x)^3)-1/6*d*(6*a*c-b*d*(4+m))*(a+b/x)^(1+m)/(c^2*(a*c-b*d)^2*(d+c/x)^2)+1/6*(6*a^2*c^2-6*a*b*c*d*(1+m)+b^2*d^2*(2+3*m+m^2))*(a+b/x)^(1+m)/(c^2*(a*c-b*d)^3*(d+c/x))+1/6*b*m*(6*a^2*c^2-6*a*b*c*d*(1+m)+b^2*d^2*(2+3*m+m^2))*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,c*(a+b/x)/(a*c-b*d))/(c^2*(a*c-b*d)^4*(1+m))
+--E 67
+
+--S 68 of 248
+--a0:=integrate(t0,x)
+--E 68
+
+--S 69 of 248
+--m0:=a0-r0
+--E 69
+
+--S 70 of 248
+--d0:=D(m0,x)
+--E 70
+
+)clear all
+
+--S 71 of 248
+t0:=x^m*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R         m |b x  - a
+--R        x  |--------
+--R           |    2
+--R          \|   x
+--R   (1)  -------------
+--R         +----------+
+--R         |     2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 248
+r0:=x^(1+m)*sqrt(b-a/x^2)/(m*sqrt(a-b*x^2))
+--R 
+--R
+--R               +--------+
+--R               |   2
+--R         m + 1 |b x  - a
+--R        x      |--------
+--R               |    2
+--R              \|   x
+--R   (2)  -----------------
+--R            +----------+
+--R            |     2
+--R          m\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +---------+
+--R                  |   2
+--R                m |%CJ b - a
+--R             %CJ  |---------
+--R           x      |      2
+--R         ++      \|   %CJ
+--R   (3)   |   ---------------- d%CJ
+--R        ++     +-----------+
+--R               |     2
+--R              \|- %CJ b + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 73
+
+--S 74 of 248
+m0:=a0-r0
+--R 
+--R
+--R                                +---------+
+--R                                |   2
+--R                              m |%CJ b - a
+--R                           %CJ  |---------                 +--------+
+--R          +----------+   x      |      2                   |   2
+--R          |     2      ++      \|   %CJ              m + 1 |b x  - a
+--R        m\|- b x  + a  |   ---------------- d%CJ  - x      |--------
+--R                      ++     +-----------+                 |    2
+--R                             |     2                      \|   x
+--R                            \|- %CJ b + a
+--R   (4)  -------------------------------------------------------------
+--R                                  +----------+
+--R                                  |     2
+--R                                m\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R            2      m + 1         3        m
+--R        (b x  - a)x      + (- b x  + a x)x
+--R   (5)  -----------------------------------
+--R                              +--------+
+--R                 +----------+ |   2
+--R               3 |     2      |b x  - a
+--R            m x \|- b x  + a  |--------
+--R                              |    2
+--R                             \|   x
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 248
+t0:=x^2*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R         2 |b x  - a
+--R        x  |--------
+--R           |    2
+--R          \|   x
+--R   (1)  -------------
+--R         +----------+
+--R         |     2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 248
+r0:=1/2*x^3*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R          3 |b x  - a
+--R         x  |--------
+--R            |    2
+--R           \|   x
+--R   (2)  --------------
+--R          +----------+
+--R          |     2
+--R        2\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +----------+ +--------+
+--R           2 |     2      |   2
+--R          x \|- b x  + a \|b x  - a
+--R   (3)  - --------------------------
+--R                      2
+--R                  2b x  - 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 78
+
+--S 79 of 248
+m0:=a0-r0
+--R 
+--R
+--R                           +--------+
+--R           +--------+      |   2
+--R         2 |   2         3 |b x  - a
+--R        x \|b x  - a  - x  |--------
+--R                           |    2
+--R                          \|   x
+--R   (4)  -----------------------------
+--R                  +----------+
+--R                  |     2
+--R                2\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R                                               +--------+
+--R                     +--------+                |   2
+--R              2      |   2            3        |b x  - a
+--R        (- b x  + a)\|b x  - a  + (b x  - a x) |--------
+--R                                               |    2
+--R                                              \|   x
+--R   (5)  -------------------------------------------------
+--R                             +--------+
+--R                +----------+ |   2      +--------+
+--R                |     2      |b x  - a  |   2
+--R               \|- b x  + a  |-------- \|b x  - a
+--R                             |    2
+--R                            \|   x
+--R                                                    Type: Expression(Integer)
+--E 80
+
+)clear all
+
+--S 81 of 248
+t0:=x*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R           |b x  - a
+--R         x |--------
+--R           |    2
+--R          \|   x
+--R   (1)  -------------
+--R         +----------+
+--R         |     2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 248
+r0:=x^2*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R         2 |b x  - a
+--R        x  |--------
+--R           |    2
+--R          \|   x
+--R   (2)  -------------
+--R         +----------+
+--R         |     2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +----------+ +--------+
+--R            |     2      |   2
+--R          x\|- b x  + a \|b x  - a
+--R   (3)  - -------------------------
+--R                      2
+--R                   b x  - a
+--R                                         Type: Union(Expression(Integer),...)
+--E 83
+
+--S 84 of 248
+m0:=a0-r0
+--R 
+--R
+--R                          +--------+
+--R          +--------+      |   2
+--R          |   2         2 |b x  - a
+--R        x\|b x  - a  - x  |--------
+--R                          |    2
+--R                         \|   x
+--R   (4)  ----------------------------
+--R                 +----------+
+--R                 |     2
+--R                \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R                                               +--------+
+--R                     +--------+                |   2
+--R              2      |   2            3        |b x  - a
+--R        (- b x  + a)\|b x  - a  + (b x  - a x) |--------
+--R                                               |    2
+--R                                              \|   x
+--R   (5)  -------------------------------------------------
+--R                              +--------+
+--R                 +----------+ |   2      +--------+
+--R                 |     2      |b x  - a  |   2
+--R               x\|- b x  + a  |-------- \|b x  - a
+--R                              |    2
+--R                             \|   x
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 248
+t0:=sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R          |b x  - a
+--R          |--------
+--R          |    2
+--R         \|   x
+--R   (1)  -------------
+--R         +----------+
+--R         |     2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 248
+r0:=x*log(x)*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R                 |b x  - a
+--R        x log(x) |--------
+--R                 |    2
+--R                \|   x
+--R   (2)  -------------------
+--R            +----------+
+--R            |     2
+--R           \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 248
+--a0:=integrate(t0,x)
+--E 88
+
+--S 89 of 248
+--m0:=a0-r0
+--E 89
+
+--S 90 of 248
+--d0:=D(m0,x)
+--E 90
+
+)clear all
+
+--S 91 of 248
+t0:=sqrt(b-a/x^2)/(x*sqrt(a-b*x^2))
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R           |b x  - a
+--R           |--------
+--R           |    2
+--R          \|   x
+--R   (1)  --------------
+--R          +----------+
+--R          |     2
+--R        x\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 248
+r0:=-sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R            |b x  - a
+--R            |--------
+--R            |    2
+--R           \|   x
+--R   (2)  - -------------
+--R           +----------+
+--R           |     2
+--R          \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +----------+ +--------+
+--R                  |     2      |   2
+--R        (- x + 1)\|- b x  + a \|b x  - a
+--R   (3)  ---------------------------------
+--R                       3
+--R                    b x  - a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 93
+
+--S 94 of 248
+m0:=a0-r0
+--R 
+--R
+--R                               +--------+
+--R                +--------+     |   2
+--R                |   2          |b x  - a
+--R        (x - 1)\|b x  - a  + x |--------
+--R                               |    2
+--R                              \|   x
+--R   (4)  ---------------------------------
+--R                    +----------+
+--R                    |     2
+--R                  x\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R                                               +--------+
+--R                     +--------+                |   2
+--R              2      |   2            3        |b x  - a
+--R        (- b x  + a)\|b x  - a  + (b x  - a x) |--------
+--R                                               |    2
+--R                                              \|   x
+--R   (5)  -------------------------------------------------
+--R                              +--------+
+--R                 +----------+ |   2      +--------+
+--R               3 |     2      |b x  - a  |   2
+--R              x \|- b x  + a  |-------- \|b x  - a
+--R                              |    2
+--R                             \|   x
+--R                                                    Type: Expression(Integer)
+--E 95
+
+)clear all
+
+--S 96 of 248
+t0:=sqrt(b-a/x^2)/(x^2*sqrt(a-b*x^2))
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R           |b x  - a
+--R           |--------
+--R           |    2
+--R          \|   x
+--R   (1)  ---------------
+--R           +----------+
+--R         2 |     2
+--R        x \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 248
+r0:=-1/2*sqrt(b-a/x^2)/(x*sqrt(a-b*x^2))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R             |b x  - a
+--R             |--------
+--R             |    2
+--R            \|   x
+--R   (2)  - ---------------
+--R             +----------+
+--R             |     2
+--R          2x\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +----------+ +--------+
+--R            2      |     2      |   2
+--R        (- x  + 1)\|- b x  + a \|b x  - a
+--R   (3)  ----------------------------------
+--R                       4       2
+--R                   2b x  - 2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 98
+
+--S 99 of 248
+m0:=a0-r0
+--R 
+--R
+--R                                +--------+
+--R                 +--------+     |   2
+--R          2      |   2          |b x  - a
+--R        (x  - 1)\|b x  - a  + x |--------
+--R                                |    2
+--R                               \|   x
+--R   (4)  ----------------------------------
+--R                     +----------+
+--R                   2 |     2
+--R                 2x \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R                                               +--------+
+--R                     +--------+                |   2
+--R              2      |   2            3        |b x  - a
+--R        (- b x  + a)\|b x  - a  + (b x  - a x) |--------
+--R                                               |    2
+--R                                              \|   x
+--R   (5)  -------------------------------------------------
+--R                              +--------+
+--R                 +----------+ |   2      +--------+
+--R               4 |     2      |b x  - a  |   2
+--R              x \|- b x  + a  |-------- \|b x  - a
+--R                              |    2
+--R                             \|   x
+--R                                                    Type: Expression(Integer)
+--E 100
+
+)clear all
+
+--S 101 of 248
+t0:=(a+b*x^2)^(5/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R                              +--------+
+--R          2 4         2    2  |   2
+--R        (b x  + 2a b x  + a )\|b x  + a
+--R   (1)  --------------------------------
+--R                  +-----------+
+--R                  |   2 4    2
+--R                 \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 248
+r0:=-1/4*x*(a-b*x^2)*(a+b*x^2)^(3/2)/sqrt(a^2-b^2*x^4)-9/8*a*x*(a-b*x^2)*_
+   sqrt(a+b*x^2)/sqrt(a^2-b^2*x^4)+19/8*a^2*atan(x*sqrt(b)/sqrt(a-b*x^2))*_
+   sqrt(a-b*x^2)*sqrt(a+b*x^2)/(sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            +----------+ +--------+           +-+
+--R          2 |     2      |   2              x\|b
+--R       19a \|- b x  + a \|b x  + a atan(-------------)
+--R                                         +----------+
+--R                                         |     2
+--R                                        \|- b x  + a
+--R     + 
+--R                                     +--------+
+--R          2 5         3      2   +-+ |   2
+--R       (2b x  + 9a b x  - 11a x)\|b \|b x  + a
+--R  /
+--R       +-----------+
+--R       |   2 4    2  +-+
+--R     8\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        +-------+
+--R                        |      4
+--R                2       |  361a
+--R         (- 4b x  - 4a) |- -----
+--R                       \|   16b
+--R      *
+--R                                                                  +-------+
+--R                    +-----------+ +--------+                      |      4
+--R                  2 |   2 4    2  |   2             2 3           |  361a
+--R             - 19a \|- b x  + a  \|b x  + a  + (- 4b x  - 4a b x) |- -----
+--R                                                                 \|   16b
+--R         log(--------------------------------------------------------------)
+--R                                           2
+--R                                        b x  + a
+--R     + 
+--R                         +-----------+ +--------+
+--R              3          |   2 4    2  |   2
+--R       (- 2b x  - 11a x)\|- b x  + a  \|b x  + a
+--R  /
+--R         2
+--R     8b x  + 8a
+--R                                         Type: Union(Expression(Integer),...)
+--E 103
+
+--S 104 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                            +-------+
+--R              +-----------+ |      4
+--R              |   2 4    2  |  361a   +-+
+--R            4\|- b x  + a   |- ----- \|b
+--R                           \|   16b
+--R         *
+--R                                                                     +-------+
+--R                       +-----------+ +--------+                      |      4
+--R                     2 |   2 4    2  |   2             2 3           |  361a
+--R                - 19a \|- b x  + a  \|b x  + a  + (- 4b x  - 4a b x) |- -----
+--R                                                                    \|   16b
+--R            log(--------------------------------------------------------------)
+--R                                              2
+--R                                           b x  + a
+--R     + 
+--R              +----------+ +--------+           +-+
+--R            2 |     2      |   2              x\|b
+--R       - 19a \|- b x  + a \|b x  + a atan(-------------)
+--R                                           +----------+
+--R                                           |     2
+--R                                          \|- b x  + a
+--R  /
+--R       +-----------+
+--R       |   2 4    2  +-+
+--R     8\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 248
+t0:=(a+b*x^2)^(3/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (b x  + a)\|b x  + a
+--R   (1)  ---------------------
+--R             +-----------+
+--R             |   2 4    2
+--R            \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 248
+r0:=-1/2*x*(a-b*x^2)*sqrt(a+b*x^2)/sqrt(a^2-b^2*x^4)+3/2*a*atan(x*_
+   sqrt(b)/sqrt(a-b*x^2))*sqrt(a-b*x^2)*sqrt(a+b*x^2)/(sqrt(b)*_
+   sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R      +----------+ +--------+           +-+                         +--------+
+--R      |     2      |   2              x\|b             3        +-+ |   2
+--R   3a\|- b x  + a \|b x  + a atan(-------------) + (b x  - a x)\|b \|b x  + a
+--R                                   +----------+
+--R                                   |     2
+--R                                  \|- b x  + a
+--R   ---------------------------------------------------------------------------
+--R                                 +-----------+
+--R                                 |   2 4    2  +-+
+--R                               2\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +-----+
+--R                      |    2
+--R               2      |  9a
+--R         (- b x  - a) |- ---
+--R                     \|   b
+--R      *
+--R                                                              +-----+
+--R                  +-----------+ +--------+                    |    2
+--R                  |   2 4    2  |   2            2 3          |  9a
+--R             - 3a\|- b x  + a  \|b x  + a  + (- b x  - a b x) |- ---
+--R                                                             \|   b
+--R         log(--------------------------------------------------------)
+--R                                        2
+--R                                     b x  + a
+--R     + 
+--R           +-----------+ +--------+
+--R           |   2 4    2  |   2
+--R       - x\|- b x  + a  \|b x  + a
+--R  /
+--R         2
+--R     2b x  + 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 108
+
+--S 109 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                           +-----+
+--R             +-----------+ |    2
+--R             |   2 4    2  |  9a   +-+
+--R            \|- b x  + a   |- --- \|b
+--R                          \|   b
+--R         *
+--R                                                                 +-----+
+--R                     +-----------+ +--------+                    |    2
+--R                     |   2 4    2  |   2            2 3          |  9a
+--R                - 3a\|- b x  + a  \|b x  + a  + (- b x  - a b x) |- ---
+--R                                                                \|   b
+--R            log(--------------------------------------------------------)
+--R                                           2
+--R                                        b x  + a
+--R     + 
+--R            +----------+ +--------+           +-+
+--R            |     2      |   2              x\|b
+--R       - 3a\|- b x  + a \|b x  + a atan(-------------)
+--R                                         +----------+
+--R                                         |     2
+--R                                        \|- b x  + a
+--R  /
+--R       +-----------+
+--R       |   2 4    2  +-+
+--R     2\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 110
+
+)clear all
+
+--S 111 of 248
+t0:=(a+b*x^2)^(1/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R          \|b x  + a
+--R   (1)  --------------
+--R         +-----------+
+--R         |   2 4    2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 248
+r0:=atan(x*sqrt(b)/sqrt(a-b*x^2))*sqrt(a-b*x^2)*sqrt(a+b*x^2)/_
+   (sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R         +----------+ +--------+           +-+
+--R         |     2      |   2              x\|b
+--R        \|- b x  + a \|b x  + a atan(-------------)
+--R                                      +----------+
+--R                                      |     2
+--R                                     \|- b x  + a
+--R   (2)  -------------------------------------------
+--R                      +-----------+
+--R                      |   2 4    2  +-+
+--R                     \|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     +-----------+ +--------+                  +---+
+--R                     |   2 4    2  |   2          2 3          |  1
+--R           +---+    \|- b x  + a  \|b x  + a  + (b x  + a b x) |- -
+--R           |  1                                               \|  b
+--R   (3)  -  |- - log(------------------------------------------------)
+--R          \|  b                            2
+--R                                        b x  + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 113
+
+--S 114 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R             +-----------+ +---+
+--R             |   2 4    2  |  1  +-+
+--R            \|- b x  + a   |- - \|b
+--R                          \|  b
+--R         *
+--R                 +-----------+ +--------+                  +---+
+--R                 |   2 4    2  |   2          2 3          |  1
+--R                \|- b x  + a  \|b x  + a  + (b x  + a b x) |- -
+--R                                                          \|  b
+--R            log(------------------------------------------------)
+--R                                       2
+--R                                    b x  + a
+--R     + 
+--R          +----------+ +--------+           +-+
+--R          |     2      |   2              x\|b
+--R       - \|- b x  + a \|b x  + a atan(-------------)
+--R                                       +----------+
+--R                                       |     2
+--R                                      \|- b x  + a
+--R  /
+--R      +-----------+
+--R      |   2 4    2  +-+
+--R     \|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 115
+
+)clear all
+
+--S 116 of 248
+t0:=1/((a+b*x^2)^(1/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R         +-----------+ +--------+
+--R         |   2 4    2  |   2
+--R        \|- b x  + a  \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 248
+r0:=atan(x*sqrt(2)*sqrt(b)/sqrt(a-b*x^2))*sqrt(a-b*x^2)*sqrt(a+b*x^2)/_
+   (a*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R         +----------+ +--------+         +-+ +-+
+--R         |     2      |   2            x\|2 \|b
+--R        \|- b x  + a \|b x  + a atan(-------------)
+--R                                      +----------+
+--R                                      |     2
+--R                                     \|- b x  + a
+--R   (2)  -------------------------------------------
+--R                        +-----------+
+--R                    +-+ |   2 4    2  +-+
+--R                  a\|2 \|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 248
+--a0:=integrate(t0,x)
+--E 118
+
+--S 119 of 248
+--m0:=a0-r0
+--E 119
+
+--S 120 of 248
+--d0:=D(m0,x)
+--E 120
+
+)clear all
+
+--S 121 of 248
+t0:=1/((a+b*x^2)^(3/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                         1
+--R   (1)  -----------------------------------
+--R                   +-----------+ +--------+
+--R            2      |   2 4    2  |   2
+--R        (b x  + a)\|- b x  + a  \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 248
+r0:=1/4*x*(a-b*x^2)/(a^2*sqrt(a+b*x^2)*sqrt(a^2-b^2*x^4))+_
+   3/4*atan(x*sqrt(2)*sqrt(b)/sqrt(a-b*x^2))*sqrt(a-b*x^2)*_
+   sqrt(a+b*x^2)/(a^2*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                     +----------+         +-+ +-+
+--R             2       |     2            x\|2 \|b             3        +-+ +-+
+--R        (3b x  + 3a)\|- b x  + a atan(-------------) + (- b x  + a x)\|2 \|b
+--R                                       +----------+
+--R                                       |     2
+--R                                      \|- b x  + a
+--R   (2)  ---------------------------------------------------------------------
+--R                                 +-----------+     +--------+
+--R                           2 +-+ |   2 4    2  +-+ |   2
+--R                         4a \|2 \|- b x  + a  \|b \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 248
+--a0:=integrate(t0,x)
+--E 123
+
+--S 124 of 248
+--m0:=a0-r0
+--E 124
+
+--S 125 of 248
+--d0:=D(m0,x)
+--E 125
+
+)clear all
+
+--S 126 of 248
+t0:=1/((a+b*x^2)^(5/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R                              +-----------+ +--------+
+--R          2 4         2    2  |   2 4    2  |   2
+--R        (b x  + 2a b x  + a )\|- b x  + a  \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 248
+r0:=1/8*x*(a-b*x^2)/(a^2*(a+b*x^2)^(3/2)*sqrt(a^2-b^2*x^4))+_
+    9/32*x*(a-b*x^2)/(a^3*sqrt(a+b*x^2)*sqrt(a^2-b^2*x^4))+_
+    19/32*atan(x*sqrt(2)*sqrt(b)/sqrt(a-b*x^2))*sqrt(a-b*x^2)*_
+    sqrt(a+b*x^2)/(a^3*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                  +----------+         +-+ +-+
+--R           2 4          2      2  |     2            x\|2 \|b
+--R       (19b x  + 38a b x  + 19a )\|- b x  + a atan(-------------)
+--R                                                    +----------+
+--R                                                    |     2
+--R                                                   \|- b x  + a
+--R     + 
+--R            2 5         3      2   +-+ +-+
+--R       (- 9b x  - 4a b x  + 13a x)\|2 \|b
+--R  /
+--R                           +-----------+     +--------+
+--R         3   2      4  +-+ |   2 4    2  +-+ |   2
+--R     (32a b x  + 32a )\|2 \|- b x  + a  \|b \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 248
+--a0:=integrate(t0,x)
+--E 128
+
+--S 129 of 248
+--m0:=a0-r0
+--E 129
+
+--S 130 of 248
+--d0:=D(m0,x)
+--E 130
+
+)clear all
+
+--S 131 of 248
+t0:=(a-b*x^2)^(5/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R                              +----------+
+--R          2 4         2    2  |     2
+--R        (b x  - 2a b x  + a )\|- b x  + a
+--R   (1)  ----------------------------------
+--R                   +-----------+
+--R                   |   2 4    2
+--R                  \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 248
+r0:=-1/4*x*(a-b*x^2)^(3/2)*(a+b*x^2)/sqrt(a^2-b^2*x^4)-9/8*a*x*(a+b*x^2)*_
+   sqrt(a-b*x^2)/sqrt(a^2-b^2*x^4)+19/8*a^2*atanh(x*sqrt(b)/sqrt(a+b*x^2))*_
+   sqrt(a-b*x^2)*sqrt(a+b*x^2)/(sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            +----------+ +--------+           +-+
+--R          2 |     2      |   2              x\|b
+--R       19a \|- b x  + a \|b x  + a atanh(-----------)
+--R                                          +--------+
+--R                                          |   2
+--R                                         \|b x  + a
+--R     + 
+--R                                 +----------+
+--R          2 5         3      2   |     2      +-+
+--R       (2b x  - 9a b x  - 11a x)\|- b x  + a \|b
+--R  /
+--R       +-----------+
+--R       |   2 4    2  +-+
+--R     8\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        +-----+
+--R                        |    4
+--R                2       |361a
+--R         (- 4b x  + 4a) |-----
+--R                       \| 16b
+--R      *
+--R                                +-----+
+--R                                |    4         +-----------+ +----------+
+--R                  2 3           |361a        2 |   2 4    2  |     2
+--R             (- 4b x  + 4a b x) |-----  - 19a \|- b x  + a  \|- b x  + a
+--R                               \| 16b
+--R         log(------------------------------------------------------------)
+--R                                          2
+--R                                       b x  - a
+--R     + 
+--R                         +-----------+ +----------+
+--R              3          |   2 4    2  |     2
+--R       (- 2b x  + 11a x)\|- b x  + a  \|- b x  + a
+--R  /
+--R         2
+--R     8b x  - 8a
+--R                                         Type: Union(Expression(Integer),...)
+--E 133
+
+--S 134 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                            +-----+
+--R              +-----------+ |    4
+--R              |   2 4    2  |361a   +-+
+--R            4\|- b x  + a   |----- \|b
+--R                           \| 16b
+--R         *
+--R                                   +-----+
+--R                                   |    4         +-----------+ +----------+
+--R                     2 3           |361a        2 |   2 4    2  |     2
+--R                (- 4b x  + 4a b x) |-----  - 19a \|- b x  + a  \|- b x  + a
+--R                                  \| 16b
+--R            log(------------------------------------------------------------)
+--R                                             2
+--R                                          b x  - a
+--R     + 
+--R              +----------+ +--------+           +-+
+--R            2 |     2      |   2              x\|b
+--R       - 19a \|- b x  + a \|b x  + a atanh(-----------)
+--R                                            +--------+
+--R                                            |   2
+--R                                           \|b x  + a
+--R  /
+--R       +-----------+
+--R       |   2 4    2  +-+
+--R     8\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 248
+t0:=(a-b*x^2)^(3/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R                     +----------+
+--R              2      |     2
+--R        (- b x  + a)\|- b x  + a
+--R   (1)  -------------------------
+--R               +-----------+
+--R               |   2 4    2
+--R              \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 248
+r0:=-1/2*x*(a+b*x^2)*sqrt(a-b*x^2)/sqrt(a^2-b^2*x^4)+_
+     3/2*a*atanh(x*sqrt(b)/sqrt(a+b*x^2))*sqrt(a-b*x^2)*_
+     sqrt(a+b*x^2)/(sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R          +----------+ +--------+           +-+
+--R          |     2      |   2              x\|b
+--R       3a\|- b x  + a \|b x  + a atanh(-----------)
+--R                                        +--------+
+--R                                        |   2
+--R                                       \|b x  + a
+--R     + 
+--R                      +----------+
+--R             3        |     2      +-+
+--R       (- b x  - a x)\|- b x  + a \|b
+--R  /
+--R       +-----------+
+--R       |   2 4    2  +-+
+--R     2\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +---+
+--R                      |  2
+--R               2      |9a
+--R         (- b x  + a) |---
+--R                     \| b
+--R      *
+--R                              +---+
+--R                              |  2       +-----------+ +----------+
+--R                 2 3          |9a        |   2 4    2  |     2
+--R             (- b x  + a b x) |---  - 3a\|- b x  + a  \|- b x  + a
+--R                             \| b
+--R         log(------------------------------------------------------)
+--R                                       2
+--R                                    b x  - a
+--R     + 
+--R         +-----------+ +----------+
+--R         |   2 4    2  |     2
+--R       x\|- b x  + a  \|- b x  + a
+--R  /
+--R         2
+--R     2b x  - 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 138
+
+--S 139 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                           +---+
+--R             +-----------+ |  2
+--R             |   2 4    2  |9a   +-+
+--R            \|- b x  + a   |--- \|b
+--R                          \| b
+--R         *
+--R                                 +---+
+--R                                 |  2       +-----------+ +----------+
+--R                    2 3          |9a        |   2 4    2  |     2
+--R                (- b x  + a b x) |---  - 3a\|- b x  + a  \|- b x  + a
+--R                                \| b
+--R            log(------------------------------------------------------)
+--R                                          2
+--R                                       b x  - a
+--R     + 
+--R            +----------+ +--------+           +-+
+--R            |     2      |   2              x\|b
+--R       - 3a\|- b x  + a \|b x  + a atanh(-----------)
+--R                                          +--------+
+--R                                          |   2
+--R                                         \|b x  + a
+--R  /
+--R       +-----------+
+--R       |   2 4    2  +-+
+--R     2\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 140
+
+)clear all
+
+--S 141 of 248
+t0:=(a-b*x^2)^(1/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R          +----------+
+--R          |     2
+--R         \|- b x  + a
+--R   (1)  --------------
+--R         +-----------+
+--R         |   2 4    2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 248
+r0:=atanh(x*sqrt(b)/sqrt(a+b*x^2))*sqrt(a-b*x^2)*sqrt(a+b*x^2)/(sqrt(b)*_
+    sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R         +----------+ +--------+           +-+
+--R         |     2      |   2              x\|b
+--R        \|- b x  + a \|b x  + a atanh(-----------)
+--R                                       +--------+
+--R                                       |   2
+--R                                      \|b x  + a
+--R   (2)  ------------------------------------------
+--R                     +-----------+
+--R                     |   2 4    2  +-+
+--R                    \|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   +-+    +-----------+ +----------+
+--R                      2 3          |1     |   2 4    2  |     2
+--R           +-+    (- b x  + a b x) |-  - \|- b x  + a  \|- b x  + a
+--R           |1                     \|b
+--R   (3)  -  |- log(--------------------------------------------------)
+--R          \|b                             2
+--R                                       b x  - a
+--R                                         Type: Union(Expression(Integer),...)
+--E 143
+
+--S 144 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R             +-----------+ +-+
+--R             |   2 4    2  |1  +-+
+--R            \|- b x  + a   |- \|b
+--R                          \|b
+--R         *
+--R                                 +-+    +-----------+ +----------+
+--R                    2 3          |1     |   2 4    2  |     2
+--R                (- b x  + a b x) |-  - \|- b x  + a  \|- b x  + a
+--R                                \|b
+--R            log(--------------------------------------------------)
+--R                                        2
+--R                                     b x  - a
+--R     + 
+--R          +----------+ +--------+           +-+
+--R          |     2      |   2              x\|b
+--R       - \|- b x  + a \|b x  + a atanh(-----------)
+--R                                        +--------+
+--R                                        |   2
+--R                                       \|b x  + a
+--R  /
+--R      +-----------+
+--R      |   2 4    2  +-+
+--R     \|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 145
+
+)clear all
+
+--S 146 of 248
+t0:=1/((a-b*x^2)^(1/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R         +-----------+ +----------+
+--R         |   2 4    2  |     2
+--R        \|- b x  + a  \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 248
+r0:=atanh(x*sqrt(2)*sqrt(b)/sqrt(a+b*x^2))*sqrt(a-b*x^2)*_
+    sqrt(a+b*x^2)/(a*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R         +----------+ +--------+         +-+ +-+
+--R         |     2      |   2            x\|2 \|b
+--R        \|- b x  + a \|b x  + a atanh(-----------)
+--R                                       +--------+
+--R                                       |   2
+--R                                      \|b x  + a
+--R   (2)  ------------------------------------------
+--R                        +-----------+
+--R                    +-+ |   2 4    2  +-+
+--R                  a\|2 \|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 248
+--a0:=integrate(t0,x)
+--E 148
+
+--S 149 of 248
+--m0:=a0-r0
+--E 149
+
+--S 150 of 248
+--d0:=D(m0,x)
+--E 150
+
+)clear all
+
+--S 151 of 248
+t0:=1/((a-b*x^2)^(3/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                            1
+--R   (1)  - -------------------------------------
+--R                     +-----------+ +----------+
+--R              2      |   2 4    2  |     2
+--R          (b x  - a)\|- b x  + a  \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 248
+r0:=1/4*x*(a+b*x^2)/(a^2*sqrt(a-b*x^2)*sqrt(a^2-b^2*x^4))+_
+    3/4*atanh(x*sqrt(2)*sqrt(b)/sqrt(a+b*x^2))*sqrt(a-b*x^2)*_
+    sqrt(a+b*x^2)/(a^2*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                       +--------+         +-+ +-+
+--R               2       |   2            x\|2 \|b          3        +-+ +-+
+--R        (- 3b x  + 3a)\|b x  + a atanh(-----------) + (b x  + a x)\|2 \|b
+--R                                        +--------+
+--R                                        |   2
+--R                                       \|b x  + a
+--R   (2)  ------------------------------------------------------------------
+--R                              +-----------+ +----------+
+--R                        2 +-+ |   2 4    2  |     2      +-+
+--R                      4a \|2 \|- b x  + a  \|- b x  + a \|b
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 248
+--a0:=integrate(t0,x)
+--E 153
+
+--S 154 of 248
+--m0:=a0-r0
+--E 154
+
+--S 155 of 248
+--d0:=D(m0,x)
+--E 155
+
+)clear all
+
+--S 156 of 248
+t0:=1/((a-b*x^2)^(5/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R                              +-----------+ +----------+
+--R          2 4         2    2  |   2 4    2  |     2
+--R        (b x  - 2a b x  + a )\|- b x  + a  \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 248
+r0:=1/8*x*(a+b*x^2)/(a^2*(a-b*x^2)^(3/2)*sqrt(a^2-b^2*x^4))+_
+    9/32*x*(a+b*x^2)/(a^3*sqrt(a-b*x^2)*sqrt(a^2-b^2*x^4))+_
+    19/32*atanh(x*sqrt(2)*sqrt(b)/sqrt(a+b*x^2))*sqrt(a-b*x^2)*_
+    sqrt(a+b*x^2)/(a^3*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                    +--------+         +-+ +-+
+--R             2 4          2      2  |   2            x\|2 \|b
+--R       (- 19b x  + 38a b x  - 19a )\|b x  + a atanh(-----------)
+--R                                                     +--------+
+--R                                                     |   2
+--R                                                    \|b x  + a
+--R     + 
+--R          2 5         3      2   +-+ +-+
+--R       (9b x  - 4a b x  - 13a x)\|2 \|b
+--R  /
+--R                           +-----------+ +----------+
+--R         3   2      4  +-+ |   2 4    2  |     2      +-+
+--R     (32a b x  - 32a )\|2 \|- b x  + a  \|- b x  + a \|b
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 248
+--a0:=integrate(t0,x)
+--E 158
+
+--S 159 of 248
+--m0:=a0-r0
+--E 159
+
+--S 160 of 248
+--d0:=D(m0,x)
+--E 160
+
+)clear all
+
+--S 161 of 248
+t0:=sqrt(x^2/(-1+x^2))/(1+x^2)
+--R 
+--R
+--R         +------+
+--R         |   2
+--R         |  x
+--R         |------
+--R         | 2
+--R        \|x  - 1
+--R   (1)  ---------
+--R           2
+--R          x  + 1
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 248
+r0:=atan(sqrt(-1+x^2)/sqrt(2))*sqrt(-x^2/(1-x^2))*sqrt(-1+x^2)/(x*sqrt(2))
+--R 
+--R
+--R         +------+               +------+
+--R         |   2    +------+      | 2
+--R         |  x     | 2          \|x  - 1
+--R         |------ \|x  - 1 atan(---------)
+--R         | 2                       +-+
+--R        \|x  - 1                  \|2
+--R   (2)  ---------------------------------
+--R                        +-+
+--R                      x\|2
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +------+
+--R               2      | 2         3               +-+
+--R             (x  + 2)\|x  - 1  - x  - x         x\|2
+--R        atan(--------------------------) - atan(-----)
+--R                         +-+                      2
+--R                        \|2
+--R   (3)  ----------------------------------------------
+--R                              +-+
+--R                             \|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 163
+
+--S 164 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +------+              +------+               +------+
+--R                2      | 2         3         |   2    +------+      | 2
+--R              (x  + 2)\|x  - 1  - x  - x     |  x     | 2          \|x  - 1
+--R       x atan(--------------------------) -  |------ \|x  - 1 atan(---------)
+--R                          +-+                | 2                       +-+
+--R                         \|2                \|x  - 1                  \|2
+--R     + 
+--R                  +-+
+--R                x\|2
+--R       - x atan(-----)
+--R                  2
+--R  /
+--R       +-+
+--R     x\|2
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                +------+                               +------+
+--R                |   2           +------+               |   2
+--R         3      |  x         3  | 2           4     2  |  x         4    2
+--R   ((- 2x  + x) |------  - 2x )\|x  - 1  + (2x  - 2x ) |------  + 2x  - x
+--R                | 2                                    | 2
+--R               \|x  - 1                               \|x  - 1
+--R   -----------------------------------------------------------------------
+--R                   +------+                                   +------+
+--R                   |   2    +------+                          |   2
+--R           5       |  x     | 2             6    4     2      |  x
+--R        (2x  - 2x) |------ \|x  - 1  + (- 2x  + x  + 2x  - 1) |------
+--R                   | 2                                        | 2
+--R                  \|x  - 1                                   \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 248
+t0:=sqrt(x^2/(-1+a+(1+a)*x^2))/(1+x^2)
+--R 
+--R
+--R         +-----------------+
+--R         |         2
+--R         |        x
+--R         |-----------------
+--R         |        2
+--R        \|(a + 1)x  + a - 1
+--R   (1)  --------------------
+--R                2
+--R               x  + 1
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 248
+r0:=atan(sqrt(-1+a+(1+a)*x^2)/sqrt(2))*sqrt(-x^2/(1-a-(1+a)*x^2))*_
+    sqrt(-1+a+(1+a)*x^2)/(x*sqrt(2))
+--R 
+--R
+--R         +-----------------+                          +-----------------+
+--R         |         2         +-----------------+      |        2
+--R         |        x          |        2              \|(a + 1)x  + a - 1
+--R         |----------------- \|(a + 1)x  + a - 1 atan(--------------------)
+--R         |        2                                           +-+
+--R        \|(a + 1)x  + a - 1                                  \|2
+--R   (2)  ------------------------------------------------------------------
+--R                                         +-+
+--R                                       x\|2
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    +-----------------+
+--R                +-+ |        2                2      +-+ +-----+
+--R               \|2 \|(a + 1)x  + a - 1  + (- x  - 1)\|2 \|a - 1
+--R          atan(-------------------------------------------------)
+--R                                        2
+--R                                      2x
+--R   (3)  - -------------------------------------------------------
+--R                                     +-+
+--R                                    \|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 168
+
+--S 169 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +-----------------+
+--R                 +-+ |        2                2      +-+ +-----+
+--R                \|2 \|(a + 1)x  + a - 1  + (- x  - 1)\|2 \|a - 1
+--R       - x atan(-------------------------------------------------)
+--R                                         2
+--R                                       2x
+--R     + 
+--R          +-----------------+                          +-----------------+
+--R          |         2         +-----------------+      |        2
+--R          |        x          |        2              \|(a + 1)x  + a - 1
+--R       -  |----------------- \|(a + 1)x  + a - 1 atan(--------------------)
+--R          |        2                                           +-+
+--R         \|(a + 1)x  + a - 1                                  \|2
+--R  /
+--R       +-+
+--R     x\|2
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R                                                          +-----------------+
+--R             +-----------------+                          |         2
+--R           2 |        2                     3             |        x
+--R        - x \|(a + 1)x  + a - 1  + ((a + 1)x  + (a - 1)x) |-----------------
+--R                                                          |        2
+--R                                                         \|(a + 1)x  + a - 1
+--R   (5)  ---------------------------------------------------------------------
+--R                                     +-----------------+
+--R                                     |         2         +-----------------+
+--R                  4       2          |        x          |        2
+--R         ((a + 1)x  + 2a x  + a - 1) |----------------- \|(a + 1)x  + a - 1
+--R                                     |        2
+--R                                    \|(a + 1)x  + a - 1
+--R                                                    Type: Expression(Integer)
+--E 170
+
+)clear all
+
+--S 171 of 248
+t0:=1/((1+x)*(-1+x^2))^(2/3)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         +---------------+2
+--R        3| 3    2
+--R        \|x  + x  - x - 1
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 248
+r0:=-3/2*(1-x^2)/(-(1+x)*(1-x^2))^(2/3)
+--R 
+--R
+--R                 2
+--R               3x  - 3
+--R   (2)  --------------------
+--R          +---------------+2
+--R         3| 3    2
+--R        2\|x  + x  - x - 1
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +---------------+
+--R         3| 3    2
+--R        3\|x  + x  - x - 1
+--R   (3)  -------------------
+--R               2x + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 173
+
+--S 174 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 175
+
+)clear all
+
+--S 176 of 248
+t0:=(-1+x^2)/((1+x^2)*sqrt(x*(1+x^2)))
+--R 
+--R
+--R               2
+--R              x  - 1
+--R   (1)  -----------------
+--R                 +------+
+--R          2      | 3
+--R        (x  + 1)\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 248
+r0:=-2*x/sqrt(x*(1+x^2))
+--R 
+--R
+--R              2x
+--R   (2)  - ---------
+--R           +------+
+--R           | 3
+--R          \|x  + x
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +------+
+--R            | 3
+--R          2\|x  + x
+--R   (3)  - ----------
+--R             2
+--R            x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 178
+
+--S 179 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 248
+t0:=(-1+x^2)/((1+x^2)*sqrt(x+x^3))
+--R 
+--R
+--R               2
+--R              x  - 1
+--R   (1)  -----------------
+--R                 +------+
+--R          2      | 3
+--R        (x  + 1)\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 248
+r0:=-2*x/sqrt(x+x^3)
+--R 
+--R
+--R              2x
+--R   (2)  - ---------
+--R           +------+
+--R           | 3
+--R          \|x  + x
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +------+
+--R            | 3
+--R          2\|x  + x
+--R   (3)  - ----------
+--R             2
+--R            x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 183
+
+--S 184 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 185
+
+)clear all
+
+--S 186 of 248
+t0:=sqrt((-1+x^2)^2/(x*(1+x^2)))/(1+x^2)
+--R 
+--R
+--R         +------------+
+--R         | 4     2
+--R         |x  - 2x  + 1
+--R         |------------
+--R         |    3
+--R        \|   x  + x
+--R   (1)  ---------------
+--R              2
+--R             x  + 1
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 248
+r0:=2*x*sqrt((1-x^2)^2/(x*(1+x^2)))/(1-x^2)
+--R 
+--R
+--R             +------------+
+--R             | 4     2
+--R             |x  - 2x  + 1
+--R          2x |------------
+--R             |    3
+--R            \|   x  + x
+--R   (2)  - -----------------
+--R                 2
+--R                x  - 1
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +------+
+--R            | 3
+--R          2\|x  + x
+--R   (3)  - ----------
+--R             2
+--R            x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 188
+
+--S 189 of 248
+m0:=a0-r0
+--R 
+--R
+--R                                          +------------+
+--R                    +------+              | 4     2
+--R             2      | 3           3       |x  - 2x  + 1
+--R        (- 2x  + 2)\|x  + x  + (2x  + 2x) |------------
+--R                                          |    3
+--R                                         \|   x  + x
+--R   (4)  ------------------------------------------------
+--R                              4
+--R                             x  - 1
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R                                             +------------+
+--R                         +------+            | 4     2
+--R            4     2      | 3          5      |x  - 2x  + 1
+--R        (- x  + 2x  - 1)\|x  + x  + (x  - x) |------------
+--R                                             |    3
+--R                                            \|   x  + x
+--R   (5)  ---------------------------------------------------
+--R                              +------------+
+--R                              | 4     2      +------+
+--R                 5     3      |x  - 2x  + 1  | 3
+--R               (x  + 2x  + x) |------------ \|x  + x
+--R                              |    3
+--R                             \|   x  + x
+--R                                                    Type: Expression(Integer)
+--E 190
+
+)clear all
+
+--S 191 of 248
+t0:=sqrt((-1+x^2)^2/(x+x^3))/(1+x^2)
+--R 
+--R
+--R         +------------+
+--R         | 4     2
+--R         |x  - 2x  + 1
+--R         |------------
+--R         |    3
+--R        \|   x  + x
+--R   (1)  ---------------
+--R              2
+--R             x  + 1
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 248
+r0:=2*x*sqrt((1-x^2)^2/(x+x^3))/(1-x^2)
+--R 
+--R
+--R             +------------+
+--R             | 4     2
+--R             |x  - 2x  + 1
+--R          2x |------------
+--R             |    3
+--R            \|   x  + x
+--R   (2)  - -----------------
+--R                 2
+--R                x  - 1
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +------+
+--R            | 3
+--R          2\|x  + x
+--R   (3)  - ----------
+--R             2
+--R            x  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 193
+
+--S 194 of 248
+m0:=a0-r0
+--R 
+--R
+--R                                          +------------+
+--R                    +------+              | 4     2
+--R             2      | 3           3       |x  - 2x  + 1
+--R        (- 2x  + 2)\|x  + x  + (2x  + 2x) |------------
+--R                                          |    3
+--R                                         \|   x  + x
+--R   (4)  ------------------------------------------------
+--R                              4
+--R                             x  - 1
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R                                             +------------+
+--R                         +------+            | 4     2
+--R            4     2      | 3          5      |x  - 2x  + 1
+--R        (- x  + 2x  - 1)\|x  + x  + (x  - x) |------------
+--R                                             |    3
+--R                                            \|   x  + x
+--R   (5)  ---------------------------------------------------
+--R                              +------------+
+--R                              | 4     2      +------+
+--R                 5     3      |x  - 2x  + 1  | 3
+--R               (x  + 2x  + x) |------------ \|x  + x
+--R                              |    3
+--R                             \|   x  + x
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 248
+t0:=1/(sqrt(a+b/x^2)*sqrt(c+d*x^2))
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         +--------+
+--R         |   2      +--------+
+--R         |a x  + b  |   2
+--R         |-------- \|d x  + c
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 248
+r0:=atanh(sqrt(d)*sqrt(b+a*x^2)/(sqrt(a)*sqrt(c+d*x^2)))*_
+    sqrt(b+a*x^2)/(x*sqrt(a)*sqrt(d)*sqrt(a+b/x^2))
+--R 
+--R
+--R                              +--------+
+--R         +--------+       +-+ |   2
+--R         |   2           \|d \|a x  + b
+--R        \|a x  + b atanh(---------------)
+--R                              +--------+
+--R                          +-+ |   2
+--R                         \|a \|d x  + c
+--R   (2)  ---------------------------------
+--R                     +--------+
+--R                     |   2
+--R                 +-+ |a x  + b  +-+
+--R               x\|a  |-------- \|d
+--R                     |    2
+--R                    \|   x
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 248
+--a0:=integrate(t0,x)
+--E 198
+
+--S 199 of 248
+--m0:=a0-r0
+--E 199
+
+--S 200 of 248
+--d0:=D(m0,x)
+--E 200
+
+)clear all
+
+--S 201 of 248
+t0:=sqrt(-2*x^2+x^4)/((-1+x^2)*(2+x^2))
+--R 
+--R
+--R         +--------+
+--R         | 4     2
+--R        \|x  - 2x
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  - 2
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 248
+r0:=2/3*atan(1/2*sqrt(-2+x^2))*sqrt(-2*x^2+x^4)/(x*sqrt(-2+x^2))-_
+    1/3*atan(sqrt(-2+x^2))*sqrt(-2*x^2+x^4)/(x*sqrt(-2+x^2))
+--R 
+--R
+--R                                                         +------+
+--R           +--------+      +------+      +--------+      | 2
+--R           | 4     2       | 2           | 4     2      \|x  - 2
+--R        - \|x  - 2x  atan(\|x  - 2 ) + 2\|x  - 2x  atan(---------)
+--R                                                            2
+--R   (2)  ----------------------------------------------------------
+--R                                   +------+
+--R                                   | 2
+--R                                3x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       +------+                            +------+
+--R                2      | 2         3                2      | 2         3
+--R              (x  + 1)\|x  - 2  - x  + x          (x  + 4)\|x  - 2  - x  - 2x
+--R       - atan(--------------------------) + 2atan(---------------------------)
+--R                           2                                   4
+--R     + 
+--R                       x
+--R       atan(x) - 2atan(-)
+--R                       2
+--R  /
+--R     3
+--R                                         Type: Union(Expression(Integer),...)
+--E 203
+
+--S 204 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +------+
+--R           +------+       2      | 2         3
+--R           | 2          (x  + 1)\|x  - 2  - x  + x
+--R       - x\|x  - 2 atan(--------------------------)
+--R                                     2
+--R     + 
+--R                                +------+
+--R          +------+       2      | 2         3          +--------+      +------+
+--R          | 2          (x  + 4)\|x  - 2  - x  - 2x     | 4     2       | 2
+--R       2x\|x  - 2 atan(---------------------------) + \|x  - 2x  atan(\|x  - 2 )
+--R                                    4
+--R     + 
+--R                           +------+
+--R           +--------+      | 2                                  +------+
+--R           | 4     2      \|x  - 2                          x   | 2
+--R       - 2\|x  - 2x  atan(---------) + (x atan(x) - 2x atan(-))\|x  - 2
+--R                              2                             2
+--R  /
+--R        +------+
+--R        | 2
+--R     3x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     +------+                  +--------+
+--R            4     2  | 2         5     3       | 4     2
+--R       ((- x  + 2x )\|x  - 2  + x  - 3x  + 2x)\|x  - 2x
+--R     + 
+--R                          +------+
+--R           6     4     2  | 2         7     5     3
+--R       (- x  + 3x  - 2x )\|x  - 2  + x  - 4x  + 4x
+--R  /
+--R                     +------+                       +--------+
+--R        6     2      | 2         7    5     3       | 4     2
+--R     ((x  - 3x  + 2)\|x  - 2  - x  + x  + 4x  - 4x)\|x  - 2x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+)clear all
+
+--S 206 of 248
+t0:=sqrt(1+(-1)/(-1+x^2)^2)/(2-x^2)
+--R 
+--R
+--R           +------------+
+--R           |   4     2
+--R           |  x  - 2x
+--R           |------------
+--R           | 4     2
+--R          \|x  - 2x  + 1
+--R   (1)  - ---------------
+--R                2
+--R               x  - 2
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 248
+r0a:=(1-x^2)*atan(sqrt(-2+x^2))*sqrt(1+(-1)/(1-x^2)^2)/(x*sqrt(-2+x^2))
+--R 
+--R
+--R                   +------------+
+--R                   |   4     2         +------+
+--R            2      |  x  - 2x          | 2
+--R        (- x  + 1) |------------ atan(\|x  - 2 )
+--R                   | 4     2
+--R                  \|x  - 2x  + 1
+--R   (2)  ----------------------------------------
+--R                         +------+
+--R                         | 2
+--R                       x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 207
+
+--S 208 of 248
+r0b:=(1-x^2)*atan(sqrt(-2+x^2))*sqrt(-2*x^2+x^4)*sqrt(1+(-1)/(1-x^2)^2)/_
+     (x*sqrt(-2+x^2)*sqrt(-1+(-1+x^2)^2))
+--R 
+--R
+--R                   +------------+
+--R                   |   4     2         +------+
+--R            2      |  x  - 2x          | 2
+--R        (- x  + 1) |------------ atan(\|x  - 2 )
+--R                   | 4     2
+--R                  \|x  - 2x  + 1
+--R   (3)  ----------------------------------------
+--R                         +------+
+--R                         | 2
+--R                       x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        +------+
+--R                 2      | 2         3
+--R               (x  + 1)\|x  - 2  - x  + x
+--R   (4)  - atan(--------------------------) + atan(x)
+--R                            2
+--R                                         Type: Union(Expression(Integer),...)
+--E 209
+
+--S 210 of 248
+m0:=a0-r0a
+--R 
+--R
+--R   (5)
+--R                                 +------+
+--R           +------+       2      | 2         3
+--R           | 2          (x  + 1)\|x  - 2  - x  + x
+--R       - x\|x  - 2 atan(--------------------------)
+--R                                     2
+--R     + 
+--R                +------------+
+--R                |   4     2         +------+              +------+
+--R         2      |  x  - 2x          | 2                   | 2
+--R       (x  - 1) |------------ atan(\|x  - 2 ) + x atan(x)\|x  - 2
+--R                | 4     2
+--R               \|x  - 2x  + 1
+--R  /
+--R       +------+
+--R       | 2
+--R     x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 210
+
+--S 211 of 248
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Polynomial(Integer)
+--E 211
+
+--S 212 of 248
+m0:=a0-r0b
+--R 
+--R
+--R   (7)
+--R                                 +------+
+--R           +------+       2      | 2         3
+--R           | 2          (x  + 1)\|x  - 2  - x  + x
+--R       - x\|x  - 2 atan(--------------------------)
+--R                                     2
+--R     + 
+--R                +------------+
+--R                |   4     2         +------+              +------+
+--R         2      |  x  - 2x          | 2                   | 2
+--R       (x  - 1) |------------ atan(\|x  - 2 ) + x atan(x)\|x  - 2
+--R                | 4     2
+--R               \|x  - 2x  + 1
+--R  /
+--R       +------+
+--R       | 2
+--R     x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 248
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Polynomial(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 248
+t0:=sqrt((-2*x^2+x^4)/(-1+x^2)^2)/(2+x^2)
+--R 
+--R
+--R         +------------+
+--R         |   4     2
+--R         |  x  - 2x
+--R         |------------
+--R         | 4     2
+--R        \|x  - 2x  + 1
+--R   (1)  ---------------
+--R              2
+--R             x  + 2
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 248
+r0:=-2/3*(1-x^2)*atan(1/2*sqrt(-2+x^2))*sqrt((-2*x^2+x^4)/(1-x^2)^2)/_
+     (x*sqrt(-2+x^2))+1/3*(1-x^2)*atan(sqrt(-2+x^2))*sqrt((-2*x^2+x^4)/_
+     (1-x^2)^2)/(x*sqrt(-2+x^2))
+--R 
+--R
+--R   (2)
+--R                  +------------+
+--R                  |   4     2         +------+
+--R           2      |  x  - 2x          | 2
+--R       (- x  + 1) |------------ atan(\|x  - 2 )
+--R                  | 4     2
+--R                 \|x  - 2x  + 1
+--R     + 
+--R                 +------------+      +------+
+--R                 |   4     2         | 2
+--R          2      |  x  - 2x         \|x  - 2
+--R       (2x  - 2) |------------ atan(---------)
+--R                 | 4     2              2
+--R                \|x  - 2x  + 1
+--R  /
+--R        +------+
+--R        | 2
+--R     3x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       +------+                            +------+
+--R                2      | 2         3                2      | 2         3
+--R              (x  + 1)\|x  - 2  - x  + x          (x  + 4)\|x  - 2  - x  - 2x
+--R       - atan(--------------------------) + 2atan(---------------------------)
+--R                           2                                   4
+--R     + 
+--R                       x
+--R       atan(x) - 2atan(-)
+--R                       2
+--R  /
+--R     3
+--R                                         Type: Union(Expression(Integer),...)
+--E 216
+
+--S 217 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +------+
+--R           +------+       2      | 2         3
+--R           | 2          (x  + 1)\|x  - 2  - x  + x
+--R       - x\|x  - 2 atan(--------------------------)
+--R                                     2
+--R     + 
+--R                                +------+
+--R          +------+       2      | 2         3
+--R          | 2          (x  + 4)\|x  - 2  - x  - 2x
+--R       2x\|x  - 2 atan(---------------------------)
+--R                                    4
+--R     + 
+--R                +------------+
+--R                |   4     2         +------+
+--R         2      |  x  - 2x          | 2
+--R       (x  - 1) |------------ atan(\|x  - 2 )
+--R                | 4     2
+--R               \|x  - 2x  + 1
+--R     + 
+--R                   +------------+      +------+
+--R                   |   4     2         | 2
+--R            2      |  x  - 2x         \|x  - 2
+--R       (- 2x  + 2) |------------ atan(---------)
+--R                   | 4     2              2
+--R                  \|x  - 2x  + 1
+--R     + 
+--R                                +------+
+--R                            x   | 2
+--R       (x atan(x) - 2x atan(-))\|x  - 2
+--R                            2
+--R  /
+--R        +------+
+--R        | 2
+--R     3x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                           +------------+
+--R                           |   4     2                      +------+
+--R            6     4     2  |  x  - 2x        6     4     2  | 2
+--R       ((- x  + 3x  - 2x ) |------------  - x  + 3x  - 2x )\|x  - 2
+--R                           | 4     2
+--R                          \|x  - 2x  + 1
+--R     + 
+--R                             +------------+
+--R                             |   4     2
+--R         7     5     3       |  x  - 2x        7     5     3
+--R       (x  - 4x  + 5x  - 2x) |------------  + x  - 4x  + 4x
+--R                             | 4     2
+--R                            \|x  - 2x  + 1
+--R  /
+--R                                 +------------+
+--R                                 |   4     2    +------+
+--R         8    6     4     2      |  x  - 2x     | 2
+--R       (x  - x  - 3x  + 5x  - 2) |------------ \|x  - 2
+--R                                 | 4     2
+--R                                \|x  - 2x  + 1
+--R     + 
+--R                                     +------------+
+--R                                     |   4     2
+--R           9     7     5     3       |  x  - 2x
+--R       (- x  + 2x  + 3x  - 8x  + 4x) |------------
+--R                                     | 4     2
+--R                                    \|x  - 2x  + 1
+--R                                                    Type: Expression(Integer)
+--E 218
+
+)clear all
+
+--S 219 of 248
+t0:=(1+2*x/(1+x^2))^(5/2)
+--R 
+--R
+--R                                  +-----------+
+--R                                  | 2
+--R          4     3     2           |x  + 2x + 1
+--R        (x  + 4x  + 6x  + 4x + 1) |-----------
+--R                                  |    2
+--R                                 \|   x  + 1
+--R   (1)  ---------------------------------------
+--R                       4     2
+--R                      x  + 2x  + 1
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 248
+r0:=-1/3*(1-x)*(1+x^2)*(1+2*x/(1+x^2))^(5/2)/(1+x)+2/3*(1+3*x)*(1+x^2)^2*_
+     (1+2*x/(1+x^2))^(5/2)/(1+x)^2-(1+x^2)^3*(1+2*x/(1+x^2))^(5/2)/(1+x)^5-_
+     3*(1+x^2)^3*(1+2*x/(1+x^2))^(5/2)/(1+x)^4-2*(1+x^2)^3*_
+     (1+2*x/(1+x^2))^(5/2)/(1+x)^3+5*(1+x^2)^(5/2)*(1+2*x/(1+x^2))^(5/2)*_
+     asinh(x)/(1+x)^5
+--R 
+--R
+--R   (2)
+--R                           +-----------+
+--R                           | 2           +------+
+--R           2               |x  + 2x + 1  | 2
+--R       (15x  + 15)asinh(x) |----------- \|x  + 1
+--R                           |    2
+--R                          \|   x  + 1
+--R     + 
+--R                                     +-----------+
+--R                                     | 2
+--R          4     3      2             |x  + 2x + 1
+--R       (3x  - 8x  - 18x  - 12x - 17) |-----------
+--R                                     |    2
+--R                                    \|   x  + 1
+--R  /
+--R       3     2
+--R     3x  + 3x  + 3x + 3
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         +------+
+--R                 6       4       2       | 2            7       5       3
+--R         ((- 120x  - 240x  - 135x  - 15)\|x  + 1  + 120x  + 300x  + 240x  + 60x)
+--R      *
+--R              +------+
+--R              | 2
+--R         log(\|x  + 1  - x)
+--R     + 
+--R                                                 +------+
+--R             7       5       3      2            | 2           8       6       4
+--R       (- 24x  + 132x  + 208x  - 24x  + 68x - 8)\|x  + 1  + 24x  - 120x  - 277x
+--R     + 
+--R          3       2
+--R       24x  - 154x  + 20x - 17
+--R  /
+--R                              +------+
+--R         6      4      2      | 2           7      5      3
+--R     (24x  + 48x  + 27x  + 3)\|x  + 1  - 24x  - 60x  - 48x  - 12x
+--R                                         Type: Union(Expression(Integer),...)
+--E 221
+
+--S 222 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                        +------+
+--R                  7       6       5       4       3       2             | 2
+--R           (- 120x  - 120x  - 240x  - 240x  - 135x  - 135x  - 15x - 15)\|x  + 1
+--R         + 
+--R               8       7       6       5       4       3      2
+--R           120x  + 120x  + 300x  + 300x  + 240x  + 240x  + 60x  + 60x
+--R      *
+--R              +------+
+--R              | 2
+--R         log(\|x  + 1  - x)
+--R     + 
+--R                    7       5       3                     8      7       6
+--R               (120x  + 300x  + 240x  + 60x)asinh(x) - 24x  + 64x  + 120x
+--R             + 
+--R                   5       4       3       2
+--R               160x  + 277x  + 104x  + 154x  + 12x + 17
+--R          *
+--R              +-----------+
+--R              | 2
+--R              |x  + 2x + 1
+--R              |-----------
+--R              |    2
+--R             \|   x  + 1
+--R         + 
+--R                8      7       6       5       4       3      2
+--R           - 24x  - 24x  + 132x  + 132x  + 208x  + 184x  + 44x  + 60x - 8
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R     + 
+--R                  8       6       4       2                    9      8       7
+--R           (- 120x  - 360x  - 375x  - 150x  - 15)asinh(x) + 24x  - 64x  - 108x
+--R         + 
+--R                 6       5       4       3      2
+--R           - 192x  - 340x  - 176x  - 276x  - 48x  - 68x
+--R      *
+--R          +-----------+
+--R          | 2
+--R          |x  + 2x + 1
+--R          |-----------
+--R          |    2
+--R         \|   x  + 1
+--R     + 
+--R          9      8       7       6       5       4       3       2
+--R       24x  + 24x  - 120x  - 120x  - 277x  - 253x  - 130x  - 134x  + 3x - 17
+--R  /
+--R                                                          +------+
+--R           7      6      5      4      3      2           | 2           8      7
+--R       (24x  + 24x  + 48x  + 48x  + 27x  + 27x  + 3x + 3)\|x  + 1  - 24x  - 24x
+--R     + 
+--R            6      5      4      3      2
+--R       - 60x  - 60x  - 48x  - 48x  - 12x  - 12x
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     14       13        12        11        10        9        8
+--R               - 128x   - 640x   - 1600x   - 2880x   - 4112x   - 4688x  - 4408x
+--R             + 
+--R                      7        6        5       4       3      2
+--R               - 3480x  - 2248x  - 1192x  - 520x  - 168x  - 40x  - 8x
+--R          *
+--R              +-----------+
+--R              | 2
+--R              |x  + 2x + 1
+--R              |-----------
+--R              |    2
+--R             \|   x  + 1
+--R         + 
+--R                 14       13        12        11        10        9        8
+--R           - 128x   - 768x   - 2176x   - 4096x   - 5920x   - 6848x  - 6400x
+--R         + 
+--R                  7        6        5       4       3      2
+--R           - 4928x  - 3137x  - 1606x  - 655x  - 212x  - 47x  - 6x - 1
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R     + 
+--R               15       14        13        12        11        10        9
+--R           128x   + 640x   + 1664x   + 3200x   + 4896x   + 6048x   + 6272x
+--R         + 
+--R                8        7        6        5       4       3      2
+--R           5504x  + 4033x  + 2501x  + 1291x  + 527x  + 175x  + 43x  + 5x + 1
+--R      *
+--R          +-----------+
+--R          | 2
+--R          |x  + 2x + 1
+--R          |-----------
+--R          |    2
+--R         \|   x  + 1
+--R     + 
+--R           15       14        13        12        11        10        9        8
+--R       128x   + 768x   + 2240x   + 4480x   + 6992x   + 8800x   + 9096x  + 7888x
+--R     + 
+--R            7        6        5       4       3      2
+--R       5728x  + 3440x  + 1712x  + 688x  + 208x  + 48x  + 8x
+--R  /
+--R              14       12        10        8       6       4      2
+--R         (128x   + 640x   + 1312x   + 1408x  + 833x  + 259x  + 35x  + 1)
+--R      *
+--R          +-----------+
+--R          | 2           +------+
+--R          |x  + 2x + 1  | 2
+--R          |----------- \|x  + 1
+--R          |    2
+--R         \|   x  + 1
+--R     + 
+--R                15       13        11        9        7       5       3
+--R         (- 128x   - 704x   - 1616x   - 1992x  - 1408x  - 560x  - 112x  - 8x)
+--R      *
+--R          +-----------+
+--R          | 2
+--R          |x  + 2x + 1
+--R          |-----------
+--R          |    2
+--R         \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 223
+
+)clear all
+
+--S 224 of 248
+t0:=(1+2*x/(1+x^2))^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R                      | 2
+--R          2           |x  + 2x + 1
+--R        (x  + 2x + 1) |-----------
+--R                      |    2
+--R                     \|   x  + 1
+--R   (1)  ---------------------------
+--R                    2
+--R                   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 248
+r0:=-(1-x)*(1+x^2)*(1+2*x/(1+x^2))^(3/2)/(1+x)+(1+x^2)^2*_
+     (1+2*x/(1+x^2))^(3/2)/(1+x)^3-(1+x^2)^2*(1+2*x/(1+x^2))^(3/2)/(1+x)^2+_
+     3*(1+x^2)^(3/2)*(1+2*x/(1+x^2))^(3/2)*asinh(x)/(1+x)^3
+--R 
+--R
+--R                  +-----------+                          +-----------+
+--R                  | 2           +------+                 | 2
+--R                  |x  + 2x + 1  | 2          2           |x  + 2x + 1
+--R        3asinh(x) |----------- \|x  + 1  + (x  - 2x - 1) |-----------
+--R                  |    2                                 |    2
+--R                 \|   x  + 1                            \|   x  + 1
+--R   (2)  --------------------------------------------------------------
+--R                                     x + 1
+--R                                                    Type: Expression(Integer)
+--E 225
+
+--S 226 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +------+                 +------+
+--R             2      | 2          3           | 2
+--R       ((- 6x  - 3)\|x  + 1  + 6x  + 6x)log(\|x  + 1  - x)
+--R     + 
+--R                        +------+
+--R            3           | 2          4    2
+--R       (- 2x  + 2x - 2)\|x  + 1  + 2x  - x  + 2x - 1
+--R  /
+--R               +------+
+--R        2      | 2          3
+--R     (2x  + 1)\|x  + 1  - 2x  - 2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 226
+
+--S 227 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +------+
+--R               3     2           | 2          4     3     2
+--R         ((- 6x  - 6x  - 3x - 3)\|x  + 1  + 6x  + 6x  + 6x  + 6x)
+--R      *
+--R              +------+
+--R              | 2
+--R         log(\|x  + 1  - x)
+--R     + 
+--R                                                          +-----------+
+--R                                                          | 2
+--R               3                   4     3    2           |x  + 2x + 1      4
+--R           ((6x  + 6x)asinh(x) - 2x  + 4x  + x  + 2x + 1) |-----------  - 2x
+--R                                                          |    2
+--R                                                         \|   x  + 1
+--R         + 
+--R               3     2
+--R           - 2x  + 2x  - 2
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R     + 
+--R                                                          +-----------+
+--R                                                          | 2
+--R             4     2                  5     4     2       |x  + 2x + 1      5
+--R       ((- 6x  - 9x  - 3)asinh(x) + 2x  - 4x  - 4x  - 2x) |-----------  + 2x
+--R                                                          |    2
+--R                                                         \|   x  + 1
+--R     + 
+--R         4    3    2
+--R       2x  - x  + x  + x - 1
+--R  /
+--R                         +------+
+--R        3     2          | 2          4     3     2
+--R     (2x  + 2x  + x + 1)\|x  + 1  - 2x  - 2x  - 2x  - 2x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                                                  +-----------+
+--R                                                                  | 2
+--R                8      7      6      5      4      3      2       |x  + 2x + 1
+--R           (- 8x  - 24x  - 36x  - 44x  - 40x  - 24x  - 12x  - 4x) |-----------
+--R                                                                  |    2
+--R                                                                 \|   x  + 1
+--R         + 
+--R               8      7      6      5      4      3      2
+--R           - 8x  - 32x  - 56x  - 64x  - 57x  - 36x  - 14x  - 4x - 1
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R     + 
+--R            9      8      7      6      5      4      3      2
+--R         (8x  + 24x  + 40x  + 56x  + 57x  + 43x  + 28x  + 12x  + 3x + 1)
+--R      *
+--R          +-----------+
+--R          | 2
+--R          |x  + 2x + 1
+--R          |-----------
+--R          |    2
+--R         \|   x  + 1
+--R     + 
+--R         9      8      7      6      5      4      3      2
+--R       8x  + 32x  + 60x  + 80x  + 84x  + 64x  + 36x  + 16x  + 4x
+--R  /
+--R                                      +-----------+
+--R                                      | 2           +------+
+--R          8      6      4      2      |x  + 2x + 1  | 2
+--R       (8x  + 24x  + 25x  + 10x  + 1) |----------- \|x  + 1
+--R                                      |    2
+--R                                     \|   x  + 1
+--R     + 
+--R                                         +-----------+
+--R                                         | 2
+--R            9      7      5      3       |x  + 2x + 1
+--R       (- 8x  - 28x  - 36x  - 20x  - 4x) |-----------
+--R                                         |    2
+--R                                        \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 248
+t0:=(1+2*x/(1+x^2))^(1/2)
+--R 
+--R
+--R         +-----------+
+--R         | 2
+--R         |x  + 2x + 1
+--R   (1)   |-----------
+--R         |    2
+--R        \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 248
+r0:=(1+x^2)*sqrt(1+2*x/(1+x^2))/(1+x)+asinh(x)*sqrt(1+x^2)*_
+    sqrt(1+2*x/(1+x^2))/(1+x)
+--R 
+--R
+--R                 +-----------+                     +-----------+
+--R                 | 2           +------+            | 2
+--R                 |x  + 2x + 1  | 2          2      |x  + 2x + 1
+--R        asinh(x) |----------- \|x  + 1  + (x  + 1) |-----------
+--R                 |    2                            |    2
+--R                \|   x  + 1                       \|   x  + 1
+--R   (2)  --------------------------------------------------------
+--R                                  x + 1
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +------+          +------+          +------+
+--R            | 2               | 2               | 2         2
+--R        (- \|x  + 1  + x)log(\|x  + 1  - x) - x\|x  + 1  + x  + 1
+--R   (3)  ---------------------------------------------------------
+--R                               +------+
+--R                               | 2
+--R                              \|x  + 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 231
+
+--S 232 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +------+               +------+
+--R                  | 2         2          | 2
+--R       ((- x - 1)\|x  + 1  + x  + x)log(\|x  + 1  - x)
+--R     + 
+--R                              +-----------+
+--R                              | 2                     +------+
+--R                       2      |x  + 2x + 1     2      | 2
+--R       ((x asinh(x) - x  - 1) |-----------  - x  - x)\|x  + 1
+--R                              |    2
+--R                             \|   x  + 1
+--R     + 
+--R                                     +-----------+
+--R                                     | 2
+--R            2                 3      |x  + 2x + 1     3    2
+--R       ((- x  - 1)asinh(x) + x  + x) |-----------  + x  + x  + x + 1
+--R                                     |    2
+--R                                    \|   x  + 1
+--R  /
+--R             +------+
+--R             | 2         2
+--R     (x + 1)\|x  + 1  - x  - x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                   +-----------+
+--R                                   | 2
+--R               4     3     2       |x  + 2x + 1      4     3     2
+--R         ((- 2x  - 2x  - 2x  - 2x) |-----------  - 2x  - 4x  - 3x  - 2x - 1)
+--R                                   |    2
+--R                                  \|   x  + 1
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R     + 
+--R                                     +-----------+
+--R                                     | 2
+--R        5     4     3     2          |x  + 2x + 1      5     4     3     2
+--R     (2x  + 2x  + 3x  + 3x  + x + 1) |-----------  + 2x  + 4x  + 4x  + 4x  + 2x
+--R                                     |    2
+--R                                    \|   x  + 1
+--R  /
+--R                     +-----------+                               +-----------+
+--R                     | 2           +------+                      | 2
+--R        4     2      |x  + 2x + 1  | 2             5     3       |x  + 2x + 1
+--R     (2x  + 3x  + 1) |----------- \|x  + 1  + (- 2x  - 4x  - 2x) |-----------
+--R                     |    2                                      |    2
+--R                    \|   x  + 1                                 \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 233
+
+)clear all
+
+--S 234 of 248
+t0:=1/(1+2*x/(1+x^2))^(1/2)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         | 2
+--R         |x  + 2x + 1
+--R         |-----------
+--R         |    2
+--R        \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 248
+r0:=(1+x)/sqrt(1+2*x/(1+x^2))-(1+x)*asinh(x)/(sqrt(1+x^2)*_
+    sqrt(1+2*x/(1+x^2)))-(1+x)*atanh((1-x)/(sqrt(2)*sqrt(1+x^2)))*_
+    sqrt(2)/(sqrt(1+x^2)*sqrt(1+2*x/(1+x^2)))
+--R 
+--R
+--R                                                  +------+
+--R                +-+          x - 1                | 2
+--R        (x + 1)\|2 atanh(-------------) + (x + 1)\|x  + 1  + (- x - 1)asinh(x)
+--R                              +------+
+--R                          +-+ | 2
+--R                         \|2 \|x  + 1
+--R   (2)  ----------------------------------------------------------------------
+--R                                 +-----------+
+--R                                 | 2           +------+
+--R                                 |x  + 2x + 1  | 2
+--R                                 |----------- \|x  + 1
+--R                                 |    2
+--R                                \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         +------+          +------+
+--R         | 2               | 2
+--R       (\|x  + 1  - x)log(\|x  + 1  - x)
+--R     + 
+--R               +------+
+--R           +-+ | 2          +-+
+--R         (\|2 \|x  + 1  - x\|2 )
+--R      *
+--R                            +------+
+--R               +-+          | 2                  +-+    2
+--R             (\|2  + x + 1)\|x  + 1  + (- x - 1)\|2  - x  - x - 2
+--R         log(----------------------------------------------------)
+--R                                   +------+
+--R                                   | 2         2
+--R                           (x + 1)\|x  + 1  - x  - x
+--R     + 
+--R           +------+
+--R           | 2         2
+--R       - x\|x  + 1  + x  + 1
+--R  /
+--R      +------+
+--R      | 2
+--R     \|x  + 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 236
+
+--S 237 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +-----------+                       +-----------+
+--R          | 2           +------+              | 2                +------+
+--R          |x  + 2x + 1  | 2            2      |x  + 2x + 1       | 2
+--R       (x |----------- \|x  + 1  + (- x  - 1) |----------- )log(\|x  + 1  - x)
+--R          |    2                              |    2
+--R         \|   x  + 1                         \|   x  + 1
+--R     + 
+--R                +-----------+                           +-----------+
+--R                | 2           +------+                  | 2
+--R            +-+ |x  + 2x + 1  | 2            2      +-+ |x  + 2x + 1
+--R         (x\|2  |----------- \|x  + 1  + (- x  - 1)\|2  |----------- )
+--R                |    2                                  |    2
+--R               \|   x  + 1                             \|   x  + 1
+--R      *
+--R                            +------+
+--R               +-+          | 2                  +-+    2
+--R             (\|2  + x + 1)\|x  + 1  + (- x - 1)\|2  - x  - x - 2
+--R         log(----------------------------------------------------)
+--R                                   +------+
+--R                                   | 2         2
+--R                           (x + 1)\|x  + 1  - x  - x
+--R     + 
+--R                    +------+
+--R                +-+ | 2            2      +-+           x - 1
+--R       ((x + 1)\|2 \|x  + 1  + (- x  - x)\|2 )atanh(-------------)
+--R                                                         +------+
+--R                                                     +-+ | 2
+--R                                                    \|2 \|x  + 1
+--R     + 
+--R                   +-----------+
+--R                   | 2                                         +------+
+--R            2      |x  + 2x + 1                         2      | 2
+--R       ((- x  - 1) |-----------  + (- x - 1)asinh(x) - x  - x)\|x  + 1
+--R                   |    2
+--R                  \|   x  + 1
+--R     + 
+--R                +-----------+
+--R                | 2
+--R         3      |x  + 2x + 1      2                 3    2
+--R       (x  + x) |-----------  + (x  + x)asinh(x) + x  + x  + x + 1
+--R                |    2
+--R               \|   x  + 1
+--R  /
+--R       +-----------+                       +-----------+
+--R       | 2           +------+              | 2
+--R       |x  + 2x + 1  | 2            2      |x  + 2x + 1
+--R     x |----------- \|x  + 1  + (- x  - 1) |-----------
+--R       |    2                              |    2
+--R      \|   x  + 1                         \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 237
+
+--S 238 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                     5     4      3     2           +-+      6      5      4
+--R               (- 16x  - 8x  - 20x  - 8x  - 5x - 1)\|2  - 16x  - 16x  - 36x
+--R             + 
+--R                    3      2
+--R               - 20x  - 21x  - 5x - 2
+--R          *
+--R              +-----------+
+--R              | 2
+--R              |x  + 2x + 1
+--R              |-----------
+--R              |    2
+--R             \|   x  + 1
+--R         + 
+--R                 5      4      3      2           +-+      6      5      4
+--R           (- 16x  - 24x  - 20x  - 16x  - 5x - 1)\|2  - 16x  - 32x  - 44x
+--R         + 
+--R                3      2
+--R           - 40x  - 21x  - 10x - 1
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R     + 
+--R               6     5      4      3      2           +-+      7      6      5
+--R           (16x  + 8x  + 28x  + 12x  + 13x  + 4x + 1)\|2  + 16x  + 16x  + 44x
+--R         + 
+--R              4      3      2
+--R           28x  + 37x  + 13x  + 9x + 1
+--R      *
+--R          +-----------+
+--R          | 2
+--R          |x  + 2x + 1
+--R          |-----------
+--R          |    2
+--R         \|   x  + 1
+--R     + 
+--R           6      5      4      3      2           +-+      7      6      5
+--R       (16x  + 24x  + 28x  + 28x  + 13x  + 6x + 1)\|2  + 16x  + 32x  + 52x
+--R     + 
+--R          4      3      2
+--R       56x  + 41x  + 26x  + 7x + 2
+--R  /
+--R               5      4      3      2           +-+      6      5      4      3
+--R           (16x  + 24x  + 20x  + 16x  + 5x + 1)\|2  + 16x  + 32x  + 44x  + 40x
+--R         + 
+--R              2
+--R           21x  + 10x + 1
+--R      *
+--R          +-----------+
+--R          | 2           +------+
+--R          |x  + 2x + 1  | 2
+--R          |----------- \|x  + 1
+--R          |    2
+--R         \|   x  + 1
+--R     + 
+--R                 6      5      4      3      2           +-+      7      6
+--R           (- 16x  - 24x  - 28x  - 28x  - 13x  - 6x - 1)\|2  - 16x  - 32x
+--R         + 
+--R                5      4      3      2
+--R           - 52x  - 56x  - 41x  - 26x  - 7x - 2
+--R      *
+--R          +-----------+
+--R          | 2
+--R          |x  + 2x + 1
+--R          |-----------
+--R          |    2
+--R         \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 238
+
+)clear all
+
+--S 239 of 248
+t0:=1/(1+2*x/(1+x^2))^(3/2)
+--R 
+--R
+--R                    2
+--R                   x  + 1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R                      | 2
+--R          2           |x  + 2x + 1
+--R        (x  + 2x + 1) |-----------
+--R                      |    2
+--R                     \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 248
+r0:=1/2*(-1-x)/(1+2*x/(1+x^2))^(3/2)+3/2*(1+x)^2*(2+x)/((1+x^2)*_
+    (1+2*x/(1+x^2))^(3/2))-3*(1+x)^3*asinh(x)/((1+x^2)^(3/2)*_
+    (1+2*x/(1+x^2))^(3/2))-9/2*(1+x)^3*atanh((1-x)/(sqrt(2)*_
+    sqrt(1+x^2)))/((1+x^2)^(3/2)*(1+2*x/(1+x^2))^(3/2)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                                                                +------+
+--R          2                     x - 1           2           +-+ | 2
+--R       (9x  + 18x + 9)atanh(-------------) + (2x  + 9x + 5)\|2 \|x  + 1
+--R                                 +------+
+--R                             +-+ | 2
+--R                            \|2 \|x  + 1
+--R     + 
+--R            2            +-+
+--R       (- 6x  - 12x - 6)\|2 asinh(x)
+--R  /
+--R                  +-----------+
+--R                  | 2           +------+
+--R              +-+ |x  + 2x + 1  | 2
+--R     (2x + 2)\|2  |----------- \|x  + 1
+--R                  |    2
+--R                 \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 240
+
+--S 241 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                              +------+
+--R               4      3      2            +-+ | 2
+--R           (24x  + 48x  + 30x  + 12x + 6)\|2 \|x  + 1
+--R         + 
+--R                 5      4      3      2        +-+
+--R           (- 24x  - 48x  - 42x  - 36x  - 18x)\|2
+--R      *
+--R              +------+
+--R              | 2
+--R         log(\|x  + 1  - x)
+--R     + 
+--R                                          +------+
+--R               4      3      2            | 2           5      4      3      2
+--R           (36x  + 72x  + 45x  + 18x + 9)\|x  + 1  - 36x  - 72x  - 63x  - 54x
+--R         + 
+--R           - 27x
+--R      *
+--R                               +------+
+--R                      +-+      | 2            2          +-+
+--R             ((x + 1)\|2  + 2)\|x  + 1  + (- x  - x - 2)\|2  - 2x - 2
+--R         log(--------------------------------------------------------)
+--R                                     +------+
+--R                                     | 2         2
+--R                             (x + 1)\|x  + 1  - x  - x
+--R     + 
+--R                                                +------+
+--R            5      4      3     2           +-+ | 2
+--R       (- 8x  - 16x  + 14x  - 2x  - 5x + 5)\|2 \|x  + 1
+--R     + 
+--R          6      5      4      3     2           +-+
+--R       (8x  + 16x  - 10x  + 10x  - 3x  - 6x + 5)\|2
+--R  /
+--R                                        +------+
+--R          4      3      2           +-+ | 2
+--R       (8x  + 16x  + 10x  + 4x + 2)\|2 \|x  + 1
+--R     + 
+--R            5      4      3      2       +-+
+--R       (- 8x  - 16x  - 14x  - 12x  - 6x)\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 241
+
+--S 242 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +-----------+
+--R                                                 | 2           +------+
+--R               5      4      3      2        +-+ |x  + 2x + 1  | 2
+--R           (24x  + 48x  + 42x  + 36x  + 18x)\|2  |----------- \|x  + 1
+--R                                                 |    2
+--R                                                \|   x  + 1
+--R         + 
+--R                                                              +-----------+
+--R                                                              | 2
+--R                 6      5      4      3      2            +-+ |x  + 2x + 1
+--R           (- 24x  - 48x  - 54x  - 60x  - 36x  - 12x - 6)\|2  |-----------
+--R                                                              |    2
+--R                                                             \|   x  + 1
+--R      *
+--R              +------+
+--R              | 2
+--R         log(\|x  + 1  - x)
+--R     + 
+--R                                             +-----------+
+--R                                             | 2           +------+
+--R               5      4      3      2        |x  + 2x + 1  | 2
+--R           (36x  + 72x  + 63x  + 54x  + 27x) |----------- \|x  + 1
+--R                                             |    2
+--R                                            \|   x  + 1
+--R         + 
+--R                                                          +-----------+
+--R                                                          | 2
+--R                 6      5      4      3      2            |x  + 2x + 1
+--R           (- 36x  - 72x  - 81x  - 90x  - 54x  - 18x - 9) |-----------
+--R                                                          |    2
+--R                                                         \|   x  + 1
+--R      *
+--R                               +------+
+--R                      +-+      | 2            2          +-+
+--R             ((x + 1)\|2  + 2)\|x  + 1  + (- x  - x - 2)\|2  - 2x - 2
+--R         log(--------------------------------------------------------)
+--R                                     +------+
+--R                                     | 2         2
+--R                             (x + 1)\|x  + 1  - x  - x
+--R     + 
+--R                                                   +------+
+--R               5       4       3      2            | 2           6       5
+--R           (36x  + 108x  + 117x  + 63x  + 27x + 9)\|x  + 1  - 36x  - 108x
+--R         + 
+--R                 4       3      2
+--R           - 135x  - 117x  - 81x  - 27x
+--R      *
+--R                   x - 1
+--R         atanh(-------------)
+--R                    +------+
+--R                +-+ | 2
+--R               \|2 \|x  + 1
+--R     + 
+--R                                                           +-----------+
+--R                                                           | 2
+--R                6      5      4      3     2           +-+ |x  + 2x + 1
+--R           (- 8x  - 16x  + 10x  - 10x  + 3x  + 6x - 5)\|2  |-----------
+--R                                                           |    2
+--R                                                          \|   x  + 1
+--R         + 
+--R                 5      4      3      2            +-+
+--R           (- 24x  - 72x  - 78x  - 42x  - 18x - 6)\|2 asinh(x)
+--R         + 
+--R                6      5      4      3      2        +-+
+--R           (- 8x  - 44x  - 62x  - 53x  - 42x  - 15x)\|2
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R     + 
+--R                                                          +-----------+
+--R                                                          | 2
+--R          7      6     5      4     3     2           +-+ |x  + 2x + 1
+--R       (8x  + 16x  - 6x  + 18x  - 9x  - 3x  + 5x - 5)\|2  |-----------
+--R                                                          |    2
+--R                                                         \|   x  + 1
+--R     + 
+--R           6      5      4      3      2        +-+
+--R       (24x  + 72x  + 90x  + 78x  + 54x  + 18x)\|2 asinh(x)
+--R     + 
+--R          7      6      5      4      3      2            +-+
+--R       (8x  + 44x  + 66x  + 75x  + 72x  + 36x  + 14x + 5)\|2
+--R  /
+--R                                           +-----------+
+--R                                           | 2           +------+
+--R          5      4      3      2       +-+ |x  + 2x + 1  | 2
+--R       (8x  + 16x  + 14x  + 12x  + 6x)\|2  |----------- \|x  + 1
+--R                                           |    2
+--R                                          \|   x  + 1
+--R     + 
+--R                                                        +-----------+
+--R                                                        | 2
+--R            6      5      4      3      2           +-+ |x  + 2x + 1
+--R       (- 8x  - 16x  - 18x  - 20x  - 12x  - 4x - 2)\|2  |-----------
+--R                                                        |    2
+--R                                                       \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                         12       11        10       9        8        7
+--R                   - 256x   - 256x   - 1088x   - 832x  - 1776x  - 1008x
+--R                 + 
+--R                          6       5       4       3      2
+--R                   - 1384x  - 552x  - 513x  - 129x  - 75x  - 9x - 2
+--R              *
+--R                  +-+
+--R                 \|2
+--R             + 
+--R                     11       10        9       8        7       6        5
+--R               - 512x   - 256x   - 1664x  - 768x  - 2016x  - 832x  - 1104x
+--R             + 
+--R                     4       3      2
+--R               - 384x  - 258x  - 66x  - 18x - 2
+--R          *
+--R              +-----------+
+--R              | 2
+--R              |x  + 2x + 1
+--R              |-----------
+--R              |    2
+--R             \|   x  + 1
+--R         + 
+--R                     12       11        10        9        8        7        6
+--R               - 256x   - 512x   - 1216x   - 1664x  - 2032x  - 2016x  - 1512x
+--R             + 
+--R                      5       4       3      2
+--R               - 1104x  - 497x  - 258x  - 58x  - 18x - 1
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                 11       10        9        8        7        6        5
+--R           - 512x   - 768x   - 1664x  - 2048x  - 2016x  - 1920x  - 1104x
+--R         + 
+--R                 4       3      2
+--R           - 736x  - 258x  - 98x  - 18x - 2
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R     + 
+--R                   13       12        11       10        9        8        7
+--R               256x   + 256x   + 1216x   + 960x   + 2288x  + 1392x  + 2152x
+--R             + 
+--R                   6        5       4       3      2
+--R               968x  + 1041x  + 321x  + 234x  + 42x  + 17x + 1
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R               12       11        10       9        8        7        6       5
+--R           512x   + 256x   + 1920x   + 896x  + 2784x  + 1184x  + 1936x  + 720x
+--R         + 
+--R               4       3      2
+--R           642x  + 192x  + 84x  + 16x + 2
+--R      *
+--R          +-----------+
+--R          | 2
+--R          |x  + 2x + 1
+--R          |-----------
+--R          |    2
+--R         \|   x  + 1
+--R     + 
+--R               13       12        11        10        9        8        7
+--R           256x   + 512x   + 1344x   + 1920x   + 2608x  + 2784x  + 2392x
+--R         + 
+--R                6        5       4       3      2
+--R           1936x  + 1065x  + 642x  + 204x  + 84x  + 11x + 2
+--R      *
+--R          +-+
+--R         \|2
+--R     + 
+--R           12       11        10        9        8        7        6        5
+--R       512x   + 768x   + 1920x   + 2432x  + 2784x  + 2848x  + 1936x  + 1488x
+--R     + 
+--R           4       3      2
+--R       642x  + 324x  + 84x  + 20x + 2
+--R  /
+--R                   12        11        10        9        8        7        6
+--R               256x   + 1024x   + 2240x   + 3584x  + 4336x  + 4160x  + 3240x
+--R             + 
+--R                    5       4       3      2
+--R               1984x  + 977x  + 372x  + 94x  + 20x + 1
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R               11        10        9        8        7        6        5
+--R           512x   + 1792x   + 3200x  + 4352x  + 4576x  + 3648x  + 2384x
+--R         + 
+--R                4       3       2
+--R           1216x  + 450x  + 134x  + 22x + 2
+--R      *
+--R          +-----------+
+--R          | 2           +------+
+--R          |x  + 2x + 1  | 2
+--R          |----------- \|x  + 1
+--R          |    2
+--R         \|   x  + 1
+--R     + 
+--R                     13        12        11        10        9        8        7
+--R               - 256x   - 1024x   - 2368x   - 4096x   - 5424x  - 5824x  - 5144x
+--R             + 
+--R                      6        5        4       3       2
+--R               - 3680x  - 2185x  - 1028x  - 368x  - 106x  - 15x - 2
+--R          *
+--R              +-+
+--R             \|2
+--R         + 
+--R                 12        11        10        9        8        7        6
+--R           - 512x   - 1792x   - 3456x   - 5248x  - 6112x  - 5600x  - 4304x
+--R         + 
+--R                  5        4       3       2
+--R           - 2608x  - 1250x  - 488x  - 124x  - 24x - 2
+--R      *
+--R          +-----------+
+--R          | 2
+--R          |x  + 2x + 1
+--R          |-----------
+--R          |    2
+--R         \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 248
+t0:=sqrt(1+2*x/(1+x^2))/(1+x^2)
+--R 
+--R
+--R         +-----------+
+--R         | 2
+--R         |x  + 2x + 1
+--R         |-----------
+--R         |    2
+--R        \|   x  + 1
+--R   (1)  --------------
+--R             2
+--R            x  + 1
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 248
+r0:=-(1-x)*sqrt(1+2*x/(1+x^2))/(1+x)
+--R 
+--R
+--R                +-----------+
+--R                | 2
+--R                |x  + 2x + 1
+--R        (x - 1) |-----------
+--R                |    2
+--R               \|   x  + 1
+--R   (2)  ---------------------
+--R                x + 1
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 248
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +------+
+--R          | 2
+--R         \|x  + 1  - x - 1
+--R   (3)  -------------------
+--R          +------+
+--R          | 2         2
+--R        x\|x  + 1  - x  - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 246
+
+--S 247 of 248
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +-----------+
+--R                   | 2                    +------+
+--R            2      |x  + 2x + 1           | 2
+--R       ((- x  + x) |-----------  + x + 1)\|x  + 1
+--R                   |    2
+--R                  \|   x  + 1
+--R     + 
+--R                         +-----------+
+--R                         | 2
+--R         3    2          |x  + 2x + 1     2
+--R       (x  - x  + x - 1) |-----------  - x  - 2x - 1
+--R                         |    2
+--R                        \|   x  + 1
+--R  /
+--R              +------+
+--R       2      | 2         3    2
+--R     (x  + x)\|x  + 1  - x  - x  - x - 1
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 248
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                                   +-----------+
+--R                                   | 2
+--R               4     3     2       |x  + 2x + 1      4     3     2
+--R         ((- 2x  - 2x  - 2x  - 2x) |-----------  - 2x  - 4x  - 3x  - 2x - 1)
+--R                                   |    2
+--R                                  \|   x  + 1
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R     + 
+--R                                     +-----------+
+--R                                     | 2
+--R        5     4     3     2          |x  + 2x + 1      5     4     3     2
+--R     (2x  + 2x  + 3x  + 3x  + x + 1) |-----------  + 2x  + 4x  + 4x  + 4x  + 2x
+--R                                     |    2
+--R                                    \|   x  + 1
+--R  /
+--R                             +-----------+
+--R                             | 2           +------+
+--R          6     4     2      |x  + 2x + 1  | 2
+--R       (2x  + 5x  + 4x  + 1) |----------- \|x  + 1
+--R                             |    2
+--R                            \|   x  + 1
+--R     + 
+--R                                +-----------+
+--R                                | 2
+--R            7     5     3       |x  + 2x + 1
+--R       (- 2x  - 6x  - 6x  - 2x) |-----------
+--R                                |    2
+--R                               \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 248
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich22a.input.pamphlet b/src/input/rich22a.input.pamphlet
new file mode 100644
index 0000000..fe7de18
--- /dev/null
+++ b/src/input/rich22a.input.pamphlet
@@ -0,0 +1,15779 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich22a.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Algebraic function problems.input
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich22a.output
+)spool rich22a.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1004
+t0:=x^2/(sqrt(a+b*x)+sqrt(c+b*x))
+--R 
+--R
+--R                    2
+--R                   x
+--R   (1)  -----------------------
+--R         +-------+    +-------+
+--R        \|b x + c  + \|b x + a
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1004
+r0:=2/3*a^2*(a+b*x)^(3/2)/(b^3*(a-c))-4/5*a*(a+b*x)^(5/2)/(b^3*(a-c))+_
+   2/7*(a+b*x)^(7/2)/(b^3*(a-c))-2/3*c^2*(c+b*x)^(3/2)/(b^3*(a-c))+_
+   4/5*c*(c+b*x)^(5/2)/(b^3*(a-c))-2/7*(c+b*x)^(7/2)/(b^3*(a-c))
+--R 
+--R
+--R   (2)
+--R           3 3     2   2       2       3  +-------+
+--R       (30b x  + 6b c x  - 8b c x + 16c )\|b x + c
+--R     + 
+--R             3 3       2 2     2         3  +-------+
+--R       (- 30b x  - 6a b x  + 8a b x - 16a )\|b x + a
+--R  /
+--R         3          3
+--R     105b c - 105a b
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 5 5           4           4  4
+--R           - 960b x  + (- 1056b c - 1056a b )x
+--R         + 
+--R                  3 2         3        2 3  3
+--R           (- 172b c  - 744a b c - 172a b )x
+--R         + 
+--R                  2 3        2 2      2 2        3 2  2
+--R           (- 126b c  + 30a b c  + 30a b c - 126a b )x
+--R         + 
+--R                    4           3      2   2       3          4         5
+--R           (- 280b c  - 112a b c  + 16a b c  - 112a b c - 280a b)x - 80c
+--R         + 
+--R                   4      2 3      3 2       4       5
+--R           - 160a c  - 16a c  - 16a c  - 160a c - 80a
+--R      *
+--R          +-------+ +-------+
+--R         \|b x + a \|b x + c
+--R     + 
+--R           6 6         5           5  5        4 2          4        2 4  4
+--R       960b x  + (1536b c + 1536a b )x  + (580b c  + 2040a b c + 580a b )x
+--R     + 
+--R            3 3         3 2       2 3        3 3  3
+--R       (140b c  + 500a b c  + 500a b c + 140a b )x
+--R     + 
+--R            2 4         2 3      2 2 2       3 2        4 2  2
+--R       (350b c  + 140a b c  - 20a b c  + 140a b c + 350a b )x
+--R     + 
+--R              5           4      2   3      3   2       4          5         6
+--R       (200b c  + 400a b c  + 40a b c  + 40a b c  + 400a b c + 200a b)x + 16c
+--R     + 
+--R             5      2 4      4 2       5       6
+--R       160a c  + 80a c  + 80a c  + 160a c + 16a
+--R  /
+--R                 5           5  2         4 2         4         2 4         3 3
+--R           (1680b c - 1680a b )x  + (1260b c  + 840a b c - 2100a b )x + 105b c
+--R         + 
+--R                 3 2       2 3        3 3
+--R           945a b c  - 525a b c - 525a b
+--R      *
+--R          +-------+
+--R         \|b x + c
+--R     + 
+--R                   5           5  2           4 2         4         2 4
+--R           (- 1680b c + 1680a b )x  + (- 2100b c  + 840a b c + 1260a b )x
+--R         + 
+--R                 3 3         3 2       2 3        3 3
+--R           - 525b c  - 525a b c  + 945a b c + 105a b
+--R      *
+--R          +-------+
+--R         \|b x + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 1004
+t0:=x/(sqrt(a+b*x)+sqrt(c+b*x))
+--R 
+--R
+--R                   x
+--R   (1)  -----------------------
+--R         +-------+    +-------+
+--R        \|b x + c  + \|b x + a
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 1004
+r0:=-2/3*a*(a+b*x)^(3/2)/(b^2*(a-c))+2/5*(a+b*x)^(5/2)/(b^2*(a-c))+_
+   2/3*c*(c+b*x)^(3/2)/(b^2*(a-c))-2/5*(c+b*x)^(5/2)/(b^2*(a-c))
+--R 
+--R
+--R           2 2              2  +-------+        2 2              2  +-------+
+--R        (6b x  + 2b c x - 4c )\|b x + c  + (- 6b x  - 2a b x + 4a )\|b x + a
+--R   (2)  ---------------------------------------------------------------------
+--R                                       2         2
+--R                                    15b c - 15a b
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2              2  +-------+        2 2              2  +-------+
+--R        (6b x  + 2b c x - 4c )\|b x + c  + (- 6b x  - 2a b x + 4a )\|b x + a
+--R   (3)  ---------------------------------------------------------------------
+--R                                       2         2
+--R                                    15b c - 15a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 1004
+t0:=1/(sqrt(a+b*x)+sqrt(c+b*x))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R         +-------+    +-------+
+--R        \|b x + c  + \|b x + a
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1004
+r0:=2/3*(a+b*x)^(3/2)/(b*(a-c))-2/3*(c+b*x)^(3/2)/(b*(a-c))
+--R 
+--R
+--R                    +-------+                 +-------+
+--R        (2b x + 2c)\|b x + c  + (- 2b x - 2a)\|b x + a
+--R   (2)  -----------------------------------------------
+--R                          3b c - 3a b
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +-------+ +-------+     2 2                      2     2
+--R   (- 4b x - 2c - 2a)\|b x + a \|b x + c  + 4b x  + (4b c + 4a b)x + 2c  + 2a
+--R   ---------------------------------------------------------------------------
+--R                             +-------+                   +-------+
+--R               (3b c - 3a b)\|b x + c  + (- 3b c + 3a b)\|b x + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 13
+
+--S 14 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 1004
+t0:=1/(x*(sqrt(a+b*x)+sqrt(c+b*x)))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R          +-------+     +-------+
+--R        x\|b x + c  + x\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1004
+r0:=-2*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(a-c)+2*atanh(sqrt(c+b*x)/sqrt(c))*_
+   sqrt(c)/(a-c)+2*sqrt(a+b*x)/(a-c)-2*sqrt(c+b*x)/(a-c)
+--R 
+--R
+--R   (2)
+--R                 +-------+                +-------+
+--R       +-+      \|b x + c       +-+      \|b x + a       +-------+     +-------+
+--R   - 2\|c atanh(----------) + 2\|a atanh(----------) + 2\|b x + c  - 2\|b x + a
+--R                    +-+                      +-+
+--R                   \|c                      \|a
+--R   -----------------------------------------------------------------------------
+--R                                       c - a
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         (- c + a)
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |                   +------------------------------+
+--R          |   2            2  |             16a c
+--R          |(2c  - 4a c + 2a ) |------------------------------  + 4c + 4a
+--R          |                   | 4       3     2 2     3     4
+--R          |                  \|c  - 4a c  + 6a c  - 4a c + a
+--R          |-------------------------------------------------------------
+--R          |                         2           2
+--R         \|                        c  - 2a c + a
+--R      *
+--R         log
+--R                (c - a)
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |                   +------------------------------+
+--R               |   2            2  |             16a c
+--R               |(2c  - 4a c + 2a ) |------------------------------  + 4c + 4a
+--R               |                   | 4       3     2 2     3     4
+--R               |                  \|c  - 4a c  + 6a c  - 4a c + a
+--R               |-------------------------------------------------------------
+--R               |                         2           2
+--R              \|                        c  - 2a c + a
+--R            + 
+--R                +-------+     +-------+
+--R              2\|b x + c  - 2\|b x + a
+--R     + 
+--R         (- c + a)
+--R      *
+--R          +---------------------------------------------------------------+
+--R          |                     +------------------------------+
+--R          |     2            2  |             16a c
+--R          |(- 2c  + 4a c - 2a ) |------------------------------  + 4c + 4a
+--R          |                     | 4       3     2 2     3     4
+--R          |                    \|c  - 4a c  + 6a c  - 4a c + a
+--R          |---------------------------------------------------------------
+--R          |                          2           2
+--R         \|                         c  - 2a c + a
+--R      *
+--R         log
+--R                (c - a)
+--R             *
+--R               +---------------------------------------------------------------+
+--R               |                     +------------------------------+
+--R               |     2            2  |             16a c
+--R               |(- 2c  + 4a c - 2a ) |------------------------------  + 4c + 4a
+--R               |                     | 4       3     2 2     3     4
+--R               |                    \|c  - 4a c  + 6a c  - 4a c + a
+--R               |---------------------------------------------------------------
+--R               |                          2           2
+--R              \|                         c  - 2a c + a
+--R            + 
+--R                +-------+     +-------+
+--R              2\|b x + c  - 2\|b x + a
+--R     + 
+--R         (c - a)
+--R      *
+--R          +---------------------------------------------------------------+
+--R          |                     +------------------------------+
+--R          |     2            2  |             16a c
+--R          |(- 2c  + 4a c - 2a ) |------------------------------  + 4c + 4a
+--R          |                     | 4       3     2 2     3     4
+--R          |                    \|c  - 4a c  + 6a c  - 4a c + a
+--R          |---------------------------------------------------------------
+--R          |                          2           2
+--R         \|                         c  - 2a c + a
+--R      *
+--R         log
+--R                (- c + a)
+--R             *
+--R               +---------------------------------------------------------------+
+--R               |                     +------------------------------+
+--R               |     2            2  |             16a c
+--R               |(- 2c  + 4a c - 2a ) |------------------------------  + 4c + 4a
+--R               |                     | 4       3     2 2     3     4
+--R               |                    \|c  - 4a c  + 6a c  - 4a c + a
+--R               |---------------------------------------------------------------
+--R               |                          2           2
+--R              \|                         c  - 2a c + a
+--R            + 
+--R                +-------+     +-------+
+--R              2\|b x + c  - 2\|b x + a
+--R     + 
+--R                 +-------------------------------------------------------------+
+--R                 |                   +------------------------------+
+--R                 |   2            2  |             16a c
+--R                 |(2c  - 4a c + 2a ) |------------------------------  + 4c + 4a
+--R                 |                   | 4       3     2 2     3     4
+--R                 |                  \|c  - 4a c  + 6a c  - 4a c + a
+--R         (c - a) |-------------------------------------------------------------
+--R                 |                         2           2
+--R                \|                        c  - 2a c + a
+--R      *
+--R         log
+--R                (- c + a)
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |                   +------------------------------+
+--R               |   2            2  |             16a c
+--R               |(2c  - 4a c + 2a ) |------------------------------  + 4c + 4a
+--R               |                   | 4       3     2 2     3     4
+--R               |                  \|c  - 4a c  + 6a c  - 4a c + a
+--R               |-------------------------------------------------------------
+--R               |                         2           2
+--R              \|                        c  - 2a c + a
+--R            + 
+--R                +-------+     +-------+
+--R              2\|b x + c  - 2\|b x + a
+--R     + 
+--R         +-------+     +-------+
+--R       4\|b x + c  - 4\|b x + a
+--R  /
+--R     2c - 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         (- c + a)
+--R      *
+--R          +-------------------------------------------------------------+
+--R          |                   +------------------------------+
+--R          |   2            2  |             16a c
+--R          |(2c  - 4a c + 2a ) |------------------------------  + 4c + 4a
+--R          |                   | 4       3     2 2     3     4
+--R          |                  \|c  - 4a c  + 6a c  - 4a c + a
+--R          |-------------------------------------------------------------
+--R          |                         2           2
+--R         \|                        c  - 2a c + a
+--R      *
+--R         log
+--R                (c - a)
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |                   +------------------------------+
+--R               |   2            2  |             16a c
+--R               |(2c  - 4a c + 2a ) |------------------------------  + 4c + 4a
+--R               |                   | 4       3     2 2     3     4
+--R               |                  \|c  - 4a c  + 6a c  - 4a c + a
+--R               |-------------------------------------------------------------
+--R               |                         2           2
+--R              \|                        c  - 2a c + a
+--R            + 
+--R                +-------+     +-------+
+--R              2\|b x + c  - 2\|b x + a
+--R     + 
+--R         (- c + a)
+--R      *
+--R          +---------------------------------------------------------------+
+--R          |                     +------------------------------+
+--R          |     2            2  |             16a c
+--R          |(- 2c  + 4a c - 2a ) |------------------------------  + 4c + 4a
+--R          |                     | 4       3     2 2     3     4
+--R          |                    \|c  - 4a c  + 6a c  - 4a c + a
+--R          |---------------------------------------------------------------
+--R          |                          2           2
+--R         \|                         c  - 2a c + a
+--R      *
+--R         log
+--R                (c - a)
+--R             *
+--R               +---------------------------------------------------------------+
+--R               |                     +------------------------------+
+--R               |     2            2  |             16a c
+--R               |(- 2c  + 4a c - 2a ) |------------------------------  + 4c + 4a
+--R               |                     | 4       3     2 2     3     4
+--R               |                    \|c  - 4a c  + 6a c  - 4a c + a
+--R               |---------------------------------------------------------------
+--R               |                          2           2
+--R              \|                         c  - 2a c + a
+--R            + 
+--R                +-------+     +-------+
+--R              2\|b x + c  - 2\|b x + a
+--R     + 
+--R         (c - a)
+--R      *
+--R          +---------------------------------------------------------------+
+--R          |                     +------------------------------+
+--R          |     2            2  |             16a c
+--R          |(- 2c  + 4a c - 2a ) |------------------------------  + 4c + 4a
+--R          |                     | 4       3     2 2     3     4
+--R          |                    \|c  - 4a c  + 6a c  - 4a c + a
+--R          |---------------------------------------------------------------
+--R          |                          2           2
+--R         \|                         c  - 2a c + a
+--R      *
+--R         log
+--R                (- c + a)
+--R             *
+--R               +---------------------------------------------------------------+
+--R               |                     +------------------------------+
+--R               |     2            2  |             16a c
+--R               |(- 2c  + 4a c - 2a ) |------------------------------  + 4c + 4a
+--R               |                     | 4       3     2 2     3     4
+--R               |                    \|c  - 4a c  + 6a c  - 4a c + a
+--R               |---------------------------------------------------------------
+--R               |                          2           2
+--R              \|                         c  - 2a c + a
+--R            + 
+--R                +-------+     +-------+
+--R              2\|b x + c  - 2\|b x + a
+--R     + 
+--R                 +-------------------------------------------------------------+
+--R                 |                   +------------------------------+
+--R                 |   2            2  |             16a c
+--R                 |(2c  - 4a c + 2a ) |------------------------------  + 4c + 4a
+--R                 |                   | 4       3     2 2     3     4
+--R                 |                  \|c  - 4a c  + 6a c  - 4a c + a
+--R         (c - a) |-------------------------------------------------------------
+--R                 |                         2           2
+--R                \|                        c  - 2a c + a
+--R      *
+--R         log
+--R                (- c + a)
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |                   +------------------------------+
+--R               |   2            2  |             16a c
+--R               |(2c  - 4a c + 2a ) |------------------------------  + 4c + 4a
+--R               |                   | 4       3     2 2     3     4
+--R               |                  \|c  - 4a c  + 6a c  - 4a c + a
+--R               |-------------------------------------------------------------
+--R               |                         2           2
+--R              \|                        c  - 2a c + a
+--R            + 
+--R                +-------+     +-------+
+--R              2\|b x + c  - 2\|b x + a
+--R     + 
+--R                   +-------+                +-------+
+--R         +-+      \|b x + c       +-+      \|b x + a
+--R       4\|c atanh(----------) - 4\|a atanh(----------)
+--R                      +-+                      +-+
+--R                     \|c                      \|a
+--R  /
+--R     2c - 2a
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 1004
+t0:=1/(x^2*(sqrt(a+b*x)+sqrt(c+b*x)))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R         2 +-------+    2 +-------+
+--R        x \|b x + c  + x \|b x + a
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 1004
+r0:=-b*atanh(sqrt(a+b*x)/sqrt(a))/((a-c)*sqrt(a))+b*atanh(sqrt(c+b*x)/_
+   sqrt(c))/((a-c)*sqrt(c))-sqrt(a+b*x)/((a-c)*x)+sqrt(c+b*x)/((a-c)*x)
+--R 
+--R
+--R   (2)
+--R                       +-------+                  +-------+
+--R             +-+      \|b x + c         +-+      \|b x + a
+--R       - b x\|a atanh(----------) + b x\|c atanh(----------)
+--R                          +-+                        +-+
+--R                         \|c                        \|a
+--R     + 
+--R          +-+ +-+ +-------+    +-+ +-+ +-------+
+--R       - \|a \|c \|b x + c  + \|a \|c \|b x + a
+--R  /
+--R              +-+ +-+
+--R     (c - a)x\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 1004
+--a0:=integrate(t0,x)
+--E 23
+
+--S 24 of 1004
+--m0:=a0-r0
+--E 24
+
+--S 25 of 1004
+--d0:=normalize(D(m0,x))
+--E 25
+
+)clear all
+
+--S 26 of 1004
+t0:=x^2/(sqrt(a+b*x)+sqrt(c+b*x))^2
+--R 
+--R
+--R                          2
+--R                         x
+--R   (1)  ------------------------------------
+--R          +-------+ +-------+
+--R        2\|b x + a \|b x + c  + 2b x + c + a
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1004
+r0:=1/3*(a+c)*x^3/(a-c)^2+1/2*b*x^4/(a-c)^2+5/12*(a+c)*(a+b*x)^(3/2)*_
+   (c+b*x)^(3/2)/(b^3*(a-c)^2)-1/2*x*(a+b*x)^(3/2)*(c+b*x)^(3/2)/_
+   (b^2*(a-c)^2)-1/32*(4*a*c-5*(a+c)^2)*atanh(sqrt(a+b*x)/sqrt(c+b*x))/b^3+_
+   1/16*(4*a*c-5*(a+c)^2)*(a+b*x)^(3/2)*sqrt(c+b*x)/(b^3*(a-c)^2)-_
+   1/32*(4*a*c-5*(a+c)^2)*sqrt(a+b*x)*sqrt(c+b*x)/(b^3*(a-c))
+--R 
+--R
+--R   (2)
+--R                                                    +-------+
+--R           4        3     2 2      3       4       \|b x + a
+--R       (15c  - 12a c  - 6a c  - 12a c + 15a )atanh(----------)
+--R                                                    +-------+
+--R                                                   \|b x + c
+--R     + 
+--R                3 3        2        2  2         2               2         3
+--R           - 48b x  + (- 8b c - 8a b )x  + (10b c  - 4a b c + 10a b)x - 15c
+--R         + 
+--R               2     2       3
+--R           7a c  + 7a c - 15a
+--R      *
+--R          +-------+ +-------+
+--R         \|b x + a \|b x + c
+--R     + 
+--R          4 4       3         3  3
+--R       48b x  + (32b c + 32a b )x
+--R  /
+--R        3 2         3       2 3
+--R     96b c  - 192a b c + 96a b
+--R                                                    Type: Expression(Integer)
+--E 27
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 28 of 1004
+--a0:=integrate(t0,x)
+--E 28
+
+--S 29 of 1004
+--m0:=a0-r0
+--E 29
+
+--S 30 of 1004
+--d0:=normalize(D(m0,x))
+--E 30
+
+)clear all
+
+--S 31 of 1004
+t0:=x/(sqrt(a+b*x)+sqrt(c+b*x))^2
+--R 
+--R
+--R                          x
+--R   (1)  ------------------------------------
+--R          +-------+ +-------+
+--R        2\|b x + a \|b x + c  + 2b x + c + a
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 1004
+r0:=1/2*(a+c)*x^2/(a-c)^2+2/3*b*x^3/(a-c)^2-2/3*(a+b*x)^(3/2)*(c+b*x)^(3/2)/_
+   (b^2*(a-c)^2)-1/4*(a+c)*atanh(sqrt(a+b*x)/sqrt(c+b*x))/b^2+_
+   1/2*(a+c)*(a+b*x)^(3/2)*sqrt(c+b*x)/(b^2*(a-c)^2)-1/4*(a+c)*_
+   sqrt(a+b*x)*sqrt(c+b*x)/(b^2*(a-c))
+--R 
+--R
+--R   (2)
+--R                                          +-------+
+--R            3       2     2      3       \|b x + a
+--R       (- 3c  + 3a c  + 3a c - 3a )atanh(----------)
+--R                                          +-------+
+--R                                         \|b x + c
+--R     + 
+--R            2 2                        2            2  +-------+ +-------+
+--R       (- 8b x  + (- 2b c - 2a b)x + 3c  - 2a c + 3a )\|b x + a \|b x + c
+--R     + 
+--R         3 3      2        2  2
+--R       8b x  + (6b c + 6a b )x
+--R  /
+--R        2 2        2       2 2
+--R     12b c  - 24a b c + 12a b
+--R                                                    Type: Expression(Integer)
+--E 32
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 33 of 1004
+--a0:=integrate(t0,x)
+--E 33
+
+--S 34 of 1004
+--m0:=a0-r0
+--E 34
+
+--S 35 of 1004
+--d0:=normalize(D(m0,x))
+--E 35
+
+)clear all
+
+--S 36 of 1004
+t0:=1/(sqrt(a+b*x)+sqrt(c+b*x))^2
+--R 
+--R
+--R                          1
+--R   (1)  ------------------------------------
+--R          +-------+ +-------+
+--R        2\|b x + a \|b x + c  + 2b x + c + a
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 1004
+r0a:=1/2*atanh(sqrt(a+b*x)/sqrt(c+b*x))/b+1/8*(a-c)^2/(b*(sqrt(a+b*x)+sqrt(c+b*x))^4)
+--R 
+--R
+--R   (2)
+--R                               +-------+ +-------+      2 2
+--R           (32b x + 16c + 16a)\|b x + a \|b x + c  + 32b x  + (32b c + 32a b)x
+--R         + 
+--R             2             2
+--R           4c  + 24a c + 4a
+--R      *
+--R                +-------+
+--R               \|b x + a
+--R         atanh(----------)
+--R                +-------+
+--R               \|b x + c
+--R     + 
+--R        2           2
+--R       c  - 2a c + a
+--R  /
+--R           2                   +-------+ +-------+      3 2       2         2
+--R       (64b x + 32b c + 32a b)\|b x + a \|b x + c  + 64b x  + (64b c + 64a b )x
+--R     + 
+--R           2               2
+--R       8b c  + 48a b c + 8a b
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 1004
+r0b:=(a+c)*x/(a-c)^2+b*x^2/(a-c)^2+1/2*atanh(sqrt(a+b*x)/sqrt(c+b*x))/b-(a+b*x)^(3/2)*sqrt(c+b*x)/(b*(a-c)^2)+1/2*sqrt(a+b*x)*sqrt(c+b*x)/(b*(a-c))
+--R 
+--R
+--R   (3)
+--R                              +-------+
+--R         2           2       \|b x + a                      +-------+ +-------+
+--R       (c  - 2a c + a )atanh(----------) + (- 2b x - c - a)\|b x + a \|b x + c
+--R                              +-------+
+--R                             \|b x + c
+--R     + 
+--R         2 2
+--R       2b x  + (2b c + 2a b)x
+--R  /
+--R         2              2
+--R     2b c  - 4a b c + 2a b
+--R                                                    Type: Expression(Integer)
+--E 38
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 39 of 1004
+--a0:=integrate(t0,x)
+--E 39
+
+--S 40 of 1004
+--m0:=a0-r0
+--E 40
+
+--S 41 of 1004
+--d0:=normalize(D(m0,x))
+--E 41
+
+)clear all
+
+--S 42 of 1004
+t0:=1/(x*(sqrt(a+b*x)+sqrt(c+b*x))^2)
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R           +-------+ +-------+       2
+--R        2x\|b x + a \|b x + c  + 2b x  + (c + a)x
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 1004
+r0:=2*b*x/(a-c)^2-2*(a+c)*atanh(sqrt(a+b*x)/sqrt(c+b*x))/(a-c)^2+(a+c)*_
+   log(x)/(a-c)^2+4*atanh(sqrt(c)*sqrt(a+b*x)/(sqrt(a)*sqrt(c+b*x)))*_
+   sqrt(a)*sqrt(c)/(a-c)^2-2*sqrt(a+b*x)*sqrt(c+b*x)/(a-c)^2
+--R 
+--R
+--R   (2)
+--R                       +-+ +-------+                      +-------+
+--R         +-+ +-+      \|c \|b x + a                      \|b x + a
+--R       4\|a \|c atanh(--------------) + (- 2c - 2a)atanh(----------)
+--R                       +-+ +-------+                      +-------+
+--R                      \|a \|b x + c                      \|b x + c
+--R     + 
+--R           +-------+ +-------+
+--R       - 2\|b x + a \|b x + c  + (c + a)log(x) + 2b x
+--R  /
+--R      2           2
+--R     c  - 2a c + a
+--R                                                    Type: Expression(Integer)
+--E 43
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 44 of 1004
+--a0:=integrate(t0,x)
+--E 44
+
+--S 45 of 1004
+--m0:=a0-r0
+--E 45
+
+--S 46 of 1004
+--d0:=normalize(D(m0,x))
+--E 46
+
+)clear all
+
+--S 47 of 1004
+t0:=1/(x^2*(sqrt(a+b*x)+sqrt(c+b*x))^2)
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R          2 +-------+ +-------+       3           2
+--R        2x \|b x + a \|b x + c  + 2b x  + (c + a)x
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 1004
+r0:=(-a-c)/((a-c)^2*x)-4*b*atanh(sqrt(a+b*x)/sqrt(c+b*x))/(a-c)^2+_
+   2*b*log(x)/(a-c)^2+2*b*(a+c)*atanh(sqrt(c)*sqrt(a+b*x)/(sqrt(a)*_
+   sqrt(c+b*x)))/((a-c)^2*sqrt(a)*sqrt(c))+2*sqrt(a+b*x)*sqrt(c+b*x)/_
+   ((a-c)^2*x)
+--R 
+--R
+--R   (2)
+--R                             +-+ +-------+                       +-------+
+--R                            \|c \|b x + a          +-+ +-+      \|b x + a
+--R       (2b c + 2a b)x atanh(--------------) - 4b x\|a \|c atanh(----------)
+--R                             +-+ +-------+                       +-------+
+--R                            \|a \|b x + c                       \|b x + c
+--R     + 
+--R         +-+ +-+ +-------+ +-------+                         +-+ +-+
+--R       2\|a \|c \|b x + a \|b x + c  + (2b x log(x) - c - a)\|a \|c
+--R  /
+--R       2           2   +-+ +-+
+--R     (c  - 2a c + a )x\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 48
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 49 of 1004
+--a0:=integrate(t0,x)
+--E 49
+
+--S 50 of 1004
+--m0:=a0-r0
+--E 50
+
+--S 51 of 1004
+--d0:=normalize(D(m0,x))
+--E 51
+
+)clear all
+
+--S 52 of 1004
+t0:=x^2/(sqrt(a+b*x)+sqrt(c+b*x))^3
+--R 
+--R
+--R                                   2
+--R                                  x
+--R   (1)  -----------------------------------------------------
+--R                        +-------+                   +-------+
+--R        (4b x + c + 3a)\|b x + c  + (4b x + 3c + a)\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 1004
+r0:=-8/3*a^3*(a+b*x)^(3/2)/(b^3*(a-c)^3)+2/3*a^2*(a+3*c)*(a+b*x)^(3/2)/_
+   (b^3*(a-c)^3)+24/5*a^2*(a+b*x)^(5/2)/(b^3*(a-c)^3)-4/5*a*(a+3*c)*_
+   (a+b*x)^(5/2)/(b^3*(a-c)^3)-24/7*a*(a+b*x)^(7/2)/(b^3*(a-c)^3)+_
+   2/7*(a+3*c)*(a+b*x)^(7/2)/(b^3*(a-c)^3)+8/9*(a+b*x)^(9/2)/(b^3*_
+   (a-c)^3)+8/3*c^3*(c+b*x)^(3/2)/(b^3*(a-c)^3)-2/3*c^2*(3*a+c)*_
+   (c+b*x)^(3/2)/(b^3*(a-c)^3)-24/5*c^2*(c+b*x)^(5/2)/(b^3*(a-c)^3)+_
+   4/5*c*(3*a+c)*(c+b*x)^(5/2)/(b^3*(a-c)^3)+24/7*c*(c+b*x)^(7/2)/_
+   (b^3*(a-c)^3)-2/7*(3*a+c)*(c+b*x)^(7/2)/(b^3*(a-c)^3)-_
+   8/9*(c+b*x)^(9/2)/(b^3*(a-c)^3)
+--R 
+--R
+--R   (2)
+--R               4 4        3          3  3         2 2        2   2
+--R           280b x  + (130b c + 270a b )x  + (- 30b c  + 54a b c)x
+--R         + 
+--R                 3          2        4         3
+--R           (40b c  - 72a b c )x - 80c  + 144a c
+--R      *
+--R          +-------+
+--R         \|b x + c
+--R     + 
+--R                 4 4          3          3  3           2       2 2  2
+--R           - 280b x  + (- 270b c - 130a b )x  + (- 54a b c + 30a b )x
+--R         + 
+--R               2         3          3       4
+--R           (72a b c - 40a b)x - 144a c + 80a
+--R      *
+--R          +-------+
+--R         \|b x + a
+--R  /
+--R         3 3         3 2       2 3        3 3
+--R     315b c  - 945a b c  + 945a b c - 315a b
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 4        3          3  3         2 2        2   2
+--R           280b x  + (130b c + 270a b )x  + (- 30b c  + 54a b c)x
+--R         + 
+--R                 3          2        4         3
+--R           (40b c  - 72a b c )x - 80c  + 144a c
+--R      *
+--R          +-------+
+--R         \|b x + c
+--R     + 
+--R                 4 4          3          3  3           2       2 2  2
+--R           - 280b x  + (- 270b c - 130a b )x  + (- 54a b c + 30a b )x
+--R         + 
+--R               2         3          3       4
+--R           (72a b c - 40a b)x - 144a c + 80a
+--R      *
+--R          +-------+
+--R         \|b x + a
+--R  /
+--R         3 3         3 2       2 3        3 3
+--R     315b c  - 945a b c  + 945a b c - 315a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 54
+
+--S 55 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 56
+
+)clear all
+
+--S 57 of 1004
+t0:=x/(sqrt(a+b*x)+sqrt(c+b*x))^3
+--R 
+--R
+--R                                  x
+--R   (1)  -----------------------------------------------------
+--R                        +-------+                   +-------+
+--R        (4b x + c + 3a)\|b x + c  + (4b x + 3c + a)\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 57
+
+--S 58 of 1004
+r0:=8/3*a^2*(a+b*x)^(3/2)/(b^2*(a-c)^3)-2/3*a*(a+3*c)*(a+b*x)^(3/2)/(b^2*_
+   (a-c)^3)-16/5*a*(a+b*x)^(5/2)/(b^2*(a-c)^3)+2/5*(a+3*c)*(a+b*x)^(5/2)/_
+   (b^2*(a-c)^3)+8/7*(a+b*x)^(7/2)/(b^2*(a-c)^3)-8/3*c^2*(c+b*x)^(3/2)/_
+   (b^2*(a-c)^3)+2/3*c*(3*a+c)*(c+b*x)^(3/2)/(b^2*(a-c)^3)+16/5*c*_
+   (c+b*x)^(5/2)/(b^2*(a-c)^3)-2/5*(3*a+c)*(c+b*x)^(5/2)/(b^2*(a-c)^3)-_
+   8/7*(c+b*x)^(7/2)/(b^2*(a-c)^3)
+--R 
+--R
+--R   (2)
+--R             3 3       2         2  2          2                  3        2
+--R         (40b x  + (22b c + 42a b )x  + (- 6b c  + 14a b c)x + 12c  - 28a c )
+--R      *
+--R          +-------+
+--R         \|b x + c
+--R     + 
+--R               3 3         2         2  2                  2         2       3
+--R         (- 40b x  + (- 42b c - 22a b )x  + (- 14a b c + 6a b)x + 28a c - 12a )
+--R      *
+--R          +-------+
+--R         \|b x + a
+--R  /
+--R        2 3         2 2       2 2       3 2
+--R     35b c  - 105a b c  + 105a b c - 35a b
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3 3       2         2  2          2                  3        2
+--R         (40b x  + (22b c + 42a b )x  + (- 6b c  + 14a b c)x + 12c  - 28a c )
+--R      *
+--R          +-------+
+--R         \|b x + c
+--R     + 
+--R               3 3         2         2  2                  2         2       3
+--R         (- 40b x  + (- 42b c - 22a b )x  + (- 14a b c + 6a b)x + 28a c - 12a )
+--R      *
+--R          +-------+
+--R         \|b x + a
+--R  /
+--R        2 3         2 2       2 2       3 2
+--R     35b c  - 105a b c  + 105a b c - 35a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 59
+
+--S 60 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+--S 61 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 61
+
+)clear all
+
+--S 62 of 1004
+t0:=1/(sqrt(a+b*x)+sqrt(c+b*x))^3
+--R 
+--R
+--R                                  1
+--R   (1)  -----------------------------------------------------
+--R                        +-------+                   +-------+
+--R        (4b x + c + 3a)\|b x + c  + (4b x + 3c + a)\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 1004
+r0a:=1/10*(a-c)^2/(b*(sqrt(a+b*x)+sqrt(c+b*x))^5)+(-1/2)/(b*(sqrt(a+b*x)+sqrt(c+b*x)))
+--R 
+--R
+--R   (2)
+--R             2 2                          2              2  +-------+
+--R       (- 40b x  + (- 30b c - 50a b)x - 2c  - 26a c - 12a )\|b x + c
+--R     + 
+--R             2 2                           2             2  +-------+
+--R       (- 40b x  + (- 50b c - 30a b)x - 12c  - 26a c - 2a )\|b x + a
+--R  /
+--R              3 2        2          2          2                 2   +-------+
+--R         (160b x  + (160b c + 160a b )x + 30b c  + 100a b c + 30a b)\|b x + a
+--R      *
+--R          +-------+
+--R         \|b x + c
+--R     + 
+--R           4 3        3          3  2       2 2         2       2 2         3
+--R       160b x  + (240b c + 240a b )x  + (90b c  + 300a b c + 90a b )x + 5b c
+--R     + 
+--R              2      2        3
+--R       75a b c  + 75a b c + 5a b
+--R                                                    Type: Expression(Integer)
+--E 63
+
+--S 64 of 1004
+r0b:=-8/3*a*(a+b*x)^(3/2)/(b*(a-c)^3)+2/3*(a+3*c)*(a+b*x)^(3/2)/(b*(a-c)^3)+8/5*(a+b*x)^(5/2)/(b*(a-c)^3)+8/3*c*(c+b*x)^(3/2)/(b*(a-c)^3)-2/3*(3*a+c)*(c+b*x)^(3/2)/(b*(a-c)^3)-8/5*(c+b*x)^(5/2)/(b*(a-c)^3)
+--R 
+--R
+--R   (3)
+--R          2 2                       2          +-------+
+--R       (8b x  + (6b c + 10a b)x - 2c  + 10a c)\|b x + c
+--R     + 
+--R            2 2                                 2  +-------+
+--R       (- 8b x  + (- 10b c - 6a b)x - 10a c + 2a )\|b x + a
+--R  /
+--R         3          2      2        3
+--R     5b c  - 15a b c  + 15a b c - 5a b
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (4)
+--R          2 2                       2          +-------+
+--R       (8b x  + (6b c + 10a b)x - 2c  + 10a c)\|b x + c
+--R     + 
+--R            2 2                                 2  +-------+
+--R       (- 8b x  + (- 10b c - 6a b)x - 10a c + 2a )\|b x + a
+--R  /
+--R         3          2      2        3
+--R     5b c  - 15a b c  + 15a b c - 5a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 65
+
+--S 66 of 1004
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 1004
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 1004
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 1004
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 1004
+t0:=1/(x*(sqrt(a+b*x)+sqrt(c+b*x))^3)
+--R 
+--R
+--R                                      1
+--R   (1)  -------------------------------------------------------------
+--R             2              +-------+        2              +-------+
+--R        (4b x  + (c + 3a)x)\|b x + c  + (4b x  + (3c + a)x)\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 1004
+r0:=8/3*(a+b*x)^(3/2)/(a-c)^3-8/3*(c+b*x)^(3/2)/(a-c)^3-2*(a+3*c)*_
+   atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(a-c)^3+2*(3*a+c)*atanh(sqrt(c+b*x)/_
+   sqrt(c))*sqrt(c)/(a-c)^3+2*(a+3*c)*sqrt(a+b*x)/(a-c)^3-2*(3*a+c)*_
+   sqrt(c+b*x)/(a-c)^3
+--R 
+--R
+--R   (2)
+--R                              +-------+                         +-------+
+--R                    +-+      \|b x + c                +-+      \|b x + a
+--R       (- 6c - 18a)\|c atanh(----------) + (18c + 6a)\|a atanh(----------)
+--R                                 +-+                               +-+
+--R                                \|c                               \|a
+--R     + 
+--R                          +-------+                        +-------+
+--R       (8b x + 14c + 18a)\|b x + c  + (- 8b x - 18c - 14a)\|b x + a
+--R  /
+--R       3       2     2      3
+--R     3c  - 9a c  + 9a c - 3a
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1004
+--a0:=integrate(t0,x)
+--E 72
+
+--S 73 of 1004
+--m0:=a0-r0
+--E 73
+
+--S 74 of 1004
+--d0:=normalize(D(m0,x))
+--E 74
+
+)clear all
+
+--S 75 of 1004
+t0:=1/(x^2*(sqrt(a+b*x)+sqrt(c+b*x))^3)
+--R 
+--R
+--R                                       1
+--R   (1)  ---------------------------------------------------------------
+--R             3            2  +-------+        3            2  +-------+
+--R        (4b x  + (c + 3a)x )\|b x + c  + (4b x  + (3c + a)x )\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 75
+
+--S 76 of 1004
+r0a:=-3*b*(3*a+c)*atanh(sqrt(a+b*x)/sqrt(a))/((a-c)^3*sqrt(a))-3*b*(a+3*c)*atanh(sqrt(c+b*x)/sqrt(c))/((-a+c)^3*sqrt(c))+8*b*sqrt(a+b*x)/(a-c)^3-(a+3*c)*sqrt(a+b*x)/((a-c)^3*x)-8*b*sqrt(c+b*x)/(a-c)^3+(3*a+c)*sqrt(c+b*x)/((a-c)^3*x)
+--R 
+--R
+--R   (2)
+--R                                  +-------+
+--R                        +-+      \|b x + c
+--R       (- 9b c - 3a b)x\|a atanh(----------)
+--R                                     +-+
+--R                                    \|c
+--R     + 
+--R                                +-------+
+--R                      +-+      \|b x + a                     +-+ +-+ +-------+
+--R       (3b c + 9a b)x\|c atanh(----------) + (8b x - c - 3a)\|a \|c \|b x + c
+--R                                   +-+
+--R                                  \|a
+--R     + 
+--R                         +-+ +-+ +-------+
+--R       (- 8b x + 3c + a)\|a \|c \|b x + a
+--R  /
+--R       3       2     2     3   +-+ +-+
+--R     (c  - 3a c  + 3a c - a )x\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 1004
+r0b:=-b*(a+3*c)*atanh(sqrt(a+b*x)/sqrt(a))/((a-c)^3*sqrt(a))-8*b*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(a-c)^3+b*(3*a+c)*atanh(sqrt(c+b*x)/sqrt(c))/((a-c)^3*sqrt(c))+8*b*atanh(sqrt(c+b*x)/sqrt(c))*sqrt(c)/(a-c)^3+8*b*sqrt(a+b*x)/(a-c)^3-(a+3*c)*sqrt(a+b*x)/((a-c)^3*x)-8*b*sqrt(c+b*x)/(a-c)^3+(3*a+c)*sqrt(c+b*x)/((a-c)^3*x)
+--R 
+--R
+--R   (3)
+--R                                  +-------+
+--R                        +-+      \|b x + c
+--R       (- 9b c - 3a b)x\|a atanh(----------)
+--R                                     +-+
+--R                                    \|c
+--R     + 
+--R                                +-------+
+--R                      +-+      \|b x + a                     +-+ +-+ +-------+
+--R       (3b c + 9a b)x\|c atanh(----------) + (8b x - c - 3a)\|a \|c \|b x + c
+--R                                   +-+
+--R                                  \|a
+--R     + 
+--R                         +-+ +-+ +-------+
+--R       (- 8b x + 3c + a)\|a \|c \|b x + a
+--R  /
+--R       3       2     2     3   +-+ +-+
+--R     (c  - 3a c  + 3a c - a )x\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 1004
+--a0:=integrate(t0,x)
+--E 78
+
+--S 79 of 1004
+--m0:=a0-r0
+--E 79
+
+--S 80 of 1004
+--d0:=normalize(D(m0,x))
+--E 80
+
+)clear all
+
+--S 81 of 1004
+t0:=x^3/(sqrt(a+b*x)+sqrt(a+c*x))
+--R 
+--R
+--R                    3
+--R                   x
+--R   (1)  -----------------------
+--R         +-------+    +-------+
+--R        \|c x + a  + \|b x + a
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 1004
+r0:=2/3*a^2*(a+b*x)^(3/2)/(b^3*(b-c))-4/5*a*(a+b*x)^(5/2)/(b^3*(b-c))+_
+   2/7*(a+b*x)^(7/2)/(b^3*(b-c))-2/3*a^2*(a+c*x)^(3/2)/((b-c)*c^3)+_
+   4/5*a*(a+c*x)^(5/2)/((b-c)*c^3)-2/7*(a+c*x)^(7/2)/((b-c)*c^3)
+--R 
+--R
+--R   (2)
+--R           3 3 3       3 2 2     2 3         3 3  +-------+
+--R       (30b c x  + 6a b c x  - 8a b c x + 16a b )\|c x + a
+--R     + 
+--R             3 3 3       2 3 2     2   3       3 3  +-------+
+--R       (- 30b c x  - 6a b c x  + 8a b c x - 16a c )\|b x + a
+--R  /
+--R         3 4       4 3
+--R     105b c  - 105b c
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 3 3       3 2 2     2 3         3 3  +-------+
+--R       (30b c x  + 6a b c x  - 8a b c x + 16a b )\|c x + a
+--R     + 
+--R             3 3 3       2 3 2     2   3       3 3  +-------+
+--R       (- 30b c x  - 6a b c x  + 8a b c x - 16a c )\|b x + a
+--R  /
+--R         3 4       4 3
+--R     105b c  - 105b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 83
+
+--S 84 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 1004
+t0:=x^2/(sqrt(a+b*x)+sqrt(a+c*x))
+--R 
+--R
+--R                    2
+--R                   x
+--R   (1)  -----------------------
+--R         +-------+    +-------+
+--R        \|c x + a  + \|b x + a
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 1004
+r0:=-2/3*a*(a+b*x)^(3/2)/(b^2*(b-c))+2/5*(a+b*x)^(5/2)/(b^2*(b-c))+_
+   2/3*a*(a+c*x)^(3/2)/((b-c)*c^2)-2/5*(a+c*x)^(5/2)/((b-c)*c^2)
+--R 
+--R
+--R   (2)
+--R          2 2 2       2        2 2  +-------+
+--R       (6b c x  + 2a b c x - 4a b )\|c x + a
+--R     + 
+--R            2 2 2         2      2 2  +-------+
+--R       (- 6b c x  - 2a b c x + 4a c )\|b x + a
+--R  /
+--R        2 3      3 2
+--R     15b c  - 15b c
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2 2       2        2 2  +-------+
+--R       (6b c x  + 2a b c x - 4a b )\|c x + a
+--R     + 
+--R            2 2 2         2      2 2  +-------+
+--R       (- 6b c x  - 2a b c x + 4a c )\|b x + a
+--R  /
+--R        2 3      3 2
+--R     15b c  - 15b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 88
+
+--S 89 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 1004
+t0:=x/(sqrt(a+b*x)+sqrt(a+c*x))
+--R 
+--R
+--R                   x
+--R   (1)  -----------------------
+--R         +-------+    +-------+
+--R        \|c x + a  + \|b x + a
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1004
+r0:=2/3*(a+b*x)^(3/2)/(b*(b-c))-2/3*(a+c*x)^(3/2)/((b-c)*c)
+--R 
+--R
+--R                        +-------+                     +-------+
+--R        (2b c x + 2a b)\|c x + a  + (- 2b c x - 2a c)\|b x + a
+--R   (2)  -------------------------------------------------------
+--R                                  2     2
+--R                              3b c  - 3b c
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        +-------+                     +-------+
+--R        (2b c x + 2a b)\|c x + a  + (- 2b c x - 2a c)\|b x + a
+--R   (3)  -------------------------------------------------------
+--R                                  2     2
+--R                              3b c  - 3b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 93
+
+--S 94 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 95
+
+)clear all
+
+--S 96 of 1004
+t0:=1/(sqrt(a+b*x)+sqrt(a+c*x))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R         +-------+    +-------+
+--R        \|c x + a  + \|b x + a
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 1004
+r0:=-2*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(b-c)+2*atanh(sqrt(a+c*x)/sqrt(a))*_
+   sqrt(a)/(b-c)+2*sqrt(a+b*x)/(b-c)-2*sqrt(a+c*x)/(b-c)
+--R 
+--R
+--R   (2)
+--R                 +-------+                +-------+
+--R       +-+      \|c x + a       +-+      \|b x + a       +-------+     +-------+
+--R   - 2\|a atanh(----------) + 2\|a atanh(----------) + 2\|c x + a  - 2\|b x + a
+--R                    +-+                      +-+
+--R                   \|a                      \|a
+--R   -----------------------------------------------------------------------------
+--R                                       c - b
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 1004
+--a0:=integrate(t0,x)
+--E 98
+
+--S 99 of 1004
+--m0:=a0-r0
+--E 99
+
+--S 100 of 1004
+--d0:=normalize(D(m0,x))
+--E 100
+
+)clear all
+
+--S 101 of 1004
+t0:=1/(x*(sqrt(a+b*x)+sqrt(a+c*x)))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R          +-------+     +-------+
+--R        x\|c x + a  + x\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1004
+r0:=-b*atanh(sqrt(a+b*x)/sqrt(a))/((b-c)*sqrt(a))+_
+   c*atanh(sqrt(a+c*x)/sqrt(a))/((b-c)*sqrt(a))-sqrt(a+b*x)/((b-c)*x)+_
+   sqrt(a+c*x)/((b-c)*x)
+--R 
+--R
+--R   (2)
+--R                    +-------+               +-------+
+--R                   \|c x + a               \|b x + a      +-+ +-------+
+--R       - c x atanh(----------) + b x atanh(----------) - \|a \|c x + a
+--R                       +-+                     +-+
+--R                      \|a                     \|a
+--R     + 
+--R        +-+ +-------+
+--R       \|a \|b x + a
+--R  /
+--R              +-+
+--R     (c - b)x\|a
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 1004
+--a0:=integrate(t0,x)
+--E 103
+
+--S 104 of 1004
+--m0:=a0-r0
+--E 104
+
+--S 105 of 1004
+--d0:=normalize(D(m0,x))
+--E 105
+
+)clear all
+
+--S 106 of 1004
+t0:=1/(x^2*(sqrt(a+b*x)+sqrt(a+c*x)))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R         2 +-------+    2 +-------+
+--R        x \|c x + a  + x \|b x + a
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 1004
+r0:=1/4*b^2*atanh(sqrt(a+b*x)/sqrt(a))/(a^(3/2)*(b-c))-1/4*c^2*_
+   atanh(sqrt(a+c*x)/sqrt(a))/(a^(3/2)*(b-c))-1/2*sqrt(a+b*x)/((b-c)*x^2)-_
+   1/4*b*sqrt(a+b*x)/(a*(b-c)*x)+1/2*sqrt(a+c*x)/((b-c)*x^2)+_
+   1/4*c*sqrt(a+c*x)/(a*(b-c)*x)
+--R 
+--R
+--R   (2)
+--R                  +-------+               +-------+
+--R        2 2      \|c x + a      2 2      \|b x + a
+--R       c x atanh(----------) - b x atanh(----------)
+--R                     +-+                     +-+
+--R                    \|a                     \|a
+--R     + 
+--R                    +-+ +-------+              +-+ +-------+
+--R       (- c x - 2a)\|a \|c x + a  + (b x + 2a)\|a \|b x + a
+--R  /
+--R                   2 +-+
+--R     (4a c - 4a b)x \|a
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 1004
+--a0:=integrate(t0,x)
+--E 108
+
+--S 109 of 1004
+--m0:=a0-r0
+--E 109
+
+--S 110 of 1004
+--d0:=normalize(D(m0,x))
+--E 110
+
+)clear all
+
+--S 111 of 1004
+t0:=x^3/(sqrt(a+b*x)+sqrt(a+c*x))^2
+--R 
+--R
+--R                           3
+--R                          x
+--R   (1)  -------------------------------------
+--R          +-------+ +-------+
+--R        2\|b x + a \|c x + a  + (c + b)x + 2a
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 1004
+r0:=a*x^2/(b-c)^2+1/3*(b+c)*x^3/(b-c)^2-2/3*(a+b*x)^(3/2)*(a+c*x)^(3/2)/_
+   (b*(b-c)^2*c)-1/4*a^3*(b+c)*atanh(sqrt(c)*sqrt(a+b*x)/(sqrt(b)*_
+   sqrt(a+c*x)))/(b^(5/2)*c^(5/2))+1/2*a*(b+c)*(a+b*x)^(3/2)*_
+   sqrt(a+c*x)/(b^2*(b-c)^2*c)+1/4*a^2*(b+c)*sqrt(a+b*x)*_
+   sqrt(a+c*x)/(b^2*(b-c)*c^2)
+--R 
+--R
+--R   (2)
+--R                                                  +-+ +-------+
+--R            3 3     3   2     3 2      3 3       \|c \|b x + a
+--R       (- 3a c  + 3a b c  + 3a b c - 3a b )atanh(--------------)
+--R                                                  +-+ +-------+
+--R                                                 \|b \|c x + a
+--R     + 
+--R              2 2 2            2       2        2 2     2        2 2  +-+ +-+
+--R         (- 8b c x  + (- 2a b c  - 2a b c)x + 3a c  - 2a b c + 3a b )\|b \|c
+--R      *
+--R          +-------+ +-------+
+--R         \|b x + a \|c x + a
+--R     + 
+--R           2 3     3 2  3        2 2 2  +-+ +-+
+--R       ((4b c  + 4b c )x  + 12a b c x )\|b \|c
+--R  /
+--R         2 4      3 3      4 2  +-+ +-+
+--R     (12b c  - 24b c  + 12b c )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 1004
+--a0:=integrate(t0,x)
+--E 113
+
+--S 114 of 1004
+--m0:=a0-r0
+--E 114
+
+--S 115 of 1004
+--d0:=normalize(D(m0,x))
+--E 115
+
+)clear all
+
+--S 116 of 1004
+t0:=x^2/(sqrt(a+b*x)+sqrt(a+c*x))^2
+--R 
+--R
+--R                           2
+--R                          x
+--R   (1)  -------------------------------------
+--R          +-------+ +-------+
+--R        2\|b x + a \|c x + a  + (c + b)x + 2a
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1004
+r0:=2*a*x/(b-c)^2+1/2*(b+c)*x^2/(b-c)^2+1/2*a^2*atanh(sqrt(c)*sqrt(a+b*x)/_
+   (sqrt(b)*sqrt(a+c*x)))/(b^(3/2)*c^(3/2))-(a+b*x)^(3/2)*sqrt(a+c*x)/_
+   (b*(b-c)^2)-1/2*a*sqrt(a+b*x)*sqrt(a+c*x)/(b*(b-c)*c)
+--R 
+--R
+--R   (2)
+--R                                    +-+ +-------+
+--R         2 2     2       2 2       \|c \|b x + a
+--R       (a c  - 2a b c + a b )atanh(--------------)
+--R                                    +-+ +-------+
+--R                                   \|b \|c x + a
+--R     + 
+--R                              +-+ +-+ +-------+ +-------+
+--R       (- 2b c x - a c - a b)\|b \|c \|b x + a \|c x + a
+--R     + 
+--R            2    2   2             +-+ +-+
+--R       ((b c  + b c)x  + 4a b c x)\|b \|c
+--R  /
+--R          3     2 2     3   +-+ +-+
+--R     (2b c  - 4b c  + 2b c)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 1004
+--a0:=integrate(t0,x)
+--E 118
+
+--S 119 of 1004
+--m0:=a0-r0
+--E 119
+
+--S 120 of 1004
+--d0:=normalize(D(m0,x))
+--E 120
+
+)clear all
+
+--S 121 of 1004
+t0:=x/(sqrt(a+b*x)+sqrt(a+c*x))^2
+--R 
+--R
+--R                          x
+--R   (1)  -------------------------------------
+--R          +-------+ +-------+
+--R        2\|b x + a \|c x + a  + (c + b)x + 2a
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1004
+r0:=(b+c)*x/(b-c)^2+4*a*atanh(sqrt(a+b*x)/sqrt(a+c*x))/(b-c)^2+_
+   2*a*log(x)/(b-c)^2-2*a*(b+c)*atanh(sqrt(c)*sqrt(a+b*x)/(sqrt(b)*_
+   sqrt(a+c*x)))/((b-c)^2*sqrt(b)*sqrt(c))-2*sqrt(a+b*x)*sqrt(a+c*x)/(b-c)^2
+--R 
+--R
+--R   (2)
+--R                             +-+ +-------+                     +-------+
+--R                            \|c \|b x + a        +-+ +-+      \|b x + a
+--R       (- 2a c - 2a b)atanh(--------------) + 4a\|b \|c atanh(----------)
+--R                             +-+ +-------+                     +-------+
+--R                            \|b \|c x + a                     \|c x + a
+--R     + 
+--R           +-+ +-+ +-------+ +-------+                          +-+ +-+
+--R       - 2\|b \|c \|b x + a \|c x + a  + (2a log(x) + (c + b)x)\|b \|c
+--R  /
+--R       2           2  +-+ +-+
+--R     (c  - 2b c + b )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 122
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 123 of 1004
+--a0:=integrate(t0,x)
+--E 123
+
+--S 124 of 1004
+--m0:=a0-r0
+--E 124
+
+--S 125 of 1004
+--d0:=normalize(D(m0,x))
+--E 125
+
+)clear all
+
+--S 126 of 1004
+t0:=1/(sqrt(a+b*x)+sqrt(a+c*x))^2
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R          +-------+ +-------+
+--R        2\|b x + a \|c x + a  + (c + b)x + 2a
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 1004
+r0:=-2*a/((b-c)^2*x)+2*(b+c)*atanh(sqrt(a+b*x)/sqrt(a+c*x))/(b-c)^2+_
+   (b+c)*log(x)/(b-c)^2-4*atanh(sqrt(c)*sqrt(a+b*x)/(sqrt(b)*_
+   sqrt(a+c*x)))*sqrt(b)*sqrt(c)/(b-c)^2+2*sqrt(a+b*x)*sqrt(a+c*x)/_
+   ((b-c)^2*x)
+--R 
+--R
+--R   (2)
+--R                          +-+ +-------+                      +-------+
+--R            +-+ +-+      \|c \|b x + a                      \|b x + a
+--R       - 4x\|b \|c atanh(--------------) + (2c + 2b)x atanh(----------)
+--R                          +-+ +-------+                      +-------+
+--R                         \|b \|c x + a                      \|c x + a
+--R     + 
+--R         +-------+ +-------+
+--R       2\|b x + a \|c x + a  + (c + b)x log(x) - 2a
+--R  /
+--R       2           2
+--R     (c  - 2b c + b )x
+--R                                                    Type: Expression(Integer)
+--E 127
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 128 of 1004
+--a0:=integrate(t0,x)
+--E 128
+
+--S 129 of 1004
+--m0:=a0-r0
+--E 129
+
+--S 130 of 1004
+--d0:=normalize(D(m0,x))
+--E 130
+
+)clear all
+
+--S 131 of 1004
+t0:=1/(x*(sqrt(a+b*x)+sqrt(a+c*x))^2)
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R           +-------+ +-------+           2
+--R        2x\|b x + a \|c x + a  + (c + b)x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 1004
+r0:=-a/((b-c)^2*x^2)+(-b-c)/((b-c)^2*x)-1/2*atanh(sqrt(a+b*x)/sqrt(a+c*x))/a+_
+   (a+c*x)^(3/2)*sqrt(a+b*x)/(a*(b-c)^2*x^2)+1/2*sqrt(a+b*x)*_
+   sqrt(a+c*x)/(a*(b-c)*x)
+--R 
+--R
+--R   (2)
+--R                                  +-------+
+--R           2           2  2      \|b x + a
+--R       (- c  + 2b c - b )x atanh(----------)
+--R                                  +-------+
+--R                                 \|c x + a
+--R     + 
+--R                       +-------+ +-------+                        2
+--R       ((c + b)x + 2a)\|b x + a \|c x + a  + (- 2a c - 2a b)x - 2a
+--R  /
+--R          2                2  2
+--R     (2a c  - 4a b c + 2a b )x
+--R                                                    Type: Expression(Integer)
+--E 132
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 133 of 1004
+--a0:=integrate(t0,x)
+--E 133
+
+--S 134 of 1004
+--m0:=a0-r0
+--E 134
+
+--S 135 of 1004
+--d0:=normalize(D(m0,x))
+--E 135
+
+)clear all
+
+--S 136 of 1004
+t0:=1/(x^2*(sqrt(a+b*x)+sqrt(a+c*x))^2)
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R          2 +-------+ +-------+           3       2
+--R        2x \|b x + a \|c x + a  + (c + b)x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 1004
+r0:=-2/3*a/((b-c)^2*x^3)+1/2*(-b-c)/((b-c)^2*x^2)+1/4*(b+c)*_
+   atanh(sqrt(a+b*x)/sqrt(a+c*x))/a^2+2/3*sqrt(a+b*x)*sqrt(a+c*x)/_
+   ((b-c)^2*x^3)+1/6*(b+c)*sqrt(a+b*x)*sqrt(a+c*x)/(a*(b-c)^2*x^2)-_
+   1/12*(3*b^2-2*b*c+3*c^2)*sqrt(a+b*x)*sqrt(a+c*x)/(a^2*(b-c)^2*x)
+--R 
+--R
+--R   (2)
+--R                                          +-------+
+--R          3       2     2      3  3      \|b x + a
+--R       (3c  - 3b c  - 3b c + 3b )x atanh(----------)
+--R                                          +-------+
+--R                                         \|c x + a
+--R     + 
+--R             2            2  2                      2  +-------+ +-------+
+--R       ((- 3c  + 2b c - 3b )x  + (2a c + 2a b)x + 8a )\|b x + a \|c x + a
+--R     + 
+--R            2      2        3
+--R       (- 6a c - 6a b)x - 8a
+--R  /
+--R         2 2      2         2 2  3
+--R     (12a c  - 24a b c + 12a b )x
+--R                                                    Type: Expression(Integer)
+--E 137
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 138 of 1004
+--a0:=integrate(t0,x)
+--E 138
+
+--S 139 of 1004
+--m0:=a0-r0
+--E 139
+
+--S 140 of 1004
+--d0:=normalize(D(m0,x))
+--E 140
+
+)clear all
+
+--S 141 of 1004
+t0:=x^4/(sqrt(a+b*x)+sqrt(a+c*x))^3
+--R 
+--R
+--R                                    4
+--R                                   x
+--R   (1)  -------------------------------------------------------
+--R                         +-------+                    +-------+
+--R        ((c + 3b)x + 4a)\|c x + a  + ((3c + b)x + 4a)\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 1004
+r0:=-8/3*a^2*(a+b*x)^(3/2)/(b^2*(b-c)^3)+2/3*a^2*(b+3*c)*(a+b*x)^(3/2)/_
+   (b^3*(b-c)^3)+8/5*a*(a+b*x)^(5/2)/(b^2*(b-c)^3)-4/5*a*(b+3*c)*_
+   (a+b*x)^(5/2)/(b^3*(b-c)^3)+2/7*(b+3*c)*(a+b*x)^(7/2)/(b^3*(b-c)^3)+_
+   8/3*a^2*(a+c*x)^(3/2)/((b-c)^3*c^2)-2/3*a^2*(3*b+c)*(a+c*x)^(3/2)/_
+   ((b-c)^3*c^3)-8/5*a*(a+c*x)^(5/2)/((b-c)^3*c^2)+4/5*a*(3*b+c)*_
+   (a+c*x)^(5/2)/((b-c)^3*c^3)-2/7*(3*b+c)*(a+c*x)^(7/2)/((b-c)^3*c^3)
+--R 
+--R
+--R   (2)
+--R               3 4      4 3  3         3 3       4 2  2       2 3 2     2 4
+--R           (10b c  + 30b c )x  + (58a b c  + 6a b c )x  + (16a b c  - 8a b c)x
+--R         + 
+--R                3 3       3 4
+--R           - 32a b c + 16a b
+--R      *
+--R          +-------+
+--R         \|c x + a
+--R     + 
+--R                 3 4      4 3  3          2 4        3 3  2
+--R           (- 30b c  - 10b c )x  + (- 6a b c  - 58a b c )x
+--R         + 
+--R              2   4      2 2 3        3 4      3   3
+--R           (8a b c  - 16a b c )x - 16a c  + 32a b c
+--R      *
+--R          +-------+
+--R         \|b x + a
+--R  /
+--R        3 6       4 5       5 4      6 3
+--R     35b c  - 105b c  + 105b c  - 35b c
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 4      4 3  3         3 3       4 2  2       2 3 2     2 4
+--R           (10b c  + 30b c )x  + (58a b c  + 6a b c )x  + (16a b c  - 8a b c)x
+--R         + 
+--R                3 3       3 4
+--R           - 32a b c + 16a b
+--R      *
+--R          +-------+
+--R         \|c x + a
+--R     + 
+--R                 3 4      4 3  3          2 4        3 3  2
+--R           (- 30b c  - 10b c )x  + (- 6a b c  - 58a b c )x
+--R         + 
+--R              2   4      2 2 3        3 4      3   3
+--R           (8a b c  - 16a b c )x - 16a c  + 32a b c
+--R      *
+--R          +-------+
+--R         \|b x + a
+--R  /
+--R        3 6       4 5       5 4      6 3
+--R     35b c  - 105b c  + 105b c  - 35b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 143
+
+--S 144 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 145
+
+)clear all
+
+--S 146 of 1004
+t0:=x^3/(sqrt(a+b*x)+sqrt(a+c*x))^3
+--R 
+--R
+--R                                    3
+--R                                   x
+--R   (1)  -------------------------------------------------------
+--R                         +-------+                    +-------+
+--R        ((c + 3b)x + 4a)\|c x + a  + ((3c + b)x + 4a)\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 1004
+r0:=8/3*a*(a+b*x)^(3/2)/(b*(b-c)^3)-2/3*a*(b+3*c)*(a+b*x)^(3/2)/(b^2*_
+   (b-c)^3)+2/5*(b+3*c)*(a+b*x)^(5/2)/(b^2*(b-c)^3)-8/3*a*_
+   (a+c*x)^(3/2)/((b-c)^3*c)+2/3*a*(3*b+c)*(a+c*x)^(3/2)/((b-c)^3*c^2)-_
+   2/5*(3*b+c)*(a+c*x)^(5/2)/((b-c)^3*c^2)
+--R 
+--R
+--R   (2)
+--R           2 3     3 2  2         2 2       3         2 2      2 3  +-------+
+--R       ((2b c  + 6b c )x  + (14a b c  + 2a b c)x + 12a b c - 4a b )\|c x + a
+--R     + 
+--R               2 3     3 2  2            3        2 2       2 3      2   2
+--R         ((- 6b c  - 2b c )x  + (- 2a b c  - 14a b c )x + 4a c  - 12a b c )
+--R      *
+--R          +-------+
+--R         \|b x + a
+--R  /
+--R       2 5      3 4      4 3     5 2
+--R     5b c  - 15b c  + 15b c  - 5b c
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 3     3 2  2         2 2       3         2 2      2 3  +-------+
+--R       ((2b c  + 6b c )x  + (14a b c  + 2a b c)x + 12a b c - 4a b )\|c x + a
+--R     + 
+--R               2 3     3 2  2            3        2 2       2 3      2   2
+--R         ((- 6b c  - 2b c )x  + (- 2a b c  - 14a b c )x + 4a c  - 12a b c )
+--R      *
+--R          +-------+
+--R         \|b x + a
+--R  /
+--R       2 5      3 4      4 3     5 2
+--R     5b c  - 15b c  + 15b c  - 5b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 148
+
+--S 149 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 1004
+t0:=x^2/(sqrt(a+b*x)+sqrt(a+c*x))^3
+--R 
+--R
+--R                                    2
+--R                                   x
+--R   (1)  -------------------------------------------------------
+--R                         +-------+                    +-------+
+--R        ((c + 3b)x + 4a)\|c x + a  + ((3c + b)x + 4a)\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 1004
+r0:=2/3*(b+3*c)*(a+b*x)^(3/2)/(b*(b-c)^3)-2/3*(3*b+c)*(a+c*x)^(3/2)/_
+   ((b-c)^3*c)-8*a^(3/2)*atanh(sqrt(a+b*x)/sqrt(a))/(b-c)^3+8*a^(3/2)*_
+   atanh(sqrt(a+c*x)/sqrt(a))/(b-c)^3+8*a*sqrt(a+b*x)/(b-c)^3-_
+   8*a*sqrt(a+c*x)/(b-c)^3
+--R 
+--R
+--R   (2)
+--R                           +-------+                      +-------+
+--R                 +-+      \|c x + a             +-+      \|b x + a
+--R       - 24a b c\|a atanh(----------) + 24a b c\|a atanh(----------)
+--R                              +-+                            +-+
+--R                             \|a                            \|a
+--R     + 
+--R             2     2                    2  +-------+
+--R       ((2b c  + 6b c)x + 26a b c + 6a b )\|c x + a
+--R     + 
+--R               2     2          2            +-------+
+--R       ((- 6b c  - 2b c)x - 6a c  - 26a b c)\|b x + a
+--R  /
+--R         4     2 3     3 2     4
+--R     3b c  - 9b c  + 9b c  - 3b c
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 1004
+--a0:=integrate(t0,x)
+--E 153
+
+--S 154 of 1004
+--m0:=a0-r0
+--E 154
+
+--S 155 of 1004
+--d0:=normalize(D(m0,x))
+--E 155
+
+)clear all
+
+--S 156 of 1004
+t0:=x/(sqrt(a+b*x)+sqrt(a+c*x))^3
+--R 
+--R
+--R                                   x
+--R   (1)  -------------------------------------------------------
+--R                         +-------+                    +-------+
+--R        ((c + 3b)x + 4a)\|c x + a  + ((3c + b)x + 4a)\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 1004
+r0a:=-6*(b+c)*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(b-c)^3+6*(b+c)*atanh(sqrt(a+c*x)/sqrt(a))*sqrt(a)/(b-c)^3+2*(b+3*c)*sqrt(a+b*x)/(b-c)^3-4*a*sqrt(a+b*x)/((b-c)^3*x)-2*(3*b+c)*sqrt(a+c*x)/(b-c)^3+4*a*sqrt(a+c*x)/((b-c)^3*x)
+--R 
+--R
+--R   (2)
+--R                              +-------+                         +-------+
+--R                    +-+      \|c x + a                +-+      \|b x + a
+--R       (- 6c - 6b)x\|a atanh(----------) + (6c + 6b)x\|a atanh(----------)
+--R                                 +-+                               +-+
+--R                                \|a                               \|a
+--R     + 
+--R                         +-------+                       +-------+
+--R       ((2c + 6b)x - 4a)\|c x + a  + ((- 6c - 2b)x + 4a)\|b x + a
+--R  /
+--R       3       2     2     3
+--R     (c  - 3b c  + 3b c - b )x
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 1004
+r0b:=-4*b*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(b-c)^3-2*(b+3*c)*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(b-c)^3+4*c*atanh(sqrt(a+c*x)/sqrt(a))*sqrt(a)/(b-c)^3+2*(3*b+c)*atanh(sqrt(a+c*x)/sqrt(a))*sqrt(a)/(b-c)^3+2*(b+3*c)*sqrt(a+b*x)/(b-c)^3-4*a*sqrt(a+b*x)/((b-c)^3*x)-2*(3*b+c)*sqrt(a+c*x)/(b-c)^3+4*a*sqrt(a+c*x)/((b-c)^3*x)
+--R 
+--R
+--R   (3)
+--R                              +-------+                         +-------+
+--R                    +-+      \|c x + a                +-+      \|b x + a
+--R       (- 6c - 6b)x\|a atanh(----------) + (6c + 6b)x\|a atanh(----------)
+--R                                 +-+                               +-+
+--R                                \|a                               \|a
+--R     + 
+--R                         +-------+                       +-------+
+--R       ((2c + 6b)x - 4a)\|c x + a  + ((- 6c - 2b)x + 4a)\|b x + a
+--R  /
+--R       3       2     2     3
+--R     (c  - 3b c  + 3b c - b )x
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 1004
+--a0:=integrate(t0,x)
+--E 159
+
+--S 160 of 1004
+--m0:=a0-r0
+--E 160
+
+--S 161 of 1004
+--d0:=normalize(D(m0,x))
+--E 161
+
+)clear all
+
+--S 162 of 1004
+t0:=1/(sqrt(a+b*x)+sqrt(a+c*x))^3
+--R 
+--R
+--R                                   1
+--R   (1)  -------------------------------------------------------
+--R                         +-------+                    +-------+
+--R        ((c + 3b)x + 4a)\|c x + a  + ((3c + b)x + 4a)\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 1004
+r0a:=-3*b*c*atanh(sqrt(a+b*x)/sqrt(a))/((b-c)^3*sqrt(a))+3*b*c*atanh(sqrt(a+c*x)/sqrt(a))/((b-c)^3*sqrt(a))-2*a*sqrt(a+b*x)/((b-c)^3*x^2)-(2*b+3*c)*sqrt(a+b*x)/((b-c)^3*x)+2*a*sqrt(a+c*x)/((b-c)^3*x^2)+(3*b+2*c)*sqrt(a+c*x)/((b-c)^3*x)
+--R 
+--R
+--R   (2)
+--R                       +-------+                  +-------+
+--R               2      \|c x + a           2      \|b x + a
+--R       - 3b c x atanh(----------) + 3b c x atanh(----------)
+--R                          +-+                        +-+
+--R                         \|a                        \|a
+--R     + 
+--R                           +-+ +-------+                     +-+ +-------+
+--R       ((- 2c - 3b)x - 2a)\|a \|c x + a  + ((3c + 2b)x + 2a)\|a \|b x + a
+--R  /
+--R       3       2     2     3  2 +-+
+--R     (c  - 3b c  + 3b c - b )x \|a
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 1004
+r0b:=b^2*atanh(sqrt(a+b*x)/sqrt(a))/((b-c)^3*sqrt(a))-b*(b+3*c)*atanh(sqrt(a+b*x)/sqrt(a))/((b-c)^3*sqrt(a))-c^2*atanh(sqrt(a+c*x)/sqrt(a))/((b-c)^3*sqrt(a))+c*(3*b+c)*atanh(sqrt(a+c*x)/sqrt(a))/((b-c)^3*sqrt(a))-2*a*sqrt(a+b*x)/((b-c)^3*x^2)-b*sqrt(a+b*x)/((b-c)^3*x)-(b+3*c)*sqrt(a+b*x)/((b-c)^3*x)+2*a*sqrt(a+c*x)/((b-c)^3*x^2)+c*sqrt(a+c*x)/((b-c)^3*x)+(3*b+c)*sqrt(a+c*x)/((b-c)^3*x)
+--R 
+--R
+--R   (3)
+--R                       +-------+                  +-------+
+--R               2      \|c x + a           2      \|b x + a
+--R       - 3b c x atanh(----------) + 3b c x atanh(----------)
+--R                          +-+                        +-+
+--R                         \|a                        \|a
+--R     + 
+--R                           +-+ +-------+                     +-+ +-------+
+--R       ((- 2c - 3b)x - 2a)\|a \|c x + a  + ((3c + 2b)x + 2a)\|a \|b x + a
+--R  /
+--R       3       2     2     3  2 +-+
+--R     (c  - 3b c  + 3b c - b )x \|a
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 1004
+--a0:=integrate(t0,x)
+--E 165
+
+--S 166 of 1004
+--m0:=a0-r0
+--E 166
+
+--S 167 of 1004
+--d0:=normalize(D(m0,x))
+--E 167
+
+)clear all
+
+--S 168 of 1004
+t0:=x^3*(sqrt(1-x)+sqrt(1+x))^2
+--R 
+--R
+--R          3 +-------+ +-----+     3
+--R   (1)  2x \|- x + 1 \|x + 1  + 2x
+--R                                                    Type: Expression(Integer)
+--E 168
+
+--S 169 of 1004
+r0:=1/2*x^4-2/3*(1-x^2)^(3/2)+2/5*(1-x^2)^(5/2)
+--R 
+--R
+--R                         +--------+
+--R            4     2      |   2           4
+--R        (12x  - 4x  - 8)\|- x  + 1  + 15x
+--R   (2)  ----------------------------------
+--R                        30
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4     2      +-------+ +-----+      4
+--R        (12x  - 4x  - 8)\|- x + 1 \|x + 1  + 15x
+--R   (3)  -----------------------------------------
+--R                            30
+--R                                         Type: Union(Expression(Integer),...)
+--E 170
+
+--S 171 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                                                              +--------+
+--R           4     2      +-------+ +-----+        4     2      |   2
+--R        (6x  - 2x  - 4)\|- x + 1 \|x + 1  + (- 6x  + 2x  + 4)\|- x  + 1
+--R   (4)  ----------------------------------------------------------------
+--R                                       15
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                                      +--------+
+--R           5     3  +-------+ +-----+        5     3  |   2
+--R        (2x  - 2x )\|- x + 1 \|x + 1  + (- 2x  + 2x )\|- x  + 1
+--R   (5)  --------------------------------------------------------
+--R                       +--------+
+--R                       |   2      +-------+ +-----+
+--R                      \|- x  + 1 \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 172
+
+)clear all
+
+--S 173 of 1004
+t0:=x^2*(sqrt(1-x)+sqrt(1+x))^2
+--R 
+--R
+--R          2 +-------+ +-----+     2
+--R   (1)  2x \|- x + 1 \|x + 1  + 2x
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 1004
+r0:=2/3*x^3+1/4*asin(x)-1/4*x*sqrt(1-x^2)+1/2*x^3*sqrt(1-x^2)
+--R 
+--R
+--R                   +--------+
+--R           3       |   2                     3
+--R        (6x  - 3x)\|- x  + 1  + 3asin(x) + 8x
+--R   (2)  --------------------------------------
+--R                          12
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 1004
+--a0:=integrate(t0,x)
+--E 175
+
+--S 176 of 1004
+--m0:=a0-r0
+--E 176
+
+--S 177 of 1004
+--d0:=normalize(D(m0,x))
+--E 177
+
+)clear all
+
+--S 178 of 1004
+t0:=x*(sqrt(1-x)+sqrt(1+x))^2
+--R 
+--R
+--R           +-------+ +-----+
+--R   (1)  2x\|- x + 1 \|x + 1  + 2x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 1004
+r0:=x^2-2/3*(1-x^2)^(3/2)
+--R 
+--R
+--R                  +--------+
+--R           2      |   2          2
+--R        (2x  - 2)\|- x  + 1  + 3x
+--R   (2)  --------------------------
+--R                     3
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2      +-------+ +-----+     2
+--R        (2x  - 2)\|- x + 1 \|x + 1  + 3x
+--R   (3)  ---------------------------------
+--R                        3
+--R                                         Type: Union(Expression(Integer),...)
+--E 180
+
+--S 181 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                                                  +--------+
+--R           2      +-------+ +-----+        2      |   2
+--R        (2x  - 2)\|- x + 1 \|x + 1  + (- 2x  + 2)\|- x  + 1
+--R   (4)  ----------------------------------------------------
+--R                                  3
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                                    +--------+
+--R           3       +-------+ +-----+        3       |   2
+--R        (2x  - 2x)\|- x + 1 \|x + 1  + (- 2x  + 2x)\|- x  + 1
+--R   (5)  ------------------------------------------------------
+--R                      +--------+
+--R                      |   2      +-------+ +-----+
+--R                     \|- x  + 1 \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 182
+
+)clear all
+
+--S 183 of 1004
+t0:=(sqrt(1-x)+sqrt(1+x))^2
+--R 
+--R
+--R          +-------+ +-----+
+--R   (1)  2\|- x + 1 \|x + 1  + 2
+--R                                                    Type: Expression(Integer)
+--E 183
+
+--S 184 of 1004
+r0:=2*x+asin(x)+x*sqrt(1-x^2)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R   (2)  x\|- x  + 1  + asin(x) + 2x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 1004
+--a0:=integrate(t0,x)
+--E 185
+
+--S 186 of 1004
+--m0:=a0-r0
+--E 186
+
+--S 187 of 1004
+--d0:=normalize(D(m0,x))
+--E 187
+
+)clear all
+
+--S 188 of 1004
+t0:=(sqrt(1-x)+sqrt(1+x))^2/x
+--R 
+--R
+--R          +-------+ +-----+
+--R        2\|- x + 1 \|x + 1  + 2
+--R   (1)  -----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 1004
+r0:=-2*atanh(sqrt(1-x^2))+2*log(x)+2*sqrt(1-x^2)
+--R 
+--R
+--R                  +--------+      +--------+
+--R                  |   2           |   2
+--R   (2)  - 2atanh(\|- x  + 1 ) + 2\|- x  + 1  + 2log(x)
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +-------+ +-----+
+--R               - \|- x + 1 \|x + 1  - 1      +-------+ +-----+
+--R   (3)  - 2log(------------------------) + 2\|- x + 1 \|x + 1
+--R                           2
+--R                          x
+--R                                         Type: Union(Expression(Integer),...)
+--E 190
+
+--S 191 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-------+ +-----+                +--------+
+--R            - \|- x + 1 \|x + 1  - 1            |   2
+--R     - 2log(------------------------) + 2atanh(\|- x  + 1 )
+--R                        2
+--R                       x
+--R   + 
+--R                             +--------+
+--R       +-------+ +-----+     |   2
+--R     2\|- x + 1 \|x + 1  - 2\|- x  + 1  - 2log(x)
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      +--------+                                            +--------+
+--R      |   2          2      +-------+ +-----+        2      |   2          2
+--R   (2\|- x  + 1  + 2x  - 2)\|- x + 1 \|x + 1  + (- 2x  + 2)\|- x  + 1  + 2x  - 2
+--R   -----------------------------------------------------------------------------
+--R                     +--------+                       +--------+
+--R                     |   2      +-------+ +-----+     |   2
+--R                   x\|- x  + 1 \|- x + 1 \|x + 1  + x\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 1004
+t0:=(sqrt(1-x)+sqrt(1+x))^2/x^2
+--R 
+--R
+--R          +-------+ +-----+
+--R        2\|- x + 1 \|x + 1  + 2
+--R   (1)  -----------------------
+--R                    2
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 1004
+r0:=(-2)/x-2*asin(x)-2*sqrt(1-x^2)/x
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R        - 2\|- x  + 1  - 2x asin(x) - 2
+--R   (2)  -------------------------------
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 1004
+--a0:=integrate(t0,x)
+--E 195
+
+--S 196 of 1004
+--m0:=a0-r0
+--E 196
+
+--S 197 of 1004
+--d0:=normalize(D(m0,x))
+--E 197
+
+)clear all
+
+--S 198 of 1004
+t0:=(sqrt(1-x)+sqrt(1+x))^2/x^3
+--R 
+--R
+--R          +-------+ +-----+
+--R        2\|- x + 1 \|x + 1  + 2
+--R   (1)  -----------------------
+--R                    3
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 198
+
+--S 199 of 1004
+r0:=(-1)/x^2+atanh(sqrt(1-x^2))-sqrt(1-x^2)/x^2
+--R 
+--R
+--R                 +--------+     +--------+
+--R         2       |   2          |   2
+--R        x atanh(\|- x  + 1 ) - \|- x  + 1  - 1
+--R   (2)  --------------------------------------
+--R                           2
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     +-------+ +-----+
+--R             2    - \|- x + 1 \|x + 1  + 1       +-------+ +-----+     2
+--R        - 16x log(------------------------) - 16\|- x + 1 \|x + 1  + 3x  - 16
+--R                              x
+--R   (3)  ---------------------------------------------------------------------
+--R                                            2
+--R                                         16x
+--R                                         Type: Union(Expression(Integer),...)
+--E 200
+
+--S 201 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    +-------+ +-----+                   +--------+
+--R            2    - \|- x + 1 \|x + 1  + 1       2       |   2
+--R       - 16x log(------------------------) - 16x atanh(\|- x  + 1 )
+--R                             x
+--R     + 
+--R                                   +--------+
+--R            +-------+ +-----+      |   2          2
+--R       - 16\|- x + 1 \|x + 1  + 16\|- x  + 1  + 3x
+--R  /
+--R        2
+--R     16x
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                +--------+
+--R          +-------+ +-----+     |   2
+--R        2\|- x + 1 \|x + 1  - 2\|- x  + 1
+--R   (5)  ----------------------------------
+--R                         3
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+)clear all
+
+--S 203 of 1004
+t0:=sqrt(1-x)*(sqrt(1-x)+sqrt(1+x))
+--R 
+--R
+--R         +-------+ +-----+
+--R   (1)  \|- x + 1 \|x + 1  - x + 1
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 1004
+r0:=x-1/2*x^2+1/2*asin(x)+1/2*x*sqrt(1-x^2)
+--R 
+--R
+--R          +--------+
+--R          |   2                   2
+--R        x\|- x  + 1  + asin(x) - x  + 2x
+--R   (2)  --------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 1004
+--a0:=integrate(t0,x)
+--E 205
+
+--S 206 of 1004
+--m0:=a0-r0
+--E 206
+
+--S 207 of 1004
+--d0:=normalize(D(m0,x))
+--E 207
+
+)clear all
+
+--S 208 of 1004
+t0:=x^3*(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))
+--R 
+--R
+--R            3 +-------+ +-----+     3
+--R   (1)  - 2x \|- x + 1 \|x + 1  - 2x
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 1004
+r0:=-1/2*x^4+2/3*(1-x^2)^(3/2)-2/5*(1-x^2)^(5/2)
+--R 
+--R
+--R                           +--------+
+--R              4     2      |   2           4
+--R        (- 12x  + 4x  + 8)\|- x  + 1  - 15x
+--R   (2)  ------------------------------------
+--R                         30
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R              4     2      +-------+ +-----+      4
+--R        (- 12x  + 4x  + 8)\|- x + 1 \|x + 1  - 15x
+--R   (3)  -------------------------------------------
+--R                             30
+--R                                         Type: Union(Expression(Integer),...)
+--E 210
+
+--S 211 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                                                              +--------+
+--R             4     2      +-------+ +-----+      4     2      |   2
+--R        (- 6x  + 2x  + 4)\|- x + 1 \|x + 1  + (6x  - 2x  - 4)\|- x  + 1
+--R   (4)  ----------------------------------------------------------------
+--R                                       15
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                                      +--------+
+--R             5     3  +-------+ +-----+      5     3  |   2
+--R        (- 2x  + 2x )\|- x + 1 \|x + 1  + (2x  - 2x )\|- x  + 1
+--R   (5)  --------------------------------------------------------
+--R                       +--------+
+--R                       |   2      +-------+ +-----+
+--R                      \|- x  + 1 \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 212
+
+)clear all
+
+--S 213 of 1004
+t0:=x^2*(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))
+--R 
+--R
+--R            2 +-------+ +-----+     2
+--R   (1)  - 2x \|- x + 1 \|x + 1  - 2x
+--R                                                    Type: Expression(Integer)
+--E 213
+
+--S 214 of 1004
+r0:=-2/3*x^3-1/4*asin(x)+1/4*x*sqrt(1-x^2)-1/2*x^3*sqrt(1-x^2)
+--R 
+--R
+--R                     +--------+
+--R             3       |   2                     3
+--R        (- 6x  + 3x)\|- x  + 1  - 3asin(x) - 8x
+--R   (2)  ----------------------------------------
+--R                           12
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 1004
+--a0:=integrate(t0,x)
+--E 215
+
+--S 216 of 1004
+--m0:=a0-r0
+--E 216
+
+--S 217 of 1004
+--d0:=normalize(D(m0,x))
+--E 217
+
+)clear all
+
+--S 218 of 1004
+t0:=x*(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))
+--R 
+--R
+--R             +-------+ +-----+
+--R   (1)  - 2x\|- x + 1 \|x + 1  - 2x
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 1004
+r0:=-x^2+2/3*(1-x^2)^(3/2)
+--R 
+--R
+--R                    +--------+
+--R             2      |   2          2
+--R        (- 2x  + 2)\|- x  + 1  - 3x
+--R   (2)  ----------------------------
+--R                      3
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2      +-------+ +-----+     2
+--R        (- 2x  + 2)\|- x + 1 \|x + 1  - 3x
+--R   (3)  -----------------------------------
+--R                         3
+--R                                         Type: Union(Expression(Integer),...)
+--E 220
+
+--S 221 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                                                  +--------+
+--R             2      +-------+ +-----+      2      |   2
+--R        (- 2x  + 2)\|- x + 1 \|x + 1  + (2x  - 2)\|- x  + 1
+--R   (4)  ----------------------------------------------------
+--R                                  3
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                                    +--------+
+--R             3       +-------+ +-----+      3       |   2
+--R        (- 2x  + 2x)\|- x + 1 \|x + 1  + (2x  - 2x)\|- x  + 1
+--R   (5)  ------------------------------------------------------
+--R                      +--------+
+--R                      |   2      +-------+ +-----+
+--R                     \|- x  + 1 \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 1004
+t0:=(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))
+--R 
+--R
+--R            +-------+ +-----+
+--R   (1)  - 2\|- x + 1 \|x + 1  - 2
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 1004
+r0:=-2*x-asin(x)-x*sqrt(1-x^2)
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R   (2)  - x\|- x  + 1  - asin(x) - 2x
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 1004
+--a0:=integrate(t0,x)
+--E 225
+
+--S 226 of 1004
+--m0:=a0-r0
+--E 226
+
+--S 227 of 1004
+--d0:=normalize(D(m0,x))
+--E 227
+
+)clear all
+
+--S 228 of 1004
+t0:=(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))/x
+--R 
+--R
+--R            +-------+ +-----+
+--R        - 2\|- x + 1 \|x + 1  - 2
+--R   (1)  -------------------------
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 228
+
+--S 229 of 1004
+r0:=2*atanh(sqrt(1-x^2))-2*log(x)-2*sqrt(1-x^2)
+--R 
+--R
+--R                +--------+      +--------+
+--R                |   2           |   2
+--R   (2)  2atanh(\|- x  + 1 ) - 2\|- x  + 1  - 2log(x)
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +-------+ +-----+          +-------+ +-----+
+--R   (3)  - 2log(\|- x + 1 \|x + 1  - 1) - 2\|- x + 1 \|x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 230
+
+--S 231 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              +--------+
+--R             +-------+ +-----+                |   2           +-------+ +-----+
+--R     - 2log(\|- x + 1 \|x + 1  - 1) - 2atanh(\|- x  + 1 ) - 2\|- x + 1 \|x + 1
+--R   + 
+--R       +--------+
+--R       |   2
+--R     2\|- x  + 1  + 2log(x)
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R      +--------+                                          +--------+
+--R      |   2          2      +-------+ +-----+      2      |   2          2
+--R   (2\|- x  + 1  - 2x  + 2)\|- x + 1 \|x + 1  + (2x  - 2)\|- x  + 1  + 2x  - 2
+--R   ---------------------------------------------------------------------------
+--R                    +--------+                       +--------+
+--R                    |   2      +-------+ +-----+     |   2
+--R                  x\|- x  + 1 \|- x + 1 \|x + 1  - x\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 232
+
+)clear all
+
+--S 233 of 1004
+t0:=(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))/x^2
+--R 
+--R
+--R            +-------+ +-----+
+--R        - 2\|- x + 1 \|x + 1  - 2
+--R   (1)  -------------------------
+--R                     2
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 1004
+r0:=2/x+2*asin(x)+2*sqrt(1-x^2)/x
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        2\|- x  + 1  + 2x asin(x) + 2
+--R   (2)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 1004
+--a0:=integrate(t0,x)
+--E 235
+
+--S 236 of 1004
+--m0:=a0-r0
+--E 236
+
+--S 237 of 1004
+--d0:=normalize(D(m0,x))
+--E 237
+
+)clear all
+
+--S 238 of 1004
+t0:=(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))/x^3
+--R 
+--R
+--R            +-------+ +-----+
+--R        - 2\|- x + 1 \|x + 1  - 2
+--R   (1)  -------------------------
+--R                     3
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 1004
+r0:=1/x^2-atanh(sqrt(1-x^2))+sqrt(1-x^2)/x^2
+--R 
+--R
+--R                   +--------+     +--------+
+--R           2       |   2          |   2
+--R        - x atanh(\|- x  + 1 ) + \|- x  + 1  + 1
+--R   (2)  ----------------------------------------
+--R                            2
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +-------+ +-----+
+--R             2    \|- x + 1 \|x + 1  + 1       +-------+ +-----+      2
+--R        - 32x log(----------------------) + 32\|- x + 1 \|x + 1  - 21x  + 32
+--R                             x
+--R   (3)  --------------------------------------------------------------------
+--R                                           2
+--R                                        32x
+--R                                         Type: Union(Expression(Integer),...)
+--E 240
+
+--S 241 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +-------+ +-----+                   +--------+
+--R            2    \|- x + 1 \|x + 1  + 1       2       |   2
+--R       - 32x log(----------------------) + 32x atanh(\|- x  + 1 )
+--R                            x
+--R     + 
+--R                                 +--------+
+--R          +-------+ +-----+      |   2           2
+--R       32\|- x + 1 \|x + 1  - 32\|- x  + 1  - 21x
+--R  /
+--R        2
+--R     32x
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                  +--------+
+--R            +-------+ +-----+     |   2
+--R        - 2\|- x + 1 \|x + 1  + 2\|- x  + 1
+--R   (5)  ------------------------------------
+--R                          3
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 242
+
+)clear all
+
+--S 243 of 1004
+t0:=(sqrt(1-x)+sqrt(1+x))/(-sqrt(1-x)+sqrt(1+x))
+--R 
+--R
+--R         +-----+    +-------+
+--R        \|x + 1  + \|- x + 1
+--R   (1)  ---------------------
+--R         +-----+    +-------+
+--R        \|x + 1  - \|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 243
+
+--S 244 of 1004
+r0:=-atanh(sqrt(1-x^2))+log(x)+sqrt(1-x^2)
+--R 
+--R
+--R                 +--------+     +--------+
+--R                 |   2          |   2
+--R   (2)  - atanh(\|- x  + 1 ) + \|- x  + 1  + log(x)
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-------+ +-----+
+--R              - \|- x + 1 \|x + 1  - 1     +-------+ +-----+
+--R   (3)  - log(------------------------) + \|- x + 1 \|x + 1
+--R                          2
+--R                         x
+--R                                         Type: Union(Expression(Integer),...)
+--E 245
+
+--S 246 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-------+ +-----+               +--------+
+--R           - \|- x + 1 \|x + 1  - 1           |   2          +-------+ +-----+
+--R     - log(------------------------) + atanh(\|- x  + 1 ) + \|- x + 1 \|x + 1
+--R                       2
+--R                      x
+--R   + 
+--R        +--------+
+--R        |   2
+--R     - \|- x  + 1  - log(x)
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R     +--------+                                          +--------+
+--R     |   2         2      +-------+ +-----+       2      |   2         2
+--R   (\|- x  + 1  + x  - 1)\|- x + 1 \|x + 1  + (- x  + 1)\|- x  + 1  + x  - 1
+--R   -------------------------------------------------------------------------
+--R                   +--------+                       +--------+
+--R                   |   2      +-------+ +-----+     |   2
+--R                 x\|- x  + 1 \|- x + 1 \|x + 1  + x\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 247
+
+)clear all
+
+--S 248 of 1004
+t0:=(-sqrt(-1+x)+sqrt(1+x))/(sqrt(-1+x)+sqrt(1+x))
+--R 
+--R
+--R         +-----+    +-----+
+--R        \|x + 1  - \|x - 1
+--R   (1)  -------------------
+--R         +-----+    +-----+
+--R        \|x + 1  + \|x - 1
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 1004
+r0a:=1/2*x^2+1/2*acosh(x)-1/2*x*sqrt(-1+x)*sqrt(1+x)
+--R 
+--R
+--R            +-----+ +-----+               2
+--R        - x\|x - 1 \|x + 1  + acosh(x) + x
+--R   (2)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 249
+
+--S 250 of 1004
+r0b:=1/2*x^2+1/2*acosh(x)-1/2*(-1+x)^(3/2)*sqrt(1+x)-1/2*sqrt(-1+x)*sqrt(1+x)
+--R 
+--R
+--R            +-----+ +-----+               2
+--R        - x\|x - 1 \|x + 1  + acosh(x) + x
+--R   (3)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-----+ +-----+          +-----+ +-----+    2
+--R        - log(- \|x - 1 \|x + 1  + x) - x\|x - 1 \|x + 1  + x
+--R   (4)  ------------------------------------------------------
+--R                                   2
+--R                                         Type: Union(Expression(Integer),...)
+--E 251
+
+--S 252 of 1004
+m0a:=a0-r0a
+--R 
+--R
+--R                 +-----+ +-----+
+--R        - log(- \|x - 1 \|x + 1  + x) - acosh(x)
+--R   (5)  ----------------------------------------
+--R                            2
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 1004
+d0a:=D(m0a,x)
+--R 
+--R
+--R         +------+
+--R         | 2         +-----+ +-----+
+--R        \|x  - 1  - \|x - 1 \|x + 1
+--R   (6)  ----------------------------
+--R                           +------+
+--R           +-----+ +-----+ | 2
+--R         2\|x - 1 \|x + 1 \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 1004
+m0b:=a0-r0b
+--R 
+--R
+--R                 +-----+ +-----+
+--R        - log(- \|x - 1 \|x + 1  + x) - acosh(x)
+--R   (7)  ----------------------------------------
+--R                            2
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 1004
+d0b:=D(m0b,x)
+--R 
+--R
+--R         +------+
+--R         | 2         +-----+ +-----+
+--R        \|x  - 1  - \|x - 1 \|x + 1
+--R   (8)  ----------------------------
+--R                           +------+
+--R           +-----+ +-----+ | 2
+--R         2\|x - 1 \|x + 1 \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 1004
+t0:=x^m*sqrt(a*x^n)
+--R 
+--R
+--R           +----+
+--R         m |   n
+--R   (1)  x \|a x
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 1004
+r0:=2*x^(1+m)*sqrt(a*x^n)/(2+2*m+n)
+--R 
+--R
+--R                +----+
+--R          m + 1 |   n
+--R        2x     \|a x
+--R   (2)  --------------
+--R          n + 2m + 2
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 1004
+--a0:=integrate(t0,x)
+--E 258
+
+--S 259 of 1004
+--m0:=a0-r0
+--E 259
+
+--S 260 of 1004
+--d0:=normalize(D(m0,x))
+--E 260
+
+)clear all
+
+--S 261 of 1004
+t0:=x^(-1-1/2*n)*sqrt(a*x^n)
+--R 
+--R
+--R         - n - 2
+--R         ------- +----+
+--R            2    |   n
+--R   (1)  x       \|a x
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 1004
+r0:=log(x)*sqrt(a*x^n)/x^(1/2*n)
+--R 
+--R
+--R               +----+
+--R               |   n
+--R        log(x)\|a x
+--R   (2)  -------------
+--R               n
+--R               -
+--R               2
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+
+--R   (3)  log(x)\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 263
+
+--S 264 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                                 n
+--R                 +----+          -
+--R                 |   n           2 +-+
+--R        - log(x)\|a x   + log(x)x \|a
+--R   (4)  ------------------------------
+--R                       n
+--R                       -
+--R                       2
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +---------------+
+--R             |     n log(x) 2        n log(x)
+--R             |     --------          --------
+--R         +-+ |         2                 2
+--R        \|a \|a (%e        )   - a %e
+--R   (5)  -------------------------------------
+--R                   +---------------+
+--R                   |     n log(x) 2
+--R                   |     --------
+--R                   |         2
+--R                 x\|a (%e        )
+--R                                                    Type: Expression(Integer)
+--E 265
+
+)clear all
+
+--S 266 of 1004
+t0:=x^2*sqrt(a*x^n)
+--R 
+--R
+--R           +----+
+--R         2 |   n
+--R   (1)  x \|a x
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1004
+r0:=2*x^3*sqrt(a*x^n)/(6+n)
+--R 
+--R
+--R            +----+
+--R          3 |   n
+--R        2x \|a x
+--R   (2)  ----------
+--R           n + 6
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 1004
+--a0:=integrate(t0,x)
+--E 268
+
+--S 269 of 1004
+--m0:=a0-r0
+--E 269
+
+--S 270 of 1004
+--d0:=normalize(D(m0,x))
+--E 270
+
+)clear all
+
+--S 271 of 1004
+t0:=x*sqrt(a*x^n)
+--R 
+--R
+--R          +----+
+--R          |   n
+--R   (1)  x\|a x
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 1004
+r0:=2*x^2*sqrt(a*x^n)/(4+n)
+--R 
+--R
+--R            +----+
+--R          2 |   n
+--R        2x \|a x
+--R   (2)  ----------
+--R           n + 4
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 1004
+--a0:=integrate(t0,x)
+--E 273
+
+--S 274 of 1004
+--m0:=a0-r0
+--E 274
+
+--S 275 of 1004
+--d0:=normalize(D(m0,x))
+--E 275
+
+)clear all
+
+--S 276 of 1004
+t0:=sqrt(a*x^n)
+--R 
+--R
+--R         +----+
+--R         |   n
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 1004
+r0:=2*x*sqrt(a*x^n)/(2+n)
+--R 
+--R
+--R           +----+
+--R           |   n
+--R        2x\|a x
+--R   (2)  ---------
+--R          n + 2
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 1004
+--a0:=integrate(t0,x)
+--E 278
+
+--S 279 of 1004
+--m0:=a0-r0
+--E 279
+
+--S 280 of 1004
+--d0:=normalize(D(m0,x))
+--E 280
+
+)clear all
+
+--S 281 of 1004
+t0:=sqrt(a*x^n)/x
+--R 
+--R
+--R         +----+
+--R         |   n
+--R        \|a x
+--R   (1)  -------
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 1004
+r0:=2*sqrt(a*x^n)/n
+--R 
+--R
+--R          +----+
+--R          |   n
+--R        2\|a x
+--R   (2)  --------
+--R            n
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +------------+
+--R          |    n log(x)
+--R        2\|a %e
+--R   (3)  ----------------
+--R                n
+--R                                         Type: Union(Expression(Integer),...)
+--E 283
+
+--S 284 of 1004
+m0:=a0-r0
+--R 
+--R
+--R          +------------+     +----+
+--R          |    n log(x)      |   n
+--R        2\|a %e          - 2\|a x
+--R   (4)  ---------------------------
+--R                     n
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 1004
+t0:=sqrt(a*x^n)/x^2
+--R 
+--R
+--R         +----+
+--R         |   n
+--R        \|a x
+--R   (1)  -------
+--R            2
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 1004
+r0:=-2*sqrt(a*x^n)/((2-n)*x)
+--R 
+--R
+--R          +----+
+--R          |   n
+--R        2\|a x
+--R   (2)  --------
+--R        (n - 2)x
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 1004
+--a0:=integrate(t0,x)
+--E 288
+
+--S 289 of 1004
+--m0:=a0-r0
+--E 289
+
+--S 290 of 1004
+--d0:=normalize(D(m0,x))
+--E 290
+
+)clear all
+
+--S 291 of 1004
+t0:=sqrt(a*x^n)/x^3
+--R 
+--R
+--R         +----+
+--R         |   n
+--R        \|a x
+--R   (1)  -------
+--R            3
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 1004
+r0:=-2*sqrt(a*x^n)/((4-n)*x^2)
+--R 
+--R
+--R           +----+
+--R           |   n
+--R         2\|a x
+--R   (2)  ---------
+--R                2
+--R        (n - 4)x
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 1004
+--a0:=integrate(t0,x)
+--E 293
+
+--S 294 of 1004
+--m0:=a0-r0
+--E 294
+
+--S 295 of 1004
+--d0:=normalize(D(m0,x))
+--E 295
+
+)clear all
+
+--S 296 of 1004
+t0:=x^m*(a*x^n)^(3/2)
+--R 
+--R
+--R               +----+
+--R           m n |   n
+--R   (1)  a x x \|a x
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1004
+r0:=2*a*x^(1+m+n)*sqrt(a*x^n)/(2+2*m+3*n)
+--R 
+--R
+--R                      +----+
+--R            n + m + 1 |   n
+--R        2a x         \|a x
+--R   (2)  --------------------
+--R             3n + 2m + 2
+--R                                                    Type: Expression(Integer)
+--E 297
+
+--S 298 of 1004
+--a0:=integrate(t0,x)
+--E 298
+
+--S 299 of 1004
+--m0:=a0-r0
+--E 299
+
+--S 300 of 1004
+--d0:=normalize(D(m0,x))
+--E 300
+
+)clear all
+
+--S 301 of 1004
+t0:=x^(-1-3/2*n)*(a*x^n)^(3/2)
+--R 
+--R
+--R           - 3n - 2
+--R           --------   +----+
+--R               2    n |   n
+--R   (1)  a x        x \|a x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1004
+r0:=a*log(x)*sqrt(a*x^n)/x^(1/2*n)
+--R 
+--R
+--R                 +----+
+--R                 |   n
+--R        a log(x)\|a x
+--R   (2)  ---------------
+--R                n
+--R                -
+--R                2
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-+
+--R   (3)  a log(x)\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 303
+
+--S 304 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                                     n
+--R                   +----+            -
+--R                   |   n             2 +-+
+--R        - a log(x)\|a x   + a log(x)x \|a
+--R   (4)  ----------------------------------
+--R                         n
+--R                         -
+--R                         2
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +---------------+
+--R              |     n log(x) 2        n log(x)
+--R              |     --------          --------
+--R          +-+ |         2          2      2
+--R        a\|a \|a (%e        )   - a %e
+--R   (5)  --------------------------------------
+--R                    +---------------+
+--R                    |     n log(x) 2
+--R                    |     --------
+--R                    |         2
+--R                  x\|a (%e        )
+--R                                                    Type: Expression(Integer)
+--E 305
+
+)clear all
+
+--S 306 of 1004
+t0:=x^2*(a*x^n)^(3/2)
+--R 
+--R
+--R               +----+
+--R           2 n |   n
+--R   (1)  a x x \|a x
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 1004
+r0:=2/3*a*x^(3+n)*sqrt(a*x^n)/(2+n)
+--R 
+--R
+--R                  +----+
+--R            n + 3 |   n
+--R        2a x     \|a x
+--R   (2)  ----------------
+--R             3n + 6
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 1004
+--a0:=integrate(t0,x)
+--E 308
+
+--S 309 of 1004
+--m0:=a0-r0
+--E 309
+
+--S 310 of 1004
+--d0:=normalize(D(m0,x))
+--E 310
+
+)clear all
+
+--S 311 of 1004
+t0:=x*(a*x^n)^(3/2)
+--R 
+--R
+--R               +----+
+--R             n |   n
+--R   (1)  a x x \|a x
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 1004
+r0:=2*a*x^(2+n)*sqrt(a*x^n)/(4+3*n)
+--R 
+--R
+--R                  +----+
+--R            n + 2 |   n
+--R        2a x     \|a x
+--R   (2)  ----------------
+--R             3n + 4
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 1004
+--a0:=integrate(t0,x)
+--E 313
+
+--S 314 of 1004
+--m0:=a0-r0
+--E 314
+
+--S 315 of 1004
+--d0:=normalize(D(m0,x))
+--E 315
+
+)clear all
+
+--S 316 of 1004
+t0:=(a*x^n)^(3/2)
+--R 
+--R
+--R             +----+
+--R           n |   n
+--R   (1)  a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 1004
+r0:=2*a*x^(1+n)*sqrt(a*x^n)/(2+3*n)
+--R 
+--R
+--R                  +----+
+--R            n + 1 |   n
+--R        2a x     \|a x
+--R   (2)  ----------------
+--R             3n + 2
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 1004
+--a0:=integrate(t0,x)
+--E 318
+
+--S 319 of 1004
+--m0:=a0-r0
+--E 319
+
+--S 320 of 1004
+--d0:=normalize(D(m0,x))
+--E 320
+
+)clear all
+
+--S 321 of 1004
+t0:=(a*x^n)^(3/2)/x
+--R 
+--R
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R   (1)  -----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 1004
+r0:=2/3*a*x^n*sqrt(a*x^n)/n
+--R 
+--R
+--R              +----+
+--R            n |   n
+--R        2a x \|a x
+--R   (2)  ------------
+--R             3n
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +------------+
+--R             n log(x) |    n log(x)
+--R        2a %e        \|a %e
+--R   (3)  ----------------------------
+--R                     3n
+--R                                         Type: Union(Expression(Integer),...)
+--E 323
+
+--S 324 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                      +------------+         +----+
+--R             n log(x) |    n log(x)        n |   n
+--R        2a %e        \|a %e          - 2a x \|a x
+--R   (4)  -------------------------------------------
+--R                             3n
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 325
+
+)clear all
+
+--S 326 of 1004
+t0:=(a*x^n)^(3/2)/x^2
+--R 
+--R
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R   (1)  -----------
+--R              2
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 1004
+r0:=-2*a*x^(-1+n)*sqrt(a*x^n)/(2-3*n)
+--R 
+--R
+--R                  +----+
+--R            n - 1 |   n
+--R        2a x     \|a x
+--R   (2)  ----------------
+--R             3n - 2
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 1004
+--a0:=integrate(t0,x)
+--E 328
+
+--S 329 of 1004
+--m0:=a0-r0
+--E 329
+
+--S 330 of 1004
+--d0:=normalize(D(m0,x))
+--E 330
+
+)clear all
+
+--S 331 of 1004
+t0:=(a*x^n)^(3/2)/x^3
+--R 
+--R
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R   (1)  -----------
+--R              3
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 1004
+r0:=-2*a*x^(-2+n)*sqrt(a*x^n)/(4-3*n)
+--R 
+--R
+--R                  +----+
+--R            n - 2 |   n
+--R        2a x     \|a x
+--R   (2)  ----------------
+--R             3n - 4
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 1004
+--a0:=integrate(t0,x)
+--E 333
+
+--S 334 of 1004
+--m0:=a0-r0
+--E 334
+
+--S 335 of 1004
+--d0:=normalize(D(m0,x))
+--E 335
+
+)clear all
+
+--S 336 of 1004
+t0:=sqrt(a*x^3)
+--R 
+--R
+--R         +----+
+--R         |   3
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 1004
+r0:=2/5*x*sqrt(a*x^3)
+--R 
+--R
+--R           +----+
+--R           |   3
+--R        2x\|a x
+--R   (2)  ---------
+--R            5
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 +---+
+--R        2x \|a x
+--R   (3)  ---------
+--R            5
+--R                                         Type: Union(Expression(Integer),...)
+--E 338
+
+--S 339 of 1004
+m0:=a0-r0
+--R 
+--R
+--R             +----+
+--R             |   3      2 +---+
+--R        - 2x\|a x   + 2x \|a x
+--R   (4)  -----------------------
+--R                   5
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +----+
+--R           2 |   3       3 +---+
+--R        a x \|a x   - a x \|a x
+--R   (5)  ------------------------
+--R                     +----+
+--R               +---+ |   3
+--R              \|a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 340
+
+)clear all
+
+--S 341 of 1004
+t0:=sqrt(a*x^2)
+--R 
+--R
+--R         +----+
+--R         |   2
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 1004
+r0:=1/2*x*sqrt(a*x^2)
+--R 
+--R
+--R          +----+
+--R          |   2
+--R        x\|a x
+--R   (2)  --------
+--R            2
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2 +-+
+--R        x \|a
+--R   (3)  ------
+--R           2
+--R                                         Type: Union(Expression(Integer),...)
+--E 343
+
+--S 344 of 1004
+m0:=a0-r0
+--R 
+--R
+--R            +----+
+--R            |   2     2 +-+
+--R        - x\|a x   + x \|a
+--R   (4)  -------------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +----+
+--R          +-+ |   2       2
+--R        x\|a \|a x   - a x
+--R   (5)  -------------------
+--R               +----+
+--R               |   2
+--R              \|a x
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 1004
+t0:=sqrt(a*x)
+--R 
+--R
+--R         +---+
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 1004
+r0:=2/3*(a*x)^(3/2)/a
+--R 
+--R
+--R           +---+
+--R        2x\|a x
+--R   (2)  --------
+--R            3
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           +---+
+--R        2x\|a x
+--R   (3)  --------
+--R            3
+--R                                         Type: Union(Expression(Integer),...)
+--E 348
+
+--S 349 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 350
+
+)clear all
+
+--S 351 of 1004
+t0:=sqrt(a/x)
+--R 
+--R
+--R         +-+
+--R         |a
+--R   (1)   |-
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 1004
+r0:=2*x*sqrt(a/x)
+--R 
+--R
+--R           +-+
+--R           |a
+--R   (2)  2x |-
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2a
+--R   (3)  ----
+--R         +-+
+--R         |a
+--R         |-
+--R        \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 353
+
+--S 354 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+--S 355 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 355
+
+)clear all
+
+--S 356 of 1004
+t0:=sqrt(a/x^2)
+--R 
+--R
+--R         +--+
+--R         | a
+--R   (1)   |--
+--R         | 2
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 1004
+r0:=x*log(x)*sqrt(a/x^2)
+--R 
+--R
+--R                 +--+
+--R                 | a
+--R   (2)  x log(x) |--
+--R                 | 2
+--R                \|x
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+
+--R   (3)  log(x)\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 358
+
+--S 359 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                              +--+
+--R               +-+            | a
+--R   (4)  log(x)\|a  - x log(x) |--
+--R                              | 2
+--R                             \|x
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          +--+
+--R          | a  +-+
+--R        x |-- \|a  - a
+--R          | 2
+--R         \|x
+--R   (5)  --------------
+--R               +--+
+--R             2 | a
+--R            x  |--
+--R               | 2
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 1004
+t0:=sqrt(a/x^3)
+--R 
+--R
+--R         +--+
+--R         | a
+--R   (1)   |--
+--R         | 3
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 1004
+r0:=-2*x*sqrt(a/x^3)
+--R 
+--R
+--R             +--+
+--R             | a
+--R   (2)  - 2x |--
+--R             | 3
+--R            \|x
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +-+
+--R             |a
+--R   (3)  - 2  |-
+--R            \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 363
+
+--S 364 of 1004
+m0:=a0-r0
+--R 
+--R
+--R             +-+     +--+
+--R             |a      | a
+--R   (4)  - 2  |- + 2x |--
+--R            \|x      | 3
+--R                    \|x
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R            +-+       +--+
+--R            |a        | a
+--R        - a |-  + a x |--
+--R           \|x        | 3
+--R                     \|x
+--R   (5)  ------------------
+--R               +--+ +-+
+--R             3 | a  |a
+--R            x  |--  |-
+--R               | 3 \|x
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 365
+
+)clear all
+
+--S 366 of 1004
+t0:=(a*x^3)^(3/2)
+--R 
+--R
+--R             +----+
+--R           3 |   3
+--R   (1)  a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 1004
+r0:=2/11*a*x^4*sqrt(a*x^3)
+--R 
+--R
+--R              +----+
+--R            4 |   3
+--R        2a x \|a x
+--R   (2)  ------------
+--R             11
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5 +---+
+--R        2a x \|a x
+--R   (3)  -----------
+--R             11
+--R                                         Type: Union(Expression(Integer),...)
+--E 368
+
+--S 369 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                +----+
+--R              4 |   3        5 +---+
+--R        - 2a x \|a x   + 2a x \|a x
+--R   (4)  ----------------------------
+--R                     11
+--R                                                    Type: Expression(Integer)
+--E 369
+
+--S 370 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +----+
+--R         2 5 |   3     2 6 +---+
+--R        a x \|a x   - a x \|a x
+--R   (5)  ------------------------
+--R                     +----+
+--R               +---+ |   3
+--R              \|a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 370
+
+)clear all
+
+--S 371 of 1004
+t0:=(a*x^2)^(3/2)
+--R 
+--R
+--R             +----+
+--R           2 |   2
+--R   (1)  a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1004
+r0:=1/4*a*x^3*sqrt(a*x^2)
+--R 
+--R
+--R             +----+
+--R           3 |   2
+--R        a x \|a x
+--R   (2)  -----------
+--R             4
+--R                                                    Type: Expression(Integer)
+--E 372
+
+--S 373 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4 +-+
+--R        a x \|a
+--R   (3)  --------
+--R            4
+--R                                         Type: Union(Expression(Integer),...)
+--E 373
+
+--S 374 of 1004
+m0:=a0-r0
+--R 
+--R
+--R               +----+
+--R             3 |   2       4 +-+
+--R        - a x \|a x   + a x \|a
+--R   (4)  ------------------------
+--R                    4
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R           3 +-+ |   2     2 4
+--R        a x \|a \|a x   - a x
+--R   (5)  ----------------------
+--R                 +----+
+--R                 |   2
+--R                \|a x
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 1004
+t0:=(a*x)^(3/2)
+--R 
+--R
+--R            +---+
+--R   (1)  a x\|a x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1004
+r0:=2/5*(a*x)^(5/2)/a
+--R 
+--R
+--R            2 +---+
+--R        2a x \|a x
+--R   (2)  -----------
+--R             5
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 +---+
+--R        2a x \|a x
+--R   (3)  -----------
+--R             5
+--R                                         Type: Union(Expression(Integer),...)
+--E 378
+
+--S 379 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 380
+
+)clear all
+
+--S 381 of 1004
+t0:=(a/x)^(3/2)
+--R 
+--R
+--R          +-+
+--R          |a
+--R        a |-
+--R         \|x
+--R   (1)  -----
+--R          x
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 1004
+r0:=-2*a*sqrt(a/x)
+--R 
+--R
+--R             +-+
+--R             |a
+--R   (2)  - 2a |-
+--R            \|x
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +-+
+--R             |a
+--R   (3)  - 2a |-
+--R            \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 383
+
+--S 384 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 384
+
+--S 385 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 385
+
+)clear all
+
+--S 386 of 1004
+t0:=(a/x^2)^(3/2)
+--R 
+--R
+--R          +--+
+--R          | a
+--R        a |--
+--R          | 2
+--R         \|x
+--R   (1)  ------
+--R           2
+--R          x
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 1004
+r0:=-1/2*a*sqrt(a/x^2)/x
+--R 
+--R
+--R            +--+
+--R            | a
+--R          a |--
+--R            | 2
+--R           \|x
+--R   (2)  - ------
+--R            2x
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +-+
+--R          a\|a
+--R   (3)  - -----
+--R             2
+--R           2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 388
+
+--S 389 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                      +--+
+--R            +-+       | a
+--R        - a\|a  + a x |--
+--R                      | 2
+--R                     \|x
+--R   (4)  ------------------
+--R                  2
+--R                2x
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +--+
+--R          +-+       | a
+--R        a\|a  - a x |--
+--R                    | 2
+--R                   \|x
+--R   (5)  ----------------
+--R                3
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 1004
+t0:=(a/x^3)^(3/2)
+--R 
+--R
+--R          +--+
+--R          | a
+--R        a |--
+--R          | 3
+--R         \|x
+--R   (1)  ------
+--R           3
+--R          x
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1004
+r0:=-2/7*a*sqrt(a/x^3)/x^2
+--R 
+--R
+--R             +--+
+--R             | a
+--R          2a |--
+--R             | 3
+--R            \|x
+--R   (2)  - -------
+--R              2
+--R            7x
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +-+
+--R             |a
+--R          2a |-
+--R            \|x
+--R   (3)  - ------
+--R              3
+--R            7x
+--R                                         Type: Union(Expression(Integer),...)
+--E 393
+
+--S 394 of 1004
+m0:=a0-r0
+--R 
+--R
+--R             +-+        +--+
+--R             |a         | a
+--R        - 2a |-  + 2a x |--
+--R            \|x         | 3
+--R                       \|x
+--R   (4)  --------------------
+--R                   3
+--R                 7x
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +-+       +--+
+--R           2 |a     2  | a
+--R        - a  |-  + a x |--
+--R            \|x        | 3
+--R                      \|x
+--R   (5)  -------------------
+--R               +--+ +-+
+--R             6 | a  |a
+--R            x  |--  |-
+--R               | 3 \|x
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 395
+
+)clear all
+
+--S 396 of 1004
+t0:=x^m/sqrt(a*x^n)
+--R 
+--R
+--R            m
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   n
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 396
+
+--S 397 of 1004
+r0:=2*x^(1+m)/((2+2*m-n)*sqrt(a*x^n))
+--R 
+--R
+--R                  m + 1
+--R                2x
+--R   (2)  - -------------------
+--R                       +----+
+--R                       |   n
+--R          (n - 2m - 2)\|a x
+--R                                                    Type: Expression(Integer)
+--E 397
+
+-- integrate: implementation incomplete (constant residues)
+--S 398 of 1004
+--a0:=integrate(t0,x)
+--E 398
+
+--S 399 of 1004
+--m0:=a0-r0
+--E 399
+
+--S 400 of 1004
+--d0:=normalize(D(m0,x))
+--E 400
+
+)clear all
+
+--S 401 of 1004
+t0:=x^(-1+1/2*n)/sqrt(a*x^n)
+--R 
+--R
+--R          n - 2
+--R          -----
+--R            2
+--R         x
+--R   (1)  -------
+--R         +----+
+--R         |   n
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 1004
+r0:=x^(1/2*n)*log(x)/sqrt(a*x^n)
+--R 
+--R
+--R               n
+--R               -
+--R               2
+--R        log(x)x
+--R   (2)  --------
+--R          +----+
+--R          |   n
+--R         \|a x
+--R                                                    Type: Expression(Integer)
+--E 402
+
+--S 403 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(x)
+--R   (3)  ------
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 403
+
+--S 404 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                               n
+--R               +----+          -
+--R               |   n           2 +-+
+--R        log(x)\|a x   - log(x)x \|a
+--R   (4)  ----------------------------
+--R                      +----+
+--R                  +-+ |   n
+--R                 \|a \|a x
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +---------------+
+--R             |     n log(x) 2        n log(x)
+--R             |     --------          --------
+--R         +-+ |         2                 2
+--R        \|a \|a (%e        )   - a %e
+--R   (5)  -------------------------------------
+--R                    +---------------+
+--R                    |     n log(x) 2
+--R                    |     --------
+--R                    |         2
+--R                a x\|a (%e        )
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 1004
+t0:=x^2/sqrt(a*x^n)
+--R 
+--R
+--R            2
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   n
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 1004
+r0:=2*x^3/((6-n)*sqrt(a*x^n))
+--R 
+--R
+--R                  3
+--R                2x
+--R   (2)  - --------------
+--R                  +----+
+--R                  |   n
+--R          (n - 6)\|a x
+--R                                                    Type: Expression(Integer)
+--E 407
+
+-- integrate: implementation incomplete (constant residues)
+--S 408 of 1004
+--a0:=integrate(t0,x)
+--E 408
+
+--S 409 of 1004
+--m0:=a0-r0
+--E 409
+
+--S 410 of 1004
+--d0:=normalize(D(m0,x))
+--E 410
+
+)clear all
+
+--S 411 of 1004
+t0:=x/sqrt(a*x^n)
+--R 
+--R
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   n
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 1004
+r0:=2*x^2/((4-n)*sqrt(a*x^n))
+--R 
+--R
+--R                  2
+--R                2x
+--R   (2)  - --------------
+--R                  +----+
+--R                  |   n
+--R          (n - 4)\|a x
+--R                                                    Type: Expression(Integer)
+--E 412
+
+-- integrate: implementation incomplete (constant residues)
+--S 413 of 1004
+--a0:=integrate(t0,x)
+--E 413
+
+--S 414 of 1004
+--m0:=a0-r0
+--E 414
+
+--S 415 of 1004
+--d0:=normalize(D(m0,x))
+--E 415
+
+)clear all
+
+--S 416 of 1004
+t0:=1/sqrt(a*x^n)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R         +----+
+--R         |   n
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 1004
+r0:=2*x/((2-n)*sqrt(a*x^n))
+--R 
+--R
+--R                2x
+--R   (2)  - --------------
+--R                  +----+
+--R                  |   n
+--R          (n - 2)\|a x
+--R                                                    Type: Expression(Integer)
+--E 417
+
+-- integrate: implementation incomplete (constant residues)
+--S 418 of 1004
+--a0:=integrate(t0,x)
+--E 418
+
+--S 419 of 1004
+--m0:=a0-r0
+--E 419
+
+--S 420 of 1004
+--d0:=normalize(D(m0,x))
+--E 420
+
+)clear all
+
+--S 421 of 1004
+t0:=sqrt(a*x^n)/x
+--R 
+--R
+--R         +----+
+--R         |   n
+--R        \|a x
+--R   (1)  -------
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 1004
+r0:=2*sqrt(a*x^n)/n
+--R 
+--R
+--R          +----+
+--R          |   n
+--R        2\|a x
+--R   (2)  --------
+--R            n
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +------------+
+--R          |    n log(x)
+--R        2\|a %e
+--R   (3)  ----------------
+--R                n
+--R                                         Type: Union(Expression(Integer),...)
+--E 423
+
+--S 424 of 1004
+m0:=a0-r0
+--R 
+--R
+--R          +------------+     +----+
+--R          |    n log(x)      |   n
+--R        2\|a %e          - 2\|a x
+--R   (4)  ---------------------------
+--R                     n
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 425
+
+)clear all
+
+--S 426 of 1004
+t0:=sqrt(a*x^n)/x^2
+--R 
+--R
+--R         +----+
+--R         |   n
+--R        \|a x
+--R   (1)  -------
+--R            2
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 1004
+r0:=-2*sqrt(a*x^n)/((2-n)*x)
+--R 
+--R
+--R          +----+
+--R          |   n
+--R        2\|a x
+--R   (2)  --------
+--R        (n - 2)x
+--R                                                    Type: Expression(Integer)
+--E 427
+
+-- integrate: implementation incomplete (constant residues)
+--S 428 of 1004
+--a0:=integrate(t0,x)
+--E 428
+
+--S 429 of 1004
+--m0:=a0-r0
+--E 429
+
+--S 430 of 1004
+--d0:=normalize(D(m0,x))
+--E 430
+
+)clear all
+
+--S 431 of 1004
+t0:=sqrt(a*x^n)/x^3
+--R 
+--R
+--R         +----+
+--R         |   n
+--R        \|a x
+--R   (1)  -------
+--R            3
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1004
+r0:=-2*sqrt(a*x^n)/((4-n)*x^2)
+--R 
+--R
+--R           +----+
+--R           |   n
+--R         2\|a x
+--R   (2)  ---------
+--R                2
+--R        (n - 4)x
+--R                                                    Type: Expression(Integer)
+--E 432
+
+-- integrate: implementation incomplete (constant residues)
+--S 433 of 1004
+--a0:=integrate(t0,x)
+--E 433
+
+--S 434 of 1004
+--m0:=a0-r0
+--E 434
+
+--S 435 of 1004
+--d0:=normalize(D(m0,x))
+--E 435
+
+)clear all
+
+--S 436 of 1004
+t0:=x^m/(a*x^n)^(3/2)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  -----------
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 1004
+r0:=2*x^(1+m-n)/(a*(2+2*m-3*n)*sqrt(a*x^n))
+--R 
+--R
+--R                  - n + m + 1
+--R                2x
+--R   (2)  - -------------------------
+--R                             +----+
+--R                             |   n
+--R          (3a n - 2a m - 2a)\|a x
+--R                                                    Type: Expression(Integer)
+--E 437
+
+-- integrate: implementation incomplete (constant residues)
+--S 438 of 1004
+--a0:=integrate(t0,x)
+--E 438
+
+--S 439 of 1004
+--m0:=a0-r0
+--E 439
+
+--S 440 of 1004
+--d0:=normalize(D(m0,x))
+--E 440
+
+)clear all
+
+--S 441 of 1004
+t0:=x^(-1+3/2*n)/(a*x^n)^(3/2)
+--R 
+--R
+--R           3n - 2
+--R           ------
+--R              2
+--R          x
+--R   (1)  -----------
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 1004
+r0:=x^(1/2*n)*log(x)/(a*sqrt(a*x^n))
+--R 
+--R
+--R               n
+--R               -
+--R               2
+--R        log(x)x
+--R   (2)  --------
+--R          +----+
+--R          |   n
+--R        a\|a x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 1004
+--a0:=integrate(t0,x)
+--E 443
+
+--S 444 of 1004
+--m0:=a0-r0
+--E 444
+
+--S 445 of 1004
+--d0:=normalize(D(m0,x))
+--E 445
+
+)clear all
+
+--S 446 of 1004
+t0:=x^2/(a*x^n)^(3/2)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1004
+r0:=2/3*x^(3-n)/(a*(2-n)*sqrt(a*x^n))
+--R 
+--R
+--R                 - n + 3
+--R               2x
+--R   (2)  - ------------------
+--R                      +----+
+--R                      |   n
+--R          (3a n - 6a)\|a x
+--R                                                    Type: Expression(Integer)
+--E 447
+
+-- integrate: implementation incomplete (constant residues)
+--S 448 of 1004
+--a0:=integrate(t0,x)
+--E 448
+
+--S 449 of 1004
+--m0:=a0-r0
+--E 449
+
+--S 450 of 1004
+--d0:=normalize(D(m0,x))
+--E 450
+
+)clear all
+
+--S 451 of 1004
+t0:=x/(a*x^n)^(3/2)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 1004
+r0:=2*x^(2-n)/(a*(4-3*n)*sqrt(a*x^n))
+--R 
+--R
+--R                 - n + 2
+--R               2x
+--R   (2)  - ------------------
+--R                      +----+
+--R                      |   n
+--R          (3a n - 4a)\|a x
+--R                                                    Type: Expression(Integer)
+--E 452
+
+-- integrate: implementation incomplete (constant residues)
+--S 453 of 1004
+--a0:=integrate(t0,x)
+--E 453
+
+--S 454 of 1004
+--m0:=a0-r0
+--E 454
+
+--S 455 of 1004
+--d0:=normalize(D(m0,x))
+--E 455
+
+)clear all
+
+--S 456 of 1004
+t0:=1/(a*x^n)^(3/2)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 1004
+r0:=2*x^(1-n)/(a*(2-3*n)*sqrt(a*x^n))
+--R 
+--R
+--R                 - n + 1
+--R               2x
+--R   (2)  - ------------------
+--R                      +----+
+--R                      |   n
+--R          (3a n - 2a)\|a x
+--R                                                    Type: Expression(Integer)
+--E 457
+
+-- integrate: implementation incomplete (constant residues)
+--S 458 of 1004
+--a0:=integrate(t0,x)
+--E 458
+
+--S 459 of 1004
+--m0:=a0-r0
+--E 459
+
+--S 460 of 1004
+--d0:=normalize(D(m0,x))
+--E 460
+
+)clear all
+
+--S 461 of 1004
+t0:=(a*x^n)^(3/2)/x
+--R 
+--R
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R   (1)  -----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 1004
+r0:=2/3*a*x^n*sqrt(a*x^n)/n
+--R 
+--R
+--R              +----+
+--R            n |   n
+--R        2a x \|a x
+--R   (2)  ------------
+--R             3n
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +------------+
+--R             n log(x) |    n log(x)
+--R        2a %e        \|a %e
+--R   (3)  ----------------------------
+--R                     3n
+--R                                         Type: Union(Expression(Integer),...)
+--E 463
+
+--S 464 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                      +------------+         +----+
+--R             n log(x) |    n log(x)        n |   n
+--R        2a %e        \|a %e          - 2a x \|a x
+--R   (4)  -------------------------------------------
+--R                             3n
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 1004
+t0:=(a*x^n)^(3/2)/x^2
+--R 
+--R
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R   (1)  -----------
+--R              2
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 1004
+r0:=-2*a*x^(-1+n)*sqrt(a*x^n)/(2-3*n)
+--R 
+--R
+--R                  +----+
+--R            n - 1 |   n
+--R        2a x     \|a x
+--R   (2)  ----------------
+--R             3n - 2
+--R                                                    Type: Expression(Integer)
+--E 467
+
+-- integrate: implementation incomplete (constant residues)
+--S 468 of 1004
+--a0:=integrate(t0,x)
+--E 468
+
+--S 469 of 1004
+--m0:=a0-r0
+--E 469
+
+--S 470 of 1004
+--d0:=normalize(D(m0,x))
+--E 470
+
+)clear all
+
+--S 471 of 1004
+t0:=(a*x^n)^(3/2)/x^3
+--R 
+--R
+--R             +----+
+--R           n |   n
+--R        a x \|a x
+--R   (1)  -----------
+--R              3
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 1004
+r0:=-2*a*x^(-2+n)*sqrt(a*x^n)/(4-3*n)
+--R 
+--R
+--R                  +----+
+--R            n - 2 |   n
+--R        2a x     \|a x
+--R   (2)  ----------------
+--R             3n - 4
+--R                                                    Type: Expression(Integer)
+--E 472
+
+-- integrate: implementation incomplete (constant residues)
+--S 473 of 1004
+--a0:=integrate(t0,x)
+--E 473
+
+--S 474 of 1004
+--m0:=a0-r0
+--E 474
+
+--S 475 of 1004
+--d0:=normalize(D(m0,x))
+--E 475
+
+)clear all
+
+--S 476 of 1004
+t0:=1/sqrt(a*x^3)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R         +----+
+--R         |   3
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 1004
+r0:=-2*x/sqrt(a*x^3)
+--R 
+--R
+--R             2x
+--R   (2)  - -------
+--R           +----+
+--R           |   3
+--R          \|a x
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R   (3)  - ------
+--R           +---+
+--R          \|a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 478
+
+--S 479 of 1004
+m0:=a0-r0
+--R 
+--R
+--R            +----+
+--R            |   3       +---+
+--R        - 2\|a x   + 2x\|a x
+--R   (4)  ---------------------
+--R                   +----+
+--R             +---+ |   3
+--R            \|a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R         +----+
+--R         |   3      +---+
+--R        \|a x   - x\|a x
+--R   (5)  -----------------
+--R                  +----+
+--R            +---+ |   3
+--R          x\|a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 1004
+t0:=1/sqrt(a*x^2)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R         +----+
+--R         |   2
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 1004
+r0:=x*log(x)/sqrt(a*x^2)
+--R 
+--R
+--R        x log(x)
+--R   (2)  --------
+--R          +----+
+--R          |   2
+--R         \|a x
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(x)
+--R   (3)  ------
+--R          +-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 483
+
+--S 484 of 1004
+m0:=a0-r0
+--R 
+--R
+--R               +----+
+--R               |   2             +-+
+--R        log(x)\|a x   - x log(x)\|a
+--R   (4)  ----------------------------
+--R                      +----+
+--R                  +-+ |   2
+--R                 \|a \|a x
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +----+
+--R         +-+ |   2
+--R        \|a \|a x   - a x
+--R   (5)  -----------------
+--R                +----+
+--R                |   2
+--R            a x\|a x
+--R                                                    Type: Expression(Integer)
+--E 485
+
+)clear all
+
+--S 486 of 1004
+t0:=1/sqrt(a*x)
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         +---+
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 1004
+r0:=2*sqrt(a*x)/a
+--R 
+--R
+--R          +---+
+--R        2\|a x
+--R   (2)  -------
+--R           a
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +---+
+--R        2\|a x
+--R   (3)  -------
+--R           a
+--R                                         Type: Union(Expression(Integer),...)
+--E 488
+
+--S 489 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 490
+
+)clear all
+
+--S 491 of 1004
+t0:=1/sqrt(a/x)
+--R 
+--R
+--R          1
+--R   (1)  ----
+--R         +-+
+--R         |a
+--R         |-
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 1004
+r0:=2/3*x/sqrt(a/x)
+--R 
+--R
+--R          2x
+--R   (2)  -----
+--R           +-+
+--R           |a
+--R        3  |-
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 492
+
+--S 493 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2x
+--R   (3)  -----
+--R           +-+
+--R           |a
+--R        3  |-
+--R          \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 493
+
+--S 494 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 1004
+t0:=1/sqrt(a/x^2)
+--R 
+--R
+--R          1
+--R   (1)  -----
+--R         +--+
+--R         | a
+--R         |--
+--R         | 2
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 1004
+r0:=1/2*x/sqrt(a/x^2)
+--R 
+--R
+--R           x
+--R   (2)  ------
+--R          +--+
+--R          | a
+--R        2 |--
+--R          | 2
+--R         \|x
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R          x
+--R   (3)  -----
+--R          +-+
+--R        2\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 498
+
+--S 499 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                     +--+
+--R            +-+    2 | a
+--R        - x\|a  + x  |--
+--R                     | 2
+--R                    \|x
+--R   (4)  -----------------
+--R              +--+
+--R              | a  +-+
+--R            2 |-- \|a
+--R              | 2
+--R             \|x
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          +--+
+--R          | a  +-+
+--R        x |-- \|a  - a
+--R          | 2
+--R         \|x
+--R   (5)  --------------
+--R              +--+
+--R              | a
+--R            a |--
+--R              | 2
+--R             \|x
+--R                                                    Type: Expression(Integer)
+--E 500
+
+)clear all
+
+--S 501 of 1004
+t0:=1/sqrt(a/x^3)
+--R 
+--R
+--R          1
+--R   (1)  -----
+--R         +--+
+--R         | a
+--R         |--
+--R         | 3
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 1004
+r0:=2/5*x/sqrt(a/x^3)
+--R 
+--R
+--R          2x
+--R   (2)  ------
+--R          +--+
+--R          | a
+--R        5 |--
+--R          | 3
+--R         \|x
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R         2x
+--R   (3)  -----
+--R           +-+
+--R           |a
+--R        5  |-
+--R          \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 503
+
+--S 504 of 1004
+m0:=a0-r0
+--R 
+--R
+--R             +-+       +--+
+--R             |a      2 | a
+--R        - 2x |-  + 2x  |--
+--R            \|x        | 3
+--R                      \|x
+--R   (4)  -------------------
+--R               +--+ +-+
+--R               | a  |a
+--R             5 |--  |-
+--R               | 3 \|x
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 504
+
+--S 505 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +-+     +--+
+--R           |a      | a
+--R        -  |-  + x |--
+--R          \|x      | 3
+--R                  \|x
+--R   (5)  ---------------
+--R            +--+ +-+
+--R            | a  |a
+--R            |--  |-
+--R            | 3 \|x
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 505
+
+)clear all
+
+--S 506 of 1004
+t0:=1/(a*x^3)^(3/2)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R             +----+
+--R           3 |   3
+--R        a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 1004
+r0:=(-2/7)/(a*x^2*sqrt(a*x^3))
+--R 
+--R
+--R                2
+--R   (2)  - ------------
+--R                +----+
+--R              2 |   3
+--R          7a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R   (3)  - -----------
+--R              3 +---+
+--R          7a x \|a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 508
+
+--S 509 of 1004
+m0:=a0-r0
+--R 
+--R
+--R            +----+
+--R            |   3       +---+
+--R        - 2\|a x   + 2x\|a x
+--R   (4)  ---------------------
+--R                      +----+
+--R              3 +---+ |   3
+--R          7a x \|a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R         +----+
+--R         |   3      +---+
+--R        \|a x   - x\|a x
+--R   (5)  -----------------
+--R                   +----+
+--R           4 +---+ |   3
+--R        a x \|a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 1004
+t0:=1/(a*x^2)^(3/2)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R             +----+
+--R           2 |   2
+--R        a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 1004
+r0:=(-1/2)/(a*x*sqrt(a*x^2))
+--R 
+--R
+--R               1
+--R   (2)  - -----------
+--R               +----+
+--R               |   2
+--R          2a x\|a x
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R              1
+--R   (3)  - ---------
+--R              2 +-+
+--R          2a x \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 513
+
+--S 514 of 1004
+m0:=a0-r0
+--R 
+--R
+--R           +----+
+--R           |   2      +-+
+--R        - \|a x   + x\|a
+--R   (4)  -----------------
+--R                   +----+
+--R             2 +-+ |   2
+--R         2a x \|a \|a x
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +----+
+--R         +-+ |   2
+--R        \|a \|a x   - a x
+--R   (5)  -----------------
+--R                +----+
+--R            2 3 |   2
+--R           a x \|a x
+--R                                                    Type: Expression(Integer)
+--E 515
+
+)clear all
+
+--S 516 of 1004
+t0:=1/(a*x)^(3/2)
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R            +---+
+--R        a x\|a x
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 1004
+r0:=(-2)/(a*sqrt(a*x))
+--R 
+--R
+--R             2
+--R   (2)  - -------
+--R            +---+
+--R          a\|a x
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R   (3)  - -------
+--R            +---+
+--R          a\|a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 518
+
+--S 519 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 520
+
+)clear all
+
+--S 521 of 1004
+t0:=1/(a/x)^(3/2)
+--R 
+--R
+--R          x
+--R   (1)  -----
+--R          +-+
+--R          |a
+--R        a |-
+--R         \|x
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 1004
+r0:=2/5*x^2/(a*sqrt(a/x))
+--R 
+--R
+--R            2
+--R          2x
+--R   (2)  ------
+--R           +-+
+--R           |a
+--R        5a |-
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2
+--R          2x
+--R   (3)  ------
+--R           +-+
+--R           |a
+--R        5a |-
+--R          \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 523
+
+--S 524 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 1004
+t0:=1/(a/x^2)^(3/2)
+--R 
+--R
+--R           2
+--R          x
+--R   (1)  ------
+--R          +--+
+--R          | a
+--R        a |--
+--R          | 2
+--R         \|x
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 1004
+r0:=1/4*x^3/(a*sqrt(a/x^2))
+--R 
+--R
+--R            3
+--R           x
+--R   (2)  -------
+--R           +--+
+--R           | a
+--R        4a |--
+--R           | 2
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4
+--R          x
+--R   (3)  ------
+--R           +-+
+--R        4a\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 528
+
+--S 529 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                      +--+
+--R           3 +-+    4 | a
+--R        - x \|a  + x  |--
+--R                      | 2
+--R                     \|x
+--R   (4)  ------------------
+--R               +--+
+--R               | a  +-+
+--R            4a |-- \|a
+--R               | 2
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +--+
+--R         3 | a  +-+      2
+--R        x  |-- \|a  - a x
+--R           | 2
+--R          \|x
+--R   (5)  ------------------
+--R                 +--+
+--R               2 | a
+--R              a  |--
+--R                 | 2
+--R                \|x
+--R                                                    Type: Expression(Integer)
+--E 530
+
+)clear all
+
+--S 531 of 1004
+t0:=1/(a/x^3)^(3/2)
+--R 
+--R
+--R           3
+--R          x
+--R   (1)  ------
+--R          +--+
+--R          | a
+--R        a |--
+--R          | 3
+--R         \|x
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 1004
+r0:=2/11*x^4/(a*sqrt(a/x^3))
+--R 
+--R
+--R             4
+--R           2x
+--R   (2)  --------
+--R            +--+
+--R            | a
+--R        11a |--
+--R            | 3
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            5
+--R          2x
+--R   (3)  -------
+--R            +-+
+--R            |a
+--R        11a |-
+--R           \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 533
+
+--S 534 of 1004
+m0:=a0-r0
+--R 
+--R
+--R              +-+       +--+
+--R            4 |a      5 | a
+--R        - 2x  |-  + 2x  |--
+--R             \|x        | 3
+--R                       \|x
+--R   (4)  --------------------
+--R                +--+ +-+
+--R                | a  |a
+--R            11a |--  |-
+--R                | 3 \|x
+--R               \|x
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +-+      +--+
+--R           3 |a     4 | a
+--R        - x  |-  + x  |--
+--R            \|x       | 3
+--R                     \|x
+--R   (5)  ------------------
+--R              +--+ +-+
+--R              | a  |a
+--R            a |--  |-
+--R              | 3 \|x
+--R             \|x
+--R                                                    Type: Expression(Integer)
+--E 535
+
+)clear all
+
+--S 536 of 1004
+t0:=(a*x^n)^(1/3)
+--R 
+--R
+--R         +----+
+--R        3|   n
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1004
+r0:=3*x*(a*x^n)^(1/3)/(3+n)
+--R 
+--R
+--R           +----+
+--R          3|   n
+--R        3x\|a x
+--R   (2)  ---------
+--R          n + 3
+--R                                                    Type: Expression(Integer)
+--E 537
+
+-- integrate: implementation incomplete (constant residues)
+--S 538 of 1004
+--a0:=integrate(t0,x)
+--E 538
+
+--S 539 of 1004
+--m0:=a0-r0
+--E 539
+
+--S 540 of 1004
+--d0:=normalize(D(m0,x))
+--E 540
+
+)clear all
+
+--S 541 of 1004
+t0:=(a*x^3)^(1/3)
+--R 
+--R
+--R         +----+
+--R        3|   3
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 1004
+r0:=1/2*x*(a*x^3)^(1/3)
+--R 
+--R
+--R          +----+
+--R         3|   3
+--R        x\|a x
+--R   (2)  --------
+--R            2
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2 3+-+
+--R        x  \|a
+--R   (3)  ------
+--R           2
+--R                                         Type: Union(Expression(Integer),...)
+--E 543
+
+--S 544 of 1004
+m0:=a0-r0
+--R 
+--R
+--R            +----+
+--R           3|   3     2 3+-+
+--R        - x\|a x   + x  \|a
+--R   (4)  -------------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +----+2
+--R         3+-+3|   3        3
+--R        x\|a \|a x    - a x
+--R   (5)  --------------------
+--R               +----+2
+--R              3|   3
+--R              \|a x
+--R                                                    Type: Expression(Integer)
+--E 545
+
+)clear all
+
+--S 546 of 1004
+t0:=(a*x^2)^(1/3)
+--R 
+--R
+--R         +----+
+--R        3|   2
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 1004
+r0:=3/5*x*(a*x^2)^(1/3)
+--R 
+--R
+--R           +----+
+--R          3|   2
+--R        3x\|a x
+--R   (2)  ---------
+--R            5
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           +----+
+--R          3|   2
+--R        3x\|a x
+--R   (3)  ---------
+--R            5
+--R                                         Type: Union(Expression(Integer),...)
+--E 548
+
+--S 549 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 550
+
+)clear all
+
+--S 551 of 1004
+t0:=(a*x)^(1/3)
+--R 
+--R
+--R        3+---+
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 1004
+r0:=3/4*(a*x)^(4/3)/a
+--R 
+--R
+--R          3+---+
+--R        3x\|a x
+--R   (2)  --------
+--R            4
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3+---+
+--R        3x\|a x
+--R   (3)  --------
+--R            4
+--R                                         Type: Union(Expression(Integer),...)
+--E 553
+
+--S 554 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 1004
+t0:=(a/x)^(1/3)
+--R 
+--R
+--R         +-+
+--R         |a
+--R   (1)  3|-
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 1004
+r0:=3/2*(a/x)^(1/3)*x
+--R 
+--R
+--R            +-+
+--R            |a
+--R        3x 3|-
+--R           \|x
+--R   (2)  ------
+--R           2
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3a
+--R   (3)  ------
+--R           +-+2
+--R           |a
+--R        2 3|-
+--R          \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 558
+
+--S 559 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 560
+
+)clear all
+
+--S 561 of 1004
+t0:=(a/x^2)^(1/3)
+--R 
+--R
+--R         +--+
+--R         | a
+--R   (1)   |--
+--R        3| 2
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 1004
+r0:=3*(a/x^2)^(1/3)*x
+--R 
+--R
+--R            +--+
+--R            | a
+--R   (2)  3x  |--
+--R           3| 2
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +--+
+--R            | a
+--R   (3)  3x  |--
+--R           3| 2
+--R           \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 563
+
+--S 564 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+--S 565 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 565
+
+)clear all
+
+--S 566 of 1004
+t0:=(a/x^3)^(1/3)
+--R 
+--R
+--R         +--+
+--R         | a
+--R   (1)   |--
+--R        3| 3
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1004
+r0:=(a/x^3)^(1/3)*x*log(x)
+--R 
+--R
+--R                  +--+
+--R                  | a
+--R   (2)  x log(x)  |--
+--R                 3| 3
+--R                 \|x
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3+-+
+--R   (3)  log(x)\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 568
+
+--S 569 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                               +--+
+--R              3+-+             | a
+--R   (4)  log(x)\|a  - x log(x)  |--
+--R                              3| 3
+--R                              \|x
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R            +--+2
+--R         2  | a   3+-+
+--R        x   |--   \| - a
+--R           3| 3
+--R           \|x
+--R   (5)  ----------------
+--R                +--+2
+--R             3  | a
+--R            x   |--
+--R               3| 3
+--R               \|x
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 1004
+t0:=(a*x^n)^(2/3)
+--R 
+--R
+--R         +----+2
+--R        3|   n
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 1004
+r0:=3*x*(a*x^n)^(2/3)/(3+2*n)
+--R 
+--R
+--R            +----+2
+--R           3|   n
+--R        3x \|a x
+--R   (2)  -----------
+--R           2n + 3
+--R                                                    Type: Expression(Integer)
+--E 572
+
+-- integrate: implementation incomplete (constant residues)
+--S 573 of 1004
+--a0:=integrate(t0,x)
+--E 573
+
+--S 574 of 1004
+--m0:=a0-r0
+--E 574
+
+--S 575 of 1004
+--d0:=normalize(D(m0,x))
+--E 575
+
+)clear all
+
+--S 576 of 1004
+t0:=(a*x^3)^(2/3)
+--R 
+--R
+--R         +----+2
+--R        3|   3
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 1004
+r0:=1/3*x*(a*x^3)^(2/3)
+--R 
+--R
+--R           +----+2
+--R          3|   3
+--R        x \|a x
+--R   (2)  ----------
+--R             3
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3 3+-+2
+--R        x  \|a
+--R   (3)  -------
+--R           3
+--R                                         Type: Union(Expression(Integer),...)
+--E 578
+
+--S 579 of 1004
+m0:=a0-r0
+--R 
+--R
+--R             +----+2
+--R            3|   3      3 3+-+2
+--R        - x \|a x    + x  \|a
+--R   (4)  ----------------------
+--R                   3
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                  +----+
+--R         2 3+-+2 3|   3     3
+--R        x  \|a   \|a x - a x
+--R   (5)  ---------------------
+--R                +----+
+--R               3|   3
+--R               \|a x
+--R                                                    Type: Expression(Integer)
+--E 580
+
+)clear all
+
+--S 581 of 1004
+t0:=(a*x^2)^(2/3)
+--R 
+--R
+--R         +----+2
+--R        3|   2
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1004
+r0:=3/7*x*(a*x^2)^(2/3)
+--R 
+--R
+--R            +----+2
+--R           3|   2
+--R        3x \|a x
+--R   (2)  -----------
+--R             7
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +----+2
+--R           3|   2
+--R        3x \|a x
+--R   (3)  -----------
+--R             7
+--R                                         Type: Union(Expression(Integer),...)
+--E 583
+
+--S 584 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 1004
+t0:=(a*x)^(2/3)
+--R 
+--R
+--R        3+---+2
+--R   (1)  \|a x
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 1004
+r0:=3/5*(a*x)^(5/3)/a
+--R 
+--R
+--R           3+---+2
+--R        3x \|a x
+--R   (2)  ----------
+--R             5
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3+---+2
+--R        3x \|a x
+--R   (3)  ----------
+--R             5
+--R                                         Type: Union(Expression(Integer),...)
+--E 588
+
+--S 589 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 590
+
+)clear all
+
+--S 591 of 1004
+t0:=(a/x)^(2/3)
+--R 
+--R
+--R         +-+2
+--R         |a
+--R   (1)  3|-
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 1004
+r0:=3*(a/x)^(2/3)*x
+--R 
+--R
+--R            +-+2
+--R            |a
+--R   (2)  3x 3|-
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3a
+--R   (3)  ----
+--R         +-+
+--R         |a
+--R        3|-
+--R        \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 593
+
+--S 594 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 595
+
+)clear all
+
+--S 596 of 1004
+t0:=(a/x^2)^(2/3)
+--R 
+--R
+--R         +--+2
+--R         | a
+--R   (1)   |--
+--R        3| 2
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1004
+r0:=-3*(a/x^2)^(2/3)*x
+--R 
+--R
+--R              +--+2
+--R              | a
+--R   (2)  - 3x  |--
+--R             3| 2
+--R             \|x
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3a
+--R   (3)  - ------
+--R             +--+
+--R             | a
+--R          x  |--
+--R            3| 2
+--R            \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 598
+
+--S 599 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)clear all
+
+--S 601 of 1004
+t0:=(a/x^3)^(2/3)
+--R 
+--R
+--R         +--+2
+--R         | a
+--R   (1)   |--
+--R        3| 3
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 1004
+r0:=-(a/x^3)^(2/3)*x
+--R 
+--R
+--R             +--+2
+--R             | a
+--R   (2)  - x  |--
+--R            3| 3
+--R            \|x
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3+-+2
+--R          \|a
+--R   (3)  - -----
+--R            x
+--R                                         Type: Union(Expression(Integer),...)
+--E 603
+
+--S 604 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                      +--+2
+--R          3+-+2    2  | a
+--R        - \|a   + x   |--
+--R                     3| 3
+--R                     \|x
+--R   (4)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +--+2
+--R        3+-+2    2  | a
+--R        \|a   - x   |--
+--R                   3| 3
+--R                   \|x
+--R   (5)  ----------------
+--R                2
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 605
+
+)clear all
+
+--S 606 of 1004
+t0:=1/(a*x^n)^(1/3)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R         +----+
+--R        3|   n
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 1004
+r0:=3*x/((3-n)*(a*x^n)^(1/3))
+--R 
+--R
+--R                3x
+--R   (2)  - --------------
+--R                  +----+
+--R                 3|   n
+--R          (n - 3)\|a x
+--R                                                    Type: Expression(Integer)
+--E 607
+
+-- integrate: implementation incomplete (constant residues)
+--S 608 of 1004
+--a0:=integrate(t0,x)
+--E 608
+
+--S 609 of 1004
+--m0:=a0-r0
+--E 609
+
+--S 610 of 1004
+--d0:=normalize(D(m0,x))
+--E 610
+
+)clear all
+
+--S 611 of 1004
+t0:=1/(a*x^3)^(1/3)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R         +----+
+--R        3|   3
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 1004
+r0:=x*log(x)/(a*x^3)^(1/3)
+--R 
+--R
+--R        x log(x)
+--R   (2)  --------
+--R          +----+
+--R         3|   3
+--R         \|a x
+--R                                                    Type: Expression(Integer)
+--E 612
+
+--S 613 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(x)
+--R   (3)  ------
+--R         3+-+
+--R         \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 613
+
+--S 614 of 1004
+m0:=a0-r0
+--R 
+--R
+--R               +----+
+--R              3|   3            3+-+
+--R        log(x)\|a x   - x log(x)\|a
+--R   (4)  ----------------------------
+--R                      +----+
+--R                 3+-+3|   3
+--R                 \|a \|a x
+--R                                                    Type: Expression(Integer)
+--E 614
+
+--S 615 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R         +----+
+--R        3|   3     3+-+
+--R        \|a x   - x\|a
+--R   (5)  ---------------
+--R                +----+
+--R           3+-+3|   3
+--R          x\|a \|a x
+--R                                                    Type: Expression(Integer)
+--E 615
+
+)clear all
+
+--S 616 of 1004
+t0:=1/(a*x^2)^(1/3)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R         +----+
+--R        3|   2
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 1004
+r0:=3*x/(a*x^2)^(1/3)
+--R 
+--R
+--R           3x
+--R   (2)  -------
+--R         +----+
+--R        3|   2
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +----+2
+--R         3|   2
+--R        3\|a x
+--R   (3)  ---------
+--R           a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 618
+
+--S 619 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 619
+
+--S 620 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 620
+
+)clear all
+
+--S 621 of 1004
+t0:=1/(a*x)^(1/3)
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R        3+---+
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 1004
+r0:=3/2*(a*x)^(2/3)/a
+--R 
+--R
+--R         3+---+2
+--R        3\|a x
+--R   (2)  --------
+--R           2a
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3+---+2
+--R        3\|a x
+--R   (3)  --------
+--R           2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 623
+
+--S 624 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 624
+
+--S 625 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 625
+
+)clear all
+
+--S 626 of 1004
+t0:=1/(a/x)^(1/3)
+--R 
+--R
+--R          1
+--R   (1)  ----
+--R         +-+
+--R         |a
+--R        3|-
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 1004
+r0:=3/4*x/(a/x)^(1/3)
+--R 
+--R
+--R          3x
+--R   (2)  -----
+--R           +-+
+--R           |a
+--R        4 3|-
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3x
+--R   (3)  -----
+--R           +-+
+--R           |a
+--R        4 3|-
+--R          \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 628
+
+--S 629 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 630
+
+)clear all
+
+--S 631 of 1004
+t0:=1/(a/x^2)^(1/3)
+--R 
+--R
+--R          1
+--R   (1)  -----
+--R         +--+
+--R         | a
+--R         |--
+--R        3| 2
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 1004
+r0:=3/5*x/(a/x^2)^(1/3)
+--R 
+--R
+--R          3x
+--R   (2)  ------
+--R           +--+
+--R           | a
+--R        5  |--
+--R          3| 2
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +--+2
+--R          3  | a
+--R        3x   |--
+--R            3| 2
+--R            \|x
+--R   (3)  ---------
+--R            5a
+--R                                         Type: Union(Expression(Integer),...)
+--E 633
+
+--S 634 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 634
+
+--S 635 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 635
+
+)clear all
+
+--S 636 of 1004
+t0:=1/(a/x^3)^(1/3)
+--R 
+--R
+--R          1
+--R   (1)  -----
+--R         +--+
+--R         | a
+--R         |--
+--R        3| 3
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 1004
+r0:=1/2*x/(a/x^3)^(1/3)
+--R 
+--R
+--R           x
+--R   (2)  ------
+--R           +--+
+--R           | a
+--R        2  |--
+--R          3| 3
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R          x
+--R   (3)  -----
+--R         3+-+
+--R        2\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 638
+
+--S 639 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                      +--+
+--R           3+-+    2  | a
+--R        - x\|a  + x   |--
+--R                     3| 3
+--R                     \|x
+--R   (4)  -----------------
+--R               +--+
+--R               | a 3+-+
+--R            2  |-- \|a
+--R              3| 3
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 639
+
+--S 640 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +--+
+--R          3+-+      | a
+--R        - \|a  + x  |--
+--R                   3| 3
+--R                   \|x
+--R   (5)  ---------------
+--R            +--+
+--R            | a 3+-+
+--R            |-- \|a
+--R           3| 3
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 640
+
+)clear all
+
+--S 641 of 1004
+t0:=1/(a*x^n)^(2/3)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R         +----+2
+--R        3|   n
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 1004
+r0:=3*x/((3-2*n)*(a*x^n)^(2/3))
+--R 
+--R
+--R                 3x
+--R   (2)  - ----------------
+--R                   +----+2
+--R                  3|   n
+--R          (2n - 3)\|a x
+--R                                                    Type: Expression(Integer)
+--E 642
+
+-- integrate: implementation incomplete (constant residues)
+--S 643 of 1004
+--a0:=integrate(t0,x)
+--E 643
+
+--S 644 of 1004
+--m0:=a0-r0
+--E 644
+
+--S 645 of 1004
+--d0:=normalize(D(m0,x))
+--E 645
+
+)clear all
+
+--S 646 of 1004
+t0:=1/(a*x^3)^(2/3)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R         +----+2
+--R        3|   3
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 1004
+r0:=-x/(a*x^3)^(2/3)
+--R 
+--R
+--R              x
+--R   (2)  - --------
+--R           +----+2
+--R          3|   3
+--R          \|a x
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            3+-+2
+--R          x \|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 648
+
+--S 649 of 1004
+m0:=a0-r0
+--R 
+--R
+--R           +----+2
+--R          3|   3      2 3+-+2
+--R        - \|a x    + x  \|a
+--R   (4)  --------------------
+--R                    +----+2
+--R             3+-+2 3|   3
+--R           x \|a   \|a x
+--R                                                    Type: Expression(Integer)
+--E 649
+
+--S 650 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +----+2
+--R        3+-+3|   3        2
+--R        \|a \|a x    - a x
+--R   (5)  -------------------
+--R                  +----+2
+--R               2 3|   3
+--R            a x  \|a x
+--R                                                    Type: Expression(Integer)
+--E 650
+
+)clear all
+
+--S 651 of 1004
+t0:=1/(a*x^2)^(2/3)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R         +----+2
+--R        3|   2
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 1004
+r0:=-3*x/(a*x^2)^(2/3)
+--R 
+--R
+--R             3x
+--R   (2)  - --------
+--R           +----+2
+--R          3|   2
+--R          \|a x
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +----+
+--R           3|   2
+--R          3\|a x
+--R   (3)  - --------
+--R             a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 653
+
+--S 654 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 654
+
+--S 655 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 655
+
+)clear all
+
+--S 656 of 1004
+t0:=1/(a*x)^(2/3)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R        3+---+2
+--R        \|a x
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 1004
+r0:=3*(a*x)^(1/3)/a
+--R 
+--R
+--R         3+---+
+--R        3\|a x
+--R   (2)  -------
+--R           a
+--R                                                    Type: Expression(Integer)
+--E 657
+
+--S 658 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3+---+
+--R        3\|a x
+--R   (3)  -------
+--R           a
+--R                                         Type: Union(Expression(Integer),...)
+--E 658
+
+--S 659 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 659
+
+--S 660 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 660
+
+)clear all
+
+--S 661 of 1004
+t0:=1/(a/x)^(2/3)
+--R 
+--R
+--R          1
+--R   (1)  -----
+--R         +-+2
+--R         |a
+--R        3|-
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 1004
+r0:=3/5*x/(a/x)^(2/3)
+--R 
+--R
+--R          3x
+--R   (2)  ------
+--R           +-+2
+--R           |a
+--R        5 3|-
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3x
+--R   (3)  ------
+--R           +-+2
+--R           |a
+--R        5 3|-
+--R          \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 663
+
+--S 664 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 664
+
+--S 665 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 665
+
+)clear all
+
+--S 666 of 1004
+t0:=1/(a/x^2)^(2/3)
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         +--+2
+--R         | a
+--R         |--
+--R        3| 2
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 1004
+r0:=3/7*x/(a/x^2)^(2/3)
+--R 
+--R
+--R           3x
+--R   (2)  -------
+--R           +--+2
+--R           | a
+--R        7  |--
+--R          3| 2
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +--+
+--R          3  | a
+--R        3x   |--
+--R            3| 2
+--R            \|x
+--R   (3)  --------
+--R           7a
+--R                                         Type: Union(Expression(Integer),...)
+--E 668
+
+--S 669 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 669
+
+--S 670 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 670
+
+)clear all
+
+--S 671 of 1004
+t0:=1/(a/x^3)^(2/3)
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         +--+2
+--R         | a
+--R         |--
+--R        3| 3
+--R        \|x
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 1004
+r0:=1/3*x/(a/x^3)^(2/3)
+--R 
+--R
+--R           x
+--R   (2)  -------
+--R           +--+2
+--R           | a
+--R        3  |--
+--R          3| 3
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3
+--R          x
+--R   (3)  ------
+--R         3+-+2
+--R        3\|a
+--R                                         Type: Union(Expression(Integer),...)
+--E 673
+
+--S 674 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                        +--+2
+--R            3+-+2    3  | a
+--R        - x \|a   + x   |--
+--R                       3| 3
+--R                       \|x
+--R   (4)  --------------------
+--R               +--+2
+--R               | a   3+-+2
+--R            3  |--   \|a
+--R              3| 3
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R            +--+2
+--R         2  | a   3+-+
+--R        x   |--   \| - a
+--R           3| 3
+--R           \|x
+--R   (5)  ----------------
+--R               +--+2
+--R               | a
+--R            a  |--
+--R              3| 3
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 675
+
+)clear all
+
+--S 676 of 1004
+t0:=x^m*(a*x^n)^p
+--R 
+--R
+--R         m    n p
+--R   (1)  x (a x )
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 1004
+r0:=x^(1+m)*(a*x^n)^p/(1+m+n*p)
+--R 
+--R
+--R         m + 1    n p
+--R        x     (a x )
+--R   (2)  -------------
+--R         n p + m + 1
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            m log(x)  n p log(x) + p log(a)
+--R        x %e        %e
+--R   (3)  -----------------------------------
+--R                    n p + m + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 678
+
+--S 679 of 1004
+m0:=a0-r0
+--R 
+--R
+--R           m + 1    n p       m log(x)  n p log(x) + p log(a)
+--R        - x     (a x )  + x %e        %e
+--R   (4)  -----------------------------------------------------
+--R                             n p + m + 1
+--R                                                    Type: Expression(Integer)
+--E 679
+
+--S 680 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 680
+
+)clear all
+
+--S 681 of 1004
+t0:=x^m/(a*x^n)^((1+m)/n)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  -----------
+--R              m + 1
+--R              -----
+--R            n   n
+--R        (a x )
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 1004
+r0:=x^(1+m)*log(x)/(a*x^n)^((1+m)/n)
+--R 
+--R
+--R               m + 1
+--R        log(x)x
+--R   (2)  ------------
+--R               m + 1
+--R               -----
+--R             n   n
+--R         (a x )
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                (- m - 1)log(a)
+--R                ---------------
+--R                       n
+--R   (3)  log(x)%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 683
+
+--S 684 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                (- m - 1)log(a)      m + 1
+--R                ---------------      -----
+--R                       n           n   n            m + 1
+--R        log(x)%e               (a x )      - log(x)x
+--R   (4)  -------------------------------------------------
+--R                                 m + 1
+--R                                 -----
+--R                               n   n
+--R                           (a x )
+--R                                                    Type: Expression(Integer)
+--E 684
+
+--S 685 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 685
+
+)clear all
+
+--S 686 of 1004
+t0:=x^(-1-n*p)*(a*x^n)^p
+--R 
+--R
+--R         - n p - 1    n p
+--R   (1)  x         (a x )
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 1004
+r0:=(a*x^n)^p*log(x)/x^(n*p)
+--R 
+--R
+--R                  n p
+--R        log(x)(a x )
+--R   (2)  -------------
+--R              n p
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                p log(a)
+--R   (3)  log(x)%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 688
+
+--S 689 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                    n p          n p  p log(a)
+--R        - log(x)(a x )  + log(x)x   %e
+--R   (4)  --------------------------------------
+--R                          n p
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 690
+
+)clear all
+
+--S 691 of 1004
+t0:=x^2*(a*x^n)^p
+--R 
+--R
+--R         2    n p
+--R   (1)  x (a x )
+--R                                                    Type: Expression(Integer)
+--E 691
+
+--S 692 of 1004
+r0:=x^3*(a*x^n)^p/(3+n*p)
+--R 
+--R
+--R         3    n p
+--R        x (a x )
+--R   (2)  ---------
+--R         n p + 3
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3  n p log(x) + p log(a)
+--R        x %e
+--R   (3)  -------------------------
+--R                 n p + 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 693
+
+--S 694 of 1004
+m0:=a0-r0
+--R 
+--R
+--R           3    n p    3  n p log(x) + p log(a)
+--R        - x (a x )  + x %e
+--R   (4)  ---------------------------------------
+--R                        n p + 3
+--R                                                    Type: Expression(Integer)
+--E 694
+
+--S 695 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 695
+
+)clear all
+
+--S 696 of 1004
+t0:=x*(a*x^n)^p
+--R 
+--R
+--R              n p
+--R   (1)  x (a x )
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 1004
+r0:=x^2*(a*x^n)^p/(2+n*p)
+--R 
+--R
+--R         2    n p
+--R        x (a x )
+--R   (2)  ---------
+--R         n p + 2
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2  n p log(x) + p log(a)
+--R        x %e
+--R   (3)  -------------------------
+--R                 n p + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 698
+
+--S 699 of 1004
+m0:=a0-r0
+--R 
+--R
+--R           2    n p    2  n p log(x) + p log(a)
+--R        - x (a x )  + x %e
+--R   (4)  ---------------------------------------
+--R                        n p + 2
+--R                                                    Type: Expression(Integer)
+--E 699
+
+--S 700 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 700
+
+)clear all
+
+--S 701 of 1004
+t0:=(a*x^n)^p
+--R 
+--R
+--R            n p
+--R   (1)  (a x )
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 1004
+r0:=x*(a*x^n)^p/(1+n*p)
+--R 
+--R
+--R              n p
+--R        x (a x )
+--R   (2)  ---------
+--R         n p + 1
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            n p log(x) + p log(a)
+--R        x %e
+--R   (3)  -------------------------
+--R                 n p + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 703
+
+--S 704 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                n p       n p log(x) + p log(a)
+--R        - x (a x )  + x %e
+--R   (4)  ---------------------------------------
+--R                        n p + 1
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 705
+
+)clear all
+
+--S 706 of 1004
+t0:=(a*x^n)^p/x
+--R 
+--R
+--R            n p
+--R        (a x )
+--R   (1)  -------
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 1004
+r0:=(a*x^n)^p/(n*p)
+--R 
+--R
+--R            n p
+--R        (a x )
+--R   (2)  -------
+--R          n p
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          n p log(x) + p log(a)
+--R        %e
+--R   (3)  -----------------------
+--R                  n p
+--R                                         Type: Union(Expression(Integer),...)
+--E 708
+
+--S 709 of 1004
+m0:=a0-r0
+--R 
+--R
+--R              n p     n p log(x) + p log(a)
+--R        - (a x )  + %e
+--R   (4)  -----------------------------------
+--R                        n p
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 710
+
+)clear all
+
+--S 711 of 1004
+t0:=(a*x^n)^p/x^2
+--R 
+--R
+--R            n p
+--R        (a x )
+--R   (1)  -------
+--R            2
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 1004
+r0:=-(a*x^n)^p/((1-n*p)*x)
+--R 
+--R
+--R              n p
+--R          (a x )
+--R   (2)  ----------
+--R        (n p - 1)x
+--R                                                    Type: Expression(Integer)
+--E 712
+
+--S 713 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          n p log(x) + p log(a)
+--R        %e
+--R   (3)  -----------------------
+--R               (n p - 1)x
+--R                                         Type: Union(Expression(Integer),...)
+--E 713
+
+--S 714 of 1004
+m0:=a0-r0
+--R 
+--R
+--R              n p     n p log(x) + p log(a)
+--R        - (a x )  + %e
+--R   (4)  -----------------------------------
+--R                     (n p - 1)x
+--R                                                    Type: Expression(Integer)
+--E 714
+
+--S 715 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 715
+
+)clear all
+
+--S 716 of 1004
+t0:=x^m/(a*x^n)^(1/n)
+--R 
+--R
+--R            m
+--R           x
+--R   (1)  -------
+--R              1
+--R              -
+--R            n n
+--R        (a x )
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1004
+r0:=x^(1+m)/(m*(a*x^n)^(1/n))
+--R 
+--R
+--R           m + 1
+--R          x
+--R   (2)  ---------
+--R                1
+--R                -
+--R              n n
+--R        m (a x )
+--R                                                    Type: Expression(Integer)
+--E 717
+
+--S 718 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R          m log(x)
+--R        %e
+--R   (3)  ----------
+--R            log(a)
+--R            ------
+--R               n
+--R        m %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 718
+
+--S 719 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                        1           log(a)
+--R                        -           ------
+--R          m log(x)    n n    m + 1     n
+--R        %e        (a x )  - x     %e
+--R   (4)  ----------------------------------
+--R                     log(a)      1
+--R                     ------      -
+--R                        n      n n
+--R                 m %e      (a x )
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 720
+
+)clear all
+
+--S 721 of 1004
+t0:=x^2/(a*x^n)^(1/n)
+--R 
+--R
+--R            2
+--R           x
+--R   (1)  -------
+--R              1
+--R              -
+--R            n n
+--R        (a x )
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 1004
+r0:=1/2*x^3/(a*x^n)^(1/n)
+--R 
+--R
+--R            3
+--R           x
+--R   (2)  --------
+--R               1
+--R               -
+--R             n n
+--R        2(a x )
+--R                                                    Type: Expression(Integer)
+--E 722
+
+--S 723 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R            x
+--R   (3)  ---------
+--R           log(a)
+--R           ------
+--R              n
+--R        2%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 723
+
+--S 724 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                1       log(a)
+--R                -       ------
+--R         2    n n    3     n
+--R        x (a x )  - x %e
+--R   (4)  ----------------------
+--R              log(a)      1
+--R              ------      -
+--R                 n      n n
+--R           2%e      (a x )
+--R                                                    Type: Expression(Integer)
+--E 724
+
+--S 725 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 725
+
+)clear all
+
+--S 726 of 1004
+t0:=x/(a*x^n)^(1/n)
+--R 
+--R
+--R           x
+--R   (1)  -------
+--R              1
+--R              -
+--R            n n
+--R        (a x )
+--R                                                    Type: Expression(Integer)
+--E 726
+
+--S 727 of 1004
+r0:=x^2/(a*x^n)^(1/n)
+--R 
+--R
+--R            2
+--R           x
+--R   (2)  -------
+--R              1
+--R              -
+--R            n n
+--R        (a x )
+--R                                                    Type: Expression(Integer)
+--E 727
+
+--S 728 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            x
+--R   (3)  --------
+--R          log(a)
+--R          ------
+--R             n
+--R        %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 728
+
+--S 729 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                1       log(a)
+--R                -       ------
+--R              n n    2     n
+--R        x (a x )  - x %e
+--R   (4)  ----------------------
+--R              log(a)      1
+--R              ------      -
+--R                 n      n n
+--R            %e      (a x )
+--R                                                    Type: Expression(Integer)
+--E 729
+
+--S 730 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 730
+
+)clear all
+
+--S 731 of 1004
+t0:=1/(a*x^n)^(1/n)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R              1
+--R              -
+--R            n n
+--R        (a x )
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 1004
+r0:=x*log(x)/(a*x^n)^(1/n)
+--R 
+--R
+--R        x log(x)
+--R   (2)  --------
+--R               1
+--R               -
+--R             n n
+--R         (a x )
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         log(x)
+--R   (3)  --------
+--R          log(a)
+--R          ------
+--R             n
+--R        %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 733
+
+--S 734 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                    1             log(a)
+--R                    -             ------
+--R                  n n                n
+--R        log(x)(a x )  - x log(x)%e
+--R   (4)  --------------------------------
+--R                   log(a)      1
+--R                   ------      -
+--R                      n      n n
+--R                 %e      (a x )
+--R                                                    Type: Expression(Integer)
+--E 734
+
+--S 735 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 735
+
+)clear all
+
+--S 736 of 1004
+t0:=1/(x*(a*x^n)^(1/n))
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R                1
+--R                -
+--R              n n
+--R        x (a x )
+--R                                                    Type: Expression(Integer)
+--E 736
+
+--S 737 of 1004
+r0:=(-1)/(a*x^n)^(1/n)
+--R 
+--R
+--R             1
+--R   (2)  - -------
+--R                1
+--R                -
+--R              n n
+--R          (a x )
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R               1
+--R   (3)  - ----------
+--R              log(a)
+--R              ------
+--R                 n
+--R          x %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 738
+
+--S 739 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                1       log(a)
+--R                -       ------
+--R              n n          n
+--R        - (a x )  + x %e
+--R   (4)  ----------------------
+--R               log(a)      1
+--R               ------      -
+--R                  n      n n
+--R           x %e      (a x )
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 740
+
+)clear all
+
+--S 741 of 1004
+t0:=1/(x^2*(a*x^n)^(1/n))
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R                1
+--R                -
+--R         2    n n
+--R        x (a x )
+--R                                                    Type: Expression(Integer)
+--E 741
+
+--S 742 of 1004
+r0:=(-1/2)/(x*(a*x^n)^(1/n))
+--R 
+--R
+--R               1
+--R   (2)  - ----------
+--R                   1
+--R                   -
+--R                 n n
+--R          2x (a x )
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R               1
+--R   (3)  - -----------
+--R               log(a)
+--R               ------
+--R            2     n
+--R          2x %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 743
+
+--S 744 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                1       log(a)
+--R                -       ------
+--R              n n          n
+--R        - (a x )  + x %e
+--R   (4)  ----------------------
+--R               log(a)      1
+--R               ------      -
+--R            2     n      n n
+--R          2x %e      (a x )
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 745
+
+)clear all
+
+--S 746 of 1004
+t0:=(a+b*(c*x^n)^(1/n))^p
+--R 
+--R
+--R                 1     p
+--R                 -
+--R               n n
+--R   (1)  (b (c x )  + a)
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 1004
+r0:=x*(a+b*(c*x^n)^(1/n))^(1+p)/(b*(1+p)*(c*x^n)^(1/n))
+--R 
+--R
+--R                   1     p + 1
+--R                   -
+--R                 n n
+--R        x (b (c x )  + a)
+--R   (2)  ----------------------
+--R                          1
+--R                          -
+--R                        n n
+--R           (b p + b)(c x )
+--R                                                    Type: Expression(Integer)
+--E 747
+
+--S 748 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        log(c)
+--R               log(c)                   ------
+--R               ------                      n
+--R                  n         p log(b x %e       + a)
+--R        (b x %e       + a)%e
+--R   (3)  -------------------------------------------
+--R                                log(c)
+--R                                ------
+--R                                   n
+--R                     (b p + b)%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 748
+
+--S 749 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              log(c)
+--R              log(c)           1              ------
+--R              ------           -                 n
+--R                 n           n n  p log(b x %e       + a)
+--R       (b x %e       + a)(c x ) %e
+--R     + 
+--R             log(c)         1     p + 1
+--R             ------         -
+--R                n         n n
+--R       - x %e      (b (c x )  + a)
+--R  /
+--R                log(c)      1
+--R                ------      -
+--R                   n      n n
+--R     (b p + b)%e      (c x )
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 750
+
+)clear all
+
+--S 751 of 1004
+t0:=(a+b*(c*x^n)^(1/n))^3
+--R 
+--R
+--R                 1 3               1 2              1
+--R                 -                 -                -
+--R         3     n n         2     n n       2      n n    3
+--R   (1)  b ((c x ) )  + 3a b ((c x ) )  + 3a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 1004
+r0:=1/4*x*(a+b*(c*x^n)^(1/n))^4/(b*(c*x^n)^(1/n))
+--R 
+--R
+--R   (2)
+--R              1 4                 1 3                 1 2                1
+--R              -                   -                   -                  -
+--R    4       n n         3       n n       2 2       n n       3        n n    4
+--R   b x ((c x ) )  + 4a b x ((c x ) )  + 6a b x ((c x ) )  + 4a b x (c x )  + a x
+--R   -----------------------------------------------------------------------------
+--R                                              1
+--R                                              -
+--R                                            n n
+--R                                     4b (c x )
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R               log(c) 3             log(c) 2            log(c)
+--R               ------               ------              ------
+--R         3 4      n           2 3      n         2   2     n       3
+--R        b x (%e      )  + 4a b x (%e      )  + 6a b x %e       + 4a x
+--R   (3)  -------------------------------------------------------------
+--R                                      4
+--R                                         Type: Union(Expression(Integer),...)
+--E 753
+
+--S 754 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    1 4                 1 3                 1 2
+--R                    -                   -                   -
+--R          4       n n         3       n n       2 2       n n
+--R       - b x ((c x ) )  - 4a b x ((c x ) )  - 6a b x ((c x ) )
+--R     + 
+--R               log(c) 3             log(c) 2            log(c)       1
+--R               ------               ------              ------       -
+--R         4 4      n           3 3      n         2 2 2     n       n n    4
+--R       (b x (%e      )  + 4a b x (%e      )  + 6a b x %e      )(c x )  - a x
+--R  /
+--R              1
+--R              -
+--R            n n
+--R     4b (c x )
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 755
+
+)clear all
+
+--S 756 of 1004
+t0:=(a+b*(c*x^n)^(1/n))^2
+--R 
+--R
+--R                 1 2              1
+--R                 -                -
+--R         2     n n              n n    2
+--R   (1)  b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 1004
+r0:=1/3*x*(a+b*(c*x^n)^(1/n))^3/(b*(c*x^n)^(1/n))
+--R 
+--R
+--R                   1 3                 1 2                1
+--R                   -                   -                  -
+--R         3       n n         2       n n       2        n n    3
+--R        b x ((c x ) )  + 3a b x ((c x ) )  + 3a b x (c x )  + a x
+--R   (2)  ---------------------------------------------------------
+--R                                         1
+--R                                         -
+--R                                       n n
+--R                                3b (c x )
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R               log(c) 2            log(c)
+--R               ------              ------
+--R         2 3      n             2     n       2
+--R        b x (%e      )  + 3a b x %e       + 3a x
+--R   (3)  ----------------------------------------
+--R                            3
+--R                                         Type: Union(Expression(Integer),...)
+--E 758
+
+--S 759 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    1 3                 1 2
+--R                    -                   -
+--R          3       n n         2       n n
+--R       - b x ((c x ) )  - 3a b x ((c x ) )
+--R     + 
+--R               log(c) 2            log(c)       1
+--R               ------              ------       -
+--R         3 3      n           2 2     n       n n    3
+--R       (b x (%e      )  + 3a b x %e      )(c x )  - a x
+--R  /
+--R              1
+--R              -
+--R            n n
+--R     3b (c x )
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 760
+
+)clear all
+
+--S 761 of 1004
+t0:=a+b*(c*x^n)^(1/n)
+--R 
+--R
+--R                1
+--R                -
+--R              n n
+--R   (1)  b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 1004
+r0:=a*x+1/2*b*x*(c*x^n)^(1/n)
+--R 
+--R
+--R                  1
+--R                  -
+--R                n n
+--R        b x (c x )  + 2a x
+--R   (2)  ------------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R              log(c)
+--R              ------
+--R           2     n
+--R        b x %e       + 2a x
+--R   (3)  -------------------
+--R                 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 763
+
+--S 764 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                    1         log(c)
+--R                    -         ------
+--R                  n n      2     n
+--R        - b x (c x )  + b x %e
+--R   (4)  ----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 765
+
+)clear all
+
+--S 766 of 1004
+t0:=1/(a+b*(c*x^n)^(1/n))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R                1
+--R                -
+--R              n n
+--R        b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 1004
+r0:=x*log(a+b*(c*x^n)^(1/n))/(b*(c*x^n)^(1/n))
+--R 
+--R
+--R                      1
+--R                      -
+--R                    n n
+--R        x log(b (c x )  + a)
+--R   (2)  --------------------
+--R                      1
+--R                      -
+--R                    n n
+--R              b (c x )
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  log(c)
+--R                  ------
+--R                     n
+--R        log(b x %e       + a)
+--R   (3)  ---------------------
+--R                  log(c)
+--R                  ------
+--R                     n
+--R              b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 768
+
+--S 769 of 1004
+m0:=a0-r0
+--R 
+--R
+--R              log(c)            1              1          log(c)
+--R              ------            -              -          ------
+--R                 n            n n            n n             n
+--R        - x %e      log(b (c x )  + a) + (c x ) log(b x %e       + a)
+--R   (4)  -------------------------------------------------------------
+--R                                  log(c)      1
+--R                                  ------      -
+--R                                     n      n n
+--R                              b %e      (c x )
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 770
+
+)clear all
+
+--S 771 of 1004
+t0:=1/(a+b*(c*x^n)^(1/n))^2
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R                 1 2              1
+--R                 -                -
+--R         2     n n              n n    2
+--R        b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 771
+
+--S 772 of 1004
+r0a:=x/(a^2+a*b*(c*x^n)^(1/n))
+--R 
+--R
+--R                x
+--R   (2)  ----------------
+--R                  1
+--R                  -
+--R                n n    2
+--R        a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1004
+r0b:=-x/(b*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n)))
+--R 
+--R
+--R                       x
+--R   (3)  - --------------------------
+--R                   1 2             1
+--R                   -               -
+--R           2     n n             n n
+--R          b ((c x ) )  + a b (c x )
+--R                                                    Type: Expression(Integer)
+--E 773
+
+--S 774 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         1
+--R   (4)  - ------------------------------
+--R                 log(c) 2         log(c)
+--R                 ------           ------
+--R           2        n                n
+--R          b x (%e      )  + a b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 774
+
+--S 775 of 1004
+m0a:=a0-r0a
+--R 
+--R
+--R   (5)
+--R                           1          log(c) 2           log(c)
+--R                           -          ------             ------
+--R                         n n    2 2      n                  n      2
+--R               - a b (c x )  - b x (%e      )  - a b x %e       - a
+--R   ----------------------------------------------------------------------------
+--R             log(c) 2         log(c)       1            log(c) 2         log(c)
+--R             ------           ------       -            ------           ------
+--R       3        n        2 2     n       n n    2 2        n        3       n
+--R   (a b x (%e      )  + a b %e      )(c x )  + a b x (%e      )  + a b %e
+--R                                                    Type: Expression(Integer)
+--E 775
+
+--S 776 of 1004
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (6)
+--R                  1 2             log(c) 2            log(c)             1
+--R                  -               ------              ------             -
+--R          2     n n         3 2      n           2       n      2      n n
+--R       a b ((c x ) )  + (- b x (%e      )  - 2a b x %e       + a b)(c x )
+--R     + 
+--R                         log(c) 2                    log(c)
+--R                         ------                      ------
+--R           3   3 n - 1      n           2   2 n - 1     n      2       n - 1
+--R         (b c x x     (%e      )  + 2a b c x x     %e       + a b c x x     )
+--R      *
+--R               - n + 1
+--R               -------
+--R             n    n
+--R         (c x )
+--R     + 
+--R                  log(c) 2            log(c)
+--R                  ------              ------
+--R            2 2      n         2         n
+--R       - a b x (%e      )  - 2a b x %e
+--R  /
+--R                 log(c) 2            log(c)               1 2
+--R                 ------              ------               -
+--R           4 2      n         2 3       n      3 2      n n
+--R       (a b x (%e      )  + 2a b x %e       + a b )((c x ) )
+--R     + 
+--R                  log(c) 2            log(c)              1            log(c) 2
+--R                  ------              ------              -            ------
+--R          2 3 2      n         3 2       n       4      n n    3 2 2      n
+--R       (2a b x (%e      )  + 4a b x %e       + 2a b)(c x )  + a b x (%e      )
+--R     + 
+--R                log(c)
+--R                ------
+--R         4         n      5
+--R       2a b x %e       + a
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 1004
+m0b:=a0-r0b
+--R 
+--R
+--R   (7)
+--R                1 2           1          log(c) 2         log(c)
+--R                -             -          ------           ------
+--R              n n           n n      2      n                n
+--R     - b ((c x ) )  - a (c x )  + b x (%e      )  + a x %e
+--R  /
+--R               log(c) 2         log(c)        1 2
+--R               ------           ------        -
+--R         3        n          2     n        n n
+--R       (b x (%e      )  + a b %e      )((c x ) )
+--R     + 
+--R                 log(c) 2         log(c)       1
+--R                 ------           ------       -
+--R           2        n        2       n       n n
+--R       (a b x (%e      )  + a b %e      )(c x )
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 1004
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (8)
+--R                1 4               1 3
+--R                -                 -
+--R        3     n n         2     n n
+--R       b ((c x ) )  + 2a b ((c x ) )
+--R     + 
+--R               log(c) 2            log(c)               1 2
+--R               ------              ------               -
+--R         3 2      n           2       n       2       n n
+--R       (b x (%e      )  + 2a b x %e       + 2a b)((c x ) )
+--R     + 
+--R                                 log(c) 2                    log(c)
+--R                                 ------                      ------
+--R                   3   3 n - 1      n           2   2 n - 1     n
+--R               - 2b c x x     (%e      )  - 4a b c x x     %e
+--R             + 
+--R                   2       n - 1
+--R               - 2a b c x x
+--R          *
+--R                   - n + 1
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R         + 
+--R                    log(c) 2            log(c)
+--R                    ------              ------
+--R              2 2      n         2         n      3
+--R           a b x (%e      )  + 2a b x %e       + a
+--R      *
+--R               1
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                             log(c) 2                    log(c)
+--R                             ------                      ------
+--R               2   3 n - 1      n         2     2 n - 1     n      3     n - 1
+--R         (- a b c x x     (%e      )  - 2a b c x x     %e       - a c x x     )
+--R      *
+--R               - n + 1
+--R               -------
+--R             n    n
+--R         (c x )
+--R  /
+--R               log(c) 2            log(c)               1 4
+--R               ------              ------               -
+--R         5 2      n           4       n      2 3      n n
+--R       (b x (%e      )  + 2a b x %e       + a b )((c x ) )
+--R     + 
+--R                  log(c) 2            log(c)                1 3
+--R                  ------              ------                -
+--R            4 2      n         2 3       n       3 2      n n
+--R       (2a b x (%e      )  + 4a b x %e       + 2a b )((c x ) )
+--R     + 
+--R                 log(c) 2            log(c)              1 2
+--R                 ------              ------              -
+--R         2 3 2      n         3 2       n      4       n n
+--R       (a b x (%e      )  + 2a b x %e       + a b)((c x ) )
+--R                                                    Type: Expression(Integer)
+--E 778
+
+)clear all
+
+--S 779 of 1004
+t0:=1/(a+b*(c*x^n)^(1/n))^3
+--R 
+--R
+--R                                 1
+--R   (1)  --------------------------------------------------
+--R                 1 3               1 2              1
+--R                 -                 -                -
+--R         3     n n         2     n n       2      n n    3
+--R        b ((c x ) )  + 3a b ((c x ) )  + 3a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 1004
+r0:=-1/2*x/(b*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^2)
+--R 
+--R
+--R                                 x
+--R   (2)  - ----------------------------------------------
+--R                    1 3               1 2              1
+--R                    -                 -                -
+--R            3     n n         2     n n       2      n n
+--R          2b ((c x ) )  + 4a b ((c x ) )  + 2a b (c x )
+--R                                                    Type: Expression(Integer)
+--E 780
+
+--S 781 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                    1
+--R   (3)  - -----------------------------------------------------
+--R                  log(c) 3             log(c) 2          log(c)
+--R                  ------               ------            ------
+--R            3 2      n           2        n         2       n
+--R          2b x (%e      )  + 4a b x (%e      )  + 2a b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 781
+
+--S 782 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  1 3               1 2           1          log(c) 3
+--R                  -                 -             -          ------
+--R          2     n n               n n      2    n n    2 3      n
+--R       - b ((c x ) )  - 2a b ((c x ) )  - a (c x )  + b x (%e      )
+--R     + 
+--R                 log(c) 2         log(c)
+--R                 ------           ------
+--R             2      n        2       n
+--R       2a b x (%e      )  + a x %e
+--R  /
+--R                log(c) 3             log(c) 2          log(c)        1 3
+--R                ------               ------            ------        -
+--R          5 2      n           4        n         2 3     n        n n
+--R       (2b x (%e      )  + 4a b x (%e      )  + 2a b %e      )((c x ) )
+--R     + 
+--R                  log(c) 3             log(c) 2          log(c)        1 2
+--R                  ------               ------            ------        -
+--R            4 2      n         2 3        n         3 2     n        n n
+--R       (4a b x (%e      )  + 8a b x (%e      )  + 4a b %e      )((c x ) )
+--R     + 
+--R                  log(c) 3             log(c) 2          log(c)       1
+--R                  ------               ------            ------       -
+--R          2 3 2      n         3 2        n         4       n       n n
+--R       (2a b x (%e      )  + 4a b x (%e      )  + 2a b %e      )(c x )
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 783
+
+)clear all
+
+--S 784 of 1004
+t0:=(a+b*(c*x^n)^(2/n))^3
+--R 
+--R
+--R                 2 3               2 2              2
+--R                 -                 -                -
+--R         3     n n         2     n n       2      n n    3
+--R   (1)  b ((c x ) )  + 3a b ((c x ) )  + 3a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 1004
+r0:=a^3*x+a^2*b*x*(c*x^n)^(2/n)+3/5*a*b^2*x*(c*x^n)^(4/n)+_
+   1/7*b^3*x*(c*x^n)^(6/n)
+--R 
+--R
+--R                   6                 4                 2
+--R                   -                 -                 -
+--R          3      n n        2      n n      2        n n      3
+--R        5b x (c x )  + 21a b x (c x )  + 35a b x (c x )  + 35a x
+--R   (2)  --------------------------------------------------------
+--R                                   35
+--R                                                    Type: Expression(Integer)
+--E 785
+
+--S 786 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2log(c) 3              2log(c) 2             2log(c)
+--R                -------                -------               -------
+--R          3 7      n             2 5      n           2   3     n         3
+--R        5b x (%e       )  + 21a b x (%e       )  + 35a b x %e        + 35a x
+--R   (3)  --------------------------------------------------------------------
+--R                                         35
+--R                                         Type: Union(Expression(Integer),...)
+--E 786
+
+--S 787 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    6                 4                 2           2log(c) 3
+--R                    -                 -                 -           -------
+--R           3      n n        2      n n      2        n n     3 7      n
+--R       - 5b x (c x )  - 21a b x (c x )  - 35a b x (c x )  + 5b x (%e       )
+--R     + 
+--R                  2log(c) 2             2log(c)
+--R                  -------               -------
+--R            2 5      n           2   3     n
+--R       21a b x (%e       )  + 35a b x %e
+--R  /
+--R     35
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 788
+
+)clear all
+
+--S 789 of 1004
+t0:=(a+b*(c*x^n)^(2/n))^2
+--R 
+--R
+--R                 2 2              2
+--R                 -                -
+--R         2     n n              n n    2
+--R   (1)  b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 1004
+r0:=a^2*x+2/3*a*b*x*(c*x^n)^(2/n)+1/5*b^2*x*(c*x^n)^(4/n)
+--R 
+--R
+--R                   4                 2
+--R                   -                 -
+--R          2      n n               n n      2
+--R        3b x (c x )  + 10a b x (c x )  + 15a x
+--R   (2)  --------------------------------------
+--R                          15
+--R                                                    Type: Expression(Integer)
+--E 790
+
+--S 791 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2log(c) 2             2log(c)
+--R                -------               -------
+--R          2 5      n               3     n         2
+--R        3b x (%e       )  + 10a b x %e        + 15a x
+--R   (3)  ---------------------------------------------
+--R                              15
+--R                                         Type: Union(Expression(Integer),...)
+--E 791
+
+--S 792 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                4                 2           2log(c) 2             2log(c)
+--R                -                 -           -------               -------
+--R       2      n n               n n     2 5      n               3     n
+--R   - 3b x (c x )  - 10a b x (c x )  + 3b x (%e       )  + 10a b x %e
+--R   ------------------------------------------------------------------------
+--R                                      15
+--R                                                    Type: Expression(Integer)
+--E 792
+
+--S 793 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 793
+
+)clear all
+
+--S 794 of 1004
+t0:=a+b*(c*x^n)^(2/n)
+--R 
+--R
+--R                2
+--R                -
+--R              n n
+--R   (1)  b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 1004
+r0:=a*x+1/3*b*x*(c*x^n)^(2/n)
+--R 
+--R
+--R                  2
+--R                  -
+--R                n n
+--R        b x (c x )  + 3a x
+--R   (2)  ------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 795
+
+--S 796 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2log(c)
+--R              -------
+--R           3     n
+--R        b x %e        + 3a x
+--R   (3)  --------------------
+--R                  3
+--R                                         Type: Union(Expression(Integer),...)
+--E 796
+
+--S 797 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                    2         2log(c)
+--R                    -         -------
+--R                  n n      3     n
+--R        - b x (c x )  + b x %e
+--R   (4)  -----------------------------
+--R                      3
+--R                                                    Type: Expression(Integer)
+--E 797
+
+--S 798 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 798
+
+)clear all
+
+--S 799 of 1004
+t0:=1/(a+b*(c*x^n)^(2/n))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R                2
+--R                -
+--R              n n
+--R        b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 799
+
+--S 800 of 1004
+r0:=x*atan((c*x^n)^(1/n)*sqrt(b)/sqrt(a))/((c*x^n)^(1/n)*sqrt(a)*sqrt(b))
+--R 
+--R
+--R                         1
+--R                         -
+--R                +-+    n n
+--R               \|b (c x )
+--R        x atan(-----------)
+--R                    +-+
+--R                   \|a
+--R   (2)  -------------------
+--R                        1
+--R                        -
+--R           +-+ +-+    n n
+--R          \|a \|b (c x )
+--R                                                    Type: Expression(Integer)
+--E 800
+
+--S 801 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                            +---------------+
+--R               2log(c)      |        2log(c)             2log(c)
+--R               -------      |        -------             -------
+--R            2     n         |           n                   n
+--R        (b x %e        - a)\|- a b %e         + 2a b x %e
+--R    log(--------------------------------------------------------)
+--R                                  2log(c)
+--R                                  -------
+--R                               2     n
+--R                            b x %e        + a
+--R   [-------------------------------------------------------------,
+--R                           +---------------+
+--R                           |        2log(c)
+--R                           |        -------
+--R                           |           n
+--R                         2\|- a b %e
+--R           +-------------+
+--R           |      2log(c)
+--R           |      -------
+--R           |         n
+--R         x\|a b %e
+--R    atan(-----------------)
+--R                 a
+--R    -----------------------]
+--R         +-------------+
+--R         |      2log(c)
+--R         |      -------
+--R         |         n
+--R        \|a b %e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 801
+
+--S 802 of 1004
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       1
+--R                       -
+--R          +-+ +-+    n n
+--R         \|a \|b (c x )
+--R      *
+--R                                 +---------------+
+--R                    2log(c)      |        2log(c)             2log(c)
+--R                    -------      |        -------             -------
+--R                 2     n         |           n                   n
+--R             (b x %e        - a)\|- a b %e         + 2a b x %e
+--R         log(--------------------------------------------------------)
+--R                                       2log(c)
+--R                                       -------
+--R                                    2     n
+--R                                 b x %e        + a
+--R     + 
+--R                           1  +---------------+
+--R                           -  |        2log(c)
+--R                  +-+    n n  |        -------
+--R                 \|b (c x )   |           n
+--R       - 2x atan(-----------)\|- a b %e
+--R                      +-+
+--R                     \|a
+--R  /
+--R                      +---------------+
+--R                    1 |        2log(c)
+--R                    - |        -------
+--R       +-+ +-+    n n |           n
+--R     2\|a \|b (c x ) \|- a b %e
+--R                                                    Type: Expression(Integer)
+--E 802
+
+--S 803 of 1004
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                            2log(c)                      1 3
+--R                            -------                      -
+--R               2 2 +-+ +-+     n          +-+ +-+      n n
+--R           (- b x \|a \|b %e        - a b\|a \|b )((c x ) )
+--R         + 
+--R                                    2log(c)
+--R                                    -------
+--R               2   3 n - 1 +-+ +-+     n               n - 1 +-+ +-+
+--R             (b c x x     \|a \|b %e        + a b c x x     \|a \|b )
+--R          *
+--R                   - n + 1       1 2
+--R                   -------       -
+--R                 n    n        n n
+--R             (c x )       ((c x ) )
+--R         + 
+--R                              2log(c)                    1
+--R                              -------                    -
+--R                   2 +-+ +-+     n       2 +-+ +-+     n n
+--R           (- a b x \|a \|b %e        - a \|a \|b )(c x )
+--R         + 
+--R                                  2log(c)                              - n + 1
+--R                                  -------                              -------
+--R                 3 n - 1 +-+ +-+     n       2     n - 1 +-+ +-+     n    n
+--R         (a b c x x     \|a \|b %e        + a c x x     \|a \|b )(c x )
+--R      *
+--R                        1
+--R                        -
+--R               +-+    n n
+--R              \|b (c x )
+--R         atan(-----------)
+--R                   +-+
+--R                  \|a
+--R     + 
+--R                  1 4              1 2
+--R                  -                -
+--R          2     n n      2       n n
+--R       a b ((c x ) )  + a b ((c x ) )
+--R     + 
+--R                          2log(c)                        - n + 1      1
+--R                          -------                        -------      -
+--R             2   3 n - 1     n       2       n - 1     n    n       n n
+--R       (- a b c x x     %e        - a b c x x     )(c x )       (c x )
+--R  /
+--R              2log(c)               1 4            2log(c)              1 2
+--R              -------               -              -------              -
+--R         3 2     n       2 2      n n       2 2 2     n       3       n n
+--R     (a b x %e        + a b )((c x ) )  + (a b x %e        + a b)((c x ) )
+--R                                                    Type: Expression(Integer)
+--E 803
+
+--S 804 of 1004
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         +-------------+
+--R                         |      2log(c)                      1  +-------------+
+--R                 1       |      -------                      -  |      2log(c)
+--R                 -       |         n                +-+    n n  |      -------
+--R    +-+ +-+    n n     x\|a b %e                   \|b (c x )   |         n
+--R   \|a \|b (c x ) atan(-----------------) - x atan(-----------)\|a b %e
+--R                               a                        +-+
+--R                                                       \|a
+--R   ----------------------------------------------------------------------------
+--R                                          +-------------+
+--R                                        1 |      2log(c)
+--R                                        - |      -------
+--R                           +-+ +-+    n n |         n
+--R                          \|a \|b (c x ) \|a b %e
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 1004
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                            2log(c)                      1 3
+--R                            -------                      -
+--R               2 2 +-+ +-+     n          +-+ +-+      n n
+--R           (- b x \|a \|b %e        - a b\|a \|b )((c x ) )
+--R         + 
+--R                                    2log(c)
+--R                                    -------
+--R               2   3 n - 1 +-+ +-+     n               n - 1 +-+ +-+
+--R             (b c x x     \|a \|b %e        + a b c x x     \|a \|b )
+--R          *
+--R                   - n + 1       1 2
+--R                   -------       -
+--R                 n    n        n n
+--R             (c x )       ((c x ) )
+--R         + 
+--R                              2log(c)                    1
+--R                              -------                    -
+--R                   2 +-+ +-+     n       2 +-+ +-+     n n
+--R           (- a b x \|a \|b %e        - a \|a \|b )(c x )
+--R         + 
+--R                                  2log(c)                              - n + 1
+--R                                  -------                              -------
+--R                 3 n - 1 +-+ +-+     n       2     n - 1 +-+ +-+     n    n
+--R         (a b c x x     \|a \|b %e        + a c x x     \|a \|b )(c x )
+--R      *
+--R                        1
+--R                        -
+--R               +-+    n n
+--R              \|b (c x )
+--R         atan(-----------)
+--R                   +-+
+--R                  \|a
+--R     + 
+--R                  1 4              1 2
+--R                  -                -
+--R          2     n n      2       n n
+--R       a b ((c x ) )  + a b ((c x ) )
+--R     + 
+--R                          2log(c)                        - n + 1      1
+--R                          -------                        -------      -
+--R             2   3 n - 1     n       2       n - 1     n    n       n n
+--R       (- a b c x x     %e        - a b c x x     )(c x )       (c x )
+--R  /
+--R              2log(c)               1 4            2log(c)              1 2
+--R              -------               -              -------              -
+--R         3 2     n       2 2      n n       2 2 2     n       3       n n
+--R     (a b x %e        + a b )((c x ) )  + (a b x %e        + a b)((c x ) )
+--R                                                    Type: Expression(Integer)
+--E 805
+
+)clear all
+
+--S 806 of 1004
+t0:=1/(a+b*(c*x^n)^(2/n))^2
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R                 2 2              2
+--R                 -                -
+--R         2     n n              n n    2
+--R        b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 1004
+r0:=1/2*x/(a*(a+b*(c*x^n)^(2/n)))+1/2*x*atan((c*x^n)^(1/n)*_
+   sqrt(b)/sqrt(a))/(a^(3/2)*(c*x^n)^(1/n)*sqrt(b))
+--R 
+--R
+--R                                          1
+--R                   2                      -                   1
+--R                   -             +-+    n n                   -
+--R                 n n            \|b (c x )       +-+ +-+    n n
+--R        (b x (c x )  + a x)atan(-----------) + x\|a \|b (c x )
+--R                                     +-+
+--R                                    \|a
+--R   (2)  -------------------------------------------------------
+--R                              1      2                    1
+--R                              -      -                    -
+--R                 +-+ +-+    n n    n n     2 +-+ +-+    n n
+--R            2a b\|a \|b (c x ) (c x )  + 2a \|a \|b (c x )
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  2log(c)
+--R                  -------
+--R               2     n
+--R           (b x %e        + a)
+--R        *
+--R                                   +---------------+
+--R                      2log(c)      |        2log(c)             2log(c)
+--R                      -------      |        -------             -------
+--R                   2     n         |           n                   n
+--R               (b x %e        - a)\|- a b %e         + 2a b x %e
+--R           log(--------------------------------------------------------)
+--R                                         2log(c)
+--R                                         -------
+--R                                      2     n
+--R                                   b x %e        + a
+--R       + 
+--R            +---------------+
+--R            |        2log(c)
+--R            |        -------
+--R            |           n
+--R         2x\|- a b %e
+--R    /
+--R                                +---------------+
+--R                 2log(c)        |        2log(c)
+--R                 -------        |        -------
+--R              2     n        2  |           n
+--R       (4a b x %e        + 4a )\|- a b %e
+--R     ,
+--R                              +-------------+
+--R                              |      2log(c)       +-------------+
+--R           2log(c)            |      -------       |      2log(c)
+--R           -------            |         n          |      -------
+--R        2     n             x\|a b %e              |         n
+--R    (b x %e        + a)atan(-----------------) + x\|a b %e
+--R                                    a
+--R    --------------------------------------------------------------]
+--R                                        +-------------+
+--R                         2log(c)        |      2log(c)
+--R                         -------        |      -------
+--R                      2     n        2  |         n
+--R               (2a b x %e        + 2a )\|a b %e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 808
+
+--S 809 of 1004
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          2log(c)                     1      2
+--R                          -------                     -      -
+--R             2 2 +-+ +-+     n          +-+ +-+     n n    n n
+--R           (b x \|a \|b %e        + a b\|a \|b )(c x ) (c x )
+--R         + 
+--R                            2log(c)                    1
+--R                            -------                    -
+--R                 2 +-+ +-+     n       2 +-+ +-+     n n
+--R           (a b x \|a \|b %e        + a \|a \|b )(c x )
+--R      *
+--R                                 +---------------+
+--R                    2log(c)      |        2log(c)             2log(c)
+--R                    -------      |        -------             -------
+--R                 2     n         |           n                   n
+--R             (b x %e        - a)\|- a b %e         + 2a b x %e
+--R         log(--------------------------------------------------------)
+--R                                       2log(c)
+--R                                       -------
+--R                                    2     n
+--R                                 b x %e        + a
+--R     + 
+--R                        2log(c)                2            2log(c)
+--R                        -------                -            -------
+--R                   2 3     n                 n n         3     n        2
+--R             ((- 2b x %e        - 2a b x)(c x )  - 2a b x %e        - 2a x)
+--R          *
+--R                            1
+--R                            -
+--R                   +-+    n n
+--R                  \|b (c x )
+--R             atan(-----------)
+--R                       +-+
+--R                      \|a
+--R         + 
+--R                             1      2                  2log(c)      1
+--R                             -      -                  -------      -
+--R                +-+ +-+    n n    n n       3 +-+ +-+     n       n n
+--R           2b x\|a \|b (c x ) (c x )  - 2b x \|a \|b %e       (c x )
+--R      *
+--R          +---------------+
+--R          |        2log(c)
+--R          |        -------
+--R          |           n
+--R         \|- a b %e
+--R  /
+--R                           2log(c)                      1      2
+--R                           -------                      -      -
+--R              2 2 +-+ +-+     n        2  +-+ +-+     n n    n n
+--R         (4a b x \|a \|b %e        + 4a b\|a \|b )(c x ) (c x )
+--R       + 
+--R                           2log(c)                     1
+--R                           -------                     -
+--R            2   2 +-+ +-+     n        3 +-+ +-+     n n
+--R         (4a b x \|a \|b %e        + 4a \|a \|b )(c x )
+--R    *
+--R        +---------------+
+--R        |        2log(c)
+--R        |        -------
+--R        |           n
+--R       \|- a b %e
+--R                                                    Type: Expression(Integer)
+--E 809
+
+--S 810 of 1004
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                    2log(c) 2                    2log(c)
+--R                                    -------                      -------
+--R                      5 4 +-+ +-+      n            4 2 +-+ +-+     n
+--R                   - b x \|a \|b (%e       )  - 2a b x \|a \|b %e
+--R                 + 
+--R                      2 3 +-+ +-+
+--R                   - a b \|a \|b
+--R              *
+--R                        1 3
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                          2log(c) 2
+--R                                          -------
+--R                    5   5 n - 1 +-+ +-+      n
+--R                   b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                       4   3 n - 1 +-+ +-+     n       2 3     n - 1 +-+ +-+
+--R                   2a b c x x     \|a \|b %e        + a b c x x     \|a \|b
+--R              *
+--R                       - n + 1       1 2
+--R                       -------       -
+--R                     n    n        n n
+--R                 (c x )       ((c x ) )
+--R             + 
+--R                                      2log(c) 2                    2log(c)
+--R                                      -------                      -------
+--R                        4 4 +-+ +-+      n          2 3 2 +-+ +-+     n
+--R                   - a b x \|a \|b (%e       )  - 2a b x \|a \|b %e
+--R                 + 
+--R                      3 2 +-+ +-+
+--R                   - a b \|a \|b
+--R              *
+--R                       1
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                            2log(c) 2
+--R                                            -------
+--R                      4   5 n - 1 +-+ +-+      n
+--R                   a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                     2 3   3 n - 1 +-+ +-+     n       3 2     n - 1 +-+ +-+
+--R                   2a b c x x     \|a \|b %e        + a b c x x     \|a \|b
+--R              *
+--R                       - n + 1
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R          *
+--R                    2 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                       2log(c) 2                    2log(c)
+--R                                       -------                      -------
+--R                         4 4 +-+ +-+      n          2 3 2 +-+ +-+     n
+--R                   - 2a b x \|a \|b (%e       )  - 4a b x \|a \|b %e
+--R                 + 
+--R                       3 2 +-+ +-+
+--R                   - 2a b \|a \|b
+--R              *
+--R                        1 3
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                             2log(c) 2
+--R                                             -------
+--R                       4   5 n - 1 +-+ +-+      n
+--R                   2a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                     2 3   3 n - 1 +-+ +-+     n        3 2     n - 1 +-+ +-+
+--R                   4a b c x x     \|a \|b %e        + 2a b c x x     \|a \|b
+--R              *
+--R                       - n + 1       1 2
+--R                       -------       -
+--R                     n    n        n n
+--R                 (c x )       ((c x ) )
+--R             + 
+--R                                       2log(c) 2                    2log(c)
+--R                                       -------                      -------
+--R                       2 3 4 +-+ +-+      n          3 2 2 +-+ +-+     n
+--R                   - 2a b x \|a \|b (%e       )  - 4a b x \|a \|b %e
+--R                 + 
+--R                       4  +-+ +-+
+--R                   - 2a b\|a \|b
+--R              *
+--R                       1
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                             2log(c) 2
+--R                                             -------
+--R                     2 3   5 n - 1 +-+ +-+      n
+--R                   2a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                     3 2   3 n - 1 +-+ +-+     n        4       n - 1 +-+ +-+
+--R                   4a b c x x     \|a \|b %e        + 2a b c x x     \|a \|b
+--R              *
+--R                       - n + 1
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R          *
+--R                   2
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                                  2log(c) 2                    2log(c)
+--R                                  -------                      -------
+--R                  2 3 4 +-+ +-+      n          3 2 2 +-+ +-+     n
+--R               - a b x \|a \|b (%e       )  - 2a b x \|a \|b %e
+--R             + 
+--R                  4  +-+ +-+
+--R               - a b\|a \|b
+--R          *
+--R                    1 3
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                        2log(c) 2
+--R                                        -------
+--R                2 3   5 n - 1 +-+ +-+      n
+--R               a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                        2log(c)
+--R                                        -------
+--R                 3 2   3 n - 1 +-+ +-+     n       4       n - 1 +-+ +-+
+--R               2a b c x x     \|a \|b %e        + a b c x x     \|a \|b
+--R          *
+--R                   - n + 1       1 2
+--R                   -------       -
+--R                 n    n        n n
+--R             (c x )       ((c x ) )
+--R         + 
+--R                                  2log(c) 2                    2log(c)
+--R                                  -------                      -------
+--R                  3 2 4 +-+ +-+      n          4   2 +-+ +-+     n
+--R               - a b x \|a \|b (%e       )  - 2a b x \|a \|b %e
+--R             + 
+--R                  5 +-+ +-+
+--R               - a \|a \|b
+--R          *
+--R                   1
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                                        2log(c) 2
+--R                                        -------
+--R                3 2   5 n - 1 +-+ +-+      n
+--R               a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                        2log(c)
+--R                                        -------
+--R                 4     3 n - 1 +-+ +-+     n       5     n - 1 +-+ +-+
+--R               2a b c x x     \|a \|b %e        + a c x x     \|a \|b
+--R          *
+--R                   - n + 1
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R      *
+--R                        1
+--R                        -
+--R               +-+    n n
+--R              \|b (c x )
+--R         atan(-----------)
+--R                   +-+
+--R                  \|a
+--R     + 
+--R                       1 4               1 2
+--R                       -                 -
+--R             2 4     n n       3 3     n n
+--R           2a b ((c x ) )  + 2a b ((c x ) )
+--R         + 
+--R                                  2log(c) 2                    2log(c)
+--R                                  -------                      -------
+--R                    5   5 n - 1      n          2 4   3 n - 1     n
+--R               - a b c x x     (%e       )  - 2a b c x x     %e
+--R             + 
+--R                  3 3     n - 1
+--R               - a b c x x
+--R          *
+--R                   - n + 1      1
+--R                   -------      -
+--R                 n    n       n n
+--R             (c x )       (c x )
+--R      *
+--R                2 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                       2log(c) 2            2log(c)                1 4
+--R                       -------              -------                -
+--R                 5 4      n          2 4 2     n        3 3      n n
+--R           (- a b x (%e       )  - 2a b x %e        + 3a b )((c x ) )
+--R         + 
+--R                       2log(c) 2            2log(c)                1 2
+--R                       -------              -------                -
+--R               2 4 4      n          3 3 2     n        4 2      n n
+--R           (- a b x (%e       )  - 2a b x %e        + 3a b )((c x ) )
+--R         + 
+--R                                   2log(c) 2                    2log(c)
+--R                                   -------                      -------
+--R                   2 4   5 n - 1      n          3 3   3 n - 1     n
+--R               - 2a b c x x     (%e       )  - 4a b c x x     %e
+--R             + 
+--R                   4 2     n - 1
+--R               - 2a b c x x
+--R          *
+--R                   - n + 1      1
+--R                   -------      -
+--R                 n    n       n n
+--R             (c x )       (c x )
+--R      *
+--R               2
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                                 2log(c) 2                    2log(c)
+--R                                 -------                      -------
+--R                   5   5 n - 1      n          2 4   3 n - 1     n
+--R               2a b c x x     (%e       )  + 4a b c x x     %e
+--R             + 
+--R                 3 3     n - 1
+--R               2a b c x x
+--R          *
+--R                   - n + 2
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R         + 
+--R                      2log(c) 2            2log(c)
+--R                      -------              -------
+--R              2 4 4      n          3 3 2     n       4 2
+--R           - a b x (%e       )  - 2a b x %e        + a b
+--R      *
+--R                1 4
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                                 2log(c) 2                    2log(c)
+--R                                 -------                      -------
+--R                 2 4   5 n - 1      n          3 3   3 n - 1     n
+--R               2a b c x x     (%e       )  + 4a b c x x     %e
+--R             + 
+--R                 4 2     n - 1
+--R               2a b c x x
+--R          *
+--R                   - n + 2
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R         + 
+--R                      2log(c) 2            2log(c)
+--R                      -------              -------
+--R              3 3 4      n          4 2 2     n       5
+--R           - a b x (%e       )  - 2a b x %e        + a b
+--R      *
+--R                1 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                              2log(c) 2                    2log(c)
+--R                              -------                      -------
+--R              3 3   5 n - 1      n          4 2   3 n - 1     n
+--R           - a b c x x     (%e       )  - 2a b c x x     %e
+--R         + 
+--R              5       n - 1
+--R           - a b c x x
+--R      *
+--R               - n + 1      1
+--R               -------      -
+--R             n    n       n n
+--R         (c x )       (c x )
+--R  /
+--R                      2log(c) 2            2log(c)                1 4
+--R                      -------              -------                -
+--R              2 6 4      n          3 5 2     n        4 4      n n
+--R           (2a b x (%e       )  + 4a b x %e        + 2a b )((c x ) )
+--R         + 
+--R                      2log(c) 2            2log(c)                1 2
+--R                      -------              -------                -
+--R              3 5 4      n          4 4 2     n        5 3      n n
+--R           (2a b x (%e       )  + 4a b x %e        + 2a b )((c x ) )
+--R      *
+--R                2 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                      2log(c) 2            2log(c)                1 4
+--R                      -------              -------                -
+--R              3 5 4      n          4 4 2     n        5 3      n n
+--R           (4a b x (%e       )  + 8a b x %e        + 4a b )((c x ) )
+--R         + 
+--R                      2log(c) 2            2log(c)                1 2
+--R                      -------              -------                -
+--R              4 4 4      n          5 3 2     n        6 2      n n
+--R           (4a b x (%e       )  + 8a b x %e        + 4a b )((c x ) )
+--R      *
+--R               2
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                  2log(c) 2            2log(c)                1 4
+--R                  -------              -------                -
+--R          4 4 4      n          5 3 2     n        6 2      n n
+--R       (2a b x (%e       )  + 4a b x %e        + 2a b )((c x ) )
+--R     + 
+--R                  2log(c) 2            2log(c)               1 2
+--R                  -------              -------               -
+--R          5 3 4      n          6 2 2     n        7       n n
+--R       (2a b x (%e       )  + 4a b x %e        + 2a b)((c x ) )
+--R                                                    Type: Expression(Integer)
+--E 810
+
+--S 811 of 1004
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          2log(c)                     1      2
+--R                          -------                     -      -
+--R             2 2 +-+ +-+     n          +-+ +-+     n n    n n
+--R           (b x \|a \|b %e        + a b\|a \|b )(c x ) (c x )
+--R         + 
+--R                            2log(c)                    1
+--R                            -------                    -
+--R                 2 +-+ +-+     n       2 +-+ +-+     n n
+--R           (a b x \|a \|b %e        + a \|a \|b )(c x )
+--R      *
+--R                +-------------+
+--R                |      2log(c)
+--R                |      -------
+--R                |         n
+--R              x\|a b %e
+--R         atan(-----------------)
+--R                      a
+--R     + 
+--R                       2log(c)               2           2log(c)
+--R                       -------               -           -------
+--R                  2 3     n                n n        3     n       2
+--R             ((- b x %e        - a b x)(c x )  - a b x %e        - a x)
+--R          *
+--R                            1
+--R                            -
+--R                   +-+    n n
+--R                  \|b (c x )
+--R             atan(-----------)
+--R                       +-+
+--R                      \|a
+--R         + 
+--R                            1      2                 2log(c)      1
+--R                            -      -                 -------      -
+--R               +-+ +-+    n n    n n      3 +-+ +-+     n       n n
+--R           b x\|a \|b (c x ) (c x )  - b x \|a \|b %e       (c x )
+--R      *
+--R          +-------------+
+--R          |      2log(c)
+--R          |      -------
+--R          |         n
+--R         \|a b %e
+--R  /
+--R                           2log(c)                      1      2
+--R                           -------                      -      -
+--R              2 2 +-+ +-+     n        2  +-+ +-+     n n    n n
+--R         (2a b x \|a \|b %e        + 2a b\|a \|b )(c x ) (c x )
+--R       + 
+--R                           2log(c)                     1
+--R                           -------                     -
+--R            2   2 +-+ +-+     n        3 +-+ +-+     n n
+--R         (2a b x \|a \|b %e        + 2a \|a \|b )(c x )
+--R    *
+--R        +-------------+
+--R        |      2log(c)
+--R        |      -------
+--R        |         n
+--R       \|a b %e
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 1004
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                    2log(c) 2                    2log(c)
+--R                                    -------                      -------
+--R                      5 4 +-+ +-+      n            4 2 +-+ +-+     n
+--R                   - b x \|a \|b (%e       )  - 2a b x \|a \|b %e
+--R                 + 
+--R                      2 3 +-+ +-+
+--R                   - a b \|a \|b
+--R              *
+--R                        1 3
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                          2log(c) 2
+--R                                          -------
+--R                    5   5 n - 1 +-+ +-+      n
+--R                   b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                       4   3 n - 1 +-+ +-+     n       2 3     n - 1 +-+ +-+
+--R                   2a b c x x     \|a \|b %e        + a b c x x     \|a \|b
+--R              *
+--R                       - n + 1       1 2
+--R                       -------       -
+--R                     n    n        n n
+--R                 (c x )       ((c x ) )
+--R             + 
+--R                                      2log(c) 2                    2log(c)
+--R                                      -------                      -------
+--R                        4 4 +-+ +-+      n          2 3 2 +-+ +-+     n
+--R                   - a b x \|a \|b (%e       )  - 2a b x \|a \|b %e
+--R                 + 
+--R                      3 2 +-+ +-+
+--R                   - a b \|a \|b
+--R              *
+--R                       1
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                            2log(c) 2
+--R                                            -------
+--R                      4   5 n - 1 +-+ +-+      n
+--R                   a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                     2 3   3 n - 1 +-+ +-+     n       3 2     n - 1 +-+ +-+
+--R                   2a b c x x     \|a \|b %e        + a b c x x     \|a \|b
+--R              *
+--R                       - n + 1
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R          *
+--R                    2 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                       2log(c) 2                    2log(c)
+--R                                       -------                      -------
+--R                         4 4 +-+ +-+      n          2 3 2 +-+ +-+     n
+--R                   - 2a b x \|a \|b (%e       )  - 4a b x \|a \|b %e
+--R                 + 
+--R                       3 2 +-+ +-+
+--R                   - 2a b \|a \|b
+--R              *
+--R                        1 3
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                             2log(c) 2
+--R                                             -------
+--R                       4   5 n - 1 +-+ +-+      n
+--R                   2a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                     2 3   3 n - 1 +-+ +-+     n        3 2     n - 1 +-+ +-+
+--R                   4a b c x x     \|a \|b %e        + 2a b c x x     \|a \|b
+--R              *
+--R                       - n + 1       1 2
+--R                       -------       -
+--R                     n    n        n n
+--R                 (c x )       ((c x ) )
+--R             + 
+--R                                       2log(c) 2                    2log(c)
+--R                                       -------                      -------
+--R                       2 3 4 +-+ +-+      n          3 2 2 +-+ +-+     n
+--R                   - 2a b x \|a \|b (%e       )  - 4a b x \|a \|b %e
+--R                 + 
+--R                       4  +-+ +-+
+--R                   - 2a b\|a \|b
+--R              *
+--R                       1
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                             2log(c) 2
+--R                                             -------
+--R                     2 3   5 n - 1 +-+ +-+      n
+--R                   2a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                     3 2   3 n - 1 +-+ +-+     n        4       n - 1 +-+ +-+
+--R                   4a b c x x     \|a \|b %e        + 2a b c x x     \|a \|b
+--R              *
+--R                       - n + 1
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R          *
+--R                   2
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                                  2log(c) 2                    2log(c)
+--R                                  -------                      -------
+--R                  2 3 4 +-+ +-+      n          3 2 2 +-+ +-+     n
+--R               - a b x \|a \|b (%e       )  - 2a b x \|a \|b %e
+--R             + 
+--R                  4  +-+ +-+
+--R               - a b\|a \|b
+--R          *
+--R                    1 3
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                        2log(c) 2
+--R                                        -------
+--R                2 3   5 n - 1 +-+ +-+      n
+--R               a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                        2log(c)
+--R                                        -------
+--R                 3 2   3 n - 1 +-+ +-+     n       4       n - 1 +-+ +-+
+--R               2a b c x x     \|a \|b %e        + a b c x x     \|a \|b
+--R          *
+--R                   - n + 1       1 2
+--R                   -------       -
+--R                 n    n        n n
+--R             (c x )       ((c x ) )
+--R         + 
+--R                                  2log(c) 2                    2log(c)
+--R                                  -------                      -------
+--R                  3 2 4 +-+ +-+      n          4   2 +-+ +-+     n
+--R               - a b x \|a \|b (%e       )  - 2a b x \|a \|b %e
+--R             + 
+--R                  5 +-+ +-+
+--R               - a \|a \|b
+--R          *
+--R                   1
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                                        2log(c) 2
+--R                                        -------
+--R                3 2   5 n - 1 +-+ +-+      n
+--R               a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                        2log(c)
+--R                                        -------
+--R                 4     3 n - 1 +-+ +-+     n       5     n - 1 +-+ +-+
+--R               2a b c x x     \|a \|b %e        + a c x x     \|a \|b
+--R          *
+--R                   - n + 1
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R      *
+--R                        1
+--R                        -
+--R               +-+    n n
+--R              \|b (c x )
+--R         atan(-----------)
+--R                   +-+
+--R                  \|a
+--R     + 
+--R                       1 4               1 2
+--R                       -                 -
+--R             2 4     n n       3 3     n n
+--R           2a b ((c x ) )  + 2a b ((c x ) )
+--R         + 
+--R                                  2log(c) 2                    2log(c)
+--R                                  -------                      -------
+--R                    5   5 n - 1      n          2 4   3 n - 1     n
+--R               - a b c x x     (%e       )  - 2a b c x x     %e
+--R             + 
+--R                  3 3     n - 1
+--R               - a b c x x
+--R          *
+--R                   - n + 1      1
+--R                   -------      -
+--R                 n    n       n n
+--R             (c x )       (c x )
+--R      *
+--R                2 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                       2log(c) 2            2log(c)                1 4
+--R                       -------              -------                -
+--R                 5 4      n          2 4 2     n        3 3      n n
+--R           (- a b x (%e       )  - 2a b x %e        + 3a b )((c x ) )
+--R         + 
+--R                       2log(c) 2            2log(c)                1 2
+--R                       -------              -------                -
+--R               2 4 4      n          3 3 2     n        4 2      n n
+--R           (- a b x (%e       )  - 2a b x %e        + 3a b )((c x ) )
+--R         + 
+--R                                   2log(c) 2                    2log(c)
+--R                                   -------                      -------
+--R                   2 4   5 n - 1      n          3 3   3 n - 1     n
+--R               - 2a b c x x     (%e       )  - 4a b c x x     %e
+--R             + 
+--R                   4 2     n - 1
+--R               - 2a b c x x
+--R          *
+--R                   - n + 1      1
+--R                   -------      -
+--R                 n    n       n n
+--R             (c x )       (c x )
+--R      *
+--R               2
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                                 2log(c) 2                    2log(c)
+--R                                 -------                      -------
+--R                   5   5 n - 1      n          2 4   3 n - 1     n
+--R               2a b c x x     (%e       )  + 4a b c x x     %e
+--R             + 
+--R                 3 3     n - 1
+--R               2a b c x x
+--R          *
+--R                   - n + 2
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R         + 
+--R                      2log(c) 2            2log(c)
+--R                      -------              -------
+--R              2 4 4      n          3 3 2     n       4 2
+--R           - a b x (%e       )  - 2a b x %e        + a b
+--R      *
+--R                1 4
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                                 2log(c) 2                    2log(c)
+--R                                 -------                      -------
+--R                 2 4   5 n - 1      n          3 3   3 n - 1     n
+--R               2a b c x x     (%e       )  + 4a b c x x     %e
+--R             + 
+--R                 4 2     n - 1
+--R               2a b c x x
+--R          *
+--R                   - n + 2
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R         + 
+--R                      2log(c) 2            2log(c)
+--R                      -------              -------
+--R              3 3 4      n          4 2 2     n       5
+--R           - a b x (%e       )  - 2a b x %e        + a b
+--R      *
+--R                1 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                              2log(c) 2                    2log(c)
+--R                              -------                      -------
+--R              3 3   5 n - 1      n          4 2   3 n - 1     n
+--R           - a b c x x     (%e       )  - 2a b c x x     %e
+--R         + 
+--R              5       n - 1
+--R           - a b c x x
+--R      *
+--R               - n + 1      1
+--R               -------      -
+--R             n    n       n n
+--R         (c x )       (c x )
+--R  /
+--R                      2log(c) 2            2log(c)                1 4
+--R                      -------              -------                -
+--R              2 6 4      n          3 5 2     n        4 4      n n
+--R           (2a b x (%e       )  + 4a b x %e        + 2a b )((c x ) )
+--R         + 
+--R                      2log(c) 2            2log(c)                1 2
+--R                      -------              -------                -
+--R              3 5 4      n          4 4 2     n        5 3      n n
+--R           (2a b x (%e       )  + 4a b x %e        + 2a b )((c x ) )
+--R      *
+--R                2 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                      2log(c) 2            2log(c)                1 4
+--R                      -------              -------                -
+--R              3 5 4      n          4 4 2     n        5 3      n n
+--R           (4a b x (%e       )  + 8a b x %e        + 4a b )((c x ) )
+--R         + 
+--R                      2log(c) 2            2log(c)                1 2
+--R                      -------              -------                -
+--R              4 4 4      n          5 3 2     n        6 2      n n
+--R           (4a b x (%e       )  + 8a b x %e        + 4a b )((c x ) )
+--R      *
+--R               2
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                  2log(c) 2            2log(c)                1 4
+--R                  -------              -------                -
+--R          4 4 4      n          5 3 2     n        6 2      n n
+--R       (2a b x (%e       )  + 4a b x %e        + 2a b )((c x ) )
+--R     + 
+--R                  2log(c) 2            2log(c)               1 2
+--R                  -------              -------               -
+--R          5 3 4      n          6 2 2     n        7       n n
+--R       (2a b x (%e       )  + 4a b x %e        + 2a b)((c x ) )
+--R                                                    Type: Expression(Integer)
+--E 812
+
+)clear all
+
+--S 813 of 1004
+t0:=1/(a+b*(c*x^n)^(2/n))^3
+--R 
+--R
+--R                                 1
+--R   (1)  --------------------------------------------------
+--R                 2 3               2 2              2
+--R                 -                 -                -
+--R         3     n n         2     n n       2      n n    3
+--R        b ((c x ) )  + 3a b ((c x ) )  + 3a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 813
+
+--S 814 of 1004
+r0:=1/4*x/(a*(a+b*(c*x^n)^(2/n))^2)+3/8*x/(a^2*(a+b*(c*x^n)^(2/n)))+_
+   3/8*x*atan((c*x^n)^(1/n)*sqrt(b)/sqrt(a))/(a^(5/2)*(c*x^n)^(1/n)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                                                               1
+--R                    2 2                2                       -
+--R                    -                  -              +-+    n n
+--R          2       n n                n n     2       \|b (c x )
+--R       (3b x ((c x ) )  + 6a b x (c x )  + 3a x)atan(-----------)
+--R                                                          +-+
+--R                                                         \|a
+--R     + 
+--R                         1      2                     1
+--R                         -      -                     -
+--R            +-+ +-+    n n    n n        +-+ +-+    n n
+--R       3b x\|a \|b (c x ) (c x )  + 5a x\|a \|b (c x )
+--R  /
+--R                          1       2 2                      1      2
+--R                          -       -                        -      -
+--R         2 2 +-+ +-+    n n     n n        3  +-+ +-+    n n    n n
+--R       8a b \|a \|b (c x ) ((c x ) )  + 16a b\|a \|b (c x ) (c x )
+--R     + 
+--R                        1
+--R                        -
+--R         4 +-+ +-+    n n
+--R       8a \|a \|b (c x )
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                    2log(c) 2            2log(c)
+--R                    -------              -------
+--R              2 4      n              2     n        2
+--R           (3b x (%e       )  + 6a b x %e        + 3a )
+--R        *
+--R                                   +---------------+
+--R                      2log(c)      |        2log(c)             2log(c)
+--R                      -------      |        -------             -------
+--R                   2     n         |           n                   n
+--R               (b x %e        - a)\|- a b %e         + 2a b x %e
+--R           log(--------------------------------------------------------)
+--R                                         2log(c)
+--R                                         -------
+--R                                      2     n
+--R                                   b x %e        + a
+--R       + 
+--R                                  +---------------+
+--R                 2log(c)          |        2log(c)
+--R                 -------          |        -------
+--R              3     n             |           n
+--R         (6b x %e        + 10a x)\|- a b %e
+--R    /
+--R                                                         +---------------+
+--R                   2log(c) 2             2log(c)         |        2log(c)
+--R                   -------               -------         |        -------
+--R           2 2 4      n           3   2     n         4  |           n
+--R       (16a b x (%e       )  + 32a b x %e        + 16a )\|- a b %e
+--R     ,
+--R
+--R                                                            +-------------+
+--R                                                            |      2log(c)
+--R                  2log(c) 2            2log(c)              |      -------
+--R                  -------              -------              |         n
+--R            2 4      n              2     n        2      x\|a b %e
+--R         (3b x (%e       )  + 6a b x %e        + 3a )atan(-----------------)
+--R                                                                  a
+--R       + 
+--R                                 +-------------+
+--R                 2log(c)         |      2log(c)
+--R                 -------         |      -------
+--R              3     n            |         n
+--R         (3b x %e        + 5a x)\|a b %e
+--R    /
+--R                                                       +-------------+
+--R                  2log(c) 2             2log(c)        |      2log(c)
+--R                  -------               -------        |      -------
+--R          2 2 4      n           3   2     n        4  |         n
+--R       (8a b x (%e       )  + 16a b x %e        + 8a )\|a b %e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 815
+
+--S 816 of 1004
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                               2log(c) 2                    2log(c)
+--R                               -------                      -------
+--R                 4 4 +-+ +-+      n            3 2 +-+ +-+     n
+--R               3b x \|a \|b (%e       )  + 6a b x \|a \|b %e
+--R             + 
+--R                 2 2 +-+ +-+
+--R               3a b \|a \|b
+--R          *
+--R                   1       2 2
+--R                   -       -
+--R                 n n     n n
+--R             (c x ) ((c x ) )
+--R         + 
+--R                                 2log(c) 2                     2log(c)
+--R                                 -------                       -------
+--R                   3 4 +-+ +-+      n           2 2 2 +-+ +-+     n
+--R               6a b x \|a \|b (%e       )  + 12a b x \|a \|b %e
+--R             + 
+--R                 3  +-+ +-+
+--R               6a b\|a \|b
+--R          *
+--R                   1      2
+--R                   -      -
+--R                 n n    n n
+--R             (c x ) (c x )
+--R         + 
+--R                                 2log(c) 2                    2log(c)
+--R                                 -------                      -------
+--R                 2 2 4 +-+ +-+      n          3   2 +-+ +-+     n
+--R               3a b x \|a \|b (%e       )  + 6a b x \|a \|b %e
+--R             + 
+--R                 4 +-+ +-+
+--R               3a \|a \|b
+--R          *
+--R                   1
+--R                   -
+--R                 n n
+--R             (c x )
+--R      *
+--R                                 +---------------+
+--R                    2log(c)      |        2log(c)             2log(c)
+--R                    -------      |        -------             -------
+--R                 2     n         |           n                   n
+--R             (b x %e        - a)\|- a b %e         + 2a b x %e
+--R         log(--------------------------------------------------------)
+--R                                       2log(c)
+--R                                       -------
+--R                                    2     n
+--R                                 b x %e        + a
+--R     + 
+--R                          2log(c) 2             2log(c)                 2 2
+--R                          -------               -------                 -
+--R                    4 5      n             3 3     n        2 2       n n
+--R               (- 6b x (%e       )  - 12a b x %e        - 6a b x)((c x ) )
+--R             + 
+--R                             2log(c) 2             2log(c)                 2
+--R                             -------               -------                 -
+--R                       3 5      n           2 2 3     n         3        n n
+--R               (- 12a b x (%e       )  - 24a b x %e        - 12a b x)(c x )
+--R             + 
+--R                           2log(c) 2             2log(c)
+--R                           -------               -------
+--R                   2 2 5      n           3   3     n        4
+--R               - 6a b x (%e       )  - 12a b x %e        - 6a x
+--R          *
+--R                            1
+--R                            -
+--R                   +-+    n n
+--R                  \|b (c x )
+--R             atan(-----------)
+--R                       +-+
+--R                      \|a
+--R         + 
+--R                           2log(c)                         1       2 2
+--R                           -------                         -       -
+--R              3 3 +-+ +-+     n           2  +-+ +-+     n n     n n
+--R           (6b x \|a \|b %e        + 10a b x\|a \|b )(c x ) ((c x ) )
+--R         + 
+--R                              2log(c) 2                         1      2
+--R                              -------                           -      -
+--R                3 5 +-+ +-+      n           2    +-+ +-+     n n    n n
+--R           (- 6b x \|a \|b (%e       )  + 14a b x\|a \|b )(c x ) (c x )
+--R         + 
+--R                                 2log(c) 2                     2log(c)       1
+--R                                 -------                       -------       -
+--R                   2 5 +-+ +-+      n           2   3 +-+ +-+     n        n n
+--R           (- 10a b x \|a \|b (%e       )  - 14a b x \|a \|b %e       )(c x )
+--R      *
+--R          +---------------+
+--R          |        2log(c)
+--R          |        -------
+--R          |           n
+--R         \|- a b %e
+--R  /
+--R                                2log(c) 2                     2log(c)
+--R                                -------                       -------
+--R                2 4 4 +-+ +-+      n           3 3 2 +-+ +-+     n
+--R             16a b x \|a \|b (%e       )  + 32a b x \|a \|b %e
+--R           + 
+--R                4 2 +-+ +-+
+--R             16a b \|a \|b
+--R        *
+--R                 1       2 2
+--R                 -       -
+--R               n n     n n
+--R           (c x ) ((c x ) )
+--R       + 
+--R                                2log(c) 2                     2log(c)
+--R                                -------                       -------
+--R                3 3 4 +-+ +-+      n           4 2 2 +-+ +-+     n
+--R             32a b x \|a \|b (%e       )  + 64a b x \|a \|b %e
+--R           + 
+--R                5  +-+ +-+
+--R             32a b\|a \|b
+--R        *
+--R                 1      2
+--R                 -      -
+--R               n n    n n
+--R           (c x ) (c x )
+--R       + 
+--R                                2log(c) 2                     2log(c)
+--R                                -------                       -------
+--R                4 2 4 +-+ +-+      n           5   2 +-+ +-+     n
+--R             16a b x \|a \|b (%e       )  + 32a b x \|a \|b %e
+--R           + 
+--R                6 +-+ +-+
+--R             16a \|a \|b
+--R        *
+--R                 1
+--R                 -
+--R               n n
+--R           (c x )
+--R    *
+--R        +---------------+
+--R        |        2log(c)
+--R        |        -------
+--R        |           n
+--R       \|- a b %e
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 1004
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                     2log(c) 3                     2log(c) 2
+--R                                     -------                       -------
+--R                       7 6 +-+ +-+      n            6 4 +-+ +-+      n
+--R                   - 3b x \|a \|b (%e       )  - 9a b x \|a \|b (%e       )
+--R                 + 
+--R                                      2log(c)
+--R                                      -------
+--R                       2 5 2 +-+ +-+     n        3 4 +-+ +-+
+--R                   - 9a b x \|a \|b %e        - 3a b \|a \|b
+--R              *
+--R                        1 3
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                           2log(c) 3
+--R                                           -------
+--R                     7   7 n - 1 +-+ +-+      n
+--R                   3b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c) 2
+--R                                             -------
+--R                       6   5 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                     2 5   3 n - 1 +-+ +-+     n        3 4     n - 1 +-+ +-+
+--R                   9a b c x x     \|a \|b %e        + 3a b c x x     \|a \|b
+--R              *
+--R                       - n + 1       1 2
+--R                       -------       -
+--R                     n    n        n n
+--R                 (c x )       ((c x ) )
+--R             + 
+--R                                       2log(c) 3                     2log(c) 2
+--R                                       -------                       -------
+--R                         6 6 +-+ +-+      n          2 5 4 +-+ +-+      n
+--R                   - 3a b x \|a \|b (%e       )  - 9a b x \|a \|b (%e       )
+--R                 + 
+--R                                      2log(c)
+--R                                      -------
+--R                       3 4 2 +-+ +-+     n        4 3 +-+ +-+
+--R                   - 9a b x \|a \|b %e        - 3a b \|a \|b
+--R              *
+--R                       1
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                             2log(c) 3
+--R                                             -------
+--R                       6   7 n - 1 +-+ +-+      n
+--R                   3a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c) 2
+--R                                             -------
+--R                     2 5   5 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                     3 4   3 n - 1 +-+ +-+     n        4 3     n - 1 +-+ +-+
+--R                   9a b c x x     \|a \|b %e        + 3a b c x x     \|a \|b
+--R              *
+--R                       - n + 1
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R          *
+--R                    2 3
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                       2log(c) 3                      2log(c) 2
+--R                                       -------                        -------
+--R                         6 6 +-+ +-+      n           2 5 4 +-+ +-+      n
+--R                   - 9a b x \|a \|b (%e       )  - 27a b x \|a \|b (%e       )
+--R                 + 
+--R                                       2log(c)
+--R                                       -------
+--R                        3 4 2 +-+ +-+     n        4 3 +-+ +-+
+--R                   - 27a b x \|a \|b %e        - 9a b \|a \|b
+--R              *
+--R                        1 3
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                             2log(c) 3
+--R                                             -------
+--R                       6   7 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                              2log(c) 2
+--R                                              -------
+--R                      2 5   5 n - 1 +-+ +-+      n
+--R                   27a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c)
+--R                                             -------
+--R                      3 4   3 n - 1 +-+ +-+     n        4 3     n - 1 +-+ +-+
+--R                   27a b c x x     \|a \|b %e        + 9a b c x x     \|a \|b
+--R              *
+--R                       - n + 1       1 2
+--R                       -------       -
+--R                     n    n        n n
+--R                 (c x )       ((c x ) )
+--R             + 
+--R                                       2log(c) 3                      2log(c) 2
+--R                                       -------                        -------
+--R                       2 5 6 +-+ +-+      n           3 4 4 +-+ +-+      n
+--R                   - 9a b x \|a \|b (%e       )  - 27a b x \|a \|b (%e       )
+--R                 + 
+--R                                       2log(c)
+--R                                       -------
+--R                        4 3 2 +-+ +-+     n        5 2 +-+ +-+
+--R                   - 27a b x \|a \|b %e        - 9a b \|a \|b
+--R              *
+--R                       1
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                             2log(c) 3
+--R                                             -------
+--R                     2 5   7 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                              2log(c) 2
+--R                                              -------
+--R                      3 4   5 n - 1 +-+ +-+      n
+--R                   27a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c)
+--R                                             -------
+--R                      4 3   3 n - 1 +-+ +-+     n        5 2     n - 1 +-+ +-+
+--R                   27a b c x x     \|a \|b %e        + 9a b c x x     \|a \|b
+--R              *
+--R                       - n + 1
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R          *
+--R                    2 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                       2log(c) 3                      2log(c) 2
+--R                                       -------                        -------
+--R                       2 5 6 +-+ +-+      n           3 4 4 +-+ +-+      n
+--R                   - 9a b x \|a \|b (%e       )  - 27a b x \|a \|b (%e       )
+--R                 + 
+--R                                       2log(c)
+--R                                       -------
+--R                        4 3 2 +-+ +-+     n        5 2 +-+ +-+
+--R                   - 27a b x \|a \|b %e        - 9a b \|a \|b
+--R              *
+--R                        1 3
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                             2log(c) 3
+--R                                             -------
+--R                     2 5   7 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                              2log(c) 2
+--R                                              -------
+--R                      3 4   5 n - 1 +-+ +-+      n
+--R                   27a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c)
+--R                                             -------
+--R                      4 3   3 n - 1 +-+ +-+     n        5 2     n - 1 +-+ +-+
+--R                   27a b c x x     \|a \|b %e        + 9a b c x x     \|a \|b
+--R              *
+--R                       - n + 1       1 2
+--R                       -------       -
+--R                     n    n        n n
+--R                 (c x )       ((c x ) )
+--R             + 
+--R                                       2log(c) 3                      2log(c) 2
+--R                                       -------                        -------
+--R                       3 4 6 +-+ +-+      n           4 3 4 +-+ +-+      n
+--R                   - 9a b x \|a \|b (%e       )  - 27a b x \|a \|b (%e       )
+--R                 + 
+--R                                       2log(c)
+--R                                       -------
+--R                        5 2 2 +-+ +-+     n        6  +-+ +-+
+--R                   - 27a b x \|a \|b %e        - 9a b\|a \|b
+--R              *
+--R                       1
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                             2log(c) 3
+--R                                             -------
+--R                     3 4   7 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                              2log(c) 2
+--R                                              -------
+--R                      4 3   5 n - 1 +-+ +-+      n
+--R                   27a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c)
+--R                                             -------
+--R                      5 2   3 n - 1 +-+ +-+     n        6       n - 1 +-+ +-+
+--R                   27a b c x x     \|a \|b %e        + 9a b c x x     \|a \|b
+--R              *
+--R                       - n + 1
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R          *
+--R                   2
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                                   2log(c) 3                     2log(c) 2
+--R                                   -------                       -------
+--R                   3 4 6 +-+ +-+      n          4 3 4 +-+ +-+      n
+--R               - 3a b x \|a \|b (%e       )  - 9a b x \|a \|b (%e       )
+--R             + 
+--R                                  2log(c)
+--R                                  -------
+--R                   5 2 2 +-+ +-+     n        6  +-+ +-+
+--R               - 9a b x \|a \|b %e        - 3a b\|a \|b
+--R          *
+--R                    1 3
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                         2log(c) 3
+--R                                         -------
+--R                 3 4   7 n - 1 +-+ +-+      n
+--R               3a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                         2log(c) 2
+--R                                         -------
+--R                 4 3   5 n - 1 +-+ +-+      n
+--R               9a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                        2log(c)
+--R                                        -------
+--R                 5 2   3 n - 1 +-+ +-+     n        6       n - 1 +-+ +-+
+--R               9a b c x x     \|a \|b %e        + 3a b c x x     \|a \|b
+--R          *
+--R                   - n + 1       1 2
+--R                   -------       -
+--R                 n    n        n n
+--R             (c x )       ((c x ) )
+--R         + 
+--R                                   2log(c) 3                     2log(c) 2
+--R                                   -------                       -------
+--R                   4 3 6 +-+ +-+      n          5 2 4 +-+ +-+      n
+--R               - 3a b x \|a \|b (%e       )  - 9a b x \|a \|b (%e       )
+--R             + 
+--R                                  2log(c)
+--R                                  -------
+--R                   6   2 +-+ +-+     n        7 +-+ +-+
+--R               - 9a b x \|a \|b %e        - 3a \|a \|b
+--R          *
+--R                   1
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                                         2log(c) 3
+--R                                         -------
+--R                 4 3   7 n - 1 +-+ +-+      n
+--R               3a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                         2log(c) 2
+--R                                         -------
+--R                 5 2   5 n - 1 +-+ +-+      n
+--R               9a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                        2log(c)
+--R                                        -------
+--R                 6     3 n - 1 +-+ +-+     n        7     n - 1 +-+ +-+
+--R               9a b c x x     \|a \|b %e        + 3a c x x     \|a \|b
+--R          *
+--R                   - n + 1
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R      *
+--R                        1
+--R                        -
+--R               +-+    n n
+--R              \|b (c x )
+--R         atan(-----------)
+--R                   +-+
+--R                  \|a
+--R     + 
+--R                       1 4               1 2
+--R                       -                 -
+--R             3 5     n n       4 4     n n
+--R           8a b ((c x ) )  + 8a b ((c x ) )
+--R         + 
+--R                                   2log(c) 3                     2log(c) 2
+--R                                   -------                       -------
+--R                     7   7 n - 1      n          2 6   5 n - 1      n
+--R               - 3a b c x x     (%e       )  - 9a b c x x     (%e       )
+--R             + 
+--R                                  2log(c)
+--R                                  -------
+--R                   3 5   3 n - 1     n        4 4     n - 1
+--R               - 9a b c x x     %e        - 3a b c x x
+--R          *
+--R                   - n + 1      1
+--R                   -------      -
+--R                 n    n       n n
+--R             (c x )       (c x )
+--R      *
+--R                2 3
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                           2log(c) 3             2log(c) 2            2log(c)
+--R                           -------               -------              -------
+--R                     7 6      n          2 6 4      n          3 5 2     n
+--R               - 3a b x (%e       )  - 9a b x (%e       )  - 9a b x %e
+--R             + 
+--R                  4 4
+--R               21a b
+--R          *
+--R                    1 4
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                           2log(c) 3             2log(c) 2            2log(c)
+--R                           -------               -------              -------
+--R                   2 6 6      n          3 5 4      n          4 4 2     n
+--R               - 3a b x (%e       )  - 9a b x (%e       )  - 9a b x %e
+--R             + 
+--R                  5 3
+--R               21a b
+--R          *
+--R                    1 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                   2log(c) 3                      2log(c) 2
+--R                                   -------                        -------
+--R                   2 6   7 n - 1      n           3 5   5 n - 1      n
+--R               - 9a b c x x     (%e       )  - 27a b c x x     (%e       )
+--R             + 
+--R                                   2log(c)
+--R                                   -------
+--R                    4 4   3 n - 1     n        5 3     n - 1
+--R               - 27a b c x x     %e        - 9a b c x x
+--R          *
+--R                   - n + 1      1
+--R                   -------      -
+--R                 n    n       n n
+--R             (c x )       (c x )
+--R      *
+--R                2 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                                     2log(c) 3                      2log(c) 2
+--R                                     -------                        -------
+--R                       7   7 n - 1      n           2 6   5 n - 1      n
+--R                   6a b c x x     (%e       )  + 18a b c x x     (%e       )
+--R                 + 
+--R                                     2log(c)
+--R                                     -------
+--R                      3 5   3 n - 1     n        4 4     n - 1
+--R                   18a b c x x     %e        + 6a b c x x
+--R              *
+--R                       - n + 2
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R             + 
+--R                           2log(c) 3              2log(c) 2             2log(c)
+--R                           -------                -------               -------
+--R                   2 6 6      n           3 5 4      n           4 4 2     n
+--R               - 8a b x (%e       )  - 24a b x (%e       )  - 24a b x %e
+--R             + 
+--R                  5 3
+--R               16a b
+--R          *
+--R                    1 4
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                     2log(c) 3                      2log(c) 2
+--R                                     -------                        -------
+--R                     2 6   7 n - 1      n           3 5   5 n - 1      n
+--R                   6a b c x x     (%e       )  + 18a b c x x     (%e       )
+--R                 + 
+--R                                     2log(c)
+--R                                     -------
+--R                      4 4   3 n - 1     n        5 3     n - 1
+--R                   18a b c x x     %e        + 6a b c x x
+--R              *
+--R                       - n + 2
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R             + 
+--R                           2log(c) 3              2log(c) 2             2log(c)
+--R                           -------                -------               -------
+--R                   3 5 6      n           4 4 4      n           5 3 2     n
+--R               - 8a b x (%e       )  - 24a b x (%e       )  - 24a b x %e
+--R             + 
+--R                  6 2
+--R               16a b
+--R          *
+--R                    1 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                   2log(c) 3                      2log(c) 2
+--R                                   -------                        -------
+--R                   3 5   7 n - 1      n           4 4   5 n - 1      n
+--R               - 9a b c x x     (%e       )  - 27a b c x x     (%e       )
+--R             + 
+--R                                   2log(c)
+--R                                   -------
+--R                    5 3   3 n - 1     n        6 2     n - 1
+--R               - 27a b c x x     %e        - 9a b c x x
+--R          *
+--R                   - n + 1      1
+--R                   -------      -
+--R                 n    n       n n
+--R             (c x )       (c x )
+--R      *
+--R               2
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                                  2log(c) 3                      2log(c) 2
+--R                                  -------                        -------
+--R                  2 6   7 n - 1      n           3 5   5 n - 1      n
+--R               14a b c x x     (%e       )  + 42a b c x x     (%e       )
+--R             + 
+--R                                 2log(c)
+--R                                 -------
+--R                  4 4   3 n - 1     n         5 3     n - 1
+--R               42a b c x x     %e        + 14a b c x x
+--R          *
+--R                   - n + 2
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R         + 
+--R                       2log(c) 3              2log(c) 2             2log(c)
+--R                       -------                -------               -------
+--R               3 5 6      n           4 4 4      n           5 3 2     n
+--R           - 5a b x (%e       )  - 15a b x (%e       )  - 15a b x %e
+--R         + 
+--R             6 2
+--R           3a b
+--R      *
+--R                1 4
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                                  2log(c) 3                      2log(c) 2
+--R                                  -------                        -------
+--R                  3 5   7 n - 1      n           4 4   5 n - 1      n
+--R               14a b c x x     (%e       )  + 42a b c x x     (%e       )
+--R             + 
+--R                                 2log(c)
+--R                                 -------
+--R                  5 3   3 n - 1     n         6 2     n - 1
+--R               42a b c x x     %e        + 14a b c x x
+--R          *
+--R                   - n + 2
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R         + 
+--R                     2log(c) 3              2log(c) 2             2log(c)
+--R                     -------                -------               -------
+--R             4 4 6      n           5 3 4      n           6 2 2     n        7
+--R         - 5a b x (%e       )  - 15a b x (%e       )  - 15a b x %e        + 3a b
+--R      *
+--R                1 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                               2log(c) 3                     2log(c) 2
+--R                               -------                       -------
+--R               4 4   7 n - 1      n          5 3   5 n - 1      n
+--R           - 3a b c x x     (%e       )  - 9a b c x x     (%e       )
+--R         + 
+--R                              2log(c)
+--R                              -------
+--R               6 2   3 n - 1     n        7       n - 1
+--R           - 9a b c x x     %e        - 3a b c x x
+--R      *
+--R               - n + 1      1
+--R               -------      -
+--R             n    n       n n
+--R         (c x )       (c x )
+--R  /
+--R                         2log(c) 3              2log(c) 2             2log(c)
+--R                         -------                -------               -------
+--R                 3 8 6      n           4 7 4      n           5 6 2     n
+--R               8a b x (%e       )  + 24a b x (%e       )  + 24a b x %e
+--R             + 
+--R                 6 5
+--R               8a b
+--R          *
+--R                    1 4
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                         2log(c) 3              2log(c) 2             2log(c)
+--R                         -------                -------               -------
+--R                 4 7 6      n           5 6 4      n           6 5 2     n
+--R               8a b x (%e       )  + 24a b x (%e       )  + 24a b x %e
+--R             + 
+--R                 7 4
+--R               8a b
+--R          *
+--R                    1 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R      *
+--R                2 3
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                          2log(c) 3              2log(c) 2             2log(c)
+--R                          -------                -------               -------
+--R                  4 7 6      n           5 6 4      n           6 5 2     n
+--R               24a b x (%e       )  + 72a b x (%e       )  + 72a b x %e
+--R             + 
+--R                  7 4
+--R               24a b
+--R          *
+--R                    1 4
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                          2log(c) 3              2log(c) 2             2log(c)
+--R                          -------                -------               -------
+--R                  5 6 6      n           6 5 4      n           7 4 2     n
+--R               24a b x (%e       )  + 72a b x (%e       )  + 72a b x %e
+--R             + 
+--R                  8 3
+--R               24a b
+--R          *
+--R                    1 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R      *
+--R                2 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                          2log(c) 3              2log(c) 2             2log(c)
+--R                          -------                -------               -------
+--R                  5 6 6      n           6 5 4      n           7 4 2     n
+--R               24a b x (%e       )  + 72a b x (%e       )  + 72a b x %e
+--R             + 
+--R                  8 3
+--R               24a b
+--R          *
+--R                    1 4
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                          2log(c) 3              2log(c) 2             2log(c)
+--R                          -------                -------               -------
+--R                  6 5 6      n           7 4 4      n           8 3 2     n
+--R               24a b x (%e       )  + 72a b x (%e       )  + 72a b x %e
+--R             + 
+--R                  9 2
+--R               24a b
+--R          *
+--R                    1 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R      *
+--R               2
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                       2log(c) 3              2log(c) 2             2log(c)
+--R                       -------                -------               -------
+--R               6 5 6      n           7 4 4      n           8 3 2     n
+--R             8a b x (%e       )  + 24a b x (%e       )  + 24a b x %e
+--R           + 
+--R               9 2
+--R             8a b
+--R      *
+--R                1 4
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                       2log(c) 3              2log(c) 2             2log(c)
+--R                       -------                -------               -------
+--R               7 4 6      n           8 3 4      n           9 2 2     n
+--R             8a b x (%e       )  + 24a b x (%e       )  + 24a b x %e
+--R           + 
+--R               10
+--R             8a  b
+--R      *
+--R                1 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 1004
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                               2log(c) 2                    2log(c)
+--R                               -------                      -------
+--R                 4 4 +-+ +-+      n            3 2 +-+ +-+     n
+--R               3b x \|a \|b (%e       )  + 6a b x \|a \|b %e
+--R             + 
+--R                 2 2 +-+ +-+
+--R               3a b \|a \|b
+--R          *
+--R                   1       2 2
+--R                   -       -
+--R                 n n     n n
+--R             (c x ) ((c x ) )
+--R         + 
+--R                                 2log(c) 2                     2log(c)
+--R                                 -------                       -------
+--R                   3 4 +-+ +-+      n           2 2 2 +-+ +-+     n
+--R               6a b x \|a \|b (%e       )  + 12a b x \|a \|b %e
+--R             + 
+--R                 3  +-+ +-+
+--R               6a b\|a \|b
+--R          *
+--R                   1      2
+--R                   -      -
+--R                 n n    n n
+--R             (c x ) (c x )
+--R         + 
+--R                                 2log(c) 2                    2log(c)
+--R                                 -------                      -------
+--R                 2 2 4 +-+ +-+      n          3   2 +-+ +-+     n
+--R               3a b x \|a \|b (%e       )  + 6a b x \|a \|b %e
+--R             + 
+--R                 4 +-+ +-+
+--R               3a \|a \|b
+--R          *
+--R                   1
+--R                   -
+--R                 n n
+--R             (c x )
+--R      *
+--R                +-------------+
+--R                |      2log(c)
+--R                |      -------
+--R                |         n
+--R              x\|a b %e
+--R         atan(-----------------)
+--R                      a
+--R     + 
+--R                          2log(c) 2            2log(c)                 2 2
+--R                          -------              -------                 -
+--R                    4 5      n            3 3     n        2 2       n n
+--R               (- 3b x (%e       )  - 6a b x %e        - 3a b x)((c x ) )
+--R             + 
+--R                            2log(c) 2             2log(c)                2
+--R                            -------               -------                -
+--R                      3 5      n           2 2 3     n        3        n n
+--R               (- 6a b x (%e       )  - 12a b x %e        - 6a b x)(c x )
+--R             + 
+--R                           2log(c) 2            2log(c)
+--R                           -------              -------
+--R                   2 2 5      n          3   3     n        4
+--R               - 3a b x (%e       )  - 6a b x %e        - 3a x
+--R          *
+--R                            1
+--R                            -
+--R                   +-+    n n
+--R                  \|b (c x )
+--R             atan(-----------)
+--R                       +-+
+--R                      \|a
+--R         + 
+--R                           2log(c)                        1       2 2
+--R                           -------                        -       -
+--R              3 3 +-+ +-+     n          2  +-+ +-+     n n     n n
+--R           (3b x \|a \|b %e        + 5a b x\|a \|b )(c x ) ((c x ) )
+--R         + 
+--R                              2log(c) 2                        1      2
+--R                              -------                          -      -
+--R                3 5 +-+ +-+      n          2    +-+ +-+     n n    n n
+--R           (- 3b x \|a \|b (%e       )  + 7a b x\|a \|b )(c x ) (c x )
+--R         + 
+--R                                2log(c) 2                    2log(c)       1
+--R                                -------                      -------       -
+--R                  2 5 +-+ +-+      n          2   3 +-+ +-+     n        n n
+--R           (- 5a b x \|a \|b (%e       )  - 7a b x \|a \|b %e       )(c x )
+--R      *
+--R          +-------------+
+--R          |      2log(c)
+--R          |      -------
+--R          |         n
+--R         \|a b %e
+--R  /
+--R                               2log(c) 2                     2log(c)
+--R                               -------                       -------
+--R               2 4 4 +-+ +-+      n           3 3 2 +-+ +-+     n
+--R             8a b x \|a \|b (%e       )  + 16a b x \|a \|b %e
+--R           + 
+--R               4 2 +-+ +-+
+--R             8a b \|a \|b
+--R        *
+--R                 1       2 2
+--R                 -       -
+--R               n n     n n
+--R           (c x ) ((c x ) )
+--R       + 
+--R                                2log(c) 2                     2log(c)
+--R                                -------                       -------
+--R                3 3 4 +-+ +-+      n           4 2 2 +-+ +-+     n
+--R             16a b x \|a \|b (%e       )  + 32a b x \|a \|b %e
+--R           + 
+--R                5  +-+ +-+
+--R             16a b\|a \|b
+--R        *
+--R                 1      2
+--R                 -      -
+--R               n n    n n
+--R           (c x ) (c x )
+--R       + 
+--R                                 2log(c) 2                     2log(c)
+--R                                 -------                       -------
+--R                 4 2 4 +-+ +-+      n           5   2 +-+ +-+     n
+--R               8a b x \|a \|b (%e       )  + 16a b x \|a \|b %e
+--R             + 
+--R                 6 +-+ +-+
+--R               8a \|a \|b
+--R        *
+--R                 1
+--R                 -
+--R               n n
+--R           (c x )
+--R    *
+--R        +-------------+
+--R        |      2log(c)
+--R        |      -------
+--R        |         n
+--R       \|a b %e
+--R                                                    Type: Expression(Integer)
+--E 818
+
+--S 819 of 1004
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                     2log(c) 3                     2log(c) 2
+--R                                     -------                       -------
+--R                       7 6 +-+ +-+      n            6 4 +-+ +-+      n
+--R                   - 3b x \|a \|b (%e       )  - 9a b x \|a \|b (%e       )
+--R                 + 
+--R                                      2log(c)
+--R                                      -------
+--R                       2 5 2 +-+ +-+     n        3 4 +-+ +-+
+--R                   - 9a b x \|a \|b %e        - 3a b \|a \|b
+--R              *
+--R                        1 3
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                           2log(c) 3
+--R                                           -------
+--R                     7   7 n - 1 +-+ +-+      n
+--R                   3b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c) 2
+--R                                             -------
+--R                       6   5 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                     2 5   3 n - 1 +-+ +-+     n        3 4     n - 1 +-+ +-+
+--R                   9a b c x x     \|a \|b %e        + 3a b c x x     \|a \|b
+--R              *
+--R                       - n + 1       1 2
+--R                       -------       -
+--R                     n    n        n n
+--R                 (c x )       ((c x ) )
+--R             + 
+--R                                       2log(c) 3                     2log(c) 2
+--R                                       -------                       -------
+--R                         6 6 +-+ +-+      n          2 5 4 +-+ +-+      n
+--R                   - 3a b x \|a \|b (%e       )  - 9a b x \|a \|b (%e       )
+--R                 + 
+--R                                      2log(c)
+--R                                      -------
+--R                       3 4 2 +-+ +-+     n        4 3 +-+ +-+
+--R                   - 9a b x \|a \|b %e        - 3a b \|a \|b
+--R              *
+--R                       1
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                             2log(c) 3
+--R                                             -------
+--R                       6   7 n - 1 +-+ +-+      n
+--R                   3a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c) 2
+--R                                             -------
+--R                     2 5   5 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                            2log(c)
+--R                                            -------
+--R                     3 4   3 n - 1 +-+ +-+     n        4 3     n - 1 +-+ +-+
+--R                   9a b c x x     \|a \|b %e        + 3a b c x x     \|a \|b
+--R              *
+--R                       - n + 1
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R          *
+--R                    2 3
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                       2log(c) 3                      2log(c) 2
+--R                                       -------                        -------
+--R                         6 6 +-+ +-+      n           2 5 4 +-+ +-+      n
+--R                   - 9a b x \|a \|b (%e       )  - 27a b x \|a \|b (%e       )
+--R                 + 
+--R                                       2log(c)
+--R                                       -------
+--R                        3 4 2 +-+ +-+     n        4 3 +-+ +-+
+--R                   - 27a b x \|a \|b %e        - 9a b \|a \|b
+--R              *
+--R                        1 3
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                             2log(c) 3
+--R                                             -------
+--R                       6   7 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                              2log(c) 2
+--R                                              -------
+--R                      2 5   5 n - 1 +-+ +-+      n
+--R                   27a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c)
+--R                                             -------
+--R                      3 4   3 n - 1 +-+ +-+     n        4 3     n - 1 +-+ +-+
+--R                   27a b c x x     \|a \|b %e        + 9a b c x x     \|a \|b
+--R              *
+--R                       - n + 1       1 2
+--R                       -------       -
+--R                     n    n        n n
+--R                 (c x )       ((c x ) )
+--R             + 
+--R                                       2log(c) 3                      2log(c) 2
+--R                                       -------                        -------
+--R                       2 5 6 +-+ +-+      n           3 4 4 +-+ +-+      n
+--R                   - 9a b x \|a \|b (%e       )  - 27a b x \|a \|b (%e       )
+--R                 + 
+--R                                       2log(c)
+--R                                       -------
+--R                        4 3 2 +-+ +-+     n        5 2 +-+ +-+
+--R                   - 27a b x \|a \|b %e        - 9a b \|a \|b
+--R              *
+--R                       1
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                             2log(c) 3
+--R                                             -------
+--R                     2 5   7 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                              2log(c) 2
+--R                                              -------
+--R                      3 4   5 n - 1 +-+ +-+      n
+--R                   27a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c)
+--R                                             -------
+--R                      4 3   3 n - 1 +-+ +-+     n        5 2     n - 1 +-+ +-+
+--R                   27a b c x x     \|a \|b %e        + 9a b c x x     \|a \|b
+--R              *
+--R                       - n + 1
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R          *
+--R                    2 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                       2log(c) 3                      2log(c) 2
+--R                                       -------                        -------
+--R                       2 5 6 +-+ +-+      n           3 4 4 +-+ +-+      n
+--R                   - 9a b x \|a \|b (%e       )  - 27a b x \|a \|b (%e       )
+--R                 + 
+--R                                       2log(c)
+--R                                       -------
+--R                        4 3 2 +-+ +-+     n        5 2 +-+ +-+
+--R                   - 27a b x \|a \|b %e        - 9a b \|a \|b
+--R              *
+--R                        1 3
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                             2log(c) 3
+--R                                             -------
+--R                     2 5   7 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                              2log(c) 2
+--R                                              -------
+--R                      3 4   5 n - 1 +-+ +-+      n
+--R                   27a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c)
+--R                                             -------
+--R                      4 3   3 n - 1 +-+ +-+     n        5 2     n - 1 +-+ +-+
+--R                   27a b c x x     \|a \|b %e        + 9a b c x x     \|a \|b
+--R              *
+--R                       - n + 1       1 2
+--R                       -------       -
+--R                     n    n        n n
+--R                 (c x )       ((c x ) )
+--R             + 
+--R                                       2log(c) 3                      2log(c) 2
+--R                                       -------                        -------
+--R                       3 4 6 +-+ +-+      n           4 3 4 +-+ +-+      n
+--R                   - 9a b x \|a \|b (%e       )  - 27a b x \|a \|b (%e       )
+--R                 + 
+--R                                       2log(c)
+--R                                       -------
+--R                        5 2 2 +-+ +-+     n        6  +-+ +-+
+--R                   - 27a b x \|a \|b %e        - 9a b\|a \|b
+--R              *
+--R                       1
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                             2log(c) 3
+--R                                             -------
+--R                     3 4   7 n - 1 +-+ +-+      n
+--R                   9a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                              2log(c) 2
+--R                                              -------
+--R                      4 3   5 n - 1 +-+ +-+      n
+--R                   27a b c x x     \|a \|b (%e       )
+--R                 + 
+--R                                             2log(c)
+--R                                             -------
+--R                      5 2   3 n - 1 +-+ +-+     n        6       n - 1 +-+ +-+
+--R                   27a b c x x     \|a \|b %e        + 9a b c x x     \|a \|b
+--R              *
+--R                       - n + 1
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R          *
+--R                   2
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                                   2log(c) 3                     2log(c) 2
+--R                                   -------                       -------
+--R                   3 4 6 +-+ +-+      n          4 3 4 +-+ +-+      n
+--R               - 3a b x \|a \|b (%e       )  - 9a b x \|a \|b (%e       )
+--R             + 
+--R                                  2log(c)
+--R                                  -------
+--R                   5 2 2 +-+ +-+     n        6  +-+ +-+
+--R               - 9a b x \|a \|b %e        - 3a b\|a \|b
+--R          *
+--R                    1 3
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                         2log(c) 3
+--R                                         -------
+--R                 3 4   7 n - 1 +-+ +-+      n
+--R               3a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                         2log(c) 2
+--R                                         -------
+--R                 4 3   5 n - 1 +-+ +-+      n
+--R               9a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                        2log(c)
+--R                                        -------
+--R                 5 2   3 n - 1 +-+ +-+     n        6       n - 1 +-+ +-+
+--R               9a b c x x     \|a \|b %e        + 3a b c x x     \|a \|b
+--R          *
+--R                   - n + 1       1 2
+--R                   -------       -
+--R                 n    n        n n
+--R             (c x )       ((c x ) )
+--R         + 
+--R                                   2log(c) 3                     2log(c) 2
+--R                                   -------                       -------
+--R                   4 3 6 +-+ +-+      n          5 2 4 +-+ +-+      n
+--R               - 3a b x \|a \|b (%e       )  - 9a b x \|a \|b (%e       )
+--R             + 
+--R                                  2log(c)
+--R                                  -------
+--R                   6   2 +-+ +-+     n        7 +-+ +-+
+--R               - 9a b x \|a \|b %e        - 3a \|a \|b
+--R          *
+--R                   1
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                                         2log(c) 3
+--R                                         -------
+--R                 4 3   7 n - 1 +-+ +-+      n
+--R               3a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                         2log(c) 2
+--R                                         -------
+--R                 5 2   5 n - 1 +-+ +-+      n
+--R               9a b c x x     \|a \|b (%e       )
+--R             + 
+--R                                        2log(c)
+--R                                        -------
+--R                 6     3 n - 1 +-+ +-+     n        7     n - 1 +-+ +-+
+--R               9a b c x x     \|a \|b %e        + 3a c x x     \|a \|b
+--R          *
+--R                   - n + 1
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R      *
+--R                        1
+--R                        -
+--R               +-+    n n
+--R              \|b (c x )
+--R         atan(-----------)
+--R                   +-+
+--R                  \|a
+--R     + 
+--R                       1 4               1 2
+--R                       -                 -
+--R             3 5     n n       4 4     n n
+--R           8a b ((c x ) )  + 8a b ((c x ) )
+--R         + 
+--R                                   2log(c) 3                     2log(c) 2
+--R                                   -------                       -------
+--R                     7   7 n - 1      n          2 6   5 n - 1      n
+--R               - 3a b c x x     (%e       )  - 9a b c x x     (%e       )
+--R             + 
+--R                                  2log(c)
+--R                                  -------
+--R                   3 5   3 n - 1     n        4 4     n - 1
+--R               - 9a b c x x     %e        - 3a b c x x
+--R          *
+--R                   - n + 1      1
+--R                   -------      -
+--R                 n    n       n n
+--R             (c x )       (c x )
+--R      *
+--R                2 3
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                           2log(c) 3             2log(c) 2            2log(c)
+--R                           -------               -------              -------
+--R                     7 6      n          2 6 4      n          3 5 2     n
+--R               - 3a b x (%e       )  - 9a b x (%e       )  - 9a b x %e
+--R             + 
+--R                  4 4
+--R               21a b
+--R          *
+--R                    1 4
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                           2log(c) 3             2log(c) 2            2log(c)
+--R                           -------               -------              -------
+--R                   2 6 6      n          3 5 4      n          4 4 2     n
+--R               - 3a b x (%e       )  - 9a b x (%e       )  - 9a b x %e
+--R             + 
+--R                  5 3
+--R               21a b
+--R          *
+--R                    1 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                   2log(c) 3                      2log(c) 2
+--R                                   -------                        -------
+--R                   2 6   7 n - 1      n           3 5   5 n - 1      n
+--R               - 9a b c x x     (%e       )  - 27a b c x x     (%e       )
+--R             + 
+--R                                   2log(c)
+--R                                   -------
+--R                    4 4   3 n - 1     n        5 3     n - 1
+--R               - 27a b c x x     %e        - 9a b c x x
+--R          *
+--R                   - n + 1      1
+--R                   -------      -
+--R                 n    n       n n
+--R             (c x )       (c x )
+--R      *
+--R                2 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                                     2log(c) 3                      2log(c) 2
+--R                                     -------                        -------
+--R                       7   7 n - 1      n           2 6   5 n - 1      n
+--R                   6a b c x x     (%e       )  + 18a b c x x     (%e       )
+--R                 + 
+--R                                     2log(c)
+--R                                     -------
+--R                      3 5   3 n - 1     n        4 4     n - 1
+--R                   18a b c x x     %e        + 6a b c x x
+--R              *
+--R                       - n + 2
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R             + 
+--R                           2log(c) 3              2log(c) 2             2log(c)
+--R                           -------                -------               -------
+--R                   2 6 6      n           3 5 4      n           4 4 2     n
+--R               - 8a b x (%e       )  - 24a b x (%e       )  - 24a b x %e
+--R             + 
+--R                  5 3
+--R               16a b
+--R          *
+--R                    1 4
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                     2log(c) 3                      2log(c) 2
+--R                                     -------                        -------
+--R                     2 6   7 n - 1      n           3 5   5 n - 1      n
+--R                   6a b c x x     (%e       )  + 18a b c x x     (%e       )
+--R                 + 
+--R                                     2log(c)
+--R                                     -------
+--R                      4 4   3 n - 1     n        5 3     n - 1
+--R                   18a b c x x     %e        + 6a b c x x
+--R              *
+--R                       - n + 2
+--R                       -------
+--R                     n    n
+--R                 (c x )
+--R             + 
+--R                           2log(c) 3              2log(c) 2             2log(c)
+--R                           -------                -------               -------
+--R                   3 5 6      n           4 4 4      n           5 3 2     n
+--R               - 8a b x (%e       )  - 24a b x (%e       )  - 24a b x %e
+--R             + 
+--R                  6 2
+--R               16a b
+--R          *
+--R                    1 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                   2log(c) 3                      2log(c) 2
+--R                                   -------                        -------
+--R                   3 5   7 n - 1      n           4 4   5 n - 1      n
+--R               - 9a b c x x     (%e       )  - 27a b c x x     (%e       )
+--R             + 
+--R                                   2log(c)
+--R                                   -------
+--R                    5 3   3 n - 1     n        6 2     n - 1
+--R               - 27a b c x x     %e        - 9a b c x x
+--R          *
+--R                   - n + 1      1
+--R                   -------      -
+--R                 n    n       n n
+--R             (c x )       (c x )
+--R      *
+--R               2
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                                  2log(c) 3                      2log(c) 2
+--R                                  -------                        -------
+--R                  2 6   7 n - 1      n           3 5   5 n - 1      n
+--R               14a b c x x     (%e       )  + 42a b c x x     (%e       )
+--R             + 
+--R                                 2log(c)
+--R                                 -------
+--R                  4 4   3 n - 1     n         5 3     n - 1
+--R               42a b c x x     %e        + 14a b c x x
+--R          *
+--R                   - n + 2
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R         + 
+--R                       2log(c) 3              2log(c) 2             2log(c)
+--R                       -------                -------               -------
+--R               3 5 6      n           4 4 4      n           5 3 2     n
+--R           - 5a b x (%e       )  - 15a b x (%e       )  - 15a b x %e
+--R         + 
+--R             6 2
+--R           3a b
+--R      *
+--R                1 4
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                                  2log(c) 3                      2log(c) 2
+--R                                  -------                        -------
+--R                  3 5   7 n - 1      n           4 4   5 n - 1      n
+--R               14a b c x x     (%e       )  + 42a b c x x     (%e       )
+--R             + 
+--R                                 2log(c)
+--R                                 -------
+--R                  5 3   3 n - 1     n         6 2     n - 1
+--R               42a b c x x     %e        + 14a b c x x
+--R          *
+--R                   - n + 2
+--R                   -------
+--R                 n    n
+--R             (c x )
+--R         + 
+--R                     2log(c) 3              2log(c) 2             2log(c)
+--R                     -------                -------               -------
+--R             4 4 6      n           5 3 4      n           6 2 2     n        7
+--R         - 5a b x (%e       )  - 15a b x (%e       )  - 15a b x %e        + 3a b
+--R      *
+--R                1 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                               2log(c) 3                     2log(c) 2
+--R                               -------                       -------
+--R               4 4   7 n - 1      n          5 3   5 n - 1      n
+--R           - 3a b c x x     (%e       )  - 9a b c x x     (%e       )
+--R         + 
+--R                              2log(c)
+--R                              -------
+--R               6 2   3 n - 1     n        7       n - 1
+--R           - 9a b c x x     %e        - 3a b c x x
+--R      *
+--R               - n + 1      1
+--R               -------      -
+--R             n    n       n n
+--R         (c x )       (c x )
+--R  /
+--R                         2log(c) 3              2log(c) 2             2log(c)
+--R                         -------                -------               -------
+--R                 3 8 6      n           4 7 4      n           5 6 2     n
+--R               8a b x (%e       )  + 24a b x (%e       )  + 24a b x %e
+--R             + 
+--R                 6 5
+--R               8a b
+--R          *
+--R                    1 4
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                         2log(c) 3              2log(c) 2             2log(c)
+--R                         -------                -------               -------
+--R                 4 7 6      n           5 6 4      n           6 5 2     n
+--R               8a b x (%e       )  + 24a b x (%e       )  + 24a b x %e
+--R             + 
+--R                 7 4
+--R               8a b
+--R          *
+--R                    1 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R      *
+--R                2 3
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                          2log(c) 3              2log(c) 2             2log(c)
+--R                          -------                -------               -------
+--R                  4 7 6      n           5 6 4      n           6 5 2     n
+--R               24a b x (%e       )  + 72a b x (%e       )  + 72a b x %e
+--R             + 
+--R                  7 4
+--R               24a b
+--R          *
+--R                    1 4
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                          2log(c) 3              2log(c) 2             2log(c)
+--R                          -------                -------               -------
+--R                  5 6 6      n           6 5 4      n           7 4 2     n
+--R               24a b x (%e       )  + 72a b x (%e       )  + 72a b x %e
+--R             + 
+--R                  8 3
+--R               24a b
+--R          *
+--R                    1 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R      *
+--R                2 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                          2log(c) 3              2log(c) 2             2log(c)
+--R                          -------                -------               -------
+--R                  5 6 6      n           6 5 4      n           7 4 2     n
+--R               24a b x (%e       )  + 72a b x (%e       )  + 72a b x %e
+--R             + 
+--R                  8 3
+--R               24a b
+--R          *
+--R                    1 4
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                          2log(c) 3              2log(c) 2             2log(c)
+--R                          -------                -------               -------
+--R                  6 5 6      n           7 4 4      n           8 3 2     n
+--R               24a b x (%e       )  + 72a b x (%e       )  + 72a b x %e
+--R             + 
+--R                  9 2
+--R               24a b
+--R          *
+--R                    1 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R      *
+--R               2
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                       2log(c) 3              2log(c) 2             2log(c)
+--R                       -------                -------               -------
+--R               6 5 6      n           7 4 4      n           8 3 2     n
+--R             8a b x (%e       )  + 24a b x (%e       )  + 24a b x %e
+--R           + 
+--R               9 2
+--R             8a b
+--R      *
+--R                1 4
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                       2log(c) 3              2log(c) 2             2log(c)
+--R                       -------                -------               -------
+--R               7 4 6      n           8 3 4      n           9 2 2     n
+--R             8a b x (%e       )  + 24a b x (%e       )  + 24a b x %e
+--R           + 
+--R               10
+--R             8a  b
+--R      *
+--R                1 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R                                                    Type: Expression(Integer)
+--E 819
+
+)clear all
+
+--S 820 of 1004
+t0:=(a+b*(c*x^n)^(3/n))^3
+--R 
+--R
+--R                 3 3               3 2              3
+--R                 -                 -                -
+--R         3     n n         2     n n       2      n n    3
+--R   (1)  b ((c x ) )  + 3a b ((c x ) )  + 3a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 820
+
+--S 821 of 1004
+r0:=a^3*x+3/4*a^2*b*x*(c*x^n)^(3/n)+3/7*a*b^2*x*(c*x^n)^(6/n)+_
+   1/10*b^3*x*(c*x^n)^(9/n)
+--R 
+--R
+--R                    9                 6                  3
+--R                    -                 -                  -
+--R           3      n n        2      n n       2        n n       3
+--R        14b x (c x )  + 60a b x (c x )  + 105a b x (c x )  + 140a x
+--R   (2)  -----------------------------------------------------------
+--R                                    140
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3log(c) 3              3log(c) 2              3log(c)
+--R             -------                -------                -------
+--R      3 10      n             2 7      n            2   4     n          3
+--R   14b x  (%e       )  + 60a b x (%e       )  + 105a b x %e        + 140a x
+--R   ------------------------------------------------------------------------
+--R                                      140
+--R                                         Type: Union(Expression(Integer),...)
+--E 822
+
+--S 823 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     9                 6                  3
+--R                     -                 -                  -
+--R            3      n n        2      n n       2        n n
+--R       - 14b x (c x )  - 60a b x (c x )  - 105a b x (c x )
+--R     + 
+--R                 3log(c) 3              3log(c) 2              3log(c)
+--R                 -------                -------                -------
+--R          3 10      n             2 7      n            2   4     n
+--R       14b x  (%e       )  + 60a b x (%e       )  + 105a b x %e
+--R  /
+--R     140
+--R                                                    Type: Expression(Integer)
+--E 823
+
+--S 824 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 824
+
+)clear all
+
+--S 825 of 1004
+t0:=(a+b*(c*x^n)^(3/n))^2
+--R 
+--R
+--R                 3 2              3
+--R                 -                -
+--R         2     n n              n n    2
+--R   (1)  b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 825
+
+--S 826 of 1004
+r0:=a^2*x+1/2*a*b*x*(c*x^n)^(3/n)+1/7*b^2*x*(c*x^n)^(6/n)
+--R 
+--R
+--R                   6                3
+--R                   -                -
+--R          2      n n              n n      2
+--R        2b x (c x )  + 7a b x (c x )  + 14a x
+--R   (2)  -------------------------------------
+--R                          14
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3log(c) 2            3log(c)
+--R                -------              -------
+--R          2 7      n              4     n         2
+--R        2b x (%e       )  + 7a b x %e        + 14a x
+--R   (3)  --------------------------------------------
+--R                             14
+--R                                         Type: Union(Expression(Integer),...)
+--E 827
+
+--S 828 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                     6                3           3log(c) 2            3log(c)
+--R                     -                -           -------              -------
+--R            2      n n              n n     2 7      n              4     n
+--R        - 2b x (c x )  - 7a b x (c x )  + 2b x (%e       )  + 7a b x %e
+--R   (4)  ----------------------------------------------------------------------
+--R                                          14
+--R                                                    Type: Expression(Integer)
+--E 828
+
+--S 829 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 829
+
+)clear all
+
+--S 830 of 1004
+t0:=a+b*(c*x^n)^(3/n)
+--R 
+--R
+--R                3
+--R                -
+--R              n n
+--R   (1)  b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 830
+
+--S 831 of 1004
+r0:=a*x+1/4*b*x*(c*x^n)^(3/n)
+--R 
+--R
+--R                  3
+--R                  -
+--R                n n
+--R        b x (c x )  + 4a x
+--R   (2)  ------------------
+--R                 4
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3log(c)
+--R              -------
+--R           4     n
+--R        b x %e        + 4a x
+--R   (3)  --------------------
+--R                  4
+--R                                         Type: Union(Expression(Integer),...)
+--E 832
+
+--S 833 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                    3         3log(c)
+--R                    -         -------
+--R                  n n      4     n
+--R        - b x (c x )  + b x %e
+--R   (4)  -----------------------------
+--R                      4
+--R                                                    Type: Expression(Integer)
+--E 833
+
+--S 834 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 834
+
+)clear all
+
+--S 835 of 1004
+t0:=1/(a+b*(c*x^n)^(3/n))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R                3
+--R                -
+--R              n n
+--R        b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 835
+
+--S 836 of 1004
+r0:=1/3*x*log(a^(1/3)+b^(1/3)*(c*x^n)^(1/n))/(a^(2/3)*b^(1/3)*(c*x^n)^(1/n))-_
+   1/6*x*log(a^(2/3)-a^(1/3)*b^(1/3)*(c*x^n)^(1/n)+b^(2/3)*(c*x^n)^(2/n))/_
+   (a^(2/3)*b^(1/3)*(c*x^n)^(1/n))-x*atan((a^(1/3)-2*b^(1/3)*_
+   (c*x^n)^(1/n))/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(1/3)*(c*x^n)^(1/n)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                             2                 1
+--R                             -                 -
+--R           +-+    3+-+2    n n   3+-+3+-+    n n   3+-+2
+--R       - x\|3 log(\|b  (c x )  - \|a \|b (c x )  + \|a  )
+--R     + 
+--R                                                          1
+--R                           1                              -
+--R                           -                    3+-+    n n   3+-+
+--R          +-+    3+-+    n n   3+-+            2\|b (c x )  - \|a
+--R       2x\|3 log(\|b (c x )  + \|a ) + 6x atan(-------------------)
+--R                                                      +-+3+-+
+--R                                                     \|3 \|a
+--R  /
+--R                          1
+--R                          -
+--R       +-+3+-+2 3+-+    n n
+--R     6\|3 \|a   \|b (c x )
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +-------------+2      +-------------+
+--R                     |      3log(c)        |      3log(c)
+--R                     |      -------        |      -------
+--R          +-+     2 3| 2       n          3| 2       n        2
+--R       - \|3 log(x  \|a b %e         - a x\|a b %e         + a )
+--R     + 
+--R                                                      +-------------+
+--R                  +-------------+                     |      3log(c)
+--R                  |      3log(c)                      |      -------
+--R                  |      -------                  +-+3| 2       n         +-+
+--R         +-+     3| 2       n                  2x\|3 \|a b %e         - a\|3
+--R       2\|3 log(x\|a b %e         + a) + 6atan(------------------------------)
+--R                                                             3a
+--R  /
+--R           +-------------+
+--R           |      3log(c)
+--R           |      -------
+--R       +-+3| 2       n
+--R     6\|3 \|a b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 837
+
+--S 838 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +-------------+2      +-------------+
+--R                             1        |      3log(c)        |      3log(c)
+--R                             -        |      -------        |      -------
+--R          +-+3+-+2 3+-+    n n     2 3| 2       n          3| 2       n        2
+--R       - \|3 \|a   \|b (c x ) log(x  \|a b %e         - a x\|a b %e         + a )
+--R     + 
+--R                                   +-------------+
+--R                            1      |      3log(c)
+--R                            -      |      -------
+--R         +-+3+-+2 3+-+    n n     3| 2       n
+--R       2\|3 \|a   \|b (c x ) log(x\|a b %e         + a)
+--R     + 
+--R                                     +-------------+
+--R                                     |      3log(c)
+--R                        1            |      -------
+--R                        -        +-+3| 2       n         +-+
+--R        3+-+2 3+-+    n n     2x\|3 \|a b %e         - a\|3
+--R       6\|a   \|b (c x ) atan(------------------------------)
+--R                                            3a
+--R     + 
+--R                               2                 1
+--R                               -                 -
+--R             +-+    3+-+2    n n   3+-+3+-+    n n   3+-+2
+--R           x\|3 log(\|b  (c x )  - \|a \|b (c x )  + \|a  )
+--R         + 
+--R                                                                1
+--R                                 1                              -
+--R                                 -                    3+-+    n n   3+-+
+--R                +-+    3+-+    n n   3+-+            2\|b (c x )  - \|a
+--R           - 2x\|3 log(\|b (c x )  + \|a ) - 6x atan(-------------------)
+--R                                                            +-+3+-+
+--R                                                           \|3 \|a
+--R      *
+--R          +-------------+
+--R          |      3log(c)
+--R          |      -------
+--R         3| 2       n
+--R         \|a b %e
+--R  /
+--R                             +-------------+
+--R                          1  |      3log(c)
+--R                          -  |      -------
+--R       +-+3+-+2 3+-+    n n 3| 2       n
+--R     6\|3 \|a   \|b (c x )  \|a b %e
+--R                                                    Type: Expression(Integer)
+--E 838
+
+--S 839 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 839
+
+)clear all
+
+--S 840 of 1004
+t0:=1/(a+b*(c*x^n)^(3/n))^2
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R                 3 2              3
+--R                 -                -
+--R         2     n n              n n    2
+--R        b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 840
+
+--S 841 of 1004
+r0:=1/3*x/(a*(a+b*(c*x^n)^(3/n)))+2/9*x*log(a^(1/3)+b^(1/3)*(c*x^n)^(1/n))/_
+   (a^(5/3)*b^(1/3)*(c*x^n)^(1/n))-1/9*x*log(a^(2/3)-a^(1/3)*b^(1/3)*_
+   (c*x^n)^(1/n)+b^(2/3)*(c*x^n)^(2/n))/(a^(5/3)*b^(1/3)*(c*x^n)^(1/n))-_
+   2/3*x*atan((a^(1/3)-2*b^(1/3)*(c*x^n)^(1/n))/(a^(1/3)*sqrt(3)))/_
+   (a^(5/3)*b^(1/3)*(c*x^n)^(1/n)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                       3                          2                 1
+--R                       -                          -                 -
+--R              +-+    n n       +-+     3+-+2    n n   3+-+3+-+    n n   3+-+2
+--R       (- b x\|3 (c x )  - a x\|3 )log(\|b  (c x )  - \|a \|b (c x )  + \|a  )
+--R     + 
+--R                      3                          1
+--R                      -                          -
+--R             +-+    n n        +-+     3+-+    n n   3+-+
+--R       (2b x\|3 (c x )  + 2a x\|3 )log(\|b (c x )  + \|a )
+--R     + 
+--R                                            1
+--R                   3                        -                                 1
+--R                   -              3+-+    n n   3+-+                          -
+--R                 n n             2\|b (c x )  - \|a        +-+3+-+2 3+-+    n n
+--R       (6b x (c x )  + 6a x)atan(-------------------) + 3x\|3 \|a   \|b (c x )
+--R                                        +-+3+-+
+--R                                       \|3 \|a
+--R  /
+--R                             1      3                         1
+--R                             -      -                         -
+--R          +-+3+-+2 3+-+    n n    n n    2 +-+3+-+2 3+-+    n n
+--R     9a b\|3 \|a   \|b (c x ) (c x ) + 9a \|3 \|a   \|b (c x )
+--R                                                    Type: Expression(Integer)
+--E 841
+
+--S 842 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      3log(c)
+--R                      -------
+--R               3 +-+     n        +-+
+--R         (- b x \|3 %e        - a\|3 )
+--R      *
+--R                 +-------------+2      +-------------+
+--R                 |      3log(c)        |      3log(c)
+--R                 |      -------        |      -------
+--R              2 3| 2       n          3| 2       n        2
+--R         log(x  \|a b %e         - a x\|a b %e         + a )
+--R     + 
+--R                                          +-------------+
+--R                   3log(c)                |      3log(c)
+--R                   -------                |      -------
+--R            3 +-+     n         +-+      3| 2       n
+--R       (2b x \|3 %e        + 2a\|3 )log(x\|a b %e         + a)
+--R     + 
+--R                                        +-------------+
+--R                                        |      3log(c)
+--R               3log(c)                  |      -------
+--R               -------              +-+3| 2       n         +-+
+--R            3     n              2x\|3 \|a b %e         - a\|3
+--R       (6b x %e        + 6a)atan(------------------------------)
+--R                                               3a
+--R     + 
+--R              +-------------+
+--R              |      3log(c)
+--R              |      -------
+--R          +-+3| 2       n
+--R       3x\|3 \|a b %e
+--R  /
+--R                                      +-------------+
+--R                   3log(c)            |      3log(c)
+--R                   -------            |      -------
+--R            3 +-+     n        2 +-+ 3| 2       n
+--R     (9a b x \|3 %e        + 9a \|3 )\|a b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 842
+
+--S 843 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  3log(c)                         1      3
+--R                                  -------                         -      -
+--R               2 3 +-+3+-+2 3+-+     n         +-+3+-+2 3+-+    n n    n n
+--R           (- b x \|3 \|a   \|b %e       - a b\|3 \|a   \|b)(c x ) (c x )
+--R         + 
+--R                                    3log(c)                        1
+--R                                    -------                        -
+--R                   3 +-+3+-+2 3+-+     n      2 +-+3+-+2 3+-+    n n
+--R           (- a b x \|3 \|a   \|b %e       - a \|3 \|a   \|b)(c x )
+--R      *
+--R                 +-------------+2      +-------------+
+--R                 |      3log(c)        |      3log(c)
+--R                 |      -------        |      -------
+--R              2 3| 2       n          3| 2       n        2
+--R         log(x  \|a b %e         - a x\|a b %e         + a )
+--R     + 
+--R                                 3log(c)                          1      3
+--R                                 -------                          -      -
+--R              2 3 +-+3+-+2 3+-+     n          +-+3+-+2 3+-+    n n    n n
+--R           (2b x \|3 \|a   \|b %e       + 2a b\|3 \|a   \|b)(c x ) (c x )
+--R         + 
+--R                                   3log(c)                         1
+--R                                   -------                         -
+--R                  3 +-+3+-+2 3+-+     n       2 +-+3+-+2 3+-+    n n
+--R           (2a b x \|3 \|a   \|b %e       + 2a \|3 \|a   \|b)(c x )
+--R      *
+--R               +-------------+
+--R               |      3log(c)
+--R               |      -------
+--R              3| 2       n
+--R         log(x\|a b %e         + a)
+--R     + 
+--R                              3log(c)                      1      3
+--R                              -------                      -      -
+--R              2 3 3+-+2 3+-+     n         3+-+2 3+-+    n n    n n
+--R           (6b x  \|a   \|b %e      + 6a b \|a   \|b)(c x ) (c x )
+--R         + 
+--R                                3log(c)                    1
+--R                                -------                    -
+--R                  3 3+-+2 3+-+     n      2 3+-+2 3+-+   n n
+--R           (6a b x  \|a   \|b %e      + 6a  \|a   \|)(c x )
+--R      *
+--R                     +-------------+
+--R                     |      3log(c)
+--R                     |      -------
+--R                 +-+3| 2       n         +-+
+--R              2x\|3 \|a b %e         - a\|3
+--R         atan(------------------------------)
+--R                            3a
+--R     + 
+--R                          3log(c)                   3               3log(c)
+--R                          -------                   -               -------
+--R                 2 4 +-+     n            +-+     n n        4 +-+     n
+--R               (b x \|3 %e        + a b x\|3 )(c x )  + a b x \|3 %e
+--R             + 
+--R                2  +-+
+--R               a x\|3
+--R          *
+--R                            2                 1
+--R                            -                 -
+--R                 3+-+2    n n   3+-+3+-+    n n   3+-+2
+--R             log(\|b  (c x )  - \|a \|b (c x )  + \|a  )
+--R         + 
+--R                             3log(c)                    3                3log(c)
+--R                             -------                    -                -------
+--R                    2 4 +-+     n             +-+     n n         4 +-+     n
+--R               (- 2b x \|3 %e        - 2a b x\|3 )(c x )  - 2a b x \|3 %e
+--R             + 
+--R                   2  +-+
+--R               - 2a x\|3
+--R          *
+--R                           1
+--R                           -
+--R                 3+-+    n n   3+-+
+--R             log(\|b (c x )  + \|a )
+--R         + 
+--R                        3log(c)                3            3log(c)
+--R                        -------                -            -------
+--R                   2 4     n                 n n         4     n        2
+--R             ((- 6b x %e        - 6a b x)(c x )  - 6a b x %e        - 6a x)
+--R          *
+--R                             1
+--R                             -
+--R                   3+-+    n n   3+-+
+--R                  2\|b (c x )  - \|a
+--R             atan(-------------------)
+--R                         +-+3+-+
+--R                        \|3 \|a
+--R         + 
+--R                                   1      3                       3log(c)      1
+--R                                   -      -                       -------      -
+--R                +-+3+-+2 3+-+    n n    n n      4 +-+3+-+2 3+-+     n       n n
+--R           3b x\|3 \|a   \|b (c x ) (c x ) - 3b x \|3 \|a   \|b %e       (c x )
+--R      *
+--R          +-------------+
+--R          |      3log(c)
+--R          |      -------
+--R         3| 2       n
+--R         \|a b %e
+--R  /
+--R                                 3log(c)                          1      3
+--R                                 -------                          -      -
+--R              2 3 +-+3+-+2 3+-+     n       2  +-+3+-+2 3+-+    n n    n n
+--R         (9a b x \|3 \|a   \|b %e       + 9a b\|3 \|a   \|b)(c x ) (c x )
+--R       + 
+--R                                 3log(c)                         1
+--R                                 -------                         -
+--R            2   3 +-+3+-+2 3+-+     n       3 +-+3+-+2 3+-+    n n
+--R         (9a b x \|3 \|a   \|b %e       + 9a \|3 \|a   \|b)(c x )
+--R    *
+--R        +-------------+
+--R        |      3log(c)
+--R        |      -------
+--R       3| 2       n
+--R       \|a b %e
+--R                                                    Type: Expression(Integer)
+--E 843
+
+--S 844 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 844
+
+)clear all
+
+--S 845 of 1004
+t0:=1/(a+b*(c*x^n)^(3/n))^3
+--R 
+--R
+--R                                 1
+--R   (1)  --------------------------------------------------
+--R                 3 3               3 2              3
+--R                 -                 -                -
+--R         3     n n         2     n n       2      n n    3
+--R        b ((c x ) )  + 3a b ((c x ) )  + 3a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 845
+
+--S 846 of 1004
+r0:=1/6*x/(a*(a+b*(c*x^n)^(3/n))^2)+5/18*x/(a^2*(a+b*(c*x^n)^(3/n)))+_
+   5/27*x*log(a^(1/3)+b^(1/3)*(c*x^n)^(1/n))/(a^(8/3)*b^(1/3)*_
+   (c*x^n)^(1/n))-5/54*x*log(a^(2/3)-a^(1/3)*b^(1/3)*(c*x^n)^(1/n)+_
+   b^(2/3)*(c*x^n)^(2/n))/(a^(8/3)*b^(1/3)*(c*x^n)^(1/n))-5/9*x*_
+   atan((a^(1/3)-2*b^(1/3)*(c*x^n)^(1/n))/(a^(1/3)*sqrt(3)))/(a^(8/3)*_
+   b^(1/3)*(c*x^n)^(1/n)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                           3 2                    3
+--R                           -                      -
+--R              2  +-+     n n             +-+    n n     2  +-+
+--R         (- 5b x\|3 ((c x ) )  - 10a b x\|3 (c x )  - 5a x\|3 )
+--R      *
+--R                        2                 1
+--R                        -                 -
+--R             3+-+2    n n   3+-+3+-+    n n   3+-+2
+--R         log(\|b  (c x )  - \|a \|b (c x )  + \|a  )
+--R     + 
+--R                          3 2                    3
+--R                          -                      -
+--R             2  +-+     n n             +-+    n n      2  +-+
+--R         (10b x\|3 ((c x ) )  + 20a b x\|3 (c x )  + 10a x\|3 )
+--R      *
+--R                       1
+--R                       -
+--R             3+-+    n n   3+-+
+--R         log(\|b (c x )  + \|a )
+--R     + 
+--R                                                                   1
+--R                     3 2                 3                         -
+--R                     -                   -               3+-+    n n   3+-+
+--R           2       n n                 n n      2       2\|b (c x )  - \|a
+--R       (30b x ((c x ) )  + 60a b x (c x )  + 30a x)atan(-------------------)
+--R                                                               +-+3+-+
+--R                                                              \|3 \|a
+--R     + 
+--R                                1      3                           1
+--R                                -      -                           -
+--R             +-+3+-+2 3+-+    n n    n n        +-+3+-+2 3+-+    n n
+--R       15b x\|3 \|a   \|b (c x ) (c x ) + 24a x\|3 \|a   \|b (c x )
+--R  /
+--R                                 1       3 2                            1      3
+--R                                 -       -                              -      -
+--R          2 2 +-+3+-+2 3+-+    n n     n n        3  +-+3+-+2 3+-+    n n    n n
+--R       54a b \|3 \|a   \|b (c x ) ((c x ) ) + 108a b\|3 \|a   \|b (c x ) (c x )
+--R     + 
+--R                               1
+--R                               -
+--R          4 +-+3+-+2 3+-+    n n
+--R       54a \|3 \|a   \|b (c x )
+--R                                                    Type: Expression(Integer)
+--E 846
+
+--S 847 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        3log(c) 2                 3log(c)
+--R                        -------                   -------
+--R              2 6 +-+      n               3 +-+     n        2 +-+
+--R         (- 5b x \|3 (%e       )  - 10a b x \|3 %e        - 5a \|3 )
+--R      *
+--R                 +-------------+2      +-------------+
+--R                 |      3log(c)        |      3log(c)
+--R                 |      -------        |      -------
+--R              2 3| 2       n          3| 2       n        2
+--R         log(x  \|a b %e         - a x\|a b %e         + a )
+--R     + 
+--R                       3log(c) 2                 3log(c)
+--R                       -------                   -------
+--R             2 6 +-+      n               3 +-+     n         2 +-+
+--R         (10b x \|3 (%e       )  + 20a b x \|3 %e        + 10a \|3 )
+--R      *
+--R               +-------------+
+--R               |      3log(c)
+--R               |      -------
+--R              3| 2       n
+--R         log(x\|a b %e         + a)
+--R     + 
+--R                   3log(c) 2             3log(c)
+--R                   -------               -------
+--R             2 6      n               3     n         2
+--R         (30b x (%e       )  + 60a b x %e        + 30a )
+--R      *
+--R                     +-------------+
+--R                     |      3log(c)
+--R                     |      -------
+--R                 +-+3| 2       n         +-+
+--R              2x\|3 \|a b %e         - a\|3
+--R         atan(------------------------------)
+--R                            3a
+--R     + 
+--R                                         +-------------+
+--R                    3log(c)              |      3log(c)
+--R                    -------              |      -------
+--R             4 +-+     n            +-+ 3| 2       n
+--R       (15b x \|3 %e        + 24a x\|3 )\|a b %e
+--R  /
+--R                       3log(c) 2                  3log(c)
+--R                       -------                    -------
+--R           2 2 6 +-+      n            3   3 +-+     n         4 +-+
+--R       (54a b x \|3 (%e       )  + 108a b x \|3 %e        + 54a \|3 )
+--R    *
+--R        +-------------+
+--R        |      3log(c)
+--R        |      -------
+--R       3| 2       n
+--R       \|a b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 847
+
+--S 848 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       3log(c) 2                          3log(c)
+--R                                       -------                            -------
+--R                   4 6 +-+3+-+2 3+-+      n            3 3 +-+3+-+2 3+-+     n
+--R               - 5b x \|3 \|a   \|b (%e       ) - 10a b x \|3 \|a   \|b %e
+--R             + 
+--R                   2 2 +-+3+-+2 3+-+
+--R               - 5a b \|3 \|a   \|b
+--R          *
+--R                   1       3 2
+--R                   -       -
+--R                 n n     n n
+--R             (c x ) ((c x ) )
+--R         + 
+--R                                          3log(c) 2
+--R                                          -------
+--R                      3 6 +-+3+-+2 3+-+      n
+--R               - 10a b x \|3 \|a   \|b (%e       )
+--R             + 
+--R                                         3log(c)
+--R                                         -------
+--R                    2 2 3 +-+3+-+2 3+-+     n        3  +-+3+-+2 3+-+
+--R               - 20a b x \|3 \|a   \|b %e       - 10a b\|3 \|a   \|b
+--R          *
+--R                   1      3
+--R                   -      -
+--R                 n n    n n
+--R             (c x ) (c x )
+--R         + 
+--R                                         3log(c) 2
+--R                                         -------
+--R                   2 2 6 +-+3+-+2 3+-+      n
+--R               - 5a b x \|3 \|a   \|b (%e       )
+--R             + 
+--R                                         3log(c)
+--R                                         -------
+--R                    3   3 +-+3+-+2 3+-+     n       4 +-+3+-+2 3+-+
+--R               - 10a b x \|3 \|a   \|b %e       - 5a \|3 \|a   \|b
+--R          *
+--R                   1
+--R                   -
+--R                 n n
+--R             (c x )
+--R      *
+--R                 +-------------+2      +-------------+
+--R                 |      3log(c)        |      3log(c)
+--R                 |      -------        |      -------
+--R              2 3| 2       n          3| 2       n        2
+--R         log(x  \|a b %e         - a x\|a b %e         + a )
+--R     + 
+--R                                      3log(c) 2                          3log(c)
+--R                                      -------                            -------
+--R                  4 6 +-+3+-+2 3+-+      n            3 3 +-+3+-+2 3+-+     n
+--R               10b x \|3 \|a   \|b (%e       ) + 20a b x \|3 \|a   \|b %e
+--R             + 
+--R                  2 2 +-+3+-+2 3+-+
+--R               10a b \|3 \|a   \|b
+--R          *
+--R                   1       3 2
+--R                   -       -
+--R                 n n     n n
+--R             (c x ) ((c x ) )
+--R         + 
+--R                                        3log(c) 2
+--R                                        -------
+--R                    3 6 +-+3+-+2 3+-+      n
+--R               20a b x \|3 \|a   \|b (%e       )
+--R             + 
+--R                                       3log(c)
+--R                                       -------
+--R                  2 2 3 +-+3+-+2 3+-+     n        3  +-+3+-+2 3+-+
+--R               40a b x \|3 \|a   \|b %e       + 20a b\|3 \|a   \|b
+--R          *
+--R                   1      3
+--R                   -      -
+--R                 n n    n n
+--R             (c x ) (c x )
+--R         + 
+--R                                        3log(c) 2
+--R                                        -------
+--R                  2 2 6 +-+3+-+2 3+-+      n
+--R               10a b x \|3 \|a   \|b (%e       )
+--R             + 
+--R                                       3log(c)
+--R                                       -------
+--R                  3   3 +-+3+-+2 3+-+     n        4 +-+3+-+2 3+-+
+--R               20a b x \|3 \|a   \|b %e       + 10a \|3 \|a   \|b
+--R          *
+--R                   1
+--R                   -
+--R                 n n
+--R             (c x )
+--R      *
+--R               +-------------+
+--R               |      3log(c)
+--R               |      -------
+--R              3| 2       n
+--R         log(x\|a b %e         + a)
+--R     + 
+--R                                   3log(c) 2                      3log(c)
+--R                                   -------                        -------
+--R                  4 6 3+-+2 3+-+      n           3 3 3+-+2 3+-+     n
+--R               30b x  \|a   \|b (%e        + 60a b x  \|a   \|b %e
+--R             + 
+--R                  2 2 3+-+2 3+-+
+--R               30a b  \|a   \|b
+--R          *
+--R                   1       3 2
+--R                   -       -
+--R                 n n     n n
+--R             (c x ) ((c x ) )
+--R         + 
+--R                                     3log(c) 2                       3log(c)
+--R                                     -------                         -------
+--R                    3 6 3+-+2 3+-+      n          2 2 3 3+-+2 3+-+     n
+--R               60a b x  \|a   \|b (%e        + 120a b x  \|a   \|b %e
+--R             + 
+--R                  3  3+-+2 3+-+
+--R               60a b \|a   \|b
+--R          *
+--R                   1      3
+--R                   -      -
+--R                 n n    n n
+--R             (c x ) (c x )
+--R         + 
+--R                                     3log(c) 2                      3log(c)
+--R                                     -------                        -------
+--R                  2 2 6 3+-+2 3+-+      n         3   3 3+-+2 3+-+     n
+--R               30a b x  \|a   \|b (%e        + 60a b x  \|a   \|b %e
+--R             + 
+--R                  4 3+-+2 3+-+
+--R               30a  \|a   \|b
+--R          *
+--R                   1
+--R                   -
+--R                 n n
+--R             (c x )
+--R      *
+--R                     +-------------+
+--R                     |      3log(c)
+--R                     |      -------
+--R                 +-+3| 2       n         +-+
+--R              2x\|3 \|a b %e         - a\|3
+--R         atan(------------------------------)
+--R                            3a
+--R     + 
+--R                              3log(c) 2                 3log(c)
+--R                              -------                   -------
+--R                    4 7 +-+      n             3 4 +-+     n        2 2  +-+
+--R                 (5b x \|3 (%e       )  + 10a b x \|3 %e        + 5a b x\|3 )
+--R              *
+--R                        3 2
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                    3log(c) 2                 3log(c)
+--R                                    -------                   -------
+--R                          3 7 +-+      n           2 2 4 +-+     n
+--R                     10a b x \|3 (%e       )  + 20a b x \|3 %e
+--R                   + 
+--R                        3    +-+
+--R                     10a b x\|3
+--R              *
+--R                       3
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                             3log(c) 2                 3log(c)
+--R                             -------                   -------
+--R                 2 2 7 +-+      n           3   4 +-+     n        4  +-+
+--R               5a b x \|3 (%e       )  + 10a b x \|3 %e        + 5a x\|3
+--R          *
+--R                            2                 1
+--R                            -                 -
+--R                 3+-+2    n n   3+-+3+-+    n n   3+-+2
+--R             log(\|b  (c x )  - \|a \|b (c x )  + \|a  )
+--R         + 
+--R                                    3log(c) 2                 3log(c)
+--R                                    -------                   -------
+--R                          4 7 +-+      n             3 4 +-+     n
+--R                     - 10b x \|3 (%e       )  - 20a b x \|3 %e
+--R                   + 
+--R                          2 2  +-+
+--R                     - 10a b x\|3
+--R              *
+--R                        3 2
+--R                        -
+--R                      n n
+--R                 ((c x ) )
+--R             + 
+--R                                    3log(c) 2                 3log(c)
+--R                                    -------                   -------
+--R                          3 7 +-+      n           2 2 4 +-+     n
+--R                   - 20a b x \|3 (%e       )  - 40a b x \|3 %e
+--R                 + 
+--R                        3    +-+
+--R                   - 20a b x\|3
+--R              *
+--R                       3
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                                3log(c) 2                 3log(c)
+--R                                -------                   -------
+--R                    2 2 7 +-+      n           3   4 +-+     n         4  +-+
+--R               - 10a b x \|3 (%e       )  - 20a b x \|3 %e        - 10a x\|3
+--R          *
+--R                           1
+--R                           -
+--R                 3+-+    n n   3+-+
+--R             log(\|b (c x )  + \|a )
+--R         + 
+--R                           3log(c) 2             3log(c)                  3 2
+--R                           -------               -------                  -
+--R                     4 7      n             3 4     n         2 2       n n
+--R               (- 30b x (%e       )  - 60a b x %e        - 30a b x)((c x ) )
+--R             + 
+--R                             3log(c) 2              3log(c)                 3
+--R                             -------                -------                 -
+--R                       3 7      n            2 2 4     n         3        n n
+--R               (- 60a b x (%e       )  - 120a b x %e        - 60a b x)(c x )
+--R             + 
+--R                            3log(c) 2             3log(c)
+--R                            -------               -------
+--R                    2 2 7      n           3   4     n         4
+--R               - 30a b x (%e       )  - 60a b x %e        - 30a x
+--R          *
+--R                             1
+--R                             -
+--R                   3+-+    n n   3+-+
+--R                  2\|b (c x )  - \|a
+--R             atan(-------------------)
+--R                         +-+3+-+
+--R                        \|3 \|a
+--R         + 
+--R                                    3log(c)                             1
+--R                                    -------                             -
+--R                 3 4 +-+3+-+2 3+-+     n          2  +-+3+-+2 3+-+    n n
+--R             (15b x \|3 \|a   \|b %e       + 24a b x\|3 \|a   \|b)(c x )
+--R          *
+--R                    3 2
+--R                    -
+--R                  n n
+--R             ((c x ) )
+--R         + 
+--R                                       3log(c) 2                             1
+--R                                       -------                               -
+--R                   3 7 +-+3+-+2 3+-+      n          2    +-+3+-+2 3+-+    n n
+--R             (- 15b x \|3 \|a   \|b (%e       ) + 33a b x\|3 \|a   \|b)(c x )
+--R          *
+--R                   3
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                                          3log(c) 2
+--R                                          -------
+--R                      2 7 +-+3+-+2 3+-+      n
+--R               - 24a b x \|3 \|a   \|b (%e       )
+--R             + 
+--R                                         3log(c)
+--R                                         -------
+--R                    2   4 +-+3+-+2 3+-+     n
+--R               - 33a b x \|3 \|a   \|b %e
+--R          *
+--R                   1
+--R                   -
+--R                 n n
+--R             (c x )
+--R      *
+--R          +-------------+
+--R          |      3log(c)
+--R          |      -------
+--R         3| 2       n
+--R         \|a b %e
+--R  /
+--R                                      3log(c) 2                           3log(c)
+--R                                      -------                             -------
+--R                2 4 6 +-+3+-+2 3+-+      n           3 3 3 +-+3+-+2 3+-+     n
+--R             54a b x \|3 \|a   \|b (%e       ) + 108a b x \|3 \|a   \|b %e
+--R           + 
+--R                4 2 +-+3+-+2 3+-+
+--R             54a b \|3 \|a   \|b
+--R        *
+--R                 1       3 2
+--R                 -       -
+--R               n n     n n
+--R           (c x ) ((c x ) )
+--R       + 
+--R                                       3log(c) 2
+--R                                       -------
+--R                 3 3 6 +-+3+-+2 3+-+      n
+--R             108a b x \|3 \|a   \|b (%e       )
+--R           + 
+--R                                      3log(c)
+--R                                      -------
+--R                 4 2 3 +-+3+-+2 3+-+     n         5  +-+3+-+2 3+-+
+--R             216a b x \|3 \|a   \|b %e       + 108a b\|3 \|a   \|b
+--R        *
+--R                 1      3
+--R                 -      -
+--R               n n    n n
+--R           (c x ) (c x )
+--R       + 
+--R                                      3log(c) 2                           3log(c)
+--R                                      -------                             -------
+--R                4 2 6 +-+3+-+2 3+-+      n           5   3 +-+3+-+2 3+-+     n
+--R             54a b x \|3 \|a   \|b (%e       ) + 108a b x \|3 \|a   \|b %e
+--R           + 
+--R                6 +-+3+-+2 3+-+
+--R             54a \|3 \|a   \|b
+--R        *
+--R                 1
+--R                 -
+--R               n n
+--R           (c x )
+--R    *
+--R        +-------------+
+--R        |      3log(c)
+--R        |      -------
+--R       3| 2       n
+--R       \|a b %e
+--R                                                    Type: Expression(Integer)
+--E 848
+
+--S 849 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 849
+
+)clear all
+
+--S 850 of 1004
+t0:=1/(1+(x^3)^(2/3))
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R         +--+2
+--R        3| 3
+--R        \|x    + 1
+--R                                                    Type: Expression(Integer)
+--E 850
+
+--S 851 of 1004
+r0:=x*atan((x^3)^(1/3))/(x^3)^(1/3)
+--R 
+--R
+--R                +--+
+--R               3| 3
+--R        x atan(\|x  )
+--R   (2)  -------------
+--R             +--+
+--R            3| 3
+--R            \|x
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  atan(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 852
+
+--S 853 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                  +--+            +--+
+--R                 3| 3            3| 3
+--R        - x atan(\|x  ) + atan(x)\|x
+--R   (4)  ------------------------------
+--R                      +--+
+--R                     3| 3
+--R                     \|x
+--R                                                    Type: Expression(Integer)
+--E 853
+
+--S 854 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +--+
+--R                2 3| 3    3
+--R             - x  \|x  + x
+--R   (5)  -----------------------
+--R                 +--+
+--R          2     3| 3     5    3
+--R        (x  + 1)\|x   + x  + x
+--R                                                    Type: Expression(Integer)
+--E 854
+
+)clear all
+
+--S 855 of 1004
+t0:=1/(1+(x^2)^(3/2))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           +--+
+--R         2 | 2
+--R        x \|x   + 1
+--R                                                    Type: Expression(Integer)
+--E 855
+
+--S 856 of 1004
+r0:=-1/6*x*log(1+x^2-sqrt(x^2))/sqrt(x^2)+1/3*x*log(1+sqrt(x^2))/sqrt(x^2)-_
+   x*atan((1-2*sqrt(x^2))/sqrt(3))/(sqrt(3)*sqrt(x^2))
+--R 
+--R
+--R   (2)
+--R                                                                 +--+
+--R              +--+                    +--+                       | 2
+--R      +-+     | 2           +-+       | 2     2                2\|x   - 1
+--R   2x\|3 log(\|x   + 1) - x\|3 log(- \|x   + x  + 1) + 6x atan(----------)
+--R                                                                   +-+
+--R                                                                  \|3
+--R   -----------------------------------------------------------------------
+--R                                        +--+
+--R                                    +-+ | 2
+--R                                  6\|3 \|x
+--R                                                    Type: Expression(Integer)
+--E 856
+
+--S 857 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                                 +-+
+--R           +-+     2              +-+                   (2x - 1)\|3
+--R        - \|3 log(x  - x + 1) + 2\|3 log(x + 1) + 6atan(------------)
+--R                                                              3
+--R   (3)  -------------------------------------------------------------
+--R                                      +-+
+--R                                    6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 857
+
+--S 858 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                       +--+
+--R                    +--+                    +--+                       | 2
+--R            +-+     | 2           +-+       | 2     2                2\|x   - 1
+--R       - 2x\|3 log(\|x   + 1) + x\|3 log(- \|x   + x  + 1) - 6x atan(----------)
+--R                                                                         +-+
+--R                                                                        \|3
+--R     + 
+--R                                                                 +-+   +--+
+--R           +-+     2              +-+                   (2x - 1)\|3    | 2
+--R       (- \|3 log(x  - x + 1) + 2\|3 log(x + 1) + 6atan(------------))\|x
+--R                                                              3
+--R  /
+--R           +--+
+--R       +-+ | 2
+--R     6\|3 \|x
+--R                                                    Type: Expression(Integer)
+--E 858
+
+--S 859 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                      +--+
+--R                         5    4    3  | 2     6    5    4
+--R                       (x  + x  + x )\|x   - x  - x  - x
+--R   (5)  ---------------------------------------------------------------
+--R                                     +--+
+--R          7    5    4    3    2      | 2     9    7    6    5    4    2
+--R        (x  - x  + x  - x  - x  - 1)\|x   - x  - x  - x  + x  - x  + x
+--R                                                    Type: Expression(Integer)
+--E 859
+
+)clear all
+
+--S 860 of 1004
+t0:=1/(1+4*sqrt(x^4))
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R          +--+
+--R          | 4
+--R        4\|x   + 1
+--R                                                    Type: Expression(Integer)
+--E 860
+
+--S 861 of 1004
+r0:=1/2*x*atan(2*(x^4)^(1/4))/(x^4)^(1/4)
+--R 
+--R
+--R                 +--+
+--R                4| 4
+--R        x atan(2\|x  )
+--R   (2)  --------------
+--R              +--+
+--R             4| 4
+--R            2\|x
+--R                                                    Type: Expression(Integer)
+--E 861
+
+--S 862 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R        atan(2x)
+--R   (3)  --------
+--R            2
+--R                                         Type: Union(Expression(Integer),...)
+--E 862
+
+--S 863 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                   +--+             +--+
+--R                  4| 4             4| 4
+--R        - x atan(2\|x  ) + atan(2x)\|x
+--R   (4)  --------------------------------
+--R                       +--+
+--R                      4| 4
+--R                     2\|x
+--R                                                    Type: Expression(Integer)
+--E 863
+
+--S 864 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +--+2
+--R                4| 4       2
+--R               4\|x    - 4x
+--R   (5)  --------------------------
+--R                   +--+2
+--R            2     4| 4       2
+--R        (16x  + 4)\|x    + 4x  + 1
+--R                                                    Type: Expression(Integer)
+--E 864
+
+)clear all
+
+--S 865 of 1004
+t0:=1/(1-4*sqrt(x^4))
+--R 
+--R
+--R               1
+--R   (1)  - ----------
+--R            +--+
+--R            | 4
+--R          4\|x   - 1
+--R                                                    Type: Expression(Integer)
+--E 865
+
+--S 866 of 1004
+r0:=1/2*x*atanh(2*(x^4)^(1/4))/(x^4)^(1/4)
+--R 
+--R
+--R                  +--+
+--R                 4| 4
+--R        x atanh(2\|x  )
+--R   (2)  ---------------
+--R               +--+
+--R              4| 4
+--R             2\|x
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(2x + 1) - log(2x - 1)
+--R   (3)  -------------------------
+--R                    4
+--R                                         Type: Union(Expression(Integer),...)
+--E 867
+
+--S 868 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                     +--+                                +--+
+--R                    4| 4                                4| 4
+--R        - 2x atanh(2\|x  ) + (log(2x + 1) - log(2x - 1))\|x
+--R   (4)  -----------------------------------------------------
+--R                                  +--+
+--R                                 4| 4
+--R                                4\|x
+--R                                                    Type: Expression(Integer)
+--E 868
+
+--S 869 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                  +--+2
+--R                 4| 4       2
+--R              - 4\|x    + 4x
+--R   (5)  --------------------------
+--R                   +--+2
+--R            2     4| 4       2
+--R        (16x  - 4)\|x    - 4x  + 1
+--R                                                    Type: Expression(Integer)
+--E 869
+
+)clear all
+
+--S 870 of 1004
+t0:=1/(1+4*(x^6)^(1/3))
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R          +--+
+--R         3| 6
+--R        4\|x   + 1
+--R                                                    Type: Expression(Integer)
+--E 870
+
+--S 871 of 1004
+r0:=1/2*x*atan(2*(x^6)^(1/6))/(x^6)^(1/6)
+--R 
+--R
+--R                 +--+
+--R                6| 6
+--R        x atan(2\|x  )
+--R   (2)  --------------
+--R              +--+
+--R             6| 6
+--R            2\|x
+--R                                                    Type: Expression(Integer)
+--E 871
+
+--S 872 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R        atan(2x)
+--R   (3)  --------
+--R            2
+--R                                         Type: Union(Expression(Integer),...)
+--E 872
+
+--S 873 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                   +--+             +--+
+--R                  6| 6             6| 6
+--R        - x atan(2\|x  ) + atan(2x)\|x
+--R   (4)  --------------------------------
+--R                       +--+
+--R                      6| 6
+--R                     2\|x
+--R                                                    Type: Expression(Integer)
+--E 873
+
+--S 874 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +--+2
+--R                6| 6       2
+--R               4\|x    - 4x
+--R   (5)  --------------------------
+--R                   +--+2
+--R            2     6| 6       2
+--R        (16x  + 4)\|x    + 4x  + 1
+--R                                                    Type: Expression(Integer)
+--E 874
+
+)clear all
+
+--S 875 of 1004
+t0:=1/(1-4*(x^6)^(1/3))
+--R 
+--R
+--R               1
+--R   (1)  - ----------
+--R            +--+
+--R           3| 6
+--R          4\|x   - 1
+--R                                                    Type: Expression(Integer)
+--E 875
+
+--S 876 of 1004
+r0:=1/2*x*atanh(2*(x^6)^(1/6))/(x^6)^(1/6)
+--R 
+--R
+--R                  +--+
+--R                 6| 6
+--R        x atanh(2\|x  )
+--R   (2)  ---------------
+--R               +--+
+--R              6| 6
+--R             2\|x
+--R                                                    Type: Expression(Integer)
+--E 876
+
+--S 877 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(2x + 1) - log(2x - 1)
+--R   (3)  -------------------------
+--R                    4
+--R                                         Type: Union(Expression(Integer),...)
+--E 877
+
+--S 878 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                     +--+                                +--+
+--R                    6| 6                                6| 6
+--R        - 2x atanh(2\|x  ) + (log(2x + 1) - log(2x - 1))\|x
+--R   (4)  -----------------------------------------------------
+--R                                  +--+
+--R                                 6| 6
+--R                                4\|x
+--R                                                    Type: Expression(Integer)
+--E 878
+
+--S 879 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                  +--+2
+--R                 6| 6       2
+--R              - 4\|x    + 4x
+--R   (5)  --------------------------
+--R                   +--+2
+--R            2     6| 6       2
+--R        (16x  - 4)\|x    - 4x  + 1
+--R                                                    Type: Expression(Integer)
+--E 879
+
+)clear all
+
+--S 880 of 1004
+t0:=1/(1+4*(x^(2*n))^(1/n))
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R          2
+--R        4x  + 1
+--R                                                    Type: Expression(Integer)
+--E 880
+
+--S 881 of 1004
+r0:=1/2*x*atan(2*(x^(2*n))^(1/2/n))/(x^(2*n))^(1/2/n)
+--R 
+--R
+--R        atan(2x)
+--R   (2)  --------
+--R            2
+--R                                                    Type: Expression(Integer)
+--E 881
+
+--S 882 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R        atan(2x)
+--R   (3)  --------
+--R            2
+--R                                         Type: Union(Expression(Integer),...)
+--E 882
+
+--S 883 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 883
+
+--S 884 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 884
+
+)clear all
+
+--S 885 of 1004
+t0:=1/(1-4*(x^(2*n))^(1/n))
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R            2
+--R          4x  - 1
+--R                                                    Type: Expression(Integer)
+--E 885
+
+--S 886 of 1004
+r0:=1/2*x*atanh(2*(x^(2*n))^(1/2/n))/(x^(2*n))^(1/2/n)
+--R 
+--R
+--R        atanh(2x)
+--R   (2)  ---------
+--R            2
+--R                                                    Type: Expression(Integer)
+--E 886
+
+--S 887 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(2x + 1) - log(2x - 1)
+--R   (3)  -------------------------
+--R                    4
+--R                                         Type: Union(Expression(Integer),...)
+--E 887
+
+--S 888 of 1004
+m0:=a0-r0
+--R 
+--R
+--R        log(2x + 1) - log(2x - 1) - 2atanh(2x)
+--R   (4)  --------------------------------------
+--R                           4
+--R                                                    Type: Expression(Integer)
+--E 888
+
+--S 889 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 889
+
+)clear all
+
+--S 890 of 1004
+t0:=x^3/(a+b*(c*x^n)^(1/n))
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  -------------
+--R                1
+--R                -
+--R              n n
+--R        b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 890
+
+--S 891 of 1004
+r0:=a^2*x^4/(b^3*(c*x^n)^(3/n))-1/2*a*x^4/(b^2*(c*x^n)^(2/n))+_
+   1/3*x^4/(b*(c*x^n)^(1/n))-a^3*x^4*log(a+b*(c*x^n)^(1/n))/(b^4*(c*x^n)^(4/n))
+--R 
+--R
+--R   (2)
+--R                    1      2      3            1
+--R                    -      -      -            -
+--R           3 4    n n    n n    n n          n n
+--R       - 6a x (c x ) (c x ) (c x ) log(b (c x )  + a)
+--R     + 
+--R                    2                1       3                1      2       4
+--R                    -                -       -                -      -       -
+--R           3 4    n n       2 4    n n     n n     2   4    n n    n n     n n
+--R       ((2b x (c x )  - 3a b x (c x ) )(c x )  + 6a b x (c x ) (c x ) )(c x )
+--R  /
+--R              1      2      3      4
+--R              -      -      -      -
+--R       4    n n    n n    n n    n n
+--R     6b (c x ) (c x ) (c x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 891
+
+--S 892 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      log(c)                log(c) 3             log(c) 2
+--R                      ------                ------               ------
+--R           3             n            3 3      n           2 2      n
+--R       - 6a log(b x %e       + a) + 2b x (%e      )  - 3a b x (%e      )
+--R     + 
+--R                log(c)
+--R                ------
+--R         2         n
+--R       6a b x %e
+--R  /
+--R           log(c) 4
+--R           ------
+--R       4      n
+--R     6b (%e      )
+--R                                         Type: Union(Expression(Integer),...)
+--E 892
+
+--S 893 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               log(c) 4      1      2      3            1
+--R               ------        -      -      -            -
+--R         3 4      n        n n    n n    n n          n n
+--R       6a x (%e      ) (c x ) (c x ) (c x ) log(b (c x )  + a)
+--R     + 
+--R                  1      2      3      4          log(c)
+--R                  -      -      -      -          ------
+--R           3    n n    n n    n n    n n             n
+--R       - 6a (c x ) (c x ) (c x ) (c x ) log(b x %e       + a)
+--R     + 
+--R                              log(c) 3             log(c) 2            log(c)
+--R                              ------               ------              ------
+--R                        3 3      n           2 2      n         2         n
+--R                     (2b x (%e      )  - 3a b x (%e      )  + 6a b x %e      )
+--R                  *
+--R                           1
+--R                           -
+--R                         n n
+--R                     (c x )
+--R                 + 
+--R                             log(c) 4
+--R                             ------
+--R                       3 4      n
+--R                   - 2b x (%e      )
+--R              *
+--R                       2
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                         log(c) 4      1
+--R                         ------        -
+--R                   2 4      n        n n
+--R               3a b x (%e      ) (c x )
+--R          *
+--R                   3
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                       log(c) 4      1      2
+--R                       ------        -      -
+--R               2   4      n        n n    n n
+--R           - 6a b x (%e      ) (c x ) (c x )
+--R      *
+--R               4
+--R               -
+--R             n n
+--R         (c x )
+--R  /
+--R           log(c) 4      1      2      3      4
+--R           ------        -      -      -      -
+--R       4      n        n n    n n    n n    n n
+--R     6b (%e      ) (c x ) (c x ) (c x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 893
+
+--S 894 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 894
+
+)clear all
+
+--S 895 of 1004
+t0:=x^2/(a+b*(c*x^n)^(1/n))
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  -------------
+--R                1
+--R                -
+--R              n n
+--R        b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 895
+
+--S 896 of 1004
+r0:=-a*x^3/(b^2*(c*x^n)^(2/n))+1/2*x^3/(b*(c*x^n)^(1/n))+_
+   a^2*x^3*log(a+b*(c*x^n)^(1/n))/(b^3*(c*x^n)^(3/n))
+--R 
+--R
+--R   (2)
+--R              1      2            1                   2                1       3
+--R              -      -            -                   -                -       -
+--R     2 3    n n    n n          n n          2 3    n n         3    n n     n n
+--R   2a x (c x ) (c x ) log(b (c x )  + a) + (b x (c x )  - 2a b x (c x ) )(c x )
+--R   -----------------------------------------------------------------------------
+--R                                       1      2      3
+--R                                       -      -      -
+--R                                3    n n    n n    n n
+--R                              2b (c x ) (c x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 896
+
+--S 897 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     log(c)               log(c) 2            log(c)
+--R                     ------               ------              ------
+--R          2             n           2 2      n                   n
+--R        2a log(b x %e       + a) + b x (%e      )  - 2a b x %e
+--R   (3)  ------------------------------------------------------------
+--R                                     log(c) 3
+--R                                     ------
+--R                                 3      n
+--R                               2b (%e      )
+--R                                         Type: Union(Expression(Integer),...)
+--E 897
+
+--S 898 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 log(c) 3      1      2            1
+--R                 ------        -      -            -
+--R           2 3      n        n n    n n          n n
+--R       - 2a x (%e      ) (c x ) (c x ) log(b (c x )  + a)
+--R     + 
+--R                1      2      3          log(c)
+--R                -      -      -          ------
+--R         2    n n    n n    n n             n
+--R       2a (c x ) (c x ) (c x ) log(b x %e       + a)
+--R     + 
+--R                    log(c) 2            log(c)       1          log(c) 3       2
+--R                    ------              ------       -          ------         -
+--R              2 2      n                   n       n n    2 3      n         n n
+--R           ((b x (%e      )  - 2a b x %e      )(c x )  - b x (%e      ) )(c x )
+--R         + 
+--R                     log(c) 3      1
+--R                     ------        -
+--R                 3      n        n n
+--R           2a b x (%e      ) (c x )
+--R      *
+--R               3
+--R               -
+--R             n n
+--R         (c x )
+--R  /
+--R           log(c) 3      1      2      3
+--R           ------        -      -      -
+--R       3      n        n n    n n    n n
+--R     2b (%e      ) (c x ) (c x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 898
+
+--S 899 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 899
+
+)clear all
+
+--S 900 of 1004
+t0:=x/(a+b*(c*x^n)^(1/n))
+--R 
+--R
+--R              x
+--R   (1)  -------------
+--R                1
+--R                -
+--R              n n
+--R        b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 900
+
+--S 901 of 1004
+r0:=x^2/(b*(c*x^n)^(1/n))-a*x^2*log(a+b*(c*x^n)^(1/n))/(b^2*(c*x^n)^(2/n))
+--R 
+--R
+--R                    1            1                  2
+--R                    -            -                  -
+--R             2    n n          n n           2    n n
+--R        - a x (c x ) log(b (c x )  + a) + b x (c x )
+--R   (2)  ---------------------------------------------
+--R                               1      2
+--R                               -      -
+--R                        2    n n    n n
+--R                       b (c x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      log(c)              log(c)
+--R                      ------              ------
+--R                         n                   n
+--R        - a log(b x %e       + a) + b x %e
+--R   (3)  ----------------------------------------
+--R                           log(c) 2
+--R                           ------
+--R                       2      n
+--R                      b (%e      )
+--R                                         Type: Union(Expression(Integer),...)
+--E 902
+
+--S 903 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              log(c) 2      1            1
+--R              ------        -            -
+--R          2      n        n n          n n
+--R       a x (%e      ) (c x ) log(b (c x )  + a)
+--R     + 
+--R                 1      2          log(c)
+--R                 -      -          ------
+--R               n n    n n             n
+--R       - a (c x ) (c x ) log(b x %e       + a)
+--R     + 
+--R              log(c)      1          log(c) 2       2
+--R              ------      -          ------         -
+--R                 n      n n      2      n         n n
+--R       (b x %e      (c x )  - b x (%e      ) )(c x )
+--R  /
+--R          log(c) 2      1      2
+--R          ------        -      -
+--R      2      n        n n    n n
+--R     b (%e      ) (c x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 903
+
+--S 904 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 904
+
+)clear all
+
+--S 905 of 1004
+t0:=1/(a+b*(c*x^n)^(1/n))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R                1
+--R                -
+--R              n n
+--R        b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 905
+
+--S 906 of 1004
+r0:=x*log(a+b*(c*x^n)^(1/n))/(b*(c*x^n)^(1/n))
+--R 
+--R
+--R                      1
+--R                      -
+--R                    n n
+--R        x log(b (c x )  + a)
+--R   (2)  --------------------
+--R                      1
+--R                      -
+--R                    n n
+--R              b (c x )
+--R                                                    Type: Expression(Integer)
+--E 906
+
+--S 907 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  log(c)
+--R                  ------
+--R                     n
+--R        log(b x %e       + a)
+--R   (3)  ---------------------
+--R                  log(c)
+--R                  ------
+--R                     n
+--R              b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 907
+
+--S 908 of 1004
+m0:=a0-r0
+--R 
+--R
+--R              log(c)            1              1          log(c)
+--R              ------            -              -          ------
+--R                 n            n n            n n             n
+--R        - x %e      log(b (c x )  + a) + (c x ) log(b x %e       + a)
+--R   (4)  -------------------------------------------------------------
+--R                                  log(c)      1
+--R                                  ------      -
+--R                                     n      n n
+--R                              b %e      (c x )
+--R                                                    Type: Expression(Integer)
+--E 908
+
+--S 909 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 909
+
+)clear all
+
+--S 910 of 1004
+t0:=1/(x*(a+b*(c*x^n)^(1/n)))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R                  1
+--R                  -
+--R                n n
+--R        b x (c x )  + a x
+--R                                                    Type: Expression(Integer)
+--E 910
+
+--S 911 of 1004
+r0:=log(x)/a-log(a+b*(c*x^n)^(1/n))/a
+--R 
+--R
+--R                      1
+--R                      -
+--R                    n n
+--R        - log(b (c x )  + a) + log(x)
+--R   (2)  -----------------------------
+--R                      a
+--R                                                    Type: Expression(Integer)
+--E 911
+
+--S 912 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    log(c)
+--R                    ------
+--R                       n
+--R        - log(b x %e       + a) + log(x)
+--R   (3)  --------------------------------
+--R                        a
+--R                                         Type: Union(Expression(Integer),...)
+--E 912
+
+--S 913 of 1004
+m0:=a0-r0
+--R 
+--R
+--R                    1                  log(c)
+--R                    -                  ------
+--R                  n n                     n
+--R        log(b (c x )  + a) - log(b x %e       + a)
+--R   (4)  ------------------------------------------
+--R                             a
+--R                                                    Type: Expression(Integer)
+--E 913
+
+--S 914 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 914
+
+)clear all
+
+--S 915 of 1004
+t0:=1/(x^2*(a+b*(c*x^n)^(1/n)))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R                  1
+--R                  -
+--R           2    n n      2
+--R        b x (c x )  + a x
+--R                                                    Type: Expression(Integer)
+--E 915
+
+--S 916 of 1004
+r0:=(-1)/(a*x)-b*(c*x^n)^(1/n)*log(x)/(a^2*x)+b*(c*x^n)^(1/n)*_
+   log(a+b*(c*x^n)^(1/n))/(a^2*x)
+--R 
+--R
+--R                1            1                      1
+--R                -            -                      -
+--R              n n          n n                    n n
+--R        b (c x ) log(b (c x )  + a) - b log(x)(c x )  - a
+--R   (2)  -------------------------------------------------
+--R                                2
+--R                               a x
+--R                                                    Type: Expression(Integer)
+--E 916
+
+--S 917 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R              log(c)          log(c)                    log(c)
+--R              ------          ------                    ------
+--R                 n               n                         n
+--R        b x %e      log(b x %e       + a) - b x log(x)%e       - a
+--R   (3)  ----------------------------------------------------------
+--R                                     2
+--R                                    a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 917
+
+--S 918 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 1            1              log(c)          log(c)
+--R                 -            -              ------          ------
+--R               n n          n n                 n               n
+--R       - b (c x ) log(b (c x )  + a) + b x %e      log(b x %e       + a)
+--R     + 
+--R                     1               log(c)
+--R                     -               ------
+--R                   n n                  n
+--R       b log(x)(c x )  - b x log(x)%e
+--R  /
+--R      2
+--R     a x
+--R                                                    Type: Expression(Integer)
+--E 918
+
+--S 919 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 919
+
+)clear all
+
+--S 920 of 1004
+t0:=1/(x^3*(a+b*(c*x^n)^(1/n)))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R                  1
+--R                  -
+--R           3    n n      3
+--R        b x (c x )  + a x
+--R                                                    Type: Expression(Integer)
+--E 920
+
+--S 921 of 1004
+r0:=(-1/2)/(a*x^2)+b*(c*x^n)^(1/n)/(a^2*x^2)+b^2*(c*x^n)^(2/n)*log(x)/_
+   (a^3*x^2)-b^2*(c*x^n)^(2/n)*log(a+b*(c*x^n)^(1/n))/(a^3*x^2)
+--R 
+--R
+--R                   2            1                       2              1
+--R                   -            -                       -              -
+--R            2    n n          n n          2          n n            n n    2
+--R        - 2b (c x ) log(b (c x )  + a) + 2b log(x)(c x )  + 2a b (c x )  - a
+--R   (2)  ---------------------------------------------------------------------
+--R                                          3 2
+--R                                        2a x
+--R                                                    Type: Expression(Integer)
+--E 921
+
+--S 922 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 log(c) 2          log(c)                      log(c) 2
+--R                 ------            ------                      ------
+--R           2 2      n                 n            2 2            n
+--R       - 2b x (%e      ) log(b x %e       + a) + 2b x log(x)(%e      )
+--R     + 
+--R                log(c)
+--R                ------
+--R                   n      2
+--R       2a b x %e       - a
+--R  /
+--R       3 2
+--R     2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 922
+
+--S 923 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               2            1               log(c) 2          log(c)
+--R               -            -               ------            ------
+--R        2    n n          n n         2 2      n                 n
+--R       b (c x ) log(b (c x )  + a) - b x (%e      ) log(b x %e       + a)
+--R     + 
+--R                       2             1                log(c) 2           log(c)
+--R                       -             -                ------             ------
+--R          2          n n           n n    2 2            n                  n
+--R       - b log(x)(c x )  - a b (c x )  + b x log(x)(%e      )  + a b x %e
+--R  /
+--R      3 2
+--R     a x
+--R                                                    Type: Expression(Integer)
+--E 923
+
+--S 924 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 924
+
+)clear all
+
+--S 925 of 1004
+t0:=x^3/(a+b*(c*x^n)^(1/n))^2
+--R 
+--R
+--R                        3
+--R                       x
+--R   (1)  --------------------------------
+--R                 1 2              1
+--R                 -                -
+--R         2     n n              n n    2
+--R        b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 925
+
+--S 926 of 1004
+r0:=-2*a*x^4/(b^3*(c*x^n)^(3/n))+1/2*x^4/(b^2*(c*x^n)^(2/n))+a^3*x^4/(b^4*_
+   (c*x^n)^(4/n)*(a+b*(c*x^n)^(1/n)))+3*a^2*x^4*log(a+b*(c*x^n)^(1/n))/_
+   (b^4*(c*x^n)^(4/n))
+--R 
+--R
+--R   (2)
+--R                     1               2      3            1
+--R                     -               -      -            -
+--R          2   4    n n     3 4     n n    n n          n n
+--R       (6a b x (c x )  + 6a x )(c x ) (c x ) log(b (c x )  + a)
+--R     + 
+--R                     1                3                   1                 2
+--R                     -                -                   -                 -
+--R            3 4    n n      2 4     n n          2 4    n n     2   4     n n
+--R         ((b x (c x )  + a b x )(c x )  + (- 4a b x (c x )  - 4a b x )(c x ) )
+--R      *
+--R               4
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                  2      3
+--R                  -      -
+--R         3 4    n n    n n
+--R       2a x (c x ) (c x )
+--R  /
+--R               1               2      3      4
+--R               -               -      -      -
+--R        5    n n       4     n n    n n    n n
+--R     (2b (c x )  + 2a b )(c x ) (c x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 926
+
+--S 927 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 log(c)                 log(c)               log(c) 3
+--R                 ------                 ------               ------
+--R          2         n       3              n           3 3      n
+--R       (6a b x %e       + 6a )log(b x %e       + a) + b x (%e      )
+--R     + 
+--R                   log(c) 2            log(c)
+--R                   ------              ------
+--R             2 2      n         2         n       3
+--R       - 3a b x (%e      )  - 4a b x %e       + 2a
+--R  /
+--R             log(c) 5           log(c) 4
+--R             ------             ------
+--R       5        n           4      n
+--R     2b x (%e      )  + 2a b (%e      )
+--R                                         Type: Union(Expression(Integer),...)
+--E 927
+
+--S 928 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        log(c) 5             log(c) 4       1
+--R                        ------               ------         -
+--R                2 2 5      n         3   4      n         n n
+--R           (- 6a b x (%e      )  - 6a b x (%e      ) )(c x )
+--R         + 
+--R                       log(c) 5           log(c) 4
+--R                       ------             ------
+--R               3   5      n         4 4      n
+--R           - 6a b x (%e      )  - 6a x (%e      )
+--R      *
+--R               2      3            1
+--R               -      -            -
+--R             n n    n n          n n
+--R         (c x ) (c x ) log(b (c x )  + a)
+--R     + 
+--R                    log(c)              1            log(c)             2      3
+--R                    ------              -            ------             -      -
+--R             2 2       n       3      n n     3         n       4     n n    n n
+--R         ((6a b x %e       + 6a b)(c x )  + 6a b x %e       + 6a )(c x ) (c x )
+--R      *
+--R               4          log(c)
+--R               -          ------
+--R             n n             n
+--R         (c x ) log(b x %e       + a)
+--R     + 
+--R                              log(c) 3             log(c) 2            log(c)
+--R                              ------               ------              ------
+--R                        4 3      n           3 2      n         2 2       n
+--R                       b x (%e      )  - 3a b x (%e      )  - 4a b x %e
+--R                     + 
+--R                         3
+--R                       2a b
+--R                  *
+--R                           1
+--R                           -
+--R                         n n
+--R                     (c x )
+--R                 + 
+--R                          log(c) 3             log(c) 2            log(c)
+--R                          ------               ------              ------
+--R                    3 3      n         2 2 2      n         3         n       4
+--R                 a b x (%e      )  - 3a b x (%e      )  - 4a b x %e       + 2a
+--R              *
+--R                       2
+--R                       -
+--R                     n n
+--R                 (c x )
+--R             + 
+--R                         log(c) 5            log(c) 4       1
+--R                         ------              ------         -
+--R                   4 5      n          3 4      n         n n
+--R               (- b x (%e      )  - a b x (%e      ) )(c x )
+--R             + 
+--R                          log(c) 5            log(c) 4
+--R                          ------              ------
+--R                    3 5      n        2 2 4      n
+--R               - a b x (%e      )  - a b x (%e      )
+--R          *
+--R                   3
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                          log(c) 5             log(c) 4       1
+--R                          ------               ------         -
+--R                    3 5      n         2 2 4      n         n n
+--R               (4a b x (%e      )  + 4a b x (%e      ) )(c x )
+--R             + 
+--R                         log(c) 5             log(c) 4
+--R                         ------               ------
+--R                 2 2 5      n         3   4      n
+--R               4a b x (%e      )  + 4a b x (%e      )
+--R          *
+--R                   2
+--R                   -
+--R                 n n
+--R             (c x )
+--R      *
+--R               4
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                    log(c) 5           log(c) 4       2      3
+--R                    ------             ------         -      -
+--R            3   5      n         4 4      n         n n    n n
+--R       (- 2a b x (%e      )  - 2a x (%e      ) )(c x ) (c x )
+--R  /
+--R                  log(c) 5           log(c) 4       1             log(c) 5
+--R                  ------             ------         -             ------
+--R            6        n           5      n         n n       5        n
+--R         (2b x (%e      )  + 2a b (%e      ) )(c x )  + 2a b x (%e      )
+--R       + 
+--R                 log(c) 4
+--R                 ------
+--R           2 4      n
+--R         2a b (%e      )
+--R    *
+--R             2      3      4
+--R             -      -      -
+--R           n n    n n    n n
+--R       (c x ) (c x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 928
+
+--S 929 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 929
+
+)clear all
+
+--S 930 of 1004
+t0:=x^2/(a+b*(c*x^n)^(1/n))^2
+--R 
+--R
+--R                        2
+--R                       x
+--R   (1)  --------------------------------
+--R                 1 2              1
+--R                 -                -
+--R         2     n n              n n    2
+--R        b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 930
+
+--S 931 of 1004
+r0:=x^3/(b^2*(c*x^n)^(2/n))-a^2*x^3/(b^3*(c*x^n)^(3/n)*(a+b*(c*x^n)^(1/n)))-_
+   2*a*x^3*log(a+b*(c*x^n)^(1/n))/(b^3*(c*x^n)^(3/n))
+--R 
+--R
+--R   (2)
+--R                       1               2            1
+--R                       -               -            -
+--R                3    n n     2 3     n n          n n
+--R       (- 2a b x (c x )  - 2a x )(c x ) log(b (c x )  + a)
+--R     + 
+--R                  1                3             2
+--R                  -                -             -
+--R         2 3    n n        3     n n    2 3    n n
+--R       (b x (c x )  + a b x )(c x )  - a x (c x )
+--R  /
+--R              1              2      3
+--R              -              -      -
+--R       4    n n      3     n n    n n
+--R     (b (c x )  + a b )(c x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 931
+
+--S 932 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   log(c)                 log(c)               log(c) 2
+--R                   ------                 ------               ------
+--R                      n       2              n           2 2      n
+--R       (- 2a b x %e       - 2a )log(b x %e       + a) + b x (%e      )
+--R     + 
+--R               log(c)
+--R               ------
+--R                  n      2
+--R       a b x %e       - a
+--R  /
+--R            log(c) 4          log(c) 3
+--R            ------            ------
+--R      4        n          3      n
+--R     b x (%e      )  + a b (%e      )
+--R                                         Type: Union(Expression(Integer),...)
+--E 932
+
+--S 933 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      log(c) 4             log(c) 3       1             log(c) 4
+--R                      ------               ------         -             ------
+--R                2 4      n         2   3      n         n n     2   4      n
+--R           (2a b x (%e      )  + 2a b x (%e      ) )(c x )  + 2a b x (%e      )
+--R         + 
+--R                   log(c) 3
+--R                   ------
+--R             3 3      n
+--R           2a x (%e      )
+--R      *
+--R               2            1
+--R               -            -
+--R             n n          n n
+--R         (c x ) log(b (c x )  + a)
+--R     + 
+--R                      log(c)              1            log(c)             2
+--R                      ------              -            ------             -
+--R                 2       n       2      n n     2         n       3     n n
+--R         ((- 2a b x %e       - 2a b)(c x )  - 2a b x %e       - 2a )(c x )
+--R      *
+--R               3          log(c)
+--R               -          ------
+--R             n n             n
+--R         (c x ) log(b x %e       + a)
+--R     + 
+--R                       log(c) 2           log(c)             1
+--R                       ------             ------             -
+--R                 3 2      n          2       n      2      n n
+--R               (b x (%e      )  + a b x %e       - a b)(c x )
+--R             + 
+--R                        log(c) 2           log(c)
+--R                        ------             ------
+--R                  2 2      n        2         n      3
+--R               a b x (%e      )  + a b x %e       - a
+--R          *
+--R                   2
+--R                   -
+--R                 n n
+--R             (c x )
+--R         + 
+--R                     log(c) 4            log(c) 3       1            log(c) 4
+--R                     ------              ------         -            ------
+--R               3 4      n          2 3      n         n n      2 4      n
+--R           (- b x (%e      )  - a b x (%e      ) )(c x )  - a b x (%e      )
+--R         + 
+--R                      log(c) 3
+--R                      ------
+--R              2   3      n
+--R           - a b x (%e      )
+--R      *
+--R               3
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                 log(c) 4          log(c) 3       2
+--R                 ------            ------         -
+--R         2   4      n        3 3      n         n n
+--R       (a b x (%e      )  + a x (%e      ) )(c x )
+--R  /
+--R                 log(c) 4          log(c) 3       1            log(c) 4
+--R                 ------            ------         -            ------
+--R           5        n          4      n         n n      4        n
+--R         (b x (%e      )  + a b (%e      ) )(c x )  + a b x (%e      )
+--R       + 
+--R                log(c) 3
+--R                ------
+--R          2 3      n
+--R         a b (%e      )
+--R    *
+--R             2      3
+--R             -      -
+--R           n n    n n
+--R       (c x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 933
+
+--S 934 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 934
+
+)clear all
+
+--S 935 of 1004
+t0:=x/(a+b*(c*x^n)^(1/n))^2
+--R 
+--R
+--R                        x
+--R   (1)  --------------------------------
+--R                 1 2              1
+--R                 -                -
+--R         2     n n              n n    2
+--R        b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 935
+
+--S 936 of 1004
+r0:=a*x^2/(b^2*(c*x^n)^(2/n)*(a+b*(c*x^n)^(1/n)))+x^2*log(a+b*(c*x^n)^(1/n))/_
+   (b^2*(c*x^n)^(2/n))
+--R 
+--R
+--R                   1                    1
+--R                   -                    -
+--R            2    n n      2           n n           2
+--R        (b x (c x )  + a x )log(b (c x )  + a) + a x
+--R   (2)  ---------------------------------------------
+--R                           1              2
+--R                           -              -
+--R                    3    n n      2     n n
+--R                  (b (c x )  + a b )(c x )
+--R                                                    Type: Expression(Integer)
+--E 936
+
+--S 937 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R               log(c)               log(c)
+--R               ------               ------
+--R                  n                    n
+--R        (b x %e       + a)log(b x %e       + a) + a
+--R   (3)  -------------------------------------------
+--R                    log(c) 3          log(c) 2
+--R                    ------            ------
+--R              3        n          2      n
+--R             b x (%e      )  + a b (%e      )
+--R                                         Type: Union(Expression(Integer),...)
+--E 937
+
+--S 938 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     log(c) 3            log(c) 2       1            log(c) 3
+--R                     ------              ------         -            ------
+--R               2 3      n            2      n         n n        3      n
+--R           (- b x (%e      )  - a b x (%e      ) )(c x )  - a b x (%e      )
+--R         + 
+--R                    log(c) 2
+--R                    ------
+--R              2 2      n
+--R           - a x (%e      )
+--R      *
+--R                     1
+--R                     -
+--R                   n n
+--R         log(b (c x )  + a)
+--R     + 
+--R                 log(c)             1           log(c)            2
+--R                 ------             -           ------            -
+--R            2       n             n n              n      2     n n
+--R         ((b x %e       + a b)(c x )  + a b x %e       + a )(c x )
+--R      *
+--R                   log(c)
+--R                   ------
+--R                      n
+--R         log(b x %e       + a)
+--R     + 
+--R                  1            2            log(c) 3          log(c) 2
+--R                  -            -            ------            ------
+--R                n n    2     n n        3      n        2 2      n
+--R       (a b (c x )  + a )(c x )  - a b x (%e      )  - a x (%e      )
+--R  /
+--R                 log(c) 3          log(c) 2       1            log(c) 3
+--R                 ------            ------         -            ------
+--R           4        n          3      n         n n      3        n
+--R         (b x (%e      )  + a b (%e      ) )(c x )  + a b x (%e      )
+--R       + 
+--R                log(c) 2
+--R                ------
+--R          2 2      n
+--R         a b (%e      )
+--R    *
+--R             2
+--R             -
+--R           n n
+--R       (c x )
+--R                                                    Type: Expression(Integer)
+--E 938
+
+--S 939 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 939
+
+)clear all
+
+--S 940 of 1004
+t0:=1/(a+b*(c*x^n)^(1/n))^2
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R                 1 2              1
+--R                 -                -
+--R         2     n n              n n    2
+--R        b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 940
+
+--S 941 of 1004
+r0:=-x/(b*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n)))
+--R 
+--R
+--R                       x
+--R   (2)  - --------------------------
+--R                   1 2             1
+--R                   -               -
+--R           2     n n             n n
+--R          b ((c x ) )  + a b (c x )
+--R                                                    Type: Expression(Integer)
+--E 941
+
+--S 942 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         1
+--R   (3)  - ------------------------------
+--R                 log(c) 2         log(c)
+--R                 ------           ------
+--R           2        n                n
+--R          b x (%e      )  + a b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 942
+
+--S 943 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                1 2           1          log(c) 2         log(c)
+--R                -             -          ------           ------
+--R              n n           n n      2      n                n
+--R     - b ((c x ) )  - a (c x )  + b x (%e      )  + a x %e
+--R  /
+--R               log(c) 2         log(c)        1 2
+--R               ------           ------        -
+--R         3        n          2     n        n n
+--R       (b x (%e      )  + a b %e      )((c x ) )
+--R     + 
+--R                 log(c) 2         log(c)       1
+--R                 ------           ------       -
+--R           2        n        2       n       n n
+--R       (a b x (%e      )  + a b %e      )(c x )
+--R                                                    Type: Expression(Integer)
+--E 943
+
+--S 944 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 944
+
+)clear all
+
+--S 945 of 1004
+t0:=1/(x*(a+b*(c*x^n)^(1/n))^2)
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R                   1 2                1
+--R                   -                  -
+--R         2       n n                n n    2
+--R        b x ((c x ) )  + 2a b x (c x )  + a x
+--R                                                    Type: Expression(Integer)
+--E 945
+
+--S 946 of 1004
+r0:=1/(a*(a+b*(c*x^n)^(1/n)))+log(x)/a^2-log(a+b*(c*x^n)^(1/n))/a^2
+--R 
+--R
+--R                   1                 1                      1
+--R                   -                 -                      -
+--R                 n n               n n                    n n
+--R        (- b (c x )  - a)log(b (c x )  + a) + b log(x)(c x )  + a log(x) + a
+--R   (2)  --------------------------------------------------------------------
+--R                                            1
+--R                                            -
+--R                                   2      n n    3
+--R                                  a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 946
+
+--S 947 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            log(c)               log(c)                    log(c)
+--R            ------               ------                    ------
+--R               n                    n                         n
+--R   (- b x %e       - a)log(b x %e       + a) + b x log(x)%e       + a log(x) + a
+--R   -----------------------------------------------------------------------------
+--R                                        log(c)
+--R                                        ------
+--R                                 2         n      3
+--R                                a b x %e       + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 947
+
+--S 948 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               log(c)             1           log(c)                  1
+--R               ------             -           ------                  -
+--R          2       n             n n              n      2           n n
+--R       ((b x %e       + a b)(c x )  + a b x %e       + a )log(b (c x )  + a)
+--R     + 
+--R                   log(c)             1           log(c)
+--R                   ------             -           ------
+--R              2       n             n n              n      2
+--R         ((- b x %e       - a b)(c x )  - a b x %e       - a )
+--R      *
+--R                   log(c)
+--R                   ------
+--R                      n
+--R         log(b x %e       + a)
+--R     + 
+--R                 1           log(c)
+--R                 -           ------
+--R               n n              n
+--R       a b (c x )  - a b x %e
+--R  /
+--R              log(c)             1           log(c)
+--R              ------             -           ------
+--R       2 2       n      3      n n    3         n      4
+--R     (a b x %e       + a b)(c x )  + a b x %e       + a
+--R                                                    Type: Expression(Integer)
+--E 948
+
+--S 949 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 949
+
+)clear all
+
+--S 950 of 1004
+t0:=1/(x^2*(a+b*(c*x^n)^(1/n))^2)
+--R 
+--R
+--R                           1
+--R   (1)  --------------------------------------
+--R                   1 2                1
+--R                   -                  -
+--R         2 2     n n           2    n n    2 2
+--R        b x ((c x ) )  + 2a b x (c x )  + a x
+--R                                                    Type: Expression(Integer)
+--E 950
+
+--S 951 of 1004
+r0:=(-1)/(a^2*x)-b*(c*x^n)^(1/n)/(a^2*x*(a+b*(c*x^n)^(1/n)))-_
+   2*b*(c*x^n)^(1/n)*log(x)/(a^3*x)+2*b*(c*x^n)^(1/n)*_
+   log(a+b*(c*x^n)^(1/n))/(a^3*x)
+--R 
+--R
+--R   (2)
+--R                  1 2              1             1                        1 2
+--R                  -                -             -                        -
+--R          2     n n              n n           n n          2           n n
+--R       (2b ((c x ) )  + 2a b (c x ) )log(b (c x )  + a) - 2b log(x)((c x ) )
+--R     + 
+--R                                   1
+--R                                   -
+--R                                 n n    2
+--R       (- 2a b log(x) - 2a b)(c x )  - a
+--R  /
+--R                 1
+--R                 -
+--R      3        n n    4
+--R     a b x (c x )  + a x
+--R                                                    Type: Expression(Integer)
+--E 951
+
+--S 952 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                log(c) 2            log(c)           log(c)
+--R                ------              ------           ------
+--R          2 2      n                   n                n
+--R       (2b x (%e      )  + 2a b x %e      )log(b x %e       + a)
+--R     + 
+--R                       log(c) 2                               log(c)
+--R                       ------                                 ------
+--R           2 2            n                                      n      2
+--R       - 2b x log(x)(%e      )  + (- 2a b x log(x) - 2a b x)%e       - a
+--R  /
+--R             log(c)
+--R             ------
+--R      3   2     n      4
+--R     a b x %e       + a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 952
+
+--S 953 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       log(c)                1 2
+--R                       ------                -
+--R                  3       n         2      n n
+--R             (- 2b x %e       - 2a b )((c x ) )
+--R           + 
+--R                         log(c)              1
+--R                         ------              -
+--R                    2       n       2      n n
+--R             (- 2a b x %e       - 2a b)(c x )
+--R      *
+--R                     1
+--R                     -
+--R                   n n
+--R         log(b (c x )  + a)
+--R     + 
+--R                    log(c) 2            log(c)       1             log(c) 2
+--R                    ------              ------       -             ------
+--R              3 2      n           2       n       n n       2 2      n
+--R           (2b x (%e      )  + 2a b x %e      )(c x )  + 2a b x (%e      )
+--R         + 
+--R                    log(c)
+--R                    ------
+--R             2         n
+--R           2a b x %e
+--R      *
+--R                   log(c)
+--R                   ------
+--R                      n
+--R         log(b x %e       + a)
+--R     + 
+--R                     log(c)                      1 2
+--R                     ------                      -
+--R          3             n         2            n n
+--R       (2b x log(x)%e       + 2a b log(x))((c x ) )
+--R     + 
+--R                        log(c) 2                           1
+--R                        ------                             -
+--R            3 2            n         2            2      n n
+--R       (- 2b x log(x)(%e      )  + 2a b log(x) + a b)(c x )
+--R     + 
+--R                         log(c) 2                              log(c)
+--R                         ------                                ------
+--R             2 2            n            2              2         n
+--R       - 2a b x log(x)(%e      )  + (- 2a b x log(x) - a b x)%e
+--R  /
+--R              log(c)               1           log(c)
+--R              ------               -           ------
+--R       3 2 2     n      4        n n    4   2     n      5
+--R     (a b x %e       + a b x)(c x )  + a b x %e       + a x
+--R                                                    Type: Expression(Integer)
+--E 953
+
+--S 954 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 954
+
+)clear all
+
+--S 955 of 1004
+t0:=1/(x^3*(a+b*(c*x^n)^(1/n))^2)
+--R 
+--R
+--R                           1
+--R   (1)  --------------------------------------
+--R                   1 2                1
+--R                   -                  -
+--R         2 3     n n           3    n n    2 3
+--R        b x ((c x ) )  + 2a b x (c x )  + a x
+--R                                                    Type: Expression(Integer)
+--E 955
+
+--S 956 of 1004
+r0:=(-1/2)/(a^2*x^2)+2*b*(c*x^n)^(1/n)/(a^3*x^2)+b^2*(c*x^n)^(2/n)/_
+   (a^3*x^2*(a+b*(c*x^n)^(1/n)))+3*b^2*(c*x^n)^(2/n)*log(x)/(a^4*x^2)-_
+   3*b^2*(c*x^n)^(2/n)*log(a+b*(c*x^n)^(1/n))/(a^4*x^2)
+--R 
+--R
+--R   (2)
+--R                   1               2            1
+--R                   -               -            -
+--R            3    n n       2     n n          n n
+--R       (- 6b (c x )  - 6a b )(c x ) log(b (c x )  + a)
+--R     + 
+--R                       1                             2               1 2
+--R                       -                             -               -
+--R          3          n n       2             2     n n       2     n n
+--R       (6b log(x)(c x )  + 6a b log(x) + 2a b )(c x )  + 4a b ((c x ) )
+--R     + 
+--R                  1
+--R                  -
+--R         2      n n    3
+--R       3a b (c x )  - a
+--R  /
+--R                  1
+--R                  -
+--R       4   2    n n     5 2
+--R     2a b x (c x )  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  log(c) 3             log(c) 2           log(c)
+--R                  ------               ------             ------
+--R            3 3      n           2 2      n                  n
+--R       (- 6b x (%e      )  - 6a b x (%e      ) )log(b x %e       + a)
+--R     + 
+--R                     log(c) 3                               log(c) 2
+--R                     ------                                 ------
+--R         3 3            n            2 2             2 2       n
+--R       6b x log(x)(%e      )  + (6a b x log(x) + 6a b x )(%e      )
+--R     + 
+--R                log(c)
+--R                ------
+--R         2         n      3
+--R       3a b x %e       - a
+--R  /
+--R              log(c)
+--R              ------
+--R       4   3     n       5 2
+--R     2a b x %e       + 2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 957
+
+--S 958 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  log(c)               1            log(c)               2
+--R                  ------               -            ------               -
+--R             4       n         3     n n       3       n       2 2     n n
+--R         ((3b x %e       + 3a b )(c x )  + 3a b x %e       + 3a b )(c x )
+--R      *
+--R                     1
+--R                     -
+--R                   n n
+--R         log(b (c x )  + a)
+--R     + 
+--R                      log(c) 3             log(c) 2       1             log(c) 3
+--R                      ------               ------         -             ------
+--R                4 3      n           3 2      n         n n       3 3      n
+--R           (- 3b x (%e      )  - 3a b x (%e      ) )(c x )  - 3a b x (%e      )
+--R         + 
+--R                       log(c) 2
+--R                       ------
+--R               2 2 2      n
+--R           - 3a b x (%e      )
+--R      *
+--R                   log(c)
+--R                   ------
+--R                      n
+--R         log(b x %e       + a)
+--R     + 
+--R                           log(c)                     1
+--R                           ------                     -
+--R                4             n         3           n n
+--R           (- 3b x log(x)%e       - 3a b log(x))(c x )
+--R         + 
+--R                                      log(c)
+--R                                      ------
+--R                  3              3       n       2 2          2 2
+--R           (- 3a b x log(x) - a b x)%e       - 3a b log(x) - a b
+--R      *
+--R               2
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                   log(c)                1 2
+--R                   ------                -
+--R              3       n       2 2      n n
+--R       (- 2a b x %e       - 2a b )((c x ) )
+--R     + 
+--R                        log(c) 3                               log(c) 2
+--R                        ------                                 ------
+--R            4 3            n            3 2             3 2       n         3
+--R         (3b x log(x)(%e      )  + (3a b x log(x) + 3a b x )(%e      )  - 2a b)
+--R      *
+--R               1
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                       log(c) 3                               log(c) 2
+--R                       ------                                 ------
+--R           3 3            n          2 2 2           2 2 2       n
+--R       3a b x log(x)(%e      )  + (3a b x log(x) + 3a b x )(%e      )
+--R     + 
+--R                log(c)
+--R                ------
+--R         3         n
+--R       2a b x %e
+--R  /
+--R              log(c)                1           log(c)
+--R              ------                -           ------
+--R       4 2 3     n      5   2     n n    5   3     n      6 2
+--R     (a b x %e       + a b x )(c x )  + a b x %e       + a x
+--R                                                    Type: Expression(Integer)
+--E 958
+
+--S 959 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 959
+
+)clear all
+
+--S 960 of 1004
+t0:=x^3*(a+b*(c*x^n)^(1/n))^p
+--R 
+--R
+--R                   1     p
+--R                   -
+--R         3       n n
+--R   (1)  x (b (c x )  + a)
+--R                                                    Type: Expression(Integer)
+--E 960
+
+--S 961 of 1004
+r0:=-a^3*x^4*(a+b*(c*x^n)^(1/n))^(1+p)/(b^4*(1+p)*(c*x^n)^(4/n))+_
+   3*a^2*x^4*(a+b*(c*x^n)^(1/n))^(2+p)/(b^4*(2+p)*(c*x^n)^(4/n))-_
+   3*a*x^4*(a+b*(c*x^n)^(1/n))^(3+p)/(b^4*(3+p)*(c*x^n)^(4/n))+_
+   x^4*(a+b*(c*x^n)^(1/n))^(4+p)/(b^4*(4+p)*(c*x^n)^(4/n))
+--R 
+--R
+--R   (2)
+--R                                      1     p + 4
+--R                                      -
+--R         3     2            4       n n
+--R       (p  + 6p  + 11p + 6)x (b (c x )  + a)
+--R     + 
+--R                                                  1     p + 3
+--R                                                  -
+--R              3        2                4       n n
+--R       (- 3a p  - 21a p  - 42a p - 24a)x (b (c x )  + a)
+--R     + 
+--R                                                 1     p + 2
+--R                                                 -
+--R          2 3      2 2      2       2  4       n n
+--R       (3a p  + 24a p  + 57a p + 36a )x (b (c x )  + a)
+--R     + 
+--R                                                 1     p + 1
+--R                                                 -
+--R           3 3     3 2      3       3  4       n n
+--R       (- a p  - 9a p  - 26a p - 24a )x (b (c x )  + a)
+--R  /
+--R                                                  4
+--R                                                  -
+--R       4 4      4 3      4 2      4       4     n n
+--R     (b p  + 10b p  + 35b p  + 50b p + 24b )(c x )
+--R                                                    Type: Expression(Integer)
+--E 961
+
+--S 962 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                          log(c) 4
+--R                                          ------
+--R           4 3     4 2      4      4  4      n
+--R         (b p  + 6b p  + 11b p + 6b )x (%e      )
+--R       + 
+--R                                         log(c) 3
+--R                                         ------
+--R             3 3       3 2       3   3      n
+--R         (a b p  + 3a b p  + 2a b p)x (%e      )
+--R       + 
+--R                                  log(c) 2              log(c)
+--R                                  ------                ------
+--R              2 2 2     2 2   2      n         3           n       4
+--R         (- 3a b p  - 3a b p)x (%e      )  + 6a b p x %e       - 6a
+--R    *
+--R                     log(c)
+--R                     ------
+--R                        n
+--R         p log(b x %e       + a)
+--R       %e
+--R  /
+--R                                               log(c) 4
+--R                                               ------
+--R       4 4      4 3      4 2      4       4       n
+--R     (b p  + 10b p  + 35b p  + 50b p + 24b )(%e      )
+--R                                         Type: Union(Expression(Integer),...)
+--E 962
+
+--S 963 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            log(c) 4
+--R                                            ------
+--R             4 3     4 2      4      4  4      n
+--R           (b p  + 6b p  + 11b p + 6b )x (%e      )
+--R         + 
+--R                                           log(c) 3
+--R                                           ------
+--R               3 3       3 2       3   3      n
+--R           (a b p  + 3a b p  + 2a b p)x (%e      )
+--R         + 
+--R                                    log(c) 2              log(c)
+--R                                    ------                ------
+--R                2 2 2     2 2   2      n         3           n       4
+--R           (- 3a b p  - 3a b p)x (%e      )  + 6a b p x %e       - 6a
+--R      *
+--R                              log(c)
+--R               4              ------
+--R               -                 n
+--R             n n  p log(b x %e       + a)
+--R         (c x ) %e
+--R     + 
+--R                                  log(c) 4         1     p + 4
+--R                                  ------           -
+--R           3     2            4      n           n n
+--R       (- p  - 6p  - 11p - 6)x (%e      ) (b (c x )  + a)
+--R     + 
+--R                                          log(c) 4         1     p + 3
+--R                                          ------           -
+--R            3        2                4      n           n n
+--R       (3a p  + 21a p  + 42a p + 24a)x (%e      ) (b (c x )  + a)
+--R     + 
+--R                                             log(c) 4         1     p + 2
+--R                                             ------           -
+--R            2 3      2 2      2       2  4      n           n n
+--R       (- 3a p  - 24a p  - 57a p - 36a )x (%e      ) (b (c x )  + a)
+--R     + 
+--R                                         log(c) 4         1     p + 1
+--R                                         ------           -
+--R         3 3     3 2      3       3  4      n           n n
+--R       (a p  + 9a p  + 26a p + 24a )x (%e      ) (b (c x )  + a)
+--R  /
+--R                                               log(c) 4      4
+--R                                               ------        -
+--R       4 4      4 3      4 2      4       4       n        n n
+--R     (b p  + 10b p  + 35b p  + 50b p + 24b )(%e      ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 963
+
+--S 964 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 964
+
+)clear all
+
+--S 965 of 1004
+t0:=x^2*(a+b*(c*x^n)^(1/n))^p
+--R 
+--R
+--R                   1     p
+--R                   -
+--R         2       n n
+--R   (1)  x (b (c x )  + a)
+--R                                                    Type: Expression(Integer)
+--E 965
+
+--S 966 of 1004
+r0:=a^2*x^3*(a+b*(c*x^n)^(1/n))^(1+p)/(b^3*(1+p)*(c*x^n)^(3/n))-_
+   2*a*x^3*(a+b*(c*x^n)^(1/n))^(2+p)/(b^3*(2+p)*(c*x^n)^(3/n))+_
+   x^3*(a+b*(c*x^n)^(1/n))^(3+p)/(b^3*(3+p)*(c*x^n)^(3/n))
+--R 
+--R
+--R   (2)
+--R                               1     p + 3
+--R                               -
+--R         2           3       n n
+--R       (p  + 3p + 2)x (b (c x )  + a)
+--R     + 
+--R                                       1     p + 2
+--R                                       -
+--R              2              3       n n
+--R       (- 2a p  - 8a p - 6a)x (b (c x )  + a)
+--R     + 
+--R                                     1     p + 1
+--R                                     -
+--R         2 2     2      2  3       n n
+--R       (a p  + 5a p + 6a )x (b (c x )  + a)
+--R  /
+--R                                       3
+--R                                       -
+--R       3 3     3 2      3      3     n n
+--R     (b p  + 6b p  + 11b p + 6b )(c x )
+--R                                                    Type: Expression(Integer)
+--E 966
+
+--S 967 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 log(c) 3                        log(c) 2
+--R                                 ------                          ------
+--R           3 2     3      3  3      n           2 2      2   2      n
+--R         (b p  + 3b p + 2b )x (%e      )  + (a b p  + a b p)x (%e      )
+--R       + 
+--R                      log(c)
+--R                      ------
+--R             2           n       3
+--R         - 2a b p x %e       + 2a
+--R    *
+--R                     log(c)
+--R                     ------
+--R                        n
+--R         p log(b x %e       + a)
+--R       %e
+--R  /
+--R                                    log(c) 3
+--R                                    ------
+--R       3 3     3 2      3      3       n
+--R     (b p  + 6b p  + 11b p + 6b )(%e      )
+--R                                         Type: Union(Expression(Integer),...)
+--E 967
+
+--S 968 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   log(c) 3                        log(c) 2
+--R                                   ------                          ------
+--R             3 2     3      3  3      n           2 2      2   2      n
+--R           (b p  + 3b p + 2b )x (%e      )  + (a b p  + a b p)x (%e      )
+--R         + 
+--R                        log(c)
+--R                        ------
+--R               2           n       3
+--R           - 2a b p x %e       + 2a
+--R      *
+--R                              log(c)
+--R               3              ------
+--R               -                 n
+--R             n n  p log(b x %e       + a)
+--R         (c x ) %e
+--R     + 
+--R                           log(c) 3         1     p + 3
+--R                           ------           -
+--R           2           3      n           n n
+--R       (- p  - 3p - 2)x (%e      ) (b (c x )  + a)
+--R     + 
+--R                               log(c) 3         1     p + 2
+--R                               ------           -
+--R            2              3      n           n n
+--R       (2a p  + 8a p + 6a)x (%e      ) (b (c x )  + a)
+--R     + 
+--R                                 log(c) 3         1     p + 1
+--R                                 ------           -
+--R           2 2     2      2  3      n           n n
+--R       (- a p  - 5a p - 6a )x (%e      ) (b (c x )  + a)
+--R  /
+--R                                    log(c) 3      3
+--R                                    ------        -
+--R       3 3     3 2      3      3       n        n n
+--R     (b p  + 6b p  + 11b p + 6b )(%e      ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 968
+
+--S 969 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 969
+
+)clear all
+
+--S 970 of 1004
+t0:=x*(a+b*(c*x^n)^(1/n))^p
+--R 
+--R
+--R                   1     p
+--R                   -
+--R                 n n
+--R   (1)  x (b (c x )  + a)
+--R                                                    Type: Expression(Integer)
+--E 970
+
+--S 971 of 1004
+r0:=-a*x^2*(a+b*(c*x^n)^(1/n))^(1+p)/(b^2*(1+p)*(c*x^n)^(2/n))+_
+   x^2*(a+b*(c*x^n)^(1/n))^(2+p)/(b^2*(2+p)*(c*x^n)^(2/n))
+--R 
+--R
+--R                          1     p + 2                          1     p + 1
+--R                          -                                    -
+--R                2       n n                          2       n n
+--R        (p + 1)x (b (c x )  + a)      + (- a p - 2a)x (b (c x )  + a)
+--R   (2)  ------------------------------------------------------------------
+--R                                                     2
+--R                                                     -
+--R                              2 2     2      2     n n
+--R                            (b p  + 3b p + 2b )(c x )
+--R                                                    Type: Expression(Integer)
+--E 971
+
+--S 972 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                  log(c)
+--R                   log(c) 2             log(c)                    ------
+--R                   ------               ------                       n
+--R      2     2  2      n                    n      2   p log(b x %e       + a)
+--R   ((b p + b )x (%e      )  + a b p x %e       - a )%e
+--R   --------------------------------------------------------------------------
+--R                                               log(c) 2
+--R                                               ------
+--R                           2 2     2      2       n
+--R                         (b p  + 3b p + 2b )(%e      )
+--R                                         Type: Union(Expression(Integer),...)
+--E 972
+
+--S 973 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         log(c) 2             log(c)            2
+--R                         ------               ------            -
+--R            2     2  2      n                    n      2     n n
+--R         ((b p + b )x (%e      )  + a b p x %e       - a )(c x )
+--R      *
+--R                       log(c)
+--R                       ------
+--R                          n
+--R           p log(b x %e       + a)
+--R         %e
+--R     + 
+--R                     log(c) 2         1     p + 2
+--R                     ------           -
+--R                 2      n           n n
+--R       (- p - 1)x (%e      ) (b (c x )  + a)
+--R     + 
+--R                      log(c) 2         1     p + 1
+--R                      ------           -
+--R                  2      n           n n
+--R       (a p + 2a)x (%e      ) (b (c x )  + a)
+--R  /
+--R                           log(c) 2      2
+--R                           ------        -
+--R       2 2     2      2       n        n n
+--R     (b p  + 3b p + 2b )(%e      ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 973
+
+--S 974 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 974
+
+)clear all
+
+--S 975 of 1004
+t0:=(a+b*(c*x^n)^(1/n))^p
+--R 
+--R
+--R                 1     p
+--R                 -
+--R               n n
+--R   (1)  (b (c x )  + a)
+--R                                                    Type: Expression(Integer)
+--E 975
+
+--S 976 of 1004
+r0:=x*(a+b*(c*x^n)^(1/n))^(1+p)/(b*(1+p)*(c*x^n)^(1/n))
+--R 
+--R
+--R                   1     p + 1
+--R                   -
+--R                 n n
+--R        x (b (c x )  + a)
+--R   (2)  ----------------------
+--R                          1
+--R                          -
+--R                        n n
+--R           (b p + b)(c x )
+--R                                                    Type: Expression(Integer)
+--E 976
+
+--S 977 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        log(c)
+--R               log(c)                   ------
+--R               ------                      n
+--R                  n         p log(b x %e       + a)
+--R        (b x %e       + a)%e
+--R   (3)  -------------------------------------------
+--R                                log(c)
+--R                                ------
+--R                                   n
+--R                     (b p + b)%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 977
+
+--S 978 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              log(c)
+--R              log(c)           1              ------
+--R              ------           -                 n
+--R                 n           n n  p log(b x %e       + a)
+--R       (b x %e       + a)(c x ) %e
+--R     + 
+--R             log(c)         1     p + 1
+--R             ------         -
+--R                n         n n
+--R       - x %e      (b (c x )  + a)
+--R  /
+--R                log(c)      1
+--R                ------      -
+--R                   n      n n
+--R     (b p + b)%e      (c x )
+--R                                                    Type: Expression(Integer)
+--E 978
+
+--S 979 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 979
+
+)clear all
+
+--S 980 of 1004
+t0:=(a+b*(c*x^n)^(1/n))^p/x
+--R 
+--R
+--R                 1     p
+--R                 -
+--R               n n
+--R        (b (c x )  + a)
+--R   (1)  ----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 980
+
+--S 981 of 1004
+--r0:=-(a+b*(c*x^n)^(1/n))^(1+p)*_
+-- hypergeometric(1,1+p,2+p,(a+b*(c*x^n)^(1/n))/a)/(a*(1+p))
+--E 981
+
+--S 982 of 1004
+--a0:=integrate(t0,x)
+--E 982
+
+--S 983 of 1004
+--m0:=a0-r0
+--E 983
+
+--S 984 of 1004
+--d0:=normalize(D(m0,x))
+--E 984
+
+)clear all
+
+--S 985 of 1004
+t0:=x/(1+(x^n)^(1/n))^2
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         2
+--R        x  + 2x + 1
+--R                                                    Type: Expression(Integer)
+--E 985
+
+--S 986 of 1004
+r0:=x^2/((x^n)^(2/n)*(1+(x^n)^(1/n)))+x^2*log(1+(x^n)^(1/n))/(x^n)^(2/n)
+--R 
+--R
+--R        (x + 1)log(x + 1) + 1
+--R   (2)  ---------------------
+--R                x + 1
+--R                                                    Type: Expression(Integer)
+--E 986
+
+--S 987 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (x + 1)log(x + 1) + 1
+--R   (3)  ---------------------
+--R                x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 987
+
+--S 988 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 988
+
+--S 989 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 989
+
+)clear all
+
+--S 990 of 1004
+t0:=x^m*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         m       n p q
+--R   (1)  x (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 990
+
+--S 991 of 1004
+r0:=x^(1+m)*(a*(b*x^n)^p)^q/(1+m+n*p*q)
+--R 
+--R
+--R         m + 1       n p q
+--R        x     (a (b x ) )
+--R   (2)  ------------------
+--R           n p q + m + 1
+--R                                                    Type: Expression(Integer)
+--E 991
+
+--S 992 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R            m log(x)  n p q log(x) + p q log(b) + q log(a)
+--R        x %e        %e
+--R   (3)  --------------------------------------------------
+--R                           n p q + m + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 992
+
+--S 993 of 1004
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R      m + 1       n p q       m log(x)  n p q log(x) + p q log(b) + q log(a)
+--R   - x     (a (b x ) )  + x %e        %e
+--R   -------------------------------------------------------------------------
+--R                                 n p q + m + 1
+--R                                                    Type: Expression(Integer)
+--E 993
+
+--S 994 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 994
+
+)clear all
+
+--S 995 of 1004
+t0:=x^2*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         2       n p q
+--R   (1)  x (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 995
+
+--S 996 of 1004
+r0:=x^3*(a*(b*x^n)^p)^q/(3+n*p*q)
+--R 
+--R
+--R         3       n p q
+--R        x (a (b x ) )
+--R   (2)  --------------
+--R           n p q + 3
+--R                                                    Type: Expression(Integer)
+--E 996
+
+--S 997 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3  n p q log(x) + p q log(b) + q log(a)
+--R        x %e
+--R   (3)  ----------------------------------------
+--R                        n p q + 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 997
+
+--S 998 of 1004
+m0:=a0-r0
+--R 
+--R
+--R           3       n p q    3  n p q log(x) + p q log(b) + q log(a)
+--R        - x (a (b x ) )  + x %e
+--R   (4)  -----------------------------------------------------------
+--R                                 n p q + 3
+--R                                                    Type: Expression(Integer)
+--E 998
+
+--S 999 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 999
+
+)clear all
+
+--S 1000 of 1004
+t0:=x*(a*(b*x^n)^p)^q
+--R 
+--R
+--R                 n p q
+--R   (1)  x (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+--S 1001 of 1004
+r0:=x^2*(a*(b*x^n)^p)^q/(2+n*p*q)
+--R 
+--R
+--R         2       n p q
+--R        x (a (b x ) )
+--R   (2)  --------------
+--R           n p q + 2
+--R                                                    Type: Expression(Integer)
+--E 1001
+
+--S 1002 of 1004
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2  n p q log(x) + p q log(b) + q log(a)
+--R        x %e
+--R   (3)  ----------------------------------------
+--R                        n p q + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1002
+
+--S 1003 of 1004
+m0:=a0-r0
+--R 
+--R
+--R           2       n p q    2  n p q log(x) + p q log(b) + q log(a)
+--R        - x (a (b x ) )  + x %e
+--R   (4)  -----------------------------------------------------------
+--R                                 n p q + 2
+--R                                                    Type: Expression(Integer)
+--E 1003
+
+--S 1004 of 1004
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1004
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich22b.input.pamphlet b/src/input/rich22b.input.pamphlet
new file mode 100644
index 0000000..1e152a7
--- /dev/null
+++ b/src/input/rich22b.input.pamphlet
@@ -0,0 +1,13535 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich22b.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Algebraic function problems.input
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich22b.output
+)spool rich22b.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1008
+t0:=(a*(b*x^n)^p)^q
+--R 
+--R
+--R               n p q
+--R   (1)  (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1008
+r0:=x*(a*(b*x^n)^p)^q/(1+n*p*q)
+--R 
+--R
+--R                 n p q
+--R        x (a (b x ) )
+--R   (2)  --------------
+--R           n p q + 1
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            n p q log(x) + p q log(b) + q log(a)
+--R        x %e
+--R   (3)  ----------------------------------------
+--R                        n p q + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                   n p q       n p q log(x) + p q log(b) + q log(a)
+--R        - x (a (b x ) )  + x %e
+--R   (4)  -----------------------------------------------------------
+--R                                 n p q + 1
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 1008
+t0:=(a*(b*x^n)^p)^q/x
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (1)  ------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 1008
+r0:=(a*(b*x^n)^p)^q/(n*p*q)
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (2)  ------------
+--R            n p q
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          n p q log(x) + p q log(b) + q log(a)
+--R        %e
+--R   (3)  --------------------------------------
+--R                         n p q
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                 n p q     n p q log(x) + p q log(b) + q log(a)
+--R        - (a (b x ) )  + %e
+--R   (4)  -------------------------------------------------------
+--R                                 n p q
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 1008
+t0:=(a*(b*x^n)^p)^q/x^2
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (1)  ------------
+--R              2
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1008
+r0:=-(a*(b*x^n)^p)^q/((1-n*p*q)*x)
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (2)  ------------
+--R        (n p q - 1)x
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          n p q log(x) + p q log(b) + q log(a)
+--R        %e
+--R   (3)  --------------------------------------
+--R                     (n p q - 1)x
+--R                                         Type: Union(Expression(Integer),...)
+--E 13
+
+--S 14 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                 n p q     n p q log(x) + p q log(b) + q log(a)
+--R        - (a (b x ) )  + %e
+--R   (4)  -------------------------------------------------------
+--R                              (n p q - 1)x
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 1008
+t0:=(a*(b*x^n)^p)^q/x^3
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (1)  ------------
+--R              3
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1008
+r0:=-(a*(b*x^n)^p)^q/((2-n*p*q)*x^2)
+--R 
+--R
+--R                n p q
+--R         (a (b x ) )
+--R   (2)  -------------
+--R                    2
+--R        (n p q - 2)x
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          n p q log(x) + p q log(b) + q log(a)
+--R        %e
+--R   (3)  --------------------------------------
+--R                                 2
+--R                     (n p q - 2)x
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                 n p q     n p q log(x) + p q log(b) + q log(a)
+--R        - (a (b x ) )  + %e
+--R   (4)  -------------------------------------------------------
+--R                                         2
+--R                             (n p q - 2)x
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 1008
+t0:=x^2/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R                    1
+--R                   ---
+--R               m n m n
+--R        (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 1008
+r0:=1/2*x^3/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R                3
+--R               x
+--R   (2)  ---------------
+--R                     1
+--R                    ---
+--R                m n m n
+--R        2(a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  2
+--R                 x
+--R   (3)  --------------------
+--R           n log(b) + log(a)
+--R           -----------------
+--R                  m n
+--R        2%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 23
+
+--S 24 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      1        n log(b) + log(a)
+--R                     ---       -----------------
+--R         2       m n m n    3         m n
+--R        x (a (b x ) )    - x %e
+--R   (4)  ----------------------------------------
+--R              n log(b) + log(a)            1
+--R              -----------------           ---
+--R                     m n              m n m n
+--R           2%e                 (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 25
+
+)clear all
+
+--S 26 of 1008
+t0:=x/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R                    1
+--R                   ---
+--R               m n m n
+--R        (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1008
+r0:=x^2/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R               2
+--R              x
+--R   (2)  --------------
+--R                    1
+--R                   ---
+--R               m n m n
+--R        (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 x
+--R   (3)  -------------------
+--R          n log(b) + log(a)
+--R          -----------------
+--R                 m n
+--R        %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 28
+
+--S 29 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      1        n log(b) + log(a)
+--R                     ---       -----------------
+--R                 m n m n    2         m n
+--R        x (a (b x ) )    - x %e
+--R   (4)  ----------------------------------------
+--R              n log(b) + log(a)            1
+--R              -----------------           ---
+--R                     m n              m n m n
+--R            %e                 (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 1008
+t0:=1/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R                    1
+--R                   ---
+--R               m n m n
+--R        (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 1008
+r0:=x*log(x)/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R           x log(x)
+--R   (2)  --------------
+--R                    1
+--R                   ---
+--R               m n m n
+--R        (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R               log(x)
+--R   (3)  -------------------
+--R          n log(b) + log(a)
+--R          -----------------
+--R                 m n
+--R        %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 33
+
+--S 34 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                          1              n log(b) + log(a)
+--R                         ---             -----------------
+--R                     m n m n                    m n
+--R        log(x)(a (b x ) )    - x log(x)%e
+--R   (4)  --------------------------------------------------
+--R                   n log(b) + log(a)            1
+--R                   -----------------           ---
+--R                          m n              m n m n
+--R                 %e                 (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 35
+
+)clear all
+
+--S 36 of 1008
+t0:=1/(x*(a*(b*x^m)^n)^(1/(m*n)))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R                      1
+--R                     ---
+--R                 m n m n
+--R        x (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 1008
+r0:=(-1)/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R                 1
+--R   (2)  - --------------
+--R                      1
+--R                     ---
+--R                 m n m n
+--R          (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    1
+--R   (3)  - ---------------------
+--R              n log(b) + log(a)
+--R              -----------------
+--R                     m n
+--R          x %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 38
+
+--S 39 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      1        n log(b) + log(a)
+--R                     ---       -----------------
+--R                 m n m n              m n
+--R        - (a (b x ) )    + x %e
+--R   (4)  ----------------------------------------
+--R               n log(b) + log(a)            1
+--R               -----------------           ---
+--R                      m n              m n m n
+--R           x %e                 (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 40
+
+)clear all
+
+--S 41 of 1008
+t0:=1/(x^2*(a*(b*x^m)^n)^(1/(m*n)))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R                      1
+--R                     ---
+--R         2       m n m n
+--R        x (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 1008
+r0:=(-1/2)/(x*(a*(b*x^m)^n)^(1/(m*n)))
+--R 
+--R
+--R                  1
+--R   (2)  - -----------------
+--R                         1
+--R                        ---
+--R                    m n m n
+--R          2x (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     1
+--R   (3)  - ----------------------
+--R               n log(b) + log(a)
+--R               -----------------
+--R            2         m n
+--R          2x %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 43
+
+--S 44 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      1        n log(b) + log(a)
+--R                     ---       -----------------
+--R                 m n m n              m n
+--R        - (a (b x ) )    + x %e
+--R   (4)  ----------------------------------------
+--R               n log(b) + log(a)            1
+--R               -----------------           ---
+--R            2         m n              m n m n
+--R          2x %e                 (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 1008
+t0:=x^(2-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q + 2       n p q
+--R   (1)  x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 1008
+r0:=1/3*x^(3-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q + 3       n p q
+--R        x           (a (b x ) )
+--R   (2)  ------------------------
+--R                    3
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3  p q log(b) + q log(a)
+--R        x %e
+--R   (3)  -------------------------
+--R                    3
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 1008
+m0:=a0-r0
+--R 
+--R
+--R           - n p q + 3       n p q    3  p q log(b) + q log(a)
+--R        - x           (a (b x ) )  + x %e
+--R   (4)  ------------------------------------------------------
+--R                                   3
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 1008
+t0:=x^(1-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q + 1       n p q
+--R   (1)  x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 1008
+r0:=1/2*x^(2-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q + 2       n p q
+--R        x           (a (b x ) )
+--R   (2)  ------------------------
+--R                    2
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2  p q log(b) + q log(a)
+--R        x %e
+--R   (3)  -------------------------
+--R                    2
+--R                                         Type: Union(Expression(Integer),...)
+--E 53
+
+--S 54 of 1008
+m0:=a0-r0
+--R 
+--R
+--R           - n p q + 2       n p q    2  p q log(b) + q log(a)
+--R        - x           (a (b x ) )  + x %e
+--R   (4)  ------------------------------------------------------
+--R                                   2
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 55
+
+)clear all
+
+--S 56 of 1008
+t0:=(a*(b*x^n)^p)^q/x^(n*p*q)
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (1)  ------------
+--R            n p q
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1008
+r0:=x^(1-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q + 1       n p q
+--R   (2)  x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 57
+
+--S 58 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    x
+--R   (3)  -------------------------
+--R          - p q log(b) - q log(a)
+--R        %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 58
+
+--S 59 of 1008
+m0:=a0-r0
+--R 
+--R
+--R           - n p q + 1  - p q log(b) - q log(a)       n p q
+--R        - x           %e                       (a (b x ) )  + x
+--R   (4)  -------------------------------------------------------
+--R                         - p q log(b) - q log(a)
+--R                       %e
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 1008
+t0:=x^(-1-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q - 1       n p q
+--R   (1)  x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 1008
+r0:=(a*(b*x^n)^p)^q*log(x)/x^(n*p*q)
+--R 
+--R
+--R                     n p q
+--R        log(x)(a (b x ) )
+--R   (2)  ------------------
+--R               n p q
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                p q log(b) + q log(a)
+--R   (3)  log(x)%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 63
+
+--S 64 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                       n p q          n p q  p q log(b) + q log(a)
+--R        - log(x)(a (b x ) )  + log(x)x     %e
+--R   (4)  ----------------------------------------------------------
+--R                                   n p q
+--R                                  x
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 65
+
+)clear all
+
+--S 66 of 1008
+t0:=x^(-2-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q - 2       n p q
+--R   (1)  x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 1008
+r0:=-x^(-1-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R           - n p q - 1       n p q
+--R   (2)  - x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            p q log(b) + q log(a)
+--R          %e
+--R   (3)  - -----------------------
+--R                     x
+--R                                         Type: Union(Expression(Integer),...)
+--E 68
+
+--S 69 of 1008
+m0:=a0-r0
+--R 
+--R
+--R           - n p q - 1       n p q     p q log(b) + q log(a)
+--R        x x           (a (b x ) )  - %e
+--R   (4)  ----------------------------------------------------
+--R                                  x
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 70
+
+)clear all
+
+--S 71 of 1008
+t0:=x^2*(a+b*x)^n*sqrt(c*x^2)
+--R 
+--R
+--R                     +----+
+--R         2         n |   2
+--R   (1)  x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1008
+r0:=-a^3*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^4*(1+n)*x)+3*a^2*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^4*(2+n)*x)-3*a*(a+b*x)^(3+n)*sqrt(c*x^2)/(b^4*(3+n)*x)+_
+   (a+b*x)^(4+n)*sqrt(c*x^2)/(b^4*(4+n)*x)
+--R 
+--R
+--R   (2)
+--R           3     2                    n + 4
+--R         (n  + 6n  + 11n + 6)(b x + a)
+--R       + 
+--R                3        2                        n + 3
+--R         (- 3a n  - 21a n  - 42a n - 24a)(b x + a)
+--R       + 
+--R            2 3      2 2      2       2          n + 2
+--R         (3a n  + 24a n  + 57a n + 36a )(b x + a)
+--R       + 
+--R             3 3     3 2      3       3          n + 1
+--R         (- a n  - 9a n  - 26a n - 24a )(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       4 4      4 3      4 2      4       4
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )x
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4 3     4 2      4      4  4       3 3       3 2       3   3
+--R         (b n  + 6b n  + 11b n + 6b )x  + (a b n  + 3a b n  + 2a b n)x
+--R       + 
+--R              2 2 2     2 2   2     3          4
+--R         (- 3a b n  - 3a b n)x  + 6a b n x - 6a
+--R    *
+--R        +-+  n log(b x + a)
+--R       \|c %e
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     b n  + 10b n  + 35b n  + 50b n + 24b
+--R                                         Type: Union(Expression(Integer),...)
+--E 73
+
+--S 74 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4 3     4 2      4      4  5       3 3       3 2       3   4
+--R           (b n  + 6b n  + 11b n + 6b )x  + (a b n  + 3a b n  + 2a b n)x
+--R         + 
+--R                2 2 2     2 2   3     3     2     4
+--R           (- 3a b n  - 3a b n)x  + 6a b n x  - 6a x
+--R      *
+--R          +-+  n log(b x + a)
+--R         \|c %e
+--R     + 
+--R               3     2                    n + 4
+--R           (- n  - 6n  - 11n - 6)(b x + a)
+--R         + 
+--R                3        2                        n + 3
+--R           (3a n  + 21a n  + 42a n + 24a)(b x + a)
+--R         + 
+--R                2 3      2 2      2       2          n + 2
+--R           (- 3a n  - 24a n  - 57a n - 36a )(b x + a)
+--R         + 
+--R             3 3     3 2      3       3          n + 1
+--R           (a n  + 9a n  + 26a n + 24a )(b x + a)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R       4 4      4 3      4 2      4       4
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )x
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R          3 +-+ |   2       4   (n + 3)log(b x + a)
+--R        (x \|c \|c x   - c x )%e
+--R   (5)  -------------------------------------------
+--R                                          +----+
+--R             3 3       2 2     2       3  |   2
+--R           (b x  + 3a b x  + 3a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 1008
+t0:=x*(a+b*x)^n*sqrt(c*x^2)
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R   (1)  x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 1008
+r0:=a^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^3*(1+n)*x)-2*a*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^3*(2+n)*x)+(a+b*x)^(3+n)*sqrt(c*x^2)/(b^3*(3+n)*x)
+--R 
+--R
+--R   (2)
+--R           2                   n + 3          2                      n + 2
+--R         (n  + 3n + 2)(b x + a)      + (- 2a n  - 8a n - 6a)(b x + a)
+--R       + 
+--R           2 2     2      2          n + 1
+--R         (a n  + 5a n + 6a )(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       3 3     3 2      3      3
+--R     (b n  + 6b n  + 11b n + 6b )x
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3 2     3      3  3       2 2      2   2     2          3  +-+
+--R       ((b n  + 3b n + 2b )x  + (a b n  + a b n)x  - 2a b n x + 2a )\|c
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R      3 3     3 2      3      3
+--R     b n  + 6b n  + 11b n + 6b
+--R                                         Type: Union(Expression(Integer),...)
+--E 78
+
+--S 79 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3 2     3      3  4       2 2      2   3     2     2     3   +-+
+--R         ((b n  + 3b n + 2b )x  + (a b n  + a b n)x  - 2a b n x  + 2a x)\|c
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R               2                   n + 3        2                      n + 2
+--R           (- n  - 3n - 2)(b x + a)      + (2a n  + 8a n + 6a)(b x + a)
+--R         + 
+--R               2 2     2      2          n + 1
+--R           (- a n  - 5a n - 6a )(b x + a)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R       3 3     3 2      3      3
+--R     (b n  + 6b n  + 11b n + 6b )x
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R          2 +-+ |   2       3   (n + 2)log(b x + a)
+--R        (x \|c \|c x   - c x )%e
+--R   (5)  -------------------------------------------
+--R                                     +----+
+--R                  2 2             2  |   2
+--R                (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 80
+
+)clear all
+
+--S 81 of 1008
+t0:=(a+b*x)^n*sqrt(c*x^2)
+--R 
+--R
+--R                   +----+
+--R                 n |   2
+--R   (1)  (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 1008
+r0:=-a*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^2*(1+n)*x)+(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^2*(2+n)*x)
+--R 
+--R
+--R                                                             +----+
+--R                         n + 2                        n + 1  |   2
+--R        ((n + 1)(b x + a)      + (- a n - 2a)(b x + a)     )\|c x
+--R   (2)  -----------------------------------------------------------
+--R                              2 2     2      2
+--R                            (b n  + 3b n + 2b )x
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2     2  2              2  +-+  n log(b x + a)
+--R        ((b n + b )x  + a b n x - a )\|c %e
+--R   (3)  -------------------------------------------------
+--R                         2 2     2      2
+--R                        b n  + 3b n + 2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 83
+
+--S 84 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          2     2  3          2    2   +-+  n log(b x + a)
+--R       ((b n + b )x  + a b n x  - a x)\|c %e
+--R     + 
+--R                                                            +----+
+--R                          n + 2                      n + 1  |   2
+--R       ((- n - 1)(b x + a)      + (a n + 2a)(b x + a)     )\|c x
+--R  /
+--R       2 2     2      2
+--R     (b n  + 3b n + 2b )x
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2       2   (n + 1)log(b x + a)
+--R        (x\|c \|c x   - c x )%e
+--R   (5)  ------------------------------------------
+--R                               +----+
+--R                               |   2
+--R                     (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 1008
+t0:=(a+b*x)^n*sqrt(c*x^2)/x
+--R 
+--R
+--R                   +----+
+--R                 n |   2
+--R        (b x + a) \|c x
+--R   (1)  -----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 1008
+r0:=(a+b*x)^(1+n)*sqrt(c*x^2)/(b*(1+n)*x)
+--R 
+--R
+--R                       +----+
+--R                 n + 1 |   2
+--R        (b x + a)     \|c x
+--R   (2)  ---------------------
+--R              (b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  +-+  n log(b x + a)
+--R        (b x + a)\|c %e
+--R   (3)  -----------------------------
+--R                   b n + b
+--R                                         Type: Union(Expression(Integer),...)
+--E 88
+
+--S 89 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                                          +----+
+--R            2        +-+  n log(b x + a)            n + 1 |   2
+--R        (b x  + a x)\|c %e               - (b x + a)     \|c x
+--R   (4)  --------------------------------------------------------
+--R                               (b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +----+
+--R          +-+ |   2          n log(b x + a)
+--R        (\|c \|c x   - c x)%e
+--R   (5)  -----------------------------------
+--R                       +----+
+--R                       |   2
+--R                      \|c x
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 1008
+t0:=(a+b*x)^n*sqrt(c*x^2)/x^2
+--R 
+--R
+--R                   +----+
+--R                 n |   2
+--R        (b x + a) \|c x
+--R   (1)  -----------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1008
+--r0:=-(a+b*x)^(1+n)*hypergeometric(1,1+n,2+n,(a+b*x)/a)*_
+--   sqrt(c*x^2)/(a*(1+n)*x)
+--E 92
+
+--S 93 of 1008
+--a0:=integrate(t0,x)
+--E 93
+
+--S 94 of 1008
+--m0:=a0-r0
+--E 94
+
+--S 95 of 1008
+--d0:=normalize(D(m0,x))
+--E 95
+
+)clear all
+
+--S 96 of 1008
+t0:=(a+b*x)^n*sqrt(c*x^2)/x^3
+--R 
+--R
+--R                   +----+
+--R                 n |   2
+--R        (b x + a) \|c x
+--R   (1)  -----------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 1008
+--r0:=-(a+b*x)^(1+n)*sqrt(c*x^2)/(a*x^2)-b*n*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a^2*(1+n)*x)
+--E 97
+
+--S 98 of 1008
+--a0:=integrate(t0,x)
+--E 98
+
+--S 99 of 1008
+--m0:=a0-r0
+--E 99
+
+--S 100 of 1008
+--d0:=normalize(D(m0,x))
+--E 100
+
+)clear all
+
+--S 101 of 1008
+t0:=(a+b*x)^n*sqrt(c*x^2)/x^4
+--R 
+--R
+--R                   +----+
+--R                 n |   2
+--R        (b x + a) \|c x
+--R   (1)  -----------------
+--R                 4
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1008
+--r0:=-1/2*(a+b*x)^(1+n)*sqrt(c*x^2)/(a*x^3)+1/2*b*(1-n)*(a+b*x)^(1+n)*_
+--   sqrt(c*x^2)/(a^2*x^2)+1/2*b^2*(1-n)*n*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a^3*(1+n)*x)
+--E 102
+
+--S 103 of 1008
+--a0:=integrate(t0,x)
+--E 103
+
+--S 104 of 1008
+--m0:=a0-r0
+--E 104
+
+--S 105 of 1008
+--d0:=normalize(D(m0,x))
+--E 105
+
+)clear all
+
+--S 106 of 1008
+t0:=x*(c*x^2)^(3/2)*(a+b*x)^n
+--R 
+--R
+--R                       +----+
+--R           3         n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 1008
+r0:=a^4*c*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^5*(1+n)*x)-4*a^3*c*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^5*(2+n)*x)+6*a^2*c*(a+b*x)^(3+n)*sqrt(c*x^2)/(b^5*(3+n)*x)-_
+   4*a*c*(a+b*x)^(4+n)*sqrt(c*x^2)/(b^5*(4+n)*x)+c*(a+b*x)^(5+n)*_
+   sqrt(c*x^2)/(b^5*(5+n)*x)
+--R 
+--R
+--R   (2)
+--R             4        3        2                        n + 5
+--R         (c n  + 10c n  + 35c n  + 50c n + 24c)(b x + a)
+--R       + 
+--R                  4          3           2                              n + 4
+--R         (- 4a c n  - 44a c n  - 164a c n  - 244a c n - 120a c)(b x + a)
+--R       + 
+--R            2   4      2   3       2   2       2          2           n + 3
+--R         (6a c n  + 72a c n  + 294a c n  + 468a c n + 240a c)(b x + a)
+--R       + 
+--R              3   4      3   3       3   2       3          3           n + 2
+--R         (- 4a c n  - 52a c n  - 236a c n  - 428a c n - 240a c)(b x + a)
+--R       + 
+--R           4   4      4   3      4   2       4          4           n + 1
+--R         (a c n  + 14a c n  + 71a c n  + 154a c n + 120a c)(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       5 5      5 4      5 3       5 2       5        5
+--R     (b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b )x
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           5   4      5   3      5   2      5         5   5
+--R         (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c)x
+--R       + 
+--R             4   4       4   3        4   2       4     4
+--R         (a b c n  + 6a b c n  + 11a b c n  + 6a b c n)x
+--R       + 
+--R              2 3   3      2 3   2     2 3     3       3 2   2      3 2     2
+--R         (- 4a b c n  - 12a b c n  - 8a b c n)x  + (12a b c n  + 12a b c n)x
+--R       + 
+--R              4             5
+--R         - 24a b c n x + 24a c
+--R    *
+--R        +-+  n log(b x + a)
+--R       \|c %e
+--R  /
+--R      5 5      5 4      5 3       5 2       5        5
+--R     b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b
+--R                                         Type: Union(Expression(Integer),...)
+--E 108
+
+--S 109 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             5   4      5   3      5   2      5         5   6
+--R           (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c)x
+--R         + 
+--R               4   4       4   3        4   2       4     5
+--R           (a b c n  + 6a b c n  + 11a b c n  + 6a b c n)x
+--R         + 
+--R                2 3   3      2 3   2     2 3     4       3 2   2      3 2     3
+--R           (- 4a b c n  - 12a b c n  - 8a b c n)x  + (12a b c n  + 12a b c n)x
+--R         + 
+--R                4       2      5
+--R           - 24a b c n x  + 24a c x
+--R      *
+--R          +-+  n log(b x + a)
+--R         \|c %e
+--R     + 
+--R                 4        3        2                        n + 5
+--R           (- c n  - 10c n  - 35c n  - 50c n - 24c)(b x + a)
+--R         + 
+--R                  4          3           2                              n + 4
+--R           (4a c n  + 44a c n  + 164a c n  + 244a c n + 120a c)(b x + a)
+--R         + 
+--R                2   4      2   3       2   2       2          2           n + 3
+--R           (- 6a c n  - 72a c n  - 294a c n  - 468a c n - 240a c)(b x + a)
+--R         + 
+--R              3   4      3   3       3   2       3          3           n + 2
+--R           (4a c n  + 52a c n  + 236a c n  + 428a c n + 240a c)(b x + a)
+--R         + 
+--R               4   4      4   3      4   2       4          4           n + 1
+--R           (- a c n  - 14a c n  - 71a c n  - 154a c n - 120a c)(b x + a)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R       5 5      5 4      5 3       5 2       5        5
+--R     (b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b )x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +----+
+--R             4 +-+ |   2     2 5   (n + 4)log(b x + a)
+--R         (c x \|c \|c x   - c x )%e
+--R   (5)  -----------------------------------------------
+--R                                                 +----+
+--R          4 4       3 3     2 2 2     3       4  |   2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 110
+
+)clear all
+
+--S 111 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^n
+--R 
+--R
+--R                       +----+
+--R           2         n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 1008
+r0:=-a^3*c*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^4*(1+n)*x)+3*a^2*c*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^4*(2+n)*x)-3*a*c*(a+b*x)^(3+n)*sqrt(c*x^2)/(b^4*(3+n)*x)+_
+   c*(a+b*x)^(4+n)*sqrt(c*x^2)/(b^4*(4+n)*x)
+--R 
+--R
+--R   (2)
+--R             3       2                       n + 4
+--R         (c n  + 6c n  + 11c n + 6c)(b x + a)
+--R       + 
+--R                  3          2                            n + 3
+--R         (- 3a c n  - 21a c n  - 42a c n - 24a c)(b x + a)
+--R       + 
+--R            2   3      2   2      2         2           n + 2
+--R         (3a c n  + 24a c n  + 57a c n + 36a c)(b x + a)
+--R       + 
+--R             3   3     3   2      3         3           n + 1
+--R         (- a c n  - 9a c n  - 26a c n - 24a c)(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       4 4      4 3      4 2      4       4
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )x
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4   3     4   2      4        4   4
+--R         (b c n  + 6b c n  + 11b c n + 6b c)x
+--R       + 
+--R             3   3       3   2       3     3        2 2   2     2 2     2
+--R         (a b c n  + 3a b c n  + 2a b c n)x  + (- 3a b c n  - 3a b c n)x
+--R       + 
+--R           3            4
+--R         6a b c n x - 6a c
+--R    *
+--R        +-+  n log(b x + a)
+--R       \|c %e
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     b n  + 10b n  + 35b n  + 50b n + 24b
+--R                                         Type: Union(Expression(Integer),...)
+--E 113
+
+--S 114 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4   3     4   2      4        4   5
+--R           (b c n  + 6b c n  + 11b c n + 6b c)x
+--R         + 
+--R               3   3       3   2       3     4        2 2   2     2 2     3
+--R           (a b c n  + 3a b c n  + 2a b c n)x  + (- 3a b c n  - 3a b c n)x
+--R         + 
+--R             3       2     4
+--R           6a b c n x  - 6a c x
+--R      *
+--R          +-+  n log(b x + a)
+--R         \|c %e
+--R     + 
+--R                 3       2                       n + 4
+--R           (- c n  - 6c n  - 11c n - 6c)(b x + a)
+--R         + 
+--R                  3          2                            n + 3
+--R           (3a c n  + 21a c n  + 42a c n + 24a c)(b x + a)
+--R         + 
+--R                2   3      2   2      2         2           n + 2
+--R           (- 3a c n  - 24a c n  - 57a c n - 36a c)(b x + a)
+--R         + 
+--R             3   3     3   2      3         3           n + 1
+--R           (a c n  + 9a c n  + 26a c n + 24a c)(b x + a)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R       4 4      4 3      4 2      4       4
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )x
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                  +----+
+--R            3 +-+ |   2     2 4   (n + 3)log(b x + a)
+--R        (c x \|c \|c x   - c x )%e
+--R   (5)  ---------------------------------------------
+--R                                           +----+
+--R              3 3       2 2     2       3  |   2
+--R            (b x  + 3a b x  + 3a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 115
+
+)clear all
+
+--S 116 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x
+--R 
+--R
+--R                       +----+
+--R                     n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1008
+r0:=a^2*c*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^3*(1+n)*x)-2*a*c*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^3*(2+n)*x)+c*(a+b*x)^(3+n)*sqrt(c*x^2)/(b^3*(3+n)*x)
+--R 
+--R
+--R   (2)
+--R             2                      n + 3
+--R         (c n  + 3c n + 2c)(b x + a)
+--R       + 
+--R                  2                          n + 2
+--R         (- 2a c n  - 8a c n - 6a c)(b x + a)
+--R       + 
+--R           2   2     2        2           n + 1
+--R         (a c n  + 5a c n + 6a c)(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       3 3     3 2      3      3
+--R     (b n  + 6b n  + 11b n + 6b )x
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3   2     3        3   3       2   2      2     2     2            3
+--R       ((b c n  + 3b c n + 2b c)x  + (a b c n  + a b c n)x  - 2a b c n x + 2a c)
+--R    *
+--R        +-+  n log(b x + a)
+--R       \|c %e
+--R  /
+--R      3 3     3 2      3      3
+--R     b n  + 6b n  + 11b n + 6b
+--R                                         Type: Union(Expression(Integer),...)
+--E 118
+
+--S 119 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3   2     3        3   4       2   2      2     3     2       2
+--R           (b c n  + 3b c n + 2b c)x  + (a b c n  + a b c n)x  - 2a b c n x
+--R         + 
+--R             3
+--R           2a c x
+--R      *
+--R          +-+  n log(b x + a)
+--R         \|c %e
+--R     + 
+--R                 2                      n + 3
+--R           (- c n  - 3c n - 2c)(b x + a)
+--R         + 
+--R                  2                          n + 2
+--R           (2a c n  + 8a c n + 6a c)(b x + a)
+--R         + 
+--R               2   2     2        2           n + 1
+--R           (- a c n  - 5a c n - 6a c)(b x + a)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R       3 3     3 2      3      3
+--R     (b n  + 6b n  + 11b n + 6b )x
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                  +----+
+--R            2 +-+ |   2     2 3   (n + 2)log(b x + a)
+--R        (c x \|c \|c x   - c x )%e
+--R   (5)  ---------------------------------------------
+--R                                      +----+
+--R                   2 2             2  |   2
+--R                 (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x^2
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R   (1)  c (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1008
+r0:=-a*c*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^2*(1+n)*x)+c*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^2*(2+n)*x)
+--R 
+--R
+--R                                                                   +----+
+--R                           n + 2                            n + 1  |   2
+--R        ((c n + c)(b x + a)      + (- a c n - 2a c)(b x + a)     )\|c x
+--R   (2)  -----------------------------------------------------------------
+--R                                 2 2     2      2
+--R                               (b n  + 3b n + 2b )x
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2       2   2                2   +-+  n log(b x + a)
+--R        ((b c n + b c)x  + a b c n x - a c)\|c %e
+--R   (3)  -------------------------------------------------------
+--R                            2 2     2      2
+--R                           b n  + 3b n + 2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 123
+
+--S 124 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          2       2   3            2    2     +-+  n log(b x + a)
+--R       ((b c n + b c)x  + a b c n x  - a c x)\|c %e
+--R     + 
+--R                                                                  +----+
+--R                            n + 2                          n + 1  |   2
+--R       ((- c n - c)(b x + a)      + (a c n + 2a c)(b x + a)     )\|c x
+--R  /
+--R       2 2     2      2
+--R     (b n  + 3b n + 2b )x
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R             +-+ |   2     2 2   (n + 1)log(b x + a)
+--R        (c x\|c \|c x   - c x )%e
+--R   (5)  --------------------------------------------
+--R                                +----+
+--R                                |   2
+--R                      (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 125
+
+)clear all
+
+--S 126 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x^3
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 1008
+r0:=c*(a+b*x)^(1+n)*sqrt(c*x^2)/(b*(1+n)*x)
+--R 
+--R
+--R                         +----+
+--R                   n + 1 |   2
+--R        c (b x + a)     \|c x
+--R   (2)  -----------------------
+--R               (b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +-+  n log(b x + a)
+--R        (b c x + a c)\|c %e
+--R   (3)  ---------------------------------
+--R                     b n + b
+--R                                         Type: Union(Expression(Integer),...)
+--E 128
+
+--S 129 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                                                +----+
+--R              2          +-+  n log(b x + a)              n + 1 |   2
+--R        (b c x  + a c x)\|c %e               - c (b x + a)     \|c x
+--R   (4)  --------------------------------------------------------------
+--R                                  (b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2     2    n log(b x + a)
+--R        (c\|c \|c x   - c x)%e
+--R   (5)  ------------------------------------
+--R                        +----+
+--R                        |   2
+--R                       \|c x
+--R                                                    Type: Expression(Integer)
+--E 130
+
+)clear all
+
+--S 131 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x^4
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 1008
+--r0:=-c*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a*(1+n)*x)
+--E 132
+
+--S 133 of 1008
+--a0:=integrate(t0,x)
+--E 133
+
+--S 134 of 1008
+--m0:=a0-r0
+--E 134
+
+--S 135 of 1008
+--d0:=normalize(D(m0,x))
+--E 135
+
+)clear all
+
+--S 136 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x^5
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 1008
+--r0:=-c*(a+b*x)^(1+n)*sqrt(c*x^2)/(a*x^2)-b*c*n*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a^2*(1+n)*x)
+--E 137
+
+--S 138 of 1008
+--a0:=integrate(t0,x)
+--E 138
+
+--S 139 of 1008
+--m0:=a0-r0
+--E 139
+
+--S 140 of 1008
+--d0:=normalize(D(m0,x))
+--E 140
+
+)clear all
+
+--S 141 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x^6
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                  4
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 1008
+--r0:=-1/2*c*(a+b*x)^(1+n)*sqrt(c*x^2)/(a*x^3)+1/2*b*c*(1-n)*(a+b*x)^(1+n)*_
+--   sqrt(c*x^2)/(a^2*x^2)+1/2*b^2*c*(1-n)*n*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a^3*(1+n)*x)
+--E 142
+
+--S 143 of 1008
+--a0:=integrate(t0,x)
+--E 143
+
+--S 144 of 1008
+--m0:=a0-r0
+--E 144
+
+--S 145 of 1008
+--d0:=normalize(D(m0,x))
+--E 145
+
+)clear all
+
+--S 146 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^n
+--R 
+--R
+--R                       +----+
+--R         2 4         n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 1008
+r0:=-a^5*c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^6*(1+n)*x)+5*a^4*c^2*_
+   (a+b*x)^(2+n)*sqrt(c*x^2)/(b^6*(2+n)*x)-10*a^3*c^2*(a+b*x)^(3+n)*_
+   sqrt(c*x^2)/(b^6*(3+n)*x)+10*a^2*c^2*(a+b*x)^(4+n)*sqrt(c*x^2)/(b^6*_
+   (4+n)*x)-5*a*c^2*(a+b*x)^(5+n)*sqrt(c*x^2)/(b^6*(5+n)*x)+c^2*_
+   (a+b*x)^(6+n)*sqrt(c*x^2)/(b^6*(6+n)*x)
+--R 
+--R
+--R   (2)
+--R           2 5      2 4      2 3       2 2       2        2          n + 6
+--R         (c n  + 15c n  + 85c n  + 225c n  + 274c n + 120c )(b x + a)
+--R       + 
+--R                  2 5        2 4         2 3          2 2          2          2
+--R           (- 5a c n  - 80a c n  - 475a c n  - 1300a c n  - 1620a c n - 720a c )
+--R        *
+--R                    n + 5
+--R           (b x + a)
+--R       + 
+--R                  2 2 5       2 2 4        2 2 3        2 2 2        2 2
+--R               10a c n  + 170a c n  + 1070a c n  + 3070a c n  + 3960a c n
+--R             + 
+--R                    2 2
+--R               1800a c
+--R        *
+--R                    n + 4
+--R           (b x + a)
+--R       + 
+--R                  3 2 5       3 2 4        3 2 3        3 2 2        3 2
+--R             - 10a c n  - 180a c n  - 1210a c n  - 3720a c n  - 5080a c n
+--R           + 
+--R                    3 2
+--R             - 2400a c
+--R        *
+--R                    n + 3
+--R           (b x + a)
+--R       + 
+--R              4 2 5      4 2 4       4 2 3        4 2 2        4 2         4 2
+--R           (5a c n  + 95a c n  + 685a c n  + 2305a c n  + 3510a c n + 1800a c )
+--R        *
+--R                    n + 2
+--R           (b x + a)
+--R       + 
+--R               5 2 5      5 2 4       5 2 3       5 2 2        5 2        5 2
+--R           (- a c n  - 20a c n  - 155a c n  - 580a c n  - 1044a c n - 720a c )
+--R        *
+--R                    n + 1
+--R           (b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       6 6      6 5       6 4       6 3        6 2        6        6
+--R     (b n  + 21b n  + 175b n  + 735b n  + 1624b n  + 1764b n + 720b )x
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           6 2 5      6 2 4      6 2 3       6 2 2       6 2        6 2  6
+--R         (b c n  + 15b c n  + 85b c n  + 225b c n  + 274b c n + 120b c )x
+--R       + 
+--R             5 2 5        5 2 4        5 2 3        5 2 2        5 2   5
+--R         (a b c n  + 10a b c n  + 35a b c n  + 50a b c n  + 24a b c n)x
+--R       + 
+--R              2 4 2 4      2 4 2 3      2 4 2 2      2 4 2   4
+--R         (- 5a b c n  - 30a b c n  - 55a b c n  - 30a b c n)x
+--R       + 
+--R             3 3 2 3      3 3 2 2      3 3 2   3         4 2 2 2      4 2 2   2
+--R         (20a b c n  + 60a b c n  + 40a b c n)x  + (- 60a b c n  - 60a b c n)x
+--R       + 
+--R             5   2          6 2
+--R         120a b c n x - 120a c
+--R    *
+--R        +-+  n log(b x + a)
+--R       \|c %e
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     b n  + 21b n  + 175b n  + 735b n  + 1624b n  + 1764b n + 720b
+--R                                         Type: Union(Expression(Integer),...)
+--E 148
+
+--S 149 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             6 2 5      6 2 4      6 2 3       6 2 2       6 2        6 2  7
+--R           (b c n  + 15b c n  + 85b c n  + 225b c n  + 274b c n + 120b c )x
+--R         + 
+--R               5 2 5        5 2 4        5 2 3        5 2 2        5 2   6
+--R           (a b c n  + 10a b c n  + 35a b c n  + 50a b c n  + 24a b c n)x
+--R         + 
+--R                2 4 2 4      2 4 2 3      2 4 2 2      2 4 2   5
+--R           (- 5a b c n  - 30a b c n  - 55a b c n  - 30a b c n)x
+--R         + 
+--R               3 3 2 3      3 3 2 2      3 3 2   4
+--R           (20a b c n  + 60a b c n  + 40a b c n)x
+--R         + 
+--R                 4 2 2 2      4 2 2   3       5   2   2       6 2
+--R           (- 60a b c n  - 60a b c n)x  + 120a b c n x  - 120a c x
+--R      *
+--R          +-+  n log(b x + a)
+--R         \|c %e
+--R     + 
+--R               2 5      2 4      2 3       2 2       2        2          n + 6
+--R           (- c n  - 15c n  - 85c n  - 225c n  - 274c n - 120c )(b x + a)
+--R         + 
+--R                  2 5        2 4         2 3          2 2          2          2
+--R             (5a c n  + 80a c n  + 475a c n  + 1300a c n  + 1620a c n + 720a c )
+--R          *
+--R                      n + 5
+--R             (b x + a)
+--R         + 
+--R                    2 2 5       2 2 4        2 2 3        2 2 2        2 2
+--R               - 10a c n  - 170a c n  - 1070a c n  - 3070a c n  - 3960a c n
+--R             + 
+--R                      2 2
+--R               - 1800a c
+--R          *
+--R                      n + 4
+--R             (b x + a)
+--R         + 
+--R                  3 2 5       3 2 4        3 2 3        3 2 2        3 2
+--R               10a c n  + 180a c n  + 1210a c n  + 3720a c n  + 5080a c n
+--R             + 
+--R                    3 2
+--R               2400a c
+--R          *
+--R                      n + 3
+--R             (b x + a)
+--R         + 
+--R                   4 2 5      4 2 4       4 2 3        4 2 2        4 2
+--R               - 5a c n  - 95a c n  - 685a c n  - 2305a c n  - 3510a c n
+--R             + 
+--R                      4 2
+--R               - 1800a c
+--R          *
+--R                      n + 2
+--R             (b x + a)
+--R         + 
+--R               5 2 5      5 2 4       5 2 3       5 2 2        5 2        5 2
+--R             (a c n  + 20a c n  + 155a c n  + 580a c n  + 1044a c n + 720a c )
+--R          *
+--R                      n + 1
+--R             (b x + a)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R       6 6      6 5       6 4       6 3        6 2        6        6
+--R     (b n  + 21b n  + 175b n  + 735b n  + 1624b n  + 1764b n + 720b )x
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                         +----+
+--R                 2 5 +-+ |   2     3 6   (n + 5)log(b x + a)
+--R               (c x \|c \|c x   - c x )%e
+--R   (5)  -----------------------------------------------------------
+--R                                                             +----+
+--R          5 5       4 4      2 3 3      3 2 2     4       5  |   2
+--R        (b x  + 5a b x  + 10a b x  + 10a b x  + 5a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x
+--R 
+--R
+--R                       +----+
+--R         2 3         n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 1008
+r0:=a^4*c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^5*(1+n)*x)-4*a^3*c^2*_
+   (a+b*x)^(2+n)*sqrt(c*x^2)/(b^5*(2+n)*x)+6*a^2*c^2*(a+b*x)^(3+n)*_
+   sqrt(c*x^2)/(b^5*(3+n)*x)-4*a*c^2*(a+b*x)^(4+n)*sqrt(c*x^2)/(b^5*_
+   (4+n)*x)+c^2*(a+b*x)^(5+n)*sqrt(c*x^2)/(b^5*(5+n)*x)
+--R 
+--R
+--R   (2)
+--R           2 4      2 3      2 2      2       2          n + 5
+--R         (c n  + 10c n  + 35c n  + 50c n + 24c )(b x + a)
+--R       + 
+--R                2 4        2 3         2 2         2          2          n + 4
+--R         (- 4a c n  - 44a c n  - 164a c n  - 244a c n - 120a c )(b x + a)
+--R       + 
+--R            2 2 4      2 2 3       2 2 2       2 2        2 2          n + 3
+--R         (6a c n  + 72a c n  + 294a c n  + 468a c n + 240a c )(b x + a)
+--R       + 
+--R              3 2 4      3 2 3       3 2 2       3 2        3 2          n + 2
+--R         (- 4a c n  - 52a c n  - 236a c n  - 428a c n - 240a c )(b x + a)
+--R       + 
+--R           4 2 4      4 2 3      4 2 2       4 2        4 2          n + 1
+--R         (a c n  + 14a c n  + 71a c n  + 154a c n + 120a c )(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       5 5      5 4      5 3       5 2       5        5
+--R     (b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b )x
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           5 2 4      5 2 3      5 2 2      5 2       5 2  5
+--R         (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c )x
+--R       + 
+--R             4 2 4       4 2 3        4 2 2       4 2   4
+--R         (a b c n  + 6a b c n  + 11a b c n  + 6a b c n)x
+--R       + 
+--R              2 3 2 3      2 3 2 2     2 3 2   3       3 2 2 2      3 2 2   2
+--R         (- 4a b c n  - 12a b c n  - 8a b c n)x  + (12a b c n  + 12a b c n)x
+--R       + 
+--R              4   2         5 2
+--R         - 24a b c n x + 24a c
+--R    *
+--R        +-+  n log(b x + a)
+--R       \|c %e
+--R  /
+--R      5 5      5 4      5 3       5 2       5        5
+--R     b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b
+--R                                         Type: Union(Expression(Integer),...)
+--E 153
+
+--S 154 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             5 2 4      5 2 3      5 2 2      5 2       5 2  6
+--R           (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c )x
+--R         + 
+--R               4 2 4       4 2 3        4 2 2       4 2   5
+--R           (a b c n  + 6a b c n  + 11a b c n  + 6a b c n)x
+--R         + 
+--R                2 3 2 3      2 3 2 2     2 3 2   4       3 2 2 2      3 2 2   3
+--R           (- 4a b c n  - 12a b c n  - 8a b c n)x  + (12a b c n  + 12a b c n)x
+--R         + 
+--R                4   2   2      5 2
+--R           - 24a b c n x  + 24a c x
+--R      *
+--R          +-+  n log(b x + a)
+--R         \|c %e
+--R     + 
+--R               2 4      2 3      2 2      2       2          n + 5
+--R           (- c n  - 10c n  - 35c n  - 50c n - 24c )(b x + a)
+--R         + 
+--R                2 4        2 3         2 2         2          2          n + 4
+--R           (4a c n  + 44a c n  + 164a c n  + 244a c n + 120a c )(b x + a)
+--R         + 
+--R                2 2 4      2 2 3       2 2 2       2 2        2 2          n + 3
+--R           (- 6a c n  - 72a c n  - 294a c n  - 468a c n - 240a c )(b x + a)
+--R         + 
+--R              3 2 4      3 2 3       3 2 2       3 2        3 2          n + 2
+--R           (4a c n  + 52a c n  + 236a c n  + 428a c n + 240a c )(b x + a)
+--R         + 
+--R               4 2 4      4 2 3      4 2 2       4 2        4 2          n + 1
+--R           (- a c n  - 14a c n  - 71a c n  - 154a c n - 120a c )(b x + a)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R       5 5      5 4      5 3       5 2       5        5
+--R     (b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b )x
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +----+
+--R           2 4 +-+ |   2     3 5   (n + 4)log(b x + a)
+--R         (c x \|c \|c x   - c x )%e
+--R   (5)  -----------------------------------------------
+--R                                                 +----+
+--R          4 4       3 3     2 2 2     3       4  |   2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 155
+
+)clear all
+
+--S 156 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^2
+--R 
+--R
+--R                       +----+
+--R         2 2         n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 1008
+r0:=-a^3*c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^4*(1+n)*x)+3*a^2*c^2*_
+   (a+b*x)^(2+n)*sqrt(c*x^2)/(b^4*(2+n)*x)-3*a*c^2*(a+b*x)^(3+n)*_
+   sqrt(c*x^2)/(b^4*(3+n)*x)+c^2*(a+b*x)^(4+n)*sqrt(c*x^2)/(b^4*(4+n)*x)
+--R 
+--R
+--R   (2)
+--R           2 3     2 2      2      2          n + 4
+--R         (c n  + 6c n  + 11c n + 6c )(b x + a)
+--R       + 
+--R                2 3        2 2        2         2          n + 3
+--R         (- 3a c n  - 21a c n  - 42a c n - 24a c )(b x + a)
+--R       + 
+--R            2 2 3      2 2 2      2 2       2 2          n + 2
+--R         (3a c n  + 24a c n  + 57a c n + 36a c )(b x + a)
+--R       + 
+--R             3 2 3     3 2 2      3 2       3 2          n + 1
+--R         (- a c n  - 9a c n  - 26a c n - 24a c )(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       4 4      4 3      4 2      4       4
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )x
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4 2 3     4 2 2      4 2      4 2  4
+--R         (b c n  + 6b c n  + 11b c n + 6b c )x
+--R       + 
+--R             3 2 3       3 2 2       3 2   3        2 2 2 2     2 2 2   2
+--R         (a b c n  + 3a b c n  + 2a b c n)x  + (- 3a b c n  - 3a b c n)x
+--R       + 
+--R           3   2        4 2
+--R         6a b c n x - 6a c
+--R    *
+--R        +-+  n log(b x + a)
+--R       \|c %e
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     b n  + 10b n  + 35b n  + 50b n + 24b
+--R                                         Type: Union(Expression(Integer),...)
+--E 158
+
+--S 159 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4 2 3     4 2 2      4 2      4 2  5
+--R           (b c n  + 6b c n  + 11b c n + 6b c )x
+--R         + 
+--R               3 2 3       3 2 2       3 2   4        2 2 2 2     2 2 2   3
+--R           (a b c n  + 3a b c n  + 2a b c n)x  + (- 3a b c n  - 3a b c n)x
+--R         + 
+--R             3   2   2     4 2
+--R           6a b c n x  - 6a c x
+--R      *
+--R          +-+  n log(b x + a)
+--R         \|c %e
+--R     + 
+--R               2 3     2 2      2      2          n + 4
+--R           (- c n  - 6c n  - 11c n - 6c )(b x + a)
+--R         + 
+--R                2 3        2 2        2         2          n + 3
+--R           (3a c n  + 21a c n  + 42a c n + 24a c )(b x + a)
+--R         + 
+--R                2 2 3      2 2 2      2 2       2 2          n + 2
+--R           (- 3a c n  - 24a c n  - 57a c n - 36a c )(b x + a)
+--R         + 
+--R             3 2 3     3 2 2      3 2       3 2          n + 1
+--R           (a c n  + 9a c n  + 26a c n + 24a c )(b x + a)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R       4 4      4 3      4 2      4       4
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )x
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                  +----+
+--R          2 3 +-+ |   2     3 4   (n + 3)log(b x + a)
+--R        (c x \|c \|c x   - c x )%e
+--R   (5)  ---------------------------------------------
+--R                                           +----+
+--R              3 3       2 2     2       3  |   2
+--R            (b x  + 3a b x  + 3a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 160
+
+)clear all
+
+--S 161 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^3
+--R 
+--R
+--R                       +----+
+--R         2           n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 1008
+r0:=a^2*c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^3*(1+n)*x)-2*a*c^2*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^3*(2+n)*x)+c^2*(a+b*x)^(3+n)*sqrt(c*x^2)/(b^3*(3+n)*x)
+--R 
+--R
+--R   (2)
+--R           2 2     2      2          n + 3
+--R         (c n  + 3c n + 2c )(b x + a)
+--R       + 
+--R                2 2       2        2          n + 2
+--R         (- 2a c n  - 8a c n - 6a c )(b x + a)
+--R       + 
+--R           2 2 2     2 2      2 2          n + 1
+--R         (a c n  + 5a c n + 6a c )(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       3 3     3 2      3      3
+--R     (b n  + 6b n  + 11b n + 6b )x
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3 2 2     3 2      3 2  3       2 2 2      2 2   2     2   2
+--R           (b c n  + 3b c n + 2b c )x  + (a b c n  + a b c n)x  - 2a b c n x
+--R         + 
+--R             3 2
+--R           2a c
+--R    *
+--R        +-+  n log(b x + a)
+--R       \|c %e
+--R  /
+--R      3 3     3 2      3      3
+--R     b n  + 6b n  + 11b n + 6b
+--R                                         Type: Union(Expression(Integer),...)
+--E 163
+
+--S 164 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3 2 2     3 2      3 2  4       2 2 2      2 2   3     2   2   2
+--R           (b c n  + 3b c n + 2b c )x  + (a b c n  + a b c n)x  - 2a b c n x
+--R         + 
+--R             3 2
+--R           2a c x
+--R      *
+--R          +-+  n log(b x + a)
+--R         \|c %e
+--R     + 
+--R               2 2     2      2          n + 3
+--R           (- c n  - 3c n - 2c )(b x + a)
+--R         + 
+--R                2 2       2        2          n + 2
+--R           (2a c n  + 8a c n + 6a c )(b x + a)
+--R         + 
+--R               2 2 2     2 2      2 2          n + 1
+--R           (- a c n  - 5a c n - 6a c )(b x + a)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R       3 3     3 2      3      3
+--R     (b n  + 6b n  + 11b n + 6b )x
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                  +----+
+--R          2 2 +-+ |   2     3 3   (n + 2)log(b x + a)
+--R        (c x \|c \|c x   - c x )%e
+--R   (5)  ---------------------------------------------
+--R                                      +----+
+--R                   2 2             2  |   2
+--R                 (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^4
+--R 
+--R
+--R                     +----+
+--R         2         n |   2
+--R   (1)  c (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 1008
+r0:=-a*c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^2*(1+n)*x)+c^2*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^2*(2+n)*x)
+--R 
+--R
+--R                                                                     +----+
+--R           2     2          n + 2         2        2          n + 1  |   2
+--R        ((c n + c )(b x + a)      + (- a c n - 2a c )(b x + a)     )\|c x
+--R   (2)  -------------------------------------------------------------------
+--R                                  2 2     2      2
+--R                                (b n  + 3b n + 2b )x
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2     2 2  2        2       2 2  +-+  n log(b x + a)
+--R        ((b c n + b c )x  + a b c n x - a c )\|c %e
+--R   (3)  ---------------------------------------------------------
+--R                             2 2     2      2
+--R                            b n  + 3b n + 2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 168
+
+--S 169 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          2 2     2 2  3        2   2    2 2   +-+  n log(b x + a)
+--R       ((b c n + b c )x  + a b c n x  - a c x)\|c %e
+--R     + 
+--R                                                                    +----+
+--R            2     2          n + 2       2        2          n + 1  |   2
+--R       ((- c n - c )(b x + a)      + (a c n + 2a c )(b x + a)     )\|c x
+--R  /
+--R       2 2     2      2
+--R     (b n  + 3b n + 2b )x
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R          2  +-+ |   2     3 2   (n + 1)log(b x + a)
+--R        (c x\|c \|c x   - c x )%e
+--R   (5)  --------------------------------------------
+--R                                +----+
+--R                                |   2
+--R                      (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 170
+
+)clear all
+
+--S 171 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^5
+--R 
+--R
+--R                     +----+
+--R         2         n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 1008
+r0:=c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b*(1+n)*x)
+--R 
+--R
+--R                         +----+
+--R         2         n + 1 |   2
+--R        c (b x + a)     \|c x
+--R   (2)  -----------------------
+--R               (b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2       2  +-+  n log(b x + a)
+--R        (b c x + a c )\|c %e
+--R   (3)  ----------------------------------
+--R                      b n + b
+--R                                         Type: Union(Expression(Integer),...)
+--E 173
+
+--S 174 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                                                +----+
+--R            2 2      2   +-+  n log(b x + a)    2         n + 1 |   2
+--R        (b c x  + a c x)\|c %e               - c (b x + a)     \|c x
+--R   (4)  --------------------------------------------------------------
+--R                                  (b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R          2 +-+ |   2     3    n log(b x + a)
+--R        (c \|c \|c x   - c x)%e
+--R   (5)  -------------------------------------
+--R                        +----+
+--R                        |   2
+--R                       \|c x
+--R                                                    Type: Expression(Integer)
+--E 175
+
+)clear all
+
+--S 176 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^6
+--R 
+--R
+--R                     +----+
+--R         2         n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 1008
+--r0:=-c^2*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a*(1+n)*x)
+--E 177
+
+--S 178 of 1008
+--a0:=integrate(t0,x)
+--E 178
+
+--S 179 of 1008
+--m0:=a0-r0
+--E 179
+
+--S 180 of 1008
+--d0:=normalize(D(m0,x))
+--E 180
+
+)clear all
+
+--S 181 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^7
+--R 
+--R
+--R                     +----+
+--R         2         n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1008
+--r0:=-c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(a*x^2)-b*c^2*n*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a^2*(1+n)*x)
+--E 182
+
+--S 183 of 1008
+--a0:=integrate(t0,x)
+--E 183
+
+--S 184 of 1008
+--m0:=a0-r0
+--E 184
+
+--S 185 of 1008
+--d0:=normalize(D(m0,x))
+--E 185
+
+)clear all
+
+--S 186 of 1008
+t0:=x^4*(a+b*x)^n/sqrt(c*x^2)
+--R 
+--R
+--R         4         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R           \|c x
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 1008
+r0:=-a^3*x*(a+b*x)^(1+n)/(b^4*(1+n)*sqrt(c*x^2))+3*a^2*x*(a+b*x)^(2+n)/_
+   (b^4*(2+n)*sqrt(c*x^2))-3*a*x*(a+b*x)^(3+n)/(b^4*(3+n)*sqrt(c*x^2))+_
+   x*(a+b*x)^(4+n)/(b^4*(4+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         3     2                      n + 4
+--R       (n  + 6n  + 11n + 6)x (b x + a)
+--R     + 
+--R              3        2                          n + 3
+--R       (- 3a n  - 21a n  - 42a n - 24a)x (b x + a)
+--R     + 
+--R          2 3      2 2      2       2            n + 2
+--R       (3a n  + 24a n  + 57a n + 36a )x (b x + a)
+--R     + 
+--R           3 3     3 2      3       3            n + 1
+--R       (- a n  - 9a n  - 26a n - 24a )x (b x + a)
+--R  /
+--R                                             +----+
+--R       4 4      4 3      4 2      4       4  |   2
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4 3     4 2      4      4  4       3 3       3 2       3   3
+--R         (b n  + 6b n  + 11b n + 6b )x  + (a b n  + 3a b n  + 2a b n)x
+--R       + 
+--R              2 2 2     2 2   2     3          4
+--R         (- 3a b n  - 3a b n)x  + 6a b n x - 6a
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R       4 4      4 3      4 2      4       4  +-+
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 188
+
+--S 189 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4 3     4 2      4      4  4       3 3       3 2       3   3
+--R           (b n  + 6b n  + 11b n + 6b )x  + (a b n  + 3a b n  + 2a b n)x
+--R         + 
+--R                2 2 2     2 2   2     3          4
+--R           (- 3a b n  - 3a b n)x  + 6a b n x - 6a
+--R      *
+--R          +----+
+--R          |   2   n log(b x + a)
+--R         \|c x  %e
+--R     + 
+--R               3     2                      n + 4
+--R           (- n  - 6n  - 11n - 6)x (b x + a)
+--R         + 
+--R                3        2                          n + 3
+--R           (3a n  + 21a n  + 42a n + 24a)x (b x + a)
+--R         + 
+--R                2 3      2 2      2       2            n + 2
+--R           (- 3a n  - 24a n  - 57a n - 36a )x (b x + a)
+--R         + 
+--R             3 3     3 2      3       3            n + 1
+--R           (a n  + 9a n  + 26a n + 24a )x (b x + a)
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                                 +----+
+--R       4 4      4 3      4 2      4       4  +-+ |   2
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R           3 +-+ |   2       4   (n + 3)log(b x + a)
+--R         (x \|c \|c x   - c x )%e
+--R   (5)  --------------------------------------------
+--R                                              +----+
+--R          3   3       2   2     2         3   |   2
+--R        (b c x  + 3a b c x  + 3a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 190
+
+)clear all
+
+--S 191 of 1008
+t0:=x^3*(a+b*x)^n/sqrt(c*x^2)
+--R 
+--R
+--R         3         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R           \|c x
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1008
+r0:=a^2*x*(a+b*x)^(1+n)/(b^3*(1+n)*sqrt(c*x^2))-2*a*x*(a+b*x)^(2+n)/_
+   (b^3*(2+n)*sqrt(c*x^2))+x*(a+b*x)^(3+n)/(b^3*(3+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         2                     n + 3          2                        n + 2
+--R       (n  + 3n + 2)x (b x + a)      + (- 2a n  - 8a n - 6a)x (b x + a)
+--R     + 
+--R         2 2     2      2            n + 1
+--R       (a n  + 5a n + 6a )x (b x + a)
+--R  /
+--R                                  +----+
+--R       3 3     3 2      3      3  |   2
+--R     (b n  + 6b n  + 11b n + 6b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      3 2     3      3  3       2 2      2   2     2          3   n log(b x + a)
+--R   ((b n  + 3b n + 2b )x  + (a b n  + a b n)x  - 2a b n x + 2a )%e
+--R   -----------------------------------------------------------------------------
+--R                            3 3     3 2      3      3  +-+
+--R                          (b n  + 6b n  + 11b n + 6b )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 193
+
+--S 194 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                       +----+
+--R            3 2     3      3  3       2 2      2   2     2          3  |   2
+--R         ((b n  + 3b n + 2b )x  + (a b n  + a b n)x  - 2a b n x + 2a )\|c x
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R               2                     n + 3        2                        n + 2
+--R           (- n  - 3n - 2)x (b x + a)      + (2a n  + 8a n + 6a)x (b x + a)
+--R         + 
+--R               2 2     2      2            n + 1
+--R           (- a n  - 5a n - 6a )x (b x + a)
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                      +----+
+--R       3 3     3 2      3      3  +-+ |   2
+--R     (b n  + 6b n  + 11b n + 6b )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R          2 +-+ |   2       3   (n + 2)log(b x + a)
+--R        (x \|c \|c x   - c x )%e
+--R   (5)  -------------------------------------------
+--R                                        +----+
+--R                2   2               2   |   2
+--R              (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 1008
+t0:=x^2*(a+b*x)^n/sqrt(c*x^2)
+--R 
+--R
+--R         2         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R           \|c x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1008
+r0:=-a*x*(a+b*x)^(1+n)/(b^2*(1+n)*sqrt(c*x^2))+x*(a+b*x)^(2+n)/_
+   (b^2*(2+n)*sqrt(c*x^2))
+--R 
+--R
+--R                          n + 2                          n + 1
+--R        (n + 1)x (b x + a)      + (- a n - 2a)x (b x + a)
+--R   (2)  ------------------------------------------------------
+--R                                          +----+
+--R                        2 2     2      2  |   2
+--R                      (b n  + 3b n + 2b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2     2  2              2   n log(b x + a)
+--R        ((b n + b )x  + a b n x - a )%e
+--R   (3)  ---------------------------------------------
+--R                     2 2     2      2  +-+
+--R                   (b n  + 3b n + 2b )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 198
+
+--S 199 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     +----+
+--R          2     2  2              2  |   2   n log(b x + a)
+--R       ((b n + b )x  + a b n x - a )\|c x  %e
+--R     + 
+--R                            n + 2                        n + 1  +-+
+--R       ((- n - 1)x (b x + a)      + (a n + 2a)x (b x + a)     )\|c
+--R  /
+--R                             +----+
+--R       2 2     2      2  +-+ |   2
+--R     (b n  + 3b n + 2b )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2       2   (n + 1)log(b x + a)
+--R        (x\|c \|c x   - c x )%e
+--R   (5)  ------------------------------------------
+--R                                 +----+
+--R                                 |   2
+--R                   (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 200
+
+)clear all
+
+--S 201 of 1008
+t0:=x*(a+b*x)^n/sqrt(c*x^2)
+--R 
+--R
+--R                   n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R           \|c x
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 1008
+r0:=x*(a+b*x)^(1+n)/(b*(1+n)*sqrt(c*x^2))
+--R 
+--R
+--R                   n + 1
+--R        x (b x + a)
+--R   (2)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b n + b)\|c x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   n log(b x + a)
+--R        (b x + a)%e
+--R   (3)  -------------------------
+--R                        +-+
+--R              (b n + b)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 203
+
+--S 204 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                  +----+
+--R                  |   2   n log(b x + a)              n + 1 +-+
+--R        (b x + a)\|c x  %e               - x (b x + a)     \|c
+--R   (4)  -------------------------------------------------------
+--R                                        +----+
+--R                                    +-+ |   2
+--R                          (b n + b)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +----+
+--R          +-+ |   2          n log(b x + a)
+--R        (\|c \|c x   - c x)%e
+--R   (5)  -----------------------------------
+--R                        +----+
+--R                        |   2
+--R                      c\|c x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+)clear all
+
+--S 206 of 1008
+t0:=(a+b*x)^n/sqrt(c*x^2)
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R           +----+
+--R           |   2
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 1008
+--r0:=-x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*(1+n)*sqrt(c*x^2))
+--E 207
+
+--S 208 of 1008
+--a0:=integrate(t0,x)
+--E 208
+
+--S 209 of 1008
+--m0:=a0-r0
+--E 209
+
+--S 210 of 1008
+--d0:=normalize(D(m0,x))
+--E 210
+
+)clear all
+
+--S 211 of 1008
+t0:=(a+b*x)^n/(x*sqrt(c*x^2))
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R           +----+
+--R           |   2
+--R         x\|c x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 1008
+--r0:=-(a+b*x)^(1+n)/(a*sqrt(c*x^2))-b*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^2*(1+n)*sqrt(c*x^2))
+--E 212
+
+--S 213 of 1008
+--a0:=integrate(t0,x)
+--E 213
+
+--S 214 of 1008
+--m0:=a0-r0
+--E 214
+
+--S 215 of 1008
+--d0:=normalize(D(m0,x))
+--E 215
+
+)clear all
+
+--S 216 of 1008
+t0:=(a+b*x)^n/(x^2*sqrt(c*x^2))
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R            +----+
+--R          2 |   2
+--R         x \|c x
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 1008
+--r0:=1/2*b*(1-n)*(a+b*x)^(1+n)/(a^2*sqrt(c*x^2))-1/2*(a+b*x)^(1+n)/_
+--   (a*x*sqrt(c*x^2))+1/2*b^2*(1-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^3*(1+n)*sqrt(c*x^2))
+--E 217
+
+--S 218 of 1008
+--a0:=integrate(t0,x)
+--E 218
+
+--S 219 of 1008
+--m0:=a0-r0
+--E 219
+
+--S 220 of 1008
+--d0:=normalize(D(m0,x))
+--E 220
+
+)clear all
+
+--S 221 of 1008
+t0:=(a+b*x)^n/(x^3*sqrt(c*x^2))
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R            +----+
+--R          3 |   2
+--R         x \|c x
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1008
+--r0:=-1/6*b^2*(1-n)*(2-n)*(a+b*x)^(1+n)/(a^3*sqrt(c*x^2))-_
+--   1/3*(a+b*x)^(1+n)/(a*x^2*sqrt(c*x^2))+1/6*b*(2-n)*(a+b*x)^(1+n)/_
+--   (a^2*x*sqrt(c*x^2))-1/6*b^3*(1-n)*(2-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^4*(1+n)*sqrt(c*x^2))
+--E 222
+
+--S 223 of 1008
+--a0:=integrate(t0,x)
+--E 223
+
+--S 224 of 1008
+--m0:=a0-r0
+--E 224
+
+--S 225 of 1008
+--d0:=normalize(D(m0,x))
+--E 225
+
+)clear all
+
+--S 226 of 1008
+t0:=x^6*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R         4         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 1008
+r0:=-a^3*x*(a+b*x)^(1+n)/(b^4*c*(1+n)*sqrt(c*x^2))+3*a^2*x*(a+b*x)^(2+n)/_
+   (b^4*c*(2+n)*sqrt(c*x^2))-3*a*x*(a+b*x)^(3+n)/(b^4*c*(3+n)*sqrt(c*x^2))+_
+   x*(a+b*x)^(4+n)/(b^4*c*(4+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         3     2                      n + 4
+--R       (n  + 6n  + 11n + 6)x (b x + a)
+--R     + 
+--R              3        2                          n + 3
+--R       (- 3a n  - 21a n  - 42a n - 24a)x (b x + a)
+--R     + 
+--R          2 3      2 2      2       2            n + 2
+--R       (3a n  + 24a n  + 57a n + 36a )x (b x + a)
+--R     + 
+--R           3 3     3 2      3       3            n + 1
+--R       (- a n  - 9a n  - 26a n - 24a )x (b x + a)
+--R  /
+--R                                                      +----+
+--R       4   4      4   3      4   2      4         4   |   2
+--R     (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4 3     4 2      4      4  4       3 3       3 2       3   3
+--R         (b n  + 6b n  + 11b n + 6b )x  + (a b n  + 3a b n  + 2a b n)x
+--R       + 
+--R              2 2 2     2 2   2     3          4
+--R         (- 3a b n  - 3a b n)x  + 6a b n x - 6a
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R       4   4      4   3      4   2      4         4   +-+
+--R     (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 228
+
+--S 229 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4 3     4 2      4      4  4       3 3       3 2       3   3
+--R           (b n  + 6b n  + 11b n + 6b )x  + (a b n  + 3a b n  + 2a b n)x
+--R         + 
+--R                2 2 2     2 2   2     3          4
+--R           (- 3a b n  - 3a b n)x  + 6a b n x - 6a
+--R      *
+--R          +----+
+--R          |   2   n log(b x + a)
+--R         \|c x  %e
+--R     + 
+--R               3     2                      n + 4
+--R           (- n  - 6n  - 11n - 6)x (b x + a)
+--R         + 
+--R                3        2                          n + 3
+--R           (3a n  + 21a n  + 42a n + 24a)x (b x + a)
+--R         + 
+--R                2 3      2 2      2       2            n + 2
+--R           (- 3a n  - 24a n  - 57a n - 36a )x (b x + a)
+--R         + 
+--R             3 3     3 2      3       3            n + 1
+--R           (a n  + 9a n  + 26a n + 24a )x (b x + a)
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                                          +----+
+--R       4   4      4   3      4   2      4         4   +-+ |   2
+--R     (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R           3 +-+ |   2       4   (n + 3)log(b x + a)
+--R         (x \|c \|c x   - c x )%e
+--R   (5)  ---------------------------------------------
+--R                                               +----+
+--R          3 2 3       2 2 2     2   2     3 2  |   2
+--R        (b c x  + 3a b c x  + 3a b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 230
+
+)clear all
+
+--S 231 of 1008
+t0:=x^5*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R         3         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 1008
+r0:=a^2*x*(a+b*x)^(1+n)/(b^3*c*(1+n)*sqrt(c*x^2))-2*a*x*(a+b*x)^(2+n)/_
+   (b^3*c*(2+n)*sqrt(c*x^2))+x*(a+b*x)^(3+n)/(b^3*c*(3+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         2                     n + 3          2                        n + 2
+--R       (n  + 3n + 2)x (b x + a)      + (- 2a n  - 8a n - 6a)x (b x + a)
+--R     + 
+--R         2 2     2      2            n + 1
+--R       (a n  + 5a n + 6a )x (b x + a)
+--R  /
+--R                                         +----+
+--R       3   3     3   2      3        3   |   2
+--R     (b c n  + 6b c n  + 11b c n + 6b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      3 2     3      3  3       2 2      2   2     2          3   n log(b x + a)
+--R   ((b n  + 3b n + 2b )x  + (a b n  + a b n)x  - 2a b n x + 2a )%e
+--R   -----------------------------------------------------------------------------
+--R                        3   3     3   2      3        3   +-+
+--R                      (b c n  + 6b c n  + 11b c n + 6b c)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 233
+
+--S 234 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                       +----+
+--R            3 2     3      3  3       2 2      2   2     2          3  |   2
+--R         ((b n  + 3b n + 2b )x  + (a b n  + a b n)x  - 2a b n x + 2a )\|c x
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R               2                     n + 3        2                        n + 2
+--R           (- n  - 3n - 2)x (b x + a)      + (2a n  + 8a n + 6a)x (b x + a)
+--R         + 
+--R               2 2     2      2            n + 1
+--R           (- a n  - 5a n - 6a )x (b x + a)
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                             +----+
+--R       3   3     3   2      3        3   +-+ |   2
+--R     (b c n  + 6b c n  + 11b c n + 6b c)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R          2 +-+ |   2       3   (n + 2)log(b x + a)
+--R        (x \|c \|c x   - c x )%e
+--R   (5)  -------------------------------------------
+--R                                        +----+
+--R               2 2 2         2     2 2  |   2
+--R             (b c x  + 2a b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 235
+
+)clear all
+
+--S 236 of 1008
+t0:=x^4*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R         2         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 1008
+r0:=-a*x*(a+b*x)^(1+n)/(b^2*c*(1+n)*sqrt(c*x^2))+x*(a+b*x)^(2+n)/_
+   (b^2*c*(2+n)*sqrt(c*x^2))
+--R 
+--R
+--R                          n + 2                          n + 1
+--R        (n + 1)x (b x + a)      + (- a n - 2a)x (b x + a)
+--R   (2)  ------------------------------------------------------
+--R                                             +----+
+--R                      2   2     2        2   |   2
+--R                    (b c n  + 3b c n + 2b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 237
+
+--S 238 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2     2  2              2   n log(b x + a)
+--R        ((b n + b )x  + a b n x - a )%e
+--R   (3)  ---------------------------------------------
+--R                   2   2     2        2   +-+
+--R                 (b c n  + 3b c n + 2b c)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 238
+
+--S 239 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     +----+
+--R          2     2  2              2  |   2   n log(b x + a)
+--R       ((b n + b )x  + a b n x - a )\|c x  %e
+--R     + 
+--R                            n + 2                        n + 1  +-+
+--R       ((- n - 1)x (b x + a)      + (a n + 2a)x (b x + a)     )\|c
+--R  /
+--R                                  +----+
+--R       2   2     2        2   +-+ |   2
+--R     (b c n  + 3b c n + 2b c)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2       2   (n + 1)log(b x + a)
+--R        (x\|c \|c x   - c x )%e
+--R   (5)  ------------------------------------------
+--R                                  +----+
+--R                       2       2  |   2
+--R                   (b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 1008
+t0:=x^3*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R                   n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 1008
+r0:=x*(a+b*x)^(1+n)/(b*c*(1+n)*sqrt(c*x^2))
+--R 
+--R
+--R                     n + 1
+--R          x (b x + a)
+--R   (2)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c n + b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   n log(b x + a)
+--R        (b x + a)%e
+--R   (3)  -------------------------
+--R                          +-+
+--R            (b c n + b c)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 243
+
+--S 244 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                  +----+
+--R                  |   2   n log(b x + a)              n + 1 +-+
+--R        (b x + a)\|c x  %e               - x (b x + a)     \|c
+--R   (4)  -------------------------------------------------------
+--R                                          +----+
+--R                                      +-+ |   2
+--R                        (b c n + b c)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +----+
+--R          +-+ |   2          n log(b x + a)
+--R        (\|c \|c x   - c x)%e
+--R   (5)  -----------------------------------
+--R                        +----+
+--R                      2 |   2
+--R                     c \|c x
+--R                                                    Type: Expression(Integer)
+--E 245
+
+)clear all
+
+--S 246 of 1008
+t0:=x^2*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R           +----+
+--R           |   2
+--R         c\|c x
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 1008
+--r0:=-x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*c*(1+n)*sqrt(c*x^2))
+--E 247
+
+--S 248 of 1008
+--a0:=integrate(t0,x)
+--E 248
+
+--S 249 of 1008
+--m0:=a0-r0
+--E 249
+
+--S 250 of 1008
+--d0:=normalize(D(m0,x))
+--E 250
+
+)clear all
+
+--S 251 of 1008
+t0:=x*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R            +----+
+--R            |   2
+--R        c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 1008
+--r0:=-(a+b*x)^(1+n)/(a*c*sqrt(c*x^2))-b*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^2*c*(1+n)*sqrt(c*x^2))
+--E 252
+
+--S 253 of 1008
+--a0:=integrate(t0,x)
+--E 253
+
+--S 254 of 1008
+--m0:=a0-r0
+--E 254
+
+--S 255 of 1008
+--d0:=normalize(D(m0,x))
+--E 255
+
+)clear all
+
+--S 256 of 1008
+t0:=(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R                  n
+--R         (b x + a)
+--R   (1)  -----------
+--R             +----+
+--R           2 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 1008
+--r0:=1/2*b*(1-n)*(a+b*x)^(1+n)/(a^2*c*sqrt(c*x^2))-1/2*(a+b*x)^(1+n)/_
+--   (a*c*x*sqrt(c*x^2))+1/2*b^2*(1-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^3*c*(1+n)*sqrt(c*x^2))
+--E 257
+
+--S 258 of 1008
+--a0:=integrate(t0,x)
+--E 258
+
+--S 259 of 1008
+--m0:=a0-r0
+--E 259
+
+--S 260 of 1008
+--d0:=normalize(D(m0,x))
+--E 260
+
+)clear all
+
+--S 261 of 1008
+t0:=(a+b*x)^n/(x*(c*x^2)^(3/2))
+--R 
+--R
+--R                  n
+--R         (b x + a)
+--R   (1)  -----------
+--R             +----+
+--R           3 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 1008
+--r0:=-1/6*b^2*(1-n)*(2-n)*(a+b*x)^(1+n)/(a^3*c*sqrt(c*x^2))-_
+--   1/3*(a+b*x)^(1+n)/(a*c*x^2*sqrt(c*x^2))+1/6*b*(2-n)*(a+b*x)^(1+n)/_
+--   (a^2*c*x*sqrt(c*x^2))-1/6*b^3*(1-n)*(2-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^4*c*(1+n)*sqrt(c*x^2))
+--E 262
+
+--S 263 of 1008
+--a0:=integrate(t0,x)
+--E 263
+
+--S 264 of 1008
+--m0:=a0-r0
+--E 264
+
+--S 265 of 1008
+--d0:=normalize(D(m0,x))
+--E 265
+
+)clear all
+
+--S 266 of 1008
+t0:=x^8*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R         4         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R             +----+
+--R           2 |   2
+--R          c \|c x
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1008
+r0:=-a^3*x*(a+b*x)^(1+n)/(b^4*c^2*(1+n)*sqrt(c*x^2))+3*a^2*x*(a+b*x)^(2+n)/_
+   (b^4*c^2*(2+n)*sqrt(c*x^2))-3*a*x*(a+b*x)^(3+n)/(b^4*c^2*(3+n)*_
+   sqrt(c*x^2))+x*(a+b*x)^(4+n)/(b^4*c^2*(4+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         3     2                      n + 4
+--R       (n  + 6n  + 11n + 6)x (b x + a)
+--R     + 
+--R              3        2                          n + 3
+--R       (- 3a n  - 21a n  - 42a n - 24a)x (b x + a)
+--R     + 
+--R          2 3      2 2      2       2            n + 2
+--R       (3a n  + 24a n  + 57a n + 36a )x (b x + a)
+--R     + 
+--R           3 3     3 2      3       3            n + 1
+--R       (- a n  - 9a n  - 26a n - 24a )x (b x + a)
+--R  /
+--R                                                       +----+
+--R       4 2 4      4 2 3      4 2 2      4 2       4 2  |   2
+--R     (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4 3     4 2      4      4  4       3 3       3 2       3   3
+--R         (b n  + 6b n  + 11b n + 6b )x  + (a b n  + 3a b n  + 2a b n)x
+--R       + 
+--R              2 2 2     2 2   2     3          4
+--R         (- 3a b n  - 3a b n)x  + 6a b n x - 6a
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R       4 2 4      4 2 3      4 2 2      4 2       4 2  +-+
+--R     (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 268
+
+--S 269 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4 3     4 2      4      4  4       3 3       3 2       3   3
+--R           (b n  + 6b n  + 11b n + 6b )x  + (a b n  + 3a b n  + 2a b n)x
+--R         + 
+--R                2 2 2     2 2   2     3          4
+--R           (- 3a b n  - 3a b n)x  + 6a b n x - 6a
+--R      *
+--R          +----+
+--R          |   2   n log(b x + a)
+--R         \|c x  %e
+--R     + 
+--R               3     2                      n + 4
+--R           (- n  - 6n  - 11n - 6)x (b x + a)
+--R         + 
+--R                3        2                          n + 3
+--R           (3a n  + 21a n  + 42a n + 24a)x (b x + a)
+--R         + 
+--R                2 3      2 2      2       2            n + 2
+--R           (- 3a n  - 24a n  - 57a n - 36a )x (b x + a)
+--R         + 
+--R             3 3     3 2      3       3            n + 1
+--R           (a n  + 9a n  + 26a n + 24a )x (b x + a)
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                                           +----+
+--R       4 2 4      4 2 3      4 2 2      4 2       4 2  +-+ |   2
+--R     (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R           3 +-+ |   2       4   (n + 3)log(b x + a)
+--R         (x \|c \|c x   - c x )%e
+--R   (5)  ---------------------------------------------
+--R                                               +----+
+--R          3 3 3       2 3 2     2   3     3 3  |   2
+--R        (b c x  + 3a b c x  + 3a b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 1008
+t0:=x^7*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R         3         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R             +----+
+--R           2 |   2
+--R          c \|c x
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 1008
+r0:=a^2*x*(a+b*x)^(1+n)/(b^3*c^2*(1+n)*sqrt(c*x^2))-2*a*x*(a+b*x)^(2+n)/_
+   (b^3*c^2*(2+n)*sqrt(c*x^2))+x*(a+b*x)^(3+n)/(b^3*c^2*(3+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         2                     n + 3          2                        n + 2
+--R       (n  + 3n + 2)x (b x + a)      + (- 2a n  - 8a n - 6a)x (b x + a)
+--R     + 
+--R         2 2     2      2            n + 1
+--R       (a n  + 5a n + 6a )x (b x + a)
+--R  /
+--R                                          +----+
+--R       3 2 3     3 2 2      3 2      3 2  |   2
+--R     (b c n  + 6b c n  + 11b c n + 6b c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      3 2     3      3  3       2 2      2   2     2          3   n log(b x + a)
+--R   ((b n  + 3b n + 2b )x  + (a b n  + a b n)x  - 2a b n x + 2a )%e
+--R   -----------------------------------------------------------------------------
+--R                        3 2 3     3 2 2      3 2      3 2  +-+
+--R                      (b c n  + 6b c n  + 11b c n + 6b c )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 273
+
+--S 274 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                       +----+
+--R            3 2     3      3  3       2 2      2   2     2          3  |   2
+--R         ((b n  + 3b n + 2b )x  + (a b n  + a b n)x  - 2a b n x + 2a )\|c x
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R               2                     n + 3        2                        n + 2
+--R           (- n  - 3n - 2)x (b x + a)      + (2a n  + 8a n + 6a)x (b x + a)
+--R         + 
+--R               2 2     2      2            n + 1
+--R           (- a n  - 5a n - 6a )x (b x + a)
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                              +----+
+--R       3 2 3     3 2 2      3 2      3 2  +-+ |   2
+--R     (b c n  + 6b c n  + 11b c n + 6b c )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R          2 +-+ |   2       3   (n + 2)log(b x + a)
+--R        (x \|c \|c x   - c x )%e
+--R   (5)  -------------------------------------------
+--R                                        +----+
+--R               2 3 2         3     2 3  |   2
+--R             (b c x  + 2a b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 275
+
+)clear all
+
+--S 276 of 1008
+t0:=x^6*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R         2         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R             +----+
+--R           2 |   2
+--R          c \|c x
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 1008
+r0:=-a*x*(a+b*x)^(1+n)/(b^2*c^2*(1+n)*sqrt(c*x^2))+x*(a+b*x)^(2+n)/_
+   (b^2*c^2*(2+n)*sqrt(c*x^2))
+--R 
+--R
+--R                          n + 2                          n + 1
+--R        (n + 1)x (b x + a)      + (- a n - 2a)x (b x + a)
+--R   (2)  ------------------------------------------------------
+--R                                             +----+
+--R                     2 2 2     2 2      2 2  |   2
+--R                   (b c n  + 3b c n + 2b c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2     2  2              2   n log(b x + a)
+--R        ((b n + b )x  + a b n x - a )%e
+--R   (3)  ---------------------------------------------
+--R                  2 2 2     2 2      2 2  +-+
+--R                (b c n  + 3b c n + 2b c )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 278
+
+--S 279 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     +----+
+--R          2     2  2              2  |   2   n log(b x + a)
+--R       ((b n + b )x  + a b n x - a )\|c x  %e
+--R     + 
+--R                            n + 2                        n + 1  +-+
+--R       ((- n - 1)x (b x + a)      + (a n + 2a)x (b x + a)     )\|c
+--R  /
+--R                                   +----+
+--R       2 2 2     2 2      2 2  +-+ |   2
+--R     (b c n  + 3b c n + 2b c )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2       2   (n + 1)log(b x + a)
+--R        (x\|c \|c x   - c x )%e
+--R   (5)  ------------------------------------------
+--R                                  +----+
+--R                       3       3  |   2
+--R                   (b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 1008
+t0:=x^5*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R                   n
+--R        x (b x + a)
+--R   (1)  ------------
+--R             +----+
+--R           2 |   2
+--R          c \|c x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 1008
+r0:=x*(a+b*x)^(1+n)/(b*c^2*(1+n)*sqrt(c*x^2))
+--R 
+--R
+--R                      n + 1
+--R           x (b x + a)
+--R   (2)  ---------------------
+--R                       +----+
+--R            2       2  |   2
+--R        (b c n + b c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   n log(b x + a)
+--R        (b x + a)%e
+--R   (3)  -------------------------
+--R                2       2  +-+
+--R            (b c n + b c )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 283
+
+--S 284 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                  +----+
+--R                  |   2   n log(b x + a)              n + 1 +-+
+--R        (b x + a)\|c x  %e               - x (b x + a)     \|c
+--R   (4)  -------------------------------------------------------
+--R                                          +----+
+--R                           2       2  +-+ |   2
+--R                       (b c n + b c )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +----+
+--R          +-+ |   2          n log(b x + a)
+--R        (\|c \|c x   - c x)%e
+--R   (5)  -----------------------------------
+--R                        +----+
+--R                      3 |   2
+--R                     c \|c x
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 1008
+t0:=x^4*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R            +----+
+--R          2 |   2
+--R         c \|c x
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 1008
+--r0:=-x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*c^2*(1+n)*sqrt(c*x^2))
+--E 287
+
+--S 288 of 1008
+--a0:=integrate(t0,x)
+--E 288
+
+--S 289 of 1008
+--m0:=a0-r0
+--E 289
+
+--S 290 of 1008
+--d0:=normalize(D(m0,x))
+--E 290
+
+)clear all
+
+--S 291 of 1008
+t0:=x^3*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R            +----+
+--R         2  |   2
+--R        c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 1008
+--r0:=-(a+b*x)^(1+n)/(a*c^2*sqrt(c*x^2))-b*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^2*c^2*(1+n)*sqrt(c*x^2))
+--E 292
+
+--S 293 of 1008
+--a0:=integrate(t0,x)
+--E 293
+
+--S 294 of 1008
+--m0:=a0-r0
+--E 294
+
+--S 295 of 1008
+--d0:=normalize(D(m0,x))
+--E 295
+
+)clear all
+
+--S 296 of 1008
+t0:=x^2*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R                  n
+--R         (b x + a)
+--R   (1)  -----------
+--R             +----+
+--R         2 2 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1008
+--r0:=1/2*b*(1-n)*(a+b*x)^(1+n)/(a^2*c^2*sqrt(c*x^2))-1/2*(a+b*x)^(1+n)/_
+--   (a*c^2*x*sqrt(c*x^2))+1/2*b^2*(1-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^3*c^2*(1+n)*sqrt(c*x^2))
+--E 297
+
+--S 298 of 1008
+--a0:=integrate(t0,x)
+--E 298
+
+--S 299 of 1008
+--m0:=a0-r0
+--E 299
+
+--S 300 of 1008
+--d0:=normalize(D(m0,x))
+--E 300
+
+)clear all
+
+--S 301 of 1008
+t0:=x*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R                  n
+--R         (b x + a)
+--R   (1)  -----------
+--R             +----+
+--R         2 3 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1008
+--r0:=-1/6*b^2*(1-n)*(2-n)*(a+b*x)^(1+n)/(a^3*c^2*sqrt(c*x^2))-_
+--   1/3*(a+b*x)^(1+n)/(a*c^2*x^2*sqrt(c*x^2))+1/6*b*(2-n)*(a+b*x)^(1+n)/_
+--   (a^2*c^2*x*sqrt(c*x^2))-1/6*b^3*(1-n)*(2-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^4*c^2*(1+n)*sqrt(c*x^2))
+--E 302
+
+--S 303 of 1008
+--a0:=integrate(t0,x)
+--E 303
+
+--S 304 of 1008
+--m0:=a0-r0
+--E 304
+
+--S 305 of 1008
+--d0:=normalize(D(m0,x))
+--E 305
+
+)clear all
+
+--S 306 of 1008
+t0:=x^m*(a+b*x)*sqrt(c*x^2)
+--R 
+--R
+--R                    +----+
+--R                  m |   2
+--R   (1)  (b x + a)x \|c x
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 1008
+r0:=a*x^(1+m)*sqrt(c*x^2)/(2+m)+b*x^(2+m)*sqrt(c*x^2)/(3+m)
+--R 
+--R
+--R                                              +----+
+--R                    m + 2              m + 1  |   2
+--R        ((b m + 2b)x      + (a m + 3a)x     )\|c x
+--R   (2)  --------------------------------------------
+--R                          2
+--R                         m  + 5m + 6
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    3              2  +-+  m log(x)
+--R        ((b m + 2b)x  + (a m + 3a)x )\|c %e
+--R   (3)  -------------------------------------------
+--R                         2
+--R                        m  + 5m + 6
+--R                                         Type: Union(Expression(Integer),...)
+--E 308
+
+--S 309 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   3              2  +-+  m log(x)
+--R       ((b m + 2b)x  + (a m + 3a)x )\|c %e
+--R     + 
+--R                                                 +----+
+--R                     m + 2                m + 1  |   2
+--R       ((- b m - 2b)x      + (- a m - 3a)x     )\|c x
+--R  /
+--R      2
+--R     m  + 5m + 6
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                       +----+
+--R                   +-+ |   2         2           (m + 2)log(x)
+--R        ((b x + a)\|c \|c x   - b c x  - a c x)%e
+--R   (5)  ------------------------------------------------------
+--R                                 +----+
+--R                                 |   2
+--R                               x\|c x
+--R                                                    Type: Expression(Integer)
+--E 310
+
+)clear all
+
+--S 311 of 1008
+t0:=x^3*(a+b*x)*sqrt(c*x^2)
+--R 
+--R
+--R                      +----+
+--R            4      3  |   2
+--R   (1)  (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 1008
+r0:=1/5*a*x^4*sqrt(c*x^2)+1/6*b*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                        +----+
+--R             5       4  |   2
+--R        (5b x  + 6a x )\|c x
+--R   (2)  ----------------------
+--R                  30
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             6       5  +-+
+--R        (5b x  + 6a x )\|c
+--R   (3)  -------------------
+--R                 30
+--R                                         Type: Union(Expression(Integer),...)
+--E 313
+
+--S 314 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                          +----+
+--R               5       4  |   2         6       5  +-+
+--R        (- 5b x  - 6a x )\|c x   + (5b x  + 6a x )\|c
+--R   (4)  ----------------------------------------------
+--R                              30
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                          +----+
+--R            5      4  +-+ |   2         6        5
+--R        (b x  + a x )\|c \|c x   - b c x  - a c x
+--R   (5)  ------------------------------------------
+--R                           +----+
+--R                           |   2
+--R                          \|c x
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 1008
+t0:=x^2*(a+b*x)*sqrt(c*x^2)
+--R 
+--R
+--R                      +----+
+--R            3      2  |   2
+--R   (1)  (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 1008
+r0:=1/4*a*x^3*sqrt(c*x^2)+1/5*b*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                        +----+
+--R             4       3  |   2
+--R        (4b x  + 5a x )\|c x
+--R   (2)  ----------------------
+--R                  20
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             5       4  +-+
+--R        (4b x  + 5a x )\|c
+--R   (3)  -------------------
+--R                 20
+--R                                         Type: Union(Expression(Integer),...)
+--E 318
+
+--S 319 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                          +----+
+--R               4       3  |   2         5       4  +-+
+--R        (- 4b x  - 5a x )\|c x   + (4b x  + 5a x )\|c
+--R   (4)  ----------------------------------------------
+--R                              20
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                          +----+
+--R            4      3  +-+ |   2         5        4
+--R        (b x  + a x )\|c \|c x   - b c x  - a c x
+--R   (5)  ------------------------------------------
+--R                           +----+
+--R                           |   2
+--R                          \|c x
+--R                                                    Type: Expression(Integer)
+--E 320
+
+)clear all
+
+--S 321 of 1008
+t0:=x*(a+b*x)*sqrt(c*x^2)
+--R 
+--R
+--R                     +----+
+--R            2        |   2
+--R   (1)  (b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 1008
+r0:=1/3*a*x^2*sqrt(c*x^2)+1/4*b*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                        +----+
+--R             3       2  |   2
+--R        (3b x  + 4a x )\|c x
+--R   (2)  ----------------------
+--R                  12
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4       3  +-+
+--R        (3b x  + 4a x )\|c
+--R   (3)  -------------------
+--R                 12
+--R                                         Type: Union(Expression(Integer),...)
+--E 323
+
+--S 324 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                          +----+
+--R               3       2  |   2         4       3  +-+
+--R        (- 3b x  - 4a x )\|c x   + (3b x  + 4a x )\|c
+--R   (4)  ----------------------------------------------
+--R                              12
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                          +----+
+--R            3      2  +-+ |   2         4        3
+--R        (b x  + a x )\|c \|c x   - b c x  - a c x
+--R   (5)  ------------------------------------------
+--R                           +----+
+--R                           |   2
+--R                          \|c x
+--R                                                    Type: Expression(Integer)
+--E 325
+
+)clear all
+
+--S 326 of 1008
+t0:=(a+b*x)*sqrt(c*x^2)
+--R 
+--R
+--R                  +----+
+--R                  |   2
+--R   (1)  (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 1008
+r0:=1/2*a*x*sqrt(c*x^2)+1/3*b*x^2*sqrt(c*x^2)
+--R 
+--R
+--R                       +----+
+--R             2         |   2
+--R        (2b x  + 3a x)\|c x
+--R   (2)  ---------------------
+--R                  6
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3       2  +-+
+--R        (2b x  + 3a x )\|c
+--R   (3)  -------------------
+--R                 6
+--R                                         Type: Union(Expression(Integer),...)
+--E 328
+
+--S 329 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                         +----+
+--R               2         |   2         3       2  +-+
+--R        (- 2b x  - 3a x)\|c x   + (2b x  + 3a x )\|c
+--R   (4)  ---------------------------------------------
+--R                              6
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                         +----+
+--R            2        +-+ |   2         3        2
+--R        (b x  + a x)\|c \|c x   - b c x  - a c x
+--R   (5)  -----------------------------------------
+--R                          +----+
+--R                          |   2
+--R                         \|c x
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 1008
+t0:=(a+b*x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R   (1)  ----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 1008
+r0:=a*sqrt(c*x^2)+1/2*b*x*sqrt(c*x^2)
+--R 
+--R
+--R                   +----+
+--R                   |   2
+--R        (b x + 2a)\|c x
+--R   (2)  -----------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2         +-+
+--R        (b x  + 2a x)\|c
+--R   (3)  -----------------
+--R                2
+--R                                         Type: Union(Expression(Integer),...)
+--E 333
+
+--S 334 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                     +----+
+--R                     |   2        2         +-+
+--R        (- b x - 2a)\|c x   + (b x  + 2a x)\|c
+--R   (4)  ---------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                        +----+
+--R                        |   2
+--R                       \|c x
+--R                                                    Type: Expression(Integer)
+--E 335
+
+)clear all
+
+--S 336 of 1008
+t0:=(a+b*x)*sqrt(c*x^2)/x^2
+--R 
+--R
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R   (1)  ----------------
+--R                2
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 1008
+r0:=b*sqrt(c*x^2)+a*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                         +----+
+--R                         |   2
+--R        (a log(x) + b x)\|c x
+--R   (2)  -----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         +-+
+--R   (3)  (a log(x) + b x)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 338
+
+--S 339 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                           +----+
+--R                           |   2                     2  +-+
+--R        (- a log(x) - b x)\|c x   + (a x log(x) + b x )\|c
+--R   (4)  ---------------------------------------------------
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                         +----+
+--R                         |   2
+--R                       x\|c x
+--R                                                    Type: Expression(Integer)
+--E 340
+
+)clear all
+
+--S 341 of 1008
+t0:=(a+b*x)*sqrt(c*x^2)/x^3
+--R 
+--R
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R   (1)  ----------------
+--R                3
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 1008
+r0:=-a*sqrt(c*x^2)/x^2+b*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                         +----+
+--R                         |   2
+--R        (b x log(x) - a)\|c x
+--R   (2)  -----------------------
+--R                    2
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         +-+
+--R        (b x log(x) - a)\|c
+--R   (3)  --------------------
+--R                  x
+--R                                         Type: Union(Expression(Integer),...)
+--E 343
+
+--S 344 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                           +----+
+--R                           |   2        2              +-+
+--R        (- b x log(x) + a)\|c x   + (b x log(x) - a x)\|c
+--R   (4)  --------------------------------------------------
+--R                                 2
+--R                                x
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                         +----+
+--R                       2 |   2
+--R                      x \|c x
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 1008
+t0:=(a+b*x)*sqrt(c*x^2)/x^4
+--R 
+--R
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R   (1)  ----------------
+--R                4
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 1008
+r0:=-1/2*a*sqrt(c*x^2)/x^3-b*sqrt(c*x^2)/x^2
+--R 
+--R
+--R                     +----+
+--R                     |   2
+--R        (- 2b x - a)\|c x
+--R   (2)  -------------------
+--R                  3
+--R                2x
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     +-+
+--R        (- 2b x - a)\|c
+--R   (3)  ----------------
+--R                 2
+--R               2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 348
+
+--S 349 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                   +----+
+--R                   |   2           2        +-+
+--R        (2b x + a)\|c x   + (- 2b x  - a x)\|c
+--R   (4)  ---------------------------------------
+--R                            3
+--R                          2x
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                         +----+
+--R                       3 |   2
+--R                      x \|c x
+--R                                                    Type: Expression(Integer)
+--E 350
+
+)clear all
+
+--S 351 of 1008
+t0:=x^m*(c*x^2)^(3/2)*(a+b*x)
+--R 
+--R
+--R                            +----+
+--R              3        2  m |   2
+--R   (1)  (b c x  + a c x )x \|c x
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 1008
+r0:=a*c*x^(3+m)*sqrt(c*x^2)/(4+m)+b*c*x^(4+m)*sqrt(c*x^2)/(5+m)
+--R 
+--R
+--R                                                      +----+
+--R                        m + 4                  m + 3  |   2
+--R        ((b c m + 4b c)x      + (a c m + 5a c)x     )\|c x
+--R   (2)  ----------------------------------------------------
+--R                             2
+--R                            m  + 9m + 20
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        5                  4  +-+  m log(x)
+--R        ((b c m + 4b c)x  + (a c m + 5a c)x )\|c %e
+--R   (3)  ---------------------------------------------------
+--R                             2
+--R                            m  + 9m + 20
+--R                                         Type: Union(Expression(Integer),...)
+--E 353
+
+--S 354 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       5                  4  +-+  m log(x)
+--R       ((b c m + 4b c)x  + (a c m + 5a c)x )\|c %e
+--R     + 
+--R                                                         +----+
+--R                         m + 4                    m + 3  |   2
+--R       ((- b c m - 4b c)x      + (- a c m - 5a c)x     )\|c x
+--R  /
+--R      2
+--R     m  + 9m + 20
+--R                                                    Type: Expression(Integer)
+--E 354
+
+--S 355 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                           +----+
+--R                       +-+ |   2       2 2      2    (m + 4)log(x)
+--R        ((b c x + a c)\|c \|c x   - b c x  - a c x)%e
+--R   (5)  ----------------------------------------------------------
+--R                                   +----+
+--R                                   |   2
+--R                                 x\|c x
+--R                                                    Type: Expression(Integer)
+--E 355
+
+)clear all
+
+--S 356 of 1008
+t0:=x^3*(c*x^2)^(3/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R              6        5  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 1008
+r0:=1/7*a*c*x^6*sqrt(c*x^2)+1/8*b*c*x^7*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R               7         6  |   2
+--R        (7b c x  + 8a c x )\|c x
+--R   (2)  --------------------------
+--R                    56
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R               8         7  +-+
+--R        (7b c x  + 8a c x )\|c
+--R   (3)  -----------------------
+--R                   56
+--R                                         Type: Union(Expression(Integer),...)
+--E 358
+
+--S 359 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R                 7         6  |   2           8         7  +-+
+--R        (- 7b c x  - 8a c x )\|c x   + (7b c x  + 8a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  56
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R              7        6  +-+ |   2       2 8      2 7
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 1008
+t0:=x^2*(c*x^2)^(3/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R              5        4  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 1008
+r0:=1/6*a*c*x^5*sqrt(c*x^2)+1/7*b*c*x^6*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R               6         5  |   2
+--R        (6b c x  + 7a c x )\|c x
+--R   (2)  --------------------------
+--R                    42
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R               7         6  +-+
+--R        (6b c x  + 7a c x )\|c
+--R   (3)  -----------------------
+--R                   42
+--R                                         Type: Union(Expression(Integer),...)
+--E 363
+
+--S 364 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R                 6         5  |   2           7         6  +-+
+--R        (- 6b c x  - 7a c x )\|c x   + (6b c x  + 7a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  42
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R              6        5  +-+ |   2       2 7      2 6
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 365
+
+)clear all
+
+--S 366 of 1008
+t0:=x*(c*x^2)^(3/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R              4        3  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 1008
+r0:=1/5*a*c*x^4*sqrt(c*x^2)+1/6*b*c*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R               5         4  |   2
+--R        (5b c x  + 6a c x )\|c x
+--R   (2)  --------------------------
+--R                    30
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R               6         5  +-+
+--R        (5b c x  + 6a c x )\|c
+--R   (3)  -----------------------
+--R                   30
+--R                                         Type: Union(Expression(Integer),...)
+--E 368
+
+--S 369 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R                 5         4  |   2           6         5  +-+
+--R        (- 5b c x  - 6a c x )\|c x   + (5b c x  + 6a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  30
+--R                                                    Type: Expression(Integer)
+--E 369
+
+--S 370 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R              5        4  +-+ |   2       2 6      2 5
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 370
+
+)clear all
+
+--S 371 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R              3        2  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1008
+r0:=1/4*a*c*x^3*sqrt(c*x^2)+1/5*b*c*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R               4         3  |   2
+--R        (4b c x  + 5a c x )\|c x
+--R   (2)  --------------------------
+--R                    20
+--R                                                    Type: Expression(Integer)
+--E 372
+
+--S 373 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R               5         4  +-+
+--R        (4b c x  + 5a c x )\|c
+--R   (3)  -----------------------
+--R                   20
+--R                                         Type: Union(Expression(Integer),...)
+--E 373
+
+--S 374 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R                 4         3  |   2           5         4  +-+
+--R        (- 4b c x  - 5a c x )\|c x   + (4b c x  + 5a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  20
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R              4        3  +-+ |   2       2 5      2 4
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)/x
+--R 
+--R
+--R                         +----+
+--R              2          |   2
+--R   (1)  (b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1008
+r0:=1/3*a*c*x^2*sqrt(c*x^2)+1/4*b*c*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R               3         2  |   2
+--R        (3b c x  + 4a c x )\|c x
+--R   (2)  --------------------------
+--R                    12
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R               4         3  +-+
+--R        (3b c x  + 4a c x )\|c
+--R   (3)  -----------------------
+--R                   12
+--R                                         Type: Union(Expression(Integer),...)
+--E 378
+
+--S 379 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R                 3         2  |   2           4         3  +-+
+--R        (- 3b c x  - 4a c x )\|c x   + (3b c x  + 4a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  12
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R              3        2  +-+ |   2       2 4      2 3
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 380
+
+)clear all
+
+--S 381 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)/x^2
+--R 
+--R
+--R                      +----+
+--R                      |   2
+--R   (1)  (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 1008
+r0:=1/2*a*c*x*sqrt(c*x^2)+1/3*b*c*x^2*sqrt(c*x^2)
+--R 
+--R
+--R                           +----+
+--R               2           |   2
+--R        (2b c x  + 3a c x)\|c x
+--R   (2)  -------------------------
+--R                    6
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3         2  +-+
+--R        (2b c x  + 3a c x )\|c
+--R   (3)  -----------------------
+--R                   6
+--R                                         Type: Union(Expression(Integer),...)
+--E 383
+
+--S 384 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                             +----+
+--R                 2           |   2           3         2  +-+
+--R        (- 2b c x  - 3a c x)\|c x   + (2b c x  + 3a c x )\|c
+--R   (4)  -----------------------------------------------------
+--R                                  6
+--R                                                    Type: Expression(Integer)
+--E 384
+
+--S 385 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                             +----+
+--R              2          +-+ |   2       2 3      2 2
+--R        (b c x  + a c x)\|c \|c x   - b c x  - a c x
+--R   (5)  ---------------------------------------------
+--R                            +----+
+--R                            |   2
+--R                           \|c x
+--R                                                    Type: Expression(Integer)
+--E 385
+
+)clear all
+
+--S 386 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)/x^3
+--R 
+--R
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R   (1)  --------------------
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 1008
+r0:=a*c*sqrt(c*x^2)+1/2*b*c*x*sqrt(c*x^2)
+--R 
+--R
+--R                       +----+
+--R                       |   2
+--R        (b c x + 2a c)\|c x
+--R   (2)  ---------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2           +-+
+--R        (b c x  + 2a c x)\|c
+--R   (3)  ---------------------
+--R                  2
+--R                                         Type: Union(Expression(Integer),...)
+--E 388
+
+--S 389 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                         +----+
+--R                         |   2          2           +-+
+--R        (- b c x - 2a c)\|c x   + (b c x  + 2a c x)\|c
+--R   (4)  -----------------------------------------------
+--R                               2
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                          +----+
+--R                      +-+ |   2       2 2      2
+--R        (b c x + a c)\|c \|c x   - b c x  - a c x
+--R   (5)  -----------------------------------------
+--R                          +----+
+--R                          |   2
+--R                         \|c x
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)/x^4
+--R 
+--R
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R   (1)  --------------------
+--R                  2
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1008
+r0:=b*c*sqrt(c*x^2)+a*c*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                             +----+
+--R                             |   2
+--R        (a c log(x) + b c x)\|c x
+--R   (2)  ---------------------------
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             +-+
+--R   (3)  (a c log(x) + b c x)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 393
+
+--S 394 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                               +----+
+--R                               |   2                         2  +-+
+--R        (- a c log(x) - b c x)\|c x   + (a c x log(x) + b c x )\|c
+--R   (4)  -----------------------------------------------------------
+--R                                     x
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                          +----+
+--R                      +-+ |   2       2 2      2
+--R        (b c x + a c)\|c \|c x   - b c x  - a c x
+--R   (5)  -----------------------------------------
+--R                           +----+
+--R                           |   2
+--R                         x\|c x
+--R                                                    Type: Expression(Integer)
+--E 395
+
+)clear all
+
+--S 396 of 1008
+t0:=x^m*(c*x^2)^(5/2)*(a+b*x)
+--R 
+--R
+--R                            +----+
+--R            2 5      2 4  m |   2
+--R   (1)  (b c x  + a c x )x \|c x
+--R                                                    Type: Expression(Integer)
+--E 396
+
+--S 397 of 1008
+r0:=a*c^2*x^(5+m)*sqrt(c*x^2)/(6+m)+b*c^2*x^(6+m)*sqrt(c*x^2)/(7+m)
+--R 
+--R
+--R                                                        +----+
+--R             2        2  m + 6       2        2  m + 5  |   2
+--R        ((b c m + 6b c )x      + (a c m + 7a c )x     )\|c x
+--R   (2)  ------------------------------------------------------
+--R                              2
+--R                             m  + 13m + 42
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2        2  7       2        2  6  +-+  m log(x)
+--R        ((b c m + 6b c )x  + (a c m + 7a c )x )\|c %e
+--R   (3)  -----------------------------------------------------
+--R                             2
+--R                            m  + 13m + 42
+--R                                         Type: Union(Expression(Integer),...)
+--E 398
+
+--S 399 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            2        2  7       2        2  6  +-+  m log(x)
+--R       ((b c m + 6b c )x  + (a c m + 7a c )x )\|c %e
+--R     + 
+--R                                                           +----+
+--R              2        2  m + 6         2        2  m + 5  |   2
+--R       ((- b c m - 6b c )x      + (- a c m - 7a c )x     )\|c x
+--R  /
+--R      2
+--R     m  + 13m + 42
+--R                                                    Type: Expression(Integer)
+--E 399
+
+--S 400 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                            +----+
+--R             2       2  +-+ |   2       3 2      3    (m + 6)log(x)
+--R        ((b c x + a c )\|c \|c x   - b c x  - a c x)%e
+--R   (5)  -----------------------------------------------------------
+--R                                    +----+
+--R                                    |   2
+--R                                  x\|c x
+--R                                                    Type: Expression(Integer)
+--E 400
+
+)clear all
+
+--S 401 of 1008
+t0:=x^3*(c*x^2)^(5/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R            2 8      2 7  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 1008
+r0:=1/9*a*c^2*x^8*sqrt(c*x^2)+1/10*b*c^2*x^9*sqrt(c*x^2)
+--R 
+--R
+--R                             +----+
+--R             2 9        2 8  |   2
+--R        (9b c x  + 10a c x )\|c x
+--R   (2)  ---------------------------
+--R                     90
+--R                                                    Type: Expression(Integer)
+--E 402
+
+--S 403 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 10        2 9  +-+
+--R        (9b c x   + 10a c x )\|c
+--R   (3)  -------------------------
+--R                    90
+--R                                         Type: Union(Expression(Integer),...)
+--E 403
+
+--S 404 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                               +----+
+--R               2 9        2 8  |   2         2 10        2 9  +-+
+--R        (- 9b c x  - 10a c x )\|c x   + (9b c x   + 10a c x )\|c
+--R   (4)  ---------------------------------------------------------
+--R                                    90
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R            2 9      2 8  +-+ |   2       3 10      3 9
+--R        (b c x  + a c x )\|c \|c x   - b c x   - a c x
+--R   (5)  -----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 1008
+t0:=x^2*(c*x^2)^(5/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R            2 7      2 6  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 1008
+r0:=1/8*a*c^2*x^7*sqrt(c*x^2)+1/9*b*c^2*x^8*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 8       2 7  |   2
+--R        (8b c x  + 9a c x )\|c x
+--R   (2)  --------------------------
+--R                    72
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 9       2 8  +-+
+--R        (8b c x  + 9a c x )\|c
+--R   (3)  -----------------------
+--R                   72
+--R                                         Type: Union(Expression(Integer),...)
+--E 408
+
+--S 409 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R               2 8       2 7  |   2         2 9       2 8  +-+
+--R        (- 8b c x  - 9a c x )\|c x   + (8b c x  + 9a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  72
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R            2 8      2 7  +-+ |   2       3 9      3 8
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 410
+
+)clear all
+
+--S 411 of 1008
+t0:=x*(c*x^2)^(5/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R            2 6      2 5  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 1008
+r0:=1/7*a*c^2*x^6*sqrt(c*x^2)+1/8*b*c^2*x^7*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 7       2 6  |   2
+--R        (7b c x  + 8a c x )\|c x
+--R   (2)  --------------------------
+--R                    56
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 8       2 7  +-+
+--R        (7b c x  + 8a c x )\|c
+--R   (3)  -----------------------
+--R                   56
+--R                                         Type: Union(Expression(Integer),...)
+--E 413
+
+--S 414 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R               2 7       2 6  |   2         2 8       2 7  +-+
+--R        (- 7b c x  - 8a c x )\|c x   + (7b c x  + 8a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  56
+--R                                                    Type: Expression(Integer)
+--E 414
+
+--S 415 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R            2 7      2 6  +-+ |   2       3 8      3 7
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 415
+
+)clear all
+
+--S 416 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R            2 5      2 4  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 1008
+r0:=1/6*a*c^2*x^5*sqrt(c*x^2)+1/7*b*c^2*x^6*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 6       2 5  |   2
+--R        (6b c x  + 7a c x )\|c x
+--R   (2)  --------------------------
+--R                    42
+--R                                                    Type: Expression(Integer)
+--E 417
+
+--S 418 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 7       2 6  +-+
+--R        (6b c x  + 7a c x )\|c
+--R   (3)  -----------------------
+--R                   42
+--R                                         Type: Union(Expression(Integer),...)
+--E 418
+
+--S 419 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R               2 6       2 5  |   2         2 7       2 6  +-+
+--R        (- 6b c x  - 7a c x )\|c x   + (6b c x  + 7a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  42
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R            2 6      2 5  +-+ |   2       3 7      3 6
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)/x
+--R 
+--R
+--R                          +----+
+--R            2 4      2 3  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 1008
+r0:=1/5*a*c^2*x^4*sqrt(c*x^2)+1/6*b*c^2*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 5       2 4  |   2
+--R        (5b c x  + 6a c x )\|c x
+--R   (2)  --------------------------
+--R                    30
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 6       2 5  +-+
+--R        (5b c x  + 6a c x )\|c
+--R   (3)  -----------------------
+--R                   30
+--R                                         Type: Union(Expression(Integer),...)
+--E 423
+
+--S 424 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R               2 5       2 4  |   2         2 6       2 5  +-+
+--R        (- 5b c x  - 6a c x )\|c x   + (5b c x  + 6a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  30
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R            2 5      2 4  +-+ |   2       3 6      3 5
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 425
+
+)clear all
+
+--S 426 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)/x^2
+--R 
+--R
+--R                          +----+
+--R            2 3      2 2  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 1008
+r0:=1/4*a*c^2*x^3*sqrt(c*x^2)+1/5*b*c^2*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 4       2 3  |   2
+--R        (4b c x  + 5a c x )\|c x
+--R   (2)  --------------------------
+--R                    20
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 5       2 4  +-+
+--R        (4b c x  + 5a c x )\|c
+--R   (3)  -----------------------
+--R                   20
+--R                                         Type: Union(Expression(Integer),...)
+--E 428
+
+--S 429 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R               2 4       2 3  |   2         2 5       2 4  +-+
+--R        (- 4b c x  - 5a c x )\|c x   + (4b c x  + 5a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  20
+--R                                                    Type: Expression(Integer)
+--E 429
+
+--S 430 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R            2 4      2 3  +-+ |   2       3 5      3 4
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 430
+
+)clear all
+
+--S 431 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)/x^3
+--R 
+--R
+--R                         +----+
+--R            2 2      2   |   2
+--R   (1)  (b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1008
+r0:=1/3*a*c^2*x^2*sqrt(c*x^2)+1/4*b*c^2*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 3       2 2  |   2
+--R        (3b c x  + 4a c x )\|c x
+--R   (2)  --------------------------
+--R                    12
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 4       2 3  +-+
+--R        (3b c x  + 4a c x )\|c
+--R   (3)  -----------------------
+--R                   12
+--R                                         Type: Union(Expression(Integer),...)
+--E 433
+
+--S 434 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                              +----+
+--R               2 3       2 2  |   2         2 4       2 3  +-+
+--R        (- 3b c x  - 4a c x )\|c x   + (3b c x  + 4a c x )\|c
+--R   (4)  ------------------------------------------------------
+--R                                  12
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----+
+--R            2 3      2 2  +-+ |   2       3 4      3 3
+--R        (b c x  + a c x )\|c \|c x   - b c x  - a c x
+--R   (5)  ----------------------------------------------
+--R                             +----+
+--R                             |   2
+--R                            \|c x
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)/x^4
+--R 
+--R
+--R                       +----+
+--R            2       2  |   2
+--R   (1)  (b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 1008
+r0:=1/2*a*c^2*x*sqrt(c*x^2)+1/3*b*c^2*x^2*sqrt(c*x^2)
+--R 
+--R
+--R                           +----+
+--R             2 2       2   |   2
+--R        (2b c x  + 3a c x)\|c x
+--R   (2)  -------------------------
+--R                    6
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 3       2 2  +-+
+--R        (2b c x  + 3a c x )\|c
+--R   (3)  -----------------------
+--R                   6
+--R                                         Type: Union(Expression(Integer),...)
+--E 438
+
+--S 439 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                             +----+
+--R               2 2       2   |   2         2 3       2 2  +-+
+--R        (- 2b c x  - 3a c x)\|c x   + (2b c x  + 3a c x )\|c
+--R   (4)  -----------------------------------------------------
+--R                                  6
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                             +----+
+--R            2 2      2   +-+ |   2       3 3      3 2
+--R        (b c x  + a c x)\|c \|c x   - b c x  - a c x
+--R   (5)  ---------------------------------------------
+--R                            +----+
+--R                            |   2
+--R                           \|c x
+--R                                                    Type: Expression(Integer)
+--E 440
+
+)clear all
+
+--S 441 of 1008
+t0:=x^m*(a+b*x)/sqrt(c*x^2)
+--R 
+--R
+--R                  m
+--R        (b x + a)x
+--R   (1)  -----------
+--R           +----+
+--R           |   2
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 1008
+r0:=a*x^(1+m)/(m*sqrt(c*x^2))+b*x^(2+m)/((1+m)*sqrt(c*x^2))
+--R 
+--R
+--R             m + 2             m + 1
+--R        b m x      + (a m + a)x
+--R   (2)  ----------------------------
+--R                        +----+
+--R                 2      |   2
+--R               (m  + m)\|c x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           m log(x)
+--R        (b m x + a m + a)%e
+--R   (3)  ---------------------------
+--R                  2      +-+
+--R                (m  + m)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 443
+
+--S 444 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +----+
+--R                     |   2   m log(x)           m + 2               m + 1  +-+
+--R   (b m x + a m + a)\|c x  %e         + (- b m x      + (- a m - a)x     )\|c
+--R   ---------------------------------------------------------------------------
+--R                                            +----+
+--R                                 2      +-+ |   2
+--R                               (m  + m)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                       +----+
+--R                   +-+ |   2         2           (m + 2)log(x)
+--R        ((b x + a)\|c \|c x   - b c x  - a c x)%e
+--R   (5)  ------------------------------------------------------
+--R                                   +----+
+--R                                 3 |   2
+--R                              c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 445
+
+)clear all
+
+--S 446 of 1008
+t0:=x^3*(a+b*x)/sqrt(c*x^2)
+--R 
+--R
+--R           4      3
+--R        b x  + a x
+--R   (1)  -----------
+--R           +----+
+--R           |   2
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1008
+r0:=1/3*a*x^4/sqrt(c*x^2)+1/4*b*x^5/sqrt(c*x^2)
+--R 
+--R
+--R            5       4
+--R        3b x  + 4a x
+--R   (2)  -------------
+--R             +----+
+--R             |   2
+--R          12\|c x
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4       3
+--R        3b x  + 4a x
+--R   (3)  -------------
+--R               +-+
+--R            12\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 448
+
+--S 449 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                        +----+
+--R             4       3  |   2           5       4  +-+
+--R        (3b x  + 4a x )\|c x   + (- 3b x  - 4a x )\|c
+--R   (4)  ----------------------------------------------
+--R                                +----+
+--R                            +-+ |   2
+--R                         12\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                          +----+
+--R            3      2  +-+ |   2         4        3
+--R        (b x  + a x )\|c \|c x   - b c x  - a c x
+--R   (5)  ------------------------------------------
+--R                           +----+
+--R                           |   2
+--R                         c\|c x
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 1008
+t0:=x^2*(a+b*x)/sqrt(c*x^2)
+--R 
+--R
+--R           3      2
+--R        b x  + a x
+--R   (1)  -----------
+--R           +----+
+--R           |   2
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 1008
+r0:=1/2*a*x^3/sqrt(c*x^2)+1/3*b*x^4/sqrt(c*x^2)
+--R 
+--R
+--R            4       3
+--R        2b x  + 3a x
+--R   (2)  -------------
+--R             +----+
+--R             |   2
+--R           6\|c x
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3       2
+--R        2b x  + 3a x
+--R   (3)  -------------
+--R              +-+
+--R            6\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 453
+
+--S 454 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                        +----+
+--R             3       2  |   2           4       3  +-+
+--R        (2b x  + 3a x )\|c x   + (- 2b x  - 3a x )\|c
+--R   (4)  ----------------------------------------------
+--R                               +----+
+--R                           +-+ |   2
+--R                         6\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                         +----+
+--R            2        +-+ |   2         3        2
+--R        (b x  + a x)\|c \|c x   - b c x  - a c x
+--R   (5)  -----------------------------------------
+--R                           +----+
+--R                           |   2
+--R                         c\|c x
+--R                                                    Type: Expression(Integer)
+--E 455
+
+)clear all
+
+--S 456 of 1008
+t0:=x*(a+b*x)/sqrt(c*x^2)
+--R 
+--R
+--R           2
+--R        b x  + a x
+--R   (1)  ----------
+--R           +----+
+--R           |   2
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 1008
+r0:=a*x^2/sqrt(c*x^2)+1/2*b*x^3/sqrt(c*x^2)
+--R 
+--R
+--R           3       2
+--R        b x  + 2a x
+--R   (2)  ------------
+--R            +----+
+--R            |   2
+--R          2\|c x
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R        b x  + 2a x
+--R   (3)  -----------
+--R             +-+
+--R           2\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 458
+
+--S 459 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R            2         |   2          3       2  +-+
+--R        (b x  + 2a x)\|c x   + (- b x  - 2a x )\|c
+--R   (4)  -------------------------------------------
+--R                              +----+
+--R                          +-+ |   2
+--R                        2\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                         +----+
+--R                         |   2
+--R                       c\|c x
+--R                                                    Type: Expression(Integer)
+--E 460
+
+)clear all
+
+--S 461 of 1008
+t0:=(a+b*x)/sqrt(c*x^2)
+--R 
+--R
+--R        b x + a
+--R   (1)  -------
+--R         +----+
+--R         |   2
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 1008
+r0:=b*x^2/sqrt(c*x^2)+a*x*log(x)/sqrt(c*x^2)
+--R 
+--R
+--R                        2
+--R        a x log(x) + b x
+--R   (2)  -----------------
+--R              +----+
+--R              |   2
+--R             \|c x
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        a log(x) + b x
+--R   (3)  --------------
+--R              +-+
+--R             \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 463
+
+--S 464 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                         +----+
+--R                         |   2                       2  +-+
+--R        (a log(x) + b x)\|c x   + (- a x log(x) - b x )\|c
+--R   (4)  ---------------------------------------------------
+--R                                 +----+
+--R                             +-+ |   2
+--R                            \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                          |   2
+--R                      c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 1008
+t0:=(a+b*x)/(x*sqrt(c*x^2))
+--R 
+--R
+--R         b x + a
+--R   (1)  --------
+--R          +----+
+--R          |   2
+--R        x\|c x
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 1008
+r0:=-a/sqrt(c*x^2)+b*x*log(x)/sqrt(c*x^2)
+--R 
+--R
+--R        b x log(x) - a
+--R   (2)  --------------
+--R             +----+
+--R             |   2
+--R            \|c x
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        b x log(x) - a
+--R   (3)  --------------
+--R               +-+
+--R             x\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 468
+
+--S 469 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                         +----+
+--R                         |   2          2              +-+
+--R        (b x log(x) - a)\|c x   + (- b x log(x) + a x)\|c
+--R   (4)  --------------------------------------------------
+--R                                 +----+
+--R                             +-+ |   2
+--R                           x\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                        2 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 470
+
+)clear all
+
+--S 471 of 1008
+t0:=(a+b*x)/(x^2*sqrt(c*x^2))
+--R 
+--R
+--R         b x + a
+--R   (1)  ---------
+--R           +----+
+--R         2 |   2
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 1008
+r0:=-b/sqrt(c*x^2)-1/2*a/(x*sqrt(c*x^2))
+--R 
+--R
+--R        - 2b x - a
+--R   (2)  ----------
+--R            +----+
+--R            |   2
+--R         2x\|c x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 2b x - a
+--R   (3)  ----------
+--R            2 +-+
+--R          2x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 473
+
+--S 474 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                     +----+
+--R                     |   2         2        +-+
+--R        (- 2b x - a)\|c x   + (2b x  + a x)\|c
+--R   (4)  ---------------------------------------
+--R                             +----+
+--R                       2 +-+ |   2
+--R                     2x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 474
+
+--S 475 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                        3 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 475
+
+)clear all
+
+--S 476 of 1008
+t0:=(a+b*x)/(x^3*sqrt(c*x^2))
+--R 
+--R
+--R         b x + a
+--R   (1)  ---------
+--R           +----+
+--R         3 |   2
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 1008
+r0:=-1/3*a/(x^2*sqrt(c*x^2))-1/2*b/(x*sqrt(c*x^2))
+--R 
+--R
+--R        - 3b x - 2a
+--R   (2)  -----------
+--R             +----+
+--R           2 |   2
+--R         6x \|c x
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 3b x - 2a
+--R   (3)  -----------
+--R            3 +-+
+--R          6x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 478
+
+--S 479 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 3b x - 2a)\|c x   + (3b x  + 2a x)\|c
+--R   (4)  -----------------------------------------
+--R                              +----+
+--R                        3 +-+ |   2
+--R                      6x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                        4 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 1008
+t0:=(a+b*x)/(x^4*sqrt(c*x^2))
+--R 
+--R
+--R         b x + a
+--R   (1)  ---------
+--R           +----+
+--R         4 |   2
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 1008
+r0:=-1/4*a/(x^3*sqrt(c*x^2))-1/3*b/(x^2*sqrt(c*x^2))
+--R 
+--R
+--R        - 4b x - 3a
+--R   (2)  -----------
+--R             +----+
+--R           3 |   2
+--R        12x \|c x
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 4b x - 3a
+--R   (3)  -----------
+--R             4 +-+
+--R          12x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 483
+
+--S 484 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 4b x - 3a)\|c x   + (4b x  + 3a x)\|c
+--R   (4)  -----------------------------------------
+--R                              +----+
+--R                        4 +-+ |   2
+--R                     12x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                        5 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 485
+
+)clear all
+
+--S 486 of 1008
+t0:=x^m*(a+b*x)/(c*x^2)^(3/2)
+--R 
+--R
+--R                  m
+--R        (b x + a)x
+--R   (1)  -----------
+--R             +----+
+--R           2 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 1008
+r0:=-a*x^(-1+m)/(c*(2-m)*sqrt(c*x^2))-b*x^m/(c*(1-m)*sqrt(c*x^2))
+--R 
+--R
+--R                   m             m - 1
+--R        (b m - 2b)x  + (a m - a)x
+--R   (2)  ------------------------------
+--R                              +----+
+--R               2              |   2
+--R           (c m  - 3c m + 2c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                 m log(x)
+--R        ((b m - 2b)x + a m - a)%e
+--R   (3)  ---------------------------------
+--R                 2              2 +-+
+--R             (c m  - 3c m + 2c)x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 488
+
+--S 489 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R                               |   2   m log(x)
+--R       ((b m - 2b)x + a m - a)\|c x  %e
+--R     + 
+--R                     2 m               2 m - 1  +-+
+--R       ((- b m + 2b)x x  + (- a m + a)x x     )\|c
+--R  /
+--R                              +----+
+--R         2              2 +-+ |   2
+--R     (c m  - 3c m + 2c)x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                       +----+
+--R                   +-+ |   2         2           m log(x)
+--R        ((b x + a)\|c \|c x   - b c x  - a c x)%e
+--R   (5)  -------------------------------------------------
+--R                                +----+
+--R                            2 3 |   2
+--R                           c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 490
+
+)clear all
+
+--S 491 of 1008
+t0:=x^3*(a+b*x)/(c*x^2)^(3/2)
+--R 
+--R
+--R           2
+--R        b x  + a x
+--R   (1)  ----------
+--R           +----+
+--R           |   2
+--R         c\|c x
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 1008
+r0:=a*x^2/(c*sqrt(c*x^2))+1/2*b*x^3/(c*sqrt(c*x^2))
+--R 
+--R
+--R           3       2
+--R        b x  + 2a x
+--R   (2)  ------------
+--R             +----+
+--R             |   2
+--R          2c\|c x
+--R                                                    Type: Expression(Integer)
+--E 492
+
+--S 493 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R        b x  + 2a x
+--R   (3)  -----------
+--R              +-+
+--R           2c\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 493
+
+--S 494 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R            2         |   2          3       2  +-+
+--R        (b x  + 2a x)\|c x   + (- b x  - 2a x )\|c
+--R   (4)  -------------------------------------------
+--R                              +----+
+--R                          +-+ |   2
+--R                       2c\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                         +----+
+--R                       2 |   2
+--R                      c \|c x
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 1008
+t0:=x^2*(a+b*x)/(c*x^2)^(3/2)
+--R 
+--R
+--R         b x + a
+--R   (1)  --------
+--R          +----+
+--R          |   2
+--R        c\|c x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 1008
+r0:=b*x^2/(c*sqrt(c*x^2))+a*x*log(x)/(c*sqrt(c*x^2))
+--R 
+--R
+--R                        2
+--R        a x log(x) + b x
+--R   (2)  -----------------
+--R               +----+
+--R               |   2
+--R             c\|c x
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        a log(x) + b x
+--R   (3)  --------------
+--R               +-+
+--R             c\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 498
+
+--S 499 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                         +----+
+--R                         |   2                       2  +-+
+--R        (a log(x) + b x)\|c x   + (- a x log(x) - b x )\|c
+--R   (4)  ---------------------------------------------------
+--R                                  +----+
+--R                              +-+ |   2
+--R                            c\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                       2  |   2
+--R                      c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 500
+
+)clear all
+
+--S 501 of 1008
+t0:=x*(a+b*x)/(c*x^2)^(3/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  ----------
+--R            +----+
+--R            |   2
+--R        c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 1008
+r0:=-a/(c*sqrt(c*x^2))+b*x*log(x)/(c*sqrt(c*x^2))
+--R 
+--R
+--R        b x log(x) - a
+--R   (2)  --------------
+--R             +----+
+--R             |   2
+--R           c\|c x
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        b x log(x) - a
+--R   (3)  --------------
+--R                +-+
+--R            c x\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 503
+
+--S 504 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                         +----+
+--R                         |   2          2              +-+
+--R        (b x log(x) - a)\|c x   + (- b x log(x) + a x)\|c
+--R   (4)  --------------------------------------------------
+--R                                  +----+
+--R                              +-+ |   2
+--R                          c x\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 504
+
+--S 505 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      2 2 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 505
+
+)clear all
+
+--S 506 of 1008
+t0:=(a+b*x)/(c*x^2)^(3/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R           2 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 1008
+r0:=-b/(c*sqrt(c*x^2))-1/2*a/(c*x*sqrt(c*x^2))
+--R 
+--R
+--R         - 2b x - a
+--R   (2)  -----------
+--R             +----+
+--R             |   2
+--R        2c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 2b x - a
+--R   (3)  ----------
+--R             2 +-+
+--R         2c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 508
+
+--S 509 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                     +----+
+--R                     |   2         2        +-+
+--R        (- 2b x - a)\|c x   + (2b x  + a x)\|c
+--R   (4)  ---------------------------------------
+--R                              +----+
+--R                        2 +-+ |   2
+--R                    2c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      2 3 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 1008
+t0:=(a+b*x)/(x*(c*x^2)^(3/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R           3 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 1008
+r0:=-1/3*a/(c*x^2*sqrt(c*x^2))-1/2*b/(c*x*sqrt(c*x^2))
+--R 
+--R
+--R         - 3b x - 2a
+--R   (2)  ------------
+--R              +----+
+--R            2 |   2
+--R        6c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 3b x - 2a
+--R   (3)  -----------
+--R             3 +-+
+--R         6c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 513
+
+--S 514 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 3b x - 2a)\|c x   + (3b x  + 2a x)\|c
+--R   (4)  -----------------------------------------
+--R                               +----+
+--R                         3 +-+ |   2
+--R                     6c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      2 4 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 515
+
+)clear all
+
+--S 516 of 1008
+t0:=(a+b*x)/(x^2*(c*x^2)^(3/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R           4 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 1008
+r0:=-1/4*a/(c*x^3*sqrt(c*x^2))-1/3*b/(c*x^2*sqrt(c*x^2))
+--R 
+--R
+--R         - 4b x - 3a
+--R   (2)  -------------
+--R               +----+
+--R             3 |   2
+--R        12c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 4b x - 3a
+--R   (3)  -----------
+--R              4 +-+
+--R         12c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 518
+
+--S 519 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 4b x - 3a)\|c x   + (4b x  + 3a x)\|c
+--R   (4)  -----------------------------------------
+--R                               +----+
+--R                         4 +-+ |   2
+--R                    12c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      2 5 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 520
+
+)clear all
+
+--S 521 of 1008
+t0:=(a+b*x)/(x^3*(c*x^2)^(3/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R           5 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 1008
+r0:=-1/5*a/(c*x^4*sqrt(c*x^2))-1/4*b/(c*x^3*sqrt(c*x^2))
+--R 
+--R
+--R         - 5b x - 4a
+--R   (2)  -------------
+--R               +----+
+--R             4 |   2
+--R        20c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 5b x - 4a
+--R   (3)  -----------
+--R              5 +-+
+--R         20c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 523
+
+--S 524 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 5b x - 4a)\|c x   + (5b x  + 4a x)\|c
+--R   (4)  -----------------------------------------
+--R                               +----+
+--R                         5 +-+ |   2
+--R                    20c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      2 6 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 1008
+t0:=(a+b*x)/(x^4*(c*x^2)^(3/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R           6 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 1008
+r0:=-1/6*a/(c*x^5*sqrt(c*x^2))-1/5*b/(c*x^4*sqrt(c*x^2))
+--R 
+--R
+--R         - 6b x - 5a
+--R   (2)  -------------
+--R               +----+
+--R             5 |   2
+--R        30c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 6b x - 5a
+--R   (3)  -----------
+--R              6 +-+
+--R         30c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 528
+
+--S 529 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 6b x - 5a)\|c x   + (6b x  + 5a x)\|c
+--R   (4)  -----------------------------------------
+--R                               +----+
+--R                         6 +-+ |   2
+--R                    30c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      2 7 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 530
+
+)clear all
+
+--S 531 of 1008
+t0:=x^m*(a+b*x)/(c*x^2)^(5/2)
+--R 
+--R
+--R                  m
+--R        (b x + a)x
+--R   (1)  -----------
+--R             +----+
+--R         2 4 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 1008
+r0:=-a*x^(-3+m)/(c^2*(4-m)*sqrt(c*x^2))-b*x^(-2+m)/(c^2*(3-m)*sqrt(c*x^2))
+--R 
+--R
+--R                   m - 2              m - 3
+--R        (b m - 4b)x      + (a m - 3a)x
+--R   (2)  -----------------------------------
+--R                                 +----+
+--R              2 2     2       2  |   2
+--R            (c m  - 7c m + 12c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                  m log(x)
+--R        ((b m - 4b)x + a m - 3a)%e
+--R   (3)  ----------------------------------
+--R              2 2     2       2  4 +-+
+--R            (c m  - 7c m + 12c )x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 533
+
+--S 534 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +----+
+--R                                |   2   m log(x)
+--R       ((b m - 4b)x + a m - 3a)\|c x  %e
+--R     + 
+--R                     4 m - 2                4 m - 3  +-+
+--R       ((- b m + 4b)x x      + (- a m + 3a)x x     )\|c
+--R  /
+--R                                +----+
+--R       2 2     2       2  4 +-+ |   2
+--R     (c m  - 7c m + 12c )x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                       +----+
+--R                   +-+ |   2         2           m log(x)
+--R        ((b x + a)\|c \|c x   - b c x  - a c x)%e
+--R   (5)  -------------------------------------------------
+--R                                +----+
+--R                            3 5 |   2
+--R                           c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 535
+
+)clear all
+
+--S 536 of 1008
+t0:=x^3*(a+b*x)/(c*x^2)^(5/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  ----------
+--R            +----+
+--R         2  |   2
+--R        c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1008
+r0:=-a/(c^2*sqrt(c*x^2))+b*x*log(x)/(c^2*sqrt(c*x^2))
+--R 
+--R
+--R        b x log(x) - a
+--R   (2)  --------------
+--R              +----+
+--R            2 |   2
+--R           c \|c x
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        b x log(x) - a
+--R   (3)  --------------
+--R             2  +-+
+--R            c x\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 538
+
+--S 539 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                         +----+
+--R                         |   2          2              +-+
+--R        (b x log(x) - a)\|c x   + (- b x log(x) + a x)\|c
+--R   (4)  --------------------------------------------------
+--R                                  +----+
+--R                           2  +-+ |   2
+--R                          c x\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      3 2 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 1008
+t0:=x^2*(a+b*x)/(c*x^2)^(5/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 2 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 1008
+r0:=-b/(c^2*sqrt(c*x^2))-1/2*a/(c^2*x*sqrt(c*x^2))
+--R 
+--R
+--R         - 2b x - a
+--R   (2)  -----------
+--R             +----+
+--R          2  |   2
+--R        2c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 2b x - a
+--R   (3)  ----------
+--R           2 2 +-+
+--R         2c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 543
+
+--S 544 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                     +----+
+--R                     |   2         2        +-+
+--R        (- 2b x - a)\|c x   + (2b x  + a x)\|c
+--R   (4)  ---------------------------------------
+--R                              +----+
+--R                      2 2 +-+ |   2
+--R                    2c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      3 3 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 545
+
+)clear all
+
+--S 546 of 1008
+t0:=x*(a+b*x)/(c*x^2)^(5/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 3 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 1008
+r0:=-1/3*a/(c^2*x^2*sqrt(c*x^2))-1/2*b/(c^2*x*sqrt(c*x^2))
+--R 
+--R
+--R         - 3b x - 2a
+--R   (2)  ------------
+--R              +----+
+--R          2 2 |   2
+--R        6c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 3b x - 2a
+--R   (3)  -----------
+--R           2 3 +-+
+--R         6c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 548
+
+--S 549 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 3b x - 2a)\|c x   + (3b x  + 2a x)\|c
+--R   (4)  -----------------------------------------
+--R                               +----+
+--R                       2 3 +-+ |   2
+--R                     6c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      3 4 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 550
+
+)clear all
+
+--S 551 of 1008
+t0:=(a+b*x)/(c*x^2)^(5/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 4 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 1008
+r0:=-1/4*a/(c^2*x^3*sqrt(c*x^2))-1/3*b/(c^2*x^2*sqrt(c*x^2))
+--R 
+--R
+--R         - 4b x - 3a
+--R   (2)  -------------
+--R               +----+
+--R           2 3 |   2
+--R        12c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 4b x - 3a
+--R   (3)  -----------
+--R            2 4 +-+
+--R         12c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 553
+
+--S 554 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 4b x - 3a)\|c x   + (4b x  + 3a x)\|c
+--R   (4)  -----------------------------------------
+--R                               +----+
+--R                       2 4 +-+ |   2
+--R                    12c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      3 5 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 1008
+t0:=(a+b*x)/(x*(c*x^2)^(5/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 5 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 1008
+r0:=-1/5*a/(c^2*x^4*sqrt(c*x^2))-1/4*b/(c^2*x^3*sqrt(c*x^2))
+--R 
+--R
+--R         - 5b x - 4a
+--R   (2)  -------------
+--R               +----+
+--R           2 4 |   2
+--R        20c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 5b x - 4a
+--R   (3)  -----------
+--R            2 5 +-+
+--R         20c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 558
+
+--S 559 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 5b x - 4a)\|c x   + (5b x  + 4a x)\|c
+--R   (4)  -----------------------------------------
+--R                               +----+
+--R                       2 5 +-+ |   2
+--R                    20c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      3 6 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 560
+
+)clear all
+
+--S 561 of 1008
+t0:=(a+b*x)/(x^2*(c*x^2)^(5/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 6 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 1008
+r0:=-1/6*a/(c^2*x^5*sqrt(c*x^2))-1/5*b/(c^2*x^4*sqrt(c*x^2))
+--R 
+--R
+--R         - 6b x - 5a
+--R   (2)  -------------
+--R               +----+
+--R           2 5 |   2
+--R        30c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 6b x - 5a
+--R   (3)  -----------
+--R            2 6 +-+
+--R         30c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 563
+
+--S 564 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 6b x - 5a)\|c x   + (6b x  + 5a x)\|c
+--R   (4)  -----------------------------------------
+--R                               +----+
+--R                       2 6 +-+ |   2
+--R                    30c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 564
+
+--S 565 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      3 7 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 565
+
+)clear all
+
+--S 566 of 1008
+t0:=(a+b*x)/(x^3*(c*x^2)^(5/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 7 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1008
+r0:=-1/7*a/(c^2*x^6*sqrt(c*x^2))-1/6*b/(c^2*x^5*sqrt(c*x^2))
+--R 
+--R
+--R         - 7b x - 6a
+--R   (2)  -------------
+--R               +----+
+--R           2 6 |   2
+--R        42c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 7b x - 6a
+--R   (3)  -----------
+--R            2 7 +-+
+--R         42c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 568
+
+--S 569 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 7b x - 6a)\|c x   + (7b x  + 6a x)\|c
+--R   (4)  -----------------------------------------
+--R                               +----+
+--R                       2 7 +-+ |   2
+--R                    42c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      3 8 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 1008
+t0:=(a+b*x)/(x^4*(c*x^2)^(5/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 8 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 1008
+r0:=-1/8*a/(c^2*x^7*sqrt(c*x^2))-1/7*b/(c^2*x^6*sqrt(c*x^2))
+--R 
+--R
+--R         - 8b x - 7a
+--R   (2)  -------------
+--R               +----+
+--R           2 7 |   2
+--R        56c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 8b x - 7a
+--R   (3)  -----------
+--R            2 8 +-+
+--R         56c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 573
+
+--S 574 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                      +----+
+--R                      |   2         2         +-+
+--R        (- 8b x - 7a)\|c x   + (8b x  + 7a x)\|c
+--R   (4)  -----------------------------------------
+--R                               +----+
+--R                       2 8 +-+ |   2
+--R                    56c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2         2
+--R        (b x + a)\|c \|c x   - b c x  - a c x
+--R   (5)  -------------------------------------
+--R                          +----+
+--R                      3 9 |   2
+--R                     c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 575
+
+)clear all
+
+--S 576 of 1008
+t0:=x^m*(a+b*x)^2*sqrt(c*x^2)
+--R 
+--R
+--R                               +----+
+--R          2 2             2  m |   2
+--R   (1)  (b x  + 2a b x + a )x \|c x
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 1008
+r0:=a^2*x^(1+m)*sqrt(c*x^2)/(2+m)+2*a*b*x^(2+m)*sqrt(c*x^2)/(3+m)+_
+   b^2*x^(3+m)*sqrt(c*x^2)/(4+m)
+--R 
+--R
+--R   (2)
+--R           2 2     2      2  m + 3          2                    m + 2
+--R         (b m  + 5b m + 6b )x      + (2a b m  + 12a b m + 16a b)x
+--R       + 
+--R           2 2     2       2  m + 1
+--R         (a m  + 7a m + 12a )x
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R      3     2
+--R     m  + 9m  + 26m + 24
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 2     2      2  4          2                    3
+--R         (b m  + 5b m + 6b )x  + (2a b m  + 12a b m + 16a b)x
+--R       + 
+--R           2 2     2       2  2
+--R         (a m  + 7a m + 12a )x
+--R    *
+--R        +-+  m log(x)
+--R       \|c %e
+--R  /
+--R      3     2
+--R     m  + 9m  + 26m + 24
+--R                                         Type: Union(Expression(Integer),...)
+--E 578
+
+--S 579 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2 2     2      2  4          2                    3
+--R           (b m  + 5b m + 6b )x  + (2a b m  + 12a b m + 16a b)x
+--R         + 
+--R             2 2     2       2  2
+--R           (a m  + 7a m + 12a )x
+--R      *
+--R          +-+  m log(x)
+--R         \|c %e
+--R     + 
+--R               2 2     2      2  m + 3            2                    m + 2
+--R           (- b m  - 5b m - 6b )x      + (- 2a b m  - 12a b m - 16a b)x
+--R         + 
+--R               2 2     2       2  m + 1
+--R           (- a m  - 7a m - 12a )x
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R      3     2
+--R     m  + 9m  + 26m + 24
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                             +----+
+--R      2 2             2  +-+ |   2     2   3           2    2      (m + 3)log(x)
+--R   ((b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x)%e
+--R   -----------------------------------------------------------------------------
+--R                                        +----+
+--R                                      2 |   2
+--R                                     x \|c x
+--R                                                    Type: Expression(Integer)
+--E 580
+
+)clear all
+
+--S 581 of 1008
+t0:=x^3*(a+b*x)^2*sqrt(c*x^2)
+--R 
+--R
+--R                                +----+
+--R          2 5         4    2 3  |   2
+--R   (1)  (b x  + 2a b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1008
+r0:=1/5*a^2*x^4*sqrt(c*x^2)+1/3*a*b*x^5*sqrt(c*x^2)+1/7*b^2*x^6*sqrt(c*x^2)
+--R 
+--R
+--R                                     +----+
+--R            2 6          5      2 4  |   2
+--R        (15b x  + 35a b x  + 21a x )\|c x
+--R   (2)  -----------------------------------
+--R                        105
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 7          6      2 5  +-+
+--R        (15b x  + 35a b x  + 21a x )\|c
+--R   (3)  --------------------------------
+--R                       105
+--R                                         Type: Union(Expression(Integer),...)
+--E 583
+
+--S 584 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  +----+
+--R         2 6          5      2 4  |   2        2 7          6      2 5  +-+
+--R   (- 15b x  - 35a b x  - 21a x )\|c x   + (15b x  + 35a b x  + 21a x )\|c
+--R   ------------------------------------------------------------------------
+--R                                      105
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                    +----+
+--R          2 6         5    2 4  +-+ |   2     2   7           6    2   5
+--R        (b x  + 2a b x  + a x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------
+--R                                      +----+
+--R                                      |   2
+--R                                     \|c x
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 1008
+t0:=x^2*(a+b*x)^2*sqrt(c*x^2)
+--R 
+--R
+--R                                +----+
+--R          2 4         3    2 2  |   2
+--R   (1)  (b x  + 2a b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 1008
+r0:=1/4*a^2*x^3*sqrt(c*x^2)+2/5*a*b*x^4*sqrt(c*x^2)+1/6*b^2*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                                     +----+
+--R            2 5          4      2 3  |   2
+--R        (10b x  + 24a b x  + 15a x )\|c x
+--R   (2)  -----------------------------------
+--R                         60
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 6          5      2 4  +-+
+--R        (10b x  + 24a b x  + 15a x )\|c
+--R   (3)  --------------------------------
+--R                       60
+--R                                         Type: Union(Expression(Integer),...)
+--E 588
+
+--S 589 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  +----+
+--R         2 5          4      2 3  |   2        2 6          5      2 4  +-+
+--R   (- 10b x  - 24a b x  - 15a x )\|c x   + (10b x  + 24a b x  + 15a x )\|c
+--R   ------------------------------------------------------------------------
+--R                                      60
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                    +----+
+--R          2 5         4    2 3  +-+ |   2     2   6           5    2   4
+--R        (b x  + 2a b x  + a x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------
+--R                                      +----+
+--R                                      |   2
+--R                                     \|c x
+--R                                                    Type: Expression(Integer)
+--E 590
+
+)clear all
+
+--S 591 of 1008
+t0:=x*(a+b*x)^2*sqrt(c*x^2)
+--R 
+--R
+--R                               +----+
+--R          2 3         2    2   |   2
+--R   (1)  (b x  + 2a b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 1008
+r0:=1/3*a^2*x^2*sqrt(c*x^2)+1/2*a*b*x^3*sqrt(c*x^2)+1/5*b^2*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                                    +----+
+--R           2 4          3      2 2  |   2
+--R        (6b x  + 15a b x  + 10a x )\|c x
+--R   (2)  ----------------------------------
+--R                        30
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 5          4      2 3  +-+
+--R        (6b x  + 15a b x  + 10a x )\|c
+--R   (3)  -------------------------------
+--R                       30
+--R                                         Type: Union(Expression(Integer),...)
+--E 593
+
+--S 594 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                      +----+
+--R             2 4          3      2 2  |   2       2 5          4      2 3  +-+
+--R        (- 6b x  - 15a b x  - 10a x )\|c x   + (6b x  + 15a b x  + 10a x )\|c
+--R   (4)  ----------------------------------------------------------------------
+--R                                          30
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                    +----+
+--R          2 4         3    2 2  +-+ |   2     2   5           4    2   3
+--R        (b x  + 2a b x  + a x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------
+--R                                      +----+
+--R                                      |   2
+--R                                     \|c x
+--R                                                    Type: Expression(Integer)
+--E 595
+
+)clear all
+
+--S 596 of 1008
+t0:=(a+b*x)^2*sqrt(c*x^2)
+--R 
+--R
+--R                             +----+
+--R          2 2             2  |   2
+--R   (1)  (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1008
+r0:=1/2*a^2*x*sqrt(c*x^2)+2/3*a*b*x^2*sqrt(c*x^2)+1/4*b^2*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                                 +----+
+--R           2 3         2     2   |   2
+--R        (3b x  + 8a b x  + 6a x)\|c x
+--R   (2)  -------------------------------
+--R                       12
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 4         3     2 2  +-+
+--R        (3b x  + 8a b x  + 6a x )\|c
+--R   (3)  -----------------------------
+--R                      12
+--R                                         Type: Union(Expression(Integer),...)
+--E 598
+
+--S 599 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                   +----+
+--R             2 3         2     2   |   2       2 4         3     2 2  +-+
+--R        (- 3b x  - 8a b x  - 6a x)\|c x   + (3b x  + 8a b x  + 6a x )\|c
+--R   (4)  -----------------------------------------------------------------
+--R                                        12
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                   +----+
+--R          2 3         2    2   +-+ |   2     2   4           3    2   2
+--R        (b x  + 2a b x  + a x)\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ---------------------------------------------------------------
+--R                                     +----+
+--R                                     |   2
+--R                                    \|c x
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)clear all
+
+--S 601 of 1008
+t0:=(a+b*x)^2*sqrt(c*x^2)/x
+--R 
+--R
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R   (1)  ---------------------------
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 1008
+r0:=1/3*(a+b*x)^3*sqrt(c*x^2)/(b*x)
+--R 
+--R
+--R                                       +----+
+--R          3 3       2 2     2       3  |   2
+--R        (b x  + 3a b x  + 3a b x + a )\|c x
+--R   (2)  -------------------------------------
+--R                         3b x
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 3         2     2   +-+
+--R        (b x  + 3a b x  + 3a x)\|c
+--R   (3)  ---------------------------
+--R                     3
+--R                                         Type: Union(Expression(Integer),...)
+--E 603
+
+--S 604 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    +----+
+--R       3 3       2 2     2       3  |   2      3 4       2 3     2   2  +-+
+--R   (- b x  - 3a b x  - 3a b x - a )\|c x   + (b x  + 3a b x  + 3a b x )\|c
+--R   ------------------------------------------------------------------------
+--R                                     3b x
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                    +----+
+--R                                    |   2
+--R                                   \|c x
+--R                                                    Type: Expression(Integer)
+--E 605
+
+)clear all
+
+--S 606 of 1008
+t0:=(a+b*x)^2*sqrt(c*x^2)/x^2
+--R 
+--R
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R   (1)  ---------------------------
+--R                      2
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 1008
+r0:=2*a*b*sqrt(c*x^2)+1/2*b^2*x*sqrt(c*x^2)+a^2*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                                    +----+
+--R           2          2 2           |   2
+--R        (2a log(x) + b x  + 4a b x)\|c x
+--R   (2)  ----------------------------------
+--R                        2x
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2          2 2           +-+
+--R        (2a log(x) + b x  + 4a b x)\|c
+--R   (3)  -------------------------------
+--R                       2
+--R                                         Type: Union(Expression(Integer),...)
+--E 608
+
+--S 609 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +----+
+--R        2          2 2           |   2       2            2 3         2  +-+
+--R   (- 2a log(x) - b x  - 4a b x)\|c x   + (2a x log(x) + b x  + 4a b x )\|c
+--R   -------------------------------------------------------------------------
+--R                                       2x
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                    +----+
+--R                                    |   2
+--R                                  x\|c x
+--R                                                    Type: Expression(Integer)
+--E 610
+
+)clear all
+
+--S 611 of 1008
+t0:=(a+b*x)^2*sqrt(c*x^2)/x^3
+--R 
+--R
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R   (1)  ---------------------------
+--R                      3
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 1008
+r0:=b^2*sqrt(c*x^2)-a^2*sqrt(c*x^2)/x^2+2*a*b*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                                    +----+
+--R                          2 2    2  |   2
+--R        (2a b x log(x) + b x  - a )\|c x
+--R   (2)  ----------------------------------
+--R                         2
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 612
+
+--S 613 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          2 2    2  +-+
+--R        (2a b x log(x) + b x  - a )\|c
+--R   (3)  -------------------------------
+--R                       x
+--R                                         Type: Union(Expression(Integer),...)
+--E 613
+
+--S 614 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +----+
+--R                       2 2    2  |   2           2          2 3    2   +-+
+--R   (- 2a b x log(x) - b x  + a )\|c x   + (2a b x log(x) + b x  - a x)\|c
+--R   -----------------------------------------------------------------------
+--R                                       2
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 614
+
+--S 615 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                     +----+
+--R                                   2 |   2
+--R                                  x \|c x
+--R                                                    Type: Expression(Integer)
+--E 615
+
+)clear all
+
+--S 616 of 1008
+t0:=(a+b*x)^2*sqrt(c*x^2)/x^4
+--R 
+--R
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R   (1)  ---------------------------
+--R                      4
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 1008
+r0:=-1/2*a^2*sqrt(c*x^2)/x^3-2*a*b*sqrt(c*x^2)/x^2+b^2*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                                    +----+
+--R           2 2                   2  |   2
+--R        (2b x log(x) - 4a b x - a )\|c x
+--R   (2)  ----------------------------------
+--R                          3
+--R                        2x
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2                   2  +-+
+--R        (2b x log(x) - 4a b x - a )\|c
+--R   (3)  -------------------------------
+--R                        2
+--R                      2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 618
+
+--S 619 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +----+
+--R        2 2                   2  |   2       2 3               2    2   +-+
+--R   (- 2b x log(x) + 4a b x + a )\|c x   + (2b x log(x) - 4a b x  - a x)\|c
+--R   ------------------------------------------------------------------------
+--R                                        3
+--R                                      2x
+--R                                                    Type: Expression(Integer)
+--E 619
+
+--S 620 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                     +----+
+--R                                   3 |   2
+--R                                  x \|c x
+--R                                                    Type: Expression(Integer)
+--E 620
+
+)clear all
+
+--S 621 of 1008
+t0:=x^m*(c*x^2)^(3/2)*(a+b*x)^2
+--R 
+--R
+--R                                        +----+
+--R          2   4           3    2   2  m |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )x \|c x
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 1008
+r0:=a^2*c*x^(3+m)*sqrt(c*x^2)/(4+m)+2*a*b*c*x^(4+m)*sqrt(c*x^2)/(5+m)+_
+   b^2*c*x^(5+m)*sqrt(c*x^2)/(6+m)
+--R 
+--R
+--R   (2)
+--R           2   2     2         2   m + 5
+--R         (b c m  + 9b c m + 20b c)x
+--R       + 
+--R                  2                        m + 4
+--R         (2a b c m  + 20a b c m + 48a b c)x
+--R       + 
+--R           2   2      2         2   m + 3
+--R         (a c m  + 11a c m + 30a c)x
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R      3      2
+--R     m  + 15m  + 74m + 120
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2   2     2         2   6            2                        5
+--R         (b c m  + 9b c m + 20b c)x  + (2a b c m  + 20a b c m + 48a b c)x
+--R       + 
+--R           2   2      2         2   4
+--R         (a c m  + 11a c m + 30a c)x
+--R    *
+--R        +-+  m log(x)
+--R       \|c %e
+--R  /
+--R      3      2
+--R     m  + 15m  + 74m + 120
+--R                                         Type: Union(Expression(Integer),...)
+--E 623
+
+--S 624 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2   2     2         2   6            2                        5
+--R           (b c m  + 9b c m + 20b c)x  + (2a b c m  + 20a b c m + 48a b c)x
+--R         + 
+--R             2   2      2         2   4
+--R           (a c m  + 11a c m + 30a c)x
+--R      *
+--R          +-+  m log(x)
+--R         \|c %e
+--R     + 
+--R               2   2     2         2   m + 5
+--R           (- b c m  - 9b c m - 20b c)x
+--R         + 
+--R                      2                        m + 4
+--R           (- 2a b c m  - 20a b c m - 48a b c)x
+--R         + 
+--R               2   2      2         2   m + 3
+--R           (- a c m  - 11a c m - 30a c)x
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R      3      2
+--R     m  + 15m  + 74m + 120
+--R                                                    Type: Expression(Integer)
+--E 624
+
+--S 625 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                      +----+
+--R          2   2               2   +-+ |   2     2 2 3         2 2    2 2
+--R       ((b c x  + 2a b c x + a c)\|c \|c x   - b c x  - 2a b c x  - a c x)
+--R    *
+--R         (m + 5)log(x)
+--R       %e
+--R  /
+--R        +----+
+--R      2 |   2
+--R     x \|c x
+--R                                                    Type: Expression(Integer)
+--E 625
+
+)clear all
+
+--S 626 of 1008
+t0:=x^3*(c*x^2)^(3/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2   7           6    2   5  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 1008
+r0:=1/7*a^2*c*x^6*sqrt(c*x^2)+1/4*a*b*c*x^7*sqrt(c*x^2)+_
+   1/9*b^2*c*x^8*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2   8            7      2   6  |   2
+--R        (28b c x  + 63a b c x  + 36a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           252
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2   9            8      2   7  +-+
+--R        (28b c x  + 63a b c x  + 36a c x )\|c
+--R   (3)  --------------------------------------
+--R                          252
+--R                                         Type: Union(Expression(Integer),...)
+--E 628
+
+--S 629 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +----+
+--R             2   8            7      2   6  |   2
+--R       (- 28b c x  - 63a b c x  - 36a c x )\|c x
+--R     + 
+--R           2   9            8      2   7  +-+
+--R       (28b c x  + 63a b c x  + 36a c x )\|c
+--R  /
+--R     252
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                          +----+
+--R          2   8           7    2   6  +-+ |   2     2 2 9         2 8    2 2 7
+--R        (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------------
+--R                                         +----+
+--R                                         |   2
+--R                                        \|c x
+--R                                                    Type: Expression(Integer)
+--E 630
+
+)clear all
+
+--S 631 of 1008
+t0:=x^2*(c*x^2)^(3/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2   6           5    2   4  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 1008
+r0:=1/6*a^2*c*x^5*sqrt(c*x^2)+2/7*a*b*c*x^6*sqrt(c*x^2)+_
+   1/8*b^2*c*x^7*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2   7            6      2   5  |   2
+--R        (21b c x  + 48a b c x  + 28a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           168
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2   8            7      2   6  +-+
+--R        (21b c x  + 48a b c x  + 28a c x )\|c
+--R   (3)  --------------------------------------
+--R                          168
+--R                                         Type: Union(Expression(Integer),...)
+--E 633
+
+--S 634 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +----+
+--R             2   7            6      2   5  |   2
+--R       (- 21b c x  - 48a b c x  - 28a c x )\|c x
+--R     + 
+--R           2   8            7      2   6  +-+
+--R       (21b c x  + 48a b c x  + 28a c x )\|c
+--R  /
+--R     168
+--R                                                    Type: Expression(Integer)
+--E 634
+
+--S 635 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                          +----+
+--R          2   7           6    2   5  +-+ |   2     2 2 8         2 7    2 2 6
+--R        (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------------
+--R                                         +----+
+--R                                         |   2
+--R                                        \|c x
+--R                                                    Type: Expression(Integer)
+--E 635
+
+)clear all
+
+--S 636 of 1008
+t0:=x*(c*x^2)^(3/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2   5           4    2   3  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 1008
+r0:=1/5*a^2*c*x^4*sqrt(c*x^2)+1/3*a*b*c*x^5*sqrt(c*x^2)+_
+   1/7*b^2*c*x^6*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2   6            5      2   4  |   2
+--R        (15b c x  + 35a b c x  + 21a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           105
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2   7            6      2   5  +-+
+--R        (15b c x  + 35a b c x  + 21a c x )\|c
+--R   (3)  --------------------------------------
+--R                          105
+--R                                         Type: Union(Expression(Integer),...)
+--E 638
+
+--S 639 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +----+
+--R             2   6            5      2   4  |   2
+--R       (- 15b c x  - 35a b c x  - 21a c x )\|c x
+--R     + 
+--R           2   7            6      2   5  +-+
+--R       (15b c x  + 35a b c x  + 21a c x )\|c
+--R  /
+--R     105
+--R                                                    Type: Expression(Integer)
+--E 639
+
+--S 640 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                          +----+
+--R          2   6           5    2   4  +-+ |   2     2 2 7         2 6    2 2 5
+--R        (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------------
+--R                                         +----+
+--R                                         |   2
+--R                                        \|c x
+--R                                                    Type: Expression(Integer)
+--E 640
+
+)clear all
+
+--S 641 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2   4           3    2   2  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 1008
+r0:=1/4*a^2*c*x^3*sqrt(c*x^2)+2/5*a*b*c*x^4*sqrt(c*x^2)+_
+   1/6*b^2*c*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2   5            4      2   3  |   2
+--R        (10b c x  + 24a b c x  + 15a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                            60
+--R                                                    Type: Expression(Integer)
+--E 642
+
+--S 643 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2   6            5      2   4  +-+
+--R        (10b c x  + 24a b c x  + 15a c x )\|c
+--R   (3)  --------------------------------------
+--R                          60
+--R                                         Type: Union(Expression(Integer),...)
+--E 643
+
+--S 644 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +----+
+--R             2   5            4      2   3  |   2
+--R       (- 10b c x  - 24a b c x  - 15a c x )\|c x
+--R     + 
+--R           2   6            5      2   4  +-+
+--R       (10b c x  + 24a b c x  + 15a c x )\|c
+--R  /
+--R     60
+--R                                                    Type: Expression(Integer)
+--E 644
+
+--S 645 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                          +----+
+--R          2   5           4    2   3  +-+ |   2     2 2 6         2 5    2 2 4
+--R        (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------------
+--R                                         +----+
+--R                                         |   2
+--R                                        \|c x
+--R                                                    Type: Expression(Integer)
+--E 645
+
+)clear all
+
+--S 646 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^2/x
+--R 
+--R
+--R                                     +----+
+--R          2   3           2    2     |   2
+--R   (1)  (b c x  + 2a b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 1008
+r0:=1/3*a^2*c*x^2*sqrt(c*x^2)+1/2*a*b*c*x^3*sqrt(c*x^2)+_
+   1/5*b^2*c*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                                          +----+
+--R           2   4            3      2   2  |   2
+--R        (6b c x  + 15a b c x  + 10a c x )\|c x
+--R   (2)  ----------------------------------------
+--R                           30
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2   5            4      2   3  +-+
+--R        (6b c x  + 15a b c x  + 10a c x )\|c
+--R   (3)  -------------------------------------
+--R                          30
+--R                                         Type: Union(Expression(Integer),...)
+--E 648
+
+--S 649 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +----+
+--R            2   4            3      2   2  |   2
+--R       (- 6b c x  - 15a b c x  - 10a c x )\|c x
+--R     + 
+--R          2   5            4      2   3  +-+
+--R       (6b c x  + 15a b c x  + 10a c x )\|c
+--R  /
+--R     30
+--R                                                    Type: Expression(Integer)
+--E 649
+
+--S 650 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                          +----+
+--R          2   4           3    2   2  +-+ |   2     2 2 5         2 4    2 2 3
+--R        (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------------
+--R                                         +----+
+--R                                         |   2
+--R                                        \|c x
+--R                                                    Type: Expression(Integer)
+--E 650
+
+)clear all
+
+--S 651 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^2/x^2
+--R 
+--R
+--R                                  +----+
+--R          2   2               2   |   2
+--R   (1)  (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 1008
+r0:=1/2*a^2*c*x*sqrt(c*x^2)+2/3*a*b*c*x^2*sqrt(c*x^2)+_
+   1/4*b^2*c*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                                       +----+
+--R           2   3           2     2     |   2
+--R        (3b c x  + 8a b c x  + 6a c x)\|c x
+--R   (2)  -------------------------------------
+--R                          12
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2   4           3     2   2  +-+
+--R        (3b c x  + 8a b c x  + 6a c x )\|c
+--R   (3)  -----------------------------------
+--R                         12
+--R                                         Type: Union(Expression(Integer),...)
+--E 653
+
+--S 654 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    +----+
+--R        2   3           2     2     |   2       2   4           3     2   2  +-+
+--R   (- 3b c x  - 8a b c x  - 6a c x)\|c x   + (3b c x  + 8a b c x  + 6a c x )\|c
+--R   -----------------------------------------------------------------------------
+--R                                         12
+--R                                                    Type: Expression(Integer)
+--E 654
+
+--S 655 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                         +----+
+--R          2   3           2    2     +-+ |   2     2 2 4         2 3    2 2 2
+--R        (b c x  + 2a b c x  + a c x)\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ---------------------------------------------------------------------
+--R                                        +----+
+--R                                        |   2
+--R                                       \|c x
+--R                                                    Type: Expression(Integer)
+--E 655
+
+)clear all
+
+--S 656 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^2/x^3
+--R 
+--R
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R   (1)  --------------------------------
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 1008
+r0:=1/3*c*(a+b*x)^3*sqrt(c*x^2)/(b*x)
+--R 
+--R
+--R                                              +----+
+--R          3   3       2   2     2         3   |   2
+--R        (b c x  + 3a b c x  + 3a b c x + a c)\|c x
+--R   (2)  --------------------------------------------
+--R                            3b x
+--R                                                    Type: Expression(Integer)
+--E 657
+
+--S 658 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2   3           2     2     +-+
+--R        (b c x  + 3a b c x  + 3a c x)\|c
+--R   (3)  ---------------------------------
+--R                        3
+--R                                         Type: Union(Expression(Integer),...)
+--E 658
+
+--S 659 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +----+
+--R           3   3       2   2     2         3   |   2
+--R       (- b c x  - 3a b c x  - 3a b c x - a c)\|c x
+--R     + 
+--R         3   4       2   3     2     2  +-+
+--R       (b c x  + 3a b c x  + 3a b c x )\|c
+--R  /
+--R     3b x
+--R                                                    Type: Expression(Integer)
+--E 659
+
+--S 660 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                      +----+
+--R          2   2               2   +-+ |   2     2 2 3         2 2    2 2
+--R        (b c x  + 2a b c x + a c)\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  -----------------------------------------------------------------
+--R                                      +----+
+--R                                      |   2
+--R                                     \|c x
+--R                                                    Type: Expression(Integer)
+--E 660
+
+)clear all
+
+--S 661 of 1008
+t0:=(c*x^2)^(3/2)*(a+b*x)^2/x^4
+--R 
+--R
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R   (1)  --------------------------------
+--R                        2
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 1008
+r0:=2*a*b*c*sqrt(c*x^2)+1/2*b^2*c*x*sqrt(c*x^2)+a^2*c*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                                          +----+
+--R           2            2   2             |   2
+--R        (2a c log(x) + b c x  + 4a b c x)\|c x
+--R   (2)  ----------------------------------------
+--R                           2x
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2            2   2             +-+
+--R        (2a c log(x) + b c x  + 4a b c x)\|c
+--R   (3)  -------------------------------------
+--R                          2
+--R                                         Type: Union(Expression(Integer),...)
+--E 663
+
+--S 664 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +----+
+--R            2            2   2             |   2
+--R       (- 2a c log(x) - b c x  - 4a b c x)\|c x
+--R     + 
+--R          2              2   3           2  +-+
+--R       (2a c x log(x) + b c x  + 4a b c x )\|c
+--R  /
+--R     2x
+--R                                                    Type: Expression(Integer)
+--E 664
+
+--S 665 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                      +----+
+--R          2   2               2   +-+ |   2     2 2 3         2 2    2 2
+--R        (b c x  + 2a b c x + a c)\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  -----------------------------------------------------------------
+--R                                       +----+
+--R                                       |   2
+--R                                     x\|c x
+--R                                                    Type: Expression(Integer)
+--E 665
+
+)clear all
+
+--S 666 of 1008
+t0:=x^m*(c*x^2)^(5/2)*(a+b*x)^2
+--R 
+--R
+--R                                        +----+
+--R          2 2 6         2 5    2 2 4  m |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )x \|c x
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 1008
+r0:=a^2*c^2*x^(5+m)*sqrt(c*x^2)/(6+m)+2*a*b*c^2*x^(6+m)*sqrt(c*x^2)/(7+m)+_
+   b^2*c^2*x^(7+m)*sqrt(c*x^2)/(8+m)
+--R 
+--R
+--R   (2)
+--R           2 2 2      2 2       2 2  m + 7
+--R         (b c m  + 13b c m + 42b c )x
+--R       + 
+--R                2 2          2           2  m + 6
+--R         (2a b c m  + 28a b c m + 96a b c )x
+--R       + 
+--R           2 2 2      2 2       2 2  m + 5
+--R         (a c m  + 15a c m + 56a c )x
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R      3      2
+--R     m  + 21m  + 146m + 336
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 2 2      2 2       2 2  8          2 2          2           2  7
+--R         (b c m  + 13b c m + 42b c )x  + (2a b c m  + 28a b c m + 96a b c )x
+--R       + 
+--R           2 2 2      2 2       2 2  6
+--R         (a c m  + 15a c m + 56a c )x
+--R    *
+--R        +-+  m log(x)
+--R       \|c %e
+--R  /
+--R      3      2
+--R     m  + 21m  + 146m + 336
+--R                                         Type: Union(Expression(Integer),...)
+--E 668
+
+--S 669 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2 2 2      2 2       2 2  8          2 2          2           2  7
+--R           (b c m  + 13b c m + 42b c )x  + (2a b c m  + 28a b c m + 96a b c )x
+--R         + 
+--R             2 2 2      2 2       2 2  6
+--R           (a c m  + 15a c m + 56a c )x
+--R      *
+--R          +-+  m log(x)
+--R         \|c %e
+--R     + 
+--R               2 2 2      2 2       2 2  m + 7
+--R           (- b c m  - 13b c m - 42b c )x
+--R         + 
+--R                    2 2          2           2  m + 6
+--R           (- 2a b c m  - 28a b c m - 96a b c )x
+--R         + 
+--R               2 2 2      2 2       2 2  m + 5
+--R           (- a c m  - 15a c m - 56a c )x
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R  /
+--R      3      2
+--R     m  + 21m  + 146m + 336
+--R                                                    Type: Expression(Integer)
+--E 669
+
+--S 670 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                       +----+
+--R          2 2 2         2     2 2  +-+ |   2     2 3 3         3 2    2 3
+--R       ((b c x  + 2a b c x + a c )\|c \|c x   - b c x  - 2a b c x  - a c x)
+--R    *
+--R         (m + 7)log(x)
+--R       %e
+--R  /
+--R        +----+
+--R      2 |   2
+--R     x \|c x
+--R                                                    Type: Expression(Integer)
+--E 670
+
+)clear all
+
+--S 671 of 1008
+t0:=x^3*(c*x^2)^(5/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2 2 9         2 8    2 2 7  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 1008
+r0:=1/9*a^2*c^2*x^8*sqrt(c*x^2)+1/5*a*b*c^2*x^9*sqrt(c*x^2)+_
+   1/11*b^2*c^2*x^10*sqrt(c*x^2)
+--R 
+--R
+--R                                            +----+
+--R            2 2 10          2 9      2 2 8  |   2
+--R        (45b c x   + 99a b c x  + 55a c x )\|c x
+--R   (2)  ------------------------------------------
+--R                            495
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2 11          2 10      2 2 9  +-+
+--R        (45b c x   + 99a b c x   + 55a c x )\|c
+--R   (3)  ----------------------------------------
+--R                           495
+--R                                         Type: Union(Expression(Integer),...)
+--E 673
+
+--S 674 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                             +----+
+--R             2 2 10          2 9      2 2 8  |   2
+--R       (- 45b c x   - 99a b c x  - 55a c x )\|c x
+--R     + 
+--R           2 2 11          2 10      2 2 9  +-+
+--R       (45b c x   + 99a b c x   + 55a c x )\|c
+--R  /
+--R     495
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                      +----+
+--R     2 2 10         2 9    2 2 8  +-+ |   2     2 3 11         3 10    2 3 9
+--R   (b c x   + 2a b c x  + a c x )\|c \|c x   - b c x   - 2a b c x   - a c x
+--R   -------------------------------------------------------------------------
+--R                                     +----+
+--R                                     |   2
+--R                                    \|c x
+--R                                                    Type: Expression(Integer)
+--E 675
+
+)clear all
+
+--S 676 of 1008
+t0:=x^2*(c*x^2)^(5/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2 2 8         2 7    2 2 6  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 1008
+r0:=1/8*a^2*c^2*x^7*sqrt(c*x^2)+2/9*a*b*c^2*x^8*sqrt(c*x^2)+_
+   1/10*b^2*c^2*x^9*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2 2 9          2 8      2 2 7  |   2
+--R        (36b c x  + 80a b c x  + 45a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           360
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2 10          2 9      2 2 8  +-+
+--R        (36b c x   + 80a b c x  + 45a c x )\|c
+--R   (3)  ---------------------------------------
+--R                          360
+--R                                         Type: Union(Expression(Integer),...)
+--E 678
+
+--S 679 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +----+
+--R             2 2 9          2 8      2 2 7  |   2
+--R       (- 36b c x  - 80a b c x  - 45a c x )\|c x
+--R     + 
+--R           2 2 10          2 9      2 2 8  +-+
+--R       (36b c x   + 80a b c x  + 45a c x )\|c
+--R  /
+--R     360
+--R                                                    Type: Expression(Integer)
+--E 679
+
+--S 680 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                     +----+
+--R     2 2 9         2 8    2 2 7  +-+ |   2     2 3 10         3 9    2 3 8
+--R   (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x   - 2a b c x  - a c x
+--R   -----------------------------------------------------------------------
+--R                                    +----+
+--R                                    |   2
+--R                                   \|c x
+--R                                                    Type: Expression(Integer)
+--E 680
+
+)clear all
+
+--S 681 of 1008
+t0:=x*(c*x^2)^(5/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2 2 7         2 6    2 2 5  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 1008
+r0:=1/7*a^2*c^2*x^6*sqrt(c*x^2)+1/4*a*b*c^2*x^7*sqrt(c*x^2)+_
+   1/9*b^2*c^2*x^8*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2 2 8          2 7      2 2 6  |   2
+--R        (28b c x  + 63a b c x  + 36a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           252
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2 9          2 8      2 2 7  +-+
+--R        (28b c x  + 63a b c x  + 36a c x )\|c
+--R   (3)  --------------------------------------
+--R                          252
+--R                                         Type: Union(Expression(Integer),...)
+--E 683
+
+--S 684 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +----+
+--R             2 2 8          2 7      2 2 6  |   2
+--R       (- 28b c x  - 63a b c x  - 36a c x )\|c x
+--R     + 
+--R           2 2 9          2 8      2 2 7  +-+
+--R       (28b c x  + 63a b c x  + 36a c x )\|c
+--R  /
+--R     252
+--R                                                    Type: Expression(Integer)
+--E 684
+
+--S 685 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                          +----+
+--R          2 2 8         2 7    2 2 6  +-+ |   2     2 3 9         3 8    2 3 7
+--R        (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------------
+--R                                         +----+
+--R                                         |   2
+--R                                        \|c x
+--R                                                    Type: Expression(Integer)
+--E 685
+
+)clear all
+
+--S 686 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2 2 6         2 5    2 2 4  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 1008
+r0:=1/6*a^2*c^2*x^5*sqrt(c*x^2)+2/7*a*b*c^2*x^6*sqrt(c*x^2)+_
+   1/8*b^2*c^2*x^7*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2 2 7          2 6      2 2 5  |   2
+--R        (21b c x  + 48a b c x  + 28a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           168
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2 8          2 7      2 2 6  +-+
+--R        (21b c x  + 48a b c x  + 28a c x )\|c
+--R   (3)  --------------------------------------
+--R                          168
+--R                                         Type: Union(Expression(Integer),...)
+--E 688
+
+--S 689 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +----+
+--R             2 2 7          2 6      2 2 5  |   2
+--R       (- 21b c x  - 48a b c x  - 28a c x )\|c x
+--R     + 
+--R           2 2 8          2 7      2 2 6  +-+
+--R       (21b c x  + 48a b c x  + 28a c x )\|c
+--R  /
+--R     168
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                          +----+
+--R          2 2 7         2 6    2 2 5  +-+ |   2     2 3 8         3 7    2 3 6
+--R        (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------------
+--R                                         +----+
+--R                                         |   2
+--R                                        \|c x
+--R                                                    Type: Expression(Integer)
+--E 690
+
+)clear all
+
+--S 691 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^2/x
+--R 
+--R
+--R                                      +----+
+--R          2 2 5         2 4    2 2 3  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 691
+
+--S 692 of 1008
+r0:=1/5*a^2*c^2*x^4*sqrt(c*x^2)+1/3*a*b*c^2*x^5*sqrt(c*x^2)+_
+   1/7*b^2*c^2*x^6*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2 2 6          2 5      2 2 4  |   2
+--R        (15b c x  + 35a b c x  + 21a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           105
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2 7          2 6      2 2 5  +-+
+--R        (15b c x  + 35a b c x  + 21a c x )\|c
+--R   (3)  --------------------------------------
+--R                          105
+--R                                         Type: Union(Expression(Integer),...)
+--E 693
+
+--S 694 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +----+
+--R             2 2 6          2 5      2 2 4  |   2
+--R       (- 15b c x  - 35a b c x  - 21a c x )\|c x
+--R     + 
+--R           2 2 7          2 6      2 2 5  +-+
+--R       (15b c x  + 35a b c x  + 21a c x )\|c
+--R  /
+--R     105
+--R                                                    Type: Expression(Integer)
+--E 694
+
+--S 695 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                          +----+
+--R          2 2 6         2 5    2 2 4  +-+ |   2     2 3 7         3 6    2 3 5
+--R        (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------------
+--R                                         +----+
+--R                                         |   2
+--R                                        \|c x
+--R                                                    Type: Expression(Integer)
+--E 695
+
+)clear all
+
+--S 696 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^2/x^2
+--R 
+--R
+--R                                      +----+
+--R          2 2 4         2 3    2 2 2  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 1008
+r0:=1/4*a^2*c^2*x^3*sqrt(c*x^2)+2/5*a*b*c^2*x^4*sqrt(c*x^2)+_
+   1/6*b^2*c^2*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2 2 5          2 4      2 2 3  |   2
+--R        (10b c x  + 24a b c x  + 15a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                            60
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2 6          2 5      2 2 4  +-+
+--R        (10b c x  + 24a b c x  + 15a c x )\|c
+--R   (3)  --------------------------------------
+--R                          60
+--R                                         Type: Union(Expression(Integer),...)
+--E 698
+
+--S 699 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            +----+
+--R             2 2 5          2 4      2 2 3  |   2
+--R       (- 10b c x  - 24a b c x  - 15a c x )\|c x
+--R     + 
+--R           2 2 6          2 5      2 2 4  +-+
+--R       (10b c x  + 24a b c x  + 15a c x )\|c
+--R  /
+--R     60
+--R                                                    Type: Expression(Integer)
+--E 699
+
+--S 700 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                          +----+
+--R          2 2 5         2 4    2 2 3  +-+ |   2     2 3 6         3 5    2 3 4
+--R        (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------------
+--R                                         +----+
+--R                                         |   2
+--R                                        \|c x
+--R                                                    Type: Expression(Integer)
+--E 700
+
+)clear all
+
+--S 701 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^2/x^3
+--R 
+--R
+--R                                     +----+
+--R          2 2 3         2 2    2 2   |   2
+--R   (1)  (b c x  + 2a b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 1008
+r0:=1/3*a^2*c^2*x^2*sqrt(c*x^2)+1/2*a*b*c^2*x^3*sqrt(c*x^2)+_
+   1/5*b^2*c^2*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                                          +----+
+--R           2 2 4          2 3      2 2 2  |   2
+--R        (6b c x  + 15a b c x  + 10a c x )\|c x
+--R   (2)  ----------------------------------------
+--R                           30
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2 5          2 4      2 2 3  +-+
+--R        (6b c x  + 15a b c x  + 10a c x )\|c
+--R   (3)  -------------------------------------
+--R                          30
+--R                                         Type: Union(Expression(Integer),...)
+--E 703
+
+--S 704 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +----+
+--R            2 2 4          2 3      2 2 2  |   2
+--R       (- 6b c x  - 15a b c x  - 10a c x )\|c x
+--R     + 
+--R          2 2 5          2 4      2 2 3  +-+
+--R       (6b c x  + 15a b c x  + 10a c x )\|c
+--R  /
+--R     30
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                          +----+
+--R          2 2 4         2 3    2 2 2  +-+ |   2     2 3 5         3 4    2 3 3
+--R        (b c x  + 2a b c x  + a c x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------------
+--R                                         +----+
+--R                                         |   2
+--R                                        \|c x
+--R                                                    Type: Expression(Integer)
+--E 705
+
+)clear all
+
+--S 706 of 1008
+t0:=(c*x^2)^(5/2)*(a+b*x)^2/x^4
+--R 
+--R
+--R                                   +----+
+--R          2 2 2         2     2 2  |   2
+--R   (1)  (b c x  + 2a b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 1008
+r0:=1/2*a^2*c^2*x*sqrt(c*x^2)+2/3*a*b*c^2*x^2*sqrt(c*x^2)+_
+   1/4*b^2*c^2*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                                       +----+
+--R           2 2 3         2 2     2 2   |   2
+--R        (3b c x  + 8a b c x  + 6a c x)\|c x
+--R   (2)  -------------------------------------
+--R                          12
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2 4         2 3     2 2 2  +-+
+--R        (3b c x  + 8a b c x  + 6a c x )\|c
+--R   (3)  -----------------------------------
+--R                         12
+--R                                         Type: Union(Expression(Integer),...)
+--E 708
+
+--S 709 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    +----+
+--R        2 2 3         2 2     2 2   |   2       2 2 4         2 3     2 2 2  +-+
+--R   (- 3b c x  - 8a b c x  - 6a c x)\|c x   + (3b c x  + 8a b c x  + 6a c x )\|c
+--R   -----------------------------------------------------------------------------
+--R                                         12
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                         +----+
+--R          2 2 3         2 2    2 2   +-+ |   2     2 3 4         3 3    2 3 2
+--R        (b c x  + 2a b c x  + a c x)\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ---------------------------------------------------------------------
+--R                                        +----+
+--R                                        |   2
+--R                                       \|c x
+--R                                                    Type: Expression(Integer)
+--E 710
+
+)clear all
+
+--S 711 of 1008
+t0:=x^m*(a+b*x)^2/sqrt(c*x^2)
+--R 
+--R
+--R          2 2             2  m
+--R        (b x  + 2a b x + a )x
+--R   (1)  ----------------------
+--R                 +----+
+--R                 |   2
+--R                \|c x
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 1008
+r0:=a^2*x^(1+m)/(m*sqrt(c*x^2))+2*a*b*x^(2+m)/((1+m)*sqrt(c*x^2))+_
+   b^2*x^(3+m)/((2+m)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R     2 2    2   m + 3          2           m + 2     2 2     2      2  m + 1
+--R   (b m  + b m)x      + (2a b m  + 4a b m)x      + (a m  + 3a m + 2a )x
+--R   -------------------------------------------------------------------------
+--R                                             +----+
+--R                               3     2       |   2
+--R                             (m  + 3m  + 2m)\|c x
+--R                                                    Type: Expression(Integer)
+--E 712
+
+--S 713 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2    2   2          2               2 2     2      2   m log(x)
+--R        ((b m  + b m)x  + (2a b m  + 4a b m)x + a m  + 3a m + 2a )%e
+--R   (3)  --------------------------------------------------------------------
+--R                                   3     2       +-+
+--R                                 (m  + 3m  + 2m)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 713
+
+--S 714 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                    +----+
+--R            2 2    2   2          2               2 2     2      2  |   2
+--R         ((b m  + b m)x  + (2a b m  + 4a b m)x + a m  + 3a m + 2a )\|c x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R               2 2    2   m + 3            2           m + 2
+--R           (- b m  - b m)x      + (- 2a b m  - 4a b m)x
+--R         + 
+--R               2 2     2      2  m + 1
+--R           (- a m  - 3a m - 2a )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                         +----+
+--R       3     2       +-+ |   2
+--R     (m  + 3m  + 2m)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 714
+
+--S 715 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                             +----+
+--R      2 2             2  +-+ |   2     2   3           2    2      (m + 3)log(x)
+--R   ((b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x)%e
+--R   -----------------------------------------------------------------------------
+--R                                         +----+
+--R                                       4 |   2
+--R                                    c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 715
+
+)clear all
+
+--S 716 of 1008
+t0:=x^3*(a+b*x)^2/sqrt(c*x^2)
+--R 
+--R
+--R         2 5         4    2 3
+--R        b x  + 2a b x  + a x
+--R   (1)  ---------------------
+--R                +----+
+--R                |   2
+--R               \|c x
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1008
+r0:=1/3*a^2*x^4/sqrt(c*x^2)+1/2*a*b*x^5/sqrt(c*x^2)+1/5*b^2*x^6/sqrt(c*x^2)
+--R 
+--R
+--R          2 6          5      2 4
+--R        6b x  + 15a b x  + 10a x
+--R   (2)  -------------------------
+--R                   +----+
+--R                   |   2
+--R                30\|c x
+--R                                                    Type: Expression(Integer)
+--E 717
+
+--S 718 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 5          4      2 3
+--R        6b x  + 15a b x  + 10a x
+--R   (3)  -------------------------
+--R                     +-+
+--R                  30\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 718
+
+--S 719 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                    +----+
+--R           2 5          4      2 3  |   2         2 6          5      2 4  +-+
+--R        (6b x  + 15a b x  + 10a x )\|c x   + (- 6b x  - 15a b x  - 10a x )\|c
+--R   (4)  ----------------------------------------------------------------------
+--R                                            +----+
+--R                                        +-+ |   2
+--R                                     30\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                    +----+
+--R          2 4         3    2 2  +-+ |   2     2   5           4    2   3
+--R        (b x  + 2a b x  + a x )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ----------------------------------------------------------------
+--R                                      +----+
+--R                                      |   2
+--R                                    c\|c x
+--R                                                    Type: Expression(Integer)
+--E 720
+
+)clear all
+
+--S 721 of 1008
+t0:=x^2*(a+b*x)^2/sqrt(c*x^2)
+--R 
+--R
+--R         2 4         3    2 2
+--R        b x  + 2a b x  + a x
+--R   (1)  ---------------------
+--R                +----+
+--R                |   2
+--R               \|c x
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 1008
+r0:=1/2*a^2*x^3/sqrt(c*x^2)+2/3*a*b*x^4/sqrt(c*x^2)+1/4*b^2*x^5/sqrt(c*x^2)
+--R 
+--R
+--R          2 5         4     2 3
+--R        3b x  + 8a b x  + 6a x
+--R   (2)  -----------------------
+--R                  +----+
+--R                  |   2
+--R               12\|c x
+--R                                                    Type: Expression(Integer)
+--E 722
+
+--S 723 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 4         3     2 2
+--R        3b x  + 8a b x  + 6a x
+--R   (3)  -----------------------
+--R                    +-+
+--R                 12\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 723
+
+--S 724 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                  +----+
+--R           2 4         3     2 2  |   2         2 5         4     2 3  +-+
+--R        (3b x  + 8a b x  + 6a x )\|c x   + (- 3b x  - 8a b x  - 6a x )\|c
+--R   (4)  ------------------------------------------------------------------
+--R                                          +----+
+--R                                      +-+ |   2
+--R                                   12\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 724
+
+--S 725 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                   +----+
+--R          2 3         2    2   +-+ |   2     2   4           3    2   2
+--R        (b x  + 2a b x  + a x)\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ---------------------------------------------------------------
+--R                                      +----+
+--R                                      |   2
+--R                                    c\|c x
+--R                                                    Type: Expression(Integer)
+--E 725
+
+)clear all
+
+--S 726 of 1008
+t0:=x*(a+b*x)^2/sqrt(c*x^2)
+--R 
+--R
+--R         2 3         2    2
+--R        b x  + 2a b x  + a x
+--R   (1)  --------------------
+--R                +----+
+--R                |   2
+--R               \|c x
+--R                                                    Type: Expression(Integer)
+--E 726
+
+--S 727 of 1008
+r0:=1/3*x*(a+b*x)^3/(b*sqrt(c*x^2))
+--R 
+--R
+--R         3 4       2 3     2   2    3
+--R        b x  + 3a b x  + 3a b x  + a x
+--R   (2)  ------------------------------
+--R                      +----+
+--R                      |   2
+--R                   3b\|c x
+--R                                                    Type: Expression(Integer)
+--E 727
+
+--S 728 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2 3         2     2
+--R        b x  + 3a b x  + 3a x
+--R   (3)  ---------------------
+--R                  +-+
+--R                3\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 728
+
+--S 729 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +----+
+--R     3 3       2 2     2     |   2        3 4       2 3     2   2    3   +-+
+--R   (b x  + 3a b x  + 3a b x)\|c x   + (- b x  - 3a b x  - 3a b x  - a x)\|c
+--R   -------------------------------------------------------------------------
+--R                                        +----+
+--R                                    +-+ |   2
+--R                                 3b\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 729
+
+--S 730 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                    +----+
+--R                                    |   2
+--R                                  c\|c x
+--R                                                    Type: Expression(Integer)
+--E 730
+
+)clear all
+
+--S 731 of 1008
+t0:=(a+b*x)^2/sqrt(c*x^2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R               +----+
+--R               |   2
+--R              \|c x
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 1008
+r0:=2*a*b*x^2/sqrt(c*x^2)+1/2*b^2*x^3/sqrt(c*x^2)+a^2*x*log(x)/sqrt(c*x^2)
+--R 
+--R
+--R          2            2 3         2
+--R        2a x log(x) + b x  + 4a b x
+--R   (2)  ----------------------------
+--R                    +----+
+--R                    |   2
+--R                  2\|c x
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2          2 2
+--R        2a log(x) + b x  + 4a b x
+--R   (3)  -------------------------
+--R                    +-+
+--R                  2\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 733
+
+--S 734 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R      2          2 2           |   2         2            2 3         2  +-+
+--R   (2a log(x) + b x  + 4a b x)\|c x   + (- 2a x log(x) - b x  - 4a b x )\|c
+--R   -------------------------------------------------------------------------
+--R                                        +----+
+--R                                    +-+ |   2
+--R                                  2\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 734
+
+--S 735 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                     +----+
+--R                                     |   2
+--R                                 c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 735
+
+)clear all
+
+--S 736 of 1008
+t0:=(a+b*x)^2/(x*sqrt(c*x^2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R               +----+
+--R               |   2
+--R             x\|c x
+--R                                                    Type: Expression(Integer)
+--E 736
+
+--S 737 of 1008
+r0:=-a^2/sqrt(c*x^2)+b^2*x^2/sqrt(c*x^2)+2*a*b*x*log(x)/sqrt(c*x^2)
+--R 
+--R
+--R                         2 2    2
+--R        2a b x log(x) + b x  - a
+--R   (2)  -------------------------
+--R                  +----+
+--R                  |   2
+--R                 \|c x
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         2 2    2
+--R        2a b x log(x) + b x  - a
+--R   (3)  -------------------------
+--R                    +-+
+--R                  x\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 738
+
+--S 739 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R                     2 2    2  |   2             2          2 3    2   +-+
+--R   (2a b x log(x) + b x  - a )\|c x   + (- 2a b x log(x) - b x  + a x)\|c
+--R   -----------------------------------------------------------------------
+--R                                       +----+
+--R                                   +-+ |   2
+--R                                 x\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                    2 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 740
+
+)clear all
+
+--S 741 of 1008
+t0:=(a+b*x)^2/(x^2*sqrt(c*x^2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                +----+
+--R              2 |   2
+--R             x \|c x
+--R                                                    Type: Expression(Integer)
+--E 741
+
+--S 742 of 1008
+r0:=-2*a*b/sqrt(c*x^2)-1/2*a^2/(x*sqrt(c*x^2))+b^2*x*log(x)/sqrt(c*x^2)
+--R 
+--R
+--R          2 2                   2
+--R        2b x log(x) - 4a b x - a
+--R   (2)  -------------------------
+--R                   +----+
+--R                   |   2
+--R                2x\|c x
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 2                   2
+--R        2b x log(x) - 4a b x - a
+--R   (3)  -------------------------
+--R                   2 +-+
+--R                 2x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 743
+
+--S 744 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R      2 2                   2  |   2         2 3               2    2   +-+
+--R   (2b x log(x) - 4a b x - a )\|c x   + (- 2b x log(x) + 4a b x  + a x)\|c
+--R   ------------------------------------------------------------------------
+--R                                        +----+
+--R                                  2 +-+ |   2
+--R                                2x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                    3 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 745
+
+)clear all
+
+--S 746 of 1008
+t0:=(a+b*x)^2/(x^3*sqrt(c*x^2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                +----+
+--R              3 |   2
+--R             x \|c x
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 1008
+r0:=-1/3*(a+b*x)^3/(a*x^2*sqrt(c*x^2))
+--R 
+--R
+--R           3 3       2 2     2       3
+--R        - b x  - 3a b x  - 3a b x - a
+--R   (2)  ------------------------------
+--R                       +----+
+--R                     2 |   2
+--R                 3a x \|c x
+--R                                                    Type: Expression(Integer)
+--E 747
+
+--S 748 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2             2
+--R        - 3b x  - 3a b x - a
+--R   (3)  ---------------------
+--R                 3 +-+
+--R               3x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 748
+
+--S 749 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +----+
+--R          2 2     2       3  |   2      3 4       2 3     2   2    3   +-+
+--R   (- 3a b x  - 3a b x - a )\|c x   + (b x  + 3a b x  + 3a b x  + a x)\|c
+--R   -----------------------------------------------------------------------
+--R                                         +----+
+--R                                   3 +-+ |   2
+--R                               3a x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                    4 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 750
+
+)clear all
+
+--S 751 of 1008
+t0:=(a+b*x)^2/(x^4*sqrt(c*x^2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                +----+
+--R              4 |   2
+--R             x \|c x
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 1008
+r0:=-1/4*a^2/(x^3*sqrt(c*x^2))-2/3*a*b/(x^2*sqrt(c*x^2))-_
+   1/2*b^2/(x*sqrt(c*x^2))
+--R 
+--R
+--R            2 2              2
+--R        - 6b x  - 8a b x - 3a
+--R   (2)  ----------------------
+--R                   +----+
+--R                 3 |   2
+--R              12x \|c x
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2              2
+--R        - 6b x  - 8a b x - 3a
+--R   (3)  ----------------------
+--R                  4 +-+
+--R               12x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 753
+
+--S 754 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                 +----+
+--R             2 2              2  |   2       2 3         2     2   +-+
+--R        (- 6b x  - 8a b x - 3a )\|c x   + (6b x  + 8a b x  + 3a x)\|c
+--R   (4)  --------------------------------------------------------------
+--R                                         +----+
+--R                                   4 +-+ |   2
+--R                                12x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                    5 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 755
+
+)clear all
+
+--S 756 of 1008
+t0:=x^m*(a+b*x)^2/(c*x^2)^(3/2)
+--R 
+--R
+--R          2 2             2  m
+--R        (b x  + 2a b x + a )x
+--R   (1)  ----------------------
+--R                   +----+
+--R                 2 |   2
+--R              c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 1008
+r0:=-a^2*x^(-1+m)/(c*(2-m)*sqrt(c*x^2))-2*a*b*x^m/(c*(1-m)*sqrt(c*x^2))+_
+   b^2*x^(1+m)/(c*m*sqrt(c*x^2))
+--R 
+--R
+--R          2 2     2      2  m + 1          2           m     2 2    2   m - 1
+--R        (b m  - 3b m + 2b )x      + (2a b m  - 4a b m)x  + (a m  - a m)x
+--R   (2)  ---------------------------------------------------------------------
+--R                                                   +----+
+--R                                 3       2         |   2
+--R                             (c m  - 3c m  + 2c m)\|c x
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2     2      2  2          2               2 2    2    m log(x)
+--R        ((b m  - 3b m + 2b )x  + (2a b m  - 4a b m)x + a m  - a m)%e
+--R   (3)  --------------------------------------------------------------------
+--R                                 3       2         2 +-+
+--R                             (c m  - 3c m  + 2c m)x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 758
+
+--S 759 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                    +----+
+--R            2 2     2      2  2          2               2 2    2   |   2
+--R         ((b m  - 3b m + 2b )x  + (2a b m  - 4a b m)x + a m  - a m)\|c x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R               2 2     2      2  2 m + 1            2           2 m
+--R           (- b m  + 3b m - 2b )x x      + (- 2a b m  + 4a b m)x x
+--R         + 
+--R               2 2    2   2 m - 1
+--R           (- a m  + a m)x x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                 +----+
+--R         3       2         2 +-+ |   2
+--R     (c m  - 3c m  + 2c m)x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                             +----+
+--R      2 2             2  +-+ |   2     2   3           2    2      (m + 1)log(x)
+--R   ((b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x)%e
+--R   -----------------------------------------------------------------------------
+--R                                         +----+
+--R                                     2 4 |   2
+--R                                    c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 760
+
+)clear all
+
+--S 761 of 1008
+t0:=x^3*(a+b*x)^2/(c*x^2)^(3/2)
+--R 
+--R
+--R         2 3         2    2
+--R        b x  + 2a b x  + a x
+--R   (1)  --------------------
+--R                +----+
+--R                |   2
+--R              c\|c x
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 1008
+r0:=1/3*x*(a+b*x)^3/(b*c*sqrt(c*x^2))
+--R 
+--R
+--R         3 4       2 3     2   2    3
+--R        b x  + 3a b x  + 3a b x  + a x
+--R   (2)  ------------------------------
+--R                       +----+
+--R                       |   2
+--R                  3b c\|c x
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2 3         2     2
+--R        b x  + 3a b x  + 3a x
+--R   (3)  ---------------------
+--R                   +-+
+--R                3c\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 763
+
+--S 764 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +----+
+--R     3 3       2 2     2     |   2        3 4       2 3     2   2    3   +-+
+--R   (b x  + 3a b x  + 3a b x)\|c x   + (- b x  - 3a b x  - 3a b x  - a x)\|c
+--R   -------------------------------------------------------------------------
+--R                                         +----+
+--R                                     +-+ |   2
+--R                                3b c\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                     +----+
+--R                                   2 |   2
+--R                                  c \|c x
+--R                                                    Type: Expression(Integer)
+--E 765
+
+)clear all
+
+--S 766 of 1008
+t0:=x^2*(a+b*x)^2/(c*x^2)^(3/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R               +----+
+--R               |   2
+--R             c\|c x
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 1008
+r0:=2*a*b*x^2/(c*sqrt(c*x^2))+1/2*b^2*x^3/(c*sqrt(c*x^2))+_
+   a^2*x*log(x)/(c*sqrt(c*x^2))
+--R 
+--R
+--R          2            2 3         2
+--R        2a x log(x) + b x  + 4a b x
+--R   (2)  ----------------------------
+--R                     +----+
+--R                     |   2
+--R                  2c\|c x
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2          2 2
+--R        2a log(x) + b x  + 4a b x
+--R   (3)  -------------------------
+--R                     +-+
+--R                  2c\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 768
+
+--S 769 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R      2          2 2           |   2         2            2 3         2  +-+
+--R   (2a log(x) + b x  + 4a b x)\|c x   + (- 2a x log(x) - b x  - 4a b x )\|c
+--R   -------------------------------------------------------------------------
+--R                                        +----+
+--R                                    +-+ |   2
+--R                                 2c\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                     +----+
+--R                                  2  |   2
+--R                                 c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 770
+
+)clear all
+
+--S 771 of 1008
+t0:=x*(a+b*x)^2/(c*x^2)^(3/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                +----+
+--R                |   2
+--R            c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 771
+
+--S 772 of 1008
+r0:=-a^2/(c*sqrt(c*x^2))+b^2*x^2/(c*sqrt(c*x^2))+2*a*b*x*log(x)/(c*sqrt(c*x^2))
+--R 
+--R
+--R                         2 2    2
+--R        2a b x log(x) + b x  - a
+--R   (2)  -------------------------
+--R                   +----+
+--R                   |   2
+--R                 c\|c x
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         2 2    2
+--R        2a b x log(x) + b x  - a
+--R   (3)  -------------------------
+--R                     +-+
+--R                 c x\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 773
+
+--S 774 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R                     2 2    2  |   2             2          2 3    2   +-+
+--R   (2a b x log(x) + b x  - a )\|c x   + (- 2a b x log(x) - b x  + a x)\|c
+--R   -----------------------------------------------------------------------
+--R                                        +----+
+--R                                    +-+ |   2
+--R                                c x\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  2 2 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 775
+
+)clear all
+
+--S 776 of 1008
+t0:=(a+b*x)^2/(c*x^2)^(3/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R               2 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 1008
+r0:=-2*a*b/(c*sqrt(c*x^2))-1/2*a^2/(c*x*sqrt(c*x^2))+_
+   b^2*x*log(x)/(c*sqrt(c*x^2))
+--R 
+--R
+--R          2 2                   2
+--R        2b x log(x) - 4a b x - a
+--R   (2)  -------------------------
+--R                    +----+
+--R                    |   2
+--R               2c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 2                   2
+--R        2b x log(x) - 4a b x - a
+--R   (3)  -------------------------
+--R                    2 +-+
+--R                2c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 778
+
+--S 779 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R      2 2                   2  |   2         2 3               2    2   +-+
+--R   (2b x log(x) - 4a b x - a )\|c x   + (- 2b x log(x) + 4a b x  + a x)\|c
+--R   ------------------------------------------------------------------------
+--R                                         +----+
+--R                                   2 +-+ |   2
+--R                               2c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  2 3 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 780
+
+)clear all
+
+--S 781 of 1008
+t0:=(a+b*x)^2/(x*(c*x^2)^(3/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R               3 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 781
+
+--S 782 of 1008
+r0:=-1/3*(a+b*x)^3/(a*c*x^2*sqrt(c*x^2))
+--R 
+--R
+--R           3 3       2 2     2       3
+--R        - b x  - 3a b x  - 3a b x - a
+--R   (2)  ------------------------------
+--R                        +----+
+--R                      2 |   2
+--R                3a c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2             2
+--R        - 3b x  - 3a b x - a
+--R   (3)  ---------------------
+--R                  3 +-+
+--R              3c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 783
+
+--S 784 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +----+
+--R          2 2     2       3  |   2      3 4       2 3     2   2    3   +-+
+--R   (- 3a b x  - 3a b x - a )\|c x   + (b x  + 3a b x  + 3a b x  + a x)\|c
+--R   -----------------------------------------------------------------------
+--R                                          +----+
+--R                                    3 +-+ |   2
+--R                              3a c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  2 4 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 785
+
+)clear all
+
+--S 786 of 1008
+t0:=(a+b*x)^2/(x^2*(c*x^2)^(3/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R               4 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 1008
+r0:=-1/4*a^2/(c*x^3*sqrt(c*x^2))-2/3*a*b/(c*x^2*sqrt(c*x^2))-_
+   1/2*b^2/(c*x*sqrt(c*x^2))
+--R 
+--R
+--R            2 2              2
+--R        - 6b x  - 8a b x - 3a
+--R   (2)  ----------------------
+--R                    +----+
+--R                  3 |   2
+--R             12c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2              2
+--R        - 6b x  - 8a b x - 3a
+--R   (3)  ----------------------
+--R                   4 +-+
+--R              12c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 788
+
+--S 789 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                 +----+
+--R             2 2              2  |   2       2 3         2     2   +-+
+--R        (- 6b x  - 8a b x - 3a )\|c x   + (6b x  + 8a b x  + 3a x)\|c
+--R   (4)  --------------------------------------------------------------
+--R                                          +----+
+--R                                    4 +-+ |   2
+--R                               12c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  2 5 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 790
+
+)clear all
+
+--S 791 of 1008
+t0:=(a+b*x)^2/(x^3*(c*x^2)^(3/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R               5 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 1008
+r0:=-1/5*a^2/(c*x^4*sqrt(c*x^2))-1/2*a*b/(c*x^3*sqrt(c*x^2))-_
+   1/3*b^2/(c*x^2*sqrt(c*x^2))
+--R 
+--R
+--R             2 2               2
+--R        - 10b x  - 15a b x - 6a
+--R   (2)  ------------------------
+--R                     +----+
+--R                   4 |   2
+--R              30c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 792
+
+--S 793 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 2               2
+--R        - 10b x  - 15a b x - 6a
+--R   (3)  ------------------------
+--R                    5 +-+
+--R               30c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 793
+
+--S 794 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                   +----+
+--R              2 2               2  |   2        2 3          2     2   +-+
+--R        (- 10b x  - 15a b x - 6a )\|c x   + (10b x  + 15a b x  + 6a x)\|c
+--R   (4)  ------------------------------------------------------------------
+--R                                            +----+
+--R                                      5 +-+ |   2
+--R                                 30c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  2 6 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 795
+
+)clear all
+
+--S 796 of 1008
+t0:=(a+b*x)^2/(x^4*(c*x^2)^(3/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R               6 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 1008
+r0:=-1/6*a^2/(c*x^5*sqrt(c*x^2))-2/5*a*b/(c*x^4*sqrt(c*x^2))-_
+   1/4*b^2/(c*x^3*sqrt(c*x^2))
+--R 
+--R
+--R             2 2                2
+--R        - 15b x  - 24a b x - 10a
+--R   (2)  -------------------------
+--R                     +----+
+--R                   5 |   2
+--R              60c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 797
+
+--S 798 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 2                2
+--R        - 15b x  - 24a b x - 10a
+--R   (3)  -------------------------
+--R                     6 +-+
+--R                60c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 798
+
+--S 799 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                    +----+
+--R              2 2                2  |   2        2 3          2      2   +-+
+--R        (- 15b x  - 24a b x - 10a )\|c x   + (15b x  + 24a b x  + 10a x)\|c
+--R   (4)  --------------------------------------------------------------------
+--R                                             +----+
+--R                                       6 +-+ |   2
+--R                                  60c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 799
+
+--S 800 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  2 7 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 800
+
+)clear all
+
+--S 801 of 1008
+t0:=x^m*(a+b*x)^2/(c*x^2)^(5/2)
+--R 
+--R
+--R          2 2             2  m
+--R        (b x  + 2a b x + a )x
+--R   (1)  ----------------------
+--R                   +----+
+--R               2 4 |   2
+--R              c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 801
+
+--S 802 of 1008
+r0:=-a^2*x^(-3+m)/(c^2*(4-m)*sqrt(c*x^2))-2*a*b*x^(-2+m)/(c^2*(3-m)*_
+   sqrt(c*x^2))-b^2*x^(-1+m)/(c^2*(2-m)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         2 2     2       2  m - 1          2                    m - 2
+--R       (b m  - 7b m + 12b )x      + (2a b m  - 12a b m + 16a b)x
+--R     + 
+--R         2 2     2      2  m - 3
+--R       (a m  - 5a m + 6a )x
+--R  /
+--R                                   +----+
+--R       2 3     2 2      2       2  |   2
+--R     (c m  - 9c m  + 26c m - 24c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 802
+
+--S 803 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 2     2       2  2          2                        2 2     2
+--R           (b m  - 7b m + 12b )x  + (2a b m  - 12a b m + 16a b)x + a m  - 5a m
+--R         + 
+--R             2
+--R           6a
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R       2 3     2 2      2       2  4 +-+
+--R     (c m  - 9c m  + 26c m - 24c )x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 803
+
+--S 804 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2 2     2       2  2          2                        2 2     2
+--R           (b m  - 7b m + 12b )x  + (2a b m  - 12a b m + 16a b)x + a m  - 5a m
+--R         + 
+--R             2
+--R           6a
+--R      *
+--R          +----+
+--R          |   2   m log(x)
+--R         \|c x  %e
+--R     + 
+--R               2 2     2       2  4 m - 1
+--R           (- b m  + 7b m - 12b )x x
+--R         + 
+--R                  2                    4 m - 2       2 2     2      2  4 m - 3
+--R         (- 2a b m  + 12a b m - 16a b)x x      + (- a m  + 5a m - 6a )x x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                                         +----+
+--R       2 3     2 2      2       2  4 +-+ |   2
+--R     (c m  - 9c m  + 26c m - 24c )x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                             +----+
+--R      2 2             2  +-+ |   2     2   3           2    2      m log(x)
+--R   ((b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x)%e
+--R   ------------------------------------------------------------------------
+--R                                       +----+
+--R                                   3 5 |   2
+--R                                  c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 805
+
+)clear all
+
+--S 806 of 1008
+t0:=x^3*(a+b*x)^2/(c*x^2)^(5/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                +----+
+--R             2  |   2
+--R            c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 1008
+r0:=-a^2/(c^2*sqrt(c*x^2))+b^2*x^2/(c^2*sqrt(c*x^2))+_
+   2*a*b*x*log(x)/(c^2*sqrt(c*x^2))
+--R 
+--R
+--R                         2 2    2
+--R        2a b x log(x) + b x  - a
+--R   (2)  -------------------------
+--R                   +----+
+--R                 2 |   2
+--R                c \|c x
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         2 2    2
+--R        2a b x log(x) + b x  - a
+--R   (3)  -------------------------
+--R                  2  +-+
+--R                 c x\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 808
+
+--S 809 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R                     2 2    2  |   2             2          2 3    2   +-+
+--R   (2a b x log(x) + b x  - a )\|c x   + (- 2a b x log(x) - b x  + a x)\|c
+--R   -----------------------------------------------------------------------
+--R                                        +----+
+--R                                 2  +-+ |   2
+--R                                c x\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 809
+
+--S 810 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  3 2 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 810
+
+)clear all
+
+--S 811 of 1008
+t0:=x^2*(a+b*x)^2/(c*x^2)^(5/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 2 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 1008
+r0:=-2*a*b/(c^2*sqrt(c*x^2))-1/2*a^2/(c^2*x*sqrt(c*x^2))+_
+   b^2*x*log(x)/(c^2*sqrt(c*x^2))
+--R 
+--R
+--R          2 2                   2
+--R        2b x log(x) - 4a b x - a
+--R   (2)  -------------------------
+--R                    +----+
+--R                 2  |   2
+--R               2c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 2                   2
+--R        2b x log(x) - 4a b x - a
+--R   (3)  -------------------------
+--R                  2 2 +-+
+--R                2c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 813
+
+--S 814 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R      2 2                   2  |   2         2 3               2    2   +-+
+--R   (2b x log(x) - 4a b x - a )\|c x   + (- 2b x log(x) + 4a b x  + a x)\|c
+--R   ------------------------------------------------------------------------
+--R                                         +----+
+--R                                 2 2 +-+ |   2
+--R                               2c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  3 3 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 815
+
+)clear all
+
+--S 816 of 1008
+t0:=x*(a+b*x)^2/(c*x^2)^(5/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 3 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 1008
+r0:=-1/3*(a+b*x)^3/(a*c^2*x^2*sqrt(c*x^2))
+--R 
+--R
+--R           3 3       2 2     2       3
+--R        - b x  - 3a b x  - 3a b x - a
+--R   (2)  ------------------------------
+--R                        +----+
+--R                    2 2 |   2
+--R                3a c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2             2
+--R        - 3b x  - 3a b x - a
+--R   (3)  ---------------------
+--R                2 3 +-+
+--R              3c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 818
+
+--S 819 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +----+
+--R          2 2     2       3  |   2      3 4       2 3     2   2    3   +-+
+--R   (- 3a b x  - 3a b x - a )\|c x   + (b x  + 3a b x  + 3a b x  + a x)\|c
+--R   -----------------------------------------------------------------------
+--R                                          +----+
+--R                                  2 3 +-+ |   2
+--R                              3a c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  3 4 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 820
+
+)clear all
+
+--S 821 of 1008
+t0:=(a+b*x)^2/(c*x^2)^(5/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 4 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 1008
+r0:=-1/4*a^2/(c^2*x^3*sqrt(c*x^2))-2/3*a*b/(c^2*x^2*sqrt(c*x^2))-_
+   1/2*b^2/(c^2*x*sqrt(c*x^2))
+--R 
+--R
+--R            2 2              2
+--R        - 6b x  - 8a b x - 3a
+--R   (2)  ----------------------
+--R                    +----+
+--R                2 3 |   2
+--R             12c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 822
+
+--S 823 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2              2
+--R        - 6b x  - 8a b x - 3a
+--R   (3)  ----------------------
+--R                 2 4 +-+
+--R              12c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 823
+
+--S 824 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                 +----+
+--R             2 2              2  |   2       2 3         2     2   +-+
+--R        (- 6b x  - 8a b x - 3a )\|c x   + (6b x  + 8a b x  + 3a x)\|c
+--R   (4)  --------------------------------------------------------------
+--R                                          +----+
+--R                                  2 4 +-+ |   2
+--R                               12c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 824
+
+--S 825 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  3 5 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 825
+
+)clear all
+
+--S 826 of 1008
+t0:=(a+b*x)^2/(x*(c*x^2)^(5/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 5 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 1008
+r0:=-1/5*a^2/(c^2*x^4*sqrt(c*x^2))-1/2*a*b/(c^2*x^3*sqrt(c*x^2))-_
+   1/3*b^2/(c^2*x^2*sqrt(c*x^2))
+--R 
+--R
+--R             2 2               2
+--R        - 10b x  - 15a b x - 6a
+--R   (2)  ------------------------
+--R                     +----+
+--R                 2 4 |   2
+--R              30c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 827
+
+--S 828 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 2               2
+--R        - 10b x  - 15a b x - 6a
+--R   (3)  ------------------------
+--R                  2 5 +-+
+--R               30c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 828
+
+--S 829 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                   +----+
+--R              2 2               2  |   2        2 3          2     2   +-+
+--R        (- 10b x  - 15a b x - 6a )\|c x   + (10b x  + 15a b x  + 6a x)\|c
+--R   (4)  ------------------------------------------------------------------
+--R                                            +----+
+--R                                    2 5 +-+ |   2
+--R                                 30c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  3 6 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 830
+
+)clear all
+
+--S 831 of 1008
+t0:=(a+b*x)^2/(x^2*(c*x^2)^(5/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 6 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 1008
+r0:=-1/6*a^2/(c^2*x^5*sqrt(c*x^2))-2/5*a*b/(c^2*x^4*sqrt(c*x^2))-_
+   1/4*b^2/(c^2*x^3*sqrt(c*x^2))
+--R 
+--R
+--R             2 2                2
+--R        - 15b x  - 24a b x - 10a
+--R   (2)  -------------------------
+--R                     +----+
+--R                 2 5 |   2
+--R              60c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 2                2
+--R        - 15b x  - 24a b x - 10a
+--R   (3)  -------------------------
+--R                   2 6 +-+
+--R                60c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 833
+
+--S 834 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                    +----+
+--R              2 2                2  |   2        2 3          2      2   +-+
+--R        (- 15b x  - 24a b x - 10a )\|c x   + (15b x  + 24a b x  + 10a x)\|c
+--R   (4)  --------------------------------------------------------------------
+--R                                             +----+
+--R                                     2 6 +-+ |   2
+--R                                  60c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 834
+
+--S 835 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  3 7 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 835
+
+)clear all
+
+--S 836 of 1008
+t0:=(a+b*x)^2/(x^3*(c*x^2)^(5/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 7 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 1008
+r0:=-1/7*a^2/(c^2*x^6*sqrt(c*x^2))-1/3*a*b/(c^2*x^5*sqrt(c*x^2))-_
+   1/5*b^2/(c^2*x^4*sqrt(c*x^2))
+--R 
+--R
+--R             2 2                2
+--R        - 21b x  - 35a b x - 15a
+--R   (2)  -------------------------
+--R                      +----+
+--R                  2 6 |   2
+--R              105c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 2                2
+--R        - 21b x  - 35a b x - 15a
+--R   (3)  -------------------------
+--R                   2 7 +-+
+--R               105c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 838
+
+--S 839 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                    +----+
+--R              2 2                2  |   2        2 3          2      2   +-+
+--R        (- 21b x  - 35a b x - 15a )\|c x   + (21b x  + 35a b x  + 15a x)\|c
+--R   (4)  --------------------------------------------------------------------
+--R                                             +----+
+--R                                     2 7 +-+ |   2
+--R                                 105c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 839
+
+--S 840 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  3 8 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 840
+
+)clear all
+
+--S 841 of 1008
+t0:=(a+b*x)^2/(x^4*(c*x^2)^(5/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 8 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 841
+
+--S 842 of 1008
+r0:=-1/8*a^2/(c^2*x^7*sqrt(c*x^2))-2/7*a*b/(c^2*x^6*sqrt(c*x^2))-_
+   1/6*b^2/(c^2*x^5*sqrt(c*x^2))
+--R 
+--R
+--R             2 2                2
+--R        - 28b x  - 48a b x - 21a
+--R   (2)  -------------------------
+--R                      +----+
+--R                  2 7 |   2
+--R              168c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2 2                2
+--R        - 28b x  - 48a b x - 21a
+--R   (3)  -------------------------
+--R                   2 8 +-+
+--R               168c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 843
+
+--S 844 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                    +----+
+--R              2 2                2  |   2        2 3          2      2   +-+
+--R        (- 28b x  - 48a b x - 21a )\|c x   + (28b x  + 48a b x  + 21a x)\|c
+--R   (4)  --------------------------------------------------------------------
+--R                                             +----+
+--R                                     2 8 +-+ |   2
+--R                                 168c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 844
+
+--S 845 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                                 +----+
+--R          2 2             2  +-+ |   2     2   3           2    2
+--R        (b x  + 2a b x + a )\|c \|c x   - b c x  - 2a b c x  - a c x
+--R   (5)  ------------------------------------------------------------
+--R                                      +----+
+--R                                  3 9 |   2
+--R                                 c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 845
+
+)clear all
+
+--S 846 of 1008
+t0:=x^3*sqrt(c*x^2)/(a+b*x)
+--R 
+--R
+--R           +----+
+--R         3 |   2
+--R        x \|c x
+--R   (1)  ---------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 846
+
+--S 847 of 1008
+r0:=-a^3*sqrt(c*x^2)/b^4+1/2*a^2*x*sqrt(c*x^2)/b^3-1/3*a*x^2*sqrt(c*x^2)/b^2+_
+   1/4*x^3*sqrt(c*x^2)/b+a^4*log(a+b*x)*sqrt(c*x^2)/(b^5*x)
+--R 
+--R
+--R                                                                 +----+
+--R            4                 4 4       3 3     2 2 2      3     |   2
+--R        (12a log(b x + a) + 3b x  - 4a b x  + 6a b x  - 12a b x)\|c x
+--R   (2)  ---------------------------------------------------------------
+--R                                        5
+--R                                     12b x
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4                 4 4       3 3     2 2 2      3     +-+
+--R        (12a log(b x + a) + 3b x  - 4a b x  + 6a b x  - 12a b x)\|c
+--R   (3)  ------------------------------------------------------------
+--R                                       5
+--R                                    12b
+--R                                         Type: Union(Expression(Integer),...)
+--E 848
+
+--S 849 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                  +----+
+--R             4                 4 4       3 3     2 2 2      3     |   2
+--R       (- 12a log(b x + a) - 3b x  + 4a b x  - 6a b x  + 12a b x)\|c x
+--R     + 
+--R           4                   4 5       3 4     2 2 3      3   2  +-+
+--R       (12a x log(b x + a) + 3b x  - 4a b x  + 6a b x  - 12a b x )\|c
+--R  /
+--R        5
+--R     12b x
+--R                                                    Type: Expression(Integer)
+--E 849
+
+--S 850 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R         4 +-+ |   2       5
+--R        x \|c \|c x   - c x
+--R   (5)  --------------------
+--R                    +----+
+--R                    |   2
+--R          (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 850
+
+)clear all
+
+--S 851 of 1008
+t0:=x^2*sqrt(c*x^2)/(a+b*x)
+--R 
+--R
+--R           +----+
+--R         2 |   2
+--R        x \|c x
+--R   (1)  ---------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 1008
+r0:=a^2*sqrt(c*x^2)/b^3-1/2*a*x*sqrt(c*x^2)/b^2+1/3*x^2*sqrt(c*x^2)/b-_
+   a^3*log(a+b*x)*sqrt(c*x^2)/(b^4*x)
+--R 
+--R
+--R                                                       +----+
+--R             3                 3 3       2 2     2     |   2
+--R        (- 6a log(b x + a) + 2b x  - 3a b x  + 6a b x)\|c x
+--R   (2)  -----------------------------------------------------
+--R                                   4
+--R                                 6b x
+--R                                                    Type: Expression(Integer)
+--E 852
+
+--S 853 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3                 3 3       2 2     2     +-+
+--R        (- 6a log(b x + a) + 2b x  - 3a b x  + 6a b x)\|c
+--R   (3)  --------------------------------------------------
+--R                                  4
+--R                                6b
+--R                                         Type: Union(Expression(Integer),...)
+--E 853
+
+--S 854 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +----+
+--R          3                 3 3       2 2     2     |   2
+--R       (6a log(b x + a) - 2b x  + 3a b x  - 6a b x)\|c x
+--R     + 
+--R            3                   3 4       2 3     2   2  +-+
+--R       (- 6a x log(b x + a) + 2b x  - 3a b x  + 6a b x )\|c
+--R  /
+--R       4
+--R     6b x
+--R                                                    Type: Expression(Integer)
+--E 854
+
+--S 855 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R         3 +-+ |   2       4
+--R        x \|c \|c x   - c x
+--R   (5)  --------------------
+--R                    +----+
+--R                    |   2
+--R          (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 855
+
+)clear all
+
+--S 856 of 1008
+t0:=x*sqrt(c*x^2)/(a+b*x)
+--R 
+--R
+--R          +----+
+--R          |   2
+--R        x\|c x
+--R   (1)  --------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 856
+
+--S 857 of 1008
+r0:=-a*sqrt(c*x^2)/b^2+1/2*x*sqrt(c*x^2)/b+a^2*log(a+b*x)*sqrt(c*x^2)/(b^3*x)
+--R 
+--R
+--R                                          +----+
+--R           2                2 2           |   2
+--R        (2a log(b x + a) + b x  - 2a b x)\|c x
+--R   (2)  ----------------------------------------
+--R                            3
+--R                          2b x
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2                2 2           +-+
+--R        (2a log(b x + a) + b x  - 2a b x)\|c
+--R   (3)  -------------------------------------
+--R                           3
+--R                         2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 858
+
+--S 859 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +----+
+--R            2                2 2           |   2
+--R       (- 2a log(b x + a) - b x  + 2a b x)\|c x
+--R     + 
+--R          2                  2 3         2  +-+
+--R       (2a x log(b x + a) + b x  - 2a b x )\|c
+--R  /
+--R       3
+--R     2b x
+--R                                                    Type: Expression(Integer)
+--E 859
+
+--S 860 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R         2 +-+ |   2       3
+--R        x \|c \|c x   - c x
+--R   (5)  --------------------
+--R                    +----+
+--R                    |   2
+--R          (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 860
+
+)clear all
+
+--S 861 of 1008
+t0:=sqrt(c*x^2)/(a+b*x)
+--R 
+--R
+--R         +----+
+--R         |   2
+--R        \|c x
+--R   (1)  -------
+--R        b x + a
+--R                                                    Type: Expression(Integer)
+--E 861
+
+--S 862 of 1008
+r0:=sqrt(c*x^2)/b-a*log(a+b*x)*sqrt(c*x^2)/(b^2*x)
+--R 
+--R
+--R                                 +----+
+--R                                 |   2
+--R        (- a log(b x + a) + b x)\|c x
+--R   (2)  -------------------------------
+--R                       2
+--R                      b x
+--R                                                    Type: Expression(Integer)
+--E 862
+
+--S 863 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                 +-+
+--R        (- a log(b x + a) + b x)\|c
+--R   (3)  ----------------------------
+--R                      2
+--R                     b
+--R                                         Type: Union(Expression(Integer),...)
+--E 863
+
+--S 864 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                               +----+
+--R                               |   2                             2  +-+
+--R        (a log(b x + a) - b x)\|c x   + (- a x log(b x + a) + b x )\|c
+--R   (4)  ---------------------------------------------------------------
+--R                                       2
+--R                                      b x
+--R                                                    Type: Expression(Integer)
+--E 864
+
+--S 865 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +----+
+--R          +-+ |   2       2
+--R        x\|c \|c x   - c x
+--R   (5)  -------------------
+--R                    +----+
+--R                    |   2
+--R          (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 865
+
+)clear all
+
+--S 866 of 1008
+t0:=sqrt(c*x^2)/(x*(a+b*x))
+--R 
+--R
+--R           +----+
+--R           |   2
+--R          \|c x
+--R   (1)  ----------
+--R           2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 1008
+r0:=log(a+b*x)*sqrt(c*x^2)/(b*x)
+--R 
+--R
+--R                     +----+
+--R                     |   2
+--R        log(b x + a)\|c x
+--R   (2)  -------------------
+--R                b x
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     +-+
+--R        log(b x + a)\|c
+--R   (3)  ----------------
+--R                b
+--R                                         Type: Union(Expression(Integer),...)
+--E 868
+
+--S 869 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                       +----+
+--R                       |   2                   +-+
+--R        - log(b x + a)\|c x   + x log(b x + a)\|c
+--R   (4)  ------------------------------------------
+--R                            b x
+--R                                                    Type: Expression(Integer)
+--E 869
+
+--S 870 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +----+
+--R         +-+ |   2
+--R        \|c \|c x   - c x
+--R   (5)  -----------------
+--R                   +----+
+--R                   |   2
+--R         (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 870
+
+)clear all
+
+--S 871 of 1008
+t0:=sqrt(c*x^2)/(x^2*(a+b*x))
+--R 
+--R
+--R           +----+
+--R           |   2
+--R          \|c x
+--R   (1)  -----------
+--R           3      2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 871
+
+--S 872 of 1008
+r0:=log(x)*sqrt(c*x^2)/(a*x)-log(a+b*x)*sqrt(c*x^2)/(a*x)
+--R 
+--R
+--R                                  +----+
+--R                                  |   2
+--R        (- log(b x + a) + log(x))\|c x
+--R   (2)  --------------------------------
+--R                       a x
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                         +---+ +-+
+--R                x     +-+   +---+      a\|- c \|c
+--R         log(-------)\|c  2\|- c atan(------------)
+--R             b x + a                  2b c x + a c
+--R   (3)  [----------------,-------------------------]
+--R                 a                    a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 873
+
+--S 874 of 1008
+m0a:=a0.1-r0
+--R 
+--R
+--R                                +----+
+--R                                |   2             x     +-+
+--R        (log(b x + a) - log(x))\|c x   + x log(-------)\|c
+--R                                               b x + a
+--R   (4)  ---------------------------------------------------
+--R                                a x
+--R                                                    Type: Expression(Integer)
+--E 874
+
+--S 875 of 1008
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R              +----+
+--R          +-+ |   2
+--R         \|c \|c x   - c x
+--R   (5)  -------------------
+--R                     +----+
+--R            2        |   2
+--R        (b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 875
+
+--S 876 of 1008
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+ +-+                            +----+
+--R           +---+      a\|- c \|c                             |   2
+--R        2x\|- c atan(------------) + (log(b x + a) - log(x))\|c x
+--R                     2b c x + a c
+--R   (6)  -----------------------------------------------------------
+--R                                    a x
+--R                                                    Type: Expression(Integer)
+--E 876
+
+--S 877 of 1008
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R              +----+
+--R          +-+ |   2
+--R         \|c \|c x   - c x
+--R   (7)  -------------------
+--R                     +----+
+--R            2        |   2
+--R        (b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 877
+
+)clear all
+
+--S 878 of 1008
+t0:=sqrt(c*x^2)/(x^3*(a+b*x))
+--R 
+--R
+--R           +----+
+--R           |   2
+--R          \|c x
+--R   (1)  -----------
+--R           4      3
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 878
+
+--S 879 of 1008
+r0:=-sqrt(c*x^2)/(a*x^2)-b*log(x)*sqrt(c*x^2)/(a^2*x)+b*log(a+b*x)*_
+   sqrt(c*x^2)/(a^2*x)
+--R 
+--R
+--R                                            +----+
+--R                                            |   2
+--R        (b x log(b x + a) - b x log(x) - a)\|c x
+--R   (2)  ------------------------------------------
+--R                            2 2
+--R                           a x
+--R                                                    Type: Expression(Integer)
+--E 879
+
+--S 880 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 b x + a       +-+
+--R        (b x log(-------) - a)\|c
+--R                    x
+--R   (3)  --------------------------
+--R                     2
+--R                    a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 880
+
+--S 881 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +----+
+--R                                         |   2        2    b x + a         +-+
+--R   (- b x log(b x + a) + b x log(x) + a)\|c x   + (b x log(-------) - a x)\|c
+--R                                                              x
+--R   ---------------------------------------------------------------------------
+--R                                        2 2
+--R                                       a x
+--R                                                    Type: Expression(Integer)
+--E 881
+
+--S 882 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2
+--R          \|c \|c x   - c x
+--R   (5)  --------------------
+--R                      +----+
+--R            3      2  |   2
+--R        (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 882
+
+)clear all
+
+--S 883 of 1008
+t0:=sqrt(c*x^2)/(x^4*(a+b*x))
+--R 
+--R
+--R           +----+
+--R           |   2
+--R          \|c x
+--R   (1)  -----------
+--R           5      4
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 883
+
+--S 884 of 1008
+r0:=-1/2*sqrt(c*x^2)/(a*x^3)+b*sqrt(c*x^2)/(a^2*x^2)+b^2*log(x)*_
+   sqrt(c*x^2)/(a^3*x)-b^2*log(a+b*x)*sqrt(c*x^2)/(a^3*x)
+--R 
+--R
+--R                                                          +----+
+--R             2 2                 2 2                   2  |   2
+--R        (- 2b x log(b x + a) + 2b x log(x) + 2a b x - a )\|c x
+--R   (2)  --------------------------------------------------------
+--R                                    3 3
+--R                                  2a x
+--R                                                    Type: Expression(Integer)
+--E 884
+
+--S 885 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2       x                 2  +-+
+--R        (2b x log(-------) + 2a b x - a )\|c
+--R                  b x + a
+--R   (3)  -------------------------------------
+--R                          3 2
+--R                        2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 885
+
+--S 886 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                       +----+
+--R          2 2                 2 2                   2  |   2
+--R       (2b x log(b x + a) - 2b x log(x) - 2a b x + a )\|c x
+--R     + 
+--R          2 3       x             2    2   +-+
+--R       (2b x log(-------) + 2a b x  - a x)\|c
+--R                 b x + a
+--R  /
+--R       3 3
+--R     2a x
+--R                                                    Type: Expression(Integer)
+--E 886
+
+--S 887 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2
+--R          \|c \|c x   - c x
+--R   (5)  --------------------
+--R                      +----+
+--R            4      3  |   2
+--R        (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 887
+
+)clear all
+
+--S 888 of 1008
+t0:=x*(c*x^2)^(3/2)/(a+b*x)
+--R 
+--R
+--R             +----+
+--R           3 |   2
+--R        c x \|c x
+--R   (1)  -----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 888
+
+--S 889 of 1008
+r0:=-a^3*c*sqrt(c*x^2)/b^4+1/2*a^2*c*x*sqrt(c*x^2)/b^3-_
+   1/3*a*c*x^2*sqrt(c*x^2)/b^2+1/4*c*x^3*sqrt(c*x^2)/b+_
+   a^4*c*log(a+b*x)*sqrt(c*x^2)/(b^5*x)
+--R 
+--R
+--R   (2)
+--R                                                                      +----+
+--R       4                   4   4       3   3     2 2   2      3       |   2
+--R   (12a c log(b x + a) + 3b c x  - 4a b c x  + 6a b c x  - 12a b c x)\|c x
+--R   -------------------------------------------------------------------------
+--R                                        5
+--R                                     12b x
+--R                                                    Type: Expression(Integer)
+--E 889
+
+--S 890 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4                   4   4       3   3     2 2   2      3       +-+
+--R        (12a c log(b x + a) + 3b c x  - 4a b c x  + 6a b c x  - 12a b c x)\|c
+--R   (3)  ----------------------------------------------------------------------
+--R                                            5
+--R                                         12b
+--R                                         Type: Union(Expression(Integer),...)
+--E 890
+
+--S 891 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               4                   4   4       3   3     2 2   2      3
+--R         (- 12a c log(b x + a) - 3b c x  + 4a b c x  - 6a b c x  + 12a b c x)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R         4                     4   5       3   4     2 2   3      3     2  +-+
+--R     (12a c x log(b x + a) + 3b c x  - 4a b c x  + 6a b c x  - 12a b c x )\|c
+--R  /
+--R        5
+--R     12b x
+--R                                                    Type: Expression(Integer)
+--E 891
+
+--S 892 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R           4 +-+ |   2     2 5
+--R        c x \|c \|c x   - c x
+--R   (5)  ----------------------
+--R                     +----+
+--R                     |   2
+--R           (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 892
+
+)clear all
+
+--S 893 of 1008
+t0:=(c*x^2)^(3/2)/(a+b*x)
+--R 
+--R
+--R             +----+
+--R           2 |   2
+--R        c x \|c x
+--R   (1)  -----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 893
+
+--S 894 of 1008
+r0:=a^2*c*sqrt(c*x^2)/b^3-1/2*a*c*x*sqrt(c*x^2)/b^2+1/3*c*x^2*_
+   sqrt(c*x^2)/b-a^3*c*log(a+b*x)*sqrt(c*x^2)/(b^4*x)
+--R 
+--R
+--R                                                               +----+
+--R             3                   3   3       2   2     2       |   2
+--R        (- 6a c log(b x + a) + 2b c x  - 3a b c x  + 6a b c x)\|c x
+--R   (2)  -------------------------------------------------------------
+--R                                       4
+--R                                     6b x
+--R                                                    Type: Expression(Integer)
+--E 894
+
+--S 895 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3                   3   3       2   2     2       +-+
+--R        (- 6a c log(b x + a) + 2b c x  - 3a b c x  + 6a b c x)\|c
+--R   (3)  ----------------------------------------------------------
+--R                                      4
+--R                                    6b
+--R                                         Type: Union(Expression(Integer),...)
+--E 895
+
+--S 896 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                            +----+
+--R          3                   3   3       2   2     2       |   2
+--R       (6a c log(b x + a) - 2b c x  + 3a b c x  - 6a b c x)\|c x
+--R     + 
+--R            3                     3   4       2   3     2     2  +-+
+--R       (- 6a c x log(b x + a) + 2b c x  - 3a b c x  + 6a b c x )\|c
+--R  /
+--R       4
+--R     6b x
+--R                                                    Type: Expression(Integer)
+--E 896
+
+--S 897 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R           3 +-+ |   2     2 4
+--R        c x \|c \|c x   - c x
+--R   (5)  ----------------------
+--R                     +----+
+--R                     |   2
+--R           (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 897
+
+)clear all
+
+--S 898 of 1008
+t0:=(c*x^2)^(3/2)/(x*(a+b*x))
+--R 
+--R
+--R            +----+
+--R            |   2
+--R        c x\|c x
+--R   (1)  ----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 898
+
+--S 899 of 1008
+r0:=-a*c*sqrt(c*x^2)/b^2+1/2*c*x*sqrt(c*x^2)/b+a^2*c*log(a+b*x)*_
+   sqrt(c*x^2)/(b^3*x)
+--R 
+--R
+--R                                                +----+
+--R           2                  2   2             |   2
+--R        (2a c log(b x + a) + b c x  - 2a b c x)\|c x
+--R   (2)  ----------------------------------------------
+--R                               3
+--R                             2b x
+--R                                                    Type: Expression(Integer)
+--E 899
+
+--S 900 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2                  2   2             +-+
+--R        (2a c log(b x + a) + b c x  - 2a b c x)\|c
+--R   (3)  -------------------------------------------
+--R                              3
+--R                            2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 900
+
+--S 901 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +----+
+--R            2                  2   2             |   2
+--R       (- 2a c log(b x + a) - b c x  + 2a b c x)\|c x
+--R     + 
+--R          2                    2   3           2  +-+
+--R       (2a c x log(b x + a) + b c x  - 2a b c x )\|c
+--R  /
+--R       3
+--R     2b x
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R           2 +-+ |   2     2 3
+--R        c x \|c \|c x   - c x
+--R   (5)  ----------------------
+--R                     +----+
+--R                     |   2
+--R           (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 902
+
+)clear all
+
+--S 903 of 1008
+t0:=(c*x^2)^(3/2)/(x^2*(a+b*x))
+--R 
+--R
+--R          +----+
+--R          |   2
+--R        c\|c x
+--R   (1)  --------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 903
+
+--S 904 of 1008
+r0:=c*sqrt(c*x^2)/b-a*c*log(a+b*x)*sqrt(c*x^2)/(b^2*x)
+--R 
+--R
+--R                                     +----+
+--R                                     |   2
+--R        (- a c log(b x + a) + b c x)\|c x
+--R   (2)  -----------------------------------
+--R                         2
+--R                        b x
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                     +-+
+--R        (- a c log(b x + a) + b c x)\|c
+--R   (3)  --------------------------------
+--R                        2
+--R                       b
+--R                                         Type: Union(Expression(Integer),...)
+--E 905
+
+--S 906 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              +----+
+--R                              |   2                                 2  +-+
+--R   (a c log(b x + a) - b c x)\|c x   + (- a c x log(b x + a) + b c x )\|c
+--R   -----------------------------------------------------------------------
+--R                                      2
+--R                                     b x
+--R                                                    Type: Expression(Integer)
+--E 906
+
+--S 907 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R            +-+ |   2     2 2
+--R        c x\|c \|c x   - c x
+--R   (5)  ---------------------
+--R                     +----+
+--R                     |   2
+--R           (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 907
+
+)clear all
+
+--S 908 of 1008
+t0:=(c*x^2)^(3/2)/(x^3*(a+b*x))
+--R 
+--R
+--R           +----+
+--R           |   2
+--R         c\|c x
+--R   (1)  ----------
+--R           2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 908
+
+--S 909 of 1008
+r0:=c*log(a+b*x)*sqrt(c*x^2)/(b*x)
+--R 
+--R
+--R                       +----+
+--R                       |   2
+--R        c log(b x + a)\|c x
+--R   (2)  ---------------------
+--R                 b x
+--R                                                    Type: Expression(Integer)
+--E 909
+
+--S 910 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       +-+
+--R        c log(b x + a)\|c
+--R   (3)  ------------------
+--R                 b
+--R                                         Type: Union(Expression(Integer),...)
+--E 910
+
+--S 911 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                         +----+
+--R                         |   2                     +-+
+--R        - c log(b x + a)\|c x   + c x log(b x + a)\|c
+--R   (4)  ----------------------------------------------
+--R                              b x
+--R                                                    Type: Expression(Integer)
+--E 911
+
+--S 912 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +----+
+--R          +-+ |   2     2
+--R        c\|c \|c x   - c x
+--R   (5)  ------------------
+--R                   +----+
+--R                   |   2
+--R         (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 912
+
+)clear all
+
+--S 913 of 1008
+t0:=(c*x^2)^(3/2)/(x^4*(a+b*x))
+--R 
+--R
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R   (1)  -----------
+--R           3      2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 913
+
+--S 914 of 1008
+r0:=c*log(x)*sqrt(c*x^2)/(a*x)-c*log(a+b*x)*sqrt(c*x^2)/(a*x)
+--R 
+--R
+--R                                      +----+
+--R                                      |   2
+--R        (- c log(b x + a) + c log(x))\|c x
+--R   (2)  ------------------------------------
+--R                         a x
+--R                                                    Type: Expression(Integer)
+--E 914
+
+--S 915 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                            +---+ +-+
+--R                  x     +-+    +---+      a\|- c \|c
+--R         c log(-------)\|c  2c\|- c atan(------------)
+--R               b x + a                   2b c x + a c
+--R   (3)  [------------------,--------------------------]
+--R                  a                      a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 915
+
+--S 916 of 1008
+m0a:=a0.1-r0
+--R 
+--R
+--R                                    +----+
+--R                                    |   2               x     +-+
+--R        (c log(b x + a) - c log(x))\|c x   + c x log(-------)\|c
+--R                                                     b x + a
+--R   (4)  ---------------------------------------------------------
+--R                                   a x
+--R                                                    Type: Expression(Integer)
+--E 916
+
+--S 917 of 1008
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2     2
+--R         c\|c \|c x   - c x
+--R   (5)  -------------------
+--R                     +----+
+--R            2        |   2
+--R        (b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 917
+
+--S 918 of 1008
+m0b:=a0.2-r0
+--R 
+--R
+--R                          +---+ +-+                                +----+
+--R             +---+      a\|- c \|c                                 |   2
+--R        2c x\|- c atan(------------) + (c log(b x + a) - c log(x))\|c x
+--R                       2b c x + a c
+--R   (6)  -----------------------------------------------------------------
+--R                                       a x
+--R                                                    Type: Expression(Integer)
+--E 918
+
+--S 919 of 1008
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2     2
+--R         c\|c \|c x   - c x
+--R   (7)  -------------------
+--R                     +----+
+--R            2        |   2
+--R        (b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 919
+
+)clear all
+
+--S 920 of 1008
+t0:=(c*x^2)^(3/2)/(x^5*(a+b*x))
+--R 
+--R
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R   (1)  -----------
+--R           4      3
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 920
+
+--S 921 of 1008
+r0:=-c*sqrt(c*x^2)/(a*x^2)-b*c*log(x)*sqrt(c*x^2)/(a^2*x)+_
+   b*c*log(a+b*x)*sqrt(c*x^2)/(a^2*x)
+--R 
+--R
+--R                                                  +----+
+--R                                                  |   2
+--R        (b c x log(b x + a) - b c x log(x) - a c)\|c x
+--R   (2)  ------------------------------------------------
+--R                               2 2
+--R                              a x
+--R                                                    Type: Expression(Integer)
+--E 921
+
+--S 922 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   b x + a         +-+
+--R        (b c x log(-------) - a c)\|c
+--R                      x
+--R   (3)  ------------------------------
+--R                       2
+--R                      a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 922
+
+--S 923 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                   +----+
+--R                                                   |   2
+--R       (- b c x log(b x + a) + b c x log(x) + a c)\|c x
+--R     + 
+--R             2    b x + a           +-+
+--R       (b c x log(-------) - a c x)\|c
+--R                     x
+--R  /
+--R      2 2
+--R     a x
+--R                                                    Type: Expression(Integer)
+--E 923
+
+--S 924 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2     2
+--R         c\|c \|c x   - c x
+--R   (5)  --------------------
+--R                      +----+
+--R            3      2  |   2
+--R        (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 924
+
+)clear all
+
+--S 925 of 1008
+t0:=(c*x^2)^(3/2)/(x^6*(a+b*x))
+--R 
+--R
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R   (1)  -----------
+--R           5      4
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 925
+
+--S 926 of 1008
+r0:=-1/2*c*sqrt(c*x^2)/(a*x^3)+b*c*sqrt(c*x^2)/(a^2*x^2)+_
+   b^2*c*log(x)*sqrt(c*x^2)/(a^3*x)-b^2*c*log(a+b*x)*sqrt(c*x^2)/(a^3*x)
+--R 
+--R
+--R                                                                 +----+
+--R             2   2                 2   2                     2   |   2
+--R        (- 2b c x log(b x + a) + 2b c x log(x) + 2a b c x - a c)\|c x
+--R   (2)  ---------------------------------------------------------------
+--R                                       3 3
+--R                                     2a x
+--R                                                    Type: Expression(Integer)
+--E 926
+
+--S 927 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2   2       x                   2   +-+
+--R        (2b c x log(-------) + 2a b c x - a c)\|c
+--R                    b x + a
+--R   (3)  ------------------------------------------
+--R                             3 2
+--R                           2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 927
+
+--S 928 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                              +----+
+--R          2   2                 2   2                     2   |   2
+--R       (2b c x log(b x + a) - 2b c x log(x) - 2a b c x + a c)\|c x
+--R     + 
+--R          2   3       x               2    2     +-+
+--R       (2b c x log(-------) + 2a b c x  - a c x)\|c
+--R                   b x + a
+--R  /
+--R       3 3
+--R     2a x
+--R                                                    Type: Expression(Integer)
+--E 928
+
+--S 929 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2     2
+--R         c\|c \|c x   - c x
+--R   (5)  --------------------
+--R                      +----+
+--R            4      3  |   2
+--R        (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 929
+
+)clear all
+
+--S 930 of 1008
+t0:=(c*x^2)^(3/2)/(x^7*(a+b*x))
+--R 
+--R
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R   (1)  -----------
+--R           6      5
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 930
+
+--S 931 of 1008
+r0:=-1/3*c*sqrt(c*x^2)/(a*x^4)+1/2*b*c*sqrt(c*x^2)/(a^2*x^3)-_
+   b^2*c*sqrt(c*x^2)/(a^3*x^2)-b^3*c*log(x)*sqrt(c*x^2)/(a^4*x)+_
+   b^3*c*log(a+b*x)*sqrt(c*x^2)/(a^4*x)
+--R 
+--R
+--R   (2)
+--R                                                                       +----+
+--R      3   3                 3   3             2   2     2          3   |   2
+--R   (6b c x log(b x + a) - 6b c x log(x) - 6a b c x  + 3a b c x - 2a c)\|c x
+--R   --------------------------------------------------------------------------
+--R                                        4 4
+--R                                      6a x
+--R                                                    Type: Expression(Integer)
+--E 931
+
+--S 932 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3   3    b x + a        2   2     2          3   +-+
+--R        (6b c x log(-------) - 6a b c x  + 3a b c x - 2a c)\|c
+--R                       x
+--R   (3)  -------------------------------------------------------
+--R                                   4 3
+--R                                 6a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 932
+
+--S 933 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3   3                 3   3             2   2     2          3
+--R         (- 6b c x log(b x + a) + 6b c x log(x) + 6a b c x  - 3a b c x + 2a c)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R          3   4    b x + a        2   3     2     2     3     +-+
+--R       (6b c x log(-------) - 6a b c x  + 3a b c x  - 2a c x)\|c
+--R                      x
+--R  /
+--R       4 4
+--R     6a x
+--R                                                    Type: Expression(Integer)
+--E 933
+
+--S 934 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2     2
+--R         c\|c \|c x   - c x
+--R   (5)  --------------------
+--R                      +----+
+--R            5      4  |   2
+--R        (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 934
+
+)clear all
+
+--S 935 of 1008
+t0:=(c*x^2)^(5/2)/(a+b*x)
+--R 
+--R
+--R             +----+
+--R         2 4 |   2
+--R        c x \|c x
+--R   (1)  -----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 935
+
+--S 936 of 1008
+r0:=a^4*c^2*sqrt(c*x^2)/b^5-1/2*a^3*c^2*x*sqrt(c*x^2)/b^4+_
+   1/3*a^2*c^2*x^2*sqrt(c*x^2)/b^3-1/4*a*c^2*x^3*sqrt(c*x^2)/b^2+_
+   1/5*c^2*x^4*sqrt(c*x^2)/b-a^5*c^2*log(a+b*x)*sqrt(c*x^2)/(b^6*x)
+--R 
+--R
+--R   (2)
+--R              5 2                  5 2 5        4 2 4      2 3 2 3      3 2 2 2
+--R         - 60a c log(b x + a) + 12b c x  - 15a b c x  + 20a b c x  - 30a b c x
+--R       + 
+--R            4   2
+--R         60a b c x
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R        6
+--R     60b x
+--R                                                    Type: Expression(Integer)
+--E 936
+
+--S 937 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              5 2                  5 2 5        4 2 4      2 3 2 3      3 2 2 2
+--R         - 60a c log(b x + a) + 12b c x  - 15a b c x  + 20a b c x  - 30a b c x
+--R       + 
+--R            4   2
+--R         60a b c x
+--R    *
+--R        +-+
+--R       \|c
+--R  /
+--R        6
+--R     60b
+--R                                         Type: Union(Expression(Integer),...)
+--E 937
+
+--S 938 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 2                  5 2 5        4 2 4      2 3 2 3      3 2 2 2
+--R           60a c log(b x + a) - 12b c x  + 15a b c x  - 20a b c x  + 30a b c x
+--R         + 
+--R                4   2
+--R           - 60a b c x
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R                5 2                    5 2 6        4 2 5      2 3 2 4
+--R           - 60a c x log(b x + a) + 12b c x  - 15a b c x  + 20a b c x
+--R         + 
+--R                3 2 2 3      4   2 2
+--R           - 30a b c x  + 60a b c x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R        6
+--R     60b x
+--R                                                    Type: Expression(Integer)
+--E 938
+
+--S 939 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R         2 5 +-+ |   2     3 6
+--R        c x \|c \|c x   - c x
+--R   (5)  ----------------------
+--R                     +----+
+--R                     |   2
+--R           (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 939
+
+)clear all
+
+--S 940 of 1008
+t0:=(c*x^2)^(5/2)/(x*(a+b*x))
+--R 
+--R
+--R             +----+
+--R         2 3 |   2
+--R        c x \|c x
+--R   (1)  -----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 940
+
+--S 941 of 1008
+r0:=-a^3*c^2*sqrt(c*x^2)/b^4+1/2*a^2*c^2*x*sqrt(c*x^2)/b^3-_
+   1/3*a*c^2*x^2*sqrt(c*x^2)/b^2+1/4*c^2*x^3*sqrt(c*x^2)/b+_
+   a^4*c^2*log(a+b*x)*sqrt(c*x^2)/(b^5*x)
+--R 
+--R
+--R   (2)
+--R                                                                      +----+
+--R       4 2                 4 2 4       3 2 3     2 2 2 2      3   2   |   2
+--R   (12a c log(b x + a) + 3b c x  - 4a b c x  + 6a b c x  - 12a b c x)\|c x
+--R   -------------------------------------------------------------------------
+--R                                        5
+--R                                     12b x
+--R                                                    Type: Expression(Integer)
+--E 941
+
+--S 942 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4 2                 4 2 4       3 2 3     2 2 2 2      3   2   +-+
+--R        (12a c log(b x + a) + 3b c x  - 4a b c x  + 6a b c x  - 12a b c x)\|c
+--R   (3)  ----------------------------------------------------------------------
+--R                                            5
+--R                                         12b
+--R                                         Type: Union(Expression(Integer),...)
+--E 942
+
+--S 943 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               4 2                 4 2 4       3 2 3     2 2 2 2      3   2
+--R         (- 12a c log(b x + a) - 3b c x  + 4a b c x  - 6a b c x  + 12a b c x)
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R         4 2                   4 2 5       3 2 4     2 2 2 3      3   2 2  +-+
+--R     (12a c x log(b x + a) + 3b c x  - 4a b c x  + 6a b c x  - 12a b c x )\|c
+--R  /
+--R        5
+--R     12b x
+--R                                                    Type: Expression(Integer)
+--E 943
+
+--S 944 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R         2 4 +-+ |   2     3 5
+--R        c x \|c \|c x   - c x
+--R   (5)  ----------------------
+--R                     +----+
+--R                     |   2
+--R           (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 944
+
+)clear all
+
+--S 945 of 1008
+t0:=(c*x^2)^(5/2)/(x^2*(a+b*x))
+--R 
+--R
+--R             +----+
+--R         2 2 |   2
+--R        c x \|c x
+--R   (1)  -----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 945
+
+--S 946 of 1008
+r0:=a^2*c^2*sqrt(c*x^2)/b^3-1/2*a*c^2*x*sqrt(c*x^2)/b^2+_
+   1/3*c^2*x^2*sqrt(c*x^2)/b-a^3*c^2*log(a+b*x)*sqrt(c*x^2)/(b^4*x)
+--R 
+--R
+--R                                                               +----+
+--R             3 2                 3 2 3       2 2 2     2   2   |   2
+--R        (- 6a c log(b x + a) + 2b c x  - 3a b c x  + 6a b c x)\|c x
+--R   (2)  -------------------------------------------------------------
+--R                                       4
+--R                                     6b x
+--R                                                    Type: Expression(Integer)
+--E 946
+
+--S 947 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 2                 3 2 3       2 2 2     2   2   +-+
+--R        (- 6a c log(b x + a) + 2b c x  - 3a b c x  + 6a b c x)\|c
+--R   (3)  ----------------------------------------------------------
+--R                                      4
+--R                                    6b
+--R                                         Type: Union(Expression(Integer),...)
+--E 947
+
+--S 948 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                            +----+
+--R          3 2                 3 2 3       2 2 2     2   2   |   2
+--R       (6a c log(b x + a) - 2b c x  + 3a b c x  - 6a b c x)\|c x
+--R     + 
+--R            3 2                   3 2 4       2 2 3     2   2 2  +-+
+--R       (- 6a c x log(b x + a) + 2b c x  - 3a b c x  + 6a b c x )\|c
+--R  /
+--R       4
+--R     6b x
+--R                                                    Type: Expression(Integer)
+--E 948
+
+--S 949 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R         2 3 +-+ |   2     3 4
+--R        c x \|c \|c x   - c x
+--R   (5)  ----------------------
+--R                     +----+
+--R                     |   2
+--R           (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 949
+
+)clear all
+
+--S 950 of 1008
+t0:=(c*x^2)^(5/2)/(x^3*(a+b*x))
+--R 
+--R
+--R            +----+
+--R         2  |   2
+--R        c x\|c x
+--R   (1)  ----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 950
+
+--S 951 of 1008
+r0:=-a*c^2*sqrt(c*x^2)/b^2+1/2*c^2*x*sqrt(c*x^2)/b+_
+   a^2*c^2*log(a+b*x)*sqrt(c*x^2)/(b^3*x)
+--R 
+--R
+--R                                                +----+
+--R           2 2                2 2 2         2   |   2
+--R        (2a c log(b x + a) + b c x  - 2a b c x)\|c x
+--R   (2)  ----------------------------------------------
+--R                               3
+--R                             2b x
+--R                                                    Type: Expression(Integer)
+--E 951
+
+--S 952 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2                2 2 2         2   +-+
+--R        (2a c log(b x + a) + b c x  - 2a b c x)\|c
+--R   (3)  -------------------------------------------
+--R                              3
+--R                            2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 952
+
+--S 953 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +----+
+--R            2 2                2 2 2         2   |   2
+--R       (- 2a c log(b x + a) - b c x  + 2a b c x)\|c x
+--R     + 
+--R          2 2                  2 2 3         2 2  +-+
+--R       (2a c x log(b x + a) + b c x  - 2a b c x )\|c
+--R  /
+--R       3
+--R     2b x
+--R                                                    Type: Expression(Integer)
+--E 953
+
+--S 954 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R         2 2 +-+ |   2     3 3
+--R        c x \|c \|c x   - c x
+--R   (5)  ----------------------
+--R                     +----+
+--R                     |   2
+--R           (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 954
+
+)clear all
+
+--S 955 of 1008
+t0:=(c*x^2)^(5/2)/(x^4*(a+b*x))
+--R 
+--R
+--R           +----+
+--R         2 |   2
+--R        c \|c x
+--R   (1)  ---------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 955
+
+--S 956 of 1008
+r0:=c^2*sqrt(c*x^2)/b-a*c^2*log(a+b*x)*sqrt(c*x^2)/(b^2*x)
+--R 
+--R
+--R                                     +----+
+--R              2                  2   |   2
+--R        (- a c log(b x + a) + b c x)\|c x
+--R   (2)  -----------------------------------
+--R                         2
+--R                        b x
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                  2   +-+
+--R        (- a c log(b x + a) + b c x)\|c
+--R   (3)  --------------------------------
+--R                        2
+--R                       b
+--R                                         Type: Union(Expression(Integer),...)
+--E 957
+
+--S 958 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              +----+
+--R       2                  2   |   2          2                    2 2  +-+
+--R   (a c log(b x + a) - b c x)\|c x   + (- a c x log(b x + a) + b c x )\|c
+--R   -----------------------------------------------------------------------
+--R                                      2
+--R                                     b x
+--R                                                    Type: Expression(Integer)
+--E 958
+
+--S 959 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R         2  +-+ |   2     3 2
+--R        c x\|c \|c x   - c x
+--R   (5)  ---------------------
+--R                     +----+
+--R                     |   2
+--R           (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 959
+
+)clear all
+
+--S 960 of 1008
+t0:=(c*x^2)^(5/2)/(x^5*(a+b*x))
+--R 
+--R
+--R            +----+
+--R          2 |   2
+--R         c \|c x
+--R   (1)  ----------
+--R           2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 960
+
+--S 961 of 1008
+r0:=c^2*log(a+b*x)*sqrt(c*x^2)/(b*x)
+--R 
+--R
+--R                       +----+
+--R         2             |   2
+--R        c log(b x + a)\|c x
+--R   (2)  ---------------------
+--R                 b x
+--R                                                    Type: Expression(Integer)
+--E 961
+
+--S 962 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2             +-+
+--R        c log(b x + a)\|c
+--R   (3)  ------------------
+--R                 b
+--R                                         Type: Union(Expression(Integer),...)
+--E 962
+
+--S 963 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                         +----+
+--R           2             |   2     2               +-+
+--R        - c log(b x + a)\|c x   + c x log(b x + a)\|c
+--R   (4)  ----------------------------------------------
+--R                              b x
+--R                                                    Type: Expression(Integer)
+--E 963
+
+--S 964 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R         2 +-+ |   2     3
+--R        c \|c \|c x   - c x
+--R   (5)  -------------------
+--R                    +----+
+--R                    |   2
+--R          (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 964
+
+)clear all
+
+--S 965 of 1008
+t0:=(c*x^2)^(5/2)/(x^6*(a+b*x))
+--R 
+--R
+--R            +----+
+--R          2 |   2
+--R         c \|c x
+--R   (1)  -----------
+--R           3      2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 965
+
+--S 966 of 1008
+r0:=c^2*log(x)*sqrt(c*x^2)/(a*x)-c^2*log(a+b*x)*sqrt(c*x^2)/(a*x)
+--R 
+--R
+--R                                      +----+
+--R            2                2        |   2
+--R        (- c log(b x + a) + c log(x))\|c x
+--R   (2)  ------------------------------------
+--R                         a x
+--R                                                    Type: Expression(Integer)
+--E 966
+
+--S 967 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                             +---+ +-+
+--R          2       x     +-+   2 +---+      a\|- c \|c
+--R         c log(-------)\|c  2c \|- c atan(------------)
+--R               b x + a                    2b c x + a c
+--R   (3)  [------------------,---------------------------]
+--R                  a                      a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 967
+
+--S 968 of 1008
+m0a:=a0.1-r0
+--R 
+--R
+--R                                    +----+
+--R          2                2        |   2     2         x     +-+
+--R        (c log(b x + a) - c log(x))\|c x   + c x log(-------)\|c
+--R                                                     b x + a
+--R   (4)  ---------------------------------------------------------
+--R                                   a x
+--R                                                    Type: Expression(Integer)
+--E 968
+
+--S 969 of 1008
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R               +----+
+--R         2 +-+ |   2     3
+--R        c \|c \|c x   - c x
+--R   (5)  -------------------
+--R                     +----+
+--R            2        |   2
+--R        (b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 969
+
+--S 970 of 1008
+m0b:=a0.2-r0
+--R 
+--R
+--R                          +---+ +-+                                +----+
+--R          2  +---+      a\|- c \|c       2                2        |   2
+--R        2c x\|- c atan(------------) + (c log(b x + a) - c log(x))\|c x
+--R                       2b c x + a c
+--R   (6)  -----------------------------------------------------------------
+--R                                       a x
+--R                                                    Type: Expression(Integer)
+--E 970
+
+--S 971 of 1008
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R               +----+
+--R         2 +-+ |   2     3
+--R        c \|c \|c x   - c x
+--R   (7)  -------------------
+--R                     +----+
+--R            2        |   2
+--R        (b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 971
+
+)clear all
+
+--S 972 of 1008
+t0:=(c*x^2)^(5/2)/(x^7*(a+b*x))
+--R 
+--R
+--R            +----+
+--R          2 |   2
+--R         c \|c x
+--R   (1)  -----------
+--R           4      3
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 972
+
+--S 973 of 1008
+r0:=-c^2*sqrt(c*x^2)/(a*x^2)-b*c^2*log(x)*sqrt(c*x^2)/(a^2*x)+_
+   b*c^2*log(a+b*x)*sqrt(c*x^2)/(a^2*x)
+--R 
+--R
+--R                                                   +----+
+--R            2                    2              2  |   2
+--R        (b c x log(b x + a) - b c x log(x) - a c )\|c x
+--R   (2)  -------------------------------------------------
+--R                                2 2
+--R                               a x
+--R                                                    Type: Expression(Integer)
+--E 973
+
+--S 974 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2      b x + a       2  +-+
+--R        (b c x log(-------) - a c )\|c
+--R                      x
+--R   (3)  -------------------------------
+--R                       2
+--R                      a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 974
+
+--S 975 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +----+
+--R             2                    2              2  |   2
+--R       (- b c x log(b x + a) + b c x log(x) + a c )\|c x
+--R     + 
+--R           2 2    b x + a       2   +-+
+--R       (b c x log(-------) - a c x)\|c
+--R                     x
+--R  /
+--R      2 2
+--R     a x
+--R                                                    Type: Expression(Integer)
+--E 975
+
+--S 976 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R          2 +-+ |   2     3
+--R         c \|c \|c x   - c x
+--R   (5)  --------------------
+--R                      +----+
+--R            3      2  |   2
+--R        (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 976
+
+)clear all
+
+--S 977 of 1008
+t0:=x^4/((a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 1008
+r0:=a^2*x^2/(b^3*sqrt(c*x^2))-1/2*a*x^3/(b^2*sqrt(c*x^2))+_
+   1/3*x^4/(b*sqrt(c*x^2))-a^3*x*log(a+b*x)/(b^4*sqrt(c*x^2))
+--R 
+--R
+--R            3                   3 4       2 3     2   2
+--R        - 6a x log(b x + a) + 2b x  - 3a b x  + 6a b x
+--R   (2)  -----------------------------------------------
+--R                               +----+
+--R                             4 |   2
+--R                           6b \|c x
+--R                                                    Type: Expression(Integer)
+--E 978
+
+--S 979 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3                 3 3       2 2     2
+--R        - 6a log(b x + a) + 2b x  - 3a b x  + 6a b x
+--R   (3)  --------------------------------------------
+--R                             4 +-+
+--R                           6b \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 979
+
+--S 980 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +----+
+--R            3                 3 3       2 2     2     |   2
+--R       (- 6a log(b x + a) + 2b x  - 3a b x  + 6a b x)\|c x
+--R     + 
+--R          3                   3 4       2 3     2   2  +-+
+--R       (6a x log(b x + a) - 2b x  + 3a b x  - 6a b x )\|c
+--R  /
+--R             +----+
+--R       4 +-+ |   2
+--R     6b \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 980
+
+--S 981 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R         3 +-+ |   2       4
+--R        x \|c \|c x   - c x
+--R   (5)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 981
+
+)clear all
+
+--S 982 of 1008
+t0:=x^3/((a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 982
+
+--S 983 of 1008
+r0:=-a*x^2/(b^2*sqrt(c*x^2))+1/2*x^3/(b*sqrt(c*x^2))+_
+   a^2*x*log(a+b*x)/(b^3*sqrt(c*x^2))
+--R 
+--R
+--R          2                  2 3         2
+--R        2a x log(b x + a) + b x  - 2a b x
+--R   (2)  ----------------------------------
+--R                        +----+
+--R                      3 |   2
+--R                    2b \|c x
+--R                                                    Type: Expression(Integer)
+--E 983
+
+--S 984 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2                2 2
+--R        2a log(b x + a) + b x  - 2a b x
+--R   (3)  -------------------------------
+--R                      3 +-+
+--R                    2b \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 984
+
+--S 985 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +----+
+--R          2                2 2           |   2
+--R       (2a log(b x + a) + b x  - 2a b x)\|c x
+--R     + 
+--R            2                  2 3         2  +-+
+--R       (- 2a x log(b x + a) - b x  + 2a b x )\|c
+--R  /
+--R             +----+
+--R       3 +-+ |   2
+--R     2b \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 985
+
+--S 986 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R         2 +-+ |   2       3
+--R        x \|c \|c x   - c x
+--R   (5)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 986
+
+)clear all
+
+--S 987 of 1008
+t0:=x^2/((a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 987
+
+--S 988 of 1008
+r0:=x^2/(b*sqrt(c*x^2))-a*x*log(a+b*x)/(b^2*sqrt(c*x^2))
+--R 
+--R
+--R                                2
+--R        - a x log(b x + a) + b x
+--R   (2)  -------------------------
+--R                   +----+
+--R                 2 |   2
+--R                b \|c x
+--R                                                    Type: Expression(Integer)
+--E 988
+
+--S 989 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - a log(b x + a) + b x
+--R   (3)  ----------------------
+--R                 2 +-+
+--R                b \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 989
+
+--S 990 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                                 +----+
+--R                                 |   2                           2  +-+
+--R        (- a log(b x + a) + b x)\|c x   + (a x log(b x + a) - b x )\|c
+--R   (4)  ---------------------------------------------------------------
+--R                                        +----+
+--R                                  2 +-+ |   2
+--R                                 b \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 990
+
+--S 991 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2       2
+--R         x\|c \|c x   - c x
+--R   (5)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 991
+
+)clear all
+
+--S 992 of 1008
+t0:=x/((a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                x
+--R   (1)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 1008
+r0:=x*log(a+b*x)/(b*sqrt(c*x^2))
+--R 
+--R
+--R        x log(b x + a)
+--R   (2)  --------------
+--R             +----+
+--R             |   2
+--R           b\|c x
+--R                                                    Type: Expression(Integer)
+--E 993
+
+--S 994 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(b x + a)
+--R   (3)  ------------
+--R              +-+
+--R            b\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 994
+
+--S 995 of 1008
+m0:=a0-r0
+--R 
+--R
+--R                     +----+
+--R                     |   2                   +-+
+--R        log(b x + a)\|c x   - x log(b x + a)\|c
+--R   (4)  ----------------------------------------
+--R                            +----+
+--R                        +-+ |   2
+--R                      b\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 995
+
+--S 996 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2
+--R          \|c \|c x   - c x
+--R   (5)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 996
+
+)clear all
+
+--S 997 of 1008
+t0:=1/((a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 1008
+r0:=x*log(x)/(a*sqrt(c*x^2))-x*log(a+b*x)/(a*sqrt(c*x^2))
+--R 
+--R
+--R        - x log(b x + a) + x log(x)
+--R   (2)  ---------------------------
+--R                    +----+
+--R                    |   2
+--R                  a\|c x
+--R                                                    Type: Expression(Integer)
+--E 998
+
+--S 999 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                         +---+ +-+
+--R                x             (2b x + a)\|- c \|c
+--R         log(-------)   2atan(--------------------)
+--R             b x + a                   a c
+--R   (3)  [------------,- ---------------------------]
+--R               +-+                  +---+
+--R             a\|c                 a\|- c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 999
+
+--S 1000 of 1008
+m0a:=a0.1-r0
+--R 
+--R
+--R                     +----+
+--R               x     |   2                                +-+
+--R        log(-------)\|c x   + (x log(b x + a) - x log(x))\|c
+--R            b x + a
+--R   (4)  -----------------------------------------------------
+--R                                   +----+
+--R                               +-+ |   2
+--R                             a\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+--S 1001 of 1008
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R                +----+
+--R            +-+ |   2
+--R           \|c \|c x   - c x
+--R   (5)  -----------------------
+--R                         +----+
+--R              2          |   2
+--R        (b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 1001
+
+--S 1002 of 1008
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       +----+                +---+ +-+
+--R       |   2      (2b x + a)\|- c \|c                                 +---+
+--R   - 2\|c x  atan(--------------------) + (x log(b x + a) - x log(x))\|- c
+--R                           a c
+--R   ------------------------------------------------------------------------
+--R                                        +----+
+--R                                  +---+ |   2
+--R                                a\|- c \|c x
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+--S 1003 of 1008
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R                +----+
+--R            +-+ |   2
+--R           \|c \|c x   - c x
+--R   (7)  -----------------------
+--R                         +----+
+--R              2          |   2
+--R        (b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 1003
+
+)clear all
+
+--S 1004 of 1008
+t0:=1/(x*(a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R                     +----+
+--R            2        |   2
+--R        (b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 1004
+
+--S 1005 of 1008
+r0:=(-1)/(a*sqrt(c*x^2))-b*x*log(x)/(a^2*sqrt(c*x^2))+_
+   b*x*log(a+b*x)/(a^2*sqrt(c*x^2))
+--R 
+--R
+--R        b x log(b x + a) - b x log(x) - a
+--R   (2)  ---------------------------------
+--R                       +----+
+--R                     2 |   2
+--R                    a \|c x
+--R                                                    Type: Expression(Integer)
+--E 1005
+
+--S 1006 of 1008
+a0:=integrate(t0,x)
+--R 
+--R
+--R                b x + a
+--R        b x log(-------) - a
+--R                   x
+--R   (3)  --------------------
+--R                2  +-+
+--R               a x\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 1006
+
+--S 1007 of 1008
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +----+
+--R            b x + a       |   2          2                  2              +-+
+--R   (b x log(-------) - a)\|c x   + (- b x log(b x + a) + b x log(x) + a x)\|c
+--R               x
+--R   ---------------------------------------------------------------------------
+--R                                          +----+
+--R                                   2  +-+ |   2
+--R                                  a x\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 1007
+
+--S 1008 of 1008
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R             +-+ |   2
+--R            \|c \|c x   - c x
+--R   (5)  ------------------------
+--R                          +----+
+--R              3        2  |   2
+--R        (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 1008
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich22c.input.pamphlet b/src/input/rich22c.input.pamphlet
new file mode 100644
index 0000000..ab9ede0
--- /dev/null
+++ b/src/input/rich22c.input.pamphlet
@@ -0,0 +1,94228 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich22c.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Algebraic function problems.input
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich22c.output
+)spool rich22c.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1070
+t0:=1/(x^2*(a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                      +----+
+--R            3      2  |   2
+--R        (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1070
+r0:=b/(a^2*sqrt(c*x^2))+(-1/2)/(a*x*sqrt(c*x^2))+b^2*x*log(x)/(a^3*_
+   sqrt(c*x^2))-b^2*x*log(a+b*x)/(a^3*sqrt(c*x^2))
+--R 
+--R
+--R            2 2                 2 2                   2
+--R        - 2b x log(b x + a) + 2b x log(x) + 2a b x - a
+--R   (2)  -----------------------------------------------
+--R                               +----+
+--R                            3  |   2
+--R                          2a x\|c x
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 2       x                 2
+--R        2b x log(-------) + 2a b x - a
+--R                 b x + a
+--R   (3)  -------------------------------
+--R                     3 2 +-+
+--R                   2a x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +----+
+--R          2 2       x                 2  |   2
+--R       (2b x log(-------) + 2a b x - a )\|c x
+--R                 b x + a
+--R     + 
+--R          2 3                 2 3               2    2   +-+
+--R       (2b x log(b x + a) - 2b x log(x) - 2a b x  + a x)\|c
+--R  /
+--R               +----+
+--R       3 2 +-+ |   2
+--R     2a x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R             +-+ |   2
+--R            \|c \|c x   - c x
+--R   (5)  ------------------------
+--R                          +----+
+--R              4        3  |   2
+--R        (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 1070
+t0:=1/(x^3*(a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                      +----+
+--R            4      3  |   2
+--R        (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 1070
+r0:=-b^2/(a^3*sqrt(c*x^2))+(-1/3)/(a*x^2*sqrt(c*x^2))+_
+   1/2*b/(a^2*x*sqrt(c*x^2))-b^3*x*log(x)/(a^4*sqrt(c*x^2))+_
+   b^3*x*log(a+b*x)/(a^4*sqrt(c*x^2))
+--R 
+--R
+--R          3 3                 3 3             2 2     2        3
+--R        6b x log(b x + a) - 6b x log(x) - 6a b x  + 3a b x - 2a
+--R   (2)  --------------------------------------------------------
+--R                                    +----+
+--R                                4 2 |   2
+--R                              6a x \|c x
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3 3    b x + a        2 2     2        3
+--R        6b x log(-------) - 6a b x  + 3a b x - 2a
+--R                    x
+--R   (3)  ------------------------------------------
+--R                           4 3 +-+
+--R                         6a x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +----+
+--R          3 3    b x + a        2 2     2        3  |   2
+--R       (6b x log(-------) - 6a b x  + 3a b x - 2a )\|c x
+--R                    x
+--R     + 
+--R            3 4                 3 4             2 3     2   2     3   +-+
+--R       (- 6b x log(b x + a) + 6b x log(x) + 6a b x  - 3a b x  + 2a x)\|c
+--R  /
+--R               +----+
+--R       4 3 +-+ |   2
+--R     6a x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R             +-+ |   2
+--R            \|c \|c x   - c x
+--R   (5)  ------------------------
+--R                          +----+
+--R              5        4  |   2
+--R        (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 1070
+t0:=x^6/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                  4
+--R                 x
+--R   (1)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1070
+r0:=a^2*x^2/(b^3*c*sqrt(c*x^2))-1/2*a*x^3/(b^2*c*sqrt(c*x^2))+_
+   1/3*x^4/(b*c*sqrt(c*x^2))-a^3*x*log(a+b*x)/(b^4*c*sqrt(c*x^2))
+--R 
+--R
+--R            3                   3 4       2 3     2   2
+--R        - 6a x log(b x + a) + 2b x  - 3a b x  + 6a b x
+--R   (2)  -----------------------------------------------
+--R                               +----+
+--R                            4  |   2
+--R                          6b c\|c x
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3                 3 3       2 2     2
+--R        - 6a log(b x + a) + 2b x  - 3a b x  + 6a b x
+--R   (3)  --------------------------------------------
+--R                            4  +-+
+--R                          6b c\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 13
+
+--S 14 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +----+
+--R            3                 3 3       2 2     2     |   2
+--R       (- 6a log(b x + a) + 2b x  - 3a b x  + 6a b x)\|c x
+--R     + 
+--R          3                   3 4       2 3     2   2  +-+
+--R       (6a x log(b x + a) - 2b x  + 3a b x  - 6a b x )\|c
+--R  /
+--R              +----+
+--R       4  +-+ |   2
+--R     6b c\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R          3 +-+ |   2       4
+--R         x \|c \|c x   - c x
+--R   (5)  ---------------------
+--R                       +----+
+--R            2       2  |   2
+--R        (b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 1070
+t0:=x^5/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1070
+r0:=-a*x^2/(b^2*c*sqrt(c*x^2))+1/2*x^3/(b*c*sqrt(c*x^2))+_
+   a^2*x*log(a+b*x)/(b^3*c*sqrt(c*x^2))
+--R 
+--R
+--R          2                  2 3         2
+--R        2a x log(b x + a) + b x  - 2a b x
+--R   (2)  ----------------------------------
+--R                         +----+
+--R                      3  |   2
+--R                    2b c\|c x
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2                2 2
+--R        2a log(b x + a) + b x  - 2a b x
+--R   (3)  -------------------------------
+--R                      3  +-+
+--R                    2b c\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +----+
+--R          2                2 2           |   2
+--R       (2a log(b x + a) + b x  - 2a b x)\|c x
+--R     + 
+--R            2                  2 3         2  +-+
+--R       (- 2a x log(b x + a) - b x  + 2a b x )\|c
+--R  /
+--R              +----+
+--R       3  +-+ |   2
+--R     2b c\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                +----+
+--R          2 +-+ |   2       3
+--R         x \|c \|c x   - c x
+--R   (5)  ---------------------
+--R                       +----+
+--R            2       2  |   2
+--R        (b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 1070
+t0:=x^4/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                  2
+--R                 x
+--R   (1)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 1070
+r0:=x^2/(b*c*sqrt(c*x^2))-a*x*log(a+b*x)/(b^2*c*sqrt(c*x^2))
+--R 
+--R
+--R                                2
+--R        - a x log(b x + a) + b x
+--R   (2)  -------------------------
+--R                    +----+
+--R                 2  |   2
+--R                b c\|c x
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - a log(b x + a) + b x
+--R   (3)  ----------------------
+--R                 2  +-+
+--R                b c\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 23
+
+--S 24 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                                 +----+
+--R                                 |   2                           2  +-+
+--R        (- a log(b x + a) + b x)\|c x   + (a x log(b x + a) - b x )\|c
+--R   (4)  ---------------------------------------------------------------
+--R                                         +----+
+--R                                  2  +-+ |   2
+--R                                 b c\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2       2
+--R         x\|c \|c x   - c x
+--R   (5)  ---------------------
+--R                       +----+
+--R            2       2  |   2
+--R        (b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 25
+
+)clear all
+
+--S 26 of 1070
+t0:=x^3/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                  x
+--R   (1)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1070
+r0:=x*log(a+b*x)/(b*c*sqrt(c*x^2))
+--R 
+--R
+--R        x log(b x + a)
+--R   (2)  --------------
+--R              +----+
+--R              |   2
+--R          b c\|c x
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(b x + a)
+--R   (3)  ------------
+--R               +-+
+--R           b c\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 28
+
+--S 29 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                     +----+
+--R                     |   2                   +-+
+--R        log(b x + a)\|c x   - x log(b x + a)\|c
+--R   (4)  ----------------------------------------
+--R                             +----+
+--R                         +-+ |   2
+--R                     b c\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R           +-+ |   2
+--R          \|c \|c x   - c x
+--R   (5)  ---------------------
+--R                       +----+
+--R            2       2  |   2
+--R        (b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 1070
+t0:=x^2/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 1070
+r0:=x*log(x)/(a*c*sqrt(c*x^2))-x*log(a+b*x)/(a*c*sqrt(c*x^2))
+--R 
+--R
+--R        - x log(b x + a) + x log(x)
+--R   (2)  ---------------------------
+--R                     +----+
+--R                     |   2
+--R                 a c\|c x
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                         +---+ +-+
+--R                x             (2b x + a)\|- c \|c
+--R         log(-------)   2atan(--------------------)
+--R             b x + a                   a c
+--R   (3)  [------------,- ---------------------------]
+--R                +-+                  +---+
+--R            a c\|c               a c\|- c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 33
+
+--S 34 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R                     +----+
+--R               x     |   2                                +-+
+--R        log(-------)\|c x   + (x log(b x + a) - x log(x))\|c
+--R            b x + a
+--R   (4)  -----------------------------------------------------
+--R                                    +----+
+--R                                +-+ |   2
+--R                            a c\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R                +----+
+--R            +-+ |   2
+--R           \|c \|c x   - c x
+--R   (5)  -----------------------
+--R                         +----+
+--R            2 2      2   |   2
+--R        (b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       +----+                +---+ +-+
+--R       |   2      (2b x + a)\|- c \|c                                 +---+
+--R   - 2\|c x  atan(--------------------) + (x log(b x + a) - x log(x))\|- c
+--R                           a c
+--R   ------------------------------------------------------------------------
+--R                                         +----+
+--R                                   +---+ |   2
+--R                               a c\|- c \|c x
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R                +----+
+--R            +-+ |   2
+--R           \|c \|c x   - c x
+--R   (7)  -----------------------
+--R                         +----+
+--R            2 2      2   |   2
+--R        (b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 37
+
+)clear all
+
+--S 38 of 1070
+t0:=x/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R                         +----+
+--R              2          |   2
+--R        (b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 1070
+r0:=(-1)/(a*c*sqrt(c*x^2))-b*x*log(x)/(a^2*c*sqrt(c*x^2))+_
+   b*x*log(a+b*x)/(a^2*c*sqrt(c*x^2))
+--R 
+--R
+--R        b x log(b x + a) - b x log(x) - a
+--R   (2)  ---------------------------------
+--R                        +----+
+--R                     2  |   2
+--R                    a c\|c x
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                b x + a
+--R        b x log(-------) - a
+--R                   x
+--R   (3)  --------------------
+--R               2    +-+
+--R              a c x\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 40
+
+--S 41 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +----+
+--R            b x + a       |   2          2                  2              +-+
+--R   (b x log(-------) - a)\|c x   + (- b x log(b x + a) + b x log(x) + a x)\|c
+--R               x
+--R   ---------------------------------------------------------------------------
+--R                                           +----+
+--R                                  2    +-+ |   2
+--R                                 a c x\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R             +-+ |   2
+--R            \|c \|c x   - c x
+--R   (5)  ------------------------
+--R                          +----+
+--R            2 3      2 2  |   2
+--R        (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 1070
+t0:=1/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R                          +----+
+--R              3        2  |   2
+--R        (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 1070
+r0:=b/(a^2*c*sqrt(c*x^2))+(-1/2)/(a*c*x*sqrt(c*x^2))+_
+   b^2*x*log(x)/(a^3*c*sqrt(c*x^2))-b^2*x*log(a+b*x)/(a^3*c*sqrt(c*x^2))
+--R 
+--R
+--R            2 2                 2 2                   2
+--R        - 2b x log(b x + a) + 2b x log(x) + 2a b x - a
+--R   (2)  -----------------------------------------------
+--R                                +----+
+--R                           3    |   2
+--R                         2a c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 2       x                 2
+--R        2b x log(-------) + 2a b x - a
+--R                 b x + a
+--R   (3)  -------------------------------
+--R                    3   2 +-+
+--R                  2a c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 45
+
+--S 46 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                         +----+
+--R          2 2       x                 2  |   2
+--R       (2b x log(-------) + 2a b x - a )\|c x
+--R                 b x + a
+--R     + 
+--R          2 3                 2 3               2    2   +-+
+--R       (2b x log(b x + a) - 2b x log(x) - 2a b x  + a x)\|c
+--R  /
+--R                 +----+
+--R       3   2 +-+ |   2
+--R     2a c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R             +-+ |   2
+--R            \|c \|c x   - c x
+--R   (5)  ------------------------
+--R                          +----+
+--R            2 4      2 3  |   2
+--R        (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 47
+
+)clear all
+
+--S 48 of 1070
+t0:=1/(x*(c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R                          +----+
+--R              4        3  |   2
+--R        (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 48
+
+--S 49 of 1070
+r0:=-b^2/(a^3*c*sqrt(c*x^2))+(-1/3)/(a*c*x^2*sqrt(c*x^2))+_
+   1/2*b/(a^2*c*x*sqrt(c*x^2))-b^3*x*log(x)/(a^4*c*sqrt(c*x^2))+_
+   b^3*x*log(a+b*x)/(a^4*c*sqrt(c*x^2))
+--R 
+--R
+--R          3 3                 3 3             2 2     2        3
+--R        6b x log(b x + a) - 6b x log(x) - 6a b x  + 3a b x - 2a
+--R   (2)  --------------------------------------------------------
+--R                                     +----+
+--R                               4   2 |   2
+--R                             6a c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3 3    b x + a        2 2     2        3
+--R        6b x log(-------) - 6a b x  + 3a b x - 2a
+--R                    x
+--R   (3)  ------------------------------------------
+--R                          4   3 +-+
+--R                        6a c x \|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 50
+
+--S 51 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +----+
+--R          3 3    b x + a        2 2     2        3  |   2
+--R       (6b x log(-------) - 6a b x  + 3a b x - 2a )\|c x
+--R                    x
+--R     + 
+--R            3 4                 3 4             2 3     2   2     3   +-+
+--R       (- 6b x log(b x + a) + 6b x log(x) + 6a b x  - 3a b x  + 2a x)\|c
+--R  /
+--R                 +----+
+--R       4   3 +-+ |   2
+--R     6a c x \|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R             +-+ |   2
+--R            \|c \|c x   - c x
+--R   (5)  ------------------------
+--R                          +----+
+--R            2 5      2 4  |   2
+--R        (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 52
+
+)clear all
+
+--S 53 of 1070
+t0:=x^3*sqrt(c*x^2)/(a+b*x)^2
+--R 
+--R
+--R                +----+
+--R              3 |   2
+--R             x \|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 1070
+r0:=3*a^2*sqrt(c*x^2)/b^4-a*x*sqrt(c*x^2)/b^3+1/3*x^2*sqrt(c*x^2)/b^2-_
+   a^4*sqrt(c*x^2)/(b^5*x*(a+b*x))-4*a^3*log(a+b*x)*sqrt(c*x^2)/(b^5*x)
+--R 
+--R
+--R   (2)
+--R                 3         4                 4 4       3 3     2 2 2     3
+--R           (- 12a b x - 12a )log(b x + a) + b x  - 2a b x  + 6a b x  + 9a b x
+--R         + 
+--R               4
+--R           - 3a
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       6 2       5
+--R     3b x  + 3a b x
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 3         4                 4 4       3 3     2 2 2     3
+--R           (- 12a b x - 12a )log(b x + a) + b x  - 2a b x  + 6a b x  + 9a b x
+--R         + 
+--R               4
+--R           - 3a
+--R    *
+--R        +-+
+--R       \|c
+--R  /
+--R       6        5
+--R     3b x + 3a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 55
+
+--S 56 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3         4                 4 4       3 3     2 2 2     3
+--R             (12a b x + 12a )log(b x + a) - b x  + 2a b x  - 6a b x  - 9a b x
+--R           + 
+--R               4
+--R             3a
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R                 3   2      4                  4 5       3 4     2 2 3     3   2
+--R           (- 12a b x  - 12a x)log(b x + a) + b x  - 2a b x  + 6a b x  + 9a b x
+--R         + 
+--R               4
+--R           - 3a x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R       6 2       5
+--R     3b x  + 3a b x
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +----+
+--R             4 +-+ |   2       5
+--R            x \|c \|c x   - c x
+--R   (5)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 1070
+t0:=x^2*sqrt(c*x^2)/(a+b*x)^2
+--R 
+--R
+--R                +----+
+--R              2 |   2
+--R             x \|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 1070
+r0:=-2*a*sqrt(c*x^2)/b^3+1/2*x*sqrt(c*x^2)/b^2+a^3*sqrt(c*x^2)/_
+   (b^4*x*(a+b*x))+3*a^2*log(a+b*x)*sqrt(c*x^2)/(b^4*x)
+--R 
+--R
+--R                                                                     +----+
+--R            2        3                 3 3       2 2     2        3  |   2
+--R        ((6a b x + 6a )log(b x + a) + b x  - 3a b x  - 4a b x + 2a )\|c x
+--R   (2)  -------------------------------------------------------------------
+--R                                     5 2       4
+--R                                   2b x  + 2a b x
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2        3                 3 3       2 2     2        3  +-+
+--R        ((6a b x + 6a )log(b x + a) + b x  - 3a b x  - 4a b x + 2a )\|c
+--R   (3)  ----------------------------------------------------------------
+--R                                    5        4
+--R                                  2b x + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 60
+
+--S 61 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                      +----+
+--R             2        3                 3 3       2 2     2        3  |   2
+--R       ((- 6a b x - 6a )log(b x + a) - b x  + 3a b x  + 4a b x - 2a )\|c x
+--R     + 
+--R           2   2     3                  3 4       2 3     2   2     3   +-+
+--R       ((6a b x  + 6a x)log(b x + a) + b x  - 3a b x  - 4a b x  + 2a x)\|c
+--R  /
+--R       5 2       4
+--R     2b x  + 2a b x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +----+
+--R             3 +-+ |   2       4
+--R            x \|c \|c x   - c x
+--R   (5)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 62
+
+)clear all
+
+--S 63 of 1070
+t0:=x*sqrt(c*x^2)/(a+b*x)^2
+--R 
+--R
+--R               +----+
+--R               |   2
+--R             x\|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 63
+
+--S 64 of 1070
+r0:=sqrt(c*x^2)/b^2-a^2*sqrt(c*x^2)/(b^3*x*(a+b*x))-_
+   2*a*log(a+b*x)*sqrt(c*x^2)/(b^3*x)
+--R 
+--R
+--R                                                           +----+
+--R                       2                 2 2            2  |   2
+--R        ((- 2a b x - 2a )log(b x + a) + b x  + a b x - a )\|c x
+--R   (2)  ---------------------------------------------------------
+--R                                4 2      3
+--R                               b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       2                 2 2            2  +-+
+--R        ((- 2a b x - 2a )log(b x + a) + b x  + a b x - a )\|c
+--R   (3)  ------------------------------------------------------
+--R                               4       3
+--R                              b x + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 65
+
+--S 66 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                        +----+
+--R                    2                 2 2            2  |   2
+--R       ((2a b x + 2a )log(b x + a) - b x  - a b x + a )\|c x
+--R     + 
+--R                 2     2                  2 3        2    2   +-+
+--R       ((- 2a b x  - 2a x)log(b x + a) + b x  + a b x  - a x)\|c
+--R  /
+--R      4 2      3
+--R     b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +----+
+--R             2 +-+ |   2       3
+--R            x \|c \|c x   - c x
+--R   (5)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 67
+
+)clear all
+
+--S 68 of 1070
+t0:=sqrt(c*x^2)/(a+b*x)^2
+--R 
+--R
+--R               +----+
+--R               |   2
+--R              \|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 1070
+r0:=a*sqrt(c*x^2)/(b^2*x*(a+b*x))+log(a+b*x)*sqrt(c*x^2)/(b^2*x)
+--R 
+--R
+--R                                    +----+
+--R                                    |   2
+--R        ((b x + a)log(b x + a) + a)\|c x
+--R   (2)  ----------------------------------
+--R                    3 2      2
+--R                   b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                    +-+
+--R        ((b x + a)log(b x + a) + a)\|c
+--R   (3)  -------------------------------
+--R                    3       2
+--R                   b x + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 70
+
+--S 71 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +----+
+--R                                 |   2         2                           +-+
+--R   ((- b x - a)log(b x + a) - a)\|c x   + ((b x  + a x)log(b x + a) + a x)\|c
+--R   ---------------------------------------------------------------------------
+--R                                    3 2      2
+--R                                   b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                  +----+
+--R              +-+ |   2       2
+--R            x\|c \|c x   - c x
+--R   (5)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 1070
+t0:=sqrt(c*x^2)/(x*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R               \|c x
+--R   (1)  --------------------
+--R         2 3         2    2
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 1070
+r0:=-sqrt(c*x^2)/(b*x*(a+b*x))
+--R 
+--R
+--R              +----+
+--R              |   2
+--R             \|c x
+--R   (2)  - ------------
+--R           2 2
+--R          b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +-+
+--R             \|c
+--R   (3)  - ---------
+--R           2
+--R          b x + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 75
+
+--S 76 of 1070
+m0:=a0-r0
+--R 
+--R
+--R         +----+
+--R         |   2      +-+
+--R        \|c x   - x\|c
+--R   (4)  ---------------
+--R           2 2
+--R          b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                  +----+
+--R              +-+ |   2
+--R             \|c \|c x   - c x
+--R   (5)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 77
+
+)clear all
+
+--S 78 of 1070
+t0:=sqrt(c*x^2)/(x^2*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R               \|c x
+--R   (1)  ---------------------
+--R         2 4         3    2 2
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 78
+
+--S 79 of 1070
+r0:=sqrt(c*x^2)/(a*x*(a+b*x))+log(x)*sqrt(c*x^2)/(a^2*x)-_
+   log(a+b*x)*sqrt(c*x^2)/(a^2*x)
+--R 
+--R
+--R                                                        +----+
+--R                                                        |   2
+--R        ((- b x - a)log(b x + a) + (b x + a)log(x) + a)\|c x
+--R   (2)  ------------------------------------------------------
+--R                              2   2    3
+--R                             a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         x          +-+
+--R        ((b x + a)log(-------) + a)\|c
+--R                      b x + a
+--R   (3)  -------------------------------
+--R                    2       3
+--R                   a b x + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 80
+
+--S 81 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                       +----+
+--R                                                       |   2
+--R       ((b x + a)log(b x + a) + (- b x - a)log(x) - a)\|c x
+--R     + 
+--R            2              x            +-+
+--R       ((b x  + a x)log(-------) + a x)\|c
+--R                        b x + a
+--R  /
+--R      2   2    3
+--R     a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +----+
+--R               +-+ |   2
+--R              \|c \|c x   - c x
+--R   (5)  -----------------------------
+--R                               +----+
+--R          2 3         2    2   |   2
+--R        (b x  + 2a b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 82
+
+)clear all
+
+--S 83 of 1070
+t0:=sqrt(c*x^2)/(x^3*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R               \|c x
+--R   (1)  ---------------------
+--R         2 5         4    2 3
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 1070
+r0:=-sqrt(c*x^2)/(a^2*x^2)-b*sqrt(c*x^2)/(a^2*x*(a+b*x))-_
+   2*b*log(x)*sqrt(c*x^2)/(a^3*x)+2*b*log(a+b*x)*sqrt(c*x^2)/(a^3*x)
+--R 
+--R
+--R   (2)
+--R           2 2                              2 2                             2
+--R       ((2b x  + 2a b x)log(b x + a) + (- 2b x  - 2a b x)log(x) - 2a b x - a )
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R      3   3    4 2
+--R     a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2 2              b x + a              2  +-+
+--R        ((2b x  + 2a b x)log(-------) - 2a b x - a )\|c
+--R                                x
+--R   (3)  ------------------------------------------------
+--R                           3   2    4
+--R                          a b x  + a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 85
+
+--S 86 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               2 2                            2 2                             2
+--R         ((- 2b x  - 2a b x)log(b x + a) + (2b x  + 2a b x)log(x) + 2a b x + a )
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R           2 3         2     b x + a          2    2   +-+
+--R       ((2b x  + 2a b x )log(-------) - 2a b x  - a x)\|c
+--R                                x
+--R  /
+--R      3   3    4 2
+--R     a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +----+
+--R                +-+ |   2
+--R               \|c \|c x   - c x
+--R   (5)  ------------------------------
+--R                                +----+
+--R          2 4         3    2 2  |   2
+--R        (b x  + 2a b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 1070
+t0:=sqrt(c*x^2)/(x^4*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R               \|c x
+--R   (1)  ---------------------
+--R         2 6         5    2 4
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 1070
+r0:=-1/2*sqrt(c*x^2)/(a^2*x^3)+2*b*sqrt(c*x^2)/(a^3*x^2)+b^2*sqrt(c*x^2)/_
+   (a^3*x*(a+b*x))+3*b^2*log(x)*sqrt(c*x^2)/(a^4*x)-3*b^2*log(a+b*x)*_
+   sqrt(c*x^2)/(a^4*x)
+--R 
+--R
+--R   (2)
+--R              3 3       2 2                   3 3       2 2              2 2
+--R         (- 6b x  - 6a b x )log(b x + a) + (6b x  + 6a b x )log(x) + 6a b x
+--R       + 
+--R           2       3
+--R         3a b x - a
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       4   4     5 3
+--R     2a b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3 3       2 2        x           2 2     2       3  +-+
+--R        ((6b x  + 6a b x )log(-------) + 6a b x  + 3a b x - a )\|c
+--R                              b x + a
+--R   (3)  -----------------------------------------------------------
+--R                                4   3     5 2
+--R                              2a b x  + 2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 90
+
+--S 91 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3 3       2 2                     3 3       2 2              2 2
+--R           (6b x  + 6a b x )log(b x + a) + (- 6b x  - 6a b x )log(x) - 6a b x
+--R         + 
+--R               2       3
+--R           - 3a b x + a
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R           3 4       2 3        x           2 3     2   2    3   +-+
+--R       ((6b x  + 6a b x )log(-------) + 6a b x  + 3a b x  - a x)\|c
+--R                             b x + a
+--R  /
+--R       4   4     5 3
+--R     2a b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +----+
+--R                +-+ |   2
+--R               \|c \|c x   - c x
+--R   (5)  ------------------------------
+--R                                +----+
+--R          2 5         4    2 3  |   2
+--R        (b x  + 2a b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 92
+
+)clear all
+
+--S 93 of 1070
+t0:=x*(c*x^2)^(3/2)/(a+b*x)^2
+--R 
+--R
+--R                 +----+
+--R               3 |   2
+--R            c x \|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 93
+
+--S 94 of 1070
+r0:=3*a^2*c*sqrt(c*x^2)/b^4-a*c*x*sqrt(c*x^2)/b^3+1/3*c*x^2*sqrt(c*x^2)/b^2-_
+   a^4*c*sqrt(c*x^2)/(b^5*x*(a+b*x))-4*a^3*c*log(a+b*x)*sqrt(c*x^2)/(b^5*x)
+--R 
+--R
+--R   (2)
+--R               3           4                  4   4       3   3     2 2   2
+--R         (- 12a b c x - 12a c)log(b x + a) + b c x  - 2a b c x  + 6a b c x
+--R       + 
+--R           3          4
+--R         9a b c x - 3a c
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       6 2       5
+--R     3b x  + 3a b x
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3           4                  4   4       3   3     2 2   2
+--R         (- 12a b c x - 12a c)log(b x + a) + b c x  - 2a b c x  + 6a b c x
+--R       + 
+--R           3          4
+--R         9a b c x - 3a c
+--R    *
+--R        +-+
+--R       \|c
+--R  /
+--R       6        5
+--R     3b x + 3a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 95
+
+--S 96 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               3           4                  4   4       3   3     2 2   2
+--R           (12a b c x + 12a c)log(b x + a) - b c x  + 2a b c x  - 6a b c x
+--R         + 
+--R               3          4
+--R           - 9a b c x + 3a c
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R                 3     2      4                    4   5       3   4     2 2   3
+--R           (- 12a b c x  - 12a c x)log(b x + a) + b c x  - 2a b c x  + 6a b c x
+--R         + 
+--R             3     2     4
+--R           9a b c x  - 3a c x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R       6 2       5
+--R     3b x  + 3a b x
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +----+
+--R              4 +-+ |   2     2 5
+--R           c x \|c \|c x   - c x
+--R   (5)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 97
+
+)clear all
+
+--S 98 of 1070
+t0:=(c*x^2)^(3/2)/(a+b*x)^2
+--R 
+--R
+--R                 +----+
+--R               2 |   2
+--R            c x \|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 1070
+r0:=-2*a*c*sqrt(c*x^2)/b^3+1/2*c*x*sqrt(c*x^2)/b^2+a^3*c*sqrt(c*x^2)/_
+   (b^4*x*(a+b*x))+3*a^2*c*log(a+b*x)*sqrt(c*x^2)/(b^4*x)
+--R 
+--R
+--R   (2)
+--R                                                                          +----+
+--R       2          3                  3   3       2   2     2          3   |   2
+--R   ((6a b c x + 6a c)log(b x + a) + b c x  - 3a b c x  - 4a b c x + 2a c)\|c x
+--R   -----------------------------------------------------------------------------
+--R                                     5 2       4
+--R                                   2b x  + 2a b x
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       2          3                  3   3       2   2     2          3   +-+
+--R   ((6a b c x + 6a c)log(b x + a) + b c x  - 3a b c x  - 4a b c x + 2a c)\|c
+--R   --------------------------------------------------------------------------
+--R                                    5        4
+--R                                  2b x + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 100
+
+--S 101 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  2          3                  3   3       2   2     2
+--R             (- 6a b c x - 6a c)log(b x + a) - b c x  + 3a b c x  + 4a b c x
+--R           + 
+--R                 3
+--R             - 2a c
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R              2     2     3                    3   4       2   3     2     2
+--R           (6a b c x  + 6a c x)log(b x + a) + b c x  - 3a b c x  - 4a b c x
+--R         + 
+--R             3
+--R           2a c x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R       5 2       4
+--R     2b x  + 2a b x
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +----+
+--R              3 +-+ |   2     2 4
+--R           c x \|c \|c x   - c x
+--R   (5)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 1070
+t0:=(c*x^2)^(3/2)/(x*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R            c x\|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 1070
+r0:=c*sqrt(c*x^2)/b^2-a^2*c*sqrt(c*x^2)/(b^3*x*(a+b*x))-_
+   2*a*c*log(a+b*x)*sqrt(c*x^2)/(b^3*x)
+--R 
+--R
+--R                                                                   +----+
+--R                         2                  2   2              2   |   2
+--R        ((- 2a b c x - 2a c)log(b x + a) + b c x  + a b c x - a c)\|c x
+--R   (2)  -----------------------------------------------------------------
+--R                                    4 2      3
+--R                                   b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         2                  2   2              2   +-+
+--R        ((- 2a b c x - 2a c)log(b x + a) + b c x  + a b c x - a c)\|c
+--R   (3)  --------------------------------------------------------------
+--R                                   4       3
+--R                                  b x + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 105
+
+--S 106 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                +----+
+--R                      2                  2   2              2   |   2
+--R       ((2a b c x + 2a c)log(b x + a) - b c x  - a b c x + a c)\|c x
+--R     + 
+--R                   2     2                    2   3          2    2     +-+
+--R       ((- 2a b c x  - 2a c x)log(b x + a) + b c x  + a b c x  - a c x)\|c
+--R  /
+--R      4 2      3
+--R     b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +----+
+--R              2 +-+ |   2     2 3
+--R           c x \|c \|c x   - c x
+--R   (5)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 107
+
+)clear all
+
+--S 108 of 1070
+t0:=(c*x^2)^(3/2)/(x^2*(a+b*x)^2)
+--R 
+--R
+--R               +----+
+--R               |   2
+--R             c\|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 108
+
+--S 109 of 1070
+r0:=a*c*sqrt(c*x^2)/(b^2*x*(a+b*x))+c*log(a+b*x)*sqrt(c*x^2)/(b^2*x)
+--R 
+--R
+--R                                          +----+
+--R                                          |   2
+--R        ((b c x + a c)log(b x + a) + a c)\|c x
+--R   (2)  ----------------------------------------
+--R                       3 2      2
+--R                      b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                          +-+
+--R        ((b c x + a c)log(b x + a) + a c)\|c
+--R   (3)  -------------------------------------
+--R                       3       2
+--R                      b x + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 110
+
+--S 111 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +----+
+--R                                           |   2
+--R       ((- b c x - a c)log(b x + a) - a c)\|c x
+--R     + 
+--R              2                               +-+
+--R       ((b c x  + a c x)log(b x + a) + a c x)\|c
+--R  /
+--R      3 2      2
+--R     b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +----+
+--R               +-+ |   2     2 2
+--R           c x\|c \|c x   - c x
+--R   (5)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 112
+
+)clear all
+
+--S 113 of 1070
+t0:=(c*x^2)^(3/2)/(x^3*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R              c\|c x
+--R   (1)  --------------------
+--R         2 3         2    2
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 1070
+r0:=-c*sqrt(c*x^2)/(b*x*(a+b*x))
+--R 
+--R
+--R              +----+
+--R              |   2
+--R            c\|c x
+--R   (2)  - ------------
+--R           2 2
+--R          b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +-+
+--R            c\|c
+--R   (3)  - ---------
+--R           2
+--R          b x + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 115
+
+--S 116 of 1070
+m0:=a0-r0
+--R 
+--R
+--R          +----+
+--R          |   2        +-+
+--R        c\|c x   - c x\|c
+--R   (4)  ------------------
+--R            2 2
+--R           b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +----+
+--R               +-+ |   2     2
+--R             c\|c \|c x   - c x
+--R   (5)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 1070
+t0:=(c*x^2)^(3/2)/(x^4*(a+b*x)^2)
+--R 
+--R
+--R                 +----+
+--R                 |   2
+--R               c\|c x
+--R   (1)  ---------------------
+--R         2 4         3    2 2
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 1070
+r0:=c*sqrt(c*x^2)/(a*x*(a+b*x))+c*log(x)*sqrt(c*x^2)/(a^2*x)-_
+   c*log(a+b*x)*sqrt(c*x^2)/(a^2*x)
+--R 
+--R
+--R                                                                  +----+
+--R                                                                  |   2
+--R        ((- b c x - a c)log(b x + a) + (b c x + a c)log(x) + a c)\|c x
+--R   (2)  ----------------------------------------------------------------
+--R                                   2   2    3
+--R                                  a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             x            +-+
+--R        ((b c x + a c)log(-------) + a c)\|c
+--R                          b x + a
+--R   (3)  -------------------------------------
+--R                       2       3
+--R                      a b x + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 120
+
+--S 121 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                 +----+
+--R                                                                 |   2
+--R       ((b c x + a c)log(b x + a) + (- b c x - a c)log(x) - a c)\|c x
+--R     + 
+--R              2                x              +-+
+--R       ((b c x  + a c x)log(-------) + a c x)\|c
+--R                            b x + a
+--R  /
+--R      2   2    3
+--R     a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +----+
+--R                +-+ |   2     2
+--R              c\|c \|c x   - c x
+--R   (5)  -----------------------------
+--R                               +----+
+--R          2 3         2    2   |   2
+--R        (b x  + 2a b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 122
+
+)clear all
+
+--S 123 of 1070
+t0:=(c*x^2)^(3/2)/(x^5*(a+b*x)^2)
+--R 
+--R
+--R                 +----+
+--R                 |   2
+--R               c\|c x
+--R   (1)  ---------------------
+--R         2 5         4    2 3
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 123
+
+--S 124 of 1070
+r0:=-c*sqrt(c*x^2)/(a^2*x^2)-b*c*sqrt(c*x^2)/(a^2*x*(a+b*x))-_
+   2*b*c*log(x)*sqrt(c*x^2)/(a^3*x)+2*b*c*log(a+b*x)*sqrt(c*x^2)/(a^3*x)
+--R 
+--R
+--R   (2)
+--R            2   2                                2   2
+--R         (2b c x  + 2a b c x)log(b x + a) + (- 2b c x  - 2a b c x)log(x)
+--R       + 
+--R                       2
+--R         - 2a b c x - a c
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R      3   3    4 2
+--R     a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2   2                b x + a                2   +-+
+--R        ((2b c x  + 2a b c x)log(-------) - 2a b c x - a c)\|c
+--R                                    x
+--R   (3)  -------------------------------------------------------
+--R                               3   2    4
+--R                              a b x  + a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 125
+
+--S 126 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2   2                              2   2
+--R           (- 2b c x  - 2a b c x)log(b x + a) + (2b c x  + 2a b c x)log(x)
+--R         + 
+--R                       2
+--R           2a b c x + a c
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R           2   3           2     b x + a            2    2     +-+
+--R       ((2b c x  + 2a b c x )log(-------) - 2a b c x  - a c x)\|c
+--R                                    x
+--R  /
+--R      3   3    4 2
+--R     a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +----+
+--R                +-+ |   2     2
+--R              c\|c \|c x   - c x
+--R   (5)  ------------------------------
+--R                                +----+
+--R          2 4         3    2 2  |   2
+--R        (b x  + 2a b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 127
+
+)clear all
+
+--S 128 of 1070
+t0:=(c*x^2)^(3/2)/(x^6*(a+b*x)^2)
+--R 
+--R
+--R                 +----+
+--R                 |   2
+--R               c\|c x
+--R   (1)  ---------------------
+--R         2 6         5    2 4
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 1070
+r0:=-1/2*c*sqrt(c*x^2)/(a^2*x^3)+2*b*c*sqrt(c*x^2)/(a^3*x^2)+_
+   b^2*c*sqrt(c*x^2)/(a^3*x*(a+b*x))+3*b^2*c*log(x)*sqrt(c*x^2)/(a^4*x)-_
+   3*b^2*c*log(a+b*x)*sqrt(c*x^2)/(a^4*x)
+--R 
+--R
+--R   (2)
+--R              3   3       2   2                   3   3       2   2
+--R         (- 6b c x  - 6a b c x )log(b x + a) + (6b c x  + 6a b c x )log(x)
+--R       + 
+--R             2   2     2         3
+--R         6a b c x  + 3a b c x - a c
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       4   4     5 3
+--R     2a b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3   3       2   2        x           2   2     2         3   +-+
+--R        ((6b c x  + 6a b c x )log(-------) + 6a b c x  + 3a b c x - a c)\|c
+--R                                  b x + a
+--R   (3)  --------------------------------------------------------------------
+--R                                     4   3     5 2
+--R                                   2a b x  + 2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 130
+
+--S 131 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3   3       2   2                     3   3       2   2
+--R           (6b c x  + 6a b c x )log(b x + a) + (- 6b c x  - 6a b c x )log(x)
+--R         + 
+--R                 2   2     2         3
+--R           - 6a b c x  - 3a b c x + a c
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R           3   4       2   3        x           2   3     2     2    3     +-+
+--R       ((6b c x  + 6a b c x )log(-------) + 6a b c x  + 3a b c x  - a c x)\|c
+--R                                 b x + a
+--R  /
+--R       4   4     5 3
+--R     2a b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                    +----+
+--R                +-+ |   2     2
+--R              c\|c \|c x   - c x
+--R   (5)  ------------------------------
+--R                                +----+
+--R          2 5         4    2 3  |   2
+--R        (b x  + 2a b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 1070
+t0:=x^5/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                      5
+--R                     x
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 1070
+r0:=3*a^2*x^2/(b^4*sqrt(c*x^2))-a*x^3/(b^3*sqrt(c*x^2))+_
+   1/3*x^4/(b^2*sqrt(c*x^2))-a^4*x/(b^5*(a+b*x)*sqrt(c*x^2))-_
+   4*a^3*x*log(a+b*x)/(b^5*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         3   2      4                  4 5       3 4     2 2 3     3   2     4
+--R   (- 12a b x  - 12a x)log(b x + a) + b x  - 2a b x  + 6a b x  + 9a b x  - 3a x
+--R   ----------------------------------------------------------------------------
+--R                                              +----+
+--R                                  6        5  |   2
+--R                               (3b x + 3a b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3         4                 4 4       3 3     2 2 2     3        4
+--R   (- 12a b x - 12a )log(b x + a) + b x  - 2a b x  + 6a b x  + 9a b x - 3a
+--R   ------------------------------------------------------------------------
+--R                                 6        5  +-+
+--R                              (3b x + 3a b )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 135
+
+--S 136 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3         4                 4 4       3 3     2 2 2     3
+--R           (- 12a b x - 12a )log(b x + a) + b x  - 2a b x  + 6a b x  + 9a b x
+--R         + 
+--R               4
+--R           - 3a
+--R      *
+--R          +----+
+--R          |   2
+--R         \|c x
+--R     + 
+--R               3   2      4                  4 5       3 4     2 2 3     3   2
+--R           (12a b x  + 12a x)log(b x + a) - b x  + 2a b x  - 6a b x  - 9a b x
+--R         + 
+--R             4
+--R           3a x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                        +----+
+--R        6        5  +-+ |   2
+--R     (3b x + 3a b )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +----+
+--R               4 +-+ |   2       5
+--R              x \|c \|c x   - c x
+--R   (5)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 137
+
+)clear all
+
+--S 138 of 1070
+t0:=x^4/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                      4
+--R                     x
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 138
+
+--S 139 of 1070
+r0:=-2*a*x^2/(b^3*sqrt(c*x^2))+1/2*x^3/(b^2*sqrt(c*x^2))+_
+   a^3*x/(b^4*(a+b*x)*sqrt(c*x^2))+3*a^2*x*log(a+b*x)/(b^4*sqrt(c*x^2))
+--R 
+--R
+--R           2   2     3                  3 4       2 3     2   2     3
+--R        (6a b x  + 6a x)log(b x + a) + b x  - 3a b x  - 4a b x  + 2a x
+--R   (2)  --------------------------------------------------------------
+--R                                            +----+
+--R                                5        4  |   2
+--R                             (2b x + 2a b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2        3                 3 3       2 2     2        3
+--R        (6a b x + 6a )log(b x + a) + b x  - 3a b x  - 4a b x + 2a
+--R   (3)  ----------------------------------------------------------
+--R                               5        4  +-+
+--R                            (2b x + 2a b )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 140
+
+--S 141 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                    +----+
+--R           2        3                 3 3       2 2     2        3  |   2
+--R       ((6a b x + 6a )log(b x + a) + b x  - 3a b x  - 4a b x + 2a )\|c x
+--R     + 
+--R             2   2     3                  3 4       2 3     2   2     3   +-+
+--R       ((- 6a b x  - 6a x)log(b x + a) - b x  + 3a b x  + 4a b x  - 2a x)\|c
+--R  /
+--R                        +----+
+--R        5        4  +-+ |   2
+--R     (2b x + 2a b )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +----+
+--R               3 +-+ |   2       4
+--R              x \|c \|c x   - c x
+--R   (5)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 142
+
+)clear all
+
+--S 143 of 1070
+t0:=x^3/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                      3
+--R                     x
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 1070
+r0:=x^2/(b^2*sqrt(c*x^2))-a^2*x/(b^3*(a+b*x)*sqrt(c*x^2))-_
+   2*a*x*log(a+b*x)/(b^3*sqrt(c*x^2))
+--R 
+--R
+--R                 2     2                  2 3        2    2
+--R        (- 2a b x  - 2a x)log(b x + a) + b x  + a b x  - a x
+--R   (2)  ----------------------------------------------------
+--R                                      +----+
+--R                           4       3  |   2
+--R                         (b x + a b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      2                 2 2            2
+--R        (- 2a b x - 2a )log(b x + a) + b x  + a b x - a
+--R   (3)  ------------------------------------------------
+--R                          4       3  +-+
+--R                        (b x + a b )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 145
+
+--S 146 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +----+
+--R                      2                 2 2            2  |   2
+--R       ((- 2a b x - 2a )log(b x + a) + b x  + a b x - a )\|c x
+--R     + 
+--R               2     2                  2 3        2    2   +-+
+--R       ((2a b x  + 2a x)log(b x + a) - b x  - a b x  + a x)\|c
+--R  /
+--R                      +----+
+--R       4       3  +-+ |   2
+--R     (b x + a b )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +----+
+--R               2 +-+ |   2       3
+--R              x \|c \|c x   - c x
+--R   (5)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 1070
+t0:=x^2/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 1070
+r0:=a*x/(b^2*(a+b*x)*sqrt(c*x^2))+x*log(a+b*x)/(b^2*sqrt(c*x^2))
+--R 
+--R
+--R            2
+--R        (b x  + a x)log(b x + a) + a x
+--R   (2)  ------------------------------
+--R                           +----+
+--R                3       2  |   2
+--R              (b x + a b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (b x + a)log(b x + a) + a
+--R   (3)  -------------------------
+--R               3       2  +-+
+--R             (b x + a b )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 150
+
+--S 151 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R                               |   2           2                           +-+
+--R   ((b x + a)log(b x + a) + a)\|c x   + ((- b x  - a x)log(b x + a) - a x)\|c
+--R   ---------------------------------------------------------------------------
+--R                                              +----+
+--R                               3       2  +-+ |   2
+--R                             (b x + a b )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +----+
+--R                 +-+ |   2       2
+--R               x\|c \|c x   - c x
+--R   (5)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 152
+
+)clear all
+
+--S 153 of 1070
+t0:=x/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                     x
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 153
+
+--S 154 of 1070
+r0:=-x/(b*(a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                   x
+--R   (2)  - ------------------
+--R                      +----+
+--R            2         |   2
+--R          (b x + a b)\|c x
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 1
+--R   (3)  - ---------------
+--R            2         +-+
+--R          (b x + a b)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 155
+
+--S 156 of 1070
+m0:=a0-r0
+--R 
+--R
+--R              +----+
+--R              |   2      +-+
+--R           - \|c x   + x\|c
+--R   (4)  ----------------------
+--R                        +----+
+--R          2         +-+ |   2
+--R        (b x + a b)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +----+
+--R                 +-+ |   2
+--R                \|c \|c x   - c x
+--R   (5)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 157
+
+)clear all
+
+--S 158 of 1070
+t0:=1/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 1070
+r0:=x/(a*(a+b*x)*sqrt(c*x^2))+x*log(x)/(a^2*sqrt(c*x^2))-_
+   x*log(a+b*x)/(a^2*sqrt(c*x^2))
+--R 
+--R
+--R              2                          2
+--R        (- b x  - a x)log(b x + a) + (b x  + a x)log(x) + a x
+--R   (2)  -----------------------------------------------------
+--R                                      +----+
+--R                           2       3  |   2
+--R                         (a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        x
+--R        (b x + a)log(-------) + a
+--R                     b x + a
+--R   (3)  -------------------------
+--R               2       3  +-+
+--R             (a b x + a )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 160
+
+--S 161 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   +----+
+--R                        x          |   2
+--R       ((b x + a)log(-------) + a)\|c x
+--R                     b x + a
+--R     + 
+--R            2                            2                     +-+
+--R       ((b x  + a x)log(b x + a) + (- b x  - a x)log(x) - a x)\|c
+--R  /
+--R                      +----+
+--R       2       3  +-+ |   2
+--R     (a b x + a )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2
+--R                 \|c \|c x   - c x
+--R   (5)  -----------------------------------
+--R                                     +----+
+--R          2   3           2    2     |   2
+--R        (b c x  + 2a b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 1070
+t0:=1/(x*(a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R                               +----+
+--R          2 3         2    2   |   2
+--R        (b x  + 2a b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 1070
+r0:=(-1)/(a^2*sqrt(c*x^2))-b*x/(a^2*(a+b*x)*sqrt(c*x^2))-_
+   2*b*x*log(x)/(a^3*sqrt(c*x^2))+2*b*x*log(a+b*x)/(a^3*sqrt(c*x^2))
+--R 
+--R
+--R           2 2                              2 2                             2
+--R        (2b x  + 2a b x)log(b x + a) + (- 2b x  - 2a b x)log(x) - 2a b x - a
+--R   (2)  ---------------------------------------------------------------------
+--R                                              +----+
+--R                                   3       4  |   2
+--R                                 (a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2              b x + a              2
+--R        (2b x  + 2a b x)log(-------) - 2a b x - a
+--R                               x
+--R   (3)  ------------------------------------------
+--R                      3   2    4   +-+
+--R                    (a b x  + a x)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 165
+
+--S 166 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +----+
+--R           2 2              b x + a              2  |   2
+--R       ((2b x  + 2a b x)log(-------) - 2a b x - a )\|c x
+--R                               x
+--R     + 
+--R                2 3         2                   2 3         2                2
+--R           (- 2b x  - 2a b x )log(b x + a) + (2b x  + 2a b x )log(x) + 2a b x
+--R         + 
+--R            2
+--R           a x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                        +----+
+--R       3   2    4   +-+ |   2
+--R     (a b x  + a x)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                       +----+
+--R                   +-+ |   2
+--R                  \|c \|c x   - c x
+--R   (5)  ------------------------------------
+--R                                      +----+
+--R          2   4           3    2   2  |   2
+--R        (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 167
+
+)clear all
+
+--S 168 of 1070
+t0:=1/(x^2*(a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                                +----+
+--R          2 4         3    2 2  |   2
+--R        (b x  + 2a b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 168
+
+--S 169 of 1070
+r0:=2*b/(a^3*sqrt(c*x^2))+(-1/2)/(a^2*x*sqrt(c*x^2))+b^2*x/(a^3*(a+b*x)*_
+   sqrt(c*x^2))+3*b^2*x*log(x)/(a^4*sqrt(c*x^2))-_
+   3*b^2*x*log(a+b*x)/(a^4*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R            3 3       2 2                   3 3       2 2              2 2
+--R       (- 6b x  - 6a b x )log(b x + a) + (6b x  + 6a b x )log(x) + 6a b x
+--R     + 
+--R         2       3
+--R       3a b x - a
+--R  /
+--R                      +----+
+--R        4   2     5   |   2
+--R     (2a b x  + 2a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 3       2 2        x           2 2     2       3
+--R        (6b x  + 6a b x )log(-------) + 6a b x  + 3a b x - a
+--R                             b x + a
+--R   (3)  -----------------------------------------------------
+--R                           4   3     5 2  +-+
+--R                        (2a b x  + 2a x )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 170
+
+--S 171 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                               +----+
+--R           3 3       2 2        x           2 2     2       3  |   2
+--R       ((6b x  + 6a b x )log(-------) + 6a b x  + 3a b x - a )\|c x
+--R                             b x + a
+--R     + 
+--R              3 4       2 3                     3 4       2 3              2 3
+--R           (6b x  + 6a b x )log(b x + a) + (- 6b x  - 6a b x )log(x) - 6a b x
+--R         + 
+--R               2   2    3
+--R           - 3a b x  + a x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                           +----+
+--R        4   3     5 2  +-+ |   2
+--R     (2a b x  + 2a x )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                       +----+
+--R                   +-+ |   2
+--R                  \|c \|c x   - c x
+--R   (5)  ------------------------------------
+--R                                      +----+
+--R          2   5           4    2   3  |   2
+--R        (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 172
+
+)clear all
+
+--S 173 of 1070
+t0:=x^5/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                        3
+--R                       x
+--R   (1)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 1070
+r0:=x^2/(b^2*c*sqrt(c*x^2))-a^2*x/(b^3*c*(a+b*x)*sqrt(c*x^2))-_
+   2*a*x*log(a+b*x)/(b^3*c*sqrt(c*x^2))
+--R 
+--R
+--R                 2     2                  2 3        2    2
+--R        (- 2a b x  - 2a x)log(b x + a) + b x  + a b x  - a x
+--R   (2)  ----------------------------------------------------
+--R                                       +----+
+--R                         4         3   |   2
+--R                       (b c x + a b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      2                 2 2            2
+--R        (- 2a b x - 2a )log(b x + a) + b x  + a b x - a
+--R   (3)  ------------------------------------------------
+--R                         4         3   +-+
+--R                       (b c x + a b c)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 175
+
+--S 176 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                          +----+
+--R                      2                 2 2            2  |   2
+--R       ((- 2a b x - 2a )log(b x + a) + b x  + a b x - a )\|c x
+--R     + 
+--R               2     2                  2 3        2    2   +-+
+--R       ((2a b x  + 2a x)log(b x + a) - b x  - a b x  + a x)\|c
+--R  /
+--R                         +----+
+--R       4         3   +-+ |   2
+--R     (b c x + a b c)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                2 +-+ |   2       3
+--R               x \|c \|c x   - c x
+--R   (5)  ---------------------------------
+--R                                   +----+
+--R          2 2 2         2     2 2  |   2
+--R        (b c x  + 2a b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 1070
+t0:=x^4/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                        2
+--R                       x
+--R   (1)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 1070
+r0:=a*x/(b^2*c*(a+b*x)*sqrt(c*x^2))+x*log(a+b*x)/(b^2*c*sqrt(c*x^2))
+--R 
+--R
+--R            2
+--R        (b x  + a x)log(b x + a) + a x
+--R   (2)  ------------------------------
+--R                            +----+
+--R              3         2   |   2
+--R            (b c x + a b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (b x + a)log(b x + a) + a
+--R   (3)  -------------------------
+--R             3         2   +-+
+--R           (b c x + a b c)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 180
+
+--S 181 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +----+
+--R                               |   2           2                           +-+
+--R   ((b x + a)log(b x + a) + a)\|c x   + ((- b x  - a x)log(b x + a) - a x)\|c
+--R   ---------------------------------------------------------------------------
+--R                                                +----+
+--R                              3         2   +-+ |   2
+--R                            (b c x + a b c)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +----+
+--R                 +-+ |   2       2
+--R               x\|c \|c x   - c x
+--R   (5)  ---------------------------------
+--R                                   +----+
+--R          2 2 2         2     2 2  |   2
+--R        (b c x  + 2a b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 182
+
+)clear all
+
+--S 183 of 1070
+t0:=x^3/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                        x
+--R   (1)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 183
+
+--S 184 of 1070
+r0:=-x/(b*c*(a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                     x
+--R   (2)  - ----------------------
+--R                          +----+
+--R            2             |   2
+--R          (b c x + a b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   1
+--R   (3)  - -------------------
+--R            2             +-+
+--R          (b c x + a b c)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 185
+
+--S 186 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                +----+
+--R                |   2      +-+
+--R             - \|c x   + x\|c
+--R   (4)  --------------------------
+--R                            +----+
+--R          2             +-+ |   2
+--R        (b c x + a b c)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     +----+
+--R                 +-+ |   2
+--R                \|c \|c x   - c x
+--R   (5)  ---------------------------------
+--R                                   +----+
+--R          2 2 2         2     2 2  |   2
+--R        (b c x  + 2a b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 187
+
+)clear all
+
+--S 188 of 1070
+t0:=x^2/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 1070
+r0:=x/(a*c*(a+b*x)*sqrt(c*x^2))+x*log(x)/(a^2*c*sqrt(c*x^2))-_
+   x*log(a+b*x)/(a^2*c*sqrt(c*x^2))
+--R 
+--R
+--R              2                          2
+--R        (- b x  - a x)log(b x + a) + (b x  + a x)log(x) + a x
+--R   (2)  -----------------------------------------------------
+--R                                        +----+
+--R                          2         3   |   2
+--R                        (a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        x
+--R        (b x + a)log(-------) + a
+--R                     b x + a
+--R   (3)  -------------------------
+--R             2         3   +-+
+--R           (a b c x + a c)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 190
+
+--S 191 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   +----+
+--R                        x          |   2
+--R       ((b x + a)log(-------) + a)\|c x
+--R                     b x + a
+--R     + 
+--R            2                            2                     +-+
+--R       ((b x  + a x)log(b x + a) + (- b x  - a x)log(x) - a x)\|c
+--R  /
+--R                         +----+
+--R       2         3   +-+ |   2
+--R     (a b c x + a c)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      +----+
+--R                  +-+ |   2
+--R                 \|c \|c x   - c x
+--R   (5)  -----------------------------------
+--R                                     +----+
+--R          2 2 3         2 2    2 2   |   2
+--R        (b c x  + 2a b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 1070
+t0:=x/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                         1
+--R   (1)  -----------------------------------
+--R                                     +----+
+--R          2   3           2    2     |   2
+--R        (b c x  + 2a b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 1070
+r0:=(-1)/(a^2*c*sqrt(c*x^2))-b*x/(a^2*c*(a+b*x)*sqrt(c*x^2))-_
+   2*b*x*log(x)/(a^3*c*sqrt(c*x^2))+2*b*x*log(a+b*x)/(a^3*c*sqrt(c*x^2))
+--R 
+--R
+--R           2 2                              2 2                             2
+--R        (2b x  + 2a b x)log(b x + a) + (- 2b x  - 2a b x)log(x) - 2a b x - a
+--R   (2)  ---------------------------------------------------------------------
+--R                                                +----+
+--R                                  3         4   |   2
+--R                                (a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2              b x + a              2
+--R        (2b x  + 2a b x)log(-------) - 2a b x - a
+--R                               x
+--R   (3)  ------------------------------------------
+--R                    3     2    4     +-+
+--R                  (a b c x  + a c x)\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 195
+
+--S 196 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +----+
+--R           2 2              b x + a              2  |   2
+--R       ((2b x  + 2a b x)log(-------) - 2a b x - a )\|c x
+--R                               x
+--R     + 
+--R                2 3         2                   2 3         2                2
+--R           (- 2b x  - 2a b x )log(b x + a) + (2b x  + 2a b x )log(x) + 2a b x
+--R         + 
+--R            2
+--R           a x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                            +----+
+--R       3     2    4     +-+ |   2
+--R     (a b c x  + a c x)\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                       +----+
+--R                   +-+ |   2
+--R                  \|c \|c x   - c x
+--R   (5)  ------------------------------------
+--R                                      +----+
+--R          2 2 4         2 3    2 2 2  |   2
+--R        (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 197
+
+)clear all
+
+--S 198 of 1070
+t0:=1/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                          1
+--R   (1)  ------------------------------------
+--R                                      +----+
+--R          2   4           3    2   2  |   2
+--R        (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 198
+
+--S 199 of 1070
+r0:=2*b/(a^3*c*sqrt(c*x^2))+(-1/2)/(a^2*c*x*sqrt(c*x^2))+_
+   b^2*x/(a^3*c*(a+b*x)*sqrt(c*x^2))+3*b^2*x*log(x)/(a^4*c*sqrt(c*x^2))-_
+   3*b^2*x*log(a+b*x)/(a^4*c*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R            3 3       2 2                   3 3       2 2              2 2
+--R       (- 6b x  - 6a b x )log(b x + a) + (6b x  + 6a b x )log(x) + 6a b x
+--R     + 
+--R         2       3
+--R       3a b x - a
+--R  /
+--R                          +----+
+--R        4     2     5     |   2
+--R     (2a b c x  + 2a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 3       2 2        x           2 2     2       3
+--R        (6b x  + 6a b x )log(-------) + 6a b x  + 3a b x - a
+--R                             b x + a
+--R   (3)  -----------------------------------------------------
+--R                         4     3     5   2  +-+
+--R                      (2a b c x  + 2a c x )\|c
+--R                                         Type: Union(Expression(Integer),...)
+--E 200
+
+--S 201 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                               +----+
+--R           3 3       2 2        x           2 2     2       3  |   2
+--R       ((6b x  + 6a b x )log(-------) + 6a b x  + 3a b x - a )\|c x
+--R                             b x + a
+--R     + 
+--R              3 4       2 3                     3 4       2 3              2 3
+--R           (6b x  + 6a b x )log(b x + a) + (- 6b x  - 6a b x )log(x) - 6a b x
+--R         + 
+--R               2   2    3
+--R           - 3a b x  + a x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                               +----+
+--R        4     3     5   2  +-+ |   2
+--R     (2a b c x  + 2a c x )\|c \|c x
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                       +----+
+--R                   +-+ |   2
+--R                  \|c \|c x   - c x
+--R   (5)  ------------------------------------
+--R                                      +----+
+--R          2 2 5         2 4    2 2 3  |   2
+--R        (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+)clear all
+
+--S 203 of 1070
+t0:=x^m*(c*x^2)^p*(a+b*x)^(-2-m-2*p)
+--R 
+--R
+--R         m         - 2p - m - 2    2 p
+--R   (1)  x (b x + a)            (c x )
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 1070
+r0:=x^(1+m)*(c*x^2)^p*(a+b*x)^(-1-m-2*p)/(a*(1+m+2*p))
+--R 
+--R
+--R         m + 1         - 2p - m - 1    2 p
+--R        x     (b x + a)            (c x )
+--R   (2)  ----------------------------------
+--R                  2a p + a m + a
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       2         (- 2p - m - 2)log(b x + a)  m log(x)  2p log(x) + p log(c)
+--R   (b x  + a x)%e                          %e        %e
+--R   ------------------------------------------------------------------------
+--R                                2a p + a m + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 205
+
+--S 206 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2         (- 2p - m - 2)log(b x + a)  m log(x)  2p log(x) + p log(c)
+--R       (b x  + a x)%e                          %e        %e
+--R     + 
+--R          m + 1         - 2p - m - 1    2 p
+--R       - x     (b x + a)            (c x )
+--R  /
+--R     2a p + a m + a
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 1070
+t0:=x^3*(c*x^2)^p*(a+b*x)^(-5-2*p)
+--R 
+--R
+--R         3         - 2p - 5    2 p
+--R   (1)  x (b x + a)        (c x )
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 1070
+r0:=1/2*x^4*(c*x^2)^p/(a*(2+p)*(a+b*x)^(2*(2+p)))
+--R 
+--R
+--R                  4    2 p
+--R                 x (c x )
+--R   (2)  --------------------------
+--R                            2p + 4
+--R        (2a p + 4a)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        2
+--R            5      4   (- 2p - 5)log(b x + a)  p log(c x )
+--R        (b x  + a x )%e                      %e
+--R   (3)  --------------------------------------------------
+--R                             2a p + 4a
+--R                                         Type: Union(Expression(Integer),...)
+--E 210
+
+--S 211 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                  2
+--R       5      4          2p + 4  (- 2p - 5)log(b x + a)  p log(c x )    4    2 p
+--R   (b x  + a x )(b x + a)      %e                      %e            - x (c x )
+--R   -----------------------------------------------------------------------------
+--R                                                 2p + 4
+--R                             (2a p + 4a)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 212
+
+)clear all
+
+--S 213 of 1070
+t0:=x^2*(c*x^2)^p*(a+b*x)^(-4-2*p)
+--R 
+--R
+--R         2         - 2p - 4    2 p
+--R   (1)  x (b x + a)        (c x )
+--R                                                    Type: Expression(Integer)
+--E 213
+
+--S 214 of 1070
+r0:=x^3*(c*x^2)^p*(a+b*x)^(-3-2*p)/(a*(3+2*p))
+--R 
+--R
+--R         3         - 2p - 3    2 p
+--R        x (b x + a)        (c x )
+--R   (2)  --------------------------
+--R                 2a p + 3a
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        2
+--R            4      3   (- 2p - 4)log(b x + a)  p log(c x )
+--R        (b x  + a x )%e                      %e
+--R   (3)  --------------------------------------------------
+--R                             2a p + 3a
+--R                                         Type: Union(Expression(Integer),...)
+--E 215
+
+--S 216 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                       2
+--R           4      3   (- 2p - 4)log(b x + a)  p log(c x )
+--R       (b x  + a x )%e                      %e
+--R     + 
+--R          3         - 2p - 3    2 p
+--R       - x (b x + a)        (c x )
+--R  /
+--R     2a p + 3a
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 217
+
+)clear all
+
+--S 218 of 1070
+t0:=x*(c*x^2)^p*(a+b*x)^(-3-2*p)
+--R 
+--R
+--R                   - 2p - 3    2 p
+--R   (1)  x (b x + a)        (c x )
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 1070
+r0:=1/2*x^2*(c*x^2)^p/(a*(1+p)*(a+b*x)^(2*(1+p)))
+--R 
+--R
+--R                  2    2 p
+--R                 x (c x )
+--R   (2)  --------------------------
+--R                            2p + 2
+--R        (2a p + 2a)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        2
+--R            3      2   (- 2p - 3)log(b x + a)  p log(c x )
+--R        (b x  + a x )%e                      %e
+--R   (3)  --------------------------------------------------
+--R                             2a p + 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 220
+
+--S 221 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                  2
+--R       3      2          2p + 2  (- 2p - 3)log(b x + a)  p log(c x )    2    2 p
+--R   (b x  + a x )(b x + a)      %e                      %e            - x (c x )
+--R   -----------------------------------------------------------------------------
+--R                                                 2p + 2
+--R                             (2a p + 2a)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 1070
+t0:=(c*x^2)^p*(a+b*x)^(-2-2*p)
+--R 
+--R
+--R                 - 2p - 2    2 p
+--R   (1)  (b x + a)        (c x )
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 1070
+r0:=x*(c*x^2)^p*(a+b*x)^(-1-2*p)/(a*(1+2*p))
+--R 
+--R
+--R                   - 2p - 1    2 p
+--R        x (b x + a)        (c x )
+--R   (2)  --------------------------
+--R                 2a p + a
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                       2
+--R            2         (- 2p - 2)log(b x + a)  p log(c x )
+--R        (b x  + a x)%e                      %e
+--R   (3)  -------------------------------------------------
+--R                             2a p + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 225
+
+--S 226 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      2
+--R           2         (- 2p - 2)log(b x + a)  p log(c x )
+--R       (b x  + a x)%e                      %e
+--R     + 
+--R                    - 2p - 1    2 p
+--R       - x (b x + a)        (c x )
+--R  /
+--R     2a p + a
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 227
+
+)clear all
+
+--S 228 of 1070
+t0:=(c*x^2)^p*(a+b*x)^(-1-2*p)/x
+--R 
+--R
+--R                 - 2p - 1    2 p
+--R        (b x + a)        (c x )
+--R   (1)  ------------------------
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 228
+
+--S 229 of 1070
+r0:=1/2*(c*x^2)^p/(a*p*(a+b*x)^(2*p))
+--R 
+--R
+--R                 2 p
+--R             (c x )
+--R   (2)  ----------------
+--R                      2p
+--R        2a p (b x + a)
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                    2
+--R                   (- 2p - 1)log(b x + a)  p log(c x )
+--R        (b x + a)%e                      %e
+--R   (3)  ----------------------------------------------
+--R                             2a p
+--R                                         Type: Union(Expression(Integer),...)
+--E 230
+
+--S 231 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                                                               2
+--R                          2p  (- 2p - 1)log(b x + a)  p log(c x )       2 p
+--R        (b x + a)(b x + a)  %e                      %e            - (c x )
+--R   (4)  -------------------------------------------------------------------
+--R                                                2p
+--R                                  2a p (b x + a)
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 232
+
+)clear all
+
+--S 233 of 1070
+t0:=(c*x^2)^p/(x^2*(a+b*x)^(2*p))
+--R 
+--R
+--R               2 p
+--R           (c x )
+--R   (1)  -------------
+--R         2         2p
+--R        x (b x + a)
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 1070
+r0:=-(c*x^2)^p*(a+b*x)^(1-2*p)/(a*(1-2*p)*x)
+--R 
+--R
+--R                 - 2p + 1    2 p
+--R        (b x + a)        (c x )
+--R   (2)  ------------------------
+--R               (2a p - a)x
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                2
+--R                       p log(c x )
+--R            (b x + a)%e
+--R   (3)  -----------------------------
+--R                      2p log(b x + a)
+--R        (2a p - a)x %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 235
+
+--S 236 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                            2
+--R                   p log(c x )            - 2p + 1    2 p  2p log(b x + a)
+--R        (b x + a)%e            - (b x + a)        (c x ) %e
+--R   (4)  ------------------------------------------------------------------
+--R                                         2p log(b x + a)
+--R                           (2a p - a)x %e
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 1070
+t0:=(c*x^2)^p*(a+b*x)^(1-2*p)/x^3
+--R 
+--R
+--R                 - 2p + 1    2 p
+--R        (b x + a)        (c x )
+--R   (1)  ------------------------
+--R                    3
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 1070
+r0:=-1/2*(c*x^2)^p*(a+b*x)^(2-2*p)/(a*(1-p)*x^2)
+--R 
+--R
+--R                 - 2p + 2    2 p
+--R        (b x + a)        (c x )
+--R   (2)  ------------------------
+--R                          2
+--R              (2a p - 2a)x
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                    2
+--R                   (- 2p + 1)log(b x + a)  p log(c x )
+--R        (b x + a)%e                      %e
+--R   (3)  ----------------------------------------------
+--R                                     2
+--R                         (2a p - 2a)x
+--R                                         Type: Union(Expression(Integer),...)
+--E 240
+
+--S 241 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               2
+--R              (- 2p + 1)log(b x + a)  p log(c x )            - 2p + 2    2 p
+--R   (b x + a)%e                      %e            - (b x + a)        (c x )
+--R   -------------------------------------------------------------------------
+--R                                             2
+--R                                 (2a p - 2a)x
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 242
+
+)clear all
+
+--S 243 of 1070
+t0:=(c*x^2)^p*(a+b*x)^(2-2*p)/x^4
+--R 
+--R
+--R                 - 2p + 2    2 p
+--R        (b x + a)        (c x )
+--R   (1)  ------------------------
+--R                    4
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 243
+
+--S 244 of 1070
+r0:=-(c*x^2)^p*(a+b*x)^(3-2*p)/(a*(3-2*p)*x^3)
+--R 
+--R
+--R                 - 2p + 3    2 p
+--R        (b x + a)        (c x )
+--R   (2)  ------------------------
+--R                          3
+--R              (2a p - 3a)x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                    2
+--R                   (- 2p + 2)log(b x + a)  p log(c x )
+--R        (b x + a)%e                      %e
+--R   (3)  ----------------------------------------------
+--R                                     3
+--R                         (2a p - 3a)x
+--R                                         Type: Union(Expression(Integer),...)
+--E 245
+
+--S 246 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               2
+--R              (- 2p + 2)log(b x + a)  p log(c x )            - 2p + 3    2 p
+--R   (b x + a)%e                      %e            - (b x + a)        (c x )
+--R   -------------------------------------------------------------------------
+--R                                             3
+--R                                 (2a p - 3a)x
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 247
+
+)clear all
+
+--S 248 of 1070
+t0:=sqrt(a*x^23)/sqrt(1+x^5)
+--R 
+--R
+--R          +-----+
+--R          |   23
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 5
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 1070
+r0:=3/20*asinh(x^(5/2))*sqrt(a*x^23)/x^(23/2)-3/20*sqrt(a*x^23)*_
+   sqrt(1+x^5)/x^9+1/10*sqrt(a*x^23)*sqrt(1+x^5)/x^4
+--R 
+--R
+--R          +-----+                                +------+ +-----+
+--R          |   23        2 +-+       7     2  +-+ | 5      |   23
+--R        3\|a x   asinh(x \|x ) + (2x  - 3x )\|x \|x  + 1 \|a x
+--R   (2)  ---------------------------------------------------------
+--R                                   11 +-+
+--R                                20x  \|x
+--R                                                    Type: Expression(Integer)
+--E 249
+
+--S 250 of 1070
+--a0:=integrate(t0,x)
+--E 250
+
+--S 251 of 1070
+--m0:=a0-r0
+--E 251
+
+--S 252 of 1070
+--d0:=normalize(D(m0,x))
+--E 252
+
+)clear all
+
+--S 253 of 1070
+t0:=sqrt(a*x^13)/sqrt(1+x^5)
+--R 
+--R
+--R          +-----+
+--R          |   13
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 5
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 1070
+r0:=-1/5*asinh(x^(5/2))*sqrt(a*x^13)/x^(13/2)+1/5*sqrt(a*x^13)*sqrt(1+x^5)/x^4
+--R 
+--R
+--R           +-----+                       +------+ +-----+
+--R           |   13        2 +-+     2 +-+ | 5      |   13
+--R        - \|a x   asinh(x \|x ) + x \|x \|x  + 1 \|a x
+--R   (2)  -------------------------------------------------
+--R                               6 +-+
+--R                             5x \|x
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 1070
+--a0:=integrate(t0,x)
+--E 255
+
+--S 256 of 1070
+--m0:=a0-r0
+--E 256
+
+--S 257 of 1070
+--d0:=normalize(D(m0,x))
+--E 257
+
+)clear all
+
+--S 258 of 1070
+t0:=sqrt(a*x^3)/sqrt(1+x^5)
+--R 
+--R
+--R          +----+
+--R          |   3
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 5
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 258
+
+--S 259 of 1070
+r0:=2/5*asinh(x^(5/2))*sqrt(a*x^3)/x^(3/2)
+--R 
+--R
+--R          +----+
+--R          |   3        2 +-+
+--R        2\|a x  asinh(x \|x )
+--R   (2)  ---------------------
+--R                   +-+
+--R                5x\|x
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 1070
+--a0:=integrate(t0,x)
+--E 260
+
+--S 261 of 1070
+--m0:=a0-r0
+--E 261
+
+--S 262 of 1070
+--d0:=normalize(D(m0,x))
+--E 262
+
+)clear all
+
+--S 263 of 1070
+t0:=sqrt(a/x^7)/sqrt(1+x^5)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 7
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 5
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 1070
+r0:=-2/5*x*sqrt(a/x^7)*sqrt(1+x^5)
+--R 
+--R
+--R             +--+ +------+
+--R             | a  | 5
+--R          2x |-- \|x  + 1
+--R             | 7
+--R            \|x
+--R   (2)  - ----------------
+--R                  5
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +-+ +------+
+--R             |a  | 5                2
+--R        - 4  |- \|x  + 1 + (8a + 1)x
+--R            \|x
+--R   (3)  -----------------------------
+--R                        2
+--R                     10x
+--R                                         Type: Union(Expression(Integer),...)
+--E 265
+
+--S 266 of 1070
+m0:=a0-r0
+--R 
+--R
+--R              +-+      +--+  +------+
+--R              |a     3 | a   | 5                 2
+--R        (- 4  |- + 4x  |-- )\|x  + 1  + (8a + 1)x
+--R             \|x       | 7
+--R                      \|x
+--R   (4)  ------------------------------------------
+--R                              2
+--R                           10x
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +-+        +--+
+--R             |a       3 | a
+--R         - a |-  + a x  |--
+--R            \|x         | 7
+--R                       \|x
+--R   (5)  --------------------
+--R           +--+ +-+ +------+
+--R         7 | a  |a  | 5
+--R        x  |--  |- \|x  + 1
+--R           | 7 \|x
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 1070
+t0:=sqrt(a/x^17)/sqrt(1+x^5)
+--R 
+--R
+--R           +---+
+--R           | a
+--R           |---
+--R           | 17
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 5
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 1070
+r0:=-2/15*x*sqrt(a/x^17)*sqrt(1+x^5)+4/15*x^6*sqrt(a/x^17)*sqrt(1+x^5)
+--R 
+--R
+--R                   +---+ +------+
+--R           6       | a   | 5
+--R        (4x  - 2x) |--- \|x  + 1
+--R                   | 17
+--R                  \|x
+--R   (2)  -------------------------
+--R                    15
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +-+ +------+
+--R            5      |a  | 5                   7
+--R        (12x  - 6) |- \|x  + 1  + (- 9a - 2)x
+--R                  \|x
+--R   (3)  --------------------------------------
+--R                            7
+--R                         45x
+--R                                         Type: Union(Expression(Integer),...)
+--E 270
+
+--S 271 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                    +-+                   +---+  +------+
+--R             5      |a          13     8  | a    | 5                   7
+--R        ((12x  - 6) |-  + (- 12x   + 6x ) |--- )\|x  + 1  + (- 9a - 2)x
+--R                   \|x                    | 17
+--R                                         \|x
+--R   (4)  ----------------------------------------------------------------
+--R                                         7
+--R                                      45x
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R             +-+        +---+
+--R             |a       8 | a
+--R         - a |-  + a x  |---
+--R            \|x         | 17
+--R                       \|x
+--R   (5)  ----------------------
+--R            +---+ +-+ +------+
+--R         17 | a   |a  | 5
+--R        x   |---  |- \|x  + 1
+--R            | 17 \|x
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 272
+
+)clear all
+
+--S 273 of 1070
+t0:=sqrt(a*x^6)/(x*(1-x^4))
+--R 
+--R
+--R           +----+
+--R           |   6
+--R          \|a x
+--R   (1)  - -------
+--R            5
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 273
+
+--S 274 of 1070
+r0:=-1/2*atan(x)*sqrt(a*x^6)/x^3+1/2*atanh(x)*sqrt(a*x^6)/x^3
+--R 
+--R
+--R                             +----+
+--R                             |   6
+--R        (atanh(x) - atan(x))\|a x
+--R   (2)  ---------------------------
+--R                      3
+--R                    2x
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             x + 1              +-+
+--R        (log(-----) - 2atan(x))\|a
+--R             x - 1
+--R   (3)  ---------------------------
+--R                     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 275
+
+--S 276 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                                 +----+
+--R                                 |   6      3    x + 1      3         +-+
+--R        (- 2atanh(x) + 2atan(x))\|a x   + (x log(-----) - 2x atan(x))\|a
+--R                                                 x - 1
+--R   (4)  -----------------------------------------------------------------
+--R                                         3
+--R                                       4x
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R           2 +-+ |   6       5
+--R        - x \|a \|a x   + a x
+--R   (5)  ----------------------
+--R                     +----+
+--R              4      |   6
+--R            (x  - 1)\|a x
+--R                                                    Type: Expression(Integer)
+--E 277
+
+)clear all
+
+--S 278 of 1070
+t0:=sqrt(a*x^6)/(x-x^5)
+--R 
+--R
+--R           +----+
+--R           |   6
+--R          \|a x
+--R   (1)  - -------
+--R            5
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 1070
+r0:=-1/2*atan(x)*sqrt(a*x^6)/x^3+1/2*atanh(x)*sqrt(a*x^6)/x^3
+--R 
+--R
+--R                             +----+
+--R                             |   6
+--R        (atanh(x) - atan(x))\|a x
+--R   (2)  ---------------------------
+--R                      3
+--R                    2x
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             x + 1              +-+
+--R        (log(-----) - 2atan(x))\|a
+--R             x - 1
+--R   (3)  ---------------------------
+--R                     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 280
+
+--S 281 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                                 +----+
+--R                                 |   6      3    x + 1      3         +-+
+--R        (- 2atanh(x) + 2atan(x))\|a x   + (x log(-----) - 2x atan(x))\|a
+--R                                                 x - 1
+--R   (4)  -----------------------------------------------------------------
+--R                                         3
+--R                                       4x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                 +----+
+--R           2 +-+ |   6       5
+--R        - x \|a \|a x   + a x
+--R   (5)  ----------------------
+--R                     +----+
+--R              4      |   6
+--R            (x  - 1)\|a x
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 1070
+t0:=(a*x^6)^(3/2)/(x*(1-x^4))
+--R 
+--R
+--R               +----+
+--R             5 |   6
+--R          a x \|a x
+--R   (1)  - -----------
+--R              4
+--R             x  - 1
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 1070
+r0:=-a*sqrt(a*x^6)/x^2-1/5*a*x^2*sqrt(a*x^6)+1/2*a*atan(x)*sqrt(a*x^6)/x^3+_
+   1/2*a*atanh(x)*sqrt(a*x^6)/x^3
+--R 
+--R
+--R                                                   +----+
+--R                                        5          |   6
+--R        (5a atanh(x) + 5a atan(x) - 2a x  - 10a x)\|a x
+--R   (2)  -------------------------------------------------
+--R                                  3
+--R                               10x
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                x + 1                      5          +-+
+--R        (5a log(-----) + 10a atan(x) - 4a x  - 20a x)\|a
+--R                x - 1
+--R   (3)  -------------------------------------------------
+--R                                20
+--R                                         Type: Union(Expression(Integer),...)
+--E 285
+
+--S 286 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +----+
+--R                                           5          |   6
+--R       (- 10a atanh(x) - 10a atan(x) + 4a x  + 20a x)\|a x
+--R     + 
+--R            3    x + 1         3              8        4  +-+
+--R       (5a x log(-----) + 10a x atan(x) - 4a x  - 20a x )\|a
+--R                 x - 1
+--R  /
+--R        3
+--R     20x
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                   +----+
+--R             8 +-+ |   6     2 11
+--R        - a x \|a \|a x   + a x
+--R   (5)  -------------------------
+--R                      +----+
+--R               4      |   6
+--R             (x  - 1)\|a x
+--R                                                    Type: Expression(Integer)
+--E 287
+
+)clear all
+
+--S 288 of 1070
+t0:=1/(1-x^4)-sqrt(a*x^6)/(x*(1-x^4))
+--R 
+--R
+--R         +----+
+--R         |   6
+--R        \|a x   - x
+--R   (1)  -----------
+--R            5
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 288
+
+--S 289 of 1070
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(a*x^6)/x^3-1/2*atanh(x)*_
+   sqrt(a*x^6)/x^3
+--R 
+--R
+--R                               +----+
+--R                               |   6     3            3
+--R        (- atanh(x) + atan(x))\|a x   + x atanh(x) + x atan(x)
+--R   (2)  ------------------------------------------------------
+--R                                    3
+--R                                  2x
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +----------------------+
+--R             | +-----------+
+--R             | | 2               +-+
+--R            \|\|a  + 2a + 1  - 2\|a
+--R         *
+--R                                           +----------------------+
+--R                    +-----------+          | +-----------+
+--R                +-+ | 2                    | | 2               +-+      2
+--R          log((\|a \|a  + 2a + 1  + a + 1)\|\|a  + 2a + 1  - 2\|a   + (a  - 1)x)
+--R     + 
+--R          +----------------------+
+--R          | +-----------+
+--R          | | 2               +-+
+--R         \|\|a  + 2a + 1  - 2\|a
+--R      *
+--R                                          +----------------------+
+--R                   +-----------+          | +-----------+
+--R               +-+ | 2                    | | 2               +-+      2
+--R       log((- \|a \|a  + 2a + 1  - a - 1)\|\|a  + 2a + 1  - 2\|a   + (a  - 1)x)
+--R     + 
+--R       -
+--R              +----------------------+
+--R              | +-----------+
+--R              | | 2               +-+
+--R            2\|\|a  + 2a + 1  + 2\|a
+--R         *
+--R                                              +----------------------+
+--R                       +-----------+          | +-----------+
+--R                   +-+ | 2                    | | 2               +-+
+--R                 (\|a \|a  + 2a + 1  - a - 1)\|\|a  + 2a + 1  + 2\|a
+--R            atan(-----------------------------------------------------)
+--R                                         2
+--R                                       (a  - 1)x
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 290
+
+--S 291 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R               +----------------------+
+--R               | +-----------+
+--R             3 | | 2               +-+
+--R            x \|\|a  + 2a + 1  - 2\|a
+--R         *
+--R                                           +----------------------+
+--R                    +-----------+          | +-----------+
+--R                +-+ | 2                    | | 2               +-+      2
+--R          log((\|a \|a  + 2a + 1  + a + 1)\|\|a  + 2a + 1  - 2\|a   + (a  - 1)x)
+--R     + 
+--R            +----------------------+
+--R            | +-----------+
+--R          3 | | 2               +-+
+--R         x \|\|a  + 2a + 1  - 2\|a
+--R      *
+--R                                          +----------------------+
+--R                   +-----------+          | +-----------+
+--R               +-+ | 2                    | | 2               +-+      2
+--R       log((- \|a \|a  + 2a + 1  - a - 1)\|\|a  + 2a + 1  - 2\|a   + (a  - 1)x)
+--R     + 
+--R       -
+--R                +----------------------+
+--R                | +-----------+
+--R              3 | | 2               +-+
+--R            2x \|\|a  + 2a + 1  + 2\|a
+--R         *
+--R                                              +----------------------+
+--R                       +-----------+          | +-----------+
+--R                   +-+ | 2                    | | 2               +-+
+--R                 (\|a \|a  + 2a + 1  - a - 1)\|\|a  + 2a + 1  + 2\|a
+--R            atan(-----------------------------------------------------)
+--R                                         2
+--R                                       (a  - 1)x
+--R     + 
+--R                              +----+
+--R                              |   6      3             3
+--R       (2atanh(x) - 2atan(x))\|a x   - 2x atanh(x) - 2x atan(x)
+--R  /
+--R       3
+--R     4x
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R         2 +-+ |   6       5
+--R        x \|a \|a x   - a x
+--R   (5)  --------------------
+--R                    +----+
+--R             4      |   6
+--R           (x  - 1)\|a x
+--R                                                    Type: Expression(Integer)
+--E 292
+
+)clear all
+
+--S 293 of 1070
+t0:=1/(1-x^4)-sqrt(a*x^6)/(x-x^5)
+--R 
+--R
+--R         +----+
+--R         |   6
+--R        \|a x   - x
+--R   (1)  -----------
+--R            5
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 1070
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(a*x^6)/x^3-_
+   1/2*atanh(x)*sqrt(a*x^6)/x^3
+--R 
+--R
+--R                               +----+
+--R                               |   6     3            3
+--R        (- atanh(x) + atan(x))\|a x   + x atanh(x) + x atan(x)
+--R   (2)  ------------------------------------------------------
+--R                                    3
+--R                                  2x
+--R                                                    Type: Expression(Integer)
+--E 294
+
+--S 295 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +----------------------+
+--R             | +-----------+
+--R             | | 2               +-+
+--R            \|\|a  + 2a + 1  - 2\|a
+--R         *
+--R                                           +----------------------+
+--R                    +-----------+          | +-----------+
+--R                +-+ | 2                    | | 2               +-+      2
+--R          log((\|a \|a  + 2a + 1  + a + 1)\|\|a  + 2a + 1  - 2\|a   + (a  - 1)x)
+--R     + 
+--R          +----------------------+
+--R          | +-----------+
+--R          | | 2               +-+
+--R         \|\|a  + 2a + 1  - 2\|a
+--R      *
+--R                                          +----------------------+
+--R                   +-----------+          | +-----------+
+--R               +-+ | 2                    | | 2               +-+      2
+--R       log((- \|a \|a  + 2a + 1  - a - 1)\|\|a  + 2a + 1  - 2\|a   + (a  - 1)x)
+--R     + 
+--R       -
+--R              +----------------------+
+--R              | +-----------+
+--R              | | 2               +-+
+--R            2\|\|a  + 2a + 1  + 2\|a
+--R         *
+--R                                              +----------------------+
+--R                       +-----------+          | +-----------+
+--R                   +-+ | 2                    | | 2               +-+
+--R                 (\|a \|a  + 2a + 1  - a - 1)\|\|a  + 2a + 1  + 2\|a
+--R            atan(-----------------------------------------------------)
+--R                                         2
+--R                                       (a  - 1)x
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 295
+
+--S 296 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R               +----------------------+
+--R               | +-----------+
+--R             3 | | 2               +-+
+--R            x \|\|a  + 2a + 1  - 2\|a
+--R         *
+--R                                           +----------------------+
+--R                    +-----------+          | +-----------+
+--R                +-+ | 2                    | | 2               +-+      2
+--R          log((\|a \|a  + 2a + 1  + a + 1)\|\|a  + 2a + 1  - 2\|a   + (a  - 1)x)
+--R     + 
+--R            +----------------------+
+--R            | +-----------+
+--R          3 | | 2               +-+
+--R         x \|\|a  + 2a + 1  - 2\|a
+--R      *
+--R                                          +----------------------+
+--R                   +-----------+          | +-----------+
+--R               +-+ | 2                    | | 2               +-+      2
+--R       log((- \|a \|a  + 2a + 1  - a - 1)\|\|a  + 2a + 1  - 2\|a   + (a  - 1)x)
+--R     + 
+--R       -
+--R                +----------------------+
+--R                | +-----------+
+--R              3 | | 2               +-+
+--R            2x \|\|a  + 2a + 1  + 2\|a
+--R         *
+--R                                              +----------------------+
+--R                       +-----------+          | +-----------+
+--R                   +-+ | 2                    | | 2               +-+
+--R                 (\|a \|a  + 2a + 1  - a - 1)\|\|a  + 2a + 1  + 2\|a
+--R            atan(-----------------------------------------------------)
+--R                                         2
+--R                                       (a  - 1)x
+--R     + 
+--R                              +----+
+--R                              |   6      3             3
+--R       (2atanh(x) - 2atan(x))\|a x   - 2x atanh(x) - 2x atan(x)
+--R  /
+--R       3
+--R     4x
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R         2 +-+ |   6       5
+--R        x \|a \|a x   - a x
+--R   (5)  --------------------
+--R                    +----+
+--R             4      |   6
+--R           (x  - 1)\|a x
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 1070
+t0:=sqrt(a*x^3)/(x-x^3)
+--R 
+--R
+--R           +----+
+--R           |   3
+--R          \|a x
+--R   (1)  - -------
+--R            3
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 1070
+r0:=-atan(sqrt(x))*sqrt(a*x^3)/x^(3/2)+atanh(sqrt(x))*sqrt(a*x^3)/x^(3/2)
+--R 
+--R
+--R         +----+               +----+
+--R         |   3        +-+     |   3       +-+
+--R        \|a x  atanh(\|x ) - \|a x  atan(\|x )
+--R   (2)  --------------------------------------
+--R                           +-+
+--R                         x\|x
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +-+ +---+                         +---+
+--R     +-+    2\|a \|a x  + a x + a      +-+     \|a x
+--R    \|a log(---------------------) - 2\|a atan(------)
+--R                    x - 1                        +-+
+--R                                                \|a
+--R   [--------------------------------------------------,
+--R                             2
+--R                  +---+ +---+                           +---+
+--R     +---+    - 2\|- a \|a x  + a x - a      +---+     \|a x
+--R    \|- a log(-------------------------) + 2\|- a atan(------)
+--R                        x + 1                           +---+
+--R                                                       \|- a
+--R    ----------------------------------------------------------]
+--R                                 2
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 300
+
+--S 301 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      +-+ +---+                +----+
+--R         +-+ +-+    2\|a \|a x  + a x + a      |   3        +-+
+--R       x\|a \|x log(---------------------) - 2\|a x  atanh(\|x )
+--R                            x - 1
+--R     + 
+--R                         +---+      +----+
+--R            +-+ +-+     \|a x       |   3       +-+
+--R       - 2x\|a \|x atan(------) + 2\|a x  atan(\|x )
+--R                          +-+
+--R                         \|a
+--R  /
+--R        +-+
+--R     2x\|x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R                                       +----+
+--R                     +---+        +-+  |   3        2 +-+ +---+    2 3    2 2
+--R        ((- a x - a)\|a x  - 2a x\|a )\|a x   + 2a x \|a \|a x  + a x  + a x
+--R   (5)  ---------------------------------------------------------------------
+--R                                                               +----+
+--R                     2      +-+ +---+      3      2            |   3
+--R                 ((2x  - 2)\|a \|a x  + a x  + a x  - a x - a)\|a x
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          +---+ +---+                +----+
+--R         +---+ +-+    - 2\|- a \|a x  + a x - a      |   3        +-+
+--R       x\|- a \|x log(-------------------------) - 2\|a x  atanh(\|x )
+--R                                x + 1
+--R     + 
+--R                         +---+      +----+
+--R          +---+ +-+     \|a x       |   3       +-+
+--R       2x\|- a \|x atan(------) + 2\|a x  atan(\|x )
+--R                         +---+
+--R                        \|- a
+--R  /
+--R        +-+
+--R     2x\|x
+--R                                                    Type: Expression(Integer)
+--E 303
+
+--S 304 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                  +----+
+--R              +---+        +---+  |   3        2 +---+ +---+    2 3    2 2
+--R   ((a x - a)\|a x  - 2a x\|- a )\|a x   + 2a x \|- a \|a x  - a x  + a x
+--R   -----------------------------------------------------------------------
+--R                                                            +----+
+--R                2      +---+ +---+      3      2            |   3
+--R            ((2x  - 2)\|- a \|a x  - a x  + a x  + a x - a)\|a x
+--R                                                    Type: Expression(Integer)
+--E 304
+
+)clear all
+
+--S 305 of 1070
+t0:=sqrt(a*x^4)/sqrt(1+x^2)
+--R 
+--R
+--R          +----+
+--R          |   4
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 1070
+r0:=-1/2*asinh(x)*sqrt(a*x^4)/x^2+1/2*sqrt(a*x^4)*sqrt(1+x^2)/x
+--R 
+--R
+--R           +------+             +----+
+--R           | 2                  |   4
+--R        (x\|x  + 1  - asinh(x))\|a x
+--R   (2)  ------------------------------
+--R                        2
+--R                      2x
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +------+                        +------+
+--R           +-+ | 2             2      +-+      | 2
+--R       (2x\|a \|x  + 1  + (- 2x  - 1)\|a )log(\|x  + 1  - x)
+--R     + 
+--R                       +------+
+--R            3      +-+ | 2           4     2  +-+
+--R       (- 2x  - x)\|a \|x  + 1  + (2x  + 2x )\|a
+--R  /
+--R        +------+
+--R        | 2          2
+--R     4x\|x  + 1  - 4x  - 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 307
+
+--S 308 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +------+                         +------+
+--R          3 +-+ | 2             4    2  +-+      | 2
+--R       (2x \|a \|x  + 1  + (- 2x  - x )\|a )log(\|x  + 1  - x)
+--R     + 
+--R                                  +------+
+--R                           3      | 2             2                  4     2
+--R         ((2x asinh(x) + 2x  + x)\|x  + 1  + (- 2x  - 1)asinh(x) - 2x  - 2x )
+--R      *
+--R          +----+
+--R          |   4
+--R         \|a x
+--R     + 
+--R                        +------+
+--R            5    3  +-+ | 2           6     4  +-+
+--R       (- 2x  - x )\|a \|x  + 1  + (2x  + 2x )\|a
+--R  /
+--R         +------+
+--R       3 | 2          4     2
+--R     4x \|x  + 1  - 4x  - 2x
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R         2 +-+ |   4       4
+--R        x \|a \|a x   - a x
+--R   (5)  --------------------
+--R           +------+ +----+
+--R           | 2      |   4
+--R          \|x  + 1 \|a x
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 1070
+t0:=sqrt(a*x^3)/sqrt(1+x^2)
+--R 
+--R
+--R          +----+
+--R          |   3
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 1070
+--r0:=2/3*(-1)^(3/4)*elliptic_f(asin((-1)^(1/4)*sqrt(x)),-1)*_
+--   sqrt(a*x^3)/x^(3/2)+2/3*sqrt(a*x^3)*sqrt(1+x^2)/x
+--E 311
+
+--S 312 of 1070
+--a0:=integrate(t0,x)
+--E 312
+
+--S 313 of 1070
+--m0:=a0-r0
+--E 313
+
+--S 314 of 1070
+--d0:=normalize(D(m0,x))
+--E 314
+
+)clear all
+
+--S 315 of 1070
+t0:=sqrt(a*x^2)/sqrt(1+x^2)
+--R 
+--R
+--R          +----+
+--R          |   2
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 315
+
+--S 316 of 1070
+r0:=sqrt(a*x^2)*sqrt(1+x^2)/x
+--R 
+--R
+--R         +------+ +----+
+--R         | 2      |   2
+--R        \|x  + 1 \|a x
+--R   (2)  ----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +------+
+--R            +-+ | 2          2      +-+
+--R        - x\|a \|x  + 1  + (x  + 1)\|a
+--R   (3)  -------------------------------
+--R                  +------+
+--R                  | 2
+--R                 \|x  + 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 317
+
+--S 318 of 1070
+m0:=a0-r0
+--R 
+--R
+--R           +------+           +----+          +------+
+--R           | 2         2      |   2     2 +-+ | 2          3      +-+
+--R        (x\|x  + 1  - x  - 1)\|a x   - x \|a \|x  + 1  + (x  + x)\|a
+--R   (4)  -------------------------------------------------------------
+--R                                 +------+
+--R                                 | 2         2
+--R                               x\|x  + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 318
+
+--S 319 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R              +----+
+--R          +-+ |   2       2
+--R        x\|a \|a x   - a x
+--R   (5)  -------------------
+--R           +------+ +----+
+--R           | 2      |   2
+--R          \|x  + 1 \|a x
+--R                                                    Type: Expression(Integer)
+--E 319
+
+)clear all
+
+--S 320 of 1070
+t0:=sqrt(a*x)/sqrt(1+x^2)
+--R 
+--R
+--R           +---+
+--R          \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 1070
+--r0:=-2*(-1)^(1/4)*elliptic_e(asin((-1)^(1/4)*sqrt(x)),-1)*_
+--   sqrt(a*x)/sqrt(x)+2*(-1)^(1/4)*elliptic_f(asin((-1)^(1/4)*sqrt(x)),-1)*_
+--   sqrt(a*x)/sqrt(x)
+--E 321
+
+--S 322 of 1070
+--a0:=integrate(t0,x)
+--E 322
+
+--S 323 of 1070
+--m0:=a0-r0
+--E 323
+
+--S 324 of 1070
+--d0:=normalize(D(m0,x))
+--E 324
+
+)clear all
+
+--S 325 of 1070
+t0:=sqrt(a/x)/sqrt(1+x^2)
+--R 
+--R
+--R            +-+
+--R            |a
+--R            |-
+--R           \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 1070
+--r0:=-2*(-1)^(3/4)*elliptic_f(asin((-1)^(1/4)*sqrt(x)),-1)*sqrt(a/x)*sqrt(x)
+--E 326
+
+--S 327 of 1070
+--a0:=integrate(t0,x)
+--E 327
+
+--S 328 of 1070
+--m0:=a0-r0
+--E 328
+
+--S 329 of 1070
+--d0:=normalize(D(m0,x))
+--E 329
+
+)clear all
+
+--S 330 of 1070
+t0:=sqrt(a/x^2)/sqrt(1+x^2)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 2
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 330
+
+--S 331 of 1070
+r0:=-x*atanh(sqrt(1+x^2))*sqrt(a/x^2)
+--R 
+--R
+--R            +--+       +------+
+--R            | a        | 2
+--R   (2)  - x |-- atanh(\|x  + 1 )
+--R            | 2
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +------+                               +------+
+--R                    | 2         2                          | 2
+--R     +-+    (x + 1)\|x  + 1  - x  - x - 1      +---+     a\|x  + 1  - a x
+--R   [\|a log(-----------------------------),- 2\|- a atan(----------------)]
+--R                     +------+                                +---+ +-+
+--R                     | 2         2                          \|- a \|a
+--R                   x\|x  + 1  - x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 332
+
+--S 333 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R                        +------+
+--R                        | 2         2              +--+       +------+
+--R         +-+    (x + 1)\|x  + 1  - x  - x - 1      | a        | 2
+--R   (4)  \|a log(-----------------------------) + x |-- atanh(\|x  + 1 )
+--R                         +------+                  | 2
+--R                         | 2         2            \|x
+--R                       x\|x  + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 333
+
+--S 334 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                         +--+
+--R                5     4     3     2      | a  +-+       4       3       2
+--R           (- 4x  - 4x  - 5x  - 3x  - x) |-- \|a  + 4a x  + 4a x  + 5a x  + 3a x
+--R                                         | 2
+--R                                        \|x
+--R         + 
+--R           a
+--R      *
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R     + 
+--R                                         +--+
+--R          6     5     4     3     2      | a  +-+       5       4       3
+--R       (4x  + 4x  + 7x  + 5x  + 3x  + x) |-- \|a  - 4a x  - 4a x  - 7a x
+--R                                         | 2
+--R                                        \|x
+--R     + 
+--R             2
+--R       - 5a x  - 3a x - a
+--R  /
+--R                                          +--+ +------+
+--R          7     6     5     4     3    2  | a  | 2
+--R       (4x  + 4x  + 7x  + 5x  + 3x  + x ) |-- \|x  + 1
+--R                                          | 2
+--R                                         \|x
+--R     + 
+--R                                                  +--+
+--R            8     7     6     5     4     3    2  | a
+--R       (- 4x  - 4x  - 9x  - 7x  - 6x  - 3x  - x ) |--
+--R                                                  | 2
+--R                                                 \|x
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                                               +------+
+--R          +--+       +------+                  | 2
+--R          | a        | 2           +---+     a\|x  + 1  - a x
+--R   (6)  x |-- atanh(\|x  + 1 ) - 2\|- a atan(----------------)
+--R          | 2                                    +---+ +-+
+--R         \|x                                    \|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R           +--+
+--R           | a  +-+
+--R         x |-- \|a  - a
+--R           | 2
+--R          \|x
+--R   (7)  ----------------
+--R           +--+ +------+
+--R         2 | a  | 2
+--R        x  |-- \|x  + 1
+--R           | 2
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 1070
+t0:=sqrt(a/x^3)/sqrt(1+x^2)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 3
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 1070
+--r0:=-2*(-1)^(1/4)*x^(3/2)*elliptic_e(asin((-1)^(1/4)*sqrt(x)),-1)*_
+--   sqrt(a/x^3)+2*(-1)^(1/4)*x^(3/2)*elliptic_f(asin((-1)^(1/4)*_
+--   sqrt(x)),-1)*sqrt(a/x^3)-2*x*sqrt(a/x^3)*sqrt(1+x^2)
+--E 338
+
+--S 339 of 1070
+--a0:=integrate(t0,x)
+--E 339
+
+--S 340 of 1070
+--m0:=a0-r0
+--E 340
+
+--S 341 of 1070
+--d0:=normalize(D(m0,x))
+--E 341
+
+)clear all
+
+--S 342 of 1070
+t0:=sqrt(a/x^4)/sqrt(1+x^2)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 4
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 1070
+r0:=-x*sqrt(a/x^4)*sqrt(1+x^2)
+--R 
+--R
+--R            +--+ +------+
+--R            | a  | 2
+--R   (2)  - x |-- \|x  + 1
+--R            | 4
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-+
+--R                \|a
+--R   (3)  - ---------------
+--R            +------+
+--R            | 2         2
+--R          x\|x  + 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 344
+
+--S 345 of 1070
+m0:=a0-r0
+--R 
+--R
+--R             +--+ +------+                    +--+
+--R           3 | a  | 2         +-+     4    2  | a
+--R        - x  |-- \|x  + 1  - \|a  + (x  + x ) |--
+--R             | 4                              | 4
+--R            \|x                              \|x
+--R   (4)  ------------------------------------------
+--R                        +------+
+--R                        | 2         2
+--R                      x\|x  + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 345
+
+--S 346 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R            +--+
+--R          2 | a  +-+
+--R         x  |-- \|a  - a
+--R            | 4
+--R           \|x
+--R   (5)  ----------------
+--R           +--+ +------+
+--R         4 | a  | 2
+--R        x  |-- \|x  + 1
+--R           | 4
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 346
+
+)clear all
+
+--S 347 of 1070
+t0:=sqrt(a*x^4)/sqrt(1+x^3)
+--R 
+--R
+--R          +----+
+--R          |   4
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 1070
+r0:=2/3*sqrt(a*x^4)*sqrt(1+x^3)/x^2
+--R 
+--R
+--R          +------+ +----+
+--R          | 3      |   4
+--R        2\|x  + 1 \|a x
+--R   (2)  -----------------
+--R                 2
+--R               3x
+--R                                                    Type: Expression(Integer)
+--E 348
+
+--S 349 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +------+
+--R          +-+ | 3
+--R        2\|a \|x  + 1
+--R   (3)  --------------
+--R               3
+--R                                         Type: Union(Expression(Integer),...)
+--E 349
+
+--S 350 of 1070
+m0:=a0-r0
+--R 
+--R
+--R            +------+ +----+           +------+
+--R            | 3      |   4      2 +-+ | 3
+--R        - 2\|x  + 1 \|a x   + 2x \|a \|x  + 1
+--R   (4)  --------------------------------------
+--R                            2
+--R                          3x
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R               +----+
+--R         2 +-+ |   4       4
+--R        x \|a \|a x   - a x
+--R   (5)  --------------------
+--R           +------+ +----+
+--R           | 3      |   4
+--R          \|x  + 1 \|a x
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 1070
+t0:=sqrt(a*x^3)/sqrt(1+x^3)
+--R 
+--R
+--R          +----+
+--R          |   3
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 1070
+--r0:=2/5*x*hypergeometric(1/2,5/6,11/6,-x^3)*sqrt(a*x^3)
+--E 353
+
+--S 354 of 1070
+--a0:=integrate(t0,x)
+--E 354
+
+--S 355 of 1070
+--m0:=a0-r0
+--E 355
+
+--S 356 of 1070
+--d0:=normalize(D(m0,x))
+--E 356
+
+)clear all
+
+--S 357 of 1070
+t0:=sqrt(a*x^2)/sqrt(1+x^3)
+--R 
+--R
+--R          +----+
+--R          |   2
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 1070
+--r0:=(1/2+1/2*%i)*(1+x)*elliptic_e(%i*asinh((1/2+1/2*%i)*sqrt(1-2*x+%i*_
+--   sqrt(3))/3^(1/4)),-2*sqrt(3)/(3*%i-sqrt(3)))*sqrt(a*x^2)*sqrt(%i*_
+--   (1-2*x-%i*sqrt(3)))*sqrt(1-2*x+%i*sqrt(3))/(x*sqrt(1+x^3)*_
+--   sqrt((1+x)/(3+%i*sqrt(3))))+(-1-%i)*elliptic_f(%i*asinh((1/2+1/2*%i)*_
+--   sqrt(1-2*x+%i*sqrt(3))/3^(1/4)),-2*sqrt(3)/(3*%i-sqrt(3)))*_
+--   sqrt(a*x^2)*sqrt(%i*(1-2*x-%i*sqrt(3)))*sqrt((1+x)/(3+%i*sqrt(3)))*_
+--   sqrt(1-2*x+%i*sqrt(3))/(x*sqrt(1+x^3))
+--E 358
+
+--S 359 of 1070
+--a0:=integrate(t0,x)
+--E 359
+
+--S 360 of 1070
+--m0:=a0-r0
+--E 360
+
+--S 361 of 1070
+--d0:=normalize(D(m0,x))
+--E 361
+
+)clear all
+
+--S 362 of 1070
+t0:=sqrt(a*x)/sqrt(1+x^3)
+--R 
+--R
+--R           +---+
+--R          \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 1070
+r0:=2/3*asinh(x^(3/2))*sqrt(a*x)/sqrt(x)
+--R 
+--R
+--R          +---+        +-+
+--R        2\|a x asinh(x\|x )
+--R   (2)  -------------------
+--R                 +-+
+--R               3\|x
+--R                                                    Type: Expression(Integer)
+--E 363
+
+--S 364 of 1070
+--a0:=integrate(t0,x)
+--E 364
+
+--S 365 of 1070
+--m0:=a0-r0
+--E 365
+
+--S 366 of 1070
+--d0:=normalize(D(m0,x))
+--E 366
+
+)clear all
+
+--S 367 of 1070
+t0:=sqrt(a/x)/sqrt(1+x^3)
+--R 
+--R
+--R            +-+
+--R            |a
+--R            |-
+--R           \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 1070
+--r0:=x*(1+x)*elliptic_f(acos((1+x*(1-sqrt(3)))/(1+x*(1+sqrt(3)))),1/4*_
+--   (2+sqrt(3)))*sqrt(a/x)*sqrt((1-x+x^2)/(1+x*(1+sqrt(3)))^2)/(3^(1/4)*_
+--   sqrt(1+x^3)*sqrt(x*(1+x)/(1+x*(1+sqrt(3)))^2))
+--E 368
+
+--S 369 of 1070
+--a0:=integrate(t0,x)
+--E 369
+
+--S 370 of 1070
+--m0:=a0-r0
+--E 370
+
+--S 371 of 1070
+--d0:=normalize(D(m0,x))
+--E 371
+
+)clear all
+
+--S 372 of 1070
+t0:=sqrt(a/x^2)/sqrt(1+x^3)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 2
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 372
+
+--S 373 of 1070
+r0:=-2/3*x*atanh(sqrt(1+x^3))*sqrt(a/x^2)
+--R 
+--R
+--R             +--+       +------+
+--R             | a        | 3
+--R          2x |-- atanh(\|x  + 1 )
+--R             | 2
+--R            \|x
+--R   (2)  - -----------------------
+--R                     3
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     +------+                           +------+
+--R                     | 3         3                      | 3
+--R          +-+    - 2\|x  + 1  + x  + 2      +---+     a\|x  + 1
+--R         \|a log(---------------------)   2\|- a atan(----------)
+--R                            3                          +---+ +-+
+--R                           x                          \|- a \|a
+--R   (3)  [------------------------------,- -----------------------]
+--R                        3                            3
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 374
+
+--S 375 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R                    +------+
+--R                    | 3         3           +--+       +------+
+--R         +-+    - 2\|x  + 1  + x  + 2       | a        | 3
+--R        \|a log(---------------------) + 2x |-- atanh(\|x  + 1 )
+--R                           3                | 2
+--R                          x                \|x
+--R   (4)  --------------------------------------------------------
+--R                                    3
+--R                                                    Type: Expression(Integer)
+--E 375
+
+--S 376 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R           +--+
+--R           | a  +-+
+--R         x |-- \|a  - a
+--R           | 2
+--R          \|x
+--R   (5)  ----------------
+--R           +--+ +------+
+--R         2 | a  | 3
+--R        x  |-- \|x  + 1
+--R           | 2
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                +------+
+--R           +--+       +------+                  | 3
+--R           | a        | 3           +---+     a\|x  + 1
+--R        2x |-- atanh(\|x  + 1 ) - 2\|- a atan(----------)
+--R           | 2                                 +---+ +-+
+--R          \|x                                 \|- a \|a
+--R   (6)  -------------------------------------------------
+--R                                3
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R           +--+
+--R           | a  +-+
+--R         x |-- \|a  - a
+--R           | 2
+--R          \|x
+--R   (7)  ----------------
+--R           +--+ +------+
+--R         2 | a  | 3
+--R        x  |-- \|x  + 1
+--R           | 2
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 1070
+t0:=sqrt(a/x^3)/sqrt(1+x^3)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 3
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 1070
+--r0:=4/5*x^4*hypergeometric(1/2,5/6,11/6,-x^3)*sqrt(a/x^3)-_
+--   2*x*sqrt(a/x^3)*sqrt(1+x^3)
+--E 380
+
+--S 381 of 1070
+--a0:=integrate(t0,x)
+--E 381
+
+--S 382 of 1070
+--m0:=a0-r0
+--E 382
+
+--S 383 of 1070
+--d0:=normalize(D(m0,x))
+--E 383
+
+)clear all
+
+--S 384 of 1070
+t0:=sqrt(a/x^4)/sqrt(1+x^3)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 4
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 384
+
+--S 385 of 1070
+--r0:=-x*sqrt(a/x^4)*sqrt(1+x^3)+(1/4+1/4*%i)*x^2*(1+x)*elliptic_e(%i*_
+--   asinh((1/2+1/2*%i)*sqrt(1-2*x+%i*sqrt(3))/3^(1/4)),-2*sqrt(3)/(3*%i-_
+--   sqrt(3)))*sqrt(a/x^4)*sqrt(%i*(1-2*x-%i*sqrt(3)))*sqrt(1-2*x+%i*_
+--   sqrt(3))/(sqrt(1+x^3)*sqrt((1+x)/(3+%i*sqrt(3))))+(-1/2-1/2*%i)*_
+--   x^2*elliptic_f(%i*asinh((1/2+1/2*%i)*sqrt(1-2*x+%i*sqrt(3))/3^(1/4)),_
+--   -2*sqrt(3)/(3*%i-sqrt(3)))*sqrt(a/x^4)*sqrt(%i*(1-2*x-%i*sqrt(3)))*_
+--   sqrt((1+x)/(3+%i*sqrt(3)))*sqrt(1-2*x+%i*sqrt(3))/sqrt(1+x^3)
+--E 385
+
+--S 386 of 1070
+--a0:=integrate(t0,x)
+--E 386
+
+--S 387 of 1070
+--m0:=a0-r0
+--E 387
+
+--S 388 of 1070
+--d0:=normalize(D(m0,x))
+--E 388
+
+)clear all
+
+--S 389 of 1070
+t0:=sqrt(a*x^(2*n))/sqrt(1+x^n)
+--R 
+--R
+--R          +-----+
+--R          |   2n
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | n
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 1070
+--r0:=-2*x^(1-n)*hypergeometric(1/2,1/n,1+1/n,-x^n)*sqrt(a*x^(2*n))/(2+n)+_
+--   2*x^(1-n)*sqrt(a*x^(2*n))*sqrt(1+x^n)/(2+n)
+--E 390
+
+--S 391 of 1070
+--a0:=integrate(t0,x)
+--E 391
+
+--S 392 of 1070
+--m0:=a0-r0
+--E 392
+
+--S 393 of 1070
+--d0:=normalize(D(m0,x))
+--E 393
+
+)clear all
+
+--S 394 of 1070
+t0:=sqrt(a*x^n)/sqrt(1+x^n)
+--R 
+--R
+--R          +----+
+--R          |   n
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | n
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 1070
+--r0:=2*x*hypergeometric(1/2,1/2*(1+2/n),1/2*(3+2/n),-x^n)*sqrt(a*x^n)/(2+n)
+--E 395
+
+--S 396 of 1070
+--a0:=integrate(t0,x)
+--E 396
+
+--S 397 of 1070
+--m0:=a0-r0
+--E 397
+
+--S 398 of 1070
+--d0:=normalize(D(m0,x))
+--E 398
+
+)clear all
+
+--S 399 of 1070
+t0:=sqrt(a*x^(1/2*n))/sqrt(1+x^n)
+--R 
+--R
+--R          +----+
+--R          |   n
+--R          |   -
+--R          |   2
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | n
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 399
+
+--S 400 of 1070
+--r0:=4*x*hypergeometric(1/2,1/4*(1+4/n),1/4*(5+4/n),-x^n)*_
+--   sqrt(a*x^(1/2*n))/(4+n)
+--E 400
+
+--S 401 of 1070
+--a0:=integrate(t0,x)
+--E 401
+
+--S 402 of 1070
+--m0:=a0-r0
+--E 402
+
+--S 403 of 1070
+--d0:=normalize(D(m0,x))
+--E 403
+
+)clear all
+
+--S 404 of 1070
+t0:=sqrt(a*x^(2*n))/sqrt(1+x^n)+2*sqrt(a*x^(2*n))/((2+n)*x^n*sqrt(1+x^n))
+--R 
+--R
+--R                        +-----+
+--R                 n      |   2n
+--R        ((n + 2)x  + 2)\|a x
+--R   (1)  -----------------------
+--R                     +------+
+--R                   n | n
+--R           (n + 2)x \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 1070
+r0:=2*x^(1-n)*sqrt(a*x^(2*n))*sqrt(1+x^n)/(2+n)
+--R 
+--R
+--R                  +------+ +-----+
+--R          - n + 1 | n      |   2n
+--R        2x       \|x  + 1 \|a x
+--R   (2)  --------------------------
+--R                   n + 2
+--R                                                    Type: Expression(Integer)
+--E 405
+
+-- integrate: implementation incomplete (constant residues)
+--S 406 of 1070
+--a0:=integrate(t0,x)
+--E 406
+
+--S 407 of 1070
+--m0:=a0-r0
+--E 407
+
+--S 408 of 1070
+--d0:=normalize(D(m0,x))
+--E 408
+
+)clear all
+
+--S 409 of 1070
+t0:=sqrt(a*x)/(sqrt(d+e*x)*sqrt(e+f*x))
+--R 
+--R
+--R                +---+
+--R               \|a x
+--R   (1)  --------------------
+--R         +-------+ +-------+
+--R        \|e x + d \|f x + e
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 1070
+--r0:=2*elliptic_e(asin(sqrt(f)*sqrt(d+e*x)/sqrt(-e^2+d*f)),1-e^2/(d*f))*_
+--   sqrt(-e^2+d*f)*sqrt(a*x)*sqrt(e*(e+f*x)/(e^2-d*f))/(e*sqrt(f)*_
+--   sqrt(-e*x/d)*sqrt(e+f*x))
+--E 410
+
+--S 411 of 1070
+--a0:=integrate(t0,x)
+--E 411
+
+--S 412 of 1070
+--m0:=a0-r0
+--E 412
+
+--S 413 of 1070
+--d0:=normalize(D(m0,x))
+--E 413
+
+)clear all
+
+--S 414 of 1070
+t0:=(a*x^m)^r
+--R 
+--R
+--R            m r
+--R   (1)  (a x )
+--R                                                    Type: Expression(Integer)
+--E 414
+
+--S 415 of 1070
+r0:=x*(a*x^m)^r/(1+m*r)
+--R 
+--R
+--R              m r
+--R        x (a x )
+--R   (2)  ---------
+--R         m r + 1
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R            m r log(x) + r log(a)
+--R        x %e
+--R   (3)  -------------------------
+--R                 m r + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 416
+
+--S 417 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                m r       m r log(x) + r log(a)
+--R        - x (a x )  + x %e
+--R   (4)  ---------------------------------------
+--R                        m r + 1
+--R                                                    Type: Expression(Integer)
+--E 417
+
+--S 418 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 418
+
+)clear all
+
+--S 419 of 1070
+t0:=(a*x^m)^r*(b*x^n)^s
+--R 
+--R
+--R            m r    n s
+--R   (1)  (a x ) (b x )
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 1070
+r0:=x*(a*x^m)^r*(b*x^n)^s/(1+m*r+n*s)
+--R 
+--R
+--R              m r    n s
+--R        x (a x ) (b x )
+--R   (2)  ----------------
+--R          n s + m r + 1
+--R                                                    Type: Expression(Integer)
+--E 420
+
+--S 421 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R            m r log(x) + r log(a)  n s log(x) + s log(b)
+--R        x %e                     %e
+--R   (3)  ------------------------------------------------
+--R                          n s + m r + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 421
+
+--S 422 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                m r    n s       m r log(x) + r log(a)  n s log(x) + s log(b)
+--R        - x (a x ) (b x )  + x %e                     %e
+--R   (4)  ---------------------------------------------------------------------
+--R                                    n s + m r + 1
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 1070
+t0:=(a*x^m)^r*(b*x^n)^s*(c*x^p)^t
+--R 
+--R
+--R            m r    n s    p t
+--R   (1)  (a x ) (b x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 1070
+r0:=x*(a*x^m)^r*(b*x^n)^s*(c*x^p)^t/(1+m*r+n*s+p*t)
+--R 
+--R
+--R              m r    n s    p t
+--R        x (a x ) (b x ) (c x )
+--R   (2)  -----------------------
+--R          p t + n s + m r + 1
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       m r log(x) + r log(a)  n s log(x) + s log(b)  p t log(x) + t log(c)
+--R   x %e                     %e                     %e
+--R   -----------------------------------------------------------------------
+--R                             p t + n s + m r + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 426
+
+--S 427 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               m r    n s    p t
+--R       - x (a x ) (b x ) (c x )
+--R     + 
+--R           m r log(x) + r log(a)  n s log(x) + s log(b)  p t log(x) + t log(c)
+--R       x %e                     %e                     %e
+--R  /
+--R     p t + n s + m r + 1
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 428
+
+)clear all
+
+--S 429 of 1070
+t0:=(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^p
+--R 
+--R
+--R              1         1     p
+--R              -         -
+--R            n n       n n
+--R   (1)  (c x ) (b (c x )  + a)
+--R                                                    Type: Expression(Integer)
+--E 429
+
+--S 430 of 1070
+r0:=-a*x*(a+b*(c*x^n)^(1/n))^(1+p)/(b^2*(1+p)*(c*x^n)^(1/n))+_
+   x*(a+b*(c*x^n)^(1/n))^(2+p)/(b^2*(2+p)*(c*x^n)^(1/n))
+--R 
+--R
+--R                          1     p + 2                          1     p + 1
+--R                          -                                    -
+--R                        n n                                  n n
+--R        (p + 1)x (b (c x )  + a)      + (- a p - 2a)x (b (c x )  + a)
+--R   (2)  ------------------------------------------------------------------
+--R                                                     1
+--R                                                     -
+--R                              2 2     2      2     n n
+--R                            (b p  + 3b p + 2b )(c x )
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                  log(c)
+--R                   log(c) 2             log(c)                    ------
+--R                   ------               ------                       n
+--R      2     2  2      n                    n      2   p log(b x %e       + a)
+--R   ((b p + b )x (%e      )  + a b p x %e       - a )%e
+--R   --------------------------------------------------------------------------
+--R                                                log(c)
+--R                                                ------
+--R                             2 2     2      2      n
+--R                           (b p  + 3b p + 2b )%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 431
+
+--S 432 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         log(c) 2             log(c)            1
+--R                         ------               ------            -
+--R            2     2  2      n                    n      2     n n
+--R         ((b p + b )x (%e      )  + a b p x %e       - a )(c x )
+--R      *
+--R                       log(c)
+--R                       ------
+--R                          n
+--R           p log(b x %e       + a)
+--R         %e
+--R     + 
+--R                    log(c)         1     p + 2
+--R                    ------         -
+--R                       n         n n
+--R       (- p - 1)x %e      (b (c x )  + a)
+--R     + 
+--R                     log(c)         1     p + 1
+--R                     ------         -
+--R                        n         n n
+--R       (a p + 2a)x %e      (b (c x )  + a)
+--R  /
+--R                          log(c)      1
+--R                          ------      -
+--R       2 2     2      2      n      n n
+--R     (b p  + 3b p + 2b )%e      (c x )
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 433
+
+)clear all
+
+--S 434 of 1070
+t0:=(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^3
+--R 
+--R
+--R                 1 4               1 3               1 2           1
+--R                 -                 -                 -             -
+--R         3     n n         2     n n       2       n n      3    n n
+--R   (1)  b ((c x ) )  + 3a b ((c x ) )  + 3a b ((c x ) )  + a (c x )
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 1070
+r0:=-1/4*a*x*(a+b*(c*x^n)^(1/n))^4/(b^2*(c*x^n)^(1/n))+_
+   1/5*x*(a+b*(c*x^n)^(1/n))^5/(b^2*(c*x^n)^(1/n))
+--R 
+--R
+--R   (2)
+--R                   1 5                  1 4                  1 3
+--R                   -                    -                    -
+--R         5       n n          4       n n        2 3       n n
+--R       4b x ((c x ) )  + 15a b x ((c x ) )  + 20a b x ((c x ) )
+--R     + 
+--R                      1 2
+--R                      -
+--R          3 2       n n      5
+--R       10a b x ((c x ) )  - a x
+--R  /
+--R               1
+--R               -
+--R        2    n n
+--R     20b (c x )
+--R                                                    Type: Expression(Integer)
+--E 435
+
+--S 436 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           log(c) 4              log(c) 3              log(c) 2           log(c)
+--R           ------                ------                ------             ------
+--R     3 5      n            2 4      n          2   3      n          3 2     n
+--R   4b x (%e      )  + 15a b x (%e      )  + 20a b x (%e      )  + 10a x %e
+--R   -----------------------------------------------------------------------------
+--R                                         20
+--R                                         Type: Union(Expression(Integer),...)
+--E 436
+
+--S 437 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     1 5                  1 4                  1 3
+--R                     -                    -                    -
+--R           5       n n          4       n n        2 3       n n
+--R       - 4b x ((c x ) )  - 15a b x ((c x ) )  - 20a b x ((c x ) )
+--R     + 
+--R                        1 2
+--R                        -
+--R            3 2       n n
+--R       - 10a b x ((c x ) )
+--R     + 
+--R                   log(c) 4              log(c) 3              log(c) 2
+--R                   ------                ------                ------
+--R             5 5      n            4 4      n          2 3 3      n
+--R           4b x (%e      )  + 15a b x (%e      )  + 20a b x (%e      )
+--R         + 
+--R                     log(c)
+--R                     ------
+--R              3 2 2     n
+--R           10a b x %e
+--R      *
+--R               1
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R        5
+--R       a x
+--R  /
+--R               1
+--R               -
+--R        2    n n
+--R     20b (c x )
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 1070
+t0:=(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^2
+--R 
+--R
+--R                 1 3               1 2           1
+--R                 -                 -             -
+--R         2     n n               n n      2    n n
+--R   (1)  b ((c x ) )  + 2a b ((c x ) )  + a (c x )
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 1070
+r0:=1/2*a^2*x*(c*x^n)^(1/n)+2/3*a*b*x*(c*x^n)^(2/n)+1/4*b^2*x*(c*x^n)^(3/n)
+--R 
+--R
+--R                   3                2              1
+--R                   -                -              -
+--R          2      n n              n n     2      n n
+--R        3b x (c x )  + 8a b x (c x )  + 6a x (c x )
+--R   (2)  --------------------------------------------
+--R                             12
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                log(c) 3             log(c) 2          log(c)
+--R                ------               ------            ------
+--R          2 4      n             3      n         2 2     n
+--R        3b x (%e      )  + 8a b x (%e      )  + 6a x %e
+--R   (3)  -----------------------------------------------------
+--R                                  12
+--R                                         Type: Union(Expression(Integer),...)
+--E 441
+
+--S 442 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    3                2              1           log(c) 3
+--R                    -                -              -           ------
+--R           2      n n              n n     2      n n     2 4      n
+--R       - 3b x (c x )  - 8a b x (c x )  - 6a x (c x )  + 3b x (%e      )
+--R     + 
+--R                 log(c) 2          log(c)
+--R                 ------            ------
+--R             3      n         2 2     n
+--R       8a b x (%e      )  + 6a x %e
+--R  /
+--R     12
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 443
+
+)clear all
+
+--S 444 of 1070
+t0:=(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))
+--R 
+--R
+--R                 1 2           1
+--R                 -             -
+--R               n n           n n
+--R   (1)  b ((c x ) )  + a (c x )
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 1070
+r0:=1/2*a*x*(c*x^n)^(1/n)+1/3*b*x*(c*x^n)^(2/n)
+--R 
+--R
+--R                   2              1
+--R                   -              -
+--R                 n n            n n
+--R        2b x (c x )  + 3a x (c x )
+--R   (2)  ---------------------------
+--R                     6
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                log(c) 2          log(c)
+--R                ------            ------
+--R            3      n           2     n
+--R        2b x (%e      )  + 3a x %e
+--R   (3)  --------------------------------
+--R                        6
+--R                                         Type: Union(Expression(Integer),...)
+--E 446
+
+--S 447 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                     2              1           log(c) 2          log(c)
+--R                     -              -           ------            ------
+--R                   n n            n n       3      n           2     n
+--R        - 2b x (c x )  - 3a x (c x )  + 2b x (%e      )  + 3a x %e
+--R   (4)  ----------------------------------------------------------------
+--R                                        6
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 448
+
+)clear all
+
+--S 449 of 1070
+t0:=(c*x^n)^(1/n)/(a+b*(c*x^n)^(1/n))
+--R 
+--R
+--R                 1
+--R                 -
+--R               n n
+--R           (c x )
+--R   (1)  -------------
+--R                1
+--R                -
+--R              n n
+--R        b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 1070
+r0:=x/b-a*x*log(a+b*(c*x^n)^(1/n))/(b^2*(c*x^n)^(1/n))
+--R 
+--R
+--R                          1                  1
+--R                          -                  -
+--R                        n n                n n
+--R        - a x log(b (c x )  + a) + b x (c x )
+--R   (2)  --------------------------------------
+--R                               1
+--R                               -
+--R                        2    n n
+--R                       b (c x )
+--R                                                    Type: Expression(Integer)
+--E 450
+
+--S 451 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      log(c)              log(c)
+--R                      ------              ------
+--R                         n                   n
+--R        - a log(b x %e       + a) + b x %e
+--R   (3)  ----------------------------------------
+--R                           log(c)
+--R                           ------
+--R                        2     n
+--R                       b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 451
+
+--S 452 of 1070
+m0:=a0-r0
+--R 
+--R
+--R              log(c)            1                1          log(c)
+--R              ------            -                -          ------
+--R                 n            n n              n n             n
+--R        a x %e      log(b (c x )  + a) - a (c x ) log(b x %e       + a)
+--R   (4)  ---------------------------------------------------------------
+--R                                   log(c)      1
+--R                                   ------      -
+--R                                2     n      n n
+--R                               b %e      (c x )
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 1070
+t0:=(c*x^n)^(1/n)/(a+b*(c*x^n)^(1/n))^2
+--R 
+--R
+--R                           1
+--R                           -
+--R                         n n
+--R                     (c x )
+--R   (1)  --------------------------------
+--R                 1 2              1
+--R                 -                -
+--R         2     n n              n n    2
+--R        b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 1070
+r0:=a*x/(b^2*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n)))+_
+   x*log(a+b*(c*x^n)^(1/n))/(b^2*(c*x^n)^(1/n))
+--R 
+--R
+--R                   1                   1
+--R                   -                   -
+--R                 n n                 n n
+--R        (b x (c x )  + a x)log(b (c x )  + a) + a x
+--R   (2)  -------------------------------------------
+--R                          1 2             1
+--R                          -               -
+--R                  3     n n        2    n n
+--R                 b ((c x ) )  + a b (c x )
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R               log(c)               log(c)
+--R               ------               ------
+--R                  n                    n
+--R        (b x %e       + a)log(b x %e       + a) + a
+--R   (3)  -------------------------------------------
+--R                      log(c) 2         log(c)
+--R                      ------           ------
+--R                3        n          2     n
+--R               b x (%e      )  + a b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 456
+
+--S 457 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     log(c) 2           log(c)       1            log(c) 2
+--R                     ------             ------       -            ------
+--R               2 2      n                  n       n n        2      n
+--R           (- b x (%e      )  - a b x %e      )(c x )  - a b x (%e      )
+--R         + 
+--R                   log(c)
+--R                   ------
+--R              2       n
+--R           - a x %e
+--R      *
+--R                     1
+--R                     -
+--R                   n n
+--R         log(b (c x )  + a)
+--R     + 
+--R                 log(c)              1 2            log(c)            1
+--R                 ------              -              ------            -
+--R            2       n              n n                 n      2     n n
+--R         ((b x %e       + a b)((c x ) )  + (a b x %e       + a )(c x ) )
+--R      *
+--R                   log(c)
+--R                   ------
+--R                      n
+--R         log(b x %e       + a)
+--R     + 
+--R                  1 2           1            log(c) 2         log(c)
+--R                  -             -            ------           ------
+--R                n n      2    n n        2      n        2       n
+--R       a b ((c x ) )  + a (c x )  - a b x (%e      )  - a x %e
+--R  /
+--R               log(c) 2         log(c)        1 2
+--R               ------           ------        -
+--R         4        n          3     n        n n
+--R       (b x (%e      )  + a b %e      )((c x ) )
+--R     + 
+--R                 log(c) 2         log(c)       1
+--R                 ------           ------       -
+--R           3        n        2 2     n       n n
+--R       (a b x (%e      )  + a b %e      )(c x )
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 458
+
+)clear all
+
+--S 459 of 1070
+t0:=(c*x^n)^(1/n)/(a+b*(c*x^n)^(1/n))^3
+--R 
+--R
+--R                                    1
+--R                                    -
+--R                                  n n
+--R                              (c x )
+--R   (1)  --------------------------------------------------
+--R                 1 3               1 2              1
+--R                 -                 -                -
+--R         3     n n         2     n n       2      n n    3
+--R        b ((c x ) )  + 3a b ((c x ) )  + 3a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 1070
+r0:=1/2*x*(c*x^n)^(1/n)/(a*(a+b*(c*x^n)^(1/n))^2)
+--R 
+--R
+--R                              1
+--R                              -
+--R                            n n
+--R                      x (c x )
+--R   (2)  ------------------------------------
+--R                    1 2              1
+--R                    -                -
+--R            2     n n       2      n n     3
+--R        2a b ((c x ) )  + 4a b (c x )  + 2a
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                  log(c)
+--R                                  ------
+--R                                     n
+--R                         - 2b x %e       - a
+--R   (3)  -----------------------------------------------------
+--R                log(c) 3             log(c) 2          log(c)
+--R                ------               ------            ------
+--R          4 2      n           3        n         2 2     n
+--R        2b x (%e      )  + 4a b x (%e      )  + 2a b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 461
+
+--S 462 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   log(c)               1 2
+--R                   ------               -
+--R              3       n      2 2      n n
+--R       (- 2a b x %e       - a b )((c x ) )
+--R     + 
+--R                 log(c) 3             log(c) 2            log(c)              1
+--R                 ------               ------              ------              -
+--R           4 3      n           3 2      n         2 2       n       3      n n
+--R       (- b x (%e      )  - 2a b x (%e      )  - 5a b x %e       - 2a b)(c x )
+--R     + 
+--R                  log(c)
+--R                  ------
+--R           3         n      4
+--R       - 2a b x %e       - a
+--R  /
+--R                  log(c) 3             log(c) 2          log(c)        1 2
+--R                  ------               ------            ------        -
+--R            6 2      n         2 5        n         3 4     n        n n
+--R       (2a b x (%e      )  + 4a b x (%e      )  + 2a b %e      )((c x ) )
+--R     + 
+--R                  log(c) 3             log(c) 2          log(c)       1
+--R                  ------               ------            ------       -
+--R          2 5 2      n         3 4        n         4 3     n       n n
+--R       (4a b x (%e      )  + 8a b x (%e      )  + 4a b %e      )(c x )
+--R     + 
+--R                 log(c) 3             log(c) 2          log(c)
+--R                 ------               ------            ------
+--R         3 4 2      n         4 3        n         5 2     n
+--R       2a b x (%e      )  + 4a b x (%e      )  + 2a b %e
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 463
+
+)clear all
+
+--S 464 of 1070
+t0:=(c*x^n)^(1/n)/(a+b*(c*x^n)^(1/n))^4
+--R 
+--R
+--R                                             1
+--R                                             -
+--R                                           n n
+--R                                       (c x )
+--R   (1)  --------------------------------------------------------------------
+--R                 1 4               1 3               1 2              1
+--R                 -                 -                 -                -
+--R         4     n n         3     n n       2 2     n n       3      n n    4
+--R        b ((c x ) )  + 4a b ((c x ) )  + 6a b ((c x ) )  + 4a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 1070
+r0:=1/3*a*x/(b^2*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^3)-_
+   1/2*x/(b^2*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^2)
+--R 
+--R
+--R                                            1
+--R                                            -
+--R                                          n n
+--R                               - 3b x (c x )  - a x
+--R   (2)  ------------------------------------------------------------------
+--R                  1 4                1 3                1 2              1
+--R                  -                  -                  -                -
+--R          5     n n          4     n n        2 3     n n       3 2    n n
+--R        6b ((c x ) )  + 18a b ((c x ) )  + 18a b ((c x ) )  + 6a b (c x )
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         log(c)
+--R                                         ------
+--R                                            n
+--R                                - 3b x %e       - a
+--R   ----------------------------------------------------------------------------
+--R           log(c) 4              log(c) 3              log(c) 2          log(c)
+--R           ------                ------                ------            ------
+--R     5 3      n            4 2      n          2 3        n         3 2     n
+--R   6b x (%e      )  + 18a b x (%e      )  + 18a b x (%e      )  + 6a b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 466
+
+--S 467 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 log(c)               1 4
+--R                 ------               -
+--R            4       n        3      n n
+--R       (- 3b x %e       - a b )((c x ) )
+--R     + 
+--R                   log(c)                1 3
+--R                   ------                -
+--R              3       n       2 2      n n
+--R       (- 9a b x %e       - 3a b )((c x ) )
+--R     + 
+--R                   log(c)               1 2
+--R                   ------               -
+--R            2 2       n       3       n n
+--R       (- 9a b x %e       - 3a b)((c x ) )
+--R     + 
+--R                log(c) 4             log(c) 3             log(c) 2            1
+--R                ------               ------               ------              -
+--R          4 4      n           3 3      n         2 2 2      n        4     n n
+--R       (3b x (%e      )  + 9a b x (%e      )  + 9a b x (%e      )  - a )(c x )
+--R     + 
+--R              log(c) 4             log(c) 3             log(c) 2         log(c)
+--R              ------               ------               ------           ------
+--R        3 4      n         2 2 3      n         3   2      n        4       n
+--R     a b x (%e      )  + 3a b x (%e      )  + 3a b x (%e      )  + a x %e
+--R  /
+--R                   log(c) 4              log(c) 3              log(c) 2
+--R                   ------                ------                ------
+--R             8 3      n            7 2      n          2 6        n
+--R           6b x (%e      )  + 18a b x (%e      )  + 18a b x (%e      )
+--R         + 
+--R                  log(c)
+--R                  ------
+--R             3 5     n
+--R           6a b %e
+--R      *
+--R                1 4
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                      log(c) 4              log(c) 3              log(c) 2
+--R                      ------                ------                ------
+--R                7 3      n          2 6 2      n          3 5        n
+--R           18a b x (%e      )  + 54a b x (%e      )  + 54a b x (%e      )
+--R         + 
+--R                   log(c)
+--R                   ------
+--R              4 4     n
+--R           18a b %e
+--R      *
+--R                1 3
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                      log(c) 4              log(c) 3              log(c) 2
+--R                      ------                ------                ------
+--R              2 6 3      n          3 5 2      n          4 4        n
+--R           18a b x (%e      )  + 54a b x (%e      )  + 54a b x (%e      )
+--R         + 
+--R                   log(c)
+--R                   ------
+--R              5 3     n
+--R           18a b %e
+--R      *
+--R                1 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                     log(c) 4              log(c) 3              log(c) 2
+--R                     ------                ------                ------
+--R             3 5 3      n          4 4 2      n          5 3        n
+--R           6a b x (%e      )  + 18a b x (%e      )  + 18a b x (%e      )
+--R         + 
+--R                  log(c)
+--R                  ------
+--R             6 2     n
+--R           6a b %e
+--R      *
+--R               1
+--R               -
+--R             n n
+--R         (c x )
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 1070
+t0:=(c*x^n)^(1/n)/(a+b*(c*x^n)^(1/n))^5
+--R 
+--R
+--R   (1)
+--R           1
+--R           -
+--R         n n
+--R     (c x )
+--R  /
+--R                1 5               1 4                1 3                1 2
+--R                -                 -                  -                  -
+--R        5     n n         4     n n        2 3     n n        3 2     n n
+--R       b ((c x ) )  + 5a b ((c x ) )  + 10a b ((c x ) )  + 10a b ((c x ) )
+--R     + 
+--R                  1
+--R                  -
+--R         4      n n    5
+--R       5a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 1070
+r0:=1/4*a*x/(b^2*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^4)-_
+   1/3*x/(b^2*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^3)
+--R 
+--R
+--R   (2)
+--R                  1
+--R                  -
+--R                n n
+--R     - 4b x (c x )  - a x
+--R  /
+--R                  1 5                1 4                1 3                1 2
+--R                  -                  -                  -                  -
+--R          6     n n          5     n n        2 4     n n        3 3     n n
+--R       12b ((c x ) )  + 48a b ((c x ) )  + 72a b ((c x ) )  + 48a b ((c x ) )
+--R     + 
+--R                   1
+--R                   -
+--R          4 2    n n
+--R       12a b (c x )
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              log(c)
+--R              ------
+--R                 n
+--R     - 4b x %e       - a
+--R  /
+--R                log(c) 5              log(c) 4              log(c) 3
+--R                ------                ------                ------
+--R          6 4      n            5 3      n          2 4 2      n
+--R       12b x (%e      )  + 48a b x (%e      )  + 72a b x (%e      )
+--R     + 
+--R                  log(c) 2           log(c)
+--R                  ------             ------
+--R          3 3        n          4 2     n
+--R       48a b x (%e      )  + 12a b %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 471
+
+--S 472 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 log(c)               1 5
+--R                 ------               -
+--R            5       n        4      n n
+--R       (- 4b x %e       - a b )((c x ) )
+--R     + 
+--R                    log(c)                1 4
+--R                    ------                -
+--R               4       n       2 3      n n
+--R       (- 16a b x %e       - 4a b )((c x ) )
+--R     + 
+--R                    log(c)                1 3
+--R                    ------                -
+--R             2 3       n       3 2      n n
+--R       (- 24a b x %e       - 6a b )((c x ) )
+--R     + 
+--R                    log(c)               1 2
+--R                    ------               -
+--R             3 2       n       4       n n
+--R       (- 16a b x %e       - 4a b)((c x ) )
+--R     + 
+--R                   log(c) 5              log(c) 4              log(c) 3
+--R                   ------                ------                ------
+--R             5 5      n            4 4      n          2 3 3      n
+--R           4b x (%e      )  + 16a b x (%e      )  + 24a b x (%e      )
+--R         + 
+--R                      log(c) 2
+--R                      ------
+--R              3 2 2      n        5
+--R           16a b x (%e      )  - a
+--R      *
+--R               1
+--R               -
+--R             n n
+--R         (c x )
+--R     + 
+--R                log(c) 5             log(c) 4             log(c) 3
+--R                ------               ------               ------
+--R          4 5      n         2 3 4      n         3 2 3      n
+--R       a b x (%e      )  + 4a b x (%e      )  + 6a b x (%e      )
+--R     + 
+--R                 log(c) 2         log(c)
+--R                 ------           ------
+--R         4   2      n        5       n
+--R       4a b x (%e      )  + a x %e
+--R  /
+--R                     log(c) 5              log(c) 4              log(c) 3
+--R                     ------                ------                ------
+--R              10 4      n            9 3      n          2 8 2      n
+--R           12b  x (%e      )  + 48a b x (%e      )  + 72a b x (%e      )
+--R         + 
+--R                      log(c) 2           log(c)
+--R                      ------             ------
+--R              3 7        n          4 6     n
+--R           48a b x (%e      )  + 12a b %e
+--R      *
+--R                1 5
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                      log(c) 5               log(c) 4               log(c) 3
+--R                      ------                 ------                 ------
+--R                9 4      n           2 8 3      n           3 7 2      n
+--R           48a b x (%e      )  + 192a b x (%e      )  + 288a b x (%e      )
+--R         + 
+--R                       log(c) 2           log(c)
+--R                       ------             ------
+--R               4 6        n          5 5     n
+--R           192a b x (%e      )  + 48a b %e
+--R      *
+--R                1 4
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                      log(c) 5               log(c) 4               log(c) 3
+--R                      ------                 ------                 ------
+--R              2 8 4      n           3 7 3      n           4 6 2      n
+--R           72a b x (%e      )  + 288a b x (%e      )  + 432a b x (%e      )
+--R         + 
+--R                       log(c) 2           log(c)
+--R                       ------             ------
+--R               5 5        n          6 4     n
+--R           288a b x (%e      )  + 72a b %e
+--R      *
+--R                1 3
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                      log(c) 5               log(c) 4               log(c) 3
+--R                      ------                 ------                 ------
+--R              3 7 4      n           4 6 3      n           5 5 2      n
+--R           48a b x (%e      )  + 192a b x (%e      )  + 288a b x (%e      )
+--R         + 
+--R                       log(c) 2           log(c)
+--R                       ------             ------
+--R               6 4        n          7 3     n
+--R           192a b x (%e      )  + 48a b %e
+--R      *
+--R                1 2
+--R                -
+--R              n n
+--R         ((c x ) )
+--R     + 
+--R                      log(c) 5              log(c) 4              log(c) 3
+--R                      ------                ------                ------
+--R              4 6 4      n          5 5 3      n          6 4 2      n
+--R           12a b x (%e      )  + 48a b x (%e      )  + 72a b x (%e      )
+--R         + 
+--R                      log(c) 2           log(c)
+--R                      ------             ------
+--R              7 3        n          8 2     n
+--R           48a b x (%e      )  + 12a b %e
+--R      *
+--R               1
+--R               -
+--R             n n
+--R         (c x )
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 473
+
+)clear all
+
+--S 474 of 1070
+t0:=x^4*(A+B*x+C*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           6      5      4
+--R        C x  + B x  + A x
+--R   (1)  ------------------
+--R             4      2
+--R          c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 474
+
+--S 475 of 1070
+r0:=(A*c-b*C)*x/c^2+1/2*B*x^2/c+1/3*C*x^3/c-1/4*b*B*log(a+b*x^2+c*x^4)/c^2-_
+   1/2*B*(b^2-2*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-_
+   4*a*c))-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(A*b*c-_
+   b^2*C+a*c*C+(-A*c*(b^2-2*a*c)+b*(b^2-3*a*c)*C)/sqrt(b^2-4*a*c))/_
+   (c^(5/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*(A*b*c-b^2*C+a*c*C+(A*c*(b^2-2*a*c)-_
+   b*(b^2-3*a*c)*C)/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +-----------+
+--R                                      2  |          2           2
+--R           ((- 12A b - 12C a)c + 12C b )\|- 4a c + b   - 24A a c
+--R         + 
+--R                 2                    3
+--R           (12A b  + 36C a b)c - 12C b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +-----------+
+--R                                      2  |          2           2
+--R           ((- 12A b - 12C a)c + 12C b )\|- 4a c + b   + 24A a c
+--R         + 
+--R                   2                    3
+--R           (- 12A b  - 36C a b)c + 12C b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                 2
+--R                          2  +-+ +-+         2c x  + b
+--R           (12B a c - 6B b )\|2 \|c atanh(--------------)
+--R                                           +-----------+
+--R                                           |          2
+--R                                          \|- 4a c + b
+--R         + 
+--R                      +-+       4      2
+--R               - 3B b\|2 log(c x  + b x  + a)
+--R             + 
+--R                      3         2                     +-+
+--R               (4C c x  + 6B c x  + (12A c - 12C b)x)\|2
+--R          *
+--R              +-----------+
+--R              |          2  +-+
+--R             \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R        2 +-+ |          2  +-+ |   |          2       | |          2
+--R     12c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               2
+--R             3c
+--R          *
+--R             ROOT
+--R                            6     2 5      2
+--R                    (- 12a c  + 3b c )%%BI1
+--R                  + 
+--R                            6     2 5                 4       3 3
+--R                    ((- 8a c  + 2b c )%%BI0 - 8B a b c  + 2B b c )%%BI1
+--R                  + 
+--R                            6     2 5      2              4       3 3
+--R                    (- 12a c  + 3b c )%%BI0  + (- 8B a b c  + 2B b c )%%BI0
+--R                  + 
+--R                         2                  2  2  3
+--R                    (- 3A a b + (- 4A C - 2B )a )c
+--R                  + 
+--R                    2 3           2     2 2   2            4     2   3      2 5
+--R                  (A b  + 8A C a b  + 5C a b)c  + (- 2A C b  - 5C a b )c + C b
+--R               /
+--R                      6    2 5
+--R                  4a c  - b c
+--R         + 
+--R               2          2
+--R           - 3c %%BI1 - 3c %%BI0 - 3B b
+--R      *
+--R         log
+--R                              3 3         2          2  4  11
+--R                          (64A a b + (128A C - 256A B )a )c
+--R                        + 
+--R                                   3 2 3          2          2  3 2
+--R                              - 96A a b  + (- 512A C + 384A B )a b
+--R                            + 
+--R                                       2       2   4        3 5
+--R                              (- 576A C  + 256B C)a b - 128C a
+--R                         *
+--R                             10
+--R                            c
+--R                        + 
+--R                                 3   5        2          2  2 4
+--R                              36A a b  + (424A C - 208A B )a b
+--R                            + 
+--R                                     2       2   3 3       3 4 2
+--R                              (992A C  - 384B C)a b  + 512C a b
+--R                         *
+--R                             9
+--R                            c
+--R                        + 
+--R                                  3 7          2         2    6
+--R                              - 4A b  + (- 124A C + 48A B )a b
+--R                            + 
+--R                                       2       2   2 5       3 3 4
+--R                              (- 580A C  + 208B C)a b  - 552C a b
+--R                         *
+--R                             8
+--R                            c
+--R                        + 
+--R                                  2        2  8          2      2     7
+--R                              (12A C - 4A B )b  + (140A C  - 48B C)a b
+--R                            + 
+--R                                  3 2 6
+--R                              252C a b
+--R                         *
+--R                             7
+--R                            c
+--R                        + 
+--R                                   2     2   9      3   8  6     3 10 5
+--R                          ((- 12A C  + 4B C)b  - 52C a b )c  + 4C b  c
+--R                     *
+--R                        %%BI0
+--R                    + 
+--R                           3   4 10
+--R                      - 32A B a c
+--R                    + 
+--R                             3   3 2       2           3  4
+--R                          32A B a b  + (32A B C - 32A B )a b
+--R                        + 
+--R                                    2      3   5
+--R                          (- 96A B C  + 64B C)a
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                               3   2 4         2           3  3 3
+--R                          - 14A B a b  + (- 56A B C + 40A B )a b
+--R                        + 
+--R                                  2      3   4 2        3 5
+--R                          (96A B C  - 80B C)a b  + 96B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                            3     6       2           3  2 5
+--R                          2A B a b  + (28A B C - 16A B )a b
+--R                        + 
+--R                                    2      3   3 4         3 4 3
+--R                          (- 10A B C  + 32B C)a b  - 104B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                               2          3    7             2     3   2 6
+--R                          (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                        + 
+--R                               3 3 5
+--R                          36B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                             2   8       3 2 7  5
+--R                      (2A B C a b  - 4B C a b )c
+--R                 *
+--R                    %%BI1
+--R                + 
+--R                           3   4 10
+--R                      - 32A B a c
+--R                    + 
+--R                             3   3 2       2           3  4
+--R                          32A B a b  + (32A B C - 32A B )a b
+--R                        + 
+--R                                    2      3   5
+--R                          (- 96A B C  + 64B C)a
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                               3   2 4         2           3  3 3
+--R                          - 14A B a b  + (- 56A B C + 40A B )a b
+--R                        + 
+--R                                  2      3   4 2        3 5
+--R                          (96A B C  - 80B C)a b  + 96B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                            3     6       2           3  2 5
+--R                          2A B a b  + (28A B C - 16A B )a b
+--R                        + 
+--R                                    2      3   3 4         3 4 3
+--R                          (- 10A B C  + 32B C)a b  - 104B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                               2          3    7             2     3   2 6
+--R                          (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                        + 
+--R                               3 3 5
+--R                          36B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                             2   8       3 2 7  5
+--R                      (2A B C a b  - 4B C a b )c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                      5 4 9
+--R                  - 8A a c
+--R                + 
+--R                      5 3 2       4       3 2  4          2 2         4  5  8
+--R                  (14A a b  + (52A C - 36A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                          5 2 4         4       3 2  3 3
+--R                      - 7A a b  + (- 73A C + 41A B )a b
+--R                    + 
+--R                             3 2      2 2         4  4 2
+--R                      (- 108A C  + 98A B C - 36A B )a b
+--R                    + 
+--R                          2 3        2 2      4   5         4     2 3  6
+--R                      (24A C  - 12A B C  + 16B C)a b + (8A C  - 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                       5   6       4       3 2  2 5
+--R                      A a b  + (31A C - 16A B )a b
+--R                    + 
+--R                           3 2      2 2         4  3 4
+--R                      (131A C  - 95A B C + 28A B )a b
+--R                    + 
+--R                          2 3        2 2      4   4 3           4      2 3  5 2
+--R                      (62A C  - 21A B C  - 20B C)a b  + (- 66A C  + 54B C )a b
+--R                    + 
+--R                           5 6
+--R                      - 12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                           4      3 2    7         3 2      2 2        4  2 6
+--R                      (- 4A C + 2A B )a b  + (- 50A C  + 34A B C - 9A B )a b
+--R                    + 
+--R                            2 3        2 2     4   3 5         4      2 3  4 4
+--R                      (- 89A C  + 38A B C  + 8B C)a b  + (36A C  - 53B C )a b
+--R                    + 
+--R                         5 5 3
+--R                      43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         3 2     2 2       4    8
+--R                      (6A C  - 4A B C + A B )a b
+--R                    + 
+--R                          2 3        2 2    4   2 7        4      2 3  3 6
+--R                      (34A C  - 16A B C  - B C)a b  + (7A C  + 18B C )a b
+--R                    + 
+--R                           5 4 5
+--R                      - 34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                        2 3       2 2    9          4     2 3  2 8      5 3 7  3
+--R                  ((- 4A C  + 2A B C )a b  + (- 7A C  - 2B C )a b  + 10C a b )c
+--R                + 
+--R                      4   10    5 2 9  2
+--R                  (A C a b   - C a b )c
+--R             *
+--R                ROOT
+--R                               6     2 5      2
+--R                       (- 12a c  + 3b c )%%BI1
+--R                     + 
+--R                               6     2 5                 4       3 3
+--R                       ((- 8a c  + 2b c )%%BI0 - 8B a b c  + 2B b c )%%BI1
+--R                     + 
+--R                               6     2 5      2              4       3 3
+--R                       (- 12a c  + 3b c )%%BI0  + (- 8B a b c  + 2B b c )%%BI0
+--R                     + 
+--R                            2                  2  2  3
+--R                       (- 3A a b + (- 4A C - 2B )a )c
+--R                     + 
+--R                         2 3           2     2 2   2            4     2   3
+--R                       (A b  + 8A C a b  + 5C a b)c  + (- 2A C b  - 5C a b )c
+--R                     + 
+--R                        2 5
+--R                       C b
+--R                  /
+--R                         6    2 5
+--R                     4a c  - b c
+--R            + 
+--R                          3 3         2          2  4  11
+--R                      (64A a b + (128A C - 256A B )a )c
+--R                    + 
+--R                               3 2 3          2          2  3 2
+--R                          - 96A a b  + (- 512A C + 384A B )a b
+--R                        + 
+--R                                   2       2   4        3 5
+--R                          (- 576A C  + 256B C)a b - 128C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                             3   5        2          2  2 4
+--R                          36A a b  + (424A C - 208A B )a b
+--R                        + 
+--R                                 2       2   3 3       3 4 2
+--R                          (992A C  - 384B C)a b  + 512C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                              3 7          2         2    6
+--R                          - 4A b  + (- 124A C + 48A B )a b
+--R                        + 
+--R                                   2       2   2 5       3 3 4
+--R                          (- 580A C  + 208B C)a b  - 552C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                           2        2  8          2      2     7       3 2 6  7
+--R                      ((12A C - 4A B )b  + (140A C  - 48B C)a b  + 252C a b )c
+--R                    + 
+--R                               2     2   9      3   8  6     3 10 5
+--R                      ((- 12A C  + 4B C)b  - 52C a b )c  + 4C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                       3   4 10
+--R                  - 32A B a c
+--R                + 
+--R                           3   3 2       2           3  4
+--R                        32A B a b  + (32A B C - 32A B )a b
+--R                      + 
+--R                                  2      3   5
+--R                        (- 96A B C  + 64B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                           3   2 4         2           3  3 3
+--R                      - 14A B a b  + (- 56A B C + 40A B )a b
+--R                    + 
+--R                              2      3   4 2        3 5
+--R                      (96A B C  - 80B C)a b  + 96B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                        3     6       2           3  2 5
+--R                      2A B a b  + (28A B C - 16A B )a b
+--R                    + 
+--R                                2      3   3 4         3 4 3
+--R                      (- 10A B C  + 32B C)a b  - 104B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           2          3    7             2     3   2 6
+--R                      (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                    + 
+--R                           3 3 5
+--R                      36B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         2   8       3 2 7  5
+--R                  (2A B C a b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BI1
+--R            + 
+--R                          3 3         2          2  4  11
+--R                      (64A a b + (128A C - 256A B )a )c
+--R                    + 
+--R                               3 2 3          2          2  3 2
+--R                          - 96A a b  + (- 512A C + 384A B )a b
+--R                        + 
+--R                                   2       2   4        3 5
+--R                          (- 576A C  + 256B C)a b - 128C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                             3   5        2          2  2 4
+--R                          36A a b  + (424A C - 208A B )a b
+--R                        + 
+--R                                 2       2   3 3       3 4 2
+--R                          (992A C  - 384B C)a b  + 512C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                              3 7          2         2    6
+--R                          - 4A b  + (- 124A C + 48A B )a b
+--R                        + 
+--R                                   2       2   2 5       3 3 4
+--R                          (- 580A C  + 208B C)a b  - 552C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                           2        2  8          2      2     7       3 2 6  7
+--R                      ((12A C - 4A B )b  + (140A C  - 48B C)a b  + 252C a b )c
+--R                    + 
+--R                               2     2   9      3   8  6     3 10 5
+--R                      ((- 12A C  + 4B C)b  - 52C a b )c  + 4C b  c
+--R                 *
+--R                         2
+--R                    %%BI0
+--R                + 
+--R                          3   3 2        2            3  4   9
+--R                      (64A B a b  + (128A B C - 256A B )a b)c
+--R                    + 
+--R                               3   2 4          2            3  3 3
+--R                          - 96A B a b  + (- 512A B C + 384A B )a b
+--R                        + 
+--R                                     2       3   4 2         3 5
+--R                          (- 576A B C  + 256B C)a b  - 128B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                             3     6        2            3  2 5
+--R                          36A B a b  + (424A B C - 208A B )a b
+--R                        + 
+--R                                   2       3   3 4         3 4 3
+--R                          (992A B C  - 384B C)a b  + 512B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              3   8          2           3    7
+--R                          - 4A B b  + (- 124A B C + 48A B )a b
+--R                        + 
+--R                                     2       3   2 6         3 3 5
+--R                          (- 580A B C  + 208B C)a b  - 552B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              2          3  9            2      3     8
+--R                          (12A B C - 4A B )b  + (140A B C  - 48B C)a b
+--R                        + 
+--R                                3 2 7
+--R                          252B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                 2     3   10        3   9  4       3 11 3
+--R                      ((- 12A B C  + 4B C)b   - 52B C a b )c  + 4B C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                    5 4 9
+--R                  8A a c
+--R                + 
+--R                        5 3 2         4      3 2  4        2 2         4  5  8
+--R                  (- 14A a b  + (- 52A C + 4A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                        5 2 4       4      3 2  3 3
+--R                      7A a b  + (73A C - 9A B )a b
+--R                    + 
+--R                           3 2      2 2        4  4 2
+--R                      (108A C  - 66A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   5           4     2 3  6
+--R                      (- 24A C  - 84A B C  + 48B C)a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6         4      3 2  2 5
+--R                      - A a b  + (- 31A C + 2A B )a b
+--R                    + 
+--R                             3 2      2 2         4  3 4
+--R                      (- 131A C  + 39A B C + 12A B )a b
+--R                    + 
+--R                            2 3         2 2      4   4 3         4      2 3  5 2
+--R                      (- 62A C  + 117A B C  - 60B C)a b  + (66A C  + 42B C )a b
+--R                    + 
+--R                         5 6
+--R                      12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4     7       3 2     2 2        4  2 6
+--R                      4A C a b  + (50A C  - 6A B C - 7A B )a b
+--R                    + 
+--R                          2 3        2 2      4   3 5           4      2 3  4 4
+--R                      (89A C  - 48A B C  + 24B C)a b  + (- 36A C  - 51B C )a b
+--R                    + 
+--R                           5 5 3
+--R                      - 43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3 2      4    8         2 3       2 2     4   2 7
+--R                      (- 6A C  + A B )a b  + (- 34A C  + 6A B C  - 3B C)a b
+--R                    + 
+--R                             4      2 3  3 6      5 4 5
+--R                      (- 7A C  + 18B C )a b  + 34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                     2 3   9        4     2 3  2 8      5 3 7  3
+--R                  (4A C a b  + (7A C  - 2B C )a b  - 10C a b )c
+--R                + 
+--R                        4   10    5 2 9  2
+--R                  (- A C a b   + C a b )c
+--R             *
+--R                %%BI1
+--R            + 
+--R                       3   4 10
+--R                  - 32A B a c
+--R                + 
+--R                           3   3 2       2           3  4
+--R                        32A B a b  + (32A B C - 32A B )a b
+--R                      + 
+--R                                  2      3   5
+--R                        (- 96A B C  + 64B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                           3   2 4         2           3  3 3
+--R                      - 14A B a b  + (- 56A B C + 40A B )a b
+--R                    + 
+--R                              2      3   4 2        3 5
+--R                      (96A B C  - 80B C)a b  + 96B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                        3     6       2           3  2 5
+--R                      2A B a b  + (28A B C - 16A B )a b
+--R                    + 
+--R                                2      3   3 4         3 4 3
+--R                      (- 10A B C  + 32B C)a b  - 104B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           2          3    7             2     3   2 6
+--R                      (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                    + 
+--R                           3 3 5
+--R                      36B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         2   8       3 2 7  5
+--R                  (2A B C a b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BI0
+--R            + 
+--R                    5 4 9
+--R                  8A a c
+--R                + 
+--R                        5 3 2         4      3 2  4        2 2         4  5  8
+--R                  (- 14A a b  + (- 52A C + 4A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                        5 2 4       4      3 2  3 3
+--R                      7A a b  + (73A C - 9A B )a b
+--R                    + 
+--R                           3 2      2 2        4  4 2
+--R                      (108A C  - 66A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   5           4     2 3  6
+--R                      (- 24A C  - 84A B C  + 48B C)a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6         4      3 2  2 5
+--R                      - A a b  + (- 31A C + 2A B )a b
+--R                    + 
+--R                             3 2      2 2         4  3 4
+--R                      (- 131A C  + 39A B C + 12A B )a b
+--R                    + 
+--R                            2 3         2 2      4   4 3         4      2 3  5 2
+--R                      (- 62A C  + 117A B C  - 60B C)a b  + (66A C  + 42B C )a b
+--R                    + 
+--R                         5 6
+--R                      12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4     7       3 2     2 2        4  2 6
+--R                      4A C a b  + (50A C  - 6A B C - 7A B )a b
+--R                    + 
+--R                          2 3        2 2      4   3 5           4      2 3  4 4
+--R                      (89A C  - 48A B C  + 24B C)a b  + (- 36A C  - 51B C )a b
+--R                    + 
+--R                           5 5 3
+--R                      - 43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3 2      4    8         2 3       2 2     4   2 7
+--R                      (- 6A C  + A B )a b  + (- 34A C  + 6A B C  - 3B C)a b
+--R                    + 
+--R                             4      2 3  3 6      5 4 5
+--R                      (- 7A C  + 18B C )a b  + 34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                     2 3   9        4     2 3  2 8      5 3 7  3
+--R                  (4A C a b  + (7A C  - 2B C )a b  - 10C a b )c
+--R                + 
+--R                        4   10    5 2 9  2
+--R                  (- A C a b   + C a b )c
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4 8
+--R                  4A a c
+--R                + 
+--R                          6 3 2         5       4 2  4
+--R                      - 9A a b  + (- 36A C + 24A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  5
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        6 2 4       5       4 2  3 3
+--R                      6A a b  + (65A C - 32A B )a b
+--R                    + 
+--R                           4 2       3 2       2 4  4 2
+--R                      (121A C  - 120A B C + 32A B )a b
+--R                    + 
+--R                         3 3      2 2 2        4   5
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  6
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         6   6         5       4 2  2 5
+--R                      - A a b  + (- 34A C + 14A B )a b
+--R                    + 
+--R                             4 2       3 2       2 4  3 4
+--R                      (- 170A C  + 120A B C - 24A B )a b
+--R                    + 
+--R                             3 3       2 2 2        4   4 3
+--R                      (- 162A C  + 144A B C  - 32A B C)a b
+--R                    + 
+--R                          2 4        2 3      4 2  5 2         5      2 4  6
+--R                      (41A C  - 56A B C  + 32B C )a b  + (28A C  - 40B C )a b
+--R                    + 
+--R                        6 7
+--R                      4C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         5      4 2    7       4 2      3 2      2 4  2 6
+--R                      (5A C - 2A B )a b  + (75A C  - 46A B C + 8A B )a b
+--R                    + 
+--R                           3 3       2 2 2        4   3 5
+--R                      (200A C  - 132A B C  + 24A B C)a b
+--R                    + 
+--R                          2 4       2 3      4 2  4 4           5      2 4  5 3
+--R                      (50A C  + 8A B C  - 24B C )a b  + (- 95A C  + 80B C )a b
+--R                    + 
+--R                           6 6 2
+--R                      - 25C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4    8
+--R                      (- 10A C  + 6A B C - A B )a b
+--R                    + 
+--R                            3 3      2 2 2       4   2 7
+--R                      (- 80A C  + 48A B C  - 8A B C)a b
+--R                    + 
+--R                            2 4        2 3     4 2  3 6         5      2 4  4 5
+--R                      (- 95A C  + 26A B C  + 8B C )a b  + (58A C  - 58B C )a b
+--R                    + 
+--R                         6 5 4
+--R                      50C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4     9
+--R                      (10A C  - 6A B C  + A B C)a b
+--R                    + 
+--R                          2 4        2 3    4 2  2 8         5      2 4  3 7
+--R                      (40A C  - 14A B C  - B C )a b  + (- A C  + 18B C )a b
+--R                    + 
+--R                           6 4 6
+--R                      - 35C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3    10          5     2 4  2 9      6 3 8
+--R                  ((- 5A C  + 2A B C )a b   + (- 6A C  - 2B C )a b  + 10C a b )c
+--R                + 
+--R                     5   11    6 2 10
+--R                  A C a b   - C a b
+--R             *
+--R                x
+--R            + 
+--R                   5   4          4        3 3  5  7
+--R              (- 4A B a b + (- 12A B C + 4A B )a )c
+--R            + 
+--R                    5   3 3       4        3 3  4 2
+--R                  2A B a b  + (21A B C - 5A B )a b
+--R                + 
+--R                    3   2     2 3        5  5          2   3       3 2     5   6
+--R                (28A B C  - 8A B C - 4A B )a b + (- 16A B C  - 4A B C  + 8B C)a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                       4       3 3  3 4         3   2     2 3        5  4 3
+--R                  (- 7A B C + A B )a b  + (- 33A B C  + 6A B C + 4A B )a b
+--R                + 
+--R                       2   3       3 2     5   5 2           4     3 3  6
+--R                  (- 8A B C  + 5A B C  - 8B C)a b  + (24A B C  + 8B C )a b
+--R                + 
+--R                        5 7
+--R                  - 4B C a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                     3   2    2 3       5  3 5       2   3      3 2     5   4 4
+--R                  (9A B C  - A B C - A B )a b  + (18A B C  - A B C  + 2B C)a b
+--R                + 
+--R                            4     3 3  5 3       5 6 2
+--R                  (- 13A B C  - 6B C )a b  - 5B C a b
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                   2   3 3 6           4    3 3  4 5       5 5 4  3
+--R              (- 5A B C a b  + (- A B C  + B C )a b  + 5B C a b )c
+--R            + 
+--R                    4 3 7      5 4 6  2
+--R              (A B C a b  - B C a b )c
+--R     + 
+--R           -
+--R                  2
+--R                3c
+--R             *
+--R                ROOT
+--R                               6     2 5      2
+--R                       (- 12a c  + 3b c )%%BI1
+--R                     + 
+--R                               6     2 5                 4       3 3
+--R                       ((- 8a c  + 2b c )%%BI0 - 8B a b c  + 2B b c )%%BI1
+--R                     + 
+--R                               6     2 5      2              4       3 3
+--R                       (- 12a c  + 3b c )%%BI0  + (- 8B a b c  + 2B b c )%%BI0
+--R                     + 
+--R                            2                  2  2  3
+--R                       (- 3A a b + (- 4A C - 2B )a )c
+--R                     + 
+--R                         2 3           2     2 2   2            4     2   3
+--R                       (A b  + 8A C a b  + 5C a b)c  + (- 2A C b  - 5C a b )c
+--R                     + 
+--R                        2 5
+--R                       C b
+--R                  /
+--R                         6    2 5
+--R                     4a c  - b c
+--R         + 
+--R               2          2
+--R           - 3c %%BI1 - 3c %%BI0 - 3B b
+--R      *
+--R         log
+--R                                3 3           2          2  4  11
+--R                          (- 64A a b + (- 128A C + 256A B )a )c
+--R                        + 
+--R                                 3 2 3        2          2  3 2
+--R                              96A a b  + (512A C - 384A B )a b
+--R                            + 
+--R                                     2       2   4        3 5
+--R                              (576A C  - 256B C)a b + 128C a
+--R                         *
+--R                             10
+--R                            c
+--R                        + 
+--R                                   3   5          2          2  2 4
+--R                              - 36A a b  + (- 424A C + 208A B )a b
+--R                            + 
+--R                                       2       2   3 3       3 4 2
+--R                              (- 992A C  + 384B C)a b  - 512C a b
+--R                         *
+--R                             9
+--R                            c
+--R                        + 
+--R                                3 7        2         2    6
+--R                              4A b  + (124A C - 48A B )a b
+--R                            + 
+--R                                     2       2   2 5       3 3 4
+--R                              (580A C  - 208B C)a b  + 552C a b
+--R                         *
+--R                             8
+--R                            c
+--R                        + 
+--R                                    2        2  8            2      2     7
+--R                              (- 12A C + 4A B )b  + (- 140A C  + 48B C)a b
+--R                            + 
+--R                                    3 2 6
+--R                              - 252C a b
+--R                         *
+--R                             7
+--R                            c
+--R                        + 
+--R                                 2     2   9      3   8  6     3 10 5
+--R                          ((12A C  - 4B C)b  + 52C a b )c  - 4C b  c
+--R                     *
+--R                        %%BI0
+--R                    + 
+--R                         3   4 10
+--R                      32A B a c
+--R                    + 
+--R                               3   3 2         2           3  4
+--R                          - 32A B a b  + (- 32A B C + 32A B )a b
+--R                        + 
+--R                                  2      3   5
+--R                          (96A B C  - 64B C)a
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                             3   2 4       2           3  3 3
+--R                          14A B a b  + (56A B C - 40A B )a b
+--R                        + 
+--R                                    2      3   4 2        3 5
+--R                          (- 96A B C  + 80B C)a b  - 96B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                              3     6         2           3  2 5
+--R                          - 2A B a b  + (- 28A B C + 16A B )a b
+--R                        + 
+--R                                  2      3   3 4         3 4 3
+--R                          (10A B C  - 32B C)a b  + 104B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                             2          3    7           2     3   2 6
+--R                          (4A B C - 2A B )a b  + (10A B C  + 4B C)a b
+--R                        + 
+--R                                 3 3 5
+--R                          - 36B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                               2   8       3 2 7  5
+--R                      (- 2A B C a b  + 4B C a b )c
+--R                 *
+--R                    %%BI1
+--R                + 
+--R                         3   4 10
+--R                      32A B a c
+--R                    + 
+--R                               3   3 2         2           3  4
+--R                          - 32A B a b  + (- 32A B C + 32A B )a b
+--R                        + 
+--R                                  2      3   5
+--R                          (96A B C  - 64B C)a
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                             3   2 4       2           3  3 3
+--R                          14A B a b  + (56A B C - 40A B )a b
+--R                        + 
+--R                                    2      3   4 2        3 5
+--R                          (- 96A B C  + 80B C)a b  - 96B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                              3     6         2           3  2 5
+--R                          - 2A B a b  + (- 28A B C + 16A B )a b
+--R                        + 
+--R                                  2      3   3 4         3 4 3
+--R                          (10A B C  - 32B C)a b  + 104B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                             2          3    7           2     3   2 6
+--R                          (4A B C - 2A B )a b  + (10A B C  + 4B C)a b
+--R                        + 
+--R                                 3 3 5
+--R                          - 36B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                               2   8       3 2 7  5
+--R                      (- 2A B C a b  + 4B C a b )c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                    5 4 9
+--R                  8A a c
+--R                + 
+--R                        5 3 2         4       3 2  4        2 2         4  5  8
+--R                  (- 14A a b  + (- 52A C + 36A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                        5 2 4       4       3 2  3 3
+--R                      7A a b  + (73A C - 41A B )a b
+--R                    + 
+--R                           3 2      2 2         4  4 2
+--R                      (108A C  - 98A B C + 36A B )a b
+--R                    + 
+--R                            2 3        2 2      4   5           4     2 3  6
+--R                      (- 24A C  + 12A B C  - 16B C)a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6         4       3 2  2 5
+--R                      - A a b  + (- 31A C + 16A B )a b
+--R                    + 
+--R                             3 2      2 2         4  3 4
+--R                      (- 131A C  + 95A B C - 28A B )a b
+--R                    + 
+--R                            2 3        2 2      4   4 3         4      2 3  5 2
+--R                      (- 62A C  + 21A B C  + 20B C)a b  + (66A C  - 54B C )a b
+--R                    + 
+--R                         5 6
+--R                      12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         4      3 2    7       3 2      2 2        4  2 6
+--R                      (4A C - 2A B )a b  + (50A C  - 34A B C + 9A B )a b
+--R                    + 
+--R                          2 3        2 2     4   3 5           4      2 3  4 4
+--R                      (89A C  - 38A B C  - 8B C)a b  + (- 36A C  + 53B C )a b
+--R                    + 
+--R                           5 5 3
+--R                      - 43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3 2     2 2       4    8
+--R                      (- 6A C  + 4A B C - A B )a b
+--R                    + 
+--R                            2 3        2 2    4   2 7          4      2 3  3 6
+--R                      (- 34A C  + 16A B C  + B C)a b  + (- 7A C  - 18B C )a b
+--R                    + 
+--R                         5 4 5
+--R                      34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                      2 3       2 2    9        4     2 3  2 8      5 3 7  3
+--R                  ((4A C  - 2A B C )a b  + (7A C  + 2B C )a b  - 10C a b )c
+--R                + 
+--R                        4   10    5 2 9  2
+--R                  (- A C a b   + C a b )c
+--R             *
+--R                ROOT
+--R                               6     2 5      2
+--R                       (- 12a c  + 3b c )%%BI1
+--R                     + 
+--R                               6     2 5                 4       3 3
+--R                       ((- 8a c  + 2b c )%%BI0 - 8B a b c  + 2B b c )%%BI1
+--R                     + 
+--R                               6     2 5      2              4       3 3
+--R                       (- 12a c  + 3b c )%%BI0  + (- 8B a b c  + 2B b c )%%BI0
+--R                     + 
+--R                            2                  2  2  3
+--R                       (- 3A a b + (- 4A C - 2B )a )c
+--R                     + 
+--R                         2 3           2     2 2   2            4     2   3
+--R                       (A b  + 8A C a b  + 5C a b)c  + (- 2A C b  - 5C a b )c
+--R                     + 
+--R                        2 5
+--R                       C b
+--R                  /
+--R                         6    2 5
+--R                     4a c  - b c
+--R            + 
+--R                          3 3         2          2  4  11
+--R                      (64A a b + (128A C - 256A B )a )c
+--R                    + 
+--R                               3 2 3          2          2  3 2
+--R                          - 96A a b  + (- 512A C + 384A B )a b
+--R                        + 
+--R                                   2       2   4        3 5
+--R                          (- 576A C  + 256B C)a b - 128C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                             3   5        2          2  2 4
+--R                          36A a b  + (424A C - 208A B )a b
+--R                        + 
+--R                                 2       2   3 3       3 4 2
+--R                          (992A C  - 384B C)a b  + 512C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                              3 7          2         2    6
+--R                          - 4A b  + (- 124A C + 48A B )a b
+--R                        + 
+--R                                   2       2   2 5       3 3 4
+--R                          (- 580A C  + 208B C)a b  - 552C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                           2        2  8          2      2     7       3 2 6  7
+--R                      ((12A C - 4A B )b  + (140A C  - 48B C)a b  + 252C a b )c
+--R                    + 
+--R                               2     2   9      3   8  6     3 10 5
+--R                      ((- 12A C  + 4B C)b  - 52C a b )c  + 4C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                       3   4 10
+--R                  - 32A B a c
+--R                + 
+--R                           3   3 2       2           3  4
+--R                        32A B a b  + (32A B C - 32A B )a b
+--R                      + 
+--R                                  2      3   5
+--R                        (- 96A B C  + 64B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                           3   2 4         2           3  3 3
+--R                      - 14A B a b  + (- 56A B C + 40A B )a b
+--R                    + 
+--R                              2      3   4 2        3 5
+--R                      (96A B C  - 80B C)a b  + 96B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                        3     6       2           3  2 5
+--R                      2A B a b  + (28A B C - 16A B )a b
+--R                    + 
+--R                                2      3   3 4         3 4 3
+--R                      (- 10A B C  + 32B C)a b  - 104B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           2          3    7             2     3   2 6
+--R                      (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                    + 
+--R                           3 3 5
+--R                      36B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         2   8       3 2 7  5
+--R                  (2A B C a b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BI1
+--R            + 
+--R                          3 3         2          2  4  11
+--R                      (64A a b + (128A C - 256A B )a )c
+--R                    + 
+--R                               3 2 3          2          2  3 2
+--R                          - 96A a b  + (- 512A C + 384A B )a b
+--R                        + 
+--R                                   2       2   4        3 5
+--R                          (- 576A C  + 256B C)a b - 128C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                             3   5        2          2  2 4
+--R                          36A a b  + (424A C - 208A B )a b
+--R                        + 
+--R                                 2       2   3 3       3 4 2
+--R                          (992A C  - 384B C)a b  + 512C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                              3 7          2         2    6
+--R                          - 4A b  + (- 124A C + 48A B )a b
+--R                        + 
+--R                                   2       2   2 5       3 3 4
+--R                          (- 580A C  + 208B C)a b  - 552C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                           2        2  8          2      2     7       3 2 6  7
+--R                      ((12A C - 4A B )b  + (140A C  - 48B C)a b  + 252C a b )c
+--R                    + 
+--R                               2     2   9      3   8  6     3 10 5
+--R                      ((- 12A C  + 4B C)b  - 52C a b )c  + 4C b  c
+--R                 *
+--R                         2
+--R                    %%BI0
+--R                + 
+--R                          3   3 2        2            3  4   9
+--R                      (64A B a b  + (128A B C - 256A B )a b)c
+--R                    + 
+--R                               3   2 4          2            3  3 3
+--R                          - 96A B a b  + (- 512A B C + 384A B )a b
+--R                        + 
+--R                                     2       3   4 2         3 5
+--R                          (- 576A B C  + 256B C)a b  - 128B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                             3     6        2            3  2 5
+--R                          36A B a b  + (424A B C - 208A B )a b
+--R                        + 
+--R                                   2       3   3 4         3 4 3
+--R                          (992A B C  - 384B C)a b  + 512B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              3   8          2           3    7
+--R                          - 4A B b  + (- 124A B C + 48A B )a b
+--R                        + 
+--R                                     2       3   2 6         3 3 5
+--R                          (- 580A B C  + 208B C)a b  - 552B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              2          3  9            2      3     8
+--R                          (12A B C - 4A B )b  + (140A B C  - 48B C)a b
+--R                        + 
+--R                                3 2 7
+--R                          252B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                 2     3   10        3   9  4       3 11 3
+--R                      ((- 12A B C  + 4B C)b   - 52B C a b )c  + 4B C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                    5 4 9
+--R                  8A a c
+--R                + 
+--R                        5 3 2         4      3 2  4        2 2         4  5  8
+--R                  (- 14A a b  + (- 52A C + 4A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                        5 2 4       4      3 2  3 3
+--R                      7A a b  + (73A C - 9A B )a b
+--R                    + 
+--R                           3 2      2 2        4  4 2
+--R                      (108A C  - 66A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   5           4     2 3  6
+--R                      (- 24A C  - 84A B C  + 48B C)a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6         4      3 2  2 5
+--R                      - A a b  + (- 31A C + 2A B )a b
+--R                    + 
+--R                             3 2      2 2         4  3 4
+--R                      (- 131A C  + 39A B C + 12A B )a b
+--R                    + 
+--R                            2 3         2 2      4   4 3         4      2 3  5 2
+--R                      (- 62A C  + 117A B C  - 60B C)a b  + (66A C  + 42B C )a b
+--R                    + 
+--R                         5 6
+--R                      12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4     7       3 2     2 2        4  2 6
+--R                      4A C a b  + (50A C  - 6A B C - 7A B )a b
+--R                    + 
+--R                          2 3        2 2      4   3 5           4      2 3  4 4
+--R                      (89A C  - 48A B C  + 24B C)a b  + (- 36A C  - 51B C )a b
+--R                    + 
+--R                           5 5 3
+--R                      - 43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3 2      4    8         2 3       2 2     4   2 7
+--R                      (- 6A C  + A B )a b  + (- 34A C  + 6A B C  - 3B C)a b
+--R                    + 
+--R                             4      2 3  3 6      5 4 5
+--R                      (- 7A C  + 18B C )a b  + 34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                     2 3   9        4     2 3  2 8      5 3 7  3
+--R                  (4A C a b  + (7A C  - 2B C )a b  - 10C a b )c
+--R                + 
+--R                        4   10    5 2 9  2
+--R                  (- A C a b   + C a b )c
+--R             *
+--R                %%BI1
+--R            + 
+--R                       3   4 10
+--R                  - 32A B a c
+--R                + 
+--R                           3   3 2       2           3  4
+--R                        32A B a b  + (32A B C - 32A B )a b
+--R                      + 
+--R                                  2      3   5
+--R                        (- 96A B C  + 64B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                           3   2 4         2           3  3 3
+--R                      - 14A B a b  + (- 56A B C + 40A B )a b
+--R                    + 
+--R                              2      3   4 2        3 5
+--R                      (96A B C  - 80B C)a b  + 96B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                        3     6       2           3  2 5
+--R                      2A B a b  + (28A B C - 16A B )a b
+--R                    + 
+--R                                2      3   3 4         3 4 3
+--R                      (- 10A B C  + 32B C)a b  - 104B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           2          3    7             2     3   2 6
+--R                      (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                    + 
+--R                           3 3 5
+--R                      36B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         2   8       3 2 7  5
+--R                  (2A B C a b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BI0
+--R            + 
+--R                    5 4 9
+--R                  8A a c
+--R                + 
+--R                        5 3 2         4      3 2  4        2 2         4  5  8
+--R                  (- 14A a b  + (- 52A C + 4A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                        5 2 4       4      3 2  3 3
+--R                      7A a b  + (73A C - 9A B )a b
+--R                    + 
+--R                           3 2      2 2        4  4 2
+--R                      (108A C  - 66A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   5           4     2 3  6
+--R                      (- 24A C  - 84A B C  + 48B C)a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6         4      3 2  2 5
+--R                      - A a b  + (- 31A C + 2A B )a b
+--R                    + 
+--R                             3 2      2 2         4  3 4
+--R                      (- 131A C  + 39A B C + 12A B )a b
+--R                    + 
+--R                            2 3         2 2      4   4 3         4      2 3  5 2
+--R                      (- 62A C  + 117A B C  - 60B C)a b  + (66A C  + 42B C )a b
+--R                    + 
+--R                         5 6
+--R                      12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4     7       3 2     2 2        4  2 6
+--R                      4A C a b  + (50A C  - 6A B C - 7A B )a b
+--R                    + 
+--R                          2 3        2 2      4   3 5           4      2 3  4 4
+--R                      (89A C  - 48A B C  + 24B C)a b  + (- 36A C  - 51B C )a b
+--R                    + 
+--R                           5 5 3
+--R                      - 43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3 2      4    8         2 3       2 2     4   2 7
+--R                      (- 6A C  + A B )a b  + (- 34A C  + 6A B C  - 3B C)a b
+--R                    + 
+--R                             4      2 3  3 6      5 4 5
+--R                      (- 7A C  + 18B C )a b  + 34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                     2 3   9        4     2 3  2 8      5 3 7  3
+--R                  (4A C a b  + (7A C  - 2B C )a b  - 10C a b )c
+--R                + 
+--R                        4   10    5 2 9  2
+--R                  (- A C a b   + C a b )c
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4 8
+--R                  4A a c
+--R                + 
+--R                          6 3 2         5       4 2  4
+--R                      - 9A a b  + (- 36A C + 24A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  5
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        6 2 4       5       4 2  3 3
+--R                      6A a b  + (65A C - 32A B )a b
+--R                    + 
+--R                           4 2       3 2       2 4  4 2
+--R                      (121A C  - 120A B C + 32A B )a b
+--R                    + 
+--R                         3 3      2 2 2        4   5
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  6
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         6   6         5       4 2  2 5
+--R                      - A a b  + (- 34A C + 14A B )a b
+--R                    + 
+--R                             4 2       3 2       2 4  3 4
+--R                      (- 170A C  + 120A B C - 24A B )a b
+--R                    + 
+--R                             3 3       2 2 2        4   4 3
+--R                      (- 162A C  + 144A B C  - 32A B C)a b
+--R                    + 
+--R                          2 4        2 3      4 2  5 2         5      2 4  6
+--R                      (41A C  - 56A B C  + 32B C )a b  + (28A C  - 40B C )a b
+--R                    + 
+--R                        6 7
+--R                      4C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         5      4 2    7       4 2      3 2      2 4  2 6
+--R                      (5A C - 2A B )a b  + (75A C  - 46A B C + 8A B )a b
+--R                    + 
+--R                           3 3       2 2 2        4   3 5
+--R                      (200A C  - 132A B C  + 24A B C)a b
+--R                    + 
+--R                          2 4       2 3      4 2  4 4           5      2 4  5 3
+--R                      (50A C  + 8A B C  - 24B C )a b  + (- 95A C  + 80B C )a b
+--R                    + 
+--R                           6 6 2
+--R                      - 25C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4    8
+--R                      (- 10A C  + 6A B C - A B )a b
+--R                    + 
+--R                            3 3      2 2 2       4   2 7
+--R                      (- 80A C  + 48A B C  - 8A B C)a b
+--R                    + 
+--R                            2 4        2 3     4 2  3 6         5      2 4  4 5
+--R                      (- 95A C  + 26A B C  + 8B C )a b  + (58A C  - 58B C )a b
+--R                    + 
+--R                         6 5 4
+--R                      50C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4     9
+--R                      (10A C  - 6A B C  + A B C)a b
+--R                    + 
+--R                          2 4        2 3    4 2  2 8         5      2 4  3 7
+--R                      (40A C  - 14A B C  - B C )a b  + (- A C  + 18B C )a b
+--R                    + 
+--R                           6 4 6
+--R                      - 35C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3    10          5     2 4  2 9      6 3 8
+--R                  ((- 5A C  + 2A B C )a b   + (- 6A C  - 2B C )a b  + 10C a b )c
+--R                + 
+--R                     5   11    6 2 10
+--R                  A C a b   - C a b
+--R             *
+--R                x
+--R            + 
+--R                   5   4          4        3 3  5  7
+--R              (- 4A B a b + (- 12A B C + 4A B )a )c
+--R            + 
+--R                    5   3 3       4        3 3  4 2
+--R                  2A B a b  + (21A B C - 5A B )a b
+--R                + 
+--R                    3   2     2 3        5  5          2   3       3 2     5   6
+--R                (28A B C  - 8A B C - 4A B )a b + (- 16A B C  - 4A B C  + 8B C)a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                       4       3 3  3 4         3   2     2 3        5  4 3
+--R                  (- 7A B C + A B )a b  + (- 33A B C  + 6A B C + 4A B )a b
+--R                + 
+--R                       2   3       3 2     5   5 2           4     3 3  6
+--R                  (- 8A B C  + 5A B C  - 8B C)a b  + (24A B C  + 8B C )a b
+--R                + 
+--R                        5 7
+--R                  - 4B C a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                     3   2    2 3       5  3 5       2   3      3 2     5   4 4
+--R                  (9A B C  - A B C - A B )a b  + (18A B C  - A B C  + 2B C)a b
+--R                + 
+--R                            4     3 3  5 3       5 6 2
+--R                  (- 13A B C  - 6B C )a b  - 5B C a b
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                   2   3 3 6           4    3 3  4 5       5 5 4  3
+--R              (- 5A B C a b  + (- A B C  + B C )a b  + 5B C a b )c
+--R            + 
+--R                    4 3 7      5 4 6  2
+--R              (A B C a b  - B C a b )c
+--R     + 
+--R           2
+--R         6c %%BI1
+--R      *
+--R         log
+--R                             3 3           2          2  4  11
+--R                      (- 128A a b + (- 256A C + 512A B )a )c
+--R                    + 
+--R                              3 2 3         2          2  3 2
+--R                          192A a b  + (1024A C - 768A B )a b
+--R                        + 
+--R                                  2       2   4        3 5
+--R                          (1152A C  - 512B C)a b + 256C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                               3   5          2          2  2 4
+--R                          - 72A a b  + (- 848A C + 416A B )a b
+--R                        + 
+--R                                    2       2   3 3        3 4 2
+--R                          (- 1984A C  + 768B C)a b  - 1024C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                            3 7        2         2    6
+--R                          8A b  + (248A C - 96A B )a b
+--R                        + 
+--R                                  2       2   2 5        3 3 4
+--R                          (1160A C  - 416B C)a b  + 1104C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                                2        2  8            2      2     7
+--R                          (- 24A C + 8A B )b  + (- 280A C  + 96B C)a b
+--R                        + 
+--R                                3 2 6
+--R                          - 504C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                             2     2   9       3   8  6     3 10 5
+--R                      ((24A C  - 8B C)b  + 104C a b )c  - 8C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                     3   4 10
+--R                  64A B a c
+--R                + 
+--R                           3   3 2         2           3  4
+--R                      - 64A B a b  + (- 64A B C + 64A B )a b
+--R                    + 
+--R                               2       3   5
+--R                      (192A B C  - 128B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                         3   2 4        2           3  3 3
+--R                      28A B a b  + (112A B C - 80A B )a b
+--R                    + 
+--R                                 2       3   4 2         3 5
+--R                      (- 192A B C  + 160B C)a b  - 192B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                          3     6         2           3  2 5
+--R                      - 4A B a b  + (- 56A B C + 32A B )a b
+--R                    + 
+--R                              2      3   3 4         3 4 3
+--R                      (20A B C  - 64B C)a b  + 208B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                      2          3    7           2     3   2 6        3 3 5  6
+--R                  ((8A B C - 4A B )a b  + (20A B C  + 8B C)a b  - 72B C a b )c
+--R                + 
+--R                           2   8       3 2 7  5
+--R                  (- 4A B C a b  + 8B C a b )c
+--R             *
+--R                     2
+--R                %%BI1
+--R            + 
+--R                             3 3           2          2  4  11
+--R                      (- 128A a b + (- 256A C + 512A B )a )c
+--R                    + 
+--R                              3 2 3         2          2  3 2
+--R                          192A a b  + (1024A C - 768A B )a b
+--R                        + 
+--R                                  2       2   4        3 5
+--R                          (1152A C  - 512B C)a b + 256C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                               3   5          2          2  2 4
+--R                          - 72A a b  + (- 848A C + 416A B )a b
+--R                        + 
+--R                                    2       2   3 3        3 4 2
+--R                          (- 1984A C  + 768B C)a b  - 1024C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                            3 7        2         2    6
+--R                          8A b  + (248A C - 96A B )a b
+--R                        + 
+--R                                  2       2   2 5        3 3 4
+--R                          (1160A C  - 416B C)a b  + 1104C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                                2        2  8            2      2     7
+--R                          (- 24A C + 8A B )b  + (- 280A C  + 96B C)a b
+--R                        + 
+--R                                3 2 6
+--R                          - 504C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                             2     2   9       3   8  6     3 10 5
+--R                      ((24A C  - 8B C)b  + 104C a b )c  - 8C b  c
+--R                 *
+--R                         2
+--R                    %%BI0
+--R                + 
+--R                             3   3 2          2            3  4   9
+--R                      (- 128A B a b  + (- 256A B C + 512A B )a b)c
+--R                    + 
+--R                              3   2 4         2            3  3 3
+--R                          192A B a b  + (1024A B C - 768A B )a b
+--R                        + 
+--R                                    2       3   4 2         3 5
+--R                          (1152A B C  - 512B C)a b  + 256B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                               3     6          2            3  2 5
+--R                          - 72A B a b  + (- 848A B C + 416A B )a b
+--R                        + 
+--R                                      2       3   3 4          3 4 3
+--R                          (- 1984A B C  + 768B C)a b  - 1024B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                            3   8        2           3    7
+--R                          8A B b  + (248A B C - 96A B )a b
+--R                        + 
+--R                                    2       3   2 6          3 3 5
+--R                          (1160A B C  - 416B C)a b  + 1104B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                2          3  9              2      3     8
+--R                          (- 24A B C + 8A B )b  + (- 280A B C  + 96B C)a b
+--R                        + 
+--R                                  3 2 7
+--R                          - 504B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                               2     3   10         3   9  4       3 11 3
+--R                      ((24A B C  - 8B C)b   + 104B C a b )c  - 8B C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                       5 4 9
+--R                  - 16A a c
+--R                + 
+--R                      5 3 2        4      3 2  4          2 2         4  5  8
+--R                  (28A a b  + (104A C - 8A B )a b + (- 48A B C + 32A B )a )c
+--R                + 
+--R                           5 2 4          4       3 2  3 3
+--R                      - 14A a b  + (- 146A C + 18A B )a b
+--R                    + 
+--R                             3 2       2 2        4  4 2
+--R                      (- 216A C  + 132A B C - 8A B )a b
+--R                    + 
+--R                          2 3         2 2      4   5          4      2 3  6
+--R                      (48A C  + 168A B C  - 96B C)a b + (16A C  - 16B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        5   6       4      3 2  2 5
+--R                      2A a b  + (62A C - 4A B )a b
+--R                    + 
+--R                           3 2      2 2         4  3 4
+--R                      (262A C  - 78A B C - 24A B )a b
+--R                    + 
+--R                           2 3         2 2       4   4 3
+--R                      (124A C  - 234A B C  + 120B C)a b
+--R                    + 
+--R                               4      2 3  5 2      5 6
+--R                      (- 132A C  - 84B C )a b  - 24C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                          4     7          3 2      2 2         4  2 6
+--R                      - 8A C a b  + (- 100A C  + 12A B C + 14A B )a b
+--R                    + 
+--R                             2 3        2 2      4   3 5
+--R                      (- 178A C  + 96A B C  - 48B C)a b
+--R                    + 
+--R                            4       2 3  4 4      5 5 3
+--R                      (72A C  + 102B C )a b  + 86C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          3 2       4    8       2 3        2 2     4   2 7
+--R                      (12A C  - 2A B )a b  + (68A C  - 12A B C  + 6B C)a b
+--R                    + 
+--R                            4      2 3  3 6      5 4 5
+--R                      (14A C  - 36B C )a b  - 68C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                       2 3   9           4     2 3  2 8      5 3 7  3
+--R                  (- 8A C a b  + (- 14A C  + 4B C )a b  + 20C a b )c
+--R                + 
+--R                       4   10     5 2 9  2
+--R                  (2A C a b   - 2C a b )c
+--R             *
+--R                %%BI1
+--R            + 
+--R                         3 3           2          2  4  11
+--R                  (- 128A a b + (- 256A C + 512A B )a )c
+--R                + 
+--R                          3 2 3         2          2  3 2
+--R                      192A a b  + (1024A C - 768A B )a b
+--R                    + 
+--R                              2       2   4        3 5
+--R                      (1152A C  - 512B C)a b + 256C a
+--R                 *
+--R                     10
+--R                    c
+--R                + 
+--R                           3   5          2          2  2 4
+--R                      - 72A a b  + (- 848A C + 416A B )a b
+--R                    + 
+--R                                2       2   3 3        3 4 2
+--R                      (- 1984A C  + 768B C)a b  - 1024C a b
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                        3 7        2         2    6           2       2   2 5
+--R                      8A b  + (248A C - 96A B )a b  + (1160A C  - 416B C)a b
+--R                    + 
+--R                           3 3 4
+--R                      1104C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                         2        2  8            2      2     7       3 2 6  7
+--R                  ((- 24A C + 8A B )b  + (- 280A C  + 96B C)a b  - 504C a b )c
+--R                + 
+--R                         2     2   9       3   8  6     3 10 5
+--R                  ((24A C  - 8B C)b  + 104C a b )c  - 8C b  c
+--R             *
+--R                     3
+--R                %%BI0
+--R            + 
+--R                         3   3 2          2            3  4   9
+--R                  (- 128A B a b  + (- 256A B C + 512A B )a b)c
+--R                + 
+--R                          3   2 4         2            3  3 3
+--R                      192A B a b  + (1024A B C - 768A B )a b
+--R                    + 
+--R                                2       3   4 2         3 5
+--R                      (1152A B C  - 512B C)a b  + 256B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                           3     6          2            3  2 5
+--R                      - 72A B a b  + (- 848A B C + 416A B )a b
+--R                    + 
+--R                                  2       3   3 4          3 4 3
+--R                      (- 1984A B C  + 768B C)a b  - 1024B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        3   8        2           3    7
+--R                      8A B b  + (248A B C - 96A B )a b
+--R                    + 
+--R                                2       3   2 6          3 3 5
+--R                      (1160A B C  - 416B C)a b  + 1104B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                            2          3  9              2      3     8
+--R                      (- 24A B C + 8A B )b  + (- 280A B C  + 96B C)a b
+--R                    + 
+--R                              3 2 7
+--R                      - 504B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           2     3   10         3   9  4       3 11 3
+--R                  ((24A B C  - 8B C)b   + 104B C a b )c  - 8B C b  c
+--R             *
+--R                     2
+--R                %%BI0
+--R            + 
+--R                           5 3 2         4       3 2  4
+--R                      - 24A a b  + (- 80A C + 80A B )a b
+--R                    + 
+--R                            3 2      2 2         4  5
+--R                      (- 64A C  + 96A B C + 64A B )a
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                         5 2 4        4        3 2  3 3
+--R                      38A a b  + (300A C - 164A B )a b
+--R                    + 
+--R                           3 2       2 2         4  4 2
+--R                      (624A C  - 456A B C + 48A B )a b
+--R                    + 
+--R                           2 3         2 2      4   5          4      2 3  6
+--R                      (416A C  - 144A B C  - 64B C)a b + (64A C  + 32B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           5   6          4        3 2  2 5
+--R                      - 16A a b  + (- 278A C + 132A B )a b
+--R                    + 
+--R                              3 2       2 2          4  3 4
+--R                      (- 1144A C  + 780A B C - 160A B )a b
+--R                    + 
+--R                              2 3         2 2      4   4 3
+--R                      (- 1576A C  + 852A B C  - 48B C)a b
+--R                    + 
+--R                               4       2 3  5 2      5 6
+--R                      (- 728A C  + 104B C )a b  - 80C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        5 8       4       3 2    7
+--R                      2A b  + (92A C - 40A B )a b
+--R                    + 
+--R                           3 2       2 2          4  2 6
+--R                      (760A C  - 504A B C + 100A B )a b
+--R                    + 
+--R                            2 3          2 2       4   3 5
+--R                      (1904A C  - 1164A B C  + 160B C)a b
+--R                    + 
+--R                              4       2 3  4 4       5 5 3
+--R                      (1618A C  - 508B C )a b  + 380C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4      3 2  9          3 2       2 2         4    8
+--R                      (- 10A C + 4A B )b  + (- 208A C  + 132A B C - 24A B )a b
+--R                    + 
+--R                             2 3         2 2       4   2 7
+--R                      (- 992A C  + 624A B C  - 100B C)a b
+--R                    + 
+--R                                4       2 3  3 6       5 4 5
+--R                      (- 1456A C  + 552B C )a b  - 586C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                          3 2      2 2        4  10
+--R                      (20A C  - 12A B C + 2A B )b
+--R                    + 
+--R                           2 3         2 2      4     9
+--R                      (232A C  - 144A B C  + 24B C)a b
+--R                    + 
+--R                             4       2 3  2 8       5 3 7
+--R                      (626A C  - 252B C )a b  + 420C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            2 3        2 2     4   11
+--R                      (- 20A C  + 12A B C  - 2B C)b
+--R                    + 
+--R                               4      2 3    10       5 2 9
+--R                      (- 128A C  + 52B C )a b   - 154C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         4     2 3  12      5   11       5 13
+--R                  ((10A C  - 4B C )b   + 28C a b  )c - 2C b
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4 8
+--R                  4A a c
+--R                + 
+--R                          6 3 2         5       4 2  4
+--R                      - 9A a b  + (- 36A C + 24A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  5
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        6 2 4       5       4 2  3 3
+--R                      6A a b  + (65A C - 32A B )a b
+--R                    + 
+--R                           4 2       3 2       2 4  4 2
+--R                      (121A C  - 120A B C + 32A B )a b
+--R                    + 
+--R                         3 3      2 2 2        4   5
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  6
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         6   6         5       4 2  2 5
+--R                      - A a b  + (- 34A C + 14A B )a b
+--R                    + 
+--R                             4 2       3 2       2 4  3 4
+--R                      (- 170A C  + 120A B C - 24A B )a b
+--R                    + 
+--R                             3 3       2 2 2        4   4 3
+--R                      (- 162A C  + 144A B C  - 32A B C)a b
+--R                    + 
+--R                          2 4        2 3      4 2  5 2         5      2 4  6
+--R                      (41A C  - 56A B C  + 32B C )a b  + (28A C  - 40B C )a b
+--R                    + 
+--R                        6 7
+--R                      4C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         5      4 2    7       4 2      3 2      2 4  2 6
+--R                      (5A C - 2A B )a b  + (75A C  - 46A B C + 8A B )a b
+--R                    + 
+--R                           3 3       2 2 2        4   3 5
+--R                      (200A C  - 132A B C  + 24A B C)a b
+--R                    + 
+--R                          2 4       2 3      4 2  4 4           5      2 4  5 3
+--R                      (50A C  + 8A B C  - 24B C )a b  + (- 95A C  + 80B C )a b
+--R                    + 
+--R                           6 6 2
+--R                      - 25C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4    8
+--R                      (- 10A C  + 6A B C - A B )a b
+--R                    + 
+--R                            3 3      2 2 2       4   2 7
+--R                      (- 80A C  + 48A B C  - 8A B C)a b
+--R                    + 
+--R                            2 4        2 3     4 2  3 6         5      2 4  4 5
+--R                      (- 95A C  + 26A B C  + 8B C )a b  + (58A C  - 58B C )a b
+--R                    + 
+--R                         6 5 4
+--R                      50C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4     9
+--R                      (10A C  - 6A B C  + A B C)a b
+--R                    + 
+--R                          2 4        2 3    4 2  2 8         5      2 4  3 7
+--R                      (40A C  - 14A B C  - B C )a b  + (- A C  + 18B C )a b
+--R                    + 
+--R                           6 4 6
+--R                      - 35C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3    10          5     2 4  2 9      6 3 8
+--R                  ((- 5A C  + 2A B C )a b   + (- 6A C  - 2B C )a b  + 10C a b )c
+--R                + 
+--R                     5   11    6 2 10
+--R                  A C a b   - C a b
+--R             *
+--R                x
+--R            + 
+--R                 4         3 3  5 7
+--R              (4A B C + 12A B )a c
+--R            + 
+--R                    5   3 3       4         3 3  4 2
+--R                  3A B a b  + (17A B C - 19A B )a b
+--R                + 
+--R                      3   2      2 3         5  5
+--R                  (28A B C  - 48A B C + 20A B )a b
+--R                + 
+--R                      2   3        3 2     5   6
+--R                  (32A B C  - 12A B C  - 8B C)a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                     5   2 5         4         3 3  3 4
+--R                  - A B a b  + (- 22A B C + 12A B )a b
+--R                + 
+--R                        3   2      2 3         5  4 3
+--R                  (- 89A B C  + 84A B C - 24A B )a b
+--R                + 
+--R                         2   3        3 2     5   5 2             4      3 3  6
+--R                  (- 132A B C  + 99A B C  - 8B C)a b  + (- 76A B C  + 16B C )a b
+--R                + 
+--R                        5 7
+--R                  - 4B C a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                     4        3 3  2 6       3   2      2 3        5  3 5
+--R                  (5A B C - 2A B )a b  + (58A B C  - 42A B C + 9A B )a b
+--R                + 
+--R                       2   3         3 2      5   4 4            4      3 3  5 3
+--R                  (164A B C  - 120A B C  + 18B C)a b  + (162A B C  - 60B C )a b
+--R                + 
+--R                       5 6 2
+--R                  43B C a b
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                        3   2     2 3       5  2 7
+--R                  (- 10A B C  + 6A B C - A B )a b
+--R                + 
+--R                        2   3        3 2     5   3 6
+--R                  (- 72A B C  + 48A B C  - 8B C)a b
+--R                + 
+--R                             4      3 3  4 5        5 5 4
+--R                  (- 129A B C  + 54B C )a b  - 62B C a b
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                      2   3       3 2    5   2 8           4      3 3  3 7
+--R                  (10A B C  - 6A B C  + B C)a b  + (43A B C  - 18B C )a b
+--R                + 
+--R                       5 4 6
+--R                  37B C a b
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                        4     3 3  2 9        5 3 8        5 2 10
+--R              ((- 5A B C  + 2B C )a b  - 10B C a b )c + B C a b
+--R     + 
+--R           2
+--R         6c %%BI0
+--R      *
+--R         log
+--R                       3 3         2          2  4  11
+--R                  (128A a b + (256A C - 512A B )a )c
+--R                + 
+--R                            3 2 3           2          2  3 2
+--R                      - 192A a b  + (- 1024A C + 768A B )a b
+--R                    + 
+--R                                2       2   4        3 5
+--R                      (- 1152A C  + 512B C)a b - 256C a
+--R                 *
+--R                     10
+--R                    c
+--R                + 
+--R                         3   5        2          2  2 4
+--R                      72A a b  + (848A C - 416A B )a b
+--R                    + 
+--R                              2       2   3 3        3 4 2
+--R                      (1984A C  - 768B C)a b  + 1024C a b
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                          3 7          2         2    6
+--R                      - 8A b  + (- 248A C + 96A B )a b
+--R                    + 
+--R                                2       2   2 5        3 3 4
+--R                      (- 1160A C  + 416B C)a b  - 1104C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                       2        2  8          2      2     7       3 2 6  7
+--R                  ((24A C - 8A B )b  + (280A C  - 96B C)a b  + 504C a b )c
+--R                + 
+--R                           2     2   9       3   8  6     3 10 5
+--R                  ((- 24A C  + 8B C)b  - 104C a b )c  + 8C b  c
+--R             *
+--R                     3
+--R                %%BI0
+--R            + 
+--R                     3   4 10
+--R                  64A B a c
+--R                + 
+--R                         3   3 2        2            3  4
+--R                      64A B a b  + (192A B C - 448A B )a b
+--R                    + 
+--R                               2       3   5
+--R                      (192A B C  - 128B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                            3   2 4          2            3  3 3
+--R                      - 164A B a b  + (- 912A B C + 688A B )a b
+--R                    + 
+--R                                  2       3   4 2         3 5
+--R                      (- 1344A B C  + 672B C)a b  - 448B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                         3     6        2            3  2 5
+--R                      68A B a b  + (792A B C - 384A B )a b
+--R                    + 
+--R                                2       3   3 4          3 4 3
+--R                      (2004A B C  - 832B C)a b  + 1232B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                          3   8          2           3    7
+--R                      - 8A B b  + (- 240A B C + 92A B )a b
+--R                    + 
+--R                                  2       3   2 6          3 3 5
+--R                      (- 1140A B C  + 424B C)a b  - 1176B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                            2          3  9            2      3     8
+--R                        (24A B C - 8A B )b  + (276A B C  - 96B C)a b
+--R                      + 
+--R                              3 2 7
+--R                        512B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                             2     3   10         3   9  4       3 11 3
+--R                  ((- 24A B C  + 8B C)b   - 104B C a b )c  + 8B C b  c
+--R             *
+--R                     2
+--R                %%BI0
+--R            + 
+--R                       5 4 9
+--R                  - 16A a c
+--R                + 
+--R                         5 3 2        4       3 2  4
+--R                      52A a b  + (184A C - 88A B )a b
+--R                    + 
+--R                          3 2       2 2         4  5
+--R                      (64A C  - 144A B C - 32A B )a
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                           5 2 4          4        3 2  3 3
+--R                      - 52A a b  + (- 446A C + 182A B )a b
+--R                    + 
+--R                             3 2       2 2         4  4 2
+--R                      (- 840A C  + 588A B C - 56A B )a b
+--R                    + 
+--R                           2 3         2 2      4   5            4      2 3  6
+--R                    (- 368A C  + 312A B C  - 32B C)a b + (- 48A C  - 48B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6        4        3 2  2 5
+--R                      18A a b  + (340A C - 136A B )a b
+--R                    + 
+--R                            3 2       2 2          4  3 4
+--R                      (1406A C  - 858A B C + 136A B )a b
+--R                    + 
+--R                            2 3          2 2       4   4 3
+--R                      (1700A C  - 1086A B C  + 168B C)a b
+--R                    + 
+--R                             4       2 3  5 2      5 6
+--R                      (596A C  - 188B C )a b  + 56C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                          5 8          4       3 2    7
+--R                      - 2A b  + (- 100A C + 40A B )a b
+--R                    + 
+--R                             3 2       2 2         4  2 6
+--R                      (- 860A C  + 516A B C - 86A B )a b
+--R                    + 
+--R                              2 3          2 2       4   3 5
+--R                      (- 2082A C  + 1260A B C  - 208B C)a b
+--R                    + 
+--R                                4       2 3  4 4       5 5 3
+--R                      (- 1546A C  + 610B C )a b  - 294C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4      3 2  9        3 2       2 2         4    8
+--R                      (10A C - 4A B )b  + (220A C  - 132A B C + 22A B )a b
+--R                    + 
+--R                            2 3         2 2       4   2 7
+--R                      (1060A C  - 636A B C  + 106B C)a b
+--R                    + 
+--R                              4       2 3  3 6       5 4 5
+--R                      (1470A C  - 588B C )a b  + 518C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            3 2      2 2        4  10
+--R                      (- 20A C  + 12A B C - 2A B )b
+--R                    + 
+--R                             2 3         2 2      4     9
+--R                      (- 240A C  + 144A B C  - 24B C)a b
+--R                    + 
+--R                               4       2 3  2 8       5 3 7
+--R                      (- 640A C  + 256B C )a b  - 400C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          2 3        2 2     4   11          4      2 3    10
+--R                      (20A C  - 12A B C  + 2B C)b   + (130A C  - 52B C )a b
+--R                    + 
+--R                          5 2 9
+--R                      152C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                           4     2 3  12      5   11       5 13
+--R                  ((- 10A C  + 4B C )b   - 28C a b  )c + 2C b
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4 8
+--R                  4A a c
+--R                + 
+--R                          6 3 2         5       4 2  4
+--R                      - 9A a b  + (- 36A C + 24A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  5
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        6 2 4       5       4 2  3 3
+--R                      6A a b  + (65A C - 32A B )a b
+--R                    + 
+--R                           4 2       3 2       2 4  4 2
+--R                      (121A C  - 120A B C + 32A B )a b
+--R                    + 
+--R                         3 3      2 2 2        4   5
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  6
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         6   6         5       4 2  2 5
+--R                      - A a b  + (- 34A C + 14A B )a b
+--R                    + 
+--R                             4 2       3 2       2 4  3 4
+--R                      (- 170A C  + 120A B C - 24A B )a b
+--R                    + 
+--R                             3 3       2 2 2        4   4 3
+--R                      (- 162A C  + 144A B C  - 32A B C)a b
+--R                    + 
+--R                          2 4        2 3      4 2  5 2         5      2 4  6
+--R                      (41A C  - 56A B C  + 32B C )a b  + (28A C  - 40B C )a b
+--R                    + 
+--R                        6 7
+--R                      4C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         5      4 2    7       4 2      3 2      2 4  2 6
+--R                      (5A C - 2A B )a b  + (75A C  - 46A B C + 8A B )a b
+--R                    + 
+--R                           3 3       2 2 2        4   3 5
+--R                      (200A C  - 132A B C  + 24A B C)a b
+--R                    + 
+--R                          2 4       2 3      4 2  4 4           5      2 4  5 3
+--R                      (50A C  + 8A B C  - 24B C )a b  + (- 95A C  + 80B C )a b
+--R                    + 
+--R                           6 6 2
+--R                      - 25C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4    8
+--R                      (- 10A C  + 6A B C - A B )a b
+--R                    + 
+--R                            3 3      2 2 2       4   2 7
+--R                      (- 80A C  + 48A B C  - 8A B C)a b
+--R                    + 
+--R                            2 4        2 3     4 2  3 6         5      2 4  4 5
+--R                      (- 95A C  + 26A B C  + 8B C )a b  + (58A C  - 58B C )a b
+--R                    + 
+--R                         6 5 4
+--R                      50C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4     9
+--R                      (10A C  - 6A B C  + A B C)a b
+--R                    + 
+--R                          2 4        2 3    4 2  2 8         5      2 4  3 7
+--R                      (40A C  - 14A B C  - B C )a b  + (- A C  + 18B C )a b
+--R                    + 
+--R                           6 4 6
+--R                      - 35C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3    10          5     2 4  2 9      6 3 8
+--R                  ((- 5A C  + 2A B C )a b   + (- 6A C  - 2B C )a b  + 10C a b )c
+--R                + 
+--R                     5   11    6 2 10
+--R                  A C a b   - C a b
+--R             *
+--R                x
+--R            + 
+--R                 5   4        4         3 3  5  7
+--R              (8A B a b + (20A B C - 20A B )a )c
+--R            + 
+--R                      5   3 3         4         3 3  4 2
+--R                  - 7A B a b  + (- 59A B C + 29A B )a b
+--R                + 
+--R                        3   2      2 3         5  5          3 2     5   6
+--R                  (- 84A B C  + 64A B C - 12A B )a b + (20A B C  - 8B C)a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                   5   2 5       4         3 3  3 4
+--R                  A B a b  + (36A B C - 14A B )a b
+--R                + 
+--R                       3   2      2 3         5  4 3
+--R                  (155A B C  - 96A B C + 16A B )a b
+--R                + 
+--R                       2   3         3 2      5   5 2           4      3 3  6
+--R                  (148A B C  - 109A B C  + 24B C)a b  + (28A B C  - 32B C )a b
+--R                + 
+--R                       5 7
+--R                  12B C a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                       4        3 3  2 6         3   2      2 3        5  3 5
+--R                  (- 5A B C + 2A B )a b  + (- 76A B C  + 44A B C - 7A B )a b
+--R                + 
+--R                         2   3         3 2      5   4 4
+--R                  (- 200A B C  + 122A B C  - 22B C)a b
+--R                + 
+--R                             4      3 3  5 3        5 6 2
+--R                  (- 136A B C  + 72B C )a b  - 33B C a b
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                      3   2     2 3       5  2 7
+--R                  (10A B C  - 6A B C + A B )a b
+--R                + 
+--R                      2   3        3 2     5   3 6            4      3 3  4 5
+--R                  (82A B C  - 48A B C  + 8B C)a b  + (131A B C  - 56B C )a b
+--R                + 
+--R                       5 5 4
+--R                  52B C a b
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                        2   3       3 2    5   2 8             4      3 3  3 7
+--R                  (- 10A B C  + 6A B C  - B C)a b  + (- 45A B C  + 18B C )a b
+--R                + 
+--R                         5 4 6
+--R                  - 35B C a b
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                      4     3 3  2 9        5 3 8        5 2 10
+--R              ((5A B C  - 2B C )a b  + 10B C a b )c - B C a b
+--R     + 
+--R             3         2
+--R       2C c x  + 3B c x  + (6A c - 6C b)x
+--R  /
+--R       2
+--R     6c
+--R                                         Type: Union(Expression(Integer),...)
+--E 476
+
+--S 477 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R               2 +-+ |          2  +-+ |   |          2
+--R             2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R          *
+--R              +------------------+
+--R              | +-----------+
+--R              | |          2
+--R             \|\|- 4a c + b   + b
+--R          *
+--R             ROOT
+--R                            6     2 5      2
+--R                    (- 12a c  + 3b c )%%BI1
+--R                  + 
+--R                            6     2 5                 4       3 3
+--R                    ((- 8a c  + 2b c )%%BI0 - 8B a b c  + 2B b c )%%BI1
+--R                  + 
+--R                            6     2 5      2              4       3 3
+--R                    (- 12a c  + 3b c )%%BI0  + (- 8B a b c  + 2B b c )%%BI0
+--R                  + 
+--R                         2                  2  2  3
+--R                    (- 3A a b + (- 4A C - 2B )a )c
+--R                  + 
+--R                    2 3           2     2 2   2            4     2   3      2 5
+--R                  (A b  + 8A C a b  + 5C a b)c  + (- 2A C b  - 5C a b )c + C b
+--R               /
+--R                      6    2 5
+--R                  4a c  - b c
+--R         + 
+--R           -
+--R                                          +--------------------+
+--R                        +-----------+     |   +-----------+
+--R                  2 +-+ |          2  +-+ |   |          2
+--R                2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b %%BI1
+--R         + 
+--R                        +-----------+                     +-----------+
+--R                  2 +-+ |          2  +-+             +-+ |          2  +-+
+--R             (- 2c \|2 \|- 4a c + b  \|c %%BI0 - 2B b\|2 \|- 4a c + b  \|c )
+--R          *
+--R              +--------------------+ +------------------+
+--R              |   +-----------+      | +-----------+
+--R              |   |          2       | |          2
+--R             \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              3 3         2          2  4  11
+--R                          (64A a b + (128A C - 256A B )a )c
+--R                        + 
+--R                                   3 2 3          2          2  3 2
+--R                              - 96A a b  + (- 512A C + 384A B )a b
+--R                            + 
+--R                                       2       2   4        3 5
+--R                              (- 576A C  + 256B C)a b - 128C a
+--R                         *
+--R                             10
+--R                            c
+--R                        + 
+--R                                 3   5        2          2  2 4
+--R                              36A a b  + (424A C - 208A B )a b
+--R                            + 
+--R                                     2       2   3 3       3 4 2
+--R                              (992A C  - 384B C)a b  + 512C a b
+--R                         *
+--R                             9
+--R                            c
+--R                        + 
+--R                                  3 7          2         2    6
+--R                              - 4A b  + (- 124A C + 48A B )a b
+--R                            + 
+--R                                       2       2   2 5       3 3 4
+--R                              (- 580A C  + 208B C)a b  - 552C a b
+--R                         *
+--R                             8
+--R                            c
+--R                        + 
+--R                                  2        2  8          2      2     7
+--R                              (12A C - 4A B )b  + (140A C  - 48B C)a b
+--R                            + 
+--R                                  3 2 6
+--R                              252C a b
+--R                         *
+--R                             7
+--R                            c
+--R                        + 
+--R                                   2     2   9      3   8  6     3 10 5
+--R                          ((- 12A C  + 4B C)b  - 52C a b )c  + 4C b  c
+--R                     *
+--R                        %%BI0
+--R                    + 
+--R                           3   4 10
+--R                      - 32A B a c
+--R                    + 
+--R                             3   3 2       2           3  4
+--R                          32A B a b  + (32A B C - 32A B )a b
+--R                        + 
+--R                                    2      3   5
+--R                          (- 96A B C  + 64B C)a
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                               3   2 4         2           3  3 3
+--R                          - 14A B a b  + (- 56A B C + 40A B )a b
+--R                        + 
+--R                                  2      3   4 2        3 5
+--R                          (96A B C  - 80B C)a b  + 96B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                            3     6       2           3  2 5
+--R                          2A B a b  + (28A B C - 16A B )a b
+--R                        + 
+--R                                    2      3   3 4         3 4 3
+--R                          (- 10A B C  + 32B C)a b  - 104B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                               2          3    7             2     3   2 6
+--R                          (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                        + 
+--R                               3 3 5
+--R                          36B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                             2   8       3 2 7  5
+--R                      (2A B C a b  - 4B C a b )c
+--R                 *
+--R                    %%BI1
+--R                + 
+--R                           3   4 10
+--R                      - 32A B a c
+--R                    + 
+--R                             3   3 2       2           3  4
+--R                          32A B a b  + (32A B C - 32A B )a b
+--R                        + 
+--R                                    2      3   5
+--R                          (- 96A B C  + 64B C)a
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                               3   2 4         2           3  3 3
+--R                          - 14A B a b  + (- 56A B C + 40A B )a b
+--R                        + 
+--R                                  2      3   4 2        3 5
+--R                          (96A B C  - 80B C)a b  + 96B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                            3     6       2           3  2 5
+--R                          2A B a b  + (28A B C - 16A B )a b
+--R                        + 
+--R                                    2      3   3 4         3 4 3
+--R                          (- 10A B C  + 32B C)a b  - 104B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                               2          3    7             2     3   2 6
+--R                          (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                        + 
+--R                               3 3 5
+--R                          36B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                             2   8       3 2 7  5
+--R                      (2A B C a b  - 4B C a b )c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                      5 4 9
+--R                  - 8A a c
+--R                + 
+--R                      5 3 2       4       3 2  4          2 2         4  5  8
+--R                  (14A a b  + (52A C - 36A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                          5 2 4         4       3 2  3 3
+--R                      - 7A a b  + (- 73A C + 41A B )a b
+--R                    + 
+--R                             3 2      2 2         4  4 2
+--R                      (- 108A C  + 98A B C - 36A B )a b
+--R                    + 
+--R                          2 3        2 2      4   5         4     2 3  6
+--R                      (24A C  - 12A B C  + 16B C)a b + (8A C  - 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                       5   6       4       3 2  2 5
+--R                      A a b  + (31A C - 16A B )a b
+--R                    + 
+--R                           3 2      2 2         4  3 4
+--R                      (131A C  - 95A B C + 28A B )a b
+--R                    + 
+--R                          2 3        2 2      4   4 3           4      2 3  5 2
+--R                      (62A C  - 21A B C  - 20B C)a b  + (- 66A C  + 54B C )a b
+--R                    + 
+--R                           5 6
+--R                      - 12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                           4      3 2    7         3 2      2 2        4  2 6
+--R                      (- 4A C + 2A B )a b  + (- 50A C  + 34A B C - 9A B )a b
+--R                    + 
+--R                            2 3        2 2     4   3 5         4      2 3  4 4
+--R                      (- 89A C  + 38A B C  + 8B C)a b  + (36A C  - 53B C )a b
+--R                    + 
+--R                         5 5 3
+--R                      43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         3 2     2 2       4    8
+--R                      (6A C  - 4A B C + A B )a b
+--R                    + 
+--R                          2 3        2 2    4   2 7        4      2 3  3 6
+--R                      (34A C  - 16A B C  - B C)a b  + (7A C  + 18B C )a b
+--R                    + 
+--R                           5 4 5
+--R                      - 34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                        2 3       2 2    9          4     2 3  2 8      5 3 7  3
+--R                  ((- 4A C  + 2A B C )a b  + (- 7A C  - 2B C )a b  + 10C a b )c
+--R                + 
+--R                      4   10    5 2 9  2
+--R                  (A C a b   - C a b )c
+--R             *
+--R                ROOT
+--R                               6     2 5      2
+--R                       (- 12a c  + 3b c )%%BI1
+--R                     + 
+--R                               6     2 5                 4       3 3
+--R                       ((- 8a c  + 2b c )%%BI0 - 8B a b c  + 2B b c )%%BI1
+--R                     + 
+--R                               6     2 5      2              4       3 3
+--R                       (- 12a c  + 3b c )%%BI0  + (- 8B a b c  + 2B b c )%%BI0
+--R                     + 
+--R                            2                  2  2  3
+--R                       (- 3A a b + (- 4A C - 2B )a )c
+--R                     + 
+--R                         2 3           2     2 2   2            4     2   3
+--R                       (A b  + 8A C a b  + 5C a b)c  + (- 2A C b  - 5C a b )c
+--R                     + 
+--R                        2 5
+--R                       C b
+--R                  /
+--R                         6    2 5
+--R                     4a c  - b c
+--R            + 
+--R                          3 3         2          2  4  11
+--R                      (64A a b + (128A C - 256A B )a )c
+--R                    + 
+--R                               3 2 3          2          2  3 2
+--R                          - 96A a b  + (- 512A C + 384A B )a b
+--R                        + 
+--R                                   2       2   4        3 5
+--R                          (- 576A C  + 256B C)a b - 128C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                             3   5        2          2  2 4
+--R                          36A a b  + (424A C - 208A B )a b
+--R                        + 
+--R                                 2       2   3 3       3 4 2
+--R                          (992A C  - 384B C)a b  + 512C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                              3 7          2         2    6
+--R                          - 4A b  + (- 124A C + 48A B )a b
+--R                        + 
+--R                                   2       2   2 5       3 3 4
+--R                          (- 580A C  + 208B C)a b  - 552C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                           2        2  8          2      2     7       3 2 6  7
+--R                      ((12A C - 4A B )b  + (140A C  - 48B C)a b  + 252C a b )c
+--R                    + 
+--R                               2     2   9      3   8  6     3 10 5
+--R                      ((- 12A C  + 4B C)b  - 52C a b )c  + 4C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                       3   4 10
+--R                  - 32A B a c
+--R                + 
+--R                           3   3 2       2           3  4
+--R                        32A B a b  + (32A B C - 32A B )a b
+--R                      + 
+--R                                  2      3   5
+--R                        (- 96A B C  + 64B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                           3   2 4         2           3  3 3
+--R                      - 14A B a b  + (- 56A B C + 40A B )a b
+--R                    + 
+--R                              2      3   4 2        3 5
+--R                      (96A B C  - 80B C)a b  + 96B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                        3     6       2           3  2 5
+--R                      2A B a b  + (28A B C - 16A B )a b
+--R                    + 
+--R                                2      3   3 4         3 4 3
+--R                      (- 10A B C  + 32B C)a b  - 104B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           2          3    7             2     3   2 6
+--R                      (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                    + 
+--R                           3 3 5
+--R                      36B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         2   8       3 2 7  5
+--R                  (2A B C a b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BI1
+--R            + 
+--R                          3 3         2          2  4  11
+--R                      (64A a b + (128A C - 256A B )a )c
+--R                    + 
+--R                               3 2 3          2          2  3 2
+--R                          - 96A a b  + (- 512A C + 384A B )a b
+--R                        + 
+--R                                   2       2   4        3 5
+--R                          (- 576A C  + 256B C)a b - 128C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                             3   5        2          2  2 4
+--R                          36A a b  + (424A C - 208A B )a b
+--R                        + 
+--R                                 2       2   3 3       3 4 2
+--R                          (992A C  - 384B C)a b  + 512C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                              3 7          2         2    6
+--R                          - 4A b  + (- 124A C + 48A B )a b
+--R                        + 
+--R                                   2       2   2 5       3 3 4
+--R                          (- 580A C  + 208B C)a b  - 552C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                           2        2  8          2      2     7       3 2 6  7
+--R                      ((12A C - 4A B )b  + (140A C  - 48B C)a b  + 252C a b )c
+--R                    + 
+--R                               2     2   9      3   8  6     3 10 5
+--R                      ((- 12A C  + 4B C)b  - 52C a b )c  + 4C b  c
+--R                 *
+--R                         2
+--R                    %%BI0
+--R                + 
+--R                          3   3 2        2            3  4   9
+--R                      (64A B a b  + (128A B C - 256A B )a b)c
+--R                    + 
+--R                               3   2 4          2            3  3 3
+--R                          - 96A B a b  + (- 512A B C + 384A B )a b
+--R                        + 
+--R                                     2       3   4 2         3 5
+--R                          (- 576A B C  + 256B C)a b  - 128B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                             3     6        2            3  2 5
+--R                          36A B a b  + (424A B C - 208A B )a b
+--R                        + 
+--R                                   2       3   3 4         3 4 3
+--R                          (992A B C  - 384B C)a b  + 512B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              3   8          2           3    7
+--R                          - 4A B b  + (- 124A B C + 48A B )a b
+--R                        + 
+--R                                     2       3   2 6         3 3 5
+--R                          (- 580A B C  + 208B C)a b  - 552B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              2          3  9            2      3     8
+--R                          (12A B C - 4A B )b  + (140A B C  - 48B C)a b
+--R                        + 
+--R                                3 2 7
+--R                          252B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                 2     3   10        3   9  4       3 11 3
+--R                      ((- 12A B C  + 4B C)b   - 52B C a b )c  + 4B C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                    5 4 9
+--R                  8A a c
+--R                + 
+--R                        5 3 2         4      3 2  4        2 2         4  5  8
+--R                  (- 14A a b  + (- 52A C + 4A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                        5 2 4       4      3 2  3 3
+--R                      7A a b  + (73A C - 9A B )a b
+--R                    + 
+--R                           3 2      2 2        4  4 2
+--R                      (108A C  - 66A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   5           4     2 3  6
+--R                      (- 24A C  - 84A B C  + 48B C)a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6         4      3 2  2 5
+--R                      - A a b  + (- 31A C + 2A B )a b
+--R                    + 
+--R                             3 2      2 2         4  3 4
+--R                      (- 131A C  + 39A B C + 12A B )a b
+--R                    + 
+--R                            2 3         2 2      4   4 3         4      2 3  5 2
+--R                      (- 62A C  + 117A B C  - 60B C)a b  + (66A C  + 42B C )a b
+--R                    + 
+--R                         5 6
+--R                      12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4     7       3 2     2 2        4  2 6
+--R                      4A C a b  + (50A C  - 6A B C - 7A B )a b
+--R                    + 
+--R                          2 3        2 2      4   3 5           4      2 3  4 4
+--R                      (89A C  - 48A B C  + 24B C)a b  + (- 36A C  - 51B C )a b
+--R                    + 
+--R                           5 5 3
+--R                      - 43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3 2      4    8         2 3       2 2     4   2 7
+--R                      (- 6A C  + A B )a b  + (- 34A C  + 6A B C  - 3B C)a b
+--R                    + 
+--R                             4      2 3  3 6      5 4 5
+--R                      (- 7A C  + 18B C )a b  + 34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                     2 3   9        4     2 3  2 8      5 3 7  3
+--R                  (4A C a b  + (7A C  - 2B C )a b  - 10C a b )c
+--R                + 
+--R                        4   10    5 2 9  2
+--R                  (- A C a b   + C a b )c
+--R             *
+--R                %%BI1
+--R            + 
+--R                       3   4 10
+--R                  - 32A B a c
+--R                + 
+--R                           3   3 2       2           3  4
+--R                        32A B a b  + (32A B C - 32A B )a b
+--R                      + 
+--R                                  2      3   5
+--R                        (- 96A B C  + 64B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                           3   2 4         2           3  3 3
+--R                      - 14A B a b  + (- 56A B C + 40A B )a b
+--R                    + 
+--R                              2      3   4 2        3 5
+--R                      (96A B C  - 80B C)a b  + 96B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                        3     6       2           3  2 5
+--R                      2A B a b  + (28A B C - 16A B )a b
+--R                    + 
+--R                                2      3   3 4         3 4 3
+--R                      (- 10A B C  + 32B C)a b  - 104B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           2          3    7             2     3   2 6
+--R                      (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                    + 
+--R                           3 3 5
+--R                      36B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         2   8       3 2 7  5
+--R                  (2A B C a b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BI0
+--R            + 
+--R                    5 4 9
+--R                  8A a c
+--R                + 
+--R                        5 3 2         4      3 2  4        2 2         4  5  8
+--R                  (- 14A a b  + (- 52A C + 4A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                        5 2 4       4      3 2  3 3
+--R                      7A a b  + (73A C - 9A B )a b
+--R                    + 
+--R                           3 2      2 2        4  4 2
+--R                      (108A C  - 66A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   5           4     2 3  6
+--R                      (- 24A C  - 84A B C  + 48B C)a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6         4      3 2  2 5
+--R                      - A a b  + (- 31A C + 2A B )a b
+--R                    + 
+--R                             3 2      2 2         4  3 4
+--R                      (- 131A C  + 39A B C + 12A B )a b
+--R                    + 
+--R                            2 3         2 2      4   4 3         4      2 3  5 2
+--R                      (- 62A C  + 117A B C  - 60B C)a b  + (66A C  + 42B C )a b
+--R                    + 
+--R                         5 6
+--R                      12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4     7       3 2     2 2        4  2 6
+--R                      4A C a b  + (50A C  - 6A B C - 7A B )a b
+--R                    + 
+--R                          2 3        2 2      4   3 5           4      2 3  4 4
+--R                      (89A C  - 48A B C  + 24B C)a b  + (- 36A C  - 51B C )a b
+--R                    + 
+--R                           5 5 3
+--R                      - 43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3 2      4    8         2 3       2 2     4   2 7
+--R                      (- 6A C  + A B )a b  + (- 34A C  + 6A B C  - 3B C)a b
+--R                    + 
+--R                             4      2 3  3 6      5 4 5
+--R                      (- 7A C  + 18B C )a b  + 34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                     2 3   9        4     2 3  2 8      5 3 7  3
+--R                  (4A C a b  + (7A C  - 2B C )a b  - 10C a b )c
+--R                + 
+--R                        4   10    5 2 9  2
+--R                  (- A C a b   + C a b )c
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4 8
+--R                  4A a c
+--R                + 
+--R                          6 3 2         5       4 2  4
+--R                      - 9A a b  + (- 36A C + 24A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  5
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        6 2 4       5       4 2  3 3
+--R                      6A a b  + (65A C - 32A B )a b
+--R                    + 
+--R                           4 2       3 2       2 4  4 2
+--R                      (121A C  - 120A B C + 32A B )a b
+--R                    + 
+--R                         3 3      2 2 2        4   5
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  6
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         6   6         5       4 2  2 5
+--R                      - A a b  + (- 34A C + 14A B )a b
+--R                    + 
+--R                             4 2       3 2       2 4  3 4
+--R                      (- 170A C  + 120A B C - 24A B )a b
+--R                    + 
+--R                             3 3       2 2 2        4   4 3
+--R                      (- 162A C  + 144A B C  - 32A B C)a b
+--R                    + 
+--R                          2 4        2 3      4 2  5 2         5      2 4  6
+--R                      (41A C  - 56A B C  + 32B C )a b  + (28A C  - 40B C )a b
+--R                    + 
+--R                        6 7
+--R                      4C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         5      4 2    7       4 2      3 2      2 4  2 6
+--R                      (5A C - 2A B )a b  + (75A C  - 46A B C + 8A B )a b
+--R                    + 
+--R                           3 3       2 2 2        4   3 5
+--R                      (200A C  - 132A B C  + 24A B C)a b
+--R                    + 
+--R                          2 4       2 3      4 2  4 4           5      2 4  5 3
+--R                      (50A C  + 8A B C  - 24B C )a b  + (- 95A C  + 80B C )a b
+--R                    + 
+--R                           6 6 2
+--R                      - 25C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4    8
+--R                      (- 10A C  + 6A B C - A B )a b
+--R                    + 
+--R                            3 3      2 2 2       4   2 7
+--R                      (- 80A C  + 48A B C  - 8A B C)a b
+--R                    + 
+--R                            2 4        2 3     4 2  3 6         5      2 4  4 5
+--R                      (- 95A C  + 26A B C  + 8B C )a b  + (58A C  - 58B C )a b
+--R                    + 
+--R                         6 5 4
+--R                      50C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4     9
+--R                      (10A C  - 6A B C  + A B C)a b
+--R                    + 
+--R                          2 4        2 3    4 2  2 8         5      2 4  3 7
+--R                      (40A C  - 14A B C  - B C )a b  + (- A C  + 18B C )a b
+--R                    + 
+--R                           6 4 6
+--R                      - 35C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3    10          5     2 4  2 9      6 3 8
+--R                  ((- 5A C  + 2A B C )a b   + (- 6A C  - 2B C )a b  + 10C a b )c
+--R                + 
+--R                     5   11    6 2 10
+--R                  A C a b   - C a b
+--R             *
+--R                x
+--R            + 
+--R                   5   4          4        3 3  5  7
+--R              (- 4A B a b + (- 12A B C + 4A B )a )c
+--R            + 
+--R                    5   3 3       4        3 3  4 2
+--R                  2A B a b  + (21A B C - 5A B )a b
+--R                + 
+--R                    3   2     2 3        5  5          2   3       3 2     5   6
+--R                (28A B C  - 8A B C - 4A B )a b + (- 16A B C  - 4A B C  + 8B C)a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                       4       3 3  3 4         3   2     2 3        5  4 3
+--R                  (- 7A B C + A B )a b  + (- 33A B C  + 6A B C + 4A B )a b
+--R                + 
+--R                       2   3       3 2     5   5 2           4     3 3  6
+--R                  (- 8A B C  + 5A B C  - 8B C)a b  + (24A B C  + 8B C )a b
+--R                + 
+--R                        5 7
+--R                  - 4B C a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                     3   2    2 3       5  3 5       2   3      3 2     5   4 4
+--R                  (9A B C  - A B C - A B )a b  + (18A B C  - A B C  + 2B C)a b
+--R                + 
+--R                            4     3 3  5 3       5 6 2
+--R                  (- 13A B C  - 6B C )a b  - 5B C a b
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                   2   3 3 6           4    3 3  4 5       5 5 4  3
+--R              (- 5A B C a b  + (- A B C  + B C )a b  + 5B C a b )c
+--R            + 
+--R                    4 3 7      5 4 6  2
+--R              (A B C a b  - B C a b )c
+--R     + 
+--R           -
+--R                                          +--------------------+
+--R                        +-----------+     |   +-----------+
+--R                  2 +-+ |          2  +-+ |   |          2
+--R                2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b
+--R             *
+--R                ROOT
+--R                               6     2 5      2
+--R                       (- 12a c  + 3b c )%%BI1
+--R                     + 
+--R                               6     2 5                 4       3 3
+--R                       ((- 8a c  + 2b c )%%BI0 - 8B a b c  + 2B b c )%%BI1
+--R                     + 
+--R                               6     2 5      2              4       3 3
+--R                       (- 12a c  + 3b c )%%BI0  + (- 8B a b c  + 2B b c )%%BI0
+--R                     + 
+--R                            2                  2  2  3
+--R                       (- 3A a b + (- 4A C - 2B )a )c
+--R                     + 
+--R                         2 3           2     2 2   2            4     2   3
+--R                       (A b  + 8A C a b  + 5C a b)c  + (- 2A C b  - 5C a b )c
+--R                     + 
+--R                        2 5
+--R                       C b
+--R                  /
+--R                         6    2 5
+--R                     4a c  - b c
+--R         + 
+--R           -
+--R                                          +--------------------+
+--R                        +-----------+     |   +-----------+
+--R                  2 +-+ |          2  +-+ |   |          2
+--R                2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b %%BI1
+--R         + 
+--R                        +-----------+                     +-----------+
+--R                  2 +-+ |          2  +-+             +-+ |          2  +-+
+--R             (- 2c \|2 \|- 4a c + b  \|c %%BI0 - 2B b\|2 \|- 4a c + b  \|c )
+--R          *
+--R              +--------------------+ +------------------+
+--R              |   +-----------+      | +-----------+
+--R              |   |          2       | |          2
+--R             \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                3 3           2          2  4  11
+--R                          (- 64A a b + (- 128A C + 256A B )a )c
+--R                        + 
+--R                                 3 2 3        2          2  3 2
+--R                              96A a b  + (512A C - 384A B )a b
+--R                            + 
+--R                                     2       2   4        3 5
+--R                              (576A C  - 256B C)a b + 128C a
+--R                         *
+--R                             10
+--R                            c
+--R                        + 
+--R                                   3   5          2          2  2 4
+--R                              - 36A a b  + (- 424A C + 208A B )a b
+--R                            + 
+--R                                       2       2   3 3       3 4 2
+--R                              (- 992A C  + 384B C)a b  - 512C a b
+--R                         *
+--R                             9
+--R                            c
+--R                        + 
+--R                                3 7        2         2    6
+--R                              4A b  + (124A C - 48A B )a b
+--R                            + 
+--R                                     2       2   2 5       3 3 4
+--R                              (580A C  - 208B C)a b  + 552C a b
+--R                         *
+--R                             8
+--R                            c
+--R                        + 
+--R                                    2        2  8            2      2     7
+--R                              (- 12A C + 4A B )b  + (- 140A C  + 48B C)a b
+--R                            + 
+--R                                    3 2 6
+--R                              - 252C a b
+--R                         *
+--R                             7
+--R                            c
+--R                        + 
+--R                                 2     2   9      3   8  6     3 10 5
+--R                          ((12A C  - 4B C)b  + 52C a b )c  - 4C b  c
+--R                     *
+--R                        %%BI0
+--R                    + 
+--R                         3   4 10
+--R                      32A B a c
+--R                    + 
+--R                               3   3 2         2           3  4
+--R                          - 32A B a b  + (- 32A B C + 32A B )a b
+--R                        + 
+--R                                  2      3   5
+--R                          (96A B C  - 64B C)a
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                             3   2 4       2           3  3 3
+--R                          14A B a b  + (56A B C - 40A B )a b
+--R                        + 
+--R                                    2      3   4 2        3 5
+--R                          (- 96A B C  + 80B C)a b  - 96B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                              3     6         2           3  2 5
+--R                          - 2A B a b  + (- 28A B C + 16A B )a b
+--R                        + 
+--R                                  2      3   3 4         3 4 3
+--R                          (10A B C  - 32B C)a b  + 104B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                             2          3    7           2     3   2 6
+--R                          (4A B C - 2A B )a b  + (10A B C  + 4B C)a b
+--R                        + 
+--R                                 3 3 5
+--R                          - 36B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                               2   8       3 2 7  5
+--R                      (- 2A B C a b  + 4B C a b )c
+--R                 *
+--R                    %%BI1
+--R                + 
+--R                         3   4 10
+--R                      32A B a c
+--R                    + 
+--R                               3   3 2         2           3  4
+--R                          - 32A B a b  + (- 32A B C + 32A B )a b
+--R                        + 
+--R                                  2      3   5
+--R                          (96A B C  - 64B C)a
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                             3   2 4       2           3  3 3
+--R                          14A B a b  + (56A B C - 40A B )a b
+--R                        + 
+--R                                    2      3   4 2        3 5
+--R                          (- 96A B C  + 80B C)a b  - 96B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                              3     6         2           3  2 5
+--R                          - 2A B a b  + (- 28A B C + 16A B )a b
+--R                        + 
+--R                                  2      3   3 4         3 4 3
+--R                          (10A B C  - 32B C)a b  + 104B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                             2          3    7           2     3   2 6
+--R                          (4A B C - 2A B )a b  + (10A B C  + 4B C)a b
+--R                        + 
+--R                                 3 3 5
+--R                          - 36B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                               2   8       3 2 7  5
+--R                      (- 2A B C a b  + 4B C a b )c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                    5 4 9
+--R                  8A a c
+--R                + 
+--R                        5 3 2         4       3 2  4        2 2         4  5  8
+--R                  (- 14A a b  + (- 52A C + 36A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                        5 2 4       4       3 2  3 3
+--R                      7A a b  + (73A C - 41A B )a b
+--R                    + 
+--R                           3 2      2 2         4  4 2
+--R                      (108A C  - 98A B C + 36A B )a b
+--R                    + 
+--R                            2 3        2 2      4   5           4     2 3  6
+--R                      (- 24A C  + 12A B C  - 16B C)a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6         4       3 2  2 5
+--R                      - A a b  + (- 31A C + 16A B )a b
+--R                    + 
+--R                             3 2      2 2         4  3 4
+--R                      (- 131A C  + 95A B C - 28A B )a b
+--R                    + 
+--R                            2 3        2 2      4   4 3         4      2 3  5 2
+--R                      (- 62A C  + 21A B C  + 20B C)a b  + (66A C  - 54B C )a b
+--R                    + 
+--R                         5 6
+--R                      12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         4      3 2    7       3 2      2 2        4  2 6
+--R                      (4A C - 2A B )a b  + (50A C  - 34A B C + 9A B )a b
+--R                    + 
+--R                          2 3        2 2     4   3 5           4      2 3  4 4
+--R                      (89A C  - 38A B C  - 8B C)a b  + (- 36A C  + 53B C )a b
+--R                    + 
+--R                           5 5 3
+--R                      - 43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3 2     2 2       4    8
+--R                      (- 6A C  + 4A B C - A B )a b
+--R                    + 
+--R                            2 3        2 2    4   2 7          4      2 3  3 6
+--R                      (- 34A C  + 16A B C  + B C)a b  + (- 7A C  - 18B C )a b
+--R                    + 
+--R                         5 4 5
+--R                      34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                      2 3       2 2    9        4     2 3  2 8      5 3 7  3
+--R                  ((4A C  - 2A B C )a b  + (7A C  + 2B C )a b  - 10C a b )c
+--R                + 
+--R                        4   10    5 2 9  2
+--R                  (- A C a b   + C a b )c
+--R             *
+--R                ROOT
+--R                               6     2 5      2
+--R                       (- 12a c  + 3b c )%%BI1
+--R                     + 
+--R                               6     2 5                 4       3 3
+--R                       ((- 8a c  + 2b c )%%BI0 - 8B a b c  + 2B b c )%%BI1
+--R                     + 
+--R                               6     2 5      2              4       3 3
+--R                       (- 12a c  + 3b c )%%BI0  + (- 8B a b c  + 2B b c )%%BI0
+--R                     + 
+--R                            2                  2  2  3
+--R                       (- 3A a b + (- 4A C - 2B )a )c
+--R                     + 
+--R                         2 3           2     2 2   2            4     2   3
+--R                       (A b  + 8A C a b  + 5C a b)c  + (- 2A C b  - 5C a b )c
+--R                     + 
+--R                        2 5
+--R                       C b
+--R                  /
+--R                         6    2 5
+--R                     4a c  - b c
+--R            + 
+--R                          3 3         2          2  4  11
+--R                      (64A a b + (128A C - 256A B )a )c
+--R                    + 
+--R                               3 2 3          2          2  3 2
+--R                          - 96A a b  + (- 512A C + 384A B )a b
+--R                        + 
+--R                                   2       2   4        3 5
+--R                          (- 576A C  + 256B C)a b - 128C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                             3   5        2          2  2 4
+--R                          36A a b  + (424A C - 208A B )a b
+--R                        + 
+--R                                 2       2   3 3       3 4 2
+--R                          (992A C  - 384B C)a b  + 512C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                              3 7          2         2    6
+--R                          - 4A b  + (- 124A C + 48A B )a b
+--R                        + 
+--R                                   2       2   2 5       3 3 4
+--R                          (- 580A C  + 208B C)a b  - 552C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                           2        2  8          2      2     7       3 2 6  7
+--R                      ((12A C - 4A B )b  + (140A C  - 48B C)a b  + 252C a b )c
+--R                    + 
+--R                               2     2   9      3   8  6     3 10 5
+--R                      ((- 12A C  + 4B C)b  - 52C a b )c  + 4C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                       3   4 10
+--R                  - 32A B a c
+--R                + 
+--R                           3   3 2       2           3  4
+--R                        32A B a b  + (32A B C - 32A B )a b
+--R                      + 
+--R                                  2      3   5
+--R                        (- 96A B C  + 64B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                           3   2 4         2           3  3 3
+--R                      - 14A B a b  + (- 56A B C + 40A B )a b
+--R                    + 
+--R                              2      3   4 2        3 5
+--R                      (96A B C  - 80B C)a b  + 96B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                        3     6       2           3  2 5
+--R                      2A B a b  + (28A B C - 16A B )a b
+--R                    + 
+--R                                2      3   3 4         3 4 3
+--R                      (- 10A B C  + 32B C)a b  - 104B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           2          3    7             2     3   2 6
+--R                      (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                    + 
+--R                           3 3 5
+--R                      36B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         2   8       3 2 7  5
+--R                  (2A B C a b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BI1
+--R            + 
+--R                          3 3         2          2  4  11
+--R                      (64A a b + (128A C - 256A B )a )c
+--R                    + 
+--R                               3 2 3          2          2  3 2
+--R                          - 96A a b  + (- 512A C + 384A B )a b
+--R                        + 
+--R                                   2       2   4        3 5
+--R                          (- 576A C  + 256B C)a b - 128C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                             3   5        2          2  2 4
+--R                          36A a b  + (424A C - 208A B )a b
+--R                        + 
+--R                                 2       2   3 3       3 4 2
+--R                          (992A C  - 384B C)a b  + 512C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                              3 7          2         2    6
+--R                          - 4A b  + (- 124A C + 48A B )a b
+--R                        + 
+--R                                   2       2   2 5       3 3 4
+--R                          (- 580A C  + 208B C)a b  - 552C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                           2        2  8          2      2     7       3 2 6  7
+--R                      ((12A C - 4A B )b  + (140A C  - 48B C)a b  + 252C a b )c
+--R                    + 
+--R                               2     2   9      3   8  6     3 10 5
+--R                      ((- 12A C  + 4B C)b  - 52C a b )c  + 4C b  c
+--R                 *
+--R                         2
+--R                    %%BI0
+--R                + 
+--R                          3   3 2        2            3  4   9
+--R                      (64A B a b  + (128A B C - 256A B )a b)c
+--R                    + 
+--R                               3   2 4          2            3  3 3
+--R                          - 96A B a b  + (- 512A B C + 384A B )a b
+--R                        + 
+--R                                     2       3   4 2         3 5
+--R                          (- 576A B C  + 256B C)a b  - 128B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                             3     6        2            3  2 5
+--R                          36A B a b  + (424A B C - 208A B )a b
+--R                        + 
+--R                                   2       3   3 4         3 4 3
+--R                          (992A B C  - 384B C)a b  + 512B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              3   8          2           3    7
+--R                          - 4A B b  + (- 124A B C + 48A B )a b
+--R                        + 
+--R                                     2       3   2 6         3 3 5
+--R                          (- 580A B C  + 208B C)a b  - 552B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              2          3  9            2      3     8
+--R                          (12A B C - 4A B )b  + (140A B C  - 48B C)a b
+--R                        + 
+--R                                3 2 7
+--R                          252B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                 2     3   10        3   9  4       3 11 3
+--R                      ((- 12A B C  + 4B C)b   - 52B C a b )c  + 4B C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                    5 4 9
+--R                  8A a c
+--R                + 
+--R                        5 3 2         4      3 2  4        2 2         4  5  8
+--R                  (- 14A a b  + (- 52A C + 4A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                        5 2 4       4      3 2  3 3
+--R                      7A a b  + (73A C - 9A B )a b
+--R                    + 
+--R                           3 2      2 2        4  4 2
+--R                      (108A C  - 66A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   5           4     2 3  6
+--R                      (- 24A C  - 84A B C  + 48B C)a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6         4      3 2  2 5
+--R                      - A a b  + (- 31A C + 2A B )a b
+--R                    + 
+--R                             3 2      2 2         4  3 4
+--R                      (- 131A C  + 39A B C + 12A B )a b
+--R                    + 
+--R                            2 3         2 2      4   4 3         4      2 3  5 2
+--R                      (- 62A C  + 117A B C  - 60B C)a b  + (66A C  + 42B C )a b
+--R                    + 
+--R                         5 6
+--R                      12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4     7       3 2     2 2        4  2 6
+--R                      4A C a b  + (50A C  - 6A B C - 7A B )a b
+--R                    + 
+--R                          2 3        2 2      4   3 5           4      2 3  4 4
+--R                      (89A C  - 48A B C  + 24B C)a b  + (- 36A C  - 51B C )a b
+--R                    + 
+--R                           5 5 3
+--R                      - 43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3 2      4    8         2 3       2 2     4   2 7
+--R                      (- 6A C  + A B )a b  + (- 34A C  + 6A B C  - 3B C)a b
+--R                    + 
+--R                             4      2 3  3 6      5 4 5
+--R                      (- 7A C  + 18B C )a b  + 34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                     2 3   9        4     2 3  2 8      5 3 7  3
+--R                  (4A C a b  + (7A C  - 2B C )a b  - 10C a b )c
+--R                + 
+--R                        4   10    5 2 9  2
+--R                  (- A C a b   + C a b )c
+--R             *
+--R                %%BI1
+--R            + 
+--R                       3   4 10
+--R                  - 32A B a c
+--R                + 
+--R                           3   3 2       2           3  4
+--R                        32A B a b  + (32A B C - 32A B )a b
+--R                      + 
+--R                                  2      3   5
+--R                        (- 96A B C  + 64B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                           3   2 4         2           3  3 3
+--R                      - 14A B a b  + (- 56A B C + 40A B )a b
+--R                    + 
+--R                              2      3   4 2        3 5
+--R                      (96A B C  - 80B C)a b  + 96B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                        3     6       2           3  2 5
+--R                      2A B a b  + (28A B C - 16A B )a b
+--R                    + 
+--R                                2      3   3 4         3 4 3
+--R                      (- 10A B C  + 32B C)a b  - 104B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           2          3    7             2     3   2 6
+--R                      (- 4A B C + 2A B )a b  + (- 10A B C  - 4B C)a b
+--R                    + 
+--R                           3 3 5
+--R                      36B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         2   8       3 2 7  5
+--R                  (2A B C a b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BI0
+--R            + 
+--R                    5 4 9
+--R                  8A a c
+--R                + 
+--R                        5 3 2         4      3 2  4        2 2         4  5  8
+--R                  (- 14A a b  + (- 52A C + 4A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                        5 2 4       4      3 2  3 3
+--R                      7A a b  + (73A C - 9A B )a b
+--R                    + 
+--R                           3 2      2 2        4  4 2
+--R                      (108A C  - 66A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   5           4     2 3  6
+--R                      (- 24A C  - 84A B C  + 48B C)a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                         5   6         4      3 2  2 5
+--R                      - A a b  + (- 31A C + 2A B )a b
+--R                    + 
+--R                             3 2      2 2         4  3 4
+--R                      (- 131A C  + 39A B C + 12A B )a b
+--R                    + 
+--R                            2 3         2 2      4   4 3         4      2 3  5 2
+--R                      (- 62A C  + 117A B C  - 60B C)a b  + (66A C  + 42B C )a b
+--R                    + 
+--R                         5 6
+--R                      12C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4     7       3 2     2 2        4  2 6
+--R                      4A C a b  + (50A C  - 6A B C - 7A B )a b
+--R                    + 
+--R                          2 3        2 2      4   3 5           4      2 3  4 4
+--R                      (89A C  - 48A B C  + 24B C)a b  + (- 36A C  - 51B C )a b
+--R                    + 
+--R                           5 5 3
+--R                      - 43C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3 2      4    8         2 3       2 2     4   2 7
+--R                      (- 6A C  + A B )a b  + (- 34A C  + 6A B C  - 3B C)a b
+--R                    + 
+--R                             4      2 3  3 6      5 4 5
+--R                      (- 7A C  + 18B C )a b  + 34C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                     2 3   9        4     2 3  2 8      5 3 7  3
+--R                  (4A C a b  + (7A C  - 2B C )a b  - 10C a b )c
+--R                + 
+--R                        4   10    5 2 9  2
+--R                  (- A C a b   + C a b )c
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4 8
+--R                  4A a c
+--R                + 
+--R                          6 3 2         5       4 2  4
+--R                      - 9A a b  + (- 36A C + 24A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  5
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        6 2 4       5       4 2  3 3
+--R                      6A a b  + (65A C - 32A B )a b
+--R                    + 
+--R                           4 2       3 2       2 4  4 2
+--R                      (121A C  - 120A B C + 32A B )a b
+--R                    + 
+--R                         3 3      2 2 2        4   5
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  6
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         6   6         5       4 2  2 5
+--R                      - A a b  + (- 34A C + 14A B )a b
+--R                    + 
+--R                             4 2       3 2       2 4  3 4
+--R                      (- 170A C  + 120A B C - 24A B )a b
+--R                    + 
+--R                             3 3       2 2 2        4   4 3
+--R                      (- 162A C  + 144A B C  - 32A B C)a b
+--R                    + 
+--R                          2 4        2 3      4 2  5 2         5      2 4  6
+--R                      (41A C  - 56A B C  + 32B C )a b  + (28A C  - 40B C )a b
+--R                    + 
+--R                        6 7
+--R                      4C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         5      4 2    7       4 2      3 2      2 4  2 6
+--R                      (5A C - 2A B )a b  + (75A C  - 46A B C + 8A B )a b
+--R                    + 
+--R                           3 3       2 2 2        4   3 5
+--R                      (200A C  - 132A B C  + 24A B C)a b
+--R                    + 
+--R                          2 4       2 3      4 2  4 4           5      2 4  5 3
+--R                      (50A C  + 8A B C  - 24B C )a b  + (- 95A C  + 80B C )a b
+--R                    + 
+--R                           6 6 2
+--R                      - 25C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4    8
+--R                      (- 10A C  + 6A B C - A B )a b
+--R                    + 
+--R                            3 3      2 2 2       4   2 7
+--R                      (- 80A C  + 48A B C  - 8A B C)a b
+--R                    + 
+--R                            2 4        2 3     4 2  3 6         5      2 4  4 5
+--R                      (- 95A C  + 26A B C  + 8B C )a b  + (58A C  - 58B C )a b
+--R                    + 
+--R                         6 5 4
+--R                      50C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4     9
+--R                      (10A C  - 6A B C  + A B C)a b
+--R                    + 
+--R                          2 4        2 3    4 2  2 8         5      2 4  3 7
+--R                      (40A C  - 14A B C  - B C )a b  + (- A C  + 18B C )a b
+--R                    + 
+--R                           6 4 6
+--R                      - 35C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3    10          5     2 4  2 9      6 3 8
+--R                  ((- 5A C  + 2A B C )a b   + (- 6A C  - 2B C )a b  + 10C a b )c
+--R                + 
+--R                     5   11    6 2 10
+--R                  A C a b   - C a b
+--R             *
+--R                x
+--R            + 
+--R                   5   4          4        3 3  5  7
+--R              (- 4A B a b + (- 12A B C + 4A B )a )c
+--R            + 
+--R                    5   3 3       4        3 3  4 2
+--R                  2A B a b  + (21A B C - 5A B )a b
+--R                + 
+--R                    3   2     2 3        5  5          2   3       3 2     5   6
+--R                (28A B C  - 8A B C - 4A B )a b + (- 16A B C  - 4A B C  + 8B C)a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                       4       3 3  3 4         3   2     2 3        5  4 3
+--R                  (- 7A B C + A B )a b  + (- 33A B C  + 6A B C + 4A B )a b
+--R                + 
+--R                       2   3       3 2     5   5 2           4     3 3  6
+--R                  (- 8A B C  + 5A B C  - 8B C)a b  + (24A B C  + 8B C )a b
+--R                + 
+--R                        5 7
+--R                  - 4B C a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                     3   2    2 3       5  3 5       2   3      3 2     5   4 4
+--R                  (9A B C  - A B C - A B )a b  + (18A B C  - A B C  + 2B C)a b
+--R                + 
+--R                            4     3 3  5 3       5 6 2
+--R                  (- 13A B C  - 6B C )a b  - 5B C a b
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                   2   3 3 6           4    3 3  4 5       5 5 4  3
+--R              (- 5A B C a b  + (- A B C  + B C )a b  + 5B C a b )c
+--R            + 
+--R                    4 3 7      5 4 6  2
+--R              (A B C a b  - B C a b )c
+--R     + 
+--R                                   +--------------------+ +------------------+
+--R                 +-----------+     |   +-----------+      | +-----------+
+--R           2 +-+ |          2  +-+ |   |          2       | |          2
+--R         4c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         %%BI1
+--R      *
+--R         log
+--R                             3 3           2          2  4  11
+--R                      (- 128A a b + (- 256A C + 512A B )a )c
+--R                    + 
+--R                              3 2 3         2          2  3 2
+--R                          192A a b  + (1024A C - 768A B )a b
+--R                        + 
+--R                                  2       2   4        3 5
+--R                          (1152A C  - 512B C)a b + 256C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                               3   5          2          2  2 4
+--R                          - 72A a b  + (- 848A C + 416A B )a b
+--R                        + 
+--R                                    2       2   3 3        3 4 2
+--R                          (- 1984A C  + 768B C)a b  - 1024C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                            3 7        2         2    6
+--R                          8A b  + (248A C - 96A B )a b
+--R                        + 
+--R                                  2       2   2 5        3 3 4
+--R                          (1160A C  - 416B C)a b  + 1104C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                                2        2  8            2      2     7
+--R                          (- 24A C + 8A B )b  + (- 280A C  + 96B C)a b
+--R                        + 
+--R                                3 2 6
+--R                          - 504C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                             2     2   9       3   8  6     3 10 5
+--R                      ((24A C  - 8B C)b  + 104C a b )c  - 8C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                     3   4 10
+--R                  64A B a c
+--R                + 
+--R                           3   3 2         2           3  4
+--R                      - 64A B a b  + (- 64A B C + 64A B )a b
+--R                    + 
+--R                               2       3   5
+--R                      (192A B C  - 128B C)a
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                         3   2 4        2           3  3 3
+--R                      28A B a b  + (112A B C - 80A B )a b
+--R                    + 
+--R                                 2       3   4 2         3 5
+--R                      (- 192A B C  + 160B C)a b  - 192B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                          3     6         2           3  2 5
+--R                      - 4A B a b  + (- 56A B C + 32A B )a b
+--R                    + 
+--R                              2      3   3 4         3 4 3
+--R                      (20A B C  - 64B C)a b  + 208B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                      2          3    7           2     3   2 6        3 3 5  6
+--R                  ((8A B C - 4A B )a b  + (20A B C  + 8B C)a b  - 72B C a b )c
+--R                + 
+--R                           2   8       3 2 7  5
+--R                  (- 4A B C a b  + 8B C a b )c
+--R             *
+--R                     2
+--R                %%BI1
+--R            + 
+--R                             3 3           2          2  4  11
+--R                      (- 128A a b + (- 256A C + 512A B )a )c
+--R                    + 
+--R                              3 2 3         2          2  3 2
+--R                          192A a b  + (1024A C - 768A B )a b
+--R                        + 
+--R                                  2       2   4        3 5
+--R                          (1152A C  - 512B C)a b + 256C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                               3   5          2          2  2 4
+--R                          - 72A a b  + (- 848A C + 416A B )a b
+--R                        + 
+--R                                    2       2   3 3        3 4 2
+--R                          (- 1984A C  + 768B C)a b  - 1024C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                            3 7        2         2    6
+--R                          8A b  + (248A C - 96A B )a b
+--R                        + 
+--R                                  2       2   2 5        3 3 4
+--R                          (1160A C  - 416B C)a b  + 1104C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                                2        2  8            2      2     7
+--R                          (- 24A C + 8A B )b  + (- 280A C  + 96B C)a b
+--R                        + 
+--R                                3 2 6
+--R                          - 504C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                             2     2   9       3   8  6     3 10 5
+--R                      ((24A C  - 8B C)b  + 104C a b )c  - 8C b  c
+--R                 *
+--R                         2
+--R                    %%BI0
+--R                + 
+--R                             3   3 2          2            3  4   9
+--R                      (- 128A B a b  + (- 256A B C + 512A B )a b)c
+--R                    + 
+--R                              3   2 4         2            3  3 3
+--R                          192A B a b  + (1024A B C - 768A B )a b
+--R                        + 
+--R                                    2       3   4 2         3 5
+--R                          (1152A B C  - 512B C)a b  + 256B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                               3     6          2            3  2 5
+--R                          - 72A B a b  + (- 848A B C + 416A B )a b
+--R                        + 
+--R                                      2       3   3 4          3 4 3
+--R                          (- 1984A B C  + 768B C)a b  - 1024B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                            3   8        2           3    7
+--R                          8A B b  + (248A B C - 96A B )a b
+--R                        + 
+--R                                    2       3   2 6          3 3 5
+--R                          (1160A B C  - 416B C)a b  + 1104B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                2          3  9              2      3     8
+--R                          (- 24A B C + 8A B )b  + (- 280A B C  + 96B C)a b
+--R                        + 
+--R                                  3 2 7
+--R                          - 504B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                               2     3   10         3   9  4       3 11 3
+--R                      ((24A B C  - 8B C)b   + 104B C a b )c  - 8B C b  c
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                       5 4 9
+--R                  - 16A a c
+--R                + 
+--R                      5 3 2        4      3 2  4          2 2         4  5  8
+--R                  (28A a b  + (104A C - 8A B )a b + (- 48A B C + 32A B )a )c
+--R                + 
+--R                           5 2 4          4       3 2  3 3
+--R                      - 14A a b  + (- 146A C + 18A B )a b
+--R                    + 
+--R                             3 2       2 2        4  4 2
+--R                      (- 216A C  + 132A B C - 8A B )a b
+--R                    + 
+--R                          2 3         2 2      4   5          4      2 3  6
+--R                      (48A C  + 168A B C  - 96B C)a b + (16A C  - 16B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        5   6       4      3 2  2 5
+--R                      2A a b  + (62A C - 4A B )a b
+--R                    + 
+--R                           3 2      2 2         4  3 4
+--R                      (262A C  - 78A B C - 24A B )a b
+--R                    + 
+--R                           2 3         2 2       4   4 3
+--R                      (124A C  - 234A B C  + 120B C)a b
+--R                    + 
+--R                               4      2 3  5 2      5 6
+--R                      (- 132A C  - 84B C )a b  - 24C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                          4     7          3 2      2 2         4  2 6
+--R                      - 8A C a b  + (- 100A C  + 12A B C + 14A B )a b
+--R                    + 
+--R                             2 3        2 2      4   3 5
+--R                      (- 178A C  + 96A B C  - 48B C)a b
+--R                    + 
+--R                            4       2 3  4 4      5 5 3
+--R                      (72A C  + 102B C )a b  + 86C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          3 2       4    8       2 3        2 2     4   2 7
+--R                      (12A C  - 2A B )a b  + (68A C  - 12A B C  + 6B C)a b
+--R                    + 
+--R                            4      2 3  3 6      5 4 5
+--R                      (14A C  - 36B C )a b  - 68C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                       2 3   9           4     2 3  2 8      5 3 7  3
+--R                  (- 8A C a b  + (- 14A C  + 4B C )a b  + 20C a b )c
+--R                + 
+--R                       4   10     5 2 9  2
+--R                  (2A C a b   - 2C a b )c
+--R             *
+--R                %%BI1
+--R            + 
+--R                         3 3           2          2  4  11
+--R                  (- 128A a b + (- 256A C + 512A B )a )c
+--R                + 
+--R                          3 2 3         2          2  3 2
+--R                      192A a b  + (1024A C - 768A B )a b
+--R                    + 
+--R                              2       2   4        3 5
+--R                      (1152A C  - 512B C)a b + 256C a
+--R                 *
+--R                     10
+--R                    c
+--R                + 
+--R                           3   5          2          2  2 4
+--R                      - 72A a b  + (- 848A C + 416A B )a b
+--R                    + 
+--R                                2       2   3 3        3 4 2
+--R                      (- 1984A C  + 768B C)a b  - 1024C a b
+--R                 *
+--R                     9
+--R                    c
+--R                + 
+--R                        3 7        2         2    6           2       2   2 5
+--R                      8A b  + (248A C - 96A B )a b  + (1160A C  - 416B C)a b
+--R                    + 
+--R                           3 3 4
+--R                      1104C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                         2        2  8            2      2     7       3 2 6  7
+--R                  ((- 24A C + 8A B )b  + (- 280A C  + 96B C)a b  - 504C a b )c
+--R                + 
+--R                         2     2   9       3   8  6     3 10 5
+--R                  ((24A C  - 8B C)b  + 104C a b )c  - 8C b  c
+--R             *
+--R                     3
+--R                %%BI0
+--R            + 
+--R                         3   3 2          2            3  4   9
+--R                  (- 128A B a b  + (- 256A B C + 512A B )a b)c
+--R                + 
+--R                          3   2 4         2            3  3 3
+--R                      192A B a b  + (1024A B C - 768A B )a b
+--R                    + 
+--R                                2       3   4 2         3 5
+--R                      (1152A B C  - 512B C)a b  + 256B C a b
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                           3     6          2            3  2 5
+--R                      - 72A B a b  + (- 848A B C + 416A B )a b
+--R                    + 
+--R                                  2       3   3 4          3 4 3
+--R                      (- 1984A B C  + 768B C)a b  - 1024B C a b
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        3   8        2           3    7
+--R                      8A B b  + (248A B C - 96A B )a b
+--R                    + 
+--R                                2       3   2 6          3 3 5
+--R                      (1160A B C  - 416B C)a b  + 1104B C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                            2          3  9              2      3     8
+--R                      (- 24A B C + 8A B )b  + (- 280A B C  + 96B C)a b
+--R                    + 
+--R                              3 2 7
+--R                      - 504B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           2     3   10         3   9  4       3 11 3
+--R                  ((24A B C  - 8B C)b   + 104B C a b )c  - 8B C b  c
+--R             *
+--R                     2
+--R                %%BI0
+--R            + 
+--R                           5 3 2         4       3 2  4
+--R                      - 24A a b  + (- 80A C + 80A B )a b
+--R                    + 
+--R                            3 2      2 2         4  5
+--R                      (- 64A C  + 96A B C + 64A B )a
+--R                 *
+--R                     8
+--R                    c
+--R                + 
+--R                         5 2 4        4        3 2  3 3
+--R                      38A a b  + (300A C - 164A B )a b
+--R                    + 
+--R                           3 2       2 2         4  4 2
+--R                      (624A C  - 456A B C + 48A B )a b
+--R                    + 
+--R                           2 3         2 2      4   5          4      2 3  6
+--R                      (416A C  - 144A B C  - 64B C)a b + (64A C  + 32B C )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           5   6          4        3 2  2 5
+--R                      - 16A a b  + (- 278A C + 132A B )a b
+--R                    + 
+--R                              3 2       2 2          4  3 4
+--R                      (- 1144A C  + 780A B C - 160A B )a b
+--R                    + 
+--R                              2 3         2 2      4   4 3
+--R                      (- 1576A C  + 852A B C  - 48B C)a b
+--R                    + 
+--R                               4       2 3  5 2      5 6
+--R                      (- 728A C  + 104B C )a b  - 80C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        5 8       4       3 2    7
+--R                      2A b  + (92A C - 40A B )a b
+--R                    + 
+--R                           3 2       2 2          4  2 6
+--R                      (760A C  - 504A B C + 100A B )a b
+--R                    + 
+--R                            2 3          2 2       4   3 5
+--R                      (1904A C  - 1164A B C  + 160B C)a b
+--R                    + 
+--R                              4       2 3  4 4       5 5 3
+--R                      (1618A C  - 508B C )a b  + 380C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4      3 2  9          3 2       2 2         4    8
+--R                      (- 10A C + 4A B )b  + (- 208A C  + 132A B C - 24A B )a b
+--R                    + 
+--R                             2 3         2 2       4   2 7
+--R                      (- 992A C  + 624A B C  - 100B C)a b
+--R                    + 
+--R                                4       2 3  3 6       5 4 5
+--R                      (- 1456A C  + 552B C )a b  - 586C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                          3 2      2 2        4  10
+--R                      (20A C  - 12A B C + 2A B )b
+--R                    + 
+--R                           2 3         2 2      4     9
+--R                      (232A C  - 144A B C  + 24B C)a b
+--R                    + 
+--R                             4       2 3  2 8       5 3 7
+--R                      (626A C  - 252B C )a b  + 420C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            2 3        2 2     4   11
+--R                      (- 20A C  + 12A B C  - 2B C)b
+--R                    + 
+--R                               4      2 3    10       5 2 9
+--R                      (- 128A C  + 52B C )a b   - 154C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         4     2 3  12      5   11       5 13
+--R                  ((10A C  - 4B C )b   + 28C a b  )c - 2C b
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4 8
+--R                  4A a c
+--R                + 
+--R                          6 3 2         5       4 2  4
+--R                      - 9A a b  + (- 36A C + 24A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  5
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        6 2 4       5       4 2  3 3
+--R                      6A a b  + (65A C - 32A B )a b
+--R                    + 
+--R                           4 2       3 2       2 4  4 2
+--R                      (121A C  - 120A B C + 32A B )a b
+--R                    + 
+--R                         3 3      2 2 2        4   5
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  6
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         6   6         5       4 2  2 5
+--R                      - A a b  + (- 34A C + 14A B )a b
+--R                    + 
+--R                             4 2       3 2       2 4  3 4
+--R                      (- 170A C  + 120A B C - 24A B )a b
+--R                    + 
+--R                             3 3       2 2 2        4   4 3
+--R                      (- 162A C  + 144A B C  - 32A B C)a b
+--R                    + 
+--R                          2 4        2 3      4 2  5 2         5      2 4  6
+--R                      (41A C  - 56A B C  + 32B C )a b  + (28A C  - 40B C )a b
+--R                    + 
+--R                        6 7
+--R                      4C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         5      4 2    7       4 2      3 2      2 4  2 6
+--R                      (5A C - 2A B )a b  + (75A C  - 46A B C + 8A B )a b
+--R                    + 
+--R                           3 3       2 2 2        4   3 5
+--R                      (200A C  - 132A B C  + 24A B C)a b
+--R                    + 
+--R                          2 4       2 3      4 2  4 4           5      2 4  5 3
+--R                      (50A C  + 8A B C  - 24B C )a b  + (- 95A C  + 80B C )a b
+--R                    + 
+--R                           6 6 2
+--R                      - 25C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4    8
+--R                      (- 10A C  + 6A B C - A B )a b
+--R                    + 
+--R                            3 3      2 2 2       4   2 7
+--R                      (- 80A C  + 48A B C  - 8A B C)a b
+--R                    + 
+--R                            2 4        2 3     4 2  3 6         5      2 4  4 5
+--R                      (- 95A C  + 26A B C  + 8B C )a b  + (58A C  - 58B C )a b
+--R                    + 
+--R                         6 5 4
+--R                      50C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4     9
+--R                      (10A C  - 6A B C  + A B C)a b
+--R                    + 
+--R                          2 4        2 3    4 2  2 8         5      2 4  3 7
+--R                      (40A C  - 14A B C  - B C )a b  + (- A C  + 18B C )a b
+--R                    + 
+--R                           6 4 6
+--R                      - 35C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3    10          5     2 4  2 9      6 3 8
+--R                  ((- 5A C  + 2A B C )a b   + (- 6A C  - 2B C )a b  + 10C a b )c
+--R                + 
+--R                     5   11    6 2 10
+--R                  A C a b   - C a b
+--R             *
+--R                x
+--R            + 
+--R                 4         3 3  5 7
+--R              (4A B C + 12A B )a c
+--R            + 
+--R                    5   3 3       4         3 3  4 2
+--R                  3A B a b  + (17A B C - 19A B )a b
+--R                + 
+--R                      3   2      2 3         5  5
+--R                  (28A B C  - 48A B C + 20A B )a b
+--R                + 
+--R                      2   3        3 2     5   6
+--R                  (32A B C  - 12A B C  - 8B C)a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                     5   2 5         4         3 3  3 4
+--R                  - A B a b  + (- 22A B C + 12A B )a b
+--R                + 
+--R                        3   2      2 3         5  4 3
+--R                  (- 89A B C  + 84A B C - 24A B )a b
+--R                + 
+--R                         2   3        3 2     5   5 2             4      3 3  6
+--R                  (- 132A B C  + 99A B C  - 8B C)a b  + (- 76A B C  + 16B C )a b
+--R                + 
+--R                        5 7
+--R                  - 4B C a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                     4        3 3  2 6       3   2      2 3        5  3 5
+--R                  (5A B C - 2A B )a b  + (58A B C  - 42A B C + 9A B )a b
+--R                + 
+--R                       2   3         3 2      5   4 4            4      3 3  5 3
+--R                  (164A B C  - 120A B C  + 18B C)a b  + (162A B C  - 60B C )a b
+--R                + 
+--R                       5 6 2
+--R                  43B C a b
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                        3   2     2 3       5  2 7
+--R                  (- 10A B C  + 6A B C - A B )a b
+--R                + 
+--R                        2   3        3 2     5   3 6
+--R                  (- 72A B C  + 48A B C  - 8B C)a b
+--R                + 
+--R                             4      3 3  4 5        5 5 4
+--R                  (- 129A B C  + 54B C )a b  - 62B C a b
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                      2   3       3 2    5   2 8           4      3 3  3 7
+--R                  (10A B C  - 6A B C  + B C)a b  + (43A B C  - 18B C )a b
+--R                + 
+--R                       5 4 6
+--R                  37B C a b
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                        4     3 3  2 9        5 3 8        5 2 10
+--R              ((- 5A B C  + 2B C )a b  - 10B C a b )c + B C a b
+--R     + 
+--R                                    +-----------+
+--R                                 2  |          2          2
+--R           ((4A b + 4C a)c - 4C b )\|- 4a c + b   + 8A a c
+--R         + 
+--R                  2                   3
+--R           (- 4A b  - 12C a b)c + 4C b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                    +-----------+
+--R                                 2  |          2          2        2
+--R           ((4A b + 4C a)c - 4C b )\|- 4a c + b   - 8A a c  + (4A b  + 12C a b)c
+--R         + 
+--R                 3
+--R           - 4C b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                     +-----------+
+--R               2 +-+ |          2  +-+
+--R             4c \|2 \|- 4a c + b  \|c %%BI0
+--R          *
+--R             log
+--R                           3 3         2          2  4  11
+--R                      (128A a b + (256A C - 512A B )a )c
+--R                    + 
+--R                                3 2 3           2          2  3 2
+--R                          - 192A a b  + (- 1024A C + 768A B )a b
+--R                        + 
+--R                                    2       2   4        3 5
+--R                          (- 1152A C  + 512B C)a b - 256C a
+--R                     *
+--R                         10
+--R                        c
+--R                    + 
+--R                             3   5        2          2  2 4
+--R                          72A a b  + (848A C - 416A B )a b
+--R                        + 
+--R                                  2       2   3 3        3 4 2
+--R                          (1984A C  - 768B C)a b  + 1024C a b
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                              3 7          2         2    6
+--R                          - 8A b  + (- 248A C + 96A B )a b
+--R                        + 
+--R                                    2       2   2 5        3 3 4
+--R                          (- 1160A C  + 416B C)a b  - 1104C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                           2        2  8          2      2     7       3 2 6  7
+--R                      ((24A C - 8A B )b  + (280A C  - 96B C)a b  + 504C a b )c
+--R                    + 
+--R                               2     2   9       3   8  6     3 10 5
+--R                      ((- 24A C  + 8B C)b  - 104C a b )c  + 8C b  c
+--R                 *
+--R                         3
+--R                    %%BI0
+--R                + 
+--R                         3   4 10
+--R                      64A B a c
+--R                    + 
+--R                             3   3 2        2            3  4
+--R                          64A B a b  + (192A B C - 448A B )a b
+--R                        + 
+--R                                   2       3   5
+--R                          (192A B C  - 128B C)a
+--R                     *
+--R                         9
+--R                        c
+--R                    + 
+--R                                3   2 4          2            3  3 3
+--R                          - 164A B a b  + (- 912A B C + 688A B )a b
+--R                        + 
+--R                                      2       3   4 2         3 5
+--R                          (- 1344A B C  + 672B C)a b  - 448B C a b
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                             3     6        2            3  2 5
+--R                          68A B a b  + (792A B C - 384A B )a b
+--R                        + 
+--R                                    2       3   3 4          3 4 3
+--R                          (2004A B C  - 832B C)a b  + 1232B C a b
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              3   8          2           3    7
+--R                          - 8A B b  + (- 240A B C + 92A B )a b
+--R                        + 
+--R                                      2       3   2 6          3 3 5
+--R                          (- 1140A B C  + 424B C)a b  - 1176B C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              2          3  9            2      3     8
+--R                          (24A B C - 8A B )b  + (276A B C  - 96B C)a b
+--R                        + 
+--R                                3 2 7
+--R                          512B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                 2     3   10         3   9  4       3 11 3
+--R                      ((- 24A B C  + 8B C)b   - 104B C a b )c  + 8B C b  c
+--R                 *
+--R                         2
+--R                    %%BI0
+--R                + 
+--R                           5 4 9
+--R                      - 16A a c
+--R                    + 
+--R                             5 3 2        4       3 2  4
+--R                          52A a b  + (184A C - 88A B )a b
+--R                        + 
+--R                              3 2       2 2         4  5
+--R                          (64A C  - 144A B C - 32A B )a
+--R                     *
+--R                         8
+--R                        c
+--R                    + 
+--R                               5 2 4          4        3 2  3 3
+--R                          - 52A a b  + (- 446A C + 182A B )a b
+--R                        + 
+--R                                 3 2       2 2         4  4 2
+--R                          (- 840A C  + 588A B C - 56A B )a b
+--R                        + 
+--R                                 2 3         2 2      4   5
+--R                          (- 368A C  + 312A B C  - 32B C)a b
+--R                        + 
+--R                                  4      2 3  6
+--R                          (- 48A C  - 48B C )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                             5   6        4        3 2  2 5
+--R                          18A a b  + (340A C - 136A B )a b
+--R                        + 
+--R                                3 2       2 2          4  3 4
+--R                          (1406A C  - 858A B C + 136A B )a b
+--R                        + 
+--R                                2 3          2 2       4   4 3
+--R                          (1700A C  - 1086A B C  + 168B C)a b
+--R                        + 
+--R                                 4       2 3  5 2      5 6
+--R                          (596A C  - 188B C )a b  + 56C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              5 8          4       3 2    7
+--R                          - 2A b  + (- 100A C + 40A B )a b
+--R                        + 
+--R                                 3 2       2 2         4  2 6
+--R                          (- 860A C  + 516A B C - 86A B )a b
+--R                        + 
+--R                                  2 3          2 2       4   3 5
+--R                          (- 2082A C  + 1260A B C  - 208B C)a b
+--R                        + 
+--R                                    4       2 3  4 4       5 5 3
+--R                          (- 1546A C  + 610B C )a b  - 294C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                              4      3 2  9        3 2       2 2         4    8
+--R                          (10A C - 4A B )b  + (220A C  - 132A B C + 22A B )a b
+--R                        + 
+--R                                2 3         2 2       4   2 7
+--R                          (1060A C  - 636A B C  + 106B C)a b
+--R                        + 
+--R                                  4       2 3  3 6       5 4 5
+--R                          (1470A C  - 588B C )a b  + 518C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                3 2      2 2        4  10
+--R                          (- 20A C  + 12A B C - 2A B )b
+--R                        + 
+--R                                 2 3         2 2      4     9
+--R                          (- 240A C  + 144A B C  - 24B C)a b
+--R                        + 
+--R                                   4       2 3  2 8       5 3 7
+--R                          (- 640A C  + 256B C )a b  - 400C a b
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              2 3        2 2     4   11
+--R                          (20A C  - 12A B C  + 2B C)b
+--R                        + 
+--R                                 4      2 3    10       5 2 9
+--R                          (130A C  - 52B C )a b   + 152C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                               4     2 3  12      5   11       5 13
+--R                      ((- 10A C  + 4B C )b   - 28C a b  )c + 2C b
+--R                 *
+--R                    %%BI0
+--R                + 
+--R                        6 4 8
+--R                      4A a c
+--R                    + 
+--R                              6 3 2         5       4 2  4
+--R                          - 9A a b  + (- 36A C + 24A B )a b
+--R                        + 
+--R                               4 2      3 2       2 4  5
+--R                          (- 4A C  + 32A B C - 16A B )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                            6 2 4       5       4 2  3 3
+--R                          6A a b  + (65A C - 32A B )a b
+--R                        + 
+--R                               4 2       3 2       2 4  4 2
+--R                          (121A C  - 120A B C + 32A B )a b
+--R                        + 
+--R                             3 3      2 2 2        4   5
+--R                          (8A C  - 48A B C  + 16A B C)a b
+--R                        + 
+--R                               2 4        2 3      4 2  6
+--R                          (- 4A C  + 32A B C  - 16B C )a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                             6   6         5       4 2  2 5
+--R                          - A a b  + (- 34A C + 14A B )a b
+--R                        + 
+--R                                 4 2       3 2       2 4  3 4
+--R                          (- 170A C  + 120A B C - 24A B )a b
+--R                        + 
+--R                                 3 3       2 2 2        4   4 3
+--R                          (- 162A C  + 144A B C  - 32A B C)a b
+--R                        + 
+--R                              2 4        2 3      4 2  5 2
+--R                          (41A C  - 56A B C  + 32B C )a b
+--R                        + 
+--R                                5      2 4  6      6 7
+--R                          (28A C  - 40B C )a b + 4C a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                             5      4 2    7       4 2      3 2      2 4  2 6
+--R                          (5A C - 2A B )a b  + (75A C  - 46A B C + 8A B )a b
+--R                        + 
+--R                               3 3       2 2 2        4   3 5
+--R                          (200A C  - 132A B C  + 24A B C)a b
+--R                        + 
+--R                              2 4       2 3      4 2  4 4
+--R                          (50A C  + 8A B C  - 24B C )a b
+--R                        + 
+--R                                  5      2 4  5 3      6 6 2
+--R                          (- 95A C  + 80B C )a b  - 25C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                4 2     3 2     2 4    8
+--R                          (- 10A C  + 6A B C - A B )a b
+--R                        + 
+--R                                3 3      2 2 2       4   2 7
+--R                          (- 80A C  + 48A B C  - 8A B C)a b
+--R                        + 
+--R                                2 4        2 3     4 2  3 6
+--R                          (- 95A C  + 26A B C  + 8B C )a b
+--R                        + 
+--R                                5      2 4  4 5      6 5 4
+--R                          (58A C  - 58B C )a b  + 50C a b
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3 3     2 2 2      4     9
+--R                          (10A C  - 6A B C  + A B C)a b
+--R                        + 
+--R                              2 4        2 3    4 2  2 8         5      2 4  3 7
+--R                          (40A C  - 14A B C  - B C )a b  + (- A C  + 18B C )a b
+--R                        + 
+--R                               6 4 6
+--R                          - 35C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                               2 4       2 3    10          5     2 4  2 9
+--R                          (- 5A C  + 2A B C )a b   + (- 6A C  - 2B C )a b
+--R                        + 
+--R                             6 3 8
+--R                          10C a b
+--R                     *
+--R                        c
+--R                    + 
+--R                         5   11    6 2 10
+--R                      A C a b   - C a b
+--R                 *
+--R                    x
+--R                + 
+--R                     5   4        4         3 3  5  7
+--R                  (8A B a b + (20A B C - 20A B )a )c
+--R                + 
+--R                          5   3 3         4         3 3  4 2
+--R                      - 7A B a b  + (- 59A B C + 29A B )a b
+--R                    + 
+--R                            3   2      2 3         5  5          3 2     5   6
+--R                      (- 84A B C  + 64A B C - 12A B )a b + (20A B C  - 8B C)a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       5   2 5       4         3 3  3 4
+--R                      A B a b  + (36A B C - 14A B )a b
+--R                    + 
+--R                           3   2      2 3         5  4 3
+--R                      (155A B C  - 96A B C + 16A B )a b
+--R                    + 
+--R                           2   3         3 2      5   5 2
+--R                      (148A B C  - 109A B C  + 24B C)a b
+--R                    + 
+--R                              4      3 3  6         5 7
+--R                      (28A B C  - 32B C )a b + 12B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4        3 3  2 6
+--R                      (- 5A B C + 2A B )a b
+--R                    + 
+--R                            3   2      2 3        5  3 5
+--R                      (- 76A B C  + 44A B C - 7A B )a b
+--R                    + 
+--R                             2   3         3 2      5   4 4
+--R                      (- 200A B C  + 122A B C  - 22B C)a b
+--R                    + 
+--R                                 4      3 3  5 3        5 6 2
+--R                      (- 136A B C  + 72B C )a b  - 33B C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                          3   2     2 3       5  2 7
+--R                      (10A B C  - 6A B C + A B )a b
+--R                    + 
+--R                          2   3        3 2     5   3 6
+--R                      (82A B C  - 48A B C  + 8B C)a b
+--R                    + 
+--R                               4      3 3  4 5        5 5 4
+--R                      (131A B C  - 56B C )a b  + 52B C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            2   3       3 2    5   2 8
+--R                      (- 10A B C  + 6A B C  - B C)a b
+--R                    + 
+--R                                4      3 3  3 7        5 4 6
+--R                      (- 45A B C  + 18B C )a b  - 35B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          4     3 3  2 9        5 3 8        5 2 10
+--R                  ((5A B C  - 2B C )a b  + 10B C a b )c - B C a b
+--R         + 
+--R                                                  2
+--R                           2  +-+ +-+         2c x  + b
+--R           (- 4B a c + 2B b )\|2 \|c atanh(--------------)
+--R                                            +-----------+
+--R                                            |          2
+--R                                           \|- 4a c + b
+--R         + 
+--R                                       +-----------+
+--R               +-+       4      2      |          2  +-+
+--R           B b\|2 log(c x  + b x  + a)\|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     4c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 478
+
+)clear all
+
+--S 479 of 1070
+t0:=x^3*(A+B*x+C*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           5      4      3
+--R        C x  + B x  + A x
+--R   (1)  ------------------
+--R             4      2
+--R          c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 479
+
+--S 480 of 1070
+r0:=B*x/c+1/2*C*x^2/c+1/4*(A*c-b*C)*log(a+b*x^2+c*x^4)/c^2+1/2*(A*b*c-_
+   b^2*C+2*a*c*C)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-_
+   4*a*c))-B*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+_
+   (-b^2+2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-B*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                     +------------------+
+--R                   +-----------+                     | +-----------+
+--R                   |          2          2       2   | |          2
+--R         (- 4B b c\|- 4a c + b   - 8B a c  + 4B b c)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                   +-----------+                     |   +-----------+
+--R                   |          2          2       2   |   |          2
+--R         (- 4B b c\|- 4a c + b   + 8B a c  - 4B b c)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                                        2
+--R                                 2  +-+ +-+         2c x  + b
+--R           ((2A b + 4C a)c - 2C b )\|2 \|c atanh(--------------)
+--R                                                  +-----------+
+--R                                                  |          2
+--R                                                 \|- 4a c + b
+--R         + 
+--R                          +-+       4      2               2           +-+
+--R             ((A c - C b)\|2 log(c x  + b x  + a) + (2C c x  + 4B c x)\|2 )
+--R          *
+--R              +-----------+
+--R              |          2  +-+
+--R             \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     4c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 480
+
+--S 481 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                 2
+--R                c
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ1
+--R                     + 
+--R                                  4     2 3               3
+--R                           (- 8a c  + 2b c )%%BJ0 + 8A a c
+--R                         + 
+--R                                  2           2       3
+--R                           (- 2A b  - 8C a b)c  + 2C b c
+--R                      *
+--R                         %%BJ1
+--R                     + 
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ0
+--R                     + 
+--R                              3          2           2       3            2   2
+--R                       (8A a c  + (- 2A b  - 8C a b)c  + 2C b c)%%BJ0 - 2A a c
+--R                     + 
+--R                                  2         2 2      2 3
+--R                       ((2A C - 3B )a b - 2C a )c + B b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R         + 
+--R              2         2
+--R           - c %%BJ1 - c %%BJ0 + A c - C b
+--R      *
+--R         log
+--R                              2 2 2                2  3        2 4  8
+--R                          (64A a b  + (256A C - 64B )a b + 256C a )c
+--R                        + 
+--R                                2   4                  2  2 3       2 3 2  7
+--R                          (- 32A a b  + (- 256A C + 96B )a b  - 384C a b )c
+--R                        + 
+--R                             2 6               2    5       2 2 4  6
+--R                          (4A b  + (80A C - 36B )a b  + 208C a b )c
+--R                        + 
+--R                                       2  7      2   6  5     2 8 4
+--R                          ((- 8A C + 4B )b  - 48C a b )c  + 4C b c
+--R                     *
+--R                        %%BJ0
+--R                    + 
+--R                               3 2 2         2         2  3
+--R                          - 16A a b  + (- 64A C + 32A B )a b
+--R                        + 
+--R                                  2      2   4
+--R                          (- 64A C  + 32B C)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                            3   4       2         2  2 3          2      2   3 2
+--R                          4A a b  + (56A C - 24A B )a b  + (112A C  - 32B C)a b
+--R                        + 
+--R                             3 4
+--R                          32C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                2        2    5           2      2   2 4
+--R                          (- 10A C + 4A B )a b  + (- 56A C  + 14B C)a b
+--R                        + 
+--R                               3 3 3
+--R                          - 40C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                            2     2     6      3 2 5  4     3   7 3
+--R                      ((8A C  - 2B C)a b  + 16C a b )c  - 2C a b c
+--R                 *
+--R                    %%BJ1
+--R                + 
+--R                               3 2 2         2         2  3
+--R                          - 16A a b  + (- 64A C + 32A B )a b
+--R                        + 
+--R                                  2      2   4
+--R                          (- 64A C  + 32B C)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                            3   4       2         2  2 3          2      2   3 2
+--R                          4A a b  + (56A C - 24A B )a b  + (112A C  - 32B C)a b
+--R                        + 
+--R                             3 4
+--R                          32C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                2        2    5           2      2   2 4
+--R                          (- 10A C + 4A B )a b  + (- 56A C  + 14B C)a b
+--R                        + 
+--R                               3 3 3
+--R                          - 40C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                            2     2     6      3 2 5  4     3   7 3
+--R                      ((8A C  - 2B C)a b  + 16C a b )c  - 2C a b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                     4 2 2       3       2 2  3        2 2        2      4  4  6
+--R                  (4A a b  + (16A C - 12A B )a b + (16A C  - 16A B C + 8B )a )c
+--R                + 
+--R                         4   4         3       2 2  2 3
+--R                      - A a b  + (- 20A C + 11A B )a b
+--R                    + 
+--R                            2 2        2       4  3 2           3      2 2  4
+--R                      (- 56A C  + 44A B C - 14B )a b  + (- 48A C  + 36B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         3      2 2    5       2 2        2      4  2 4
+--R                      (4A C - 2A B )a b  + (37A C  - 26A B C + 7B )a b
+--R                    + 
+--R                            3      2 2  3 3      4 4 2
+--R                      (68A C  - 41B C )a b  + 36C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           2 2       2     4    6           3      2 2  2 5
+--R                      (- 6A C  + 4A B C - B )a b  + (- 30A C  + 16B C )a b
+--R                    + 
+--R                           4 3 4
+--R                      - 28C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3     2 2    7     4 2 6  2    4   8
+--R                  ((4A C  - 2B C )a b  + 9C a b )c  - C a b c
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ1
+--R                     + 
+--R                                  4     2 3               3
+--R                           (- 8a c  + 2b c )%%BJ0 + 8A a c
+--R                         + 
+--R                                  2           2       3
+--R                           (- 2A b  - 8C a b)c  + 2C b c
+--R                      *
+--R                         %%BJ1
+--R                     + 
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ0
+--R                     + 
+--R                              3          2           2       3            2   2
+--R                       (8A a c  + (- 2A b  - 8C a b)c  + 2C b c)%%BJ0 - 2A a c
+--R                     + 
+--R                                  2         2 2      2 3
+--R                       ((2A C - 3B )a b - 2C a )c + B b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R            + 
+--R                            2 2 2                  2  3        2 4  8
+--R                      (- 64A a b  + (- 256A C + 64B )a b - 256C a )c
+--R                    + 
+--R                          2   4                2  2 3       2 3 2  7
+--R                      (32A a b  + (256A C - 96B )a b  + 384C a b )c
+--R                    + 
+--R                           2 6                 2    5       2 2 4  6
+--R                      (- 4A b  + (- 80A C + 36B )a b  - 208C a b )c
+--R                    + 
+--R                                 2  7      2   6  5     2 8 4
+--R                      ((8A C - 4B )b  + 48C a b )c  - 4C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                      3 2 2       2         2  3          2      2   4  7
+--R                  (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                + 
+--R                          3   4         2         2  2 3
+--R                      - 4A a b  + (- 56A C + 24A B )a b
+--R                    + 
+--R                               2      2   3 2      3 4
+--R                      (- 112A C  + 32B C)a b  - 32C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       2        2    5         2      2   2 4      3 3 3  5
+--R                  ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                + 
+--R                          2     2     6      3 2 5  4     3   7 3
+--R                  ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R             *
+--R                     2
+--R                %%BJ1
+--R            + 
+--R                            2 2 2                  2  3        2 4  8
+--R                      (- 64A a b  + (- 256A C + 64B )a b - 256C a )c
+--R                    + 
+--R                          2   4                2  2 3       2 3 2  7
+--R                      (32A a b  + (256A C - 96B )a b  + 384C a b )c
+--R                    + 
+--R                           2 6                 2    5       2 2 4  6
+--R                      (- 4A b  + (- 80A C + 36B )a b  - 208C a b )c
+--R                    + 
+--R                                 2  7      2   6  5     2 8 4
+--R                      ((8A C - 4B )b  + 48C a b )c  - 4C b c
+--R                 *
+--R                         2
+--R                    %%BJ0
+--R                + 
+--R                          3 2 2        2         2  3          2 4  7
+--R                      (64A a b  + (256A C - 64A B )a b + 256A C a )c
+--R                    + 
+--R                               3   4          2         2  2 3
+--R                          - 32A a b  + (- 320A C + 96A B )a b
+--R                        + 
+--R                                   2      2   3 2       3 4
+--R                          (- 640A C  + 64B C)a b  - 256C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3 6        2         2    5          2      2   2 4
+--R                          4A b  + (112A C - 36A B )a b  + (464A C  - 96B C)a b
+--R                        + 
+--R                              3 3 3
+--R                          384C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                2        2  7            2      2     6
+--R                          (- 12A C + 4A B )b  + (- 128A C  + 36B C)a b
+--R                        + 
+--R                                3 2 5
+--R                          - 208C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             2     2   8      3   7  3     3 9 2
+--R                      ((12A C  - 4B C)b  + 48C a b )c  - 4C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                           4 2 2         3       2 2  3
+--R                      - 12A a b  + (- 48A C + 20A B )a b
+--R                    + 
+--R                            2 2        2      4  4
+--R                      (- 48A C  + 16A B C + 8B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4   4       3       2 2  2 3
+--R                      3A a b  + (52A C - 13A B )a b
+--R                    + 
+--R                           2 2        2       4  3 2         3     2 2  4
+--R                      (120A C  - 20A B C - 14B )a b  + (48A C  + 4B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            3      2 2    5         2 2        2      4  2 4
+--R                      (- 10A C + 2A B )a b  + (- 75A C  + 12A B C + 7B )a b
+--R                    + 
+--R                              3     2 2  3 3     4 4 2
+--R                      (- 84A C  - 9B C )a b  + 4C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            2 2       2     4    6         3     2 2  2 5
+--R                        (12A C  - 2A B C - B )a b  + (42A C  + 2B C )a b
+--R                      + 
+--R                           4 3 4
+--R                        12C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   7     4 2 6  2    4   8
+--R                  (- 6A C a b  - 7C a b )c  + C a b c
+--R             *
+--R                %%BJ1
+--R            + 
+--R                      3 2 2       2         2  3          2      2   4  7
+--R                  (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                + 
+--R                          3   4         2         2  2 3
+--R                      - 4A a b  + (- 56A C + 24A B )a b
+--R                    + 
+--R                               2      2   3 2      3 4
+--R                      (- 112A C  + 32B C)a b  - 32C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       2        2    5         2      2   2 4      3 3 3  5
+--R                  ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                + 
+--R                          2     2     6      3 2 5  4     3   7 3
+--R                  ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R             *
+--R                     2
+--R                %%BJ0
+--R            + 
+--R                           4 2 2         3       2 2  3
+--R                      - 12A a b  + (- 48A C + 20A B )a b
+--R                    + 
+--R                            2 2        2      4  4
+--R                      (- 48A C  + 16A B C + 8B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4   4       3       2 2  2 3
+--R                      3A a b  + (52A C - 13A B )a b
+--R                    + 
+--R                           2 2        2       4  3 2         3     2 2  4
+--R                      (120A C  - 20A B C - 14B )a b  + (48A C  + 4B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            3      2 2    5         2 2        2      4  2 4
+--R                      (- 10A C + 2A B )a b  + (- 75A C  + 12A B C + 7B )a b
+--R                    + 
+--R                              3     2 2  3 3     4 4 2
+--R                      (- 84A C  - 9B C )a b  + 4C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            2 2       2     4    6         3     2 2  2 5
+--R                        (12A C  - 2A B C - B )a b  + (42A C  + 2B C )a b
+--R                      + 
+--R                           4 3 4
+--R                        12C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   7     4 2 6  2    4   8
+--R                  (- 6A C a b  - 7C a b )c  + C a b c
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    5 4 5
+--R                  4B a c
+--R                + 
+--R                         4     4        3        2 3  2 3
+--R                      - A B a b  + (- 8A B C + 6A B )a b
+--R                    + 
+--R                            2   2        3      5  3 2
+--R                      (- 24A B C  + 24A B C - 9B )a b
+--R                    + 
+--R                                3      3 2  4         4 5
+--R                      (- 32A B C  + 24B C )a b - 16B C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3        2 3    5       2   2        3      5  2 4
+--R                      (4A B C - 2A B )a b  + (24A B C  - 20A B C + 6B )a b
+--R                    + 
+--R                              3      3 2  3 3        4 4 2
+--R                      (48A B C  - 32B C )a b  + 32B C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           2   2       3     5    6             3      3 2  2 5
+--R                      (- 6A B C  + 4A B C - B )a b  + (- 24A B C  + 14B C )a b
+--R                    + 
+--R                             4 3 4
+--R                      - 24B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3     3 2    7       4 2 6        4   8
+--R                  ((4A B C  - 2B C )a b  + 8B C a b )c - B C a b
+--R             *
+--R                x
+--R            + 
+--R                 5 2 2      4      3 2  3       3 2     2 2        4  4  5
+--R              (2A a b  + (8A C - 4A B )a b + (8A C  - 4A B C - 4A B )a )c
+--R            + 
+--R                       4     3 2  2 3         3 2     2 2        4  3 2
+--R                  (- 7A C + A B )a b  + (- 18A C  + 5A B C + 3A B )a b
+--R                + 
+--R                       2 3       2 2     4   4         4     2 3  5
+--R                  (- 4A C  + 4A B C  - 4B C)a b + (8A C  + 4B C )a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                     3 2    2 2       4  2 4       2 3      2 2     4   3 3
+--R                  (9A C  - A B C - A B )a b  + (11A C  - A B C  + 2B C)a b
+--R                + 
+--R                         4     2 3  4 2     5 5
+--R                  (- 8A C  - 5B C )a b  - 4C a b
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                   2 3 2 5    2 3 3 4     5 4 3  2       4 2 6    5 3 5
+--R              (- 5A C a b  + B C a b  + 4C a b )c  + (A C a b  - C a b )c
+--R     + 
+--R              2
+--R             c
+--R          *
+--R             ROOT
+--R                            4     2 3      2
+--R                    (- 12a c  + 3b c )%%BJ1
+--R                  + 
+--R                               4     2 3               3          2           2
+--R                        (- 8a c  + 2b c )%%BJ0 + 8A a c  + (- 2A b  - 8C a b)c
+--R                      + 
+--R                            3
+--R                        2C b c
+--R                   *
+--R                      %%BJ1
+--R                  + 
+--R                            4     2 3      2
+--R                    (- 12a c  + 3b c )%%BJ0
+--R                  + 
+--R                           3          2           2       3            2   2
+--R                    (8A a c  + (- 2A b  - 8C a b)c  + 2C b c)%%BJ0 - 2A a c
+--R                  + 
+--R                               2         2 2      2 3
+--R                    ((2A C - 3B )a b - 2C a )c + B b
+--R               /
+--R                      4    2 3
+--R                  4a c  - b c
+--R         + 
+--R              2         2
+--R           - c %%BJ1 - c %%BJ0 + A c - C b
+--R      *
+--R         log
+--R                                2 2 2                  2  3        2 4  8
+--R                          (- 64A a b  + (- 256A C + 64B )a b - 256C a )c
+--R                        + 
+--R                              2   4                2  2 3       2 3 2  7
+--R                          (32A a b  + (256A C - 96B )a b  + 384C a b )c
+--R                        + 
+--R                               2 6                 2    5       2 2 4  6
+--R                          (- 4A b  + (- 80A C + 36B )a b  - 208C a b )c
+--R                        + 
+--R                                     2  7      2   6  5     2 8 4
+--R                          ((8A C - 4B )b  + 48C a b )c  - 4C b c
+--R                     *
+--R                        %%BJ0
+--R                    + 
+--R                          3 2 2       2         2  3          2      2   4  7
+--R                      (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                    + 
+--R                              3   4         2         2  2 3
+--R                          - 4A a b  + (- 56A C + 24A B )a b
+--R                        + 
+--R                                   2      2   3 2      3 4
+--R                          (- 112A C  + 32B C)a b  - 32C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                           2        2    5         2      2   2 4      3 3 3  5
+--R                      ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                    + 
+--R                              2     2     6      3 2 5  4     3   7 3
+--R                      ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R                 *
+--R                    %%BJ1
+--R                + 
+--R                          3 2 2       2         2  3          2      2   4  7
+--R                      (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                    + 
+--R                              3   4         2         2  2 3
+--R                          - 4A a b  + (- 56A C + 24A B )a b
+--R                        + 
+--R                                   2      2   3 2      3 4
+--R                          (- 112A C  + 32B C)a b  - 32C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                           2        2    5         2      2   2 4      3 3 3  5
+--R                      ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                    + 
+--R                              2     2     6      3 2 5  4     3   7 3
+--R                      ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                          4 2 2         3       2 2  3
+--R                      - 4A a b  + (- 16A C + 12A B )a b
+--R                    + 
+--R                            2 2        2      4  4
+--R                      (- 16A C  + 16A B C - 8B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       4   4       3       2 2  2 3
+--R                      A a b  + (20A C - 11A B )a b
+--R                    + 
+--R                          2 2        2       4  3 2         3      2 2  4
+--R                      (56A C  - 44A B C + 14B )a b  + (48A C  - 36B C )a b
+--R                    + 
+--R                         4 5
+--R                      16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3      2 2    5         2 2        2      4  2 4
+--R                      (- 4A C + 2A B )a b  + (- 37A C  + 26A B C - 7B )a b
+--R                    + 
+--R                              3      2 2  3 3      4 4 2
+--R                      (- 68A C  + 41B C )a b  - 36C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           2 2       2     4    6         3      2 2  2 5
+--R                        (6A C  - 4A B C + B )a b  + (30A C  - 16B C )a b
+--R                      + 
+--R                           4 3 4
+--R                        28C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3     2 2    7     4 2 6  2    4   8
+--R                  ((- 4A C  + 2B C )a b  - 9C a b )c  + C a b c
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ1
+--R                     + 
+--R                                  4     2 3               3
+--R                           (- 8a c  + 2b c )%%BJ0 + 8A a c
+--R                         + 
+--R                                  2           2       3
+--R                           (- 2A b  - 8C a b)c  + 2C b c
+--R                      *
+--R                         %%BJ1
+--R                     + 
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ0
+--R                     + 
+--R                              3          2           2       3            2   2
+--R                       (8A a c  + (- 2A b  - 8C a b)c  + 2C b c)%%BJ0 - 2A a c
+--R                     + 
+--R                                  2         2 2      2 3
+--R                       ((2A C - 3B )a b - 2C a )c + B b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R            + 
+--R                            2 2 2                  2  3        2 4  8
+--R                      (- 64A a b  + (- 256A C + 64B )a b - 256C a )c
+--R                    + 
+--R                          2   4                2  2 3       2 3 2  7
+--R                      (32A a b  + (256A C - 96B )a b  + 384C a b )c
+--R                    + 
+--R                           2 6                 2    5       2 2 4  6
+--R                      (- 4A b  + (- 80A C + 36B )a b  - 208C a b )c
+--R                    + 
+--R                                 2  7      2   6  5     2 8 4
+--R                      ((8A C - 4B )b  + 48C a b )c  - 4C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                      3 2 2       2         2  3          2      2   4  7
+--R                  (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                + 
+--R                          3   4         2         2  2 3
+--R                      - 4A a b  + (- 56A C + 24A B )a b
+--R                    + 
+--R                               2      2   3 2      3 4
+--R                      (- 112A C  + 32B C)a b  - 32C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       2        2    5         2      2   2 4      3 3 3  5
+--R                  ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                + 
+--R                          2     2     6      3 2 5  4     3   7 3
+--R                  ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R             *
+--R                     2
+--R                %%BJ1
+--R            + 
+--R                            2 2 2                  2  3        2 4  8
+--R                      (- 64A a b  + (- 256A C + 64B )a b - 256C a )c
+--R                    + 
+--R                          2   4                2  2 3       2 3 2  7
+--R                      (32A a b  + (256A C - 96B )a b  + 384C a b )c
+--R                    + 
+--R                           2 6                 2    5       2 2 4  6
+--R                      (- 4A b  + (- 80A C + 36B )a b  - 208C a b )c
+--R                    + 
+--R                                 2  7      2   6  5     2 8 4
+--R                      ((8A C - 4B )b  + 48C a b )c  - 4C b c
+--R                 *
+--R                         2
+--R                    %%BJ0
+--R                + 
+--R                          3 2 2        2         2  3          2 4  7
+--R                      (64A a b  + (256A C - 64A B )a b + 256A C a )c
+--R                    + 
+--R                               3   4          2         2  2 3
+--R                          - 32A a b  + (- 320A C + 96A B )a b
+--R                        + 
+--R                                   2      2   3 2       3 4
+--R                          (- 640A C  + 64B C)a b  - 256C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3 6        2         2    5          2      2   2 4
+--R                          4A b  + (112A C - 36A B )a b  + (464A C  - 96B C)a b
+--R                        + 
+--R                              3 3 3
+--R                          384C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                2        2  7            2      2     6
+--R                          (- 12A C + 4A B )b  + (- 128A C  + 36B C)a b
+--R                        + 
+--R                                3 2 5
+--R                          - 208C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             2     2   8      3   7  3     3 9 2
+--R                      ((12A C  - 4B C)b  + 48C a b )c  - 4C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                           4 2 2         3       2 2  3
+--R                      - 12A a b  + (- 48A C + 20A B )a b
+--R                    + 
+--R                            2 2        2      4  4
+--R                      (- 48A C  + 16A B C + 8B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4   4       3       2 2  2 3
+--R                      3A a b  + (52A C - 13A B )a b
+--R                    + 
+--R                           2 2        2       4  3 2         3     2 2  4
+--R                      (120A C  - 20A B C - 14B )a b  + (48A C  + 4B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            3      2 2    5         2 2        2      4  2 4
+--R                      (- 10A C + 2A B )a b  + (- 75A C  + 12A B C + 7B )a b
+--R                    + 
+--R                              3     2 2  3 3     4 4 2
+--R                      (- 84A C  - 9B C )a b  + 4C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            2 2       2     4    6         3     2 2  2 5
+--R                        (12A C  - 2A B C - B )a b  + (42A C  + 2B C )a b
+--R                      + 
+--R                           4 3 4
+--R                        12C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   7     4 2 6  2    4   8
+--R                  (- 6A C a b  - 7C a b )c  + C a b c
+--R             *
+--R                %%BJ1
+--R            + 
+--R                      3 2 2       2         2  3          2      2   4  7
+--R                  (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                + 
+--R                          3   4         2         2  2 3
+--R                      - 4A a b  + (- 56A C + 24A B )a b
+--R                    + 
+--R                               2      2   3 2      3 4
+--R                      (- 112A C  + 32B C)a b  - 32C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       2        2    5         2      2   2 4      3 3 3  5
+--R                  ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                + 
+--R                          2     2     6      3 2 5  4     3   7 3
+--R                  ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R             *
+--R                     2
+--R                %%BJ0
+--R            + 
+--R                           4 2 2         3       2 2  3
+--R                      - 12A a b  + (- 48A C + 20A B )a b
+--R                    + 
+--R                            2 2        2      4  4
+--R                      (- 48A C  + 16A B C + 8B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4   4       3       2 2  2 3
+--R                      3A a b  + (52A C - 13A B )a b
+--R                    + 
+--R                           2 2        2       4  3 2         3     2 2  4
+--R                      (120A C  - 20A B C - 14B )a b  + (48A C  + 4B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            3      2 2    5         2 2        2      4  2 4
+--R                      (- 10A C + 2A B )a b  + (- 75A C  + 12A B C + 7B )a b
+--R                    + 
+--R                              3     2 2  3 3     4 4 2
+--R                      (- 84A C  - 9B C )a b  + 4C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            2 2       2     4    6         3     2 2  2 5
+--R                        (12A C  - 2A B C - B )a b  + (42A C  + 2B C )a b
+--R                      + 
+--R                           4 3 4
+--R                        12C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   7     4 2 6  2    4   8
+--R                  (- 6A C a b  - 7C a b )c  + C a b c
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    5 4 5
+--R                  4B a c
+--R                + 
+--R                         4     4        3        2 3  2 3
+--R                      - A B a b  + (- 8A B C + 6A B )a b
+--R                    + 
+--R                            2   2        3      5  3 2
+--R                      (- 24A B C  + 24A B C - 9B )a b
+--R                    + 
+--R                                3      3 2  4         4 5
+--R                      (- 32A B C  + 24B C )a b - 16B C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3        2 3    5       2   2        3      5  2 4
+--R                      (4A B C - 2A B )a b  + (24A B C  - 20A B C + 6B )a b
+--R                    + 
+--R                              3      3 2  3 3        4 4 2
+--R                      (48A B C  - 32B C )a b  + 32B C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           2   2       3     5    6             3      3 2  2 5
+--R                      (- 6A B C  + 4A B C - B )a b  + (- 24A B C  + 14B C )a b
+--R                    + 
+--R                             4 3 4
+--R                      - 24B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3     3 2    7       4 2 6        4   8
+--R                  ((4A B C  - 2B C )a b  + 8B C a b )c - B C a b
+--R             *
+--R                x
+--R            + 
+--R                 5 2 2      4      3 2  3       3 2     2 2        4  4  5
+--R              (2A a b  + (8A C - 4A B )a b + (8A C  - 4A B C - 4A B )a )c
+--R            + 
+--R                       4     3 2  2 3         3 2     2 2        4  3 2
+--R                  (- 7A C + A B )a b  + (- 18A C  + 5A B C + 3A B )a b
+--R                + 
+--R                       2 3       2 2     4   4         4     2 3  5
+--R                  (- 4A C  + 4A B C  - 4B C)a b + (8A C  + 4B C )a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                     3 2    2 2       4  2 4       2 3      2 2     4   3 3
+--R                  (9A C  - A B C - A B )a b  + (11A C  - A B C  + 2B C)a b
+--R                + 
+--R                         4     2 3  4 2     5 5
+--R                  (- 8A C  - 5B C )a b  - 4C a b
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                   2 3 2 5    2 3 3 4     5 4 3  2       4 2 6    5 3 5
+--R              (- 5A C a b  + B C a b  + 4C a b )c  + (A C a b  - C a b )c
+--R     + 
+--R           2
+--R         2c %%BJ1
+--R      *
+--R         log
+--R                           2 2 2                 2  3        2 4  8
+--R                      (128A a b  + (512A C - 128B )a b + 512C a )c
+--R                    + 
+--R                            2   4                   2  2 3       2 3 2  7
+--R                      (- 64A a b  + (- 512A C + 192B )a b  - 768C a b )c
+--R                    + 
+--R                         2 6                2    5       2 2 4  6
+--R                      (8A b  + (160A C - 72B )a b  + 416C a b )c
+--R                    + 
+--R                                    2  7      2   6  5     2 8 4
+--R                      ((- 16A C + 8B )b  - 96C a b )c  + 8C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                             3 2 2          2         2  3
+--R                        - 32A a b  + (- 128A C + 64A B )a b
+--R                      + 
+--R                                 2      2   4
+--R                        (- 128A C  + 64B C)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        3   4        2         2  2 3          2      2   3 2
+--R                      8A a b  + (112A C - 48A B )a b  + (224A C  - 64B C)a b
+--R                    + 
+--R                         3 4
+--R                      64C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         2        2    5            2      2   2 4      3 3 3  5
+--R                  ((- 20A C + 8A B )a b  + (- 112A C  + 28B C)a b  - 80C a b )c
+--R                + 
+--R                         2     2     6      3 2 5  4     3   7 3
+--R                  ((16A C  - 4B C)a b  + 32C a b )c  - 4C a b c
+--R             *
+--R                     2
+--R                %%BJ1
+--R            + 
+--R                           2 2 2                 2  3        2 4  8
+--R                      (128A a b  + (512A C - 128B )a b + 512C a )c
+--R                    + 
+--R                            2   4                   2  2 3       2 3 2  7
+--R                      (- 64A a b  + (- 512A C + 192B )a b  - 768C a b )c
+--R                    + 
+--R                         2 6                2    5       2 2 4  6
+--R                      (8A b  + (160A C - 72B )a b  + 416C a b )c
+--R                    + 
+--R                                    2  7      2   6  5     2 8 4
+--R                      ((- 16A C + 8B )b  - 96C a b )c  + 8C b c
+--R                 *
+--R                         2
+--R                    %%BJ0
+--R                + 
+--R                             3 2 2          2          2  3          2 4  7
+--R                      (- 128A a b  + (- 512A C + 128A B )a b - 512A C a )c
+--R                    + 
+--R                             3   4        2          2  2 3
+--R                          64A a b  + (640A C - 192A B )a b
+--R                        + 
+--R                                  2       2   3 2       3 4
+--R                          (1280A C  - 128B C)a b  + 512C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              3 6          2         2    5
+--R                          - 8A b  + (- 224A C + 72A B )a b
+--R                        + 
+--R                                   2       2   2 4       3 3 3
+--R                          (- 928A C  + 192B C)a b  - 768C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                           2        2  7          2      2     6       3 2 5  4
+--R                      ((24A C - 8A B )b  + (256A C  - 72B C)a b  + 416C a b )c
+--R                    + 
+--R                               2     2   8      3   7  3     3 9 2
+--R                      ((- 24A C  + 8B C)b  - 96C a b )c  + 8C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                           4 2 2       3       2 2  3
+--R                        24A a b  + (96A C - 40A B )a b
+--R                      + 
+--R                            2 2        2       4  4
+--R                        (96A C  - 32A B C - 16B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                          4   4          3       2 2  2 3
+--R                      - 6A a b  + (- 104A C + 26A B )a b
+--R                    + 
+--R                             2 2        2       4  3 2           3     2 2  4
+--R                      (- 240A C  + 40A B C + 28B )a b  + (- 96A C  - 8B C )a b
+--R                    + 
+--R                         4 5
+--R                      32C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          3      2 2    5        2 2        2       4  2 4
+--R                      (20A C - 4A B )a b  + (150A C  - 24A B C - 14B )a b
+--R                    + 
+--R                             3      2 2  3 3     4 4 2
+--R                      (168A C  + 18B C )a b  - 8C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            2 2       2      4    6           3     2 2  2 5
+--R                      (- 24A C  + 4A B C + 2B )a b  + (- 84A C  - 4B C )a b
+--R                    + 
+--R                           4 3 4
+--R                      - 24C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3   7      4 2 6  2     4   8
+--R                  (12A C a b  + 14C a b )c  - 2C a b c
+--R             *
+--R                %%BJ1
+--R            + 
+--R                       2 2 2                 2  3        2 4  8
+--R                  (128A a b  + (512A C - 128B )a b + 512C a )c
+--R                + 
+--R                        2   4                   2  2 3       2 3 2  7
+--R                  (- 64A a b  + (- 512A C + 192B )a b  - 768C a b )c
+--R                + 
+--R                     2 6                2    5       2 2 4  6
+--R                  (8A b  + (160A C - 72B )a b  + 416C a b )c
+--R                + 
+--R                                2  7      2   6  5     2 8 4
+--R                  ((- 16A C + 8B )b  - 96C a b )c  + 8C b c
+--R             *
+--R                     3
+--R                %%BJ0
+--R            + 
+--R                         3 2 2          2          2  3          2 4  7
+--R                  (- 128A a b  + (- 512A C + 128A B )a b - 512A C a )c
+--R                + 
+--R                         3   4        2          2  2 3
+--R                      64A a b  + (640A C - 192A B )a b
+--R                    + 
+--R                              2       2   3 2       3 4
+--R                      (1280A C  - 128B C)a b  + 512C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                          3 6          2         2    5
+--R                      - 8A b  + (- 224A C + 72A B )a b
+--R                    + 
+--R                               2       2   2 4       3 3 3
+--R                      (- 928A C  + 192B C)a b  - 768C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                       2        2  7          2      2     6       3 2 5  4
+--R                  ((24A C - 8A B )b  + (256A C  - 72B C)a b  + 416C a b )c
+--R                + 
+--R                           2     2   8      3   7  3     3 9 2
+--R                  ((- 24A C  + 8B C)b  - 96C a b )c  + 8C b c
+--R             *
+--R                     2
+--R                %%BJ0
+--R            + 
+--R                      4 2 2        3       2 2  3        2 2 4  6
+--R                  (48A a b  + (192A C - 48A B )a b + 192A C a )c
+--R                + 
+--R                           4   4          3       2 2  2 3
+--R                      - 20A a b  + (- 256A C + 92A B )a b
+--R                    + 
+--R                             2 2         2       4  3 2
+--R                      (- 576A C  + 176A B C - 24B )a b
+--R                    + 
+--R                               3      2 2  4       4 5
+--R                      (- 256A C  + 80B C )a b + 64C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        4 6       3       2 2    5
+--R                      2A b  + (84A C - 36A B )a b
+--R                    + 
+--R                           2 2         2       4  2 4          3       2 2  3 3
+--R                      (468A C  - 220A B C + 38B )a b  + (544A C  - 164B C )a b
+--R                    + 
+--R                         4 4 2
+--R                      48C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           3      2 2  7          2 2        2       4    6
+--R                      (- 8A C + 4A B )b  + (- 132A C  + 76A B C - 16B )a b
+--R                    + 
+--R                               3       2 2  2 5       4 3 4
+--R                      (- 360A C  + 132B C )a b  - 160C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          2 2       2      4  8         3      2 2    7
+--R                      (12A C  - 8A B C + 2B )b  + (92A C  - 40B C )a b
+--R                    + 
+--R                          4 2 6
+--R                      100C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3     2 2  9      4   8       4 10
+--R                  ((- 8A C  + 4B C )b  - 24C a b )c + 2C b
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    5 4 5
+--R                  4B a c
+--R                + 
+--R                         4     4        3        2 3  2 3
+--R                      - A B a b  + (- 8A B C + 6A B )a b
+--R                    + 
+--R                            2   2        3      5  3 2
+--R                      (- 24A B C  + 24A B C - 9B )a b
+--R                    + 
+--R                                3      3 2  4         4 5
+--R                      (- 32A B C  + 24B C )a b - 16B C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3        2 3    5       2   2        3      5  2 4
+--R                      (4A B C - 2A B )a b  + (24A B C  - 20A B C + 6B )a b
+--R                    + 
+--R                              3      3 2  3 3        4 4 2
+--R                      (48A B C  - 32B C )a b  + 32B C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           2   2       3     5    6             3      3 2  2 5
+--R                      (- 6A B C  + 4A B C - B )a b  + (- 24A B C  + 14B C )a b
+--R                    + 
+--R                             4 3 4
+--R                      - 24B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3     3 2    7       4 2 6        4   8
+--R                  ((4A B C  - 2B C )a b  + 8B C a b )c - B C a b
+--R             *
+--R                x
+--R            + 
+--R                        5 2 2         4      3 2  3
+--R                    - 6A a b  + (- 24A C + 8A B )a b
+--R                  + 
+--R                          3 2     2 2        4  4
+--R                    (- 24A C  + 4A B C + 4A B )a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                   5   4       4       3 2  2 3       3 2      2 2       4  3 2
+--R                  A a b  + (27A C - 10A B )a b  + (66A C  - 25A B C + A B )a b
+--R                + 
+--R                     2 3 4            4      2 3  5
+--R                  20A C a b + (- 24A C  + 12B C )a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                       4      3 2    5         3 2      2 2        4  2 4
+--R                  (- 4A C + 2A B )a b  + (- 44A C  + 22A B C - 4A B )a b
+--R                + 
+--R                        2 3       2 2     4   3 3         4      2 3  4 2
+--R                  (- 51A C  + 8A B C  + 3B C)a b  + (28A C  - 19B C )a b
+--R                + 
+--R                     5 5
+--R                  20C a b
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                     3 2     2 2       4    6       2 3        2 2    4   2 5
+--R                  (6A C  - 4A B C + A B )a b  + (30A C  - 10A B C  - B C)a b
+--R                + 
+--R                     2 3 3 4      5 4 3
+--R                  12B C a b  - 24C a b
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                    2 3       2 2    7          4     2 3  2 6     5 3 5
+--R              ((- 4A C  + 2A B C )a b  + (- 6A C  - 2B C )a b  + 9C a b )c
+--R            + 
+--R                 4   8    5 2 7
+--R              A C a b  - C a b
+--R     + 
+--R           2
+--R         2c %%BJ0
+--R      *
+--R         log
+--R                         2 2 2                   2  3        2 4  8
+--R                  (- 128A a b  + (- 512A C + 128B )a b - 512C a )c
+--R                + 
+--R                      2   4                 2  2 3       2 3 2  7
+--R                  (64A a b  + (512A C - 192B )a b  + 768C a b )c
+--R                + 
+--R                       2 6                  2    5       2 2 4  6
+--R                  (- 8A b  + (- 160A C + 72B )a b  - 416C a b )c
+--R                + 
+--R                              2  7      2   6  5     2 8 4
+--R                  ((16A C - 8B )b  + 96C a b )c  - 8C b c
+--R             *
+--R                     3
+--R                %%BJ0
+--R            + 
+--R                      3 2 2        2         2  3           2      2   4  7
+--R                  (96A a b  + (384A C - 64A B )a b + (384A C  + 64B C)a )c
+--R                + 
+--R                           3   4          2          2  2 3
+--R                      - 56A a b  + (- 528A C + 144A B )a b
+--R                    + 
+--R                                2      2   3 2       3 4
+--R                      (- 1056A C  + 64B C)a b  - 448C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        3 6        2         2    5          2       2   2 4
+--R                      8A b  + (204A C - 64A B )a b  + (816A C  - 164B C)a b
+--R                    + 
+--R                          3 3 3
+--R                      688C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         2        2  7            2      2     6       3 2 5  4
+--R                  ((- 24A C + 8A B )b  + (- 240A C  + 68B C)a b  - 384C a b )c
+--R                + 
+--R                         2     2   8      3   7  3     3 9 2
+--R                  ((24A C  - 8B C)b  + 92C a b )c  - 8C b c
+--R             *
+--R                     2
+--R                %%BJ0
+--R            + 
+--R                           4 2 2         3      2 2  3
+--R                      - 24A a b  + (- 96A C + 8A B )a b
+--R                    + 
+--R                            2 2        2       4  4
+--R                      (- 96A C  - 32A B C - 16B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         4   4        3       2 2  2 3
+--R                      14A a b  + (152A C - 66A B )a b
+--R                    + 
+--R                           2 2         2       4  3 2          3      2 2  4
+--R                      (336A C  - 136A B C + 52B )a b  + (160A C  - 88B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 32C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4 6         3       2 2    5
+--R                      - 2A b  + (- 64A C + 32A B )a b
+--R                    + 
+--R                             2 2         2       4  2 4
+--R                      (- 318A C  + 196A B C - 52B )a b
+--R                    + 
+--R                               3       2 2  3 3      4 4 2
+--R                      (- 376A C  + 182B C )a b  - 56C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3      2 2  7        2 2        2       4    6
+--R                      (8A C - 4A B )b  + (108A C  - 72A B C + 18B )a b
+--R                    + 
+--R                             3       2 2  2 5       4 3 4
+--R                      (276A C  - 136B C )a b  + 136C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            2 2       2      4  8           3      2 2    7
+--R                      (- 12A C  + 8A B C - 2B )b  + (- 80A C  + 40B C )a b
+--R                    + 
+--R                           4 2 6
+--R                      - 86C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        3     2 2  9      4   8       4 10
+--R                  ((8A C  - 4B C )b  + 22C a b )c - 2C b
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    5 4 5
+--R                  4B a c
+--R                + 
+--R                         4     4        3        2 3  2 3
+--R                      - A B a b  + (- 8A B C + 6A B )a b
+--R                    + 
+--R                            2   2        3      5  3 2
+--R                      (- 24A B C  + 24A B C - 9B )a b
+--R                    + 
+--R                                3      3 2  4         4 5
+--R                      (- 32A B C  + 24B C )a b - 16B C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3        2 3    5       2   2        3      5  2 4
+--R                      (4A B C - 2A B )a b  + (24A B C  - 20A B C + 6B )a b
+--R                    + 
+--R                              3      3 2  3 3        4 4 2
+--R                      (48A B C  - 32B C )a b  + 32B C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           2   2       3     5    6             3      3 2  2 5
+--R                      (- 6A B C  + 4A B C - B )a b  + (- 24A B C  + 14B C )a b
+--R                    + 
+--R                             4 3 4
+--R                      - 24B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3     3 2    7       4 2 6        4   8
+--R                  ((4A B C  - 2B C )a b  + 8B C a b )c - B C a b
+--R             *
+--R                x
+--R            + 
+--R                 5 2 2     4   3       3 2     2 2        4  4  5
+--R              (2A a b  + 8A C a b + (8A C  + 4A B C + 4A B )a )c
+--R            + 
+--R                     5   4         4      3 2  2 3
+--R                  - A a b  + (- 13A C + 8A B )a b
+--R                + 
+--R                        3 2      2 2        4  3 2
+--R                  (- 30A C  + 15A B C - 7A B )a b
+--R                + 
+--R                        2 3       2 2     4   4         4      2 3  5
+--R                  (- 12A C  - 8A B C  + 8B C)a b + (8A C  - 20B C )a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                     4      3 2    5       3 2      2 2        4  2 4
+--R                  (4A C - 2A B )a b  + (26A C  - 20A B C + 6A B )a b
+--R                + 
+--R                      2 3       2 2     4   3 3           4      2 3  4 2
+--R                  (29A C  - 6A B C  - 7B C)a b  + (- 12A C  + 29B C )a b
+--R                + 
+--R                       5 5
+--R                  - 12C a b
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                       3 2     2 2       4    6
+--R                  (- 6A C  + 4A B C - A B )a b
+--R                + 
+--R                        2 3        2 2    4   2 5      2 3 3 4      5 4 3
+--R                  (- 20A C  + 10A B C  + B C)a b  - 14B C a b  + 16C a b
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                  2 3       2 2    7        4     2 3  2 6     5 3 5
+--R              ((4A C  - 2A B C )a b  + (4A C  + 2B C )a b  - 7C a b )c
+--R            + 
+--R                   4   8    5 2 7
+--R              - A C a b  + C a b
+--R     + 
+--R            2
+--R       C c x  + 2B c x
+--R  /
+--R       2
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 481
+
+--S 482 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                                          +--------------------+
+--R                        +-----------+     |   +-----------+
+--R                  2 +-+ |          2  +-+ |   |          2
+--R                2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ1
+--R                     + 
+--R                                  4     2 3               3
+--R                           (- 8a c  + 2b c )%%BJ0 + 8A a c
+--R                         + 
+--R                                  2           2       3
+--R                           (- 2A b  - 8C a b)c  + 2C b c
+--R                      *
+--R                         %%BJ1
+--R                     + 
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ0
+--R                     + 
+--R                              3          2           2       3            2   2
+--R                       (8A a c  + (- 2A b  - 8C a b)c  + 2C b c)%%BJ0 - 2A a c
+--R                     + 
+--R                                  2         2 2      2 3
+--R                       ((2A C - 3B )a b - 2C a )c + B b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R         + 
+--R           -
+--R                                          +--------------------+
+--R                        +-----------+     |   +-----------+
+--R                  2 +-+ |          2  +-+ |   |          2
+--R                2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b %%BJ1
+--R         + 
+--R                         +-----------+
+--R                   2 +-+ |          2  +-+
+--R               - 2c \|2 \|- 4a c + b  \|c %%BJ0
+--R             + 
+--R                                 +-----------+
+--R                             +-+ |          2  +-+
+--R               (2A c - 2C b)\|2 \|- 4a c + b  \|c
+--R          *
+--R              +--------------------+ +------------------+
+--R              |   +-----------+      | +-----------+
+--R              |   |          2       | |          2
+--R             \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              2 2 2                2  3        2 4  8
+--R                          (64A a b  + (256A C - 64B )a b + 256C a )c
+--R                        + 
+--R                                2   4                  2  2 3       2 3 2  7
+--R                          (- 32A a b  + (- 256A C + 96B )a b  - 384C a b )c
+--R                        + 
+--R                             2 6               2    5       2 2 4  6
+--R                          (4A b  + (80A C - 36B )a b  + 208C a b )c
+--R                        + 
+--R                                       2  7      2   6  5     2 8 4
+--R                          ((- 8A C + 4B )b  - 48C a b )c  + 4C b c
+--R                     *
+--R                        %%BJ0
+--R                    + 
+--R                               3 2 2         2         2  3
+--R                          - 16A a b  + (- 64A C + 32A B )a b
+--R                        + 
+--R                                  2      2   4
+--R                          (- 64A C  + 32B C)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                            3   4       2         2  2 3          2      2   3 2
+--R                          4A a b  + (56A C - 24A B )a b  + (112A C  - 32B C)a b
+--R                        + 
+--R                             3 4
+--R                          32C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                2        2    5           2      2   2 4
+--R                          (- 10A C + 4A B )a b  + (- 56A C  + 14B C)a b
+--R                        + 
+--R                               3 3 3
+--R                          - 40C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                            2     2     6      3 2 5  4     3   7 3
+--R                      ((8A C  - 2B C)a b  + 16C a b )c  - 2C a b c
+--R                 *
+--R                    %%BJ1
+--R                + 
+--R                               3 2 2         2         2  3
+--R                          - 16A a b  + (- 64A C + 32A B )a b
+--R                        + 
+--R                                  2      2   4
+--R                          (- 64A C  + 32B C)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                            3   4       2         2  2 3          2      2   3 2
+--R                          4A a b  + (56A C - 24A B )a b  + (112A C  - 32B C)a b
+--R                        + 
+--R                             3 4
+--R                          32C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                2        2    5           2      2   2 4
+--R                          (- 10A C + 4A B )a b  + (- 56A C  + 14B C)a b
+--R                        + 
+--R                               3 3 3
+--R                          - 40C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                            2     2     6      3 2 5  4     3   7 3
+--R                      ((8A C  - 2B C)a b  + 16C a b )c  - 2C a b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                     4 2 2       3       2 2  3        2 2        2      4  4  6
+--R                  (4A a b  + (16A C - 12A B )a b + (16A C  - 16A B C + 8B )a )c
+--R                + 
+--R                         4   4         3       2 2  2 3
+--R                      - A a b  + (- 20A C + 11A B )a b
+--R                    + 
+--R                            2 2        2       4  3 2           3      2 2  4
+--R                      (- 56A C  + 44A B C - 14B )a b  + (- 48A C  + 36B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         3      2 2    5       2 2        2      4  2 4
+--R                      (4A C - 2A B )a b  + (37A C  - 26A B C + 7B )a b
+--R                    + 
+--R                            3      2 2  3 3      4 4 2
+--R                      (68A C  - 41B C )a b  + 36C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           2 2       2     4    6           3      2 2  2 5
+--R                      (- 6A C  + 4A B C - B )a b  + (- 30A C  + 16B C )a b
+--R                    + 
+--R                           4 3 4
+--R                      - 28C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3     2 2    7     4 2 6  2    4   8
+--R                  ((4A C  - 2B C )a b  + 9C a b )c  - C a b c
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ1
+--R                     + 
+--R                                  4     2 3               3
+--R                           (- 8a c  + 2b c )%%BJ0 + 8A a c
+--R                         + 
+--R                                  2           2       3
+--R                           (- 2A b  - 8C a b)c  + 2C b c
+--R                      *
+--R                         %%BJ1
+--R                     + 
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ0
+--R                     + 
+--R                              3          2           2       3            2   2
+--R                       (8A a c  + (- 2A b  - 8C a b)c  + 2C b c)%%BJ0 - 2A a c
+--R                     + 
+--R                                  2         2 2      2 3
+--R                       ((2A C - 3B )a b - 2C a )c + B b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R            + 
+--R                            2 2 2                  2  3        2 4  8
+--R                      (- 64A a b  + (- 256A C + 64B )a b - 256C a )c
+--R                    + 
+--R                          2   4                2  2 3       2 3 2  7
+--R                      (32A a b  + (256A C - 96B )a b  + 384C a b )c
+--R                    + 
+--R                           2 6                 2    5       2 2 4  6
+--R                      (- 4A b  + (- 80A C + 36B )a b  - 208C a b )c
+--R                    + 
+--R                                 2  7      2   6  5     2 8 4
+--R                      ((8A C - 4B )b  + 48C a b )c  - 4C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                      3 2 2       2         2  3          2      2   4  7
+--R                  (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                + 
+--R                          3   4         2         2  2 3
+--R                      - 4A a b  + (- 56A C + 24A B )a b
+--R                    + 
+--R                               2      2   3 2      3 4
+--R                      (- 112A C  + 32B C)a b  - 32C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       2        2    5         2      2   2 4      3 3 3  5
+--R                  ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                + 
+--R                          2     2     6      3 2 5  4     3   7 3
+--R                  ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R             *
+--R                     2
+--R                %%BJ1
+--R            + 
+--R                            2 2 2                  2  3        2 4  8
+--R                      (- 64A a b  + (- 256A C + 64B )a b - 256C a )c
+--R                    + 
+--R                          2   4                2  2 3       2 3 2  7
+--R                      (32A a b  + (256A C - 96B )a b  + 384C a b )c
+--R                    + 
+--R                           2 6                 2    5       2 2 4  6
+--R                      (- 4A b  + (- 80A C + 36B )a b  - 208C a b )c
+--R                    + 
+--R                                 2  7      2   6  5     2 8 4
+--R                      ((8A C - 4B )b  + 48C a b )c  - 4C b c
+--R                 *
+--R                         2
+--R                    %%BJ0
+--R                + 
+--R                          3 2 2        2         2  3          2 4  7
+--R                      (64A a b  + (256A C - 64A B )a b + 256A C a )c
+--R                    + 
+--R                               3   4          2         2  2 3
+--R                          - 32A a b  + (- 320A C + 96A B )a b
+--R                        + 
+--R                                   2      2   3 2       3 4
+--R                          (- 640A C  + 64B C)a b  - 256C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3 6        2         2    5          2      2   2 4
+--R                          4A b  + (112A C - 36A B )a b  + (464A C  - 96B C)a b
+--R                        + 
+--R                              3 3 3
+--R                          384C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                2        2  7            2      2     6
+--R                          (- 12A C + 4A B )b  + (- 128A C  + 36B C)a b
+--R                        + 
+--R                                3 2 5
+--R                          - 208C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             2     2   8      3   7  3     3 9 2
+--R                      ((12A C  - 4B C)b  + 48C a b )c  - 4C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                           4 2 2         3       2 2  3
+--R                      - 12A a b  + (- 48A C + 20A B )a b
+--R                    + 
+--R                            2 2        2      4  4
+--R                      (- 48A C  + 16A B C + 8B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4   4       3       2 2  2 3
+--R                      3A a b  + (52A C - 13A B )a b
+--R                    + 
+--R                           2 2        2       4  3 2         3     2 2  4
+--R                      (120A C  - 20A B C - 14B )a b  + (48A C  + 4B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            3      2 2    5         2 2        2      4  2 4
+--R                      (- 10A C + 2A B )a b  + (- 75A C  + 12A B C + 7B )a b
+--R                    + 
+--R                              3     2 2  3 3     4 4 2
+--R                      (- 84A C  - 9B C )a b  + 4C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            2 2       2     4    6         3     2 2  2 5
+--R                        (12A C  - 2A B C - B )a b  + (42A C  + 2B C )a b
+--R                      + 
+--R                           4 3 4
+--R                        12C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   7     4 2 6  2    4   8
+--R                  (- 6A C a b  - 7C a b )c  + C a b c
+--R             *
+--R                %%BJ1
+--R            + 
+--R                      3 2 2       2         2  3          2      2   4  7
+--R                  (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                + 
+--R                          3   4         2         2  2 3
+--R                      - 4A a b  + (- 56A C + 24A B )a b
+--R                    + 
+--R                               2      2   3 2      3 4
+--R                      (- 112A C  + 32B C)a b  - 32C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       2        2    5         2      2   2 4      3 3 3  5
+--R                  ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                + 
+--R                          2     2     6      3 2 5  4     3   7 3
+--R                  ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R             *
+--R                     2
+--R                %%BJ0
+--R            + 
+--R                           4 2 2         3       2 2  3
+--R                      - 12A a b  + (- 48A C + 20A B )a b
+--R                    + 
+--R                            2 2        2      4  4
+--R                      (- 48A C  + 16A B C + 8B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4   4       3       2 2  2 3
+--R                      3A a b  + (52A C - 13A B )a b
+--R                    + 
+--R                           2 2        2       4  3 2         3     2 2  4
+--R                      (120A C  - 20A B C - 14B )a b  + (48A C  + 4B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            3      2 2    5         2 2        2      4  2 4
+--R                      (- 10A C + 2A B )a b  + (- 75A C  + 12A B C + 7B )a b
+--R                    + 
+--R                              3     2 2  3 3     4 4 2
+--R                      (- 84A C  - 9B C )a b  + 4C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            2 2       2     4    6         3     2 2  2 5
+--R                        (12A C  - 2A B C - B )a b  + (42A C  + 2B C )a b
+--R                      + 
+--R                           4 3 4
+--R                        12C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   7     4 2 6  2    4   8
+--R                  (- 6A C a b  - 7C a b )c  + C a b c
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    5 4 5
+--R                  4B a c
+--R                + 
+--R                         4     4        3        2 3  2 3
+--R                      - A B a b  + (- 8A B C + 6A B )a b
+--R                    + 
+--R                            2   2        3      5  3 2
+--R                      (- 24A B C  + 24A B C - 9B )a b
+--R                    + 
+--R                                3      3 2  4         4 5
+--R                      (- 32A B C  + 24B C )a b - 16B C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3        2 3    5       2   2        3      5  2 4
+--R                      (4A B C - 2A B )a b  + (24A B C  - 20A B C + 6B )a b
+--R                    + 
+--R                              3      3 2  3 3        4 4 2
+--R                      (48A B C  - 32B C )a b  + 32B C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           2   2       3     5    6             3      3 2  2 5
+--R                      (- 6A B C  + 4A B C - B )a b  + (- 24A B C  + 14B C )a b
+--R                    + 
+--R                             4 3 4
+--R                      - 24B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3     3 2    7       4 2 6        4   8
+--R                  ((4A B C  - 2B C )a b  + 8B C a b )c - B C a b
+--R             *
+--R                x
+--R            + 
+--R                 5 2 2      4      3 2  3       3 2     2 2        4  4  5
+--R              (2A a b  + (8A C - 4A B )a b + (8A C  - 4A B C - 4A B )a )c
+--R            + 
+--R                       4     3 2  2 3         3 2     2 2        4  3 2
+--R                  (- 7A C + A B )a b  + (- 18A C  + 5A B C + 3A B )a b
+--R                + 
+--R                       2 3       2 2     4   4         4     2 3  5
+--R                  (- 4A C  + 4A B C  - 4B C)a b + (8A C  + 4B C )a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                     3 2    2 2       4  2 4       2 3      2 2     4   3 3
+--R                  (9A C  - A B C - A B )a b  + (11A C  - A B C  + 2B C)a b
+--R                + 
+--R                         4     2 3  4 2     5 5
+--R                  (- 8A C  - 5B C )a b  - 4C a b
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                   2 3 2 5    2 3 3 4     5 4 3  2       4 2 6    5 3 5
+--R              (- 5A C a b  + B C a b  + 4C a b )c  + (A C a b  - C a b )c
+--R     + 
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R               2 +-+ |          2  +-+ |   |          2
+--R             2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R          *
+--R              +------------------+
+--R              | +-----------+
+--R              | |          2
+--R             \|\|- 4a c + b   + b
+--R          *
+--R             ROOT
+--R                            4     2 3      2
+--R                    (- 12a c  + 3b c )%%BJ1
+--R                  + 
+--R                               4     2 3               3          2           2
+--R                        (- 8a c  + 2b c )%%BJ0 + 8A a c  + (- 2A b  - 8C a b)c
+--R                      + 
+--R                            3
+--R                        2C b c
+--R                   *
+--R                      %%BJ1
+--R                  + 
+--R                            4     2 3      2
+--R                    (- 12a c  + 3b c )%%BJ0
+--R                  + 
+--R                           3          2           2       3            2   2
+--R                    (8A a c  + (- 2A b  - 8C a b)c  + 2C b c)%%BJ0 - 2A a c
+--R                  + 
+--R                               2         2 2      2 3
+--R                    ((2A C - 3B )a b - 2C a )c + B b
+--R               /
+--R                      4    2 3
+--R                  4a c  - b c
+--R         + 
+--R           -
+--R                                          +--------------------+
+--R                        +-----------+     |   +-----------+
+--R                  2 +-+ |          2  +-+ |   |          2
+--R                2c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b %%BJ1
+--R         + 
+--R                         +-----------+
+--R                   2 +-+ |          2  +-+
+--R               - 2c \|2 \|- 4a c + b  \|c %%BJ0
+--R             + 
+--R                                 +-----------+
+--R                             +-+ |          2  +-+
+--R               (2A c - 2C b)\|2 \|- 4a c + b  \|c
+--R          *
+--R              +--------------------+ +------------------+
+--R              |   +-----------+      | +-----------+
+--R              |   |          2       | |          2
+--R             \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                2 2 2                  2  3        2 4  8
+--R                          (- 64A a b  + (- 256A C + 64B )a b - 256C a )c
+--R                        + 
+--R                              2   4                2  2 3       2 3 2  7
+--R                          (32A a b  + (256A C - 96B )a b  + 384C a b )c
+--R                        + 
+--R                               2 6                 2    5       2 2 4  6
+--R                          (- 4A b  + (- 80A C + 36B )a b  - 208C a b )c
+--R                        + 
+--R                                     2  7      2   6  5     2 8 4
+--R                          ((8A C - 4B )b  + 48C a b )c  - 4C b c
+--R                     *
+--R                        %%BJ0
+--R                    + 
+--R                          3 2 2       2         2  3          2      2   4  7
+--R                      (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                    + 
+--R                              3   4         2         2  2 3
+--R                          - 4A a b  + (- 56A C + 24A B )a b
+--R                        + 
+--R                                   2      2   3 2      3 4
+--R                          (- 112A C  + 32B C)a b  - 32C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                           2        2    5         2      2   2 4      3 3 3  5
+--R                      ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                    + 
+--R                              2     2     6      3 2 5  4     3   7 3
+--R                      ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R                 *
+--R                    %%BJ1
+--R                + 
+--R                          3 2 2       2         2  3          2      2   4  7
+--R                      (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                    + 
+--R                              3   4         2         2  2 3
+--R                          - 4A a b  + (- 56A C + 24A B )a b
+--R                        + 
+--R                                   2      2   3 2      3 4
+--R                          (- 112A C  + 32B C)a b  - 32C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                           2        2    5         2      2   2 4      3 3 3  5
+--R                      ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                    + 
+--R                              2     2     6      3 2 5  4     3   7 3
+--R                      ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                          4 2 2         3       2 2  3
+--R                      - 4A a b  + (- 16A C + 12A B )a b
+--R                    + 
+--R                            2 2        2      4  4
+--R                      (- 16A C  + 16A B C - 8B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       4   4       3       2 2  2 3
+--R                      A a b  + (20A C - 11A B )a b
+--R                    + 
+--R                          2 2        2       4  3 2         3      2 2  4
+--R                      (56A C  - 44A B C + 14B )a b  + (48A C  - 36B C )a b
+--R                    + 
+--R                         4 5
+--R                      16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           3      2 2    5         2 2        2      4  2 4
+--R                      (- 4A C + 2A B )a b  + (- 37A C  + 26A B C - 7B )a b
+--R                    + 
+--R                              3      2 2  3 3      4 4 2
+--R                      (- 68A C  + 41B C )a b  - 36C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           2 2       2     4    6         3      2 2  2 5
+--R                        (6A C  - 4A B C + B )a b  + (30A C  - 16B C )a b
+--R                      + 
+--R                           4 3 4
+--R                        28C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3     2 2    7     4 2 6  2    4   8
+--R                  ((- 4A C  + 2B C )a b  - 9C a b )c  + C a b c
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ1
+--R                     + 
+--R                                  4     2 3               3
+--R                           (- 8a c  + 2b c )%%BJ0 + 8A a c
+--R                         + 
+--R                                  2           2       3
+--R                           (- 2A b  - 8C a b)c  + 2C b c
+--R                      *
+--R                         %%BJ1
+--R                     + 
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BJ0
+--R                     + 
+--R                              3          2           2       3            2   2
+--R                       (8A a c  + (- 2A b  - 8C a b)c  + 2C b c)%%BJ0 - 2A a c
+--R                     + 
+--R                                  2         2 2      2 3
+--R                       ((2A C - 3B )a b - 2C a )c + B b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R            + 
+--R                            2 2 2                  2  3        2 4  8
+--R                      (- 64A a b  + (- 256A C + 64B )a b - 256C a )c
+--R                    + 
+--R                          2   4                2  2 3       2 3 2  7
+--R                      (32A a b  + (256A C - 96B )a b  + 384C a b )c
+--R                    + 
+--R                           2 6                 2    5       2 2 4  6
+--R                      (- 4A b  + (- 80A C + 36B )a b  - 208C a b )c
+--R                    + 
+--R                                 2  7      2   6  5     2 8 4
+--R                      ((8A C - 4B )b  + 48C a b )c  - 4C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                      3 2 2       2         2  3          2      2   4  7
+--R                  (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                + 
+--R                          3   4         2         2  2 3
+--R                      - 4A a b  + (- 56A C + 24A B )a b
+--R                    + 
+--R                               2      2   3 2      3 4
+--R                      (- 112A C  + 32B C)a b  - 32C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       2        2    5         2      2   2 4      3 3 3  5
+--R                  ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                + 
+--R                          2     2     6      3 2 5  4     3   7 3
+--R                  ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R             *
+--R                     2
+--R                %%BJ1
+--R            + 
+--R                            2 2 2                  2  3        2 4  8
+--R                      (- 64A a b  + (- 256A C + 64B )a b - 256C a )c
+--R                    + 
+--R                          2   4                2  2 3       2 3 2  7
+--R                      (32A a b  + (256A C - 96B )a b  + 384C a b )c
+--R                    + 
+--R                           2 6                 2    5       2 2 4  6
+--R                      (- 4A b  + (- 80A C + 36B )a b  - 208C a b )c
+--R                    + 
+--R                                 2  7      2   6  5     2 8 4
+--R                      ((8A C - 4B )b  + 48C a b )c  - 4C b c
+--R                 *
+--R                         2
+--R                    %%BJ0
+--R                + 
+--R                          3 2 2        2         2  3          2 4  7
+--R                      (64A a b  + (256A C - 64A B )a b + 256A C a )c
+--R                    + 
+--R                               3   4          2         2  2 3
+--R                          - 32A a b  + (- 320A C + 96A B )a b
+--R                        + 
+--R                                   2      2   3 2       3 4
+--R                          (- 640A C  + 64B C)a b  - 256C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3 6        2         2    5          2      2   2 4
+--R                          4A b  + (112A C - 36A B )a b  + (464A C  - 96B C)a b
+--R                        + 
+--R                              3 3 3
+--R                          384C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                2        2  7            2      2     6
+--R                          (- 12A C + 4A B )b  + (- 128A C  + 36B C)a b
+--R                        + 
+--R                                3 2 5
+--R                          - 208C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             2     2   8      3   7  3     3 9 2
+--R                      ((12A C  - 4B C)b  + 48C a b )c  - 4C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                           4 2 2         3       2 2  3
+--R                      - 12A a b  + (- 48A C + 20A B )a b
+--R                    + 
+--R                            2 2        2      4  4
+--R                      (- 48A C  + 16A B C + 8B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4   4       3       2 2  2 3
+--R                      3A a b  + (52A C - 13A B )a b
+--R                    + 
+--R                           2 2        2       4  3 2         3     2 2  4
+--R                      (120A C  - 20A B C - 14B )a b  + (48A C  + 4B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            3      2 2    5         2 2        2      4  2 4
+--R                      (- 10A C + 2A B )a b  + (- 75A C  + 12A B C + 7B )a b
+--R                    + 
+--R                              3     2 2  3 3     4 4 2
+--R                      (- 84A C  - 9B C )a b  + 4C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            2 2       2     4    6         3     2 2  2 5
+--R                        (12A C  - 2A B C - B )a b  + (42A C  + 2B C )a b
+--R                      + 
+--R                           4 3 4
+--R                        12C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   7     4 2 6  2    4   8
+--R                  (- 6A C a b  - 7C a b )c  + C a b c
+--R             *
+--R                %%BJ1
+--R            + 
+--R                      3 2 2       2         2  3          2      2   4  7
+--R                  (16A a b  + (64A C - 32A B )a b + (64A C  - 32B C)a )c
+--R                + 
+--R                          3   4         2         2  2 3
+--R                      - 4A a b  + (- 56A C + 24A B )a b
+--R                    + 
+--R                               2      2   3 2      3 4
+--R                      (- 112A C  + 32B C)a b  - 32C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                       2        2    5         2      2   2 4      3 3 3  5
+--R                  ((10A C - 4A B )a b  + (56A C  - 14B C)a b  + 40C a b )c
+--R                + 
+--R                          2     2     6      3 2 5  4     3   7 3
+--R                  ((- 8A C  + 2B C)a b  - 16C a b )c  + 2C a b c
+--R             *
+--R                     2
+--R                %%BJ0
+--R            + 
+--R                           4 2 2         3       2 2  3
+--R                      - 12A a b  + (- 48A C + 20A B )a b
+--R                    + 
+--R                            2 2        2      4  4
+--R                      (- 48A C  + 16A B C + 8B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4   4       3       2 2  2 3
+--R                      3A a b  + (52A C - 13A B )a b
+--R                    + 
+--R                           2 2        2       4  3 2         3     2 2  4
+--R                      (120A C  - 20A B C - 14B )a b  + (48A C  + 4B C )a b
+--R                    + 
+--R                           4 5
+--R                      - 16C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            3      2 2    5         2 2        2      4  2 4
+--R                      (- 10A C + 2A B )a b  + (- 75A C  + 12A B C + 7B )a b
+--R                    + 
+--R                              3     2 2  3 3     4 4 2
+--R                      (- 84A C  - 9B C )a b  + 4C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            2 2       2     4    6         3     2 2  2 5
+--R                        (12A C  - 2A B C - B )a b  + (42A C  + 2B C )a b
+--R                      + 
+--R                           4 3 4
+--R                        12C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         3   7     4 2 6  2    4   8
+--R                  (- 6A C a b  - 7C a b )c  + C a b c
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    5 4 5
+--R                  4B a c
+--R                + 
+--R                         4     4        3        2 3  2 3
+--R                      - A B a b  + (- 8A B C + 6A B )a b
+--R                    + 
+--R                            2   2        3      5  3 2
+--R                      (- 24A B C  + 24A B C - 9B )a b
+--R                    + 
+--R                                3      3 2  4         4 5
+--R                      (- 32A B C  + 24B C )a b - 16B C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3        2 3    5       2   2        3      5  2 4
+--R                      (4A B C - 2A B )a b  + (24A B C  - 20A B C + 6B )a b
+--R                    + 
+--R                              3      3 2  3 3        4 4 2
+--R                      (48A B C  - 32B C )a b  + 32B C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           2   2       3     5    6             3      3 2  2 5
+--R                      (- 6A B C  + 4A B C - B )a b  + (- 24A B C  + 14B C )a b
+--R                    + 
+--R                             4 3 4
+--R                      - 24B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3     3 2    7       4 2 6        4   8
+--R                  ((4A B C  - 2B C )a b  + 8B C a b )c - B C a b
+--R             *
+--R                x
+--R            + 
+--R                 5 2 2      4      3 2  3       3 2     2 2        4  4  5
+--R              (2A a b  + (8A C - 4A B )a b + (8A C  - 4A B C - 4A B )a )c
+--R            + 
+--R                       4     3 2  2 3         3 2     2 2        4  3 2
+--R                  (- 7A C + A B )a b  + (- 18A C  + 5A B C + 3A B )a b
+--R                + 
+--R                       2 3       2 2     4   4         4     2 3  5
+--R                  (- 4A C  + 4A B C  - 4B C)a b + (8A C  + 4B C )a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                     3 2    2 2       4  2 4       2 3      2 2     4   3 3
+--R                  (9A C  - A B C - A B )a b  + (11A C  - A B C  + 2B C)a b
+--R                + 
+--R                         4     2 3  4 2     5 5
+--R                  (- 8A C  - 5B C )a b  - 4C a b
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                   2 3 2 5    2 3 3 4     5 4 3  2       4 2 6    5 3 5
+--R              (- 5A C a b  + B C a b  + 4C a b )c  + (A C a b  - C a b )c
+--R     + 
+--R                                   +--------------------+ +------------------+
+--R                 +-----------+     |   +-----------+      | +-----------+
+--R           2 +-+ |          2  +-+ |   |          2       | |          2
+--R         4c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         %%BJ1
+--R      *
+--R         log
+--R                           2 2 2                 2  3        2 4  8
+--R                      (128A a b  + (512A C - 128B )a b + 512C a )c
+--R                    + 
+--R                            2   4                   2  2 3       2 3 2  7
+--R                      (- 64A a b  + (- 512A C + 192B )a b  - 768C a b )c
+--R                    + 
+--R                         2 6                2    5       2 2 4  6
+--R                      (8A b  + (160A C - 72B )a b  + 416C a b )c
+--R                    + 
+--R                                    2  7      2   6  5     2 8 4
+--R                      ((- 16A C + 8B )b  - 96C a b )c  + 8C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                             3 2 2          2         2  3
+--R                        - 32A a b  + (- 128A C + 64A B )a b
+--R                      + 
+--R                                 2      2   4
+--R                        (- 128A C  + 64B C)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        3   4        2         2  2 3          2      2   3 2
+--R                      8A a b  + (112A C - 48A B )a b  + (224A C  - 64B C)a b
+--R                    + 
+--R                         3 4
+--R                      64C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                         2        2    5            2      2   2 4      3 3 3  5
+--R                  ((- 20A C + 8A B )a b  + (- 112A C  + 28B C)a b  - 80C a b )c
+--R                + 
+--R                         2     2     6      3 2 5  4     3   7 3
+--R                  ((16A C  - 4B C)a b  + 32C a b )c  - 4C a b c
+--R             *
+--R                     2
+--R                %%BJ1
+--R            + 
+--R                           2 2 2                 2  3        2 4  8
+--R                      (128A a b  + (512A C - 128B )a b + 512C a )c
+--R                    + 
+--R                            2   4                   2  2 3       2 3 2  7
+--R                      (- 64A a b  + (- 512A C + 192B )a b  - 768C a b )c
+--R                    + 
+--R                         2 6                2    5       2 2 4  6
+--R                      (8A b  + (160A C - 72B )a b  + 416C a b )c
+--R                    + 
+--R                                    2  7      2   6  5     2 8 4
+--R                      ((- 16A C + 8B )b  - 96C a b )c  + 8C b c
+--R                 *
+--R                         2
+--R                    %%BJ0
+--R                + 
+--R                             3 2 2          2          2  3          2 4  7
+--R                      (- 128A a b  + (- 512A C + 128A B )a b - 512A C a )c
+--R                    + 
+--R                             3   4        2          2  2 3
+--R                          64A a b  + (640A C - 192A B )a b
+--R                        + 
+--R                                  2       2   3 2       3 4
+--R                          (1280A C  - 128B C)a b  + 512C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              3 6          2         2    5
+--R                          - 8A b  + (- 224A C + 72A B )a b
+--R                        + 
+--R                                   2       2   2 4       3 3 3
+--R                          (- 928A C  + 192B C)a b  - 768C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                           2        2  7          2      2     6       3 2 5  4
+--R                      ((24A C - 8A B )b  + (256A C  - 72B C)a b  + 416C a b )c
+--R                    + 
+--R                               2     2   8      3   7  3     3 9 2
+--R                      ((- 24A C  + 8B C)b  - 96C a b )c  + 8C b c
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                           4 2 2       3       2 2  3
+--R                        24A a b  + (96A C - 40A B )a b
+--R                      + 
+--R                            2 2        2       4  4
+--R                        (96A C  - 32A B C - 16B )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                          4   4          3       2 2  2 3
+--R                      - 6A a b  + (- 104A C + 26A B )a b
+--R                    + 
+--R                             2 2        2       4  3 2           3     2 2  4
+--R                      (- 240A C  + 40A B C + 28B )a b  + (- 96A C  - 8B C )a b
+--R                    + 
+--R                         4 5
+--R                      32C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          3      2 2    5        2 2        2       4  2 4
+--R                      (20A C - 4A B )a b  + (150A C  - 24A B C - 14B )a b
+--R                    + 
+--R                             3      2 2  3 3     4 4 2
+--R                      (168A C  + 18B C )a b  - 8C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            2 2       2      4    6           3     2 2  2 5
+--R                      (- 24A C  + 4A B C + 2B )a b  + (- 84A C  - 4B C )a b
+--R                    + 
+--R                           4 3 4
+--R                      - 24C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        3   7      4 2 6  2     4   8
+--R                  (12A C a b  + 14C a b )c  - 2C a b c
+--R             *
+--R                %%BJ1
+--R            + 
+--R                       2 2 2                 2  3        2 4  8
+--R                  (128A a b  + (512A C - 128B )a b + 512C a )c
+--R                + 
+--R                        2   4                   2  2 3       2 3 2  7
+--R                  (- 64A a b  + (- 512A C + 192B )a b  - 768C a b )c
+--R                + 
+--R                     2 6                2    5       2 2 4  6
+--R                  (8A b  + (160A C - 72B )a b  + 416C a b )c
+--R                + 
+--R                                2  7      2   6  5     2 8 4
+--R                  ((- 16A C + 8B )b  - 96C a b )c  + 8C b c
+--R             *
+--R                     3
+--R                %%BJ0
+--R            + 
+--R                         3 2 2          2          2  3          2 4  7
+--R                  (- 128A a b  + (- 512A C + 128A B )a b - 512A C a )c
+--R                + 
+--R                         3   4        2          2  2 3
+--R                      64A a b  + (640A C - 192A B )a b
+--R                    + 
+--R                              2       2   3 2       3 4
+--R                      (1280A C  - 128B C)a b  + 512C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                          3 6          2         2    5
+--R                      - 8A b  + (- 224A C + 72A B )a b
+--R                    + 
+--R                               2       2   2 4       3 3 3
+--R                      (- 928A C  + 192B C)a b  - 768C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                       2        2  7          2      2     6       3 2 5  4
+--R                  ((24A C - 8A B )b  + (256A C  - 72B C)a b  + 416C a b )c
+--R                + 
+--R                           2     2   8      3   7  3     3 9 2
+--R                  ((- 24A C  + 8B C)b  - 96C a b )c  + 8C b c
+--R             *
+--R                     2
+--R                %%BJ0
+--R            + 
+--R                      4 2 2        3       2 2  3        2 2 4  6
+--R                  (48A a b  + (192A C - 48A B )a b + 192A C a )c
+--R                + 
+--R                           4   4          3       2 2  2 3
+--R                      - 20A a b  + (- 256A C + 92A B )a b
+--R                    + 
+--R                             2 2         2       4  3 2
+--R                      (- 576A C  + 176A B C - 24B )a b
+--R                    + 
+--R                               3      2 2  4       4 5
+--R                      (- 256A C  + 80B C )a b + 64C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        4 6       3       2 2    5
+--R                      2A b  + (84A C - 36A B )a b
+--R                    + 
+--R                           2 2         2       4  2 4          3       2 2  3 3
+--R                      (468A C  - 220A B C + 38B )a b  + (544A C  - 164B C )a b
+--R                    + 
+--R                         4 4 2
+--R                      48C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           3      2 2  7          2 2        2       4    6
+--R                      (- 8A C + 4A B )b  + (- 132A C  + 76A B C - 16B )a b
+--R                    + 
+--R                               3       2 2  2 5       4 3 4
+--R                      (- 360A C  + 132B C )a b  - 160C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          2 2       2      4  8         3      2 2    7
+--R                      (12A C  - 8A B C + 2B )b  + (92A C  - 40B C )a b
+--R                    + 
+--R                          4 2 6
+--R                      100C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3     2 2  9      4   8       4 10
+--R                  ((- 8A C  + 4B C )b  - 24C a b )c + 2C b
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    5 4 5
+--R                  4B a c
+--R                + 
+--R                         4     4        3        2 3  2 3
+--R                      - A B a b  + (- 8A B C + 6A B )a b
+--R                    + 
+--R                            2   2        3      5  3 2
+--R                      (- 24A B C  + 24A B C - 9B )a b
+--R                    + 
+--R                                3      3 2  4         4 5
+--R                      (- 32A B C  + 24B C )a b - 16B C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3        2 3    5       2   2        3      5  2 4
+--R                      (4A B C - 2A B )a b  + (24A B C  - 20A B C + 6B )a b
+--R                    + 
+--R                              3      3 2  3 3        4 4 2
+--R                      (48A B C  - 32B C )a b  + 32B C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           2   2       3     5    6             3      3 2  2 5
+--R                      (- 6A B C  + 4A B C - B )a b  + (- 24A B C  + 14B C )a b
+--R                    + 
+--R                             4 3 4
+--R                      - 24B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3     3 2    7       4 2 6        4   8
+--R                  ((4A B C  - 2B C )a b  + 8B C a b )c - B C a b
+--R             *
+--R                x
+--R            + 
+--R                        5 2 2         4      3 2  3
+--R                    - 6A a b  + (- 24A C + 8A B )a b
+--R                  + 
+--R                          3 2     2 2        4  4
+--R                    (- 24A C  + 4A B C + 4A B )a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                   5   4       4       3 2  2 3       3 2      2 2       4  3 2
+--R                  A a b  + (27A C - 10A B )a b  + (66A C  - 25A B C + A B )a b
+--R                + 
+--R                     2 3 4            4      2 3  5
+--R                  20A C a b + (- 24A C  + 12B C )a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                       4      3 2    5         3 2      2 2        4  2 4
+--R                  (- 4A C + 2A B )a b  + (- 44A C  + 22A B C - 4A B )a b
+--R                + 
+--R                        2 3       2 2     4   3 3         4      2 3  4 2
+--R                  (- 51A C  + 8A B C  + 3B C)a b  + (28A C  - 19B C )a b
+--R                + 
+--R                     5 5
+--R                  20C a b
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                     3 2     2 2       4    6       2 3        2 2    4   2 5
+--R                  (6A C  - 4A B C + A B )a b  + (30A C  - 10A B C  - B C)a b
+--R                + 
+--R                     2 3 3 4      5 4 3
+--R                  12B C a b  - 24C a b
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                    2 3       2 2    7          4     2 3  2 6     5 3 5
+--R              ((- 4A C  + 2A B C )a b  + (- 6A C  - 2B C )a b  + 9C a b )c
+--R            + 
+--R                 4   8    5 2 7
+--R              A C a b  - C a b
+--R     + 
+--R                                                   +------------------+
+--R                 +-----------+                     | +-----------+
+--R                 |          2          2       2   | |          2
+--R         (4B b c\|- 4a c + b   + 8B a c  - 4B b c)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                   +--------------------+
+--R                 +-----------+                     |   +-----------+
+--R                 |          2          2       2   |   |          2
+--R         (4B b c\|- 4a c + b   - 8B a c  + 4B b c)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                     +-----------+
+--R               2 +-+ |          2  +-+
+--R             4c \|2 \|- 4a c + b  \|c %%BJ0
+--R          *
+--R             log
+--R                             2 2 2                   2  3        2 4  8
+--R                      (- 128A a b  + (- 512A C + 128B )a b - 512C a )c
+--R                    + 
+--R                          2   4                 2  2 3       2 3 2  7
+--R                      (64A a b  + (512A C - 192B )a b  + 768C a b )c
+--R                    + 
+--R                           2 6                  2    5       2 2 4  6
+--R                      (- 8A b  + (- 160A C + 72B )a b  - 416C a b )c
+--R                    + 
+--R                                  2  7      2   6  5     2 8 4
+--R                      ((16A C - 8B )b  + 96C a b )c  - 8C b c
+--R                 *
+--R                         3
+--R                    %%BJ0
+--R                + 
+--R                          3 2 2        2         2  3           2      2   4  7
+--R                      (96A a b  + (384A C - 64A B )a b + (384A C  + 64B C)a )c
+--R                    + 
+--R                               3   4          2          2  2 3
+--R                          - 56A a b  + (- 528A C + 144A B )a b
+--R                        + 
+--R                                    2      2   3 2       3 4
+--R                          (- 1056A C  + 64B C)a b  - 448C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3 6        2         2    5          2       2   2 4
+--R                          8A b  + (204A C - 64A B )a b  + (816A C  - 164B C)a b
+--R                        + 
+--R                              3 3 3
+--R                          688C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                2        2  7            2      2     6
+--R                          (- 24A C + 8A B )b  + (- 240A C  + 68B C)a b
+--R                        + 
+--R                                3 2 5
+--R                          - 384C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             2     2   8      3   7  3     3 9 2
+--R                      ((24A C  - 8B C)b  + 92C a b )c  - 8C b c
+--R                 *
+--R                         2
+--R                    %%BJ0
+--R                + 
+--R                               4 2 2         3      2 2  3
+--R                          - 24A a b  + (- 96A C + 8A B )a b
+--R                        + 
+--R                                2 2        2       4  4
+--R                          (- 96A C  - 32A B C - 16B )a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                             4   4        3       2 2  2 3
+--R                          14A a b  + (152A C - 66A B )a b
+--R                        + 
+--R                               2 2         2       4  3 2
+--R                          (336A C  - 136A B C + 52B )a b
+--R                        + 
+--R                                 3      2 2  4       4 5
+--R                          (160A C  - 88B C )a b - 32C a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                              4 6         3       2 2    5
+--R                          - 2A b  + (- 64A C + 32A B )a b
+--R                        + 
+--R                                 2 2         2       4  2 4
+--R                          (- 318A C  + 196A B C - 52B )a b
+--R                        + 
+--R                                   3       2 2  3 3      4 4 2
+--R                          (- 376A C  + 182B C )a b  - 56C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             3      2 2  7        2 2        2       4    6
+--R                          (8A C - 4A B )b  + (108A C  - 72A B C + 18B )a b
+--R                        + 
+--R                                 3       2 2  2 5       4 3 4
+--R                          (276A C  - 136B C )a b  + 136C a b
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                2 2       2      4  8           3      2 2    7
+--R                          (- 12A C  + 8A B C - 2B )b  + (- 80A C  + 40B C )a b
+--R                        + 
+--R                               4 2 6
+--R                          - 86C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                            3     2 2  9      4   8       4 10
+--R                      ((8A C  - 4B C )b  + 22C a b )c - 2C b
+--R                 *
+--R                    %%BJ0
+--R                + 
+--R                        5 4 5
+--R                      4B a c
+--R                    + 
+--R                             4     4        3        2 3  2 3
+--R                          - A B a b  + (- 8A B C + 6A B )a b
+--R                        + 
+--R                                2   2        3      5  3 2
+--R                          (- 24A B C  + 24A B C - 9B )a b
+--R                        + 
+--R                                    3      3 2  4         4 5
+--R                          (- 32A B C  + 24B C )a b - 16B C a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             3        2 3    5       2   2        3      5  2 4
+--R                          (4A B C - 2A B )a b  + (24A B C  - 20A B C + 6B )a b
+--R                        + 
+--R                                  3      3 2  3 3        4 4 2
+--R                          (48A B C  - 32B C )a b  + 32B C a b
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                               2   2       3     5    6
+--R                          (- 6A B C  + 4A B C - B )a b
+--R                        + 
+--R                                    3      3 2  2 5        4 3 4
+--R                          (- 24A B C  + 14B C )a b  - 24B C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3     3 2    7       4 2 6        4   8
+--R                      ((4A B C  - 2B C )a b  + 8B C a b )c - B C a b
+--R                 *
+--R                    x
+--R                + 
+--R                     5 2 2     4   3       3 2     2 2        4  4  5
+--R                  (2A a b  + 8A C a b + (8A C  + 4A B C + 4A B )a )c
+--R                + 
+--R                         5   4         4      3 2  2 3
+--R                      - A a b  + (- 13A C + 8A B )a b
+--R                    + 
+--R                            3 2      2 2        4  3 2
+--R                      (- 30A C  + 15A B C - 7A B )a b
+--R                    + 
+--R                            2 3       2 2     4   4         4      2 3  5
+--R                      (- 12A C  - 8A B C  + 8B C)a b + (8A C  - 20B C )a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         4      3 2    5       3 2      2 2        4  2 4
+--R                      (4A C - 2A B )a b  + (26A C  - 20A B C + 6A B )a b
+--R                    + 
+--R                          2 3       2 2     4   3 3           4      2 3  4 2
+--R                      (29A C  - 6A B C  - 7B C)a b  + (- 12A C  + 29B C )a b
+--R                    + 
+--R                           5 5
+--R                      - 12C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           3 2     2 2       4    6
+--R                      (- 6A C  + 4A B C - A B )a b
+--R                    + 
+--R                            2 3        2 2    4   2 5      2 3 3 4      5 4 3
+--R                      (- 20A C  + 10A B C  + B C)a b  - 14B C a b  + 16C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                      2 3       2 2    7        4     2 3  2 6     5 3 5
+--R                  ((4A C  - 2A B C )a b  + (4A C  + 2B C )a b  - 7C a b )c
+--R                + 
+--R                       4   8    5 2 7
+--R                  - A C a b  + C a b
+--R         + 
+--R                                                          2
+--R                                   2  +-+ +-+         2c x  + b
+--R           ((- 2A b - 4C a)c + 2C b )\|2 \|c atanh(--------------)
+--R                                                    +-----------+
+--R                                                    |          2
+--R                                                   \|- 4a c + b
+--R         + 
+--R                                                 +-----------+
+--R                         +-+       4      2      |          2  +-+
+--R           (- A c + C b)\|2 log(c x  + b x  + a)\|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     4c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+)clear all
+
+--S 484 of 1070
+t0:=x^2*(A+B*x+C*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           4      3      2
+--R        C x  + B x  + A x
+--R   (1)  ------------------
+--R             4      2
+--R          c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 484
+
+--S 485 of 1070
+r0:=C*x/c+1/4*B*log(a+b*x^2+c*x^4)/c+1/2*b*B*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(c*sqrt(b^2-4*a*c))+atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*(A*c-b*C+(-A*b*c+(b^2-2*a*c)*C)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(A*c-b*C+_
+   (A*b*c-b^2*C+2*a*c*C)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                        +-----------+
+--R                        |          2                           2
+--R         ((4A c - 4C b)\|- 4a c + b   + (- 4A b - 8C a)c + 4C b )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                        +-----------+
+--R                        |          2                         2
+--R         ((4A c - 4C b)\|- 4a c + b   + (4A b + 8C a)c - 4C b )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                    2
+--R                +-+ +-+         2c x  + b
+--R           2B b\|2 \|c atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R         + 
+--R                                                  +-----------+
+--R              +-+       4      2             +-+  |          2  +-+
+--R           (B\|2 log(c x  + b x  + a) + 4C x\|2 )\|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     4c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             c
+--R          *
+--R             ROOT
+--R                            4     2 3      2
+--R                    (- 12a c  + 3b c )%%BK1
+--R                  + 
+--R                            4     2 3               3       2 2
+--R                    ((- 8a c  + 2b c )%%BK0 + 8B a c  - 2B b c )%%BK1
+--R                  + 
+--R                            4     2 3      2          3       2 2
+--R                    (- 12a c  + 3b c )%%BK0  + (8B a c  - 2B b c )%%BK0
+--R                  + 
+--R                      2              2    2            2     2         2 3
+--R                    (A b + (4A C - 2B )a)c  + (- 2A C b  - 3C a b)c + C b
+--R               /
+--R                      4    2 3
+--R                  4a c  - b c
+--R         + 
+--R           - c %%BK1 - c %%BK0 + B
+--R      *
+--R         log
+--R                              3 2 8         3   2       2   2          2 3  7
+--R                          128A a c  + (- 64A a b  - 320A C a b - 128A C a )c
+--R                        + 
+--R                                3 4       2     3          2      2   2 2
+--R                              8A b  + 160A C a b  + (320A C  - 64B C)a b
+--R                            + 
+--R                                 3 3
+--R                              64C a b
+--R                         *
+--R                             6
+--R                            c
+--R                        + 
+--R                                2   5            2      2     4      3 2 3  5
+--R                          (- 20A C b  + (- 136A C  + 32B C)a b  - 96C a b )c
+--R                        + 
+--R                                 2     2   6      3   5  4     3 7 3
+--R                          ((16A C  - 4B C)b  + 36C a b )c  - 4C b c
+--R                     *
+--R                        %%BK0
+--R                    + 
+--R                           3   2 7       2     2           2 3  6
+--R                      - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                    + 
+--R                            3   4      2          3    3
+--R                          2A B b  + (8A B C - 8A B )a b
+--R                        + 
+--R                                    2      3   2 2        3 3
+--R                          (- 32A B C  + 16B C)a b  - 32B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                               2          3  5            2     3     4
+--R                          (- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b
+--R                        + 
+--R                               3 2 3
+--R                          24B C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             2 6       3   5  3
+--R                      (2A B C b  - 4B C a b )c
+--R                 *
+--R                    %%BK1
+--R                + 
+--R                           3   2 7       2     2           2 3  6
+--R                      - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                    + 
+--R                            3   4      2          3    3
+--R                          2A B b  + (8A B C - 8A B )a b
+--R                        + 
+--R                                    2      3   2 2        3 3
+--R                          (- 32A B C  + 16B C)a b  - 32B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                               2          3  5            2     3     4
+--R                          (- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b
+--R                        + 
+--R                               3 2 3
+--R                          24B C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             2 6       3   5  3
+--R                      (2A B C b  - 4B C a b )c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                     5         4      3 2  2  6
+--R                  (4A a b + (8A C + 8A B )a )c
+--R                + 
+--R                         5 3         4      3 2    2         3 2     2 2   2
+--R                      - A b  + (- 18A C + 6A B )a b  + (- 24A C  + 4A B C)a b
+--R                    + 
+--R                            2 2 3
+--R                      - 8A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         4      3 2  4       3 2      2 2        4    3
+--R                      (4A C - 2A B )b  + (30A C  - 17A B C + 4A B )a b
+--R                    + 
+--R                          2 3       2 2     4   2 2           4      2 3  3
+--R                      (20A C  + 2A B C  - 4B C)a b  + (- 12A C  + 12B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           3 2     2 2       4  5
+--R                      (- 6A C  + 4A B C - A B )b
+--R                    + 
+--R                            2 3       2 2    4     4        4      2 3  2 3
+--R                      (- 21A C  + 8A B C  + B C)a b  + (3A C  - 11B C )a b
+--R                    + 
+--R                         5 3 2
+--R                      14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                      2 3       2 2  6        4     2 3    5     5 2 4  2
+--R                  ((4A C  - 2A B C )b  + (4A C  + 2B C )a b  - 7C a b )c
+--R                + 
+--R                        4 7    5   6
+--R                  (- A C b  + C a b )c
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BK1
+--R                     + 
+--R                               4     2 3               3       2 2
+--R                       ((- 8a c  + 2b c )%%BK0 + 8B a c  - 2B b c )%%BK1
+--R                     + 
+--R                               4     2 3      2          3       2 2
+--R                       (- 12a c  + 3b c )%%BK0  + (8B a c  - 2B b c )%%BK0
+--R                     + 
+--R                         2              2    2            2     2         2 3
+--R                       (A b + (4A C - 2B )a)c  + (- 2A C b  - 3C a b)c + C b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R            + 
+--R                          3 2 8         3   2       2   2          2 3  7
+--R                      128A a c  + (- 64A a b  - 320A C a b - 128A C a )c
+--R                    + 
+--R                         3 4       2     3          2      2   2 2      3 3   6
+--R                      (8A b  + 160A C a b  + (320A C  - 64B C)a b  + 64C a b)c
+--R                    + 
+--R                            2   5            2      2     4      3 2 3  5
+--R                      (- 20A C b  + (- 136A C  + 32B C)a b  - 96C a b )c
+--R                    + 
+--R                             2     2   6      3   5  4     3 7 3
+--R                      ((16A C  - 4B C)b  + 36C a b )c  - 4C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                       3   2 7       2     2           2 3  6
+--R                  - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                + 
+--R                        3   4      2          3    3             2      3   2 2
+--R                      2A B b  + (8A B C - 8A B )a b  + (- 32A B C  + 16B C)a b
+--R                    + 
+--R                             3 3
+--R                      - 32B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        2          3  5            2     3     4        3 2 3  4
+--R                  ((- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b  + 24B C a b )c
+--R                + 
+--R                         2 6       3   5  3
+--R                  (2A B C b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BK1
+--R            + 
+--R                          3 2 8         3   2       2   2          2 3  7
+--R                      128A a c  + (- 64A a b  - 320A C a b - 128A C a )c
+--R                    + 
+--R                         3 4       2     3          2      2   2 2      3 3   6
+--R                      (8A b  + 160A C a b  + (320A C  - 64B C)a b  + 64C a b)c
+--R                    + 
+--R                            2   5            2      2     4      3 2 3  5
+--R                      (- 20A C b  + (- 136A C  + 32B C)a b  - 96C a b )c
+--R                    + 
+--R                             2     2   6      3   5  4     3 7 3
+--R                      ((16A C  - 4B C)b  + 36C a b )c  - 4C b c
+--R                 *
+--R                         2
+--R                    %%BK0
+--R                + 
+--R                            3   2 7
+--R                      - 128A B a c
+--R                    + 
+--R                          3     2       2     2            2 3  6
+--R                      (64A B a b  + 320A B C a b + 128A B C a )c
+--R                    + 
+--R                              3   4       2       3              2      3   2 2
+--R                          - 8A B b  - 160A B C a b  + (- 320A B C  + 64B C)a b
+--R                        + 
+--R                                 3 3
+--R                          - 64B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                          2     5            2      3     4        3 2 3  4
+--R                      (20A B C b  + (136A B C  - 32B C)a b  + 96B C a b )c
+--R                    + 
+--R                                 2     3   6        3   5  3       3 7 2
+--R                      ((- 16A B C  + 4B C)b  - 36B C a b )c  + 4B C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                       5           4       3 2  2  6
+--R                  (- 4A a b + (- 8A C + 24A B )a )c
+--R                + 
+--R                       5 3       4      3 2    2       3 2      2 2   2
+--R                      A b  + (18A C - 6A B )a b  + (24A C  - 36A B C)a b
+--R                    + 
+--R                             2 2 3
+--R                      - 24A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4   4         3 2     2 2        4    3
+--R                      - 4A C b  + (- 30A C  + 9A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   2 2         4      2 3  3
+--R                      (- 20A C  + 30A B C  - 12B C)a b  + (12A C  + 20B C )a b
+--R                    + 
+--R                        5 4
+--R                      8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 2      4  5       2 3       2 2     4     4
+--R                      (6A C  - A B )b  + (21A C  - 6A B C  + 3B C)a b
+--R                    + 
+--R                             4      2 3  2 3      5 3 2
+--R                      (- 3A C  - 13B C )a b  - 14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 3 6          4     2 3    5     5 2 4  2
+--R                  (- 4A C b  + (- 4A C  + 2B C )a b  + 7C a b )c
+--R                + 
+--R                      4 7    5   6
+--R                  (A C b  - C a b )c
+--R             *
+--R                %%BK1
+--R            + 
+--R                       3   2 7       2     2           2 3  6
+--R                  - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                + 
+--R                        3   4      2          3    3             2      3   2 2
+--R                      2A B b  + (8A B C - 8A B )a b  + (- 32A B C  + 16B C)a b
+--R                    + 
+--R                             3 3
+--R                      - 32B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        2          3  5            2     3     4        3 2 3  4
+--R                  ((- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b  + 24B C a b )c
+--R                + 
+--R                         2 6       3   5  3
+--R                  (2A B C b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BK0
+--R            + 
+--R                       5           4       3 2  2  6
+--R                  (- 4A a b + (- 8A C + 24A B )a )c
+--R                + 
+--R                       5 3       4      3 2    2       3 2      2 2   2
+--R                      A b  + (18A C - 6A B )a b  + (24A C  - 36A B C)a b
+--R                    + 
+--R                             2 2 3
+--R                      - 24A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4   4         3 2     2 2        4    3
+--R                      - 4A C b  + (- 30A C  + 9A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   2 2         4      2 3  3
+--R                      (- 20A C  + 30A B C  - 12B C)a b  + (12A C  + 20B C )a b
+--R                    + 
+--R                        5 4
+--R                      8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 2      4  5       2 3       2 2     4     4
+--R                      (6A C  - A B )b  + (21A C  - 6A B C  + 3B C)a b
+--R                    + 
+--R                             4      2 3  2 3      5 3 2
+--R                      (- 3A C  - 13B C )a b  - 14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 3 6          4     2 3    5     5 2 4  2
+--R                  (- 4A C b  + (- 4A C  + 2B C )a b  + 7C a b )c
+--R                + 
+--R                      4 7    5   6
+--R                  (A C b  - C a b )c
+--R             *
+--R                %%BK0
+--R            + 
+--R                    6   6       6 2      5          4 2 2  5
+--R                  4A a c  + (- A b  - 20A C a b - 4A C a )c
+--R                + 
+--R                         5      4 2  3       4 2     3 2     2     3 3 2
+--R                      (5A C - 2A B )b  + (41A C  - 8A B C)a b  + 8A C a b
+--R                    + 
+--R                          2 4 3
+--R                      - 4A C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4  4         3 3      2 2 2    3
+--R                      (- 10A C  + 6A B C - A B )b  + (- 42A C  + 12A B C )a b
+--R                    + 
+--R                        2 4       2 3  2 2        5 3      6 4
+--R                      (A C  - 8A B C )a b  + 12A C a b + 4C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4   5
+--R                      (10A C  - 6A B C  + A B C)b
+--R                    + 
+--R                          2 4       2 3    4 2    4           5     2 4  2 3
+--R                      (20A C  - 2A B C  - B C )a b  + (- 11A C  + 6B C )a b
+--R                    + 
+--R                          6 3 2
+--R                      - 9C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3  6          5     2 4    5     6 2 4
+--R                  ((- 5A C  + 2A B C )b  + (- 2A C  - 2B C )a b  + 6C a b )c
+--R                + 
+--R                     5 7    6   6
+--R                  A C b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                 5           4        3 3  2  5
+--R              (4A B a b + (4A B C - 4A B )a )c
+--R            + 
+--R                     4       3 3    2        3   2     2 3   2        3 2 3  4
+--R              ((- 11A B C + A B )a b  + (- 4A B C  + 4A B C)a b + 4A B C a )c
+--R            + 
+--R                      3   2    2 3       5    3         3 2     5   2 2
+--R                  (11A B C  - A B C - A B )a b  + (- A B C  + 2B C)a b
+--R                + 
+--R                      3 3 3        5 4
+--R                  - 4B C a b - 4B C a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                   2   3   4         4    3 3  2 3       5 3 2  2
+--R              (- 5A B C a b  + (A B C  + B C )a b  + 3B C a b )c
+--R            + 
+--R                    4   5      5 2 4
+--R              (A B C a b  - B C a b )c
+--R     + 
+--R           -
+--R                c
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BK1
+--R                     + 
+--R                               4     2 3               3       2 2
+--R                       ((- 8a c  + 2b c )%%BK0 + 8B a c  - 2B b c )%%BK1
+--R                     + 
+--R                               4     2 3      2          3       2 2
+--R                       (- 12a c  + 3b c )%%BK0  + (8B a c  - 2B b c )%%BK0
+--R                     + 
+--R                         2              2    2            2     2         2 3
+--R                       (A b + (4A C - 2B )a)c  + (- 2A C b  - 3C a b)c + C b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R         + 
+--R           - c %%BK1 - c %%BK0 + B
+--R      *
+--R         log
+--R                                3 2 8       3   2       2   2          2 3  7
+--R                          - 128A a c  + (64A a b  + 320A C a b + 128A C a )c
+--R                        + 
+--R                                  3 4       2     3            2      2   2 2
+--R                              - 8A b  - 160A C a b  + (- 320A C  + 64B C)a b
+--R                            + 
+--R                                   3 3
+--R                              - 64C a b
+--R                         *
+--R                             6
+--R                            c
+--R                        + 
+--R                              2   5          2      2     4      3 2 3  5
+--R                          (20A C b  + (136A C  - 32B C)a b  + 96C a b )c
+--R                        + 
+--R                                   2     2   6      3   5  4     3 7 3
+--R                          ((- 16A C  + 4B C)b  - 36C a b )c  + 4C b c
+--R                     *
+--R                        %%BK0
+--R                    + 
+--R                         3   2 7         2     2           2 3  6
+--R                      32A B a c  + (- 32A B C a b - 32A B C a )c
+--R                    + 
+--R                              3   4        2          3    3
+--R                          - 2A B b  + (- 8A B C + 8A B )a b
+--R                        + 
+--R                                  2      3   2 2        3 3
+--R                          (32A B C  - 16B C)a b  + 32B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                          2          3  5          2     3     4        3 2 3  4
+--R                      ((4A B C - 2A B )b  + (2A B C  + 4B C)a b  - 24B C a b )c
+--R                    + 
+--R                               2 6       3   5  3
+--R                      (- 2A B C b  + 4B C a b )c
+--R                 *
+--R                    %%BK1
+--R                + 
+--R                         3   2 7         2     2           2 3  6
+--R                      32A B a c  + (- 32A B C a b - 32A B C a )c
+--R                    + 
+--R                              3   4        2          3    3
+--R                          - 2A B b  + (- 8A B C + 8A B )a b
+--R                        + 
+--R                                  2      3   2 2        3 3
+--R                          (32A B C  - 16B C)a b  + 32B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                          2          3  5          2     3     4        3 2 3  4
+--R                      ((4A B C - 2A B )b  + (2A B C  + 4B C)a b  - 24B C a b )c
+--R                    + 
+--R                               2 6       3   5  3
+--R                      (- 2A B C b  + 4B C a b )c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                       5           4      3 2  2  6
+--R                  (- 4A a b + (- 8A C - 8A B )a )c
+--R                + 
+--R                       5 3       4      3 2    2       3 2     2 2   2
+--R                      A b  + (18A C - 6A B )a b  + (24A C  - 4A B C)a b
+--R                    + 
+--R                          2 2 3
+--R                      8A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4      3 2  4         3 2      2 2        4    3
+--R                      (- 4A C + 2A B )b  + (- 30A C  + 17A B C - 4A B )a b
+--R                    + 
+--R                            2 3       2 2     4   2 2         4      2 3  3
+--R                      (- 20A C  - 2A B C  + 4B C)a b  + (12A C  - 12B C )a b
+--R                    + 
+--R                        5 4
+--R                      8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 2     2 2       4  5       2 3       2 2    4     4
+--R                      (6A C  - 4A B C + A B )b  + (21A C  - 8A B C  - B C)a b
+--R                    + 
+--R                             4      2 3  2 3      5 3 2
+--R                      (- 3A C  + 11B C )a b  - 14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        2 3       2 2  6          4     2 3    5     5 2 4  2
+--R                  ((- 4A C  + 2A B C )b  + (- 4A C  - 2B C )a b  + 7C a b )c
+--R                + 
+--R                      4 7    5   6
+--R                  (A C b  - C a b )c
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BK1
+--R                     + 
+--R                               4     2 3               3       2 2
+--R                       ((- 8a c  + 2b c )%%BK0 + 8B a c  - 2B b c )%%BK1
+--R                     + 
+--R                               4     2 3      2          3       2 2
+--R                       (- 12a c  + 3b c )%%BK0  + (8B a c  - 2B b c )%%BK0
+--R                     + 
+--R                         2              2    2            2     2         2 3
+--R                       (A b + (4A C - 2B )a)c  + (- 2A C b  - 3C a b)c + C b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R            + 
+--R                          3 2 8         3   2       2   2          2 3  7
+--R                      128A a c  + (- 64A a b  - 320A C a b - 128A C a )c
+--R                    + 
+--R                         3 4       2     3          2      2   2 2      3 3   6
+--R                      (8A b  + 160A C a b  + (320A C  - 64B C)a b  + 64C a b)c
+--R                    + 
+--R                            2   5            2      2     4      3 2 3  5
+--R                      (- 20A C b  + (- 136A C  + 32B C)a b  - 96C a b )c
+--R                    + 
+--R                             2     2   6      3   5  4     3 7 3
+--R                      ((16A C  - 4B C)b  + 36C a b )c  - 4C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                       3   2 7       2     2           2 3  6
+--R                  - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                + 
+--R                        3   4      2          3    3             2      3   2 2
+--R                      2A B b  + (8A B C - 8A B )a b  + (- 32A B C  + 16B C)a b
+--R                    + 
+--R                             3 3
+--R                      - 32B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        2          3  5            2     3     4        3 2 3  4
+--R                  ((- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b  + 24B C a b )c
+--R                + 
+--R                         2 6       3   5  3
+--R                  (2A B C b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BK1
+--R            + 
+--R                          3 2 8         3   2       2   2          2 3  7
+--R                      128A a c  + (- 64A a b  - 320A C a b - 128A C a )c
+--R                    + 
+--R                         3 4       2     3          2      2   2 2      3 3   6
+--R                      (8A b  + 160A C a b  + (320A C  - 64B C)a b  + 64C a b)c
+--R                    + 
+--R                            2   5            2      2     4      3 2 3  5
+--R                      (- 20A C b  + (- 136A C  + 32B C)a b  - 96C a b )c
+--R                    + 
+--R                             2     2   6      3   5  4     3 7 3
+--R                      ((16A C  - 4B C)b  + 36C a b )c  - 4C b c
+--R                 *
+--R                         2
+--R                    %%BK0
+--R                + 
+--R                            3   2 7
+--R                      - 128A B a c
+--R                    + 
+--R                          3     2       2     2            2 3  6
+--R                      (64A B a b  + 320A B C a b + 128A B C a )c
+--R                    + 
+--R                              3   4       2       3              2      3   2 2
+--R                          - 8A B b  - 160A B C a b  + (- 320A B C  + 64B C)a b
+--R                        + 
+--R                                 3 3
+--R                          - 64B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                          2     5            2      3     4        3 2 3  4
+--R                      (20A B C b  + (136A B C  - 32B C)a b  + 96B C a b )c
+--R                    + 
+--R                                 2     3   6        3   5  3       3 7 2
+--R                      ((- 16A B C  + 4B C)b  - 36B C a b )c  + 4B C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                       5           4       3 2  2  6
+--R                  (- 4A a b + (- 8A C + 24A B )a )c
+--R                + 
+--R                       5 3       4      3 2    2       3 2      2 2   2
+--R                      A b  + (18A C - 6A B )a b  + (24A C  - 36A B C)a b
+--R                    + 
+--R                             2 2 3
+--R                      - 24A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4   4         3 2     2 2        4    3
+--R                      - 4A C b  + (- 30A C  + 9A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   2 2         4      2 3  3
+--R                      (- 20A C  + 30A B C  - 12B C)a b  + (12A C  + 20B C )a b
+--R                    + 
+--R                        5 4
+--R                      8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 2      4  5       2 3       2 2     4     4
+--R                      (6A C  - A B )b  + (21A C  - 6A B C  + 3B C)a b
+--R                    + 
+--R                             4      2 3  2 3      5 3 2
+--R                      (- 3A C  - 13B C )a b  - 14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 3 6          4     2 3    5     5 2 4  2
+--R                  (- 4A C b  + (- 4A C  + 2B C )a b  + 7C a b )c
+--R                + 
+--R                      4 7    5   6
+--R                  (A C b  - C a b )c
+--R             *
+--R                %%BK1
+--R            + 
+--R                       3   2 7       2     2           2 3  6
+--R                  - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                + 
+--R                        3   4      2          3    3             2      3   2 2
+--R                      2A B b  + (8A B C - 8A B )a b  + (- 32A B C  + 16B C)a b
+--R                    + 
+--R                             3 3
+--R                      - 32B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        2          3  5            2     3     4        3 2 3  4
+--R                  ((- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b  + 24B C a b )c
+--R                + 
+--R                         2 6       3   5  3
+--R                  (2A B C b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BK0
+--R            + 
+--R                       5           4       3 2  2  6
+--R                  (- 4A a b + (- 8A C + 24A B )a )c
+--R                + 
+--R                       5 3       4      3 2    2       3 2      2 2   2
+--R                      A b  + (18A C - 6A B )a b  + (24A C  - 36A B C)a b
+--R                    + 
+--R                             2 2 3
+--R                      - 24A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4   4         3 2     2 2        4    3
+--R                      - 4A C b  + (- 30A C  + 9A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   2 2         4      2 3  3
+--R                      (- 20A C  + 30A B C  - 12B C)a b  + (12A C  + 20B C )a b
+--R                    + 
+--R                        5 4
+--R                      8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 2      4  5       2 3       2 2     4     4
+--R                      (6A C  - A B )b  + (21A C  - 6A B C  + 3B C)a b
+--R                    + 
+--R                             4      2 3  2 3      5 3 2
+--R                      (- 3A C  - 13B C )a b  - 14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 3 6          4     2 3    5     5 2 4  2
+--R                  (- 4A C b  + (- 4A C  + 2B C )a b  + 7C a b )c
+--R                + 
+--R                      4 7    5   6
+--R                  (A C b  - C a b )c
+--R             *
+--R                %%BK0
+--R            + 
+--R                    6   6       6 2      5          4 2 2  5
+--R                  4A a c  + (- A b  - 20A C a b - 4A C a )c
+--R                + 
+--R                         5      4 2  3       4 2     3 2     2     3 3 2
+--R                      (5A C - 2A B )b  + (41A C  - 8A B C)a b  + 8A C a b
+--R                    + 
+--R                          2 4 3
+--R                      - 4A C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4  4         3 3      2 2 2    3
+--R                      (- 10A C  + 6A B C - A B )b  + (- 42A C  + 12A B C )a b
+--R                    + 
+--R                        2 4       2 3  2 2        5 3      6 4
+--R                      (A C  - 8A B C )a b  + 12A C a b + 4C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4   5
+--R                      (10A C  - 6A B C  + A B C)b
+--R                    + 
+--R                          2 4       2 3    4 2    4           5     2 4  2 3
+--R                      (20A C  - 2A B C  - B C )a b  + (- 11A C  + 6B C )a b
+--R                    + 
+--R                          6 3 2
+--R                      - 9C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3  6          5     2 4    5     6 2 4
+--R                  ((- 5A C  + 2A B C )b  + (- 2A C  - 2B C )a b  + 6C a b )c
+--R                + 
+--R                     5 7    6   6
+--R                  A C b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                 5           4        3 3  2  5
+--R              (4A B a b + (4A B C - 4A B )a )c
+--R            + 
+--R                     4       3 3    2        3   2     2 3   2        3 2 3  4
+--R              ((- 11A B C + A B )a b  + (- 4A B C  + 4A B C)a b + 4A B C a )c
+--R            + 
+--R                      3   2    2 3       5    3         3 2     5   2 2
+--R                  (11A B C  - A B C - A B )a b  + (- A B C  + 2B C)a b
+--R                + 
+--R                      3 3 3        5 4
+--R                  - 4B C a b - 4B C a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                   2   3   4         4    3 3  2 3       5 3 2  2
+--R              (- 5A B C a b  + (A B C  + B C )a b  + 3B C a b )c
+--R            + 
+--R                    4   5      5 2 4
+--R              (A B C a b  - B C a b )c
+--R     + 
+--R         2c %%BK1
+--R      *
+--R         log
+--R                            3 2 8        3   2       2   2          2 3  7
+--R                      - 256A a c  + (128A a b  + 640A C a b + 256A C a )c
+--R                    + 
+--R                               3 4       2     3            2       2   2 2
+--R                          - 16A b  - 320A C a b  + (- 640A C  + 128B C)a b
+--R                        + 
+--R                                3 3
+--R                          - 128C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                          2   5          2      2     4       3 2 3  5
+--R                      (40A C b  + (272A C  - 64B C)a b  + 192C a b )c
+--R                    + 
+--R                               2     2   6      3   5  4     3 7 3
+--R                      ((- 32A C  + 8B C)b  - 72C a b )c  + 8C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                     3   2 7         2     2           2 3  6
+--R                  64A B a c  + (- 64A B C a b - 64A B C a )c
+--R                + 
+--R                          3   4         2           3    3
+--R                      - 4A B b  + (- 16A B C + 16A B )a b
+--R                    + 
+--R                              2      3   2 2        3 3
+--R                      (64A B C  - 32B C)a b  + 64B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                      2          3  5          2     3     4        3 2 3  4
+--R                  ((8A B C - 4A B )b  + (4A B C  + 8B C)a b  - 48B C a b )c
+--R                + 
+--R                           2 6       3   5  3
+--R                  (- 4A B C b  + 8B C a b )c
+--R             *
+--R                     2
+--R                %%BK1
+--R            + 
+--R                            3 2 8        3   2       2   2          2 3  7
+--R                      - 256A a c  + (128A a b  + 640A C a b + 256A C a )c
+--R                    + 
+--R                               3 4       2     3            2       2   2 2
+--R                          - 16A b  - 320A C a b  + (- 640A C  + 128B C)a b
+--R                        + 
+--R                                3 3
+--R                          - 128C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                          2   5          2      2     4       3 2 3  5
+--R                      (40A C b  + (272A C  - 64B C)a b  + 192C a b )c
+--R                    + 
+--R                               2     2   6      3   5  4     3 7 3
+--R                      ((- 32A C  + 8B C)b  - 72C a b )c  + 8C b c
+--R                 *
+--R                         2
+--R                    %%BK0
+--R                + 
+--R                          3   2 7
+--R                      256A B a c
+--R                    + 
+--R                             3     2       2     2            2 3  6
+--R                      (- 128A B a b  - 640A B C a b - 256A B C a )c
+--R                    + 
+--R                             3   4       2       3            2       3   2 2
+--R                          16A B b  + 320A B C a b  + (640A B C  - 128B C)a b
+--R                        + 
+--R                                3 3
+--R                          128B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                            2     5              2      3     4         3 2 3  4
+--R                      (- 40A B C b  + (- 272A B C  + 64B C)a b  - 192B C a b )c
+--R                    + 
+--R                               2     3   6        3   5  3       3 7 2
+--R                      ((32A B C  - 8B C)b  + 72B C a b )c  - 8B C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                     5          4       3 2  2  6
+--R                  (8A a b + (16A C - 48A B )a )c
+--R                + 
+--R                          5 3         4       3 2    2         3 2      2 2   2
+--R                      - 2A b  + (- 36A C + 12A B )a b  + (- 48A C  + 72A B C)a b
+--R                    + 
+--R                           2 2 3
+--R                      48A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        4   4       3 2      2 2        4    3
+--R                      8A C b  + (60A C  - 18A B C - 8A B )a b
+--R                    + 
+--R                          2 3        2 2      4   2 2           4      2 3  3
+--R                      (40A C  - 60A B C  + 24B C)a b  + (- 24A C  - 40B C )a b
+--R                    + 
+--R                           5 4
+--R                      - 16C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            3 2       4  5         2 3        2 2     4     4
+--R                      (- 12A C  + 2A B )b  + (- 42A C  + 12A B C  - 6B C)a b
+--R                    + 
+--R                           4      2 3  2 3      5 3 2
+--R                      (6A C  + 26B C )a b  + 28C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                     2 3 6        4     2 3    5      5 2 4  2
+--R                  (8A C b  + (8A C  - 4B C )a b  - 14C a b )c
+--R                + 
+--R                         4 7     5   6
+--R                  (- 2A C b  + 2C a b )c
+--R             *
+--R                %%BK1
+--R            + 
+--R                        3 2 8        3   2       2   2          2 3  7
+--R                  - 256A a c  + (128A a b  + 640A C a b + 256A C a )c
+--R                + 
+--R                             3 4       2     3            2       2   2 2
+--R                        - 16A b  - 320A C a b  + (- 640A C  + 128B C)a b
+--R                      + 
+--R                              3 3
+--R                        - 128C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                      2   5          2      2     4       3 2 3  5
+--R                  (40A C b  + (272A C  - 64B C)a b  + 192C a b )c
+--R                + 
+--R                           2     2   6      3   5  4     3 7 3
+--R                  ((- 32A C  + 8B C)b  - 72C a b )c  + 8C b c
+--R             *
+--R                     3
+--R                %%BK0
+--R            + 
+--R                      3   2 7          3     2       2     2            2 3  6
+--R                  256A B a c  + (- 128A B a b  - 640A B C a b - 256A B C a )c
+--R                + 
+--R                         3   4       2       3            2       3   2 2
+--R                      16A B b  + 320A B C a b  + (640A B C  - 128B C)a b
+--R                    + 
+--R                            3 3
+--R                      128B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        2     5              2      3     4         3 2 3  4
+--R                  (- 40A B C b  + (- 272A B C  + 64B C)a b  - 192B C a b )c
+--R                + 
+--R                           2     3   6        3   5  3       3 7 2
+--R                  ((32A B C  - 8B C)b  + 72B C a b )c  - 8B C b c
+--R             *
+--R                     2
+--R                %%BK0
+--R            + 
+--R                      5          4       3 2  2  6
+--R                  (16A a b + (64A C - 96A B )a )c
+--R                + 
+--R                          5 3         4       3 2    2
+--R                      - 4A b  + (- 88A C + 40A B )a b
+--R                    + 
+--R                             3 2       2 2   2          2 3        2 2  3
+--R                      (- 224A C  + 240A B C)a b + (- 64A C  + 96A B C )a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4      3 2  4        3 2       2 2     3
+--R                      (18A C - 4A B )b  + (184A C  - 108A B C)a b
+--R                    + 
+--R                           2 3         2 2      4   2 2         4      2 3  3
+--R                      (304A C  - 264A B C  + 48B C)a b  + (80A C  - 48B C )a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            3 2      2 2   5
+--R                      (- 32A C  + 12A B C)b
+--R                    + 
+--R                             2 3         2 2      4     4
+--R                      (- 184A C  + 108A B C  - 20B C)a b
+--R                    + 
+--R                               4      2 3  2 3      5 3 2
+--R                      (- 180A C  + 92B C )a b  - 24C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          2 3        2 2     4   6         4      2 3    5
+--R                      (28A C  - 12A B C  + 2B C)b  + (88A C  - 36B C )a b
+--R                    + 
+--R                         5 2 4
+--R                      38C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                           4     2 3  7      5   6       5 8
+--R                  ((- 12A C  + 4B C )b  - 16C a b )c + 2C b
+--R             *
+--R                %%BK0
+--R            + 
+--R                    6   6       6 2      5          4 2 2  5
+--R                  4A a c  + (- A b  - 20A C a b - 4A C a )c
+--R                + 
+--R                         5      4 2  3       4 2     3 2     2     3 3 2
+--R                      (5A C - 2A B )b  + (41A C  - 8A B C)a b  + 8A C a b
+--R                    + 
+--R                          2 4 3
+--R                      - 4A C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4  4         3 3      2 2 2    3
+--R                      (- 10A C  + 6A B C - A B )b  + (- 42A C  + 12A B C )a b
+--R                    + 
+--R                        2 4       2 3  2 2        5 3      6 4
+--R                      (A C  - 8A B C )a b  + 12A C a b + 4C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4   5
+--R                      (10A C  - 6A B C  + A B C)b
+--R                    + 
+--R                          2 4       2 3    4 2    4           5     2 4  2 3
+--R                      (20A C  - 2A B C  - B C )a b  + (- 11A C  + 6B C )a b
+--R                    + 
+--R                          6 3 2
+--R                      - 9C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3  6          5     2 4    5     6 2 4
+--R                  ((- 5A C  + 2A B C )b  + (- 2A C  - 2B C )a b  + 6C a b )c
+--R                + 
+--R                     5 7    6   6
+--R                  A C b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                   5              4         3 3  2  5
+--R              (- 4A B a b + (- 20A B C + 12A B )a )c
+--R            + 
+--R                      4        3 3    2       3   2      2 3   2
+--R                  (15A B C - 3A B )a b  + (52A B C  - 24A B C)a b
+--R                + 
+--R                      2   3        3 2  3
+--R                  (16A B C  - 12A B C )a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                        3   2     2 3       5    3
+--R                  (- 23A B C  + 6A B C + A B )a b
+--R                + 
+--R                        2   3        3 2     5   2 2             4     3 3  3
+--R                  (- 56A B C  + 27A B C  - 6B C)a b  + (- 16A B C  + 8B C )a b
+--R                + 
+--R                      5 4
+--R                  4B C a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                      2   3       3 2    5     4           4      3 3  2 3
+--R                  (18A B C  - 6A B C  + B C)a b  + (27A B C  - 10B C )a b
+--R                + 
+--R                     5 3 2
+--R                  B C a b
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                        4     3 3    5       5 2 4        5   6
+--R              ((- 7A B C  + 2B C )a b  - 4B C a b )c + B C a b
+--R     + 
+--R         2c %%BK0
+--R      *
+--R         log
+--R                      3 2 8          3   2       2   2          2 3  7
+--R                  256A a c  + (- 128A a b  - 640A C a b - 256A C a )c
+--R                + 
+--R                      3 4       2     3          2       2   2 2       3 3   6
+--R                  (16A b  + 320A C a b  + (640A C  - 128B C)a b  + 128C a b)c
+--R                + 
+--R                        2   5            2      2     4       3 2 3  5
+--R                  (- 40A C b  + (- 272A C  + 64B C)a b  - 192C a b )c
+--R                + 
+--R                         2     2   6      3   5  4     3 7 3
+--R                  ((32A C  - 8B C)b  + 72C a b )c  - 8C b c
+--R             *
+--R                     3
+--R                %%BK0
+--R            + 
+--R                        3   2 7        3     2       2     2            2 3  6
+--R                  - 192A B a c  + (128A B a b  + 576A B C a b + 192A B C a )c
+--R                + 
+--R                           3   4          2           3    3
+--R                      - 20A B b  + (- 336A B C + 16A B )a b
+--R                    + 
+--R                                 2      3   2 2        3 3
+--R                      (- 576A B C  + 96B C)a b  - 64B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            2          3  5            2      3     4
+--R                        (48A B C - 4A B )b  + (276A B C  - 56B C)a b
+--R                      + 
+--R                              3 2 3
+--R                        144B C a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                             2     3   6        3   5  3       3 7 2
+--R                  ((- 36A B C  + 8B C)b  - 64B C a b )c  + 8B C b c
+--R             *
+--R                     2
+--R                %%BK0
+--R            + 
+--R                       5            4       3 2  2  6
+--R                  (- 8A a b + (- 48A C + 48A B )a )c
+--R                + 
+--R                        5 3       4       3 2    2        3 2       2 2   2
+--R                      2A b  + (52A C - 28A B )a b  + (176A C  - 168A B C)a b
+--R                    + 
+--R                          2 3        2 2  3
+--R                      (64A C  - 48A B C )a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4      3 2  4          3 2      2 2        4    3
+--R                      (- 10A C + 4A B )b  + (- 124A C  + 90A B C - 8A B )a b
+--R                    + 
+--R                             2 3         2 2      4   2 2
+--R                      (- 264A C  + 204A B C  - 24B C)a b
+--R                    + 
+--R                               4     2 3  3       5 4
+--R                      (- 104A C  + 8B C )a b - 16C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                          3 2      2 2        4  5
+--R                      (20A C  - 12A B C + 2A B )b
+--R                    + 
+--R                           2 3        2 2      4     4          4      2 3  2 3
+--R                      (142A C  - 96A B C  + 14B C)a b  + (186A C  - 66B C )a b
+--R                    + 
+--R                         5 3 2
+--R                      52C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            2 3        2 2     4   6           4      2 3    5
+--R                      (- 20A C  + 12A B C  - 2B C)b  + (- 80A C  + 32B C )a b
+--R                    + 
+--R                           5 2 4
+--R                      - 52C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         4     2 3  7      5   6       5 8
+--R                  ((10A C  - 4B C )b  + 18C a b )c - 2C b
+--R             *
+--R                %%BK0
+--R            + 
+--R                    6   6       6 2      5          4 2 2  5
+--R                  4A a c  + (- A b  - 20A C a b - 4A C a )c
+--R                + 
+--R                         5      4 2  3       4 2     3 2     2     3 3 2
+--R                      (5A C - 2A B )b  + (41A C  - 8A B C)a b  + 8A C a b
+--R                    + 
+--R                          2 4 3
+--R                      - 4A C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4  4         3 3      2 2 2    3
+--R                      (- 10A C  + 6A B C - A B )b  + (- 42A C  + 12A B C )a b
+--R                    + 
+--R                        2 4       2 3  2 2        5 3      6 4
+--R                      (A C  - 8A B C )a b  + 12A C a b + 4C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4   5
+--R                      (10A C  - 6A B C  + A B C)b
+--R                    + 
+--R                          2 4       2 3    4 2    4           5     2 4  2 3
+--R                      (20A C  - 2A B C  - B C )a b  + (- 11A C  + 6B C )a b
+--R                    + 
+--R                          6 3 2
+--R                      - 9C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3  6          5     2 4    5     6 2 4
+--R                  ((- 5A C  + 2A B C )b  + (- 2A C  - 2B C )a b  + 6C a b )c
+--R                + 
+--R                     5 7    6   6
+--R                  A C b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                   5            4        3 3  2  5
+--R              (- 4A B a b + (12A B C - 4A B )a )c
+--R            + 
+--R                     4       3 3    2         3   2      2 3   2
+--R                  (7A B C + A B )a b  + (- 44A B C  + 16A B C)a b
+--R                + 
+--R                        2   3       3 2  3
+--R                  (- 16A B C  + 4A B C )a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                    3   2     2 3       5    3
+--R                  (A B C  - 4A B C + A B )a b
+--R                + 
+--R                      2   3        3 2     5   2 2          4 3        5 4
+--R                  (56A B C  - 25A B C  + 2B C)a b  + 16A B C a b + 4B C a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                       2   3       3 2    5     4             4     3 3  2 3
+--R                  (- 8A B C  + 6A B C  - B C)a b  + (- 29A B C  + 8B C )a b
+--R                + 
+--R                        5 3 2
+--R                  - 7B C a b
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                      4     3 3    5       5 2 4        5   6
+--R              ((5A B C  - 2B C )a b  + 6B C a b )c - B C a b
+--R     + 
+--R       2C x
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 486
+
+--S 487 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      +--------------------+
+--R                    +-----------+     |   +-----------+
+--R                +-+ |          2  +-+ |   |          2
+--R             2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R          *
+--R              +------------------+
+--R              | +-----------+
+--R              | |          2
+--R             \|\|- 4a c + b   + b
+--R          *
+--R             ROOT
+--R                            4     2 3      2
+--R                    (- 12a c  + 3b c )%%BK1
+--R                  + 
+--R                            4     2 3               3       2 2
+--R                    ((- 8a c  + 2b c )%%BK0 + 8B a c  - 2B b c )%%BK1
+--R                  + 
+--R                            4     2 3      2          3       2 2
+--R                    (- 12a c  + 3b c )%%BK0  + (8B a c  - 2B b c )%%BK0
+--R                  + 
+--R                      2              2    2            2     2         2 3
+--R                    (A b + (4A C - 2B )a)c  + (- 2A C b  - 3C a b)c + C b
+--R               /
+--R                      4    2 3
+--R                  4a c  - b c
+--R         + 
+--R           -
+--R                                         +--------------------+
+--R                       +-----------+     |   +-----------+
+--R                   +-+ |          2  +-+ |   |          2
+--R                2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b %%BK1
+--R         + 
+--R                       +-----------+                   +-----------+
+--R                   +-+ |          2  +-+           +-+ |          2  +-+
+--R             (- 2c\|2 \|- 4a c + b  \|c %%BK0 + 2B\|2 \|- 4a c + b  \|c )
+--R          *
+--R              +--------------------+ +------------------+
+--R              |   +-----------+      | +-----------+
+--R              |   |          2       | |          2
+--R             \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              3 2 8         3   2       2   2          2 3  7
+--R                          128A a c  + (- 64A a b  - 320A C a b - 128A C a )c
+--R                        + 
+--R                                3 4       2     3          2      2   2 2
+--R                              8A b  + 160A C a b  + (320A C  - 64B C)a b
+--R                            + 
+--R                                 3 3
+--R                              64C a b
+--R                         *
+--R                             6
+--R                            c
+--R                        + 
+--R                                2   5            2      2     4      3 2 3  5
+--R                          (- 20A C b  + (- 136A C  + 32B C)a b  - 96C a b )c
+--R                        + 
+--R                                 2     2   6      3   5  4     3 7 3
+--R                          ((16A C  - 4B C)b  + 36C a b )c  - 4C b c
+--R                     *
+--R                        %%BK0
+--R                    + 
+--R                           3   2 7       2     2           2 3  6
+--R                      - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                    + 
+--R                            3   4      2          3    3
+--R                          2A B b  + (8A B C - 8A B )a b
+--R                        + 
+--R                                    2      3   2 2        3 3
+--R                          (- 32A B C  + 16B C)a b  - 32B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                               2          3  5            2     3     4
+--R                          (- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b
+--R                        + 
+--R                               3 2 3
+--R                          24B C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             2 6       3   5  3
+--R                      (2A B C b  - 4B C a b )c
+--R                 *
+--R                    %%BK1
+--R                + 
+--R                           3   2 7       2     2           2 3  6
+--R                      - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                    + 
+--R                            3   4      2          3    3
+--R                          2A B b  + (8A B C - 8A B )a b
+--R                        + 
+--R                                    2      3   2 2        3 3
+--R                          (- 32A B C  + 16B C)a b  - 32B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                               2          3  5            2     3     4
+--R                          (- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b
+--R                        + 
+--R                               3 2 3
+--R                          24B C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             2 6       3   5  3
+--R                      (2A B C b  - 4B C a b )c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                     5         4      3 2  2  6
+--R                  (4A a b + (8A C + 8A B )a )c
+--R                + 
+--R                         5 3         4      3 2    2         3 2     2 2   2
+--R                      - A b  + (- 18A C + 6A B )a b  + (- 24A C  + 4A B C)a b
+--R                    + 
+--R                            2 2 3
+--R                      - 8A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         4      3 2  4       3 2      2 2        4    3
+--R                      (4A C - 2A B )b  + (30A C  - 17A B C + 4A B )a b
+--R                    + 
+--R                          2 3       2 2     4   2 2           4      2 3  3
+--R                      (20A C  + 2A B C  - 4B C)a b  + (- 12A C  + 12B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           3 2     2 2       4  5
+--R                      (- 6A C  + 4A B C - A B )b
+--R                    + 
+--R                            2 3       2 2    4     4        4      2 3  2 3
+--R                      (- 21A C  + 8A B C  + B C)a b  + (3A C  - 11B C )a b
+--R                    + 
+--R                         5 3 2
+--R                      14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                      2 3       2 2  6        4     2 3    5     5 2 4  2
+--R                  ((4A C  - 2A B C )b  + (4A C  + 2B C )a b  - 7C a b )c
+--R                + 
+--R                        4 7    5   6
+--R                  (- A C b  + C a b )c
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BK1
+--R                     + 
+--R                               4     2 3               3       2 2
+--R                       ((- 8a c  + 2b c )%%BK0 + 8B a c  - 2B b c )%%BK1
+--R                     + 
+--R                               4     2 3      2          3       2 2
+--R                       (- 12a c  + 3b c )%%BK0  + (8B a c  - 2B b c )%%BK0
+--R                     + 
+--R                         2              2    2            2     2         2 3
+--R                       (A b + (4A C - 2B )a)c  + (- 2A C b  - 3C a b)c + C b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R            + 
+--R                          3 2 8         3   2       2   2          2 3  7
+--R                      128A a c  + (- 64A a b  - 320A C a b - 128A C a )c
+--R                    + 
+--R                         3 4       2     3          2      2   2 2      3 3   6
+--R                      (8A b  + 160A C a b  + (320A C  - 64B C)a b  + 64C a b)c
+--R                    + 
+--R                            2   5            2      2     4      3 2 3  5
+--R                      (- 20A C b  + (- 136A C  + 32B C)a b  - 96C a b )c
+--R                    + 
+--R                             2     2   6      3   5  4     3 7 3
+--R                      ((16A C  - 4B C)b  + 36C a b )c  - 4C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                       3   2 7       2     2           2 3  6
+--R                  - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                + 
+--R                        3   4      2          3    3             2      3   2 2
+--R                      2A B b  + (8A B C - 8A B )a b  + (- 32A B C  + 16B C)a b
+--R                    + 
+--R                             3 3
+--R                      - 32B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        2          3  5            2     3     4        3 2 3  4
+--R                  ((- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b  + 24B C a b )c
+--R                + 
+--R                         2 6       3   5  3
+--R                  (2A B C b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BK1
+--R            + 
+--R                          3 2 8         3   2       2   2          2 3  7
+--R                      128A a c  + (- 64A a b  - 320A C a b - 128A C a )c
+--R                    + 
+--R                         3 4       2     3          2      2   2 2      3 3   6
+--R                      (8A b  + 160A C a b  + (320A C  - 64B C)a b  + 64C a b)c
+--R                    + 
+--R                            2   5            2      2     4      3 2 3  5
+--R                      (- 20A C b  + (- 136A C  + 32B C)a b  - 96C a b )c
+--R                    + 
+--R                             2     2   6      3   5  4     3 7 3
+--R                      ((16A C  - 4B C)b  + 36C a b )c  - 4C b c
+--R                 *
+--R                         2
+--R                    %%BK0
+--R                + 
+--R                            3   2 7
+--R                      - 128A B a c
+--R                    + 
+--R                          3     2       2     2            2 3  6
+--R                      (64A B a b  + 320A B C a b + 128A B C a )c
+--R                    + 
+--R                              3   4       2       3              2      3   2 2
+--R                          - 8A B b  - 160A B C a b  + (- 320A B C  + 64B C)a b
+--R                        + 
+--R                                 3 3
+--R                          - 64B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                          2     5            2      3     4        3 2 3  4
+--R                      (20A B C b  + (136A B C  - 32B C)a b  + 96B C a b )c
+--R                    + 
+--R                                 2     3   6        3   5  3       3 7 2
+--R                      ((- 16A B C  + 4B C)b  - 36B C a b )c  + 4B C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                       5           4       3 2  2  6
+--R                  (- 4A a b + (- 8A C + 24A B )a )c
+--R                + 
+--R                       5 3       4      3 2    2       3 2      2 2   2
+--R                      A b  + (18A C - 6A B )a b  + (24A C  - 36A B C)a b
+--R                    + 
+--R                             2 2 3
+--R                      - 24A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4   4         3 2     2 2        4    3
+--R                      - 4A C b  + (- 30A C  + 9A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   2 2         4      2 3  3
+--R                      (- 20A C  + 30A B C  - 12B C)a b  + (12A C  + 20B C )a b
+--R                    + 
+--R                        5 4
+--R                      8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 2      4  5       2 3       2 2     4     4
+--R                      (6A C  - A B )b  + (21A C  - 6A B C  + 3B C)a b
+--R                    + 
+--R                             4      2 3  2 3      5 3 2
+--R                      (- 3A C  - 13B C )a b  - 14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 3 6          4     2 3    5     5 2 4  2
+--R                  (- 4A C b  + (- 4A C  + 2B C )a b  + 7C a b )c
+--R                + 
+--R                      4 7    5   6
+--R                  (A C b  - C a b )c
+--R             *
+--R                %%BK1
+--R            + 
+--R                       3   2 7       2     2           2 3  6
+--R                  - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                + 
+--R                        3   4      2          3    3             2      3   2 2
+--R                      2A B b  + (8A B C - 8A B )a b  + (- 32A B C  + 16B C)a b
+--R                    + 
+--R                             3 3
+--R                      - 32B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        2          3  5            2     3     4        3 2 3  4
+--R                  ((- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b  + 24B C a b )c
+--R                + 
+--R                         2 6       3   5  3
+--R                  (2A B C b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BK0
+--R            + 
+--R                       5           4       3 2  2  6
+--R                  (- 4A a b + (- 8A C + 24A B )a )c
+--R                + 
+--R                       5 3       4      3 2    2       3 2      2 2   2
+--R                      A b  + (18A C - 6A B )a b  + (24A C  - 36A B C)a b
+--R                    + 
+--R                             2 2 3
+--R                      - 24A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4   4         3 2     2 2        4    3
+--R                      - 4A C b  + (- 30A C  + 9A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   2 2         4      2 3  3
+--R                      (- 20A C  + 30A B C  - 12B C)a b  + (12A C  + 20B C )a b
+--R                    + 
+--R                        5 4
+--R                      8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 2      4  5       2 3       2 2     4     4
+--R                      (6A C  - A B )b  + (21A C  - 6A B C  + 3B C)a b
+--R                    + 
+--R                             4      2 3  2 3      5 3 2
+--R                      (- 3A C  - 13B C )a b  - 14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 3 6          4     2 3    5     5 2 4  2
+--R                  (- 4A C b  + (- 4A C  + 2B C )a b  + 7C a b )c
+--R                + 
+--R                      4 7    5   6
+--R                  (A C b  - C a b )c
+--R             *
+--R                %%BK0
+--R            + 
+--R                    6   6       6 2      5          4 2 2  5
+--R                  4A a c  + (- A b  - 20A C a b - 4A C a )c
+--R                + 
+--R                         5      4 2  3       4 2     3 2     2     3 3 2
+--R                      (5A C - 2A B )b  + (41A C  - 8A B C)a b  + 8A C a b
+--R                    + 
+--R                          2 4 3
+--R                      - 4A C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4  4         3 3      2 2 2    3
+--R                      (- 10A C  + 6A B C - A B )b  + (- 42A C  + 12A B C )a b
+--R                    + 
+--R                        2 4       2 3  2 2        5 3      6 4
+--R                      (A C  - 8A B C )a b  + 12A C a b + 4C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4   5
+--R                      (10A C  - 6A B C  + A B C)b
+--R                    + 
+--R                          2 4       2 3    4 2    4           5     2 4  2 3
+--R                      (20A C  - 2A B C  - B C )a b  + (- 11A C  + 6B C )a b
+--R                    + 
+--R                          6 3 2
+--R                      - 9C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3  6          5     2 4    5     6 2 4
+--R                  ((- 5A C  + 2A B C )b  + (- 2A C  - 2B C )a b  + 6C a b )c
+--R                + 
+--R                     5 7    6   6
+--R                  A C b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                 5           4        3 3  2  5
+--R              (4A B a b + (4A B C - 4A B )a )c
+--R            + 
+--R                     4       3 3    2        3   2     2 3   2        3 2 3  4
+--R              ((- 11A B C + A B )a b  + (- 4A B C  + 4A B C)a b + 4A B C a )c
+--R            + 
+--R                      3   2    2 3       5    3         3 2     5   2 2
+--R                  (11A B C  - A B C - A B )a b  + (- A B C  + 2B C)a b
+--R                + 
+--R                      3 3 3        5 4
+--R                  - 4B C a b - 4B C a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                   2   3   4         4    3 3  2 3       5 3 2  2
+--R              (- 5A B C a b  + (A B C  + B C )a b  + 3B C a b )c
+--R            + 
+--R                    4   5      5 2 4
+--R              (A B C a b  - B C a b )c
+--R     + 
+--R           -
+--R                                         +--------------------+
+--R                       +-----------+     |   +-----------+
+--R                   +-+ |          2  +-+ |   |          2
+--R                2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BK1
+--R                     + 
+--R                               4     2 3               3       2 2
+--R                       ((- 8a c  + 2b c )%%BK0 + 8B a c  - 2B b c )%%BK1
+--R                     + 
+--R                               4     2 3      2          3       2 2
+--R                       (- 12a c  + 3b c )%%BK0  + (8B a c  - 2B b c )%%BK0
+--R                     + 
+--R                         2              2    2            2     2         2 3
+--R                       (A b + (4A C - 2B )a)c  + (- 2A C b  - 3C a b)c + C b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R         + 
+--R           -
+--R                                         +--------------------+
+--R                       +-----------+     |   +-----------+
+--R                   +-+ |          2  +-+ |   |          2
+--R                2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b %%BK1
+--R         + 
+--R                       +-----------+                   +-----------+
+--R                   +-+ |          2  +-+           +-+ |          2  +-+
+--R             (- 2c\|2 \|- 4a c + b  \|c %%BK0 + 2B\|2 \|- 4a c + b  \|c )
+--R          *
+--R              +--------------------+ +------------------+
+--R              |   +-----------+      | +-----------+
+--R              |   |          2       | |          2
+--R             \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                3 2 8       3   2       2   2          2 3  7
+--R                          - 128A a c  + (64A a b  + 320A C a b + 128A C a )c
+--R                        + 
+--R                                  3 4       2     3            2      2   2 2
+--R                              - 8A b  - 160A C a b  + (- 320A C  + 64B C)a b
+--R                            + 
+--R                                   3 3
+--R                              - 64C a b
+--R                         *
+--R                             6
+--R                            c
+--R                        + 
+--R                              2   5          2      2     4      3 2 3  5
+--R                          (20A C b  + (136A C  - 32B C)a b  + 96C a b )c
+--R                        + 
+--R                                   2     2   6      3   5  4     3 7 3
+--R                          ((- 16A C  + 4B C)b  - 36C a b )c  + 4C b c
+--R                     *
+--R                        %%BK0
+--R                    + 
+--R                         3   2 7         2     2           2 3  6
+--R                      32A B a c  + (- 32A B C a b - 32A B C a )c
+--R                    + 
+--R                              3   4        2          3    3
+--R                          - 2A B b  + (- 8A B C + 8A B )a b
+--R                        + 
+--R                                  2      3   2 2        3 3
+--R                          (32A B C  - 16B C)a b  + 32B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                          2          3  5          2     3     4        3 2 3  4
+--R                      ((4A B C - 2A B )b  + (2A B C  + 4B C)a b  - 24B C a b )c
+--R                    + 
+--R                               2 6       3   5  3
+--R                      (- 2A B C b  + 4B C a b )c
+--R                 *
+--R                    %%BK1
+--R                + 
+--R                         3   2 7         2     2           2 3  6
+--R                      32A B a c  + (- 32A B C a b - 32A B C a )c
+--R                    + 
+--R                              3   4        2          3    3
+--R                          - 2A B b  + (- 8A B C + 8A B )a b
+--R                        + 
+--R                                  2      3   2 2        3 3
+--R                          (32A B C  - 16B C)a b  + 32B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                          2          3  5          2     3     4        3 2 3  4
+--R                      ((4A B C - 2A B )b  + (2A B C  + 4B C)a b  - 24B C a b )c
+--R                    + 
+--R                               2 6       3   5  3
+--R                      (- 2A B C b  + 4B C a b )c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                       5           4      3 2  2  6
+--R                  (- 4A a b + (- 8A C - 8A B )a )c
+--R                + 
+--R                       5 3       4      3 2    2       3 2     2 2   2
+--R                      A b  + (18A C - 6A B )a b  + (24A C  - 4A B C)a b
+--R                    + 
+--R                          2 2 3
+--R                      8A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           4      3 2  4         3 2      2 2        4    3
+--R                      (- 4A C + 2A B )b  + (- 30A C  + 17A B C - 4A B )a b
+--R                    + 
+--R                            2 3       2 2     4   2 2         4      2 3  3
+--R                      (- 20A C  - 2A B C  + 4B C)a b  + (12A C  - 12B C )a b
+--R                    + 
+--R                        5 4
+--R                      8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 2     2 2       4  5       2 3       2 2    4     4
+--R                      (6A C  - 4A B C + A B )b  + (21A C  - 8A B C  - B C)a b
+--R                    + 
+--R                             4      2 3  2 3      5 3 2
+--R                      (- 3A C  + 11B C )a b  - 14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        2 3       2 2  6          4     2 3    5     5 2 4  2
+--R                  ((- 4A C  + 2A B C )b  + (- 4A C  - 2B C )a b  + 7C a b )c
+--R                + 
+--R                      4 7    5   6
+--R                  (A C b  - C a b )c
+--R             *
+--R                ROOT
+--R                               4     2 3      2
+--R                       (- 12a c  + 3b c )%%BK1
+--R                     + 
+--R                               4     2 3               3       2 2
+--R                       ((- 8a c  + 2b c )%%BK0 + 8B a c  - 2B b c )%%BK1
+--R                     + 
+--R                               4     2 3      2          3       2 2
+--R                       (- 12a c  + 3b c )%%BK0  + (8B a c  - 2B b c )%%BK0
+--R                     + 
+--R                         2              2    2            2     2         2 3
+--R                       (A b + (4A C - 2B )a)c  + (- 2A C b  - 3C a b)c + C b
+--R                  /
+--R                         4    2 3
+--R                     4a c  - b c
+--R            + 
+--R                          3 2 8         3   2       2   2          2 3  7
+--R                      128A a c  + (- 64A a b  - 320A C a b - 128A C a )c
+--R                    + 
+--R                         3 4       2     3          2      2   2 2      3 3   6
+--R                      (8A b  + 160A C a b  + (320A C  - 64B C)a b  + 64C a b)c
+--R                    + 
+--R                            2   5            2      2     4      3 2 3  5
+--R                      (- 20A C b  + (- 136A C  + 32B C)a b  - 96C a b )c
+--R                    + 
+--R                             2     2   6      3   5  4     3 7 3
+--R                      ((16A C  - 4B C)b  + 36C a b )c  - 4C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                       3   2 7       2     2           2 3  6
+--R                  - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                + 
+--R                        3   4      2          3    3             2      3   2 2
+--R                      2A B b  + (8A B C - 8A B )a b  + (- 32A B C  + 16B C)a b
+--R                    + 
+--R                             3 3
+--R                      - 32B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        2          3  5            2     3     4        3 2 3  4
+--R                  ((- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b  + 24B C a b )c
+--R                + 
+--R                         2 6       3   5  3
+--R                  (2A B C b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BK1
+--R            + 
+--R                          3 2 8         3   2       2   2          2 3  7
+--R                      128A a c  + (- 64A a b  - 320A C a b - 128A C a )c
+--R                    + 
+--R                         3 4       2     3          2      2   2 2      3 3   6
+--R                      (8A b  + 160A C a b  + (320A C  - 64B C)a b  + 64C a b)c
+--R                    + 
+--R                            2   5            2      2     4      3 2 3  5
+--R                      (- 20A C b  + (- 136A C  + 32B C)a b  - 96C a b )c
+--R                    + 
+--R                             2     2   6      3   5  4     3 7 3
+--R                      ((16A C  - 4B C)b  + 36C a b )c  - 4C b c
+--R                 *
+--R                         2
+--R                    %%BK0
+--R                + 
+--R                            3   2 7
+--R                      - 128A B a c
+--R                    + 
+--R                          3     2       2     2            2 3  6
+--R                      (64A B a b  + 320A B C a b + 128A B C a )c
+--R                    + 
+--R                              3   4       2       3              2      3   2 2
+--R                          - 8A B b  - 160A B C a b  + (- 320A B C  + 64B C)a b
+--R                        + 
+--R                                 3 3
+--R                          - 64B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                          2     5            2      3     4        3 2 3  4
+--R                      (20A B C b  + (136A B C  - 32B C)a b  + 96B C a b )c
+--R                    + 
+--R                                 2     3   6        3   5  3       3 7 2
+--R                      ((- 16A B C  + 4B C)b  - 36B C a b )c  + 4B C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                       5           4       3 2  2  6
+--R                  (- 4A a b + (- 8A C + 24A B )a )c
+--R                + 
+--R                       5 3       4      3 2    2       3 2      2 2   2
+--R                      A b  + (18A C - 6A B )a b  + (24A C  - 36A B C)a b
+--R                    + 
+--R                             2 2 3
+--R                      - 24A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4   4         3 2     2 2        4    3
+--R                      - 4A C b  + (- 30A C  + 9A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   2 2         4      2 3  3
+--R                      (- 20A C  + 30A B C  - 12B C)a b  + (12A C  + 20B C )a b
+--R                    + 
+--R                        5 4
+--R                      8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 2      4  5       2 3       2 2     4     4
+--R                      (6A C  - A B )b  + (21A C  - 6A B C  + 3B C)a b
+--R                    + 
+--R                             4      2 3  2 3      5 3 2
+--R                      (- 3A C  - 13B C )a b  - 14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 3 6          4     2 3    5     5 2 4  2
+--R                  (- 4A C b  + (- 4A C  + 2B C )a b  + 7C a b )c
+--R                + 
+--R                      4 7    5   6
+--R                  (A C b  - C a b )c
+--R             *
+--R                %%BK1
+--R            + 
+--R                       3   2 7       2     2           2 3  6
+--R                  - 32A B a c  + (32A B C a b + 32A B C a )c
+--R                + 
+--R                        3   4      2          3    3             2      3   2 2
+--R                      2A B b  + (8A B C - 8A B )a b  + (- 32A B C  + 16B C)a b
+--R                    + 
+--R                             3 3
+--R                      - 32B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        2          3  5            2     3     4        3 2 3  4
+--R                  ((- 4A B C + 2A B )b  + (- 2A B C  - 4B C)a b  + 24B C a b )c
+--R                + 
+--R                         2 6       3   5  3
+--R                  (2A B C b  - 4B C a b )c
+--R             *
+--R                     2
+--R                %%BK0
+--R            + 
+--R                       5           4       3 2  2  6
+--R                  (- 4A a b + (- 8A C + 24A B )a )c
+--R                + 
+--R                       5 3       4      3 2    2       3 2      2 2   2
+--R                      A b  + (18A C - 6A B )a b  + (24A C  - 36A B C)a b
+--R                    + 
+--R                             2 2 3
+--R                      - 24A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4   4         3 2     2 2        4    3
+--R                      - 4A C b  + (- 30A C  + 9A B C + 4A B )a b
+--R                    + 
+--R                            2 3        2 2      4   2 2         4      2 3  3
+--R                      (- 20A C  + 30A B C  - 12B C)a b  + (12A C  + 20B C )a b
+--R                    + 
+--R                        5 4
+--R                      8C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3 2      4  5       2 3       2 2     4     4
+--R                      (6A C  - A B )b  + (21A C  - 6A B C  + 3B C)a b
+--R                    + 
+--R                             4      2 3  2 3      5 3 2
+--R                      (- 3A C  - 13B C )a b  - 14C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 3 6          4     2 3    5     5 2 4  2
+--R                  (- 4A C b  + (- 4A C  + 2B C )a b  + 7C a b )c
+--R                + 
+--R                      4 7    5   6
+--R                  (A C b  - C a b )c
+--R             *
+--R                %%BK0
+--R            + 
+--R                    6   6       6 2      5          4 2 2  5
+--R                  4A a c  + (- A b  - 20A C a b - 4A C a )c
+--R                + 
+--R                         5      4 2  3       4 2     3 2     2     3 3 2
+--R                      (5A C - 2A B )b  + (41A C  - 8A B C)a b  + 8A C a b
+--R                    + 
+--R                          2 4 3
+--R                      - 4A C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4  4         3 3      2 2 2    3
+--R                      (- 10A C  + 6A B C - A B )b  + (- 42A C  + 12A B C )a b
+--R                    + 
+--R                        2 4       2 3  2 2        5 3      6 4
+--R                      (A C  - 8A B C )a b  + 12A C a b + 4C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4   5
+--R                      (10A C  - 6A B C  + A B C)b
+--R                    + 
+--R                          2 4       2 3    4 2    4           5     2 4  2 3
+--R                      (20A C  - 2A B C  - B C )a b  + (- 11A C  + 6B C )a b
+--R                    + 
+--R                          6 3 2
+--R                      - 9C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3  6          5     2 4    5     6 2 4
+--R                  ((- 5A C  + 2A B C )b  + (- 2A C  - 2B C )a b  + 6C a b )c
+--R                + 
+--R                     5 7    6   6
+--R                  A C b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                 5           4        3 3  2  5
+--R              (4A B a b + (4A B C - 4A B )a )c
+--R            + 
+--R                     4       3 3    2        3   2     2 3   2        3 2 3  4
+--R              ((- 11A B C + A B )a b  + (- 4A B C  + 4A B C)a b + 4A B C a )c
+--R            + 
+--R                      3   2    2 3       5    3         3 2     5   2 2
+--R                  (11A B C  - A B C - A B )a b  + (- A B C  + 2B C)a b
+--R                + 
+--R                      3 3 3        5 4
+--R                  - 4B C a b - 4B C a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                   2   3   4         4    3 3  2 3       5 3 2  2
+--R              (- 5A B C a b  + (A B C  + B C )a b  + 3B C a b )c
+--R            + 
+--R                    4   5      5 2 4
+--R              (A B C a b  - B C a b )c
+--R     + 
+--R                                  +--------------------+ +------------------+
+--R                +-----------+     |   +-----------+      | +-----------+
+--R            +-+ |          2  +-+ |   |          2       | |          2
+--R         4c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         %%BK1
+--R      *
+--R         log
+--R                            3 2 8        3   2       2   2          2 3  7
+--R                      - 256A a c  + (128A a b  + 640A C a b + 256A C a )c
+--R                    + 
+--R                               3 4       2     3            2       2   2 2
+--R                          - 16A b  - 320A C a b  + (- 640A C  + 128B C)a b
+--R                        + 
+--R                                3 3
+--R                          - 128C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                          2   5          2      2     4       3 2 3  5
+--R                      (40A C b  + (272A C  - 64B C)a b  + 192C a b )c
+--R                    + 
+--R                               2     2   6      3   5  4     3 7 3
+--R                      ((- 32A C  + 8B C)b  - 72C a b )c  + 8C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                     3   2 7         2     2           2 3  6
+--R                  64A B a c  + (- 64A B C a b - 64A B C a )c
+--R                + 
+--R                          3   4         2           3    3
+--R                      - 4A B b  + (- 16A B C + 16A B )a b
+--R                    + 
+--R                              2      3   2 2        3 3
+--R                      (64A B C  - 32B C)a b  + 64B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                      2          3  5          2     3     4        3 2 3  4
+--R                  ((8A B C - 4A B )b  + (4A B C  + 8B C)a b  - 48B C a b )c
+--R                + 
+--R                           2 6       3   5  3
+--R                  (- 4A B C b  + 8B C a b )c
+--R             *
+--R                     2
+--R                %%BK1
+--R            + 
+--R                            3 2 8        3   2       2   2          2 3  7
+--R                      - 256A a c  + (128A a b  + 640A C a b + 256A C a )c
+--R                    + 
+--R                               3 4       2     3            2       2   2 2
+--R                          - 16A b  - 320A C a b  + (- 640A C  + 128B C)a b
+--R                        + 
+--R                                3 3
+--R                          - 128C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                          2   5          2      2     4       3 2 3  5
+--R                      (40A C b  + (272A C  - 64B C)a b  + 192C a b )c
+--R                    + 
+--R                               2     2   6      3   5  4     3 7 3
+--R                      ((- 32A C  + 8B C)b  - 72C a b )c  + 8C b c
+--R                 *
+--R                         2
+--R                    %%BK0
+--R                + 
+--R                          3   2 7
+--R                      256A B a c
+--R                    + 
+--R                             3     2       2     2            2 3  6
+--R                      (- 128A B a b  - 640A B C a b - 256A B C a )c
+--R                    + 
+--R                             3   4       2       3            2       3   2 2
+--R                          16A B b  + 320A B C a b  + (640A B C  - 128B C)a b
+--R                        + 
+--R                                3 3
+--R                          128B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                            2     5              2      3     4         3 2 3  4
+--R                      (- 40A B C b  + (- 272A B C  + 64B C)a b  - 192B C a b )c
+--R                    + 
+--R                               2     3   6        3   5  3       3 7 2
+--R                      ((32A B C  - 8B C)b  + 72B C a b )c  - 8B C b c
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                     5          4       3 2  2  6
+--R                  (8A a b + (16A C - 48A B )a )c
+--R                + 
+--R                          5 3         4       3 2    2         3 2      2 2   2
+--R                      - 2A b  + (- 36A C + 12A B )a b  + (- 48A C  + 72A B C)a b
+--R                    + 
+--R                           2 2 3
+--R                      48A B C a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        4   4       3 2      2 2        4    3
+--R                      8A C b  + (60A C  - 18A B C - 8A B )a b
+--R                    + 
+--R                          2 3        2 2      4   2 2           4      2 3  3
+--R                      (40A C  - 60A B C  + 24B C)a b  + (- 24A C  - 40B C )a b
+--R                    + 
+--R                           5 4
+--R                      - 16C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            3 2       4  5         2 3        2 2     4     4
+--R                      (- 12A C  + 2A B )b  + (- 42A C  + 12A B C  - 6B C)a b
+--R                    + 
+--R                           4      2 3  2 3      5 3 2
+--R                      (6A C  + 26B C )a b  + 28C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                     2 3 6        4     2 3    5      5 2 4  2
+--R                  (8A C b  + (8A C  - 4B C )a b  - 14C a b )c
+--R                + 
+--R                         4 7     5   6
+--R                  (- 2A C b  + 2C a b )c
+--R             *
+--R                %%BK1
+--R            + 
+--R                        3 2 8        3   2       2   2          2 3  7
+--R                  - 256A a c  + (128A a b  + 640A C a b + 256A C a )c
+--R                + 
+--R                             3 4       2     3            2       2   2 2
+--R                        - 16A b  - 320A C a b  + (- 640A C  + 128B C)a b
+--R                      + 
+--R                              3 3
+--R                        - 128C a b
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                      2   5          2      2     4       3 2 3  5
+--R                  (40A C b  + (272A C  - 64B C)a b  + 192C a b )c
+--R                + 
+--R                           2     2   6      3   5  4     3 7 3
+--R                  ((- 32A C  + 8B C)b  - 72C a b )c  + 8C b c
+--R             *
+--R                     3
+--R                %%BK0
+--R            + 
+--R                      3   2 7          3     2       2     2            2 3  6
+--R                  256A B a c  + (- 128A B a b  - 640A B C a b - 256A B C a )c
+--R                + 
+--R                         3   4       2       3            2       3   2 2
+--R                      16A B b  + 320A B C a b  + (640A B C  - 128B C)a b
+--R                    + 
+--R                            3 3
+--R                      128B C a b
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        2     5              2      3     4         3 2 3  4
+--R                  (- 40A B C b  + (- 272A B C  + 64B C)a b  - 192B C a b )c
+--R                + 
+--R                           2     3   6        3   5  3       3 7 2
+--R                  ((32A B C  - 8B C)b  + 72B C a b )c  - 8B C b c
+--R             *
+--R                     2
+--R                %%BK0
+--R            + 
+--R                      5          4       3 2  2  6
+--R                  (16A a b + (64A C - 96A B )a )c
+--R                + 
+--R                          5 3         4       3 2    2
+--R                      - 4A b  + (- 88A C + 40A B )a b
+--R                    + 
+--R                             3 2       2 2   2          2 3        2 2  3
+--R                      (- 224A C  + 240A B C)a b + (- 64A C  + 96A B C )a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          4      3 2  4        3 2       2 2     3
+--R                      (18A C - 4A B )b  + (184A C  - 108A B C)a b
+--R                    + 
+--R                           2 3         2 2      4   2 2         4      2 3  3
+--R                      (304A C  - 264A B C  + 48B C)a b  + (80A C  - 48B C )a b
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            3 2      2 2   5
+--R                      (- 32A C  + 12A B C)b
+--R                    + 
+--R                             2 3         2 2      4     4
+--R                      (- 184A C  + 108A B C  - 20B C)a b
+--R                    + 
+--R                               4      2 3  2 3      5 3 2
+--R                      (- 180A C  + 92B C )a b  - 24C a b
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          2 3        2 2     4   6         4      2 3    5
+--R                      (28A C  - 12A B C  + 2B C)b  + (88A C  - 36B C )a b
+--R                    + 
+--R                         5 2 4
+--R                      38C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                           4     2 3  7      5   6       5 8
+--R                  ((- 12A C  + 4B C )b  - 16C a b )c + 2C b
+--R             *
+--R                %%BK0
+--R            + 
+--R                    6   6       6 2      5          4 2 2  5
+--R                  4A a c  + (- A b  - 20A C a b - 4A C a )c
+--R                + 
+--R                         5      4 2  3       4 2     3 2     2     3 3 2
+--R                      (5A C - 2A B )b  + (41A C  - 8A B C)a b  + 8A C a b
+--R                    + 
+--R                          2 4 3
+--R                      - 4A C a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                            4 2     3 2     2 4  4         3 3      2 2 2    3
+--R                      (- 10A C  + 6A B C - A B )b  + (- 42A C  + 12A B C )a b
+--R                    + 
+--R                        2 4       2 3  2 2        5 3      6 4
+--R                      (A C  - 8A B C )a b  + 12A C a b + 4C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          3 3     2 2 2      4   5
+--R                      (10A C  - 6A B C  + A B C)b
+--R                    + 
+--R                          2 4       2 3    4 2    4           5     2 4  2 3
+--R                      (20A C  - 2A B C  - B C )a b  + (- 11A C  + 6B C )a b
+--R                    + 
+--R                          6 3 2
+--R                      - 9C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 4       2 3  6          5     2 4    5     6 2 4
+--R                  ((- 5A C  + 2A B C )b  + (- 2A C  - 2B C )a b  + 6C a b )c
+--R                + 
+--R                     5 7    6   6
+--R                  A C b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                   5              4         3 3  2  5
+--R              (- 4A B a b + (- 20A B C + 12A B )a )c
+--R            + 
+--R                      4        3 3    2       3   2      2 3   2
+--R                  (15A B C - 3A B )a b  + (52A B C  - 24A B C)a b
+--R                + 
+--R                      2   3        3 2  3
+--R                  (16A B C  - 12A B C )a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                        3   2     2 3       5    3
+--R                  (- 23A B C  + 6A B C + A B )a b
+--R                + 
+--R                        2   3        3 2     5   2 2             4     3 3  3
+--R                  (- 56A B C  + 27A B C  - 6B C)a b  + (- 16A B C  + 8B C )a b
+--R                + 
+--R                      5 4
+--R                  4B C a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                      2   3       3 2    5     4           4      3 3  2 3
+--R                  (18A B C  - 6A B C  + B C)a b  + (27A B C  - 10B C )a b
+--R                + 
+--R                     5 3 2
+--R                  B C a b
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                        4     3 3    5       5 2 4        5   6
+--R              ((- 7A B C  + 2B C )a b  - 4B C a b )c + B C a b
+--R     + 
+--R                          +-----------+
+--R                          |          2                         2
+--R         ((- 4A c + 4C b)\|- 4a c + b   + (4A b + 8C a)c - 4C b )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                          |          2                           2
+--R         ((- 4A c + 4C b)\|- 4a c + b   + (- 4A b - 8C a)c + 4C b )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                    +-----------+
+--R                +-+ |          2  +-+
+--R             4c\|2 \|- 4a c + b  \|c %%BK0
+--R          *
+--R             log
+--R                          3 2 8          3   2       2   2          2 3  7
+--R                      256A a c  + (- 128A a b  - 640A C a b - 256A C a )c
+--R                    + 
+--R                               3 4       2     3          2       2   2 2
+--R                            16A b  + 320A C a b  + (640A C  - 128B C)a b
+--R                          + 
+--R                                3 3
+--R                            128C a b
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            2   5            2      2     4       3 2 3  5
+--R                      (- 40A C b  + (- 272A C  + 64B C)a b  - 192C a b )c
+--R                    + 
+--R                             2     2   6      3   5  4     3 7 3
+--R                      ((32A C  - 8B C)b  + 72C a b )c  - 8C b c
+--R                 *
+--R                         3
+--R                    %%BK0
+--R                + 
+--R                            3   2 7
+--R                      - 192A B a c
+--R                    + 
+--R                           3     2       2     2            2 3  6
+--R                      (128A B a b  + 576A B C a b + 192A B C a )c
+--R                    + 
+--R                               3   4          2           3    3
+--R                          - 20A B b  + (- 336A B C + 16A B )a b
+--R                        + 
+--R                                     2      3   2 2        3 3
+--R                          (- 576A B C  + 96B C)a b  - 64B C a b
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                              2          3  5            2      3     4
+--R                          (48A B C - 4A B )b  + (276A B C  - 56B C)a b
+--R                        + 
+--R                                3 2 3
+--R                          144B C a b
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                 2     3   6        3   5  3       3 7 2
+--R                      ((- 36A B C  + 8B C)b  - 64B C a b )c  + 8B C b c
+--R                 *
+--R                         2
+--R                    %%BK0
+--R                + 
+--R                           5            4       3 2  2  6
+--R                      (- 8A a b + (- 48A C + 48A B )a )c
+--R                    + 
+--R                            5 3       4       3 2    2        3 2       2 2   2
+--R                          2A b  + (52A C - 28A B )a b  + (176A C  - 168A B C)a b
+--R                        + 
+--R                              2 3        2 2  3
+--R                          (64A C  - 48A B C )a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                4      3 2  4
+--R                          (- 10A C + 4A B )b
+--R                        + 
+--R                                 3 2      2 2        4    3
+--R                          (- 124A C  + 90A B C - 8A B )a b
+--R                        + 
+--R                                 2 3         2 2      4   2 2
+--R                          (- 264A C  + 204A B C  - 24B C)a b
+--R                        + 
+--R                                   4     2 3  3       5 4
+--R                          (- 104A C  + 8B C )a b - 16C a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                              3 2      2 2        4  5
+--R                          (20A C  - 12A B C + 2A B )b
+--R                        + 
+--R                               2 3        2 2      4     4
+--R                          (142A C  - 96A B C  + 14B C)a b
+--R                        + 
+--R                                 4      2 3  2 3      5 3 2
+--R                          (186A C  - 66B C )a b  + 52C a b
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                2 3        2 2     4   6
+--R                          (- 20A C  + 12A B C  - 2B C)b
+--R                        + 
+--R                                  4      2 3    5      5 2 4
+--R                          (- 80A C  + 32B C )a b  - 52C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             4     2 3  7      5   6       5 8
+--R                      ((10A C  - 4B C )b  + 18C a b )c - 2C b
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                        6   6       6 2      5          4 2 2  5
+--R                      4A a c  + (- A b  - 20A C a b - 4A C a )c
+--R                    + 
+--R                             5      4 2  3       4 2     3 2     2     3 3 2
+--R                          (5A C - 2A B )b  + (41A C  - 8A B C)a b  + 8A C a b
+--R                        + 
+--R                              2 4 3
+--R                          - 4A C a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                4 2     3 2     2 4  4
+--R                          (- 10A C  + 6A B C - A B )b
+--R                        + 
+--R                                3 3      2 2 2    3     2 4       2 3  2 2
+--R                          (- 42A C  + 12A B C )a b  + (A C  - 8A B C )a b
+--R                        + 
+--R                               5 3      6 4
+--R                          12A C a b + 4C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3 3     2 2 2      4   5
+--R                          (10A C  - 6A B C  + A B C)b
+--R                        + 
+--R                              2 4       2 3    4 2    4           5     2 4  2 3
+--R                          (20A C  - 2A B C  - B C )a b  + (- 11A C  + 6B C )a b
+--R                        + 
+--R                              6 3 2
+--R                          - 9C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                            2 4       2 3  6          5     2 4    5     6 2 4
+--R                      ((- 5A C  + 2A B C )b  + (- 2A C  - 2B C )a b  + 6C a b )c
+--R                    + 
+--R                         5 7    6   6
+--R                      A C b  - C a b
+--R                 *
+--R                    x
+--R                + 
+--R                       5            4        3 3  2  5
+--R                  (- 4A B a b + (12A B C - 4A B )a )c
+--R                + 
+--R                         4       3 3    2         3   2      2 3   2
+--R                      (7A B C + A B )a b  + (- 44A B C  + 16A B C)a b
+--R                    + 
+--R                            2   3       3 2  3
+--R                      (- 16A B C  + 4A B C )a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                        3   2     2 3       5    3
+--R                      (A B C  - 4A B C + A B )a b
+--R                    + 
+--R                          2   3        3 2     5   2 2          4 3        5 4
+--R                      (56A B C  - 25A B C  + 2B C)a b  + 16A B C a b + 4B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           2   3       3 2    5     4             4     3 3  2 3
+--R                      (- 8A B C  + 6A B C  - B C)a b  + (- 29A B C  + 8B C )a b
+--R                    + 
+--R                            5 3 2
+--R                      - 7B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          4     3 3    5       5 2 4        5   6
+--R                  ((5A B C  - 2B C )a b  + 6B C a b )c - B C a b
+--R         + 
+--R                                      2
+--R                  +-+ +-+         2c x  + b
+--R           - 2B b\|2 \|c atanh(--------------)
+--R                                +-----------+
+--R                                |          2
+--R                               \|- 4a c + b
+--R         + 
+--R                                       +-----------+
+--R               +-+       4      2      |          2  +-+
+--R           - B\|2 log(c x  + b x  + a)\|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     4c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 488
+
+)clear all
+
+--S 489 of 1070
+t0:=x*(A+B*x+C*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           3      2
+--R        C x  + B x  + A x
+--R   (1)  -----------------
+--R            4      2
+--R         c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 489
+
+--S 490 of 1070
+r0:=1/4*C*log(a+b*x^2+c*x^4)/c-1/2*(2*A*c-b*C)*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(c*sqrt(b^2-4*a*c))-B*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(b-sqrt(b^2-4*a*c))/(sqrt(2)*_
+   sqrt(c)*sqrt(b^2-4*a*c))+B*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R              +--------------------+
+--R              |   +-----------+                   +-+ +-+
+--R              |   |          2                  x\|2 \|c
+--R       - 4B c\|- \|- 4a c + b   + b atan(-----------------------)
+--R                                          +--------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + b
+--R     + 
+--R            +------------------+
+--R            | +-----------+                  +-+ +-+
+--R            | |          2                 x\|2 \|c
+--R       4B c\|\|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                           2
+--R                       +-+ +-+         2c x  + b
+--R       (- 4A c + 2C b)\|2 \|c atanh(--------------)
+--R                                     +-----------+
+--R                                     |          2
+--R                                    \|- 4a c + b
+--R     + 
+--R                                 +-----------+
+--R         +-+       4      2      |          2  +-+
+--R       C\|2 log(c x  + b x  + a)\|- 4a c + b  \|c
+--R  /
+--R            +-----------+
+--R        +-+ |          2  +-+
+--R     4c\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                c
+--R             *
+--R                ROOT
+--R                               2     2       2
+--R                       (- 12a c  + 3b c)%%BL1
+--R                     + 
+--R                               2     2                       2
+--R                       ((- 8a c  + 2b c)%%BL0 + 8C a c - 2C b )%%BL1
+--R                     + 
+--R                               2     2       2                 2           2
+--R                       (- 12a c  + 3b c)%%BL0  + (8C a c - 2C b )%%BL0 - 2A c
+--R                     + 
+--R                                2       2
+--R                       (2A C + B )b - 2C a
+--R                  /
+--R                         2    2
+--R                     4a c  - b c
+--R         + 
+--R           - c %%BL1 - c %%BL0 + C
+--R      *
+--R         log
+--R                           2 2 5      2   2 4     2 4 3            3   5
+--R                      (128B a c  - 64B a b c  + 8B b c )%%BL0 + 64A a c
+--R                    + 
+--R                            3 2         2         2          2   2  4
+--R                      (- 16A b  + (- 96A C + 32A B )a b - 32B C a )c
+--R                    + 
+--R                           2        2  3        2   2  3
+--R                      ((24A C - 8A B )b  + 48A C a b )c
+--R                    + 
+--R                               2     2   4     3   3  2     3 5
+--R                      ((- 12A C  + 2B C)b  - 8C a b )c  + 2C b c
+--R                 *
+--R                    %%BL1
+--R                + 
+--R                         3   5         3 2         2         2          2   2  4
+--R                      64A a c  + (- 16A b  + (- 96A C + 32A B )a b - 32B C a )c
+--R                    + 
+--R                           2        2  3        2   2  3
+--R                      ((24A C - 8A B )b  + 48A C a b )c
+--R                    + 
+--R                               2     2   4     3   3  2     3 5
+--R                      ((- 12A C  + 2B C)b  - 8C a b )c  + 2C b c
+--R                 *
+--R                    %%BL0
+--R                + 
+--R                        3      2 2    4
+--R                  (- 32A C + 8A B )a c
+--R                + 
+--R                      3      2 2  2       2 2        2      4         2 2 2  3
+--R                  ((8A C - 2A B )b  + (48A C  - 24A B C + 4B )a b + 8B C a )c
+--R                + 
+--R                         2 2       2     4  3           3     2 2    2  2
+--R                  ((- 12A C  + 6A B C - B )b  + (- 24A C  + 6B C )a b )c
+--R                + 
+--R                        3     2 2  4     4   3      4 5
+--R                  ((6A C  - 2B C )b  + 4C a b )c - C b
+--R             *
+--R                ROOT
+--R                               2     2       2
+--R                       (- 12a c  + 3b c)%%BL1
+--R                     + 
+--R                               2     2                       2
+--R                       ((- 8a c  + 2b c)%%BL0 + 8C a c - 2C b )%%BL1
+--R                     + 
+--R                               2     2       2                 2           2
+--R                       (- 12a c  + 3b c)%%BL0  + (8C a c - 2C b )%%BL0 - 2A c
+--R                     + 
+--R                                2       2
+--R                       (2A C + B )b - 2C a
+--R                  /
+--R                         2    2
+--R                     4a c  - b c
+--R            + 
+--R                         2 2 5      2   2 4     2 4 3            3   5
+--R                  (- 128B a c  + 64B a b c  - 8B b c )%%BL0 - 64A a c
+--R                + 
+--R                      3 2       2         2          2   2  4
+--R                  (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                + 
+--R                         2        2  3        2   2  3
+--R                  ((- 24A C + 8A B )b  - 48A C a b )c
+--R                + 
+--R                         2     2   4     3   3  2     3 5
+--R                  ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                         2 2 5      2   2 4     2 4 3      2
+--R                  (- 128B a c  + 64B a b c  - 8B b c )%%BL0
+--R                + 
+--R                       2   2 4      2     2 3     2   4 2
+--R                  (128B C a c  - 64B C a b c  + 8B C b c )%%BL0
+--R                + 
+--R                      3      2 2    4
+--R                  (32A C + 8A B )a c
+--R                + 
+--R                             3      2 2  2         2 2       2      4
+--R                        (- 8A C - 2A B )b  + (- 48A C  + 8A B C + 4B )a b
+--R                      + 
+--R                             2 2 2
+--R                        - 24B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 2       2     4  3         3     2 2    2  2
+--R                  ((12A C  - 2A B C - B )b  + (24A C  + 6B C )a b )c
+--R                + 
+--R                         3 4     4   3      4 5
+--R                  (- 6A C b  - 4C a b )c + C b
+--R             *
+--R                %%BL1
+--R            + 
+--R                       3   5       3 2       2         2          2   2  4
+--R                  - 64A a c  + (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                + 
+--R                         2        2  3        2   2  3
+--R                  ((- 24A C + 8A B )b  - 48A C a b )c
+--R                + 
+--R                         2     2   4     3   3  2     3 5
+--R                  ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R             *
+--R                     2
+--R                %%BL0
+--R            + 
+--R                      3      2 2    4
+--R                  (32A C + 8A B )a c
+--R                + 
+--R                             3      2 2  2         2 2       2      4
+--R                        (- 8A C - 2A B )b  + (- 48A C  + 8A B C + 4B )a b
+--R                      + 
+--R                             2 2 2
+--R                        - 24B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 2       2     4  3         3     2 2    2  2
+--R                  ((12A C  - 2A B C - B )b  + (24A C  + 6B C )a b )c
+--R                + 
+--R                         3 4     4   3      4 5
+--R                  (- 6A C b  - 4C a b )c + C b
+--R             *
+--R                %%BL0
+--R            + 
+--R                     4   4          3        2 3       5   3
+--R                  16A B c  + ((- 32A B C + 8A B )b - 4B a)c
+--R                + 
+--R                    2   2       3     5  2 2            3     3 2  3       4 4
+--R                (24A B C  - 8A B C + B )b c  + (- 8A B C  + 2B C )b c + B C b
+--R             *
+--R                x
+--R            + 
+--R                  5 4       4           3 2     2 2        4    3
+--R              - 8A c  + (20A C b + (- 8A C  - 4A B C + 4A B )a)c
+--R            + 
+--R                     3 2    2 2       4  2       2 3     4          2 3 2  2
+--R              ((- 18A C  + A B C + A B )b  + (12A C  - 4B C)a b + 4B C a )c
+--R            + 
+--R                 2 3 3          4    2 3    2        4 4    5   3
+--R              (7A C b  + (- 6A C  - B C )a b )c - A C b  + C a b
+--R     + 
+--R             c
+--R          *
+--R             ROOT
+--R                            2     2       2
+--R                    (- 12a c  + 3b c)%%BL1
+--R                  + 
+--R                            2     2                       2
+--R                    ((- 8a c  + 2b c)%%BL0 + 8C a c - 2C b )%%BL1
+--R                  + 
+--R                            2     2       2                 2           2
+--R                    (- 12a c  + 3b c)%%BL0  + (8C a c - 2C b )%%BL0 - 2A c
+--R                  + 
+--R                             2       2
+--R                    (2A C + B )b - 2C a
+--R               /
+--R                      2    2
+--R                  4a c  - b c
+--R         + 
+--R           - c %%BL1 - c %%BL0 + C
+--R      *
+--R         log
+--R                             2 2 5      2   2 4     2 4 3            3   5
+--R                      (- 128B a c  + 64B a b c  - 8B b c )%%BL0 - 64A a c
+--R                    + 
+--R                          3 2       2         2          2   2  4
+--R                      (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                    + 
+--R                             2        2  3        2   2  3
+--R                      ((- 24A C + 8A B )b  - 48A C a b )c
+--R                    + 
+--R                             2     2   4     3   3  2     3 5
+--R                      ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R                 *
+--R                    %%BL1
+--R                + 
+--R                           3   5       3 2       2         2          2   2  4
+--R                      - 64A a c  + (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                    + 
+--R                             2        2  3        2   2  3
+--R                      ((- 24A C + 8A B )b  - 48A C a b )c
+--R                    + 
+--R                             2     2   4     3   3  2     3 5
+--R                      ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R                 *
+--R                    %%BL0
+--R                + 
+--R                      3      2 2    4
+--R                  (32A C - 8A B )a c
+--R                + 
+--R                             3      2 2  2         2 2        2      4
+--R                        (- 8A C + 2A B )b  + (- 48A C  + 24A B C - 4B )a b
+--R                      + 
+--R                            2 2 2
+--R                        - 8B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 2       2     4  3         3     2 2    2  2
+--R                  ((12A C  - 6A B C + B )b  + (24A C  - 6B C )a b )c
+--R                + 
+--R                          3     2 2  4     4   3      4 5
+--R                  ((- 6A C  + 2B C )b  - 4C a b )c + C b
+--R             *
+--R                ROOT
+--R                               2     2       2
+--R                       (- 12a c  + 3b c)%%BL1
+--R                     + 
+--R                               2     2                       2
+--R                       ((- 8a c  + 2b c)%%BL0 + 8C a c - 2C b )%%BL1
+--R                     + 
+--R                               2     2       2                 2           2
+--R                       (- 12a c  + 3b c)%%BL0  + (8C a c - 2C b )%%BL0 - 2A c
+--R                     + 
+--R                                2       2
+--R                       (2A C + B )b - 2C a
+--R                  /
+--R                         2    2
+--R                     4a c  - b c
+--R            + 
+--R                         2 2 5      2   2 4     2 4 3            3   5
+--R                  (- 128B a c  + 64B a b c  - 8B b c )%%BL0 - 64A a c
+--R                + 
+--R                      3 2       2         2          2   2  4
+--R                  (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                + 
+--R                         2        2  3        2   2  3
+--R                  ((- 24A C + 8A B )b  - 48A C a b )c
+--R                + 
+--R                         2     2   4     3   3  2     3 5
+--R                  ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                         2 2 5      2   2 4     2 4 3      2
+--R                  (- 128B a c  + 64B a b c  - 8B b c )%%BL0
+--R                + 
+--R                       2   2 4      2     2 3     2   4 2
+--R                  (128B C a c  - 64B C a b c  + 8B C b c )%%BL0
+--R                + 
+--R                      3      2 2    4
+--R                  (32A C + 8A B )a c
+--R                + 
+--R                             3      2 2  2         2 2       2      4
+--R                        (- 8A C - 2A B )b  + (- 48A C  + 8A B C + 4B )a b
+--R                      + 
+--R                             2 2 2
+--R                        - 24B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 2       2     4  3         3     2 2    2  2
+--R                  ((12A C  - 2A B C - B )b  + (24A C  + 6B C )a b )c
+--R                + 
+--R                         3 4     4   3      4 5
+--R                  (- 6A C b  - 4C a b )c + C b
+--R             *
+--R                %%BL1
+--R            + 
+--R                       3   5       3 2       2         2          2   2  4
+--R                  - 64A a c  + (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                + 
+--R                         2        2  3        2   2  3
+--R                  ((- 24A C + 8A B )b  - 48A C a b )c
+--R                + 
+--R                         2     2   4     3   3  2     3 5
+--R                  ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R             *
+--R                     2
+--R                %%BL0
+--R            + 
+--R                      3      2 2    4
+--R                  (32A C + 8A B )a c
+--R                + 
+--R                             3      2 2  2         2 2       2      4
+--R                        (- 8A C - 2A B )b  + (- 48A C  + 8A B C + 4B )a b
+--R                      + 
+--R                             2 2 2
+--R                        - 24B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 2       2     4  3         3     2 2    2  2
+--R                  ((12A C  - 2A B C - B )b  + (24A C  + 6B C )a b )c
+--R                + 
+--R                         3 4     4   3      4 5
+--R                  (- 6A C b  - 4C a b )c + C b
+--R             *
+--R                %%BL0
+--R            + 
+--R                     4   4          3        2 3       5   3
+--R                  16A B c  + ((- 32A B C + 8A B )b - 4B a)c
+--R                + 
+--R                    2   2       3     5  2 2            3     3 2  3       4 4
+--R                (24A B C  - 8A B C + B )b c  + (- 8A B C  + 2B C )b c + B C b
+--R             *
+--R                x
+--R            + 
+--R                  5 4       4           3 2     2 2        4    3
+--R              - 8A c  + (20A C b + (- 8A C  - 4A B C + 4A B )a)c
+--R            + 
+--R                     3 2    2 2       4  2       2 3     4          2 3 2  2
+--R              ((- 18A C  + A B C + A B )b  + (12A C  - 4B C)a b + 4B C a )c
+--R            + 
+--R                 2 3 3          4    2 3    2        4 4    5   3
+--R              (7A C b  + (- 6A C  - B C )a b )c - A C b  + C a b
+--R     + 
+--R         2c %%BL1
+--R      *
+--R         log
+--R                       2 2 5       2   2 4      2 4 3             3   5
+--R                  (256B a c  - 128B a b c  + 16B b c )%%BL0 + 128A a c
+--R                + 
+--R                        3 2          2         2          2   2  4
+--R                  (- 32A b  + (- 192A C + 64A B )a b - 64B C a )c
+--R                + 
+--R                       2         2  3        2   2  3
+--R                  ((48A C - 16A B )b  + 96A C a b )c
+--R                + 
+--R                           2     2   4      3   3  2     3 5
+--R                  ((- 24A C  + 4B C)b  - 16C a b )c  + 4C b c
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                       2 2 5       2   2 4      2 4 3      2
+--R                  (256B a c  - 128B a b c  + 16B b c )%%BL0
+--R                + 
+--R                         2   2 4       2     2 3      2   4 2
+--R                  (- 256B C a c  + 128B C a b c  - 16B C b c )%%BL0
+--R                + 
+--R                        3       2 2    4
+--R                  (- 64A C - 16A B )a c
+--R                + 
+--R                       3      2 2  2       2 2        2      4          2 2 2  3
+--R                  ((16A C + 4A B )b  + (96A C  - 16A B C - 8B )a b + 48B C a )c
+--R                + 
+--R                         2 2       2      4  3           3      2 2    2  2
+--R                  ((- 24A C  + 4A B C + 2B )b  + (- 48A C  - 12B C )a b )c
+--R                + 
+--R                        3 4     4   3       4 5
+--R                  (12A C b  + 8C a b )c - 2C b
+--R             *
+--R                %%BL1
+--R            + 
+--R                   2 2 5       2   2 4      2 4 3      3
+--R              (256B a c  - 128B a b c  + 16B b c )%%BL0
+--R            + 
+--R                     2   2 4       2     2 3      2   4 2      2
+--R              (- 256B C a c  + 128B C a b c  - 16B C b c )%%BL0
+--R            + 
+--R                     2 2   4        2 2 2           2       4          2 2 2  3
+--R                  32A B a c  + (- 8A B b  + (- 32A B C - 16B )a b + 96B C a )c
+--R                + 
+--R                        2      4  3      2 2   2  2     2 2 4
+--R                  ((8A B C + 4B )b  - 40B C a b )c  + 4B C b c
+--R             *
+--R                %%BL0
+--R            + 
+--R                     4   4          3        2 3       5   3
+--R                  16A B c  + ((- 32A B C + 8A B )b - 4B a)c
+--R                + 
+--R                    2   2       3     5  2 2            3     3 2  3       4 4
+--R                (24A B C  - 8A B C + B )b c  + (- 8A B C  + 2B C )b c + B C b
+--R             *
+--R                x
+--R            + 
+--R                5 4         4         3 2     2 2        4    3
+--R              8A c  + (- 20A C b + (8A C  - 4A B C + 4A B )a)c
+--R            + 
+--R                      3 2    2 2        4  2         2 3       2 2     4
+--R                  (18A C  + A B C - 3A B )b  + (- 12A C  + 8A B C  + 4B C)a b
+--R                + 
+--R                       2 3 2
+--R                  - 12B C a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                    2 3       2 2  3        4     2 3    2        4 4    5   3
+--R              ((- 7A C  - 2A B C )b  + (6A C  + 3B C )a b )c + A C b  - C a b
+--R     + 
+--R         2c %%BL0
+--R      *
+--R         log
+--R                     2 2 5       2   2 4      2 4 3      3
+--R              (- 256B a c  + 128B a b c  - 16B b c )%%BL0
+--R            + 
+--R                      3   5         3 2          2         2           2   2  4
+--R                  128A a c  + (- 32A b  + (- 192A C + 64A B )a b + 192B C a )c
+--R                + 
+--R                       2         2  3         2       2     2  3
+--R                  ((48A C - 16A B )b  + (96A C  - 128B C)a b )c
+--R                + 
+--R                           2      2   4      3   3  2     3 5
+--R                  ((- 24A C  + 20B C)b  - 16C a b )c  + 4C b c
+--R             *
+--R                     2
+--R                %%BL0
+--R            + 
+--R                        3       2 2    4
+--R                  (- 64A C - 48A B )a c
+--R                + 
+--R                            3       2 2  2       2 2        2      4
+--R                        (16A C + 12A B )b  + (96A C  + 16A B C + 8B )a b
+--R                      + 
+--R                             2 2 2
+--R                        - 48B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         2 2       2      4  3           3      2 2    2  2
+--R                  ((- 24A C  - 4A B C - 2B )b  + (- 48A C  + 28B C )a b )c
+--R                + 
+--R                         3     2 2  4     4   3       4 5
+--R                  ((12A C  - 4B C )b  + 8C a b )c - 2C b
+--R             *
+--R                %%BL0
+--R            + 
+--R                     4   4          3        2 3       5   3
+--R                  16A B c  + ((- 32A B C + 8A B )b - 4B a)c
+--R                + 
+--R                    2   2       3     5  2 2            3     3 2  3       4 4
+--R                (24A B C  - 8A B C + B )b c  + (- 8A B C  + 2B C )b c + B C b
+--R             *
+--R                x
+--R            + 
+--R                5 4         4         3 2      2 2         4    3
+--R              8A c  + (- 20A C b + (8A C  + 12A B C - 12A B )a)c
+--R            + 
+--R                      3 2     2 2       4  2         2 3       2 2     4
+--R                  (18A C  - 3A B C + A B )b  + (- 12A C  - 8A B C  + 4B C)a b
+--R                + 
+--R                    2 3 2
+--R                  4B C a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                    2 3       2 2  3        4    2 3    2        4 4    5   3
+--R              ((- 7A C  + 2A B C )b  + (6A C  - B C )a b )c + A C b  - C a b
+--R  /
+--R     2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 491
+
+--S 492 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                       +-----------+
+--R                   +-+ |          2  +-+
+--R                2c\|2 \|- 4a c + b  \|c
+--R             *
+--R                ROOT
+--R                               2     2       2
+--R                       (- 12a c  + 3b c)%%BL1
+--R                     + 
+--R                               2     2                       2
+--R                       ((- 8a c  + 2b c)%%BL0 + 8C a c - 2C b )%%BL1
+--R                     + 
+--R                               2     2       2                 2           2
+--R                       (- 12a c  + 3b c)%%BL0  + (8C a c - 2C b )%%BL0 - 2A c
+--R                     + 
+--R                                2       2
+--R                       (2A C + B )b - 2C a
+--R                  /
+--R                         2    2
+--R                     4a c  - b c
+--R         + 
+--R                    +-----------+                   +-----------+
+--R                +-+ |          2  +-+           +-+ |          2  +-+
+--R           - 2c\|2 \|- 4a c + b  \|c %%BL1 - 2c\|2 \|- 4a c + b  \|c %%BL0
+--R         + 
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R           2C\|2 \|- 4a c + b  \|c
+--R      *
+--R         log
+--R                           2 2 5      2   2 4     2 4 3            3   5
+--R                      (128B a c  - 64B a b c  + 8B b c )%%BL0 + 64A a c
+--R                    + 
+--R                            3 2         2         2          2   2  4
+--R                      (- 16A b  + (- 96A C + 32A B )a b - 32B C a )c
+--R                    + 
+--R                           2        2  3        2   2  3
+--R                      ((24A C - 8A B )b  + 48A C a b )c
+--R                    + 
+--R                               2     2   4     3   3  2     3 5
+--R                      ((- 12A C  + 2B C)b  - 8C a b )c  + 2C b c
+--R                 *
+--R                    %%BL1
+--R                + 
+--R                         3   5         3 2         2         2          2   2  4
+--R                      64A a c  + (- 16A b  + (- 96A C + 32A B )a b - 32B C a )c
+--R                    + 
+--R                           2        2  3        2   2  3
+--R                      ((24A C - 8A B )b  + 48A C a b )c
+--R                    + 
+--R                               2     2   4     3   3  2     3 5
+--R                      ((- 12A C  + 2B C)b  - 8C a b )c  + 2C b c
+--R                 *
+--R                    %%BL0
+--R                + 
+--R                        3      2 2    4
+--R                  (- 32A C + 8A B )a c
+--R                + 
+--R                      3      2 2  2       2 2        2      4         2 2 2  3
+--R                  ((8A C - 2A B )b  + (48A C  - 24A B C + 4B )a b + 8B C a )c
+--R                + 
+--R                         2 2       2     4  3           3     2 2    2  2
+--R                  ((- 12A C  + 6A B C - B )b  + (- 24A C  + 6B C )a b )c
+--R                + 
+--R                        3     2 2  4     4   3      4 5
+--R                  ((6A C  - 2B C )b  + 4C a b )c - C b
+--R             *
+--R                ROOT
+--R                               2     2       2
+--R                       (- 12a c  + 3b c)%%BL1
+--R                     + 
+--R                               2     2                       2
+--R                       ((- 8a c  + 2b c)%%BL0 + 8C a c - 2C b )%%BL1
+--R                     + 
+--R                               2     2       2                 2           2
+--R                       (- 12a c  + 3b c)%%BL0  + (8C a c - 2C b )%%BL0 - 2A c
+--R                     + 
+--R                                2       2
+--R                       (2A C + B )b - 2C a
+--R                  /
+--R                         2    2
+--R                     4a c  - b c
+--R            + 
+--R                         2 2 5      2   2 4     2 4 3            3   5
+--R                  (- 128B a c  + 64B a b c  - 8B b c )%%BL0 - 64A a c
+--R                + 
+--R                      3 2       2         2          2   2  4
+--R                  (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                + 
+--R                         2        2  3        2   2  3
+--R                  ((- 24A C + 8A B )b  - 48A C a b )c
+--R                + 
+--R                         2     2   4     3   3  2     3 5
+--R                  ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                         2 2 5      2   2 4     2 4 3      2
+--R                  (- 128B a c  + 64B a b c  - 8B b c )%%BL0
+--R                + 
+--R                       2   2 4      2     2 3     2   4 2
+--R                  (128B C a c  - 64B C a b c  + 8B C b c )%%BL0
+--R                + 
+--R                      3      2 2    4
+--R                  (32A C + 8A B )a c
+--R                + 
+--R                             3      2 2  2         2 2       2      4
+--R                        (- 8A C - 2A B )b  + (- 48A C  + 8A B C + 4B )a b
+--R                      + 
+--R                             2 2 2
+--R                        - 24B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 2       2     4  3         3     2 2    2  2
+--R                  ((12A C  - 2A B C - B )b  + (24A C  + 6B C )a b )c
+--R                + 
+--R                         3 4     4   3      4 5
+--R                  (- 6A C b  - 4C a b )c + C b
+--R             *
+--R                %%BL1
+--R            + 
+--R                       3   5       3 2       2         2          2   2  4
+--R                  - 64A a c  + (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                + 
+--R                         2        2  3        2   2  3
+--R                  ((- 24A C + 8A B )b  - 48A C a b )c
+--R                + 
+--R                         2     2   4     3   3  2     3 5
+--R                  ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R             *
+--R                     2
+--R                %%BL0
+--R            + 
+--R                      3      2 2    4
+--R                  (32A C + 8A B )a c
+--R                + 
+--R                             3      2 2  2         2 2       2      4
+--R                        (- 8A C - 2A B )b  + (- 48A C  + 8A B C + 4B )a b
+--R                      + 
+--R                             2 2 2
+--R                        - 24B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 2       2     4  3         3     2 2    2  2
+--R                  ((12A C  - 2A B C - B )b  + (24A C  + 6B C )a b )c
+--R                + 
+--R                         3 4     4   3      4 5
+--R                  (- 6A C b  - 4C a b )c + C b
+--R             *
+--R                %%BL0
+--R            + 
+--R                     4   4          3        2 3       5   3
+--R                  16A B c  + ((- 32A B C + 8A B )b - 4B a)c
+--R                + 
+--R                    2   2       3     5  2 2            3     3 2  3       4 4
+--R                (24A B C  - 8A B C + B )b c  + (- 8A B C  + 2B C )b c + B C b
+--R             *
+--R                x
+--R            + 
+--R                  5 4       4           3 2     2 2        4    3
+--R              - 8A c  + (20A C b + (- 8A C  - 4A B C + 4A B )a)c
+--R            + 
+--R                     3 2    2 2       4  2       2 3     4          2 3 2  2
+--R              ((- 18A C  + A B C + A B )b  + (12A C  - 4B C)a b + 4B C a )c
+--R            + 
+--R                 2 3 3          4    2 3    2        4 4    5   3
+--R              (7A C b  + (- 6A C  - B C )a b )c - A C b  + C a b
+--R     + 
+--R                    +-----------+
+--R                +-+ |          2  +-+
+--R             2c\|2 \|- 4a c + b  \|c
+--R          *
+--R             ROOT
+--R                            2     2       2
+--R                    (- 12a c  + 3b c)%%BL1
+--R                  + 
+--R                            2     2                       2
+--R                    ((- 8a c  + 2b c)%%BL0 + 8C a c - 2C b )%%BL1
+--R                  + 
+--R                            2     2       2                 2           2
+--R                    (- 12a c  + 3b c)%%BL0  + (8C a c - 2C b )%%BL0 - 2A c
+--R                  + 
+--R                             2       2
+--R                    (2A C + B )b - 2C a
+--R               /
+--R                      2    2
+--R                  4a c  - b c
+--R         + 
+--R                    +-----------+                   +-----------+
+--R                +-+ |          2  +-+           +-+ |          2  +-+
+--R           - 2c\|2 \|- 4a c + b  \|c %%BL1 - 2c\|2 \|- 4a c + b  \|c %%BL0
+--R         + 
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R           2C\|2 \|- 4a c + b  \|c
+--R      *
+--R         log
+--R                             2 2 5      2   2 4     2 4 3            3   5
+--R                      (- 128B a c  + 64B a b c  - 8B b c )%%BL0 - 64A a c
+--R                    + 
+--R                          3 2       2         2          2   2  4
+--R                      (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                    + 
+--R                             2        2  3        2   2  3
+--R                      ((- 24A C + 8A B )b  - 48A C a b )c
+--R                    + 
+--R                             2     2   4     3   3  2     3 5
+--R                      ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R                 *
+--R                    %%BL1
+--R                + 
+--R                           3   5       3 2       2         2          2   2  4
+--R                      - 64A a c  + (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                    + 
+--R                             2        2  3        2   2  3
+--R                      ((- 24A C + 8A B )b  - 48A C a b )c
+--R                    + 
+--R                             2     2   4     3   3  2     3 5
+--R                      ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R                 *
+--R                    %%BL0
+--R                + 
+--R                      3      2 2    4
+--R                  (32A C - 8A B )a c
+--R                + 
+--R                             3      2 2  2         2 2        2      4
+--R                        (- 8A C + 2A B )b  + (- 48A C  + 24A B C - 4B )a b
+--R                      + 
+--R                            2 2 2
+--R                        - 8B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 2       2     4  3         3     2 2    2  2
+--R                  ((12A C  - 6A B C + B )b  + (24A C  - 6B C )a b )c
+--R                + 
+--R                          3     2 2  4     4   3      4 5
+--R                  ((- 6A C  + 2B C )b  - 4C a b )c + C b
+--R             *
+--R                ROOT
+--R                               2     2       2
+--R                       (- 12a c  + 3b c)%%BL1
+--R                     + 
+--R                               2     2                       2
+--R                       ((- 8a c  + 2b c)%%BL0 + 8C a c - 2C b )%%BL1
+--R                     + 
+--R                               2     2       2                 2           2
+--R                       (- 12a c  + 3b c)%%BL0  + (8C a c - 2C b )%%BL0 - 2A c
+--R                     + 
+--R                                2       2
+--R                       (2A C + B )b - 2C a
+--R                  /
+--R                         2    2
+--R                     4a c  - b c
+--R            + 
+--R                         2 2 5      2   2 4     2 4 3            3   5
+--R                  (- 128B a c  + 64B a b c  - 8B b c )%%BL0 - 64A a c
+--R                + 
+--R                      3 2       2         2          2   2  4
+--R                  (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                + 
+--R                         2        2  3        2   2  3
+--R                  ((- 24A C + 8A B )b  - 48A C a b )c
+--R                + 
+--R                         2     2   4     3   3  2     3 5
+--R                  ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                         2 2 5      2   2 4     2 4 3      2
+--R                  (- 128B a c  + 64B a b c  - 8B b c )%%BL0
+--R                + 
+--R                       2   2 4      2     2 3     2   4 2
+--R                  (128B C a c  - 64B C a b c  + 8B C b c )%%BL0
+--R                + 
+--R                      3      2 2    4
+--R                  (32A C + 8A B )a c
+--R                + 
+--R                             3      2 2  2         2 2       2      4
+--R                        (- 8A C - 2A B )b  + (- 48A C  + 8A B C + 4B )a b
+--R                      + 
+--R                             2 2 2
+--R                        - 24B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 2       2     4  3         3     2 2    2  2
+--R                  ((12A C  - 2A B C - B )b  + (24A C  + 6B C )a b )c
+--R                + 
+--R                         3 4     4   3      4 5
+--R                  (- 6A C b  - 4C a b )c + C b
+--R             *
+--R                %%BL1
+--R            + 
+--R                       3   5       3 2       2         2          2   2  4
+--R                  - 64A a c  + (16A b  + (96A C - 32A B )a b + 32B C a )c
+--R                + 
+--R                         2        2  3        2   2  3
+--R                  ((- 24A C + 8A B )b  - 48A C a b )c
+--R                + 
+--R                         2     2   4     3   3  2     3 5
+--R                  ((12A C  - 2B C)b  + 8C a b )c  - 2C b c
+--R             *
+--R                     2
+--R                %%BL0
+--R            + 
+--R                      3      2 2    4
+--R                  (32A C + 8A B )a c
+--R                + 
+--R                             3      2 2  2         2 2       2      4
+--R                        (- 8A C - 2A B )b  + (- 48A C  + 8A B C + 4B )a b
+--R                      + 
+--R                             2 2 2
+--R                        - 24B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       2 2       2     4  3         3     2 2    2  2
+--R                  ((12A C  - 2A B C - B )b  + (24A C  + 6B C )a b )c
+--R                + 
+--R                         3 4     4   3      4 5
+--R                  (- 6A C b  - 4C a b )c + C b
+--R             *
+--R                %%BL0
+--R            + 
+--R                     4   4          3        2 3       5   3
+--R                  16A B c  + ((- 32A B C + 8A B )b - 4B a)c
+--R                + 
+--R                    2   2       3     5  2 2            3     3 2  3       4 4
+--R                (24A B C  - 8A B C + B )b c  + (- 8A B C  + 2B C )b c + B C b
+--R             *
+--R                x
+--R            + 
+--R                  5 4       4           3 2     2 2        4    3
+--R              - 8A c  + (20A C b + (- 8A C  - 4A B C + 4A B )a)c
+--R            + 
+--R                     3 2    2 2       4  2       2 3     4          2 3 2  2
+--R              ((- 18A C  + A B C + A B )b  + (12A C  - 4B C)a b + 4B C a )c
+--R            + 
+--R                 2 3 3          4    2 3    2        4 4    5   3
+--R              (7A C b  + (- 6A C  - B C )a b )c - A C b  + C a b
+--R     + 
+--R                +-----------+
+--R            +-+ |          2  +-+
+--R         4c\|2 \|- 4a c + b  \|c %%BL1
+--R      *
+--R         log
+--R                       2 2 5       2   2 4      2 4 3             3   5
+--R                  (256B a c  - 128B a b c  + 16B b c )%%BL0 + 128A a c
+--R                + 
+--R                        3 2          2         2          2   2  4
+--R                  (- 32A b  + (- 192A C + 64A B )a b - 64B C a )c
+--R                + 
+--R                       2         2  3        2   2  3
+--R                  ((48A C - 16A B )b  + 96A C a b )c
+--R                + 
+--R                           2     2   4      3   3  2     3 5
+--R                  ((- 24A C  + 4B C)b  - 16C a b )c  + 4C b c
+--R             *
+--R                     2
+--R                %%BL1
+--R            + 
+--R                       2 2 5       2   2 4      2 4 3      2
+--R                  (256B a c  - 128B a b c  + 16B b c )%%BL0
+--R                + 
+--R                         2   2 4       2     2 3      2   4 2
+--R                  (- 256B C a c  + 128B C a b c  - 16B C b c )%%BL0
+--R                + 
+--R                        3       2 2    4
+--R                  (- 64A C - 16A B )a c
+--R                + 
+--R                       3      2 2  2       2 2        2      4          2 2 2  3
+--R                  ((16A C + 4A B )b  + (96A C  - 16A B C - 8B )a b + 48B C a )c
+--R                + 
+--R                         2 2       2      4  3           3      2 2    2  2
+--R                  ((- 24A C  + 4A B C + 2B )b  + (- 48A C  - 12B C )a b )c
+--R                + 
+--R                        3 4     4   3       4 5
+--R                  (12A C b  + 8C a b )c - 2C b
+--R             *
+--R                %%BL1
+--R            + 
+--R                   2 2 5       2   2 4      2 4 3      3
+--R              (256B a c  - 128B a b c  + 16B b c )%%BL0
+--R            + 
+--R                     2   2 4       2     2 3      2   4 2      2
+--R              (- 256B C a c  + 128B C a b c  - 16B C b c )%%BL0
+--R            + 
+--R                     2 2   4        2 2 2           2       4          2 2 2  3
+--R                  32A B a c  + (- 8A B b  + (- 32A B C - 16B )a b + 96B C a )c
+--R                + 
+--R                        2      4  3      2 2   2  2     2 2 4
+--R                  ((8A B C + 4B )b  - 40B C a b )c  + 4B C b c
+--R             *
+--R                %%BL0
+--R            + 
+--R                     4   4          3        2 3       5   3
+--R                  16A B c  + ((- 32A B C + 8A B )b - 4B a)c
+--R                + 
+--R                    2   2       3     5  2 2            3     3 2  3       4 4
+--R                (24A B C  - 8A B C + B )b c  + (- 8A B C  + 2B C )b c + B C b
+--R             *
+--R                x
+--R            + 
+--R                5 4         4         3 2     2 2        4    3
+--R              8A c  + (- 20A C b + (8A C  - 4A B C + 4A B )a)c
+--R            + 
+--R                      3 2    2 2        4  2         2 3       2 2     4
+--R                  (18A C  + A B C - 3A B )b  + (- 12A C  + 8A B C  + 4B C)a b
+--R                + 
+--R                       2 3 2
+--R                  - 12B C a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                    2 3       2 2  3        4     2 3    2        4 4    5   3
+--R              ((- 7A C  - 2A B C )b  + (6A C  + 3B C )a b )c + A C b  - C a b
+--R     + 
+--R            +--------------------+
+--R            |   +-----------+                   +-+ +-+
+--R            |   |          2                  x\|2 \|c
+--R       4B c\|- \|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R              +------------------+
+--R              | +-----------+                  +-+ +-+
+--R              | |          2                 x\|2 \|c
+--R       - 4B c\|\|- 4a c + b   + b atan(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                        | |          2
+--R                                       \|\|- 4a c + b   + b
+--R     + 
+--R                +-----------+
+--R            +-+ |          2  +-+
+--R         4c\|2 \|- 4a c + b  \|c %%BL0
+--R      *
+--R         log
+--R                     2 2 5       2   2 4      2 4 3      3
+--R              (- 256B a c  + 128B a b c  - 16B b c )%%BL0
+--R            + 
+--R                      3   5         3 2          2         2           2   2  4
+--R                  128A a c  + (- 32A b  + (- 192A C + 64A B )a b + 192B C a )c
+--R                + 
+--R                       2         2  3         2       2     2  3
+--R                  ((48A C - 16A B )b  + (96A C  - 128B C)a b )c
+--R                + 
+--R                           2      2   4      3   3  2     3 5
+--R                  ((- 24A C  + 20B C)b  - 16C a b )c  + 4C b c
+--R             *
+--R                     2
+--R                %%BL0
+--R            + 
+--R                        3       2 2    4
+--R                  (- 64A C - 48A B )a c
+--R                + 
+--R                            3       2 2  2       2 2        2      4
+--R                        (16A C + 12A B )b  + (96A C  + 16A B C + 8B )a b
+--R                      + 
+--R                             2 2 2
+--R                        - 48B C a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         2 2       2      4  3           3      2 2    2  2
+--R                  ((- 24A C  - 4A B C - 2B )b  + (- 48A C  + 28B C )a b )c
+--R                + 
+--R                         3     2 2  4     4   3       4 5
+--R                  ((12A C  - 4B C )b  + 8C a b )c - 2C b
+--R             *
+--R                %%BL0
+--R            + 
+--R                     4   4          3        2 3       5   3
+--R                  16A B c  + ((- 32A B C + 8A B )b - 4B a)c
+--R                + 
+--R                    2   2       3     5  2 2            3     3 2  3       4 4
+--R                (24A B C  - 8A B C + B )b c  + (- 8A B C  + 2B C )b c + B C b
+--R             *
+--R                x
+--R            + 
+--R                5 4         4         3 2      2 2         4    3
+--R              8A c  + (- 20A C b + (8A C  + 12A B C - 12A B )a)c
+--R            + 
+--R                      3 2     2 2       4  2         2 3       2 2     4
+--R                  (18A C  - 3A B C + A B )b  + (- 12A C  - 8A B C  + 4B C)a b
+--R                + 
+--R                    2 3 2
+--R                  4B C a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                    2 3       2 2  3        4    2 3    2        4 4    5   3
+--R              ((- 7A C  + 2A B C )b  + (6A C  - B C )a b )c + A C b  - C a b
+--R     + 
+--R                                         2
+--R                     +-+ +-+         2c x  + b
+--R       (4A c - 2C b)\|2 \|c atanh(--------------)
+--R                                   +-----------+
+--R                                   |          2
+--R                                  \|- 4a c + b
+--R     + 
+--R                                   +-----------+
+--R           +-+       4      2      |          2  +-+
+--R       - C\|2 log(c x  + b x  + a)\|- 4a c + b  \|c
+--R  /
+--R            +-----------+
+--R        +-+ |          2  +-+
+--R     4c\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 492
+
+--S 493 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 493
+
+)clear all
+
+--S 494 of 1070
+t0:=(A+B*x+C*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            2
+--R         C x  + B x + A
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 494
+
+--S 495 of 1070
+r0:=-B*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)+atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(C+(2*A*c-b*C)/sqrt(b^2-4*a*c))/_
+   (sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*(C+(-2*A*c+b*C)/sqrt(b^2-4*a*c))/_
+   (sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2                | |          2
+--R         (C\|- 4a c + b   + 2A c - C b)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2                |   |          2
+--R         (C\|- 4a c + b   - 2A c + C b)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                                           +--------------------+
+--R                                  2        |   +-----------+
+--R              +-+ +-+         2c x  + b    |   |          2
+--R            B\|2 \|c atanh(--------------)\|- \|- 4a c + b   + b
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 495
+
+--S 496 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           ROOT
+--R                        2 2       2       2        2 2       2
+--R                  (- 12a c  + 3a b c)%%BM1  + (- 8a c  + 2a b c)%%BM0 %%BM1
+--R                + 
+--R                        2 2       2       2     2                2        2
+--R                  (- 12a c  + 3a b c)%%BM0  + (A b + (- 4A C - 2B )a)c + C a b
+--R             /
+--R                  2 2      2
+--R                4a c  - a b c
+--R         + 
+--R           - %%BM1 - %%BM0
+--R      *
+--R         log
+--R                              3 3           2          2  4  4
+--R                          (64A a b + (- 128A C + 256A B )a )c
+--R                        + 
+--R                                   3 2 3       2          2  3 2        2 4
+--R                              - 32A a b  + (64A C - 128A B )a b  - 64A C a b
+--R                            + 
+--R                                  3 5
+--R                              128C a
+--R                         *
+--R                             3
+--R                            c
+--R                        + 
+--R                                3   5        2         2  2 4        2 3 3
+--R                              4A a b  + (- 8A C + 16A B )a b  + 32A C a b
+--R                            + 
+--R                                   3 4 2
+--R                              - 64C a b
+--R                         *
+--R                             2
+--R                            c
+--R                        + 
+--R                                 2 2 5     3 3 4
+--R                          (- 4A C a b  + 8C a b )c
+--R                     *
+--R                        %%BM0
+--R                    + 
+--R                           3   3 4
+--R                      - 32A B a c
+--R                    + 
+--R                           2           3  3              2      3   4  3
+--R                      ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                    + 
+--R                            3     4         2          3  2 3      3   3 2
+--R                          2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                        + 
+--R                               3 4
+--R                          32B C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 4       3 3 3
+--R                      (6A B C a b  - 8B C a b )c
+--R                 *
+--R                    %%BM1
+--R                + 
+--R                           3   3 4
+--R                      - 32A B a c
+--R                    + 
+--R                           2           3  3              2      3   4  3
+--R                      ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                    + 
+--R                            3     4         2          3  2 3      3   3 2
+--R                          2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                        + 
+--R                               3 4
+--R                          32B C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 4       3 3 3
+--R                      (6A B C a b  - 8B C a b )c
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                    5 2 4
+--R                  8A a c
+--R                + 
+--R                       5   2         4      3 2  2        2 2         4  3  3
+--R                  (- 2A a b  + (- 12A C - 4A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                         4     3 2    3      3 2     2 2        4  2 2
+--R                      (3A C + A B )a b  + (4A C  - 6A B C + 4A B )a b
+--R                    + 
+--R                         2 3        2 2  3           4     2 3  4
+--R                      (8A C  - 12A B C )a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         3 2   4        2 3       2 2  2 3
+--R                      - A C a b  + (- 2A C  + 3A B C )a b
+--R                    + 
+--R                             4     2 3  3 2     5 4
+--R                      (- 2A C  - 2B C )a b  + 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                     4 2 4    5 3 3
+--R                  A C a b  - C a b
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12a c  + 3a b c)%%BM1  + (- 8a c  + 2a b c)%%BM0 %%BM1
+--R                     + 
+--R                             2 2       2       2     2                2
+--R                       (- 12a c  + 3a b c)%%BM0  + (A b + (- 4A C - 2B )a)c
+--R                     + 
+--R                        2
+--R                       C a b
+--R                  /
+--R                       2 2      2
+--R                     4a c  - a b c
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64A a b + (- 128A C + 256A B )a )c
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32A a b  + (64A C - 128A B )a b  - 64A C a b
+--R                          + 
+--R                                3 5
+--R                            128C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4A a b  + (- 8A C + 16A B )a b  + 32A C a b
+--R                          + 
+--R                                 3 4 2
+--R                            - 64C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4A C a b  + 8C a b )c
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                       3   3 4
+--R                  - 32A B a c
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                      + 
+--R                             3 4
+--R                        32B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6A B C a b  - 8B C a b )c
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64A a b + (- 128A C + 256A B )a )c
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32A a b  + (64A C - 128A B )a b  - 64A C a b
+--R                          + 
+--R                                3 5
+--R                            128C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4A a b  + (- 8A C + 16A B )a b  + 32A C a b
+--R                          + 
+--R                                 3 4 2
+--R                            - 64C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4A C a b  + 8C a b )c
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                      5 2 4
+--R                  - 8A a c
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2A a b  + (12A C + 4A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3A C - A B )a b  + (- 4A C  + 6A B C - 4A B )a b
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8A C  + 12A B C )a b + (8A C  - 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      A C a b  + (2A C  - 3A B C )a b  + (2A C  + 2B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - A C a b  + C a b
+--R             *
+--R                %%BM1
+--R            + 
+--R                       3   3 4
+--R                  - 32A B a c
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                      + 
+--R                             3 4
+--R                        32B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6A B C a b  - 8B C a b )c
+--R             *
+--R                     2
+--R                %%BM0
+--R            + 
+--R                      5 2 4
+--R                  - 8A a c
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2A a b  + (12A C + 4A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3A C - A B )a b  + (- 4A C  + 6A B C - 4A B )a b
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8A C  + 12A B C )a b + (8A C  - 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      A C a b  + (2A C  - 3A B C )a b  + (2A C  + 2B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - A C a b  + C a b
+--R             *
+--R                %%BM0
+--R            + 
+--R                    6   4
+--R                  4A a c
+--R                + 
+--R                         6 2        5      4 2
+--R                      - A b  + (- 4A C - 8A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      A C b  + (A C  + 8A B C)a b
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2A C a b  + (A C  + 8A B C )a b  + (- 4A C  - 8B C )a b
+--R                    + 
+--R                        6 4
+--R                      4C a
+--R                 *
+--R                    c
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  A C a b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                 5              4        3 3  2  3
+--R              (4A B a b + (- 12A B C + 4A B )a )c
+--R            + 
+--R                       4       3 3    2       3   2       5  2
+--R                  (- 7A B C - A B )a b  + (28A B C  - 4A B )a b
+--R                + 
+--R                        2   3       3 2     5   3
+--R                  (- 16A B C  - 4A B C  + 8B C)a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                 3   2   3         2   3      3 2  2 2          4 3        5 4
+--R              (3A B C a b  + (- 16A B C  + A B C )a b  + 16A B C a b - 4B C a )c
+--R            + 
+--R                   4 2 3      5 3 2
+--R              A B C a b  - B C a b
+--R     + 
+--R           -
+--R              ROOT
+--R                           2 2       2       2        2 2       2
+--R                     (- 12a c  + 3a b c)%%BM1  + (- 8a c  + 2a b c)%%BM0 %%BM1
+--R                   + 
+--R                         2 2       2       2     2                2        2
+--R                   (- 12a c  + 3a b c)%%BM0  + (A b + (- 4A C - 2B )a)c + C a b
+--R                /
+--R                     2 2      2
+--R                   4a c  - a b c
+--R         + 
+--R           - %%BM1 - %%BM0
+--R      *
+--R         log
+--R                                3 3         2          2  4  4
+--R                          (- 64A a b + (128A C - 256A B )a )c
+--R                        + 
+--R                                 3 2 3         2          2  3 2        2 4
+--R                              32A a b  + (- 64A C + 128A B )a b  + 64A C a b
+--R                            + 
+--R                                    3 5
+--R                              - 128C a
+--R                         *
+--R                             3
+--R                            c
+--R                        + 
+--R                                  3   5      2         2  2 4        2 3 3
+--R                              - 4A a b  + (8A C - 16A B )a b  - 32A C a b
+--R                            + 
+--R                                 3 4 2
+--R                              64C a b
+--R                         *
+--R                             2
+--R                            c
+--R                        + 
+--R                               2 2 5     3 3 4
+--R                          (4A C a b  - 8C a b )c
+--R                     *
+--R                        %%BM0
+--R                    + 
+--R                         3   3 4
+--R                      32A B a c
+--R                    + 
+--R                             2           3  3            2      3   4  3
+--R                      ((- 96A B C + 32A B )a b + (96A B C  - 64B C)a )c
+--R                    + 
+--R                              3     4       2          3  2 3      3   3 2
+--R                          - 2A B a b  + (24A B C - 8A B )a b  + 16B C a b
+--R                        + 
+--R                                 3 4
+--R                          - 32B C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                               2 2 4       3 3 3
+--R                      (- 6A B C a b  + 8B C a b )c
+--R                 *
+--R                    %%BM1
+--R                + 
+--R                         3   3 4
+--R                      32A B a c
+--R                    + 
+--R                             2           3  3            2      3   4  3
+--R                      ((- 96A B C + 32A B )a b + (96A B C  - 64B C)a )c
+--R                    + 
+--R                              3     4       2          3  2 3      3   3 2
+--R                          - 2A B a b  + (24A B C - 8A B )a b  + 16B C a b
+--R                        + 
+--R                                 3 4
+--R                          - 32B C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                               2 2 4       3 3 3
+--R                      (- 6A B C a b  + 8B C a b )c
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                      5 2 4
+--R                  - 8A a c
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2A a b  + (12A C + 4A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3A C - A B )a b  + (- 4A C  + 6A B C - 4A B )a b
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8A C  + 12A B C )a b + (8A C  - 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      A C a b  + (2A C  - 3A B C )a b  + (2A C  + 2B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - A C a b  + C a b
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12a c  + 3a b c)%%BM1  + (- 8a c  + 2a b c)%%BM0 %%BM1
+--R                     + 
+--R                             2 2       2       2     2                2
+--R                       (- 12a c  + 3a b c)%%BM0  + (A b + (- 4A C - 2B )a)c
+--R                     + 
+--R                        2
+--R                       C a b
+--R                  /
+--R                       2 2      2
+--R                     4a c  - a b c
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64A a b + (- 128A C + 256A B )a )c
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32A a b  + (64A C - 128A B )a b  - 64A C a b
+--R                          + 
+--R                                3 5
+--R                            128C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4A a b  + (- 8A C + 16A B )a b  + 32A C a b
+--R                          + 
+--R                                 3 4 2
+--R                            - 64C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4A C a b  + 8C a b )c
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                       3   3 4
+--R                  - 32A B a c
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                      + 
+--R                             3 4
+--R                        32B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6A B C a b  - 8B C a b )c
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64A a b + (- 128A C + 256A B )a )c
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32A a b  + (64A C - 128A B )a b  - 64A C a b
+--R                          + 
+--R                                3 5
+--R                            128C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4A a b  + (- 8A C + 16A B )a b  + 32A C a b
+--R                          + 
+--R                                 3 4 2
+--R                            - 64C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4A C a b  + 8C a b )c
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                      5 2 4
+--R                  - 8A a c
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2A a b  + (12A C + 4A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3A C - A B )a b  + (- 4A C  + 6A B C - 4A B )a b
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8A C  + 12A B C )a b + (8A C  - 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      A C a b  + (2A C  - 3A B C )a b  + (2A C  + 2B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - A C a b  + C a b
+--R             *
+--R                %%BM1
+--R            + 
+--R                       3   3 4
+--R                  - 32A B a c
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                      + 
+--R                             3 4
+--R                        32B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6A B C a b  - 8B C a b )c
+--R             *
+--R                     2
+--R                %%BM0
+--R            + 
+--R                      5 2 4
+--R                  - 8A a c
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2A a b  + (12A C + 4A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3A C - A B )a b  + (- 4A C  + 6A B C - 4A B )a b
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8A C  + 12A B C )a b + (8A C  - 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      A C a b  + (2A C  - 3A B C )a b  + (2A C  + 2B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - A C a b  + C a b
+--R             *
+--R                %%BM0
+--R            + 
+--R                    6   4
+--R                  4A a c
+--R                + 
+--R                         6 2        5      4 2
+--R                      - A b  + (- 4A C - 8A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      A C b  + (A C  + 8A B C)a b
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2A C a b  + (A C  + 8A B C )a b  + (- 4A C  - 8B C )a b
+--R                    + 
+--R                        6 4
+--R                      4C a
+--R                 *
+--R                    c
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  A C a b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                 5              4        3 3  2  3
+--R              (4A B a b + (- 12A B C + 4A B )a )c
+--R            + 
+--R                       4       3 3    2       3   2       5  2
+--R                  (- 7A B C - A B )a b  + (28A B C  - 4A B )a b
+--R                + 
+--R                        2   3       3 2     5   3
+--R                  (- 16A B C  - 4A B C  + 8B C)a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                 3   2   3         2   3      3 2  2 2          4 3        5 4
+--R              (3A B C a b  + (- 16A B C  + A B C )a b  + 16A B C a b - 4B C a )c
+--R            + 
+--R                   4 2 3      5 3 2
+--R              A B C a b  - B C a b
+--R     + 
+--R         2%%BM1
+--R      *
+--R         log
+--R                             3 3         2          2  4  4
+--R                      (- 128A a b + (256A C - 512A B )a )c
+--R                    + 
+--R                             3 2 3          2          2  3 2         2 4
+--R                          64A a b  + (- 128A C + 256A B )a b  + 128A C a b
+--R                        + 
+--R                                3 5
+--R                          - 256C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5       2         2  2 4        2 3 3
+--R                          - 8A a b  + (16A C - 32A B )a b  - 64A C a b
+--R                        + 
+--R                              3 4 2
+--R                          128C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                           2 2 5      3 3 4
+--R                      (8A C a b  - 16C a b )c
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                     3   3 4
+--R                  64A B a c
+--R                + 
+--R                          2           3  3             2       3   4  3
+--R                  ((- 192A B C + 64A B )a b + (192A B C  - 128B C)a )c
+--R                + 
+--R                          3     4       2           3  2 3      3   3 2
+--R                      - 4A B a b  + (48A B C - 16A B )a b  + 32B C a b
+--R                    + 
+--R                             3 4
+--R                      - 64B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                            2 2 4        3 3 3
+--R                  (- 12A B C a b  + 16B C a b )c
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                             3 3         2          2  4  4
+--R                      (- 128A a b + (256A C - 512A B )a )c
+--R                    + 
+--R                             3 2 3          2          2  3 2         2 4
+--R                          64A a b  + (- 128A C + 256A B )a b  + 128A C a b
+--R                        + 
+--R                                3 5
+--R                          - 256C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5       2         2  2 4        2 3 3
+--R                          - 8A a b  + (16A C - 32A B )a b  - 64A C a b
+--R                        + 
+--R                              3 4 2
+--R                          128C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                           2 2 5      3 3 4
+--R                      (8A C a b  - 16C a b )c
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                     5 2 4
+--R                  16A a c
+--R                + 
+--R                       5   2         4      3 2  2        2 2         4  3  3
+--R                  (- 4A a b  + (- 24A C - 8A B )a b + (48A B C - 32A B )a )c
+--R                + 
+--R                         4      3 2    3      3 2      2 2        4  2 2
+--R                      (6A C + 2A B )a b  + (8A C  - 12A B C + 8A B )a b
+--R                    + 
+--R                          2 3        2 2  3            4      2 3  4
+--R                      (16A C  - 24A B C )a b + (- 16A C  + 16B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3 2   4        2 3       2 2  2 3
+--R                      - 2A C a b  + (- 4A C  + 6A B C )a b
+--R                    + 
+--R                             4     2 3  3 2     5 4
+--R                      (- 4A C  - 4B C )a b  + 8C a b
+--R                 *
+--R                    c
+--R                + 
+--R                      4 2 4     5 3 3
+--R                  2A C a b  - 2C a b
+--R             *
+--R                %%BM1
+--R            + 
+--R                         3 3         2          2  4  4
+--R                  (- 128A a b + (256A C - 512A B )a )c
+--R                + 
+--R                      3 2 3          2          2  3 2         2 4        3 5  3
+--R                  (64A a b  + (- 128A C + 256A B )a b  + 128A C a b - 256C a )c
+--R                + 
+--R                       3   5       2         2  2 4        2 3 3       3 4 2  2
+--R                  (- 8A a b  + (16A C - 32A B )a b  - 64A C a b  + 128C a b )c
+--R                + 
+--R                       2 2 5      3 3 4
+--R                  (8A C a b  - 16C a b )c
+--R             *
+--R                     3
+--R                %%BM0
+--R            + 
+--R                        5   2         4       3 2  2
+--R                      8A a b  + (- 48A C + 16A B )a b
+--R                    + 
+--R                          3 2      2 2         4  3
+--R                      (64A C  - 96A B C - 64A B )a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          5 4       4      3 2    3
+--R                      - 2A b  + (12A C - 4A B )a b
+--R                    + 
+--R                            3 2      2 2         4  2 2       2 3        2 2  3
+--R                      (- 16A C  + 24A B C + 16A B )a b  + (32A C  + 48A B C )a b
+--R                    + 
+--R                              4      2 3  4
+--R                      (- 64A C  - 32B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 3        2 2  2 3        4     2 3  3 2      5 4
+--R                  ((- 8A C  - 12A B C )a b  + (8A C  + 8B C )a b  + 16C a b)c
+--R                + 
+--R                      4 2 4     5 3 3
+--R                  2A C a b  - 4C a b
+--R             *
+--R                %%BM0
+--R            + 
+--R                    6   4
+--R                  4A a c
+--R                + 
+--R                         6 2        5      4 2
+--R                      - A b  + (- 4A C - 8A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      A C b  + (A C  + 8A B C)a b
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2A C a b  + (A C  + 8A B C )a b  + (- 4A C  - 8B C )a b
+--R                    + 
+--R                        6 4
+--R                      4C a
+--R                 *
+--R                    c
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  A C a b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                 4         3 3  2 3
+--R              (4A B C + 12A B )a c
+--R            + 
+--R                     5   3      4        3 3    2         3   2       5  2
+--R                  - A B b  + (9A B C - 3A B )a b  + (- 36A B C  + 4A B )a b
+--R                + 
+--R                      2   3        3 2     5   3
+--R                  (32A B C  - 12A B C  - 8B C)a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                  3   2   3       2   3       3 2  2 2          4 3        5 4
+--R              (- A B C a b  + (12A B C  + 3A B C )a b  - 12A B C a b - 4B C a )c
+--R            + 
+--R                      4 2 3       5 3 2
+--R              - 2A B C a b  + 3B C a b
+--R     + 
+--R         2%%BM0
+--R      *
+--R         log
+--R                       3 3           2          2  4  4
+--R                  (128A a b + (- 256A C + 512A B )a )c
+--R                + 
+--R                        3 2 3        2          2  3 2         2 4        3 5  3
+--R                  (- 64A a b  + (128A C - 256A B )a b  - 128A C a b + 256C a )c
+--R                + 
+--R                     3   5         2         2  2 4        2 3 3       3 4 2  2
+--R                  (8A a b  + (- 16A C + 32A B )a b  + 64A C a b  - 128C a b )c
+--R                + 
+--R                         2 2 5      3 3 4
+--R                  (- 8A C a b  + 16C a b )c
+--R             *
+--R                     3
+--R                %%BM0
+--R            + 
+--R                     3   3 4
+--R                  64A B a c
+--R                + 
+--R                          2           3  3             2       3   4  3
+--R                  ((- 192A B C + 64A B )a b + (192A B C  - 128B C)a )c
+--R                + 
+--R                          3     4       2           3  2 3      3   3 2
+--R                      - 4A B a b  + (48A B C - 16A B )a b  + 32B C a b
+--R                    + 
+--R                             3 4
+--R                      - 64B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                            2 2 4        3 3 3
+--R                  (- 12A B C a b  + 16B C a b )c
+--R             *
+--R                     2
+--R                %%BM0
+--R            + 
+--R                     5 2 4
+--R                  16A a c
+--R                + 
+--R                           5   2       4       3 2  2
+--R                      - 12A a b  + (24A C - 24A B )a b
+--R                    + 
+--R                            3 2       2 2         4  3
+--R                      (- 64A C  + 144A B C + 32A B )a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                        5 4        4      3 2    3
+--R                      2A b  + (- 6A C + 6A B )a b
+--R                    + 
+--R                          3 2      2 2        4  2 2         2 3        2 2  3
+--R                      (24A C  - 36A B C - 8A B )a b  + (- 16A C  - 72A B C )a b
+--R                    + 
+--R                            4      2 3  4
+--R                      (48A C  + 48B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3 2   4      2 3        2 2  2 3
+--R                      - 2A C a b  + (4A C  + 18A B C )a b
+--R                    + 
+--R                              4      2 3  3 2     5 4
+--R                      (- 12A C  - 12B C )a b  - 8C a b
+--R                 *
+--R                    c
+--R                + 
+--R                    5 3 3
+--R                  2C a b
+--R             *
+--R                %%BM0
+--R            + 
+--R                    6   4
+--R                  4A a c
+--R                + 
+--R                         6 2        5      4 2
+--R                      - A b  + (- 4A C - 8A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      A C b  + (A C  + 8A B C)a b
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2A C a b  + (A C  + 8A B C )a b  + (- 4A C  - 8B C )a b
+--R                    + 
+--R                        6 4
+--R                      4C a
+--R                 *
+--R                    c
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  A C a b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                   5            4         3 3  2  3
+--R              (- 8A B a b + (20A B C - 20A B )a )c
+--R            + 
+--R                   5   3      4        3 3    2         3   2       5  2
+--R                  A B b  + (5A B C + 5A B )a b  + (- 20A B C  + 4A B )a b
+--R                + 
+--R                        3 2     5   3
+--R                  (20A B C  - 8B C)a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                      3   2   3       2   3       3 2  2 2          4 3
+--R                  - 5A B C a b  + (20A B C  - 5A B C )a b  - 20A B C a b
+--R                + 
+--R                       5 4
+--R                  12B C a
+--R             *
+--R                c
+--R            + 
+--R                   5 3 2
+--R              - B C a b
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 496
+
+--S 497 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    +--------------------+ +------------------+
+--R                  +-----------+     |   +-----------+      | +-----------+
+--R              +-+ |          2  +-+ |   |          2       | |          2
+--R             \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R          *
+--R             ROOT
+--R                          2 2       2       2        2 2       2
+--R                    (- 12a c  + 3a b c)%%BM1  + (- 8a c  + 2a b c)%%BM0 %%BM1
+--R                  + 
+--R                        2 2       2       2     2                2        2
+--R                  (- 12a c  + 3a b c)%%BM0  + (A b + (- 4A C - 2B )a)c + C a b
+--R               /
+--R                    2 2      2
+--R                  4a c  - a b c
+--R         + 
+--R           -
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R                 +-+ |          2  +-+ |   |          2
+--R                \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b %%BM1
+--R         + 
+--R           -
+--R                                            +--------------------+
+--R                     +-----------+          |   +-----------+
+--R                 +-+ |          2  +-+      |   |          2
+--R                \|2 \|- 4a c + b  \|c %%BM0\|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                              3 3           2          2  4  4
+--R                          (64A a b + (- 128A C + 256A B )a )c
+--R                        + 
+--R                                   3 2 3       2          2  3 2        2 4
+--R                              - 32A a b  + (64A C - 128A B )a b  - 64A C a b
+--R                            + 
+--R                                  3 5
+--R                              128C a
+--R                         *
+--R                             3
+--R                            c
+--R                        + 
+--R                                3   5        2         2  2 4        2 3 3
+--R                              4A a b  + (- 8A C + 16A B )a b  + 32A C a b
+--R                            + 
+--R                                   3 4 2
+--R                              - 64C a b
+--R                         *
+--R                             2
+--R                            c
+--R                        + 
+--R                                 2 2 5     3 3 4
+--R                          (- 4A C a b  + 8C a b )c
+--R                     *
+--R                        %%BM0
+--R                    + 
+--R                           3   3 4
+--R                      - 32A B a c
+--R                    + 
+--R                           2           3  3              2      3   4  3
+--R                      ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                    + 
+--R                            3     4         2          3  2 3      3   3 2
+--R                          2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                        + 
+--R                               3 4
+--R                          32B C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 4       3 3 3
+--R                      (6A B C a b  - 8B C a b )c
+--R                 *
+--R                    %%BM1
+--R                + 
+--R                           3   3 4
+--R                      - 32A B a c
+--R                    + 
+--R                           2           3  3              2      3   4  3
+--R                      ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                    + 
+--R                            3     4         2          3  2 3      3   3 2
+--R                          2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                        + 
+--R                               3 4
+--R                          32B C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 4       3 3 3
+--R                      (6A B C a b  - 8B C a b )c
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                    5 2 4
+--R                  8A a c
+--R                + 
+--R                       5   2         4      3 2  2        2 2         4  3  3
+--R                  (- 2A a b  + (- 12A C - 4A B )a b + (24A B C - 16A B )a )c
+--R                + 
+--R                         4     3 2    3      3 2     2 2        4  2 2
+--R                      (3A C + A B )a b  + (4A C  - 6A B C + 4A B )a b
+--R                    + 
+--R                         2 3        2 2  3           4     2 3  4
+--R                      (8A C  - 12A B C )a b + (- 8A C  + 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         3 2   4        2 3       2 2  2 3
+--R                      - A C a b  + (- 2A C  + 3A B C )a b
+--R                    + 
+--R                             4     2 3  3 2     5 4
+--R                      (- 2A C  - 2B C )a b  + 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                     4 2 4    5 3 3
+--R                  A C a b  - C a b
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12a c  + 3a b c)%%BM1  + (- 8a c  + 2a b c)%%BM0 %%BM1
+--R                     + 
+--R                             2 2       2       2     2                2
+--R                       (- 12a c  + 3a b c)%%BM0  + (A b + (- 4A C - 2B )a)c
+--R                     + 
+--R                        2
+--R                       C a b
+--R                  /
+--R                       2 2      2
+--R                     4a c  - a b c
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64A a b + (- 128A C + 256A B )a )c
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32A a b  + (64A C - 128A B )a b  - 64A C a b
+--R                          + 
+--R                                3 5
+--R                            128C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4A a b  + (- 8A C + 16A B )a b  + 32A C a b
+--R                          + 
+--R                                 3 4 2
+--R                            - 64C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4A C a b  + 8C a b )c
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                       3   3 4
+--R                  - 32A B a c
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                      + 
+--R                             3 4
+--R                        32B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6A B C a b  - 8B C a b )c
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64A a b + (- 128A C + 256A B )a )c
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32A a b  + (64A C - 128A B )a b  - 64A C a b
+--R                          + 
+--R                                3 5
+--R                            128C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4A a b  + (- 8A C + 16A B )a b  + 32A C a b
+--R                          + 
+--R                                 3 4 2
+--R                            - 64C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4A C a b  + 8C a b )c
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                      5 2 4
+--R                  - 8A a c
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2A a b  + (12A C + 4A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3A C - A B )a b  + (- 4A C  + 6A B C - 4A B )a b
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8A C  + 12A B C )a b + (8A C  - 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      A C a b  + (2A C  - 3A B C )a b  + (2A C  + 2B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - A C a b  + C a b
+--R             *
+--R                %%BM1
+--R            + 
+--R                       3   3 4
+--R                  - 32A B a c
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                      + 
+--R                             3 4
+--R                        32B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6A B C a b  - 8B C a b )c
+--R             *
+--R                     2
+--R                %%BM0
+--R            + 
+--R                      5 2 4
+--R                  - 8A a c
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2A a b  + (12A C + 4A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3A C - A B )a b  + (- 4A C  + 6A B C - 4A B )a b
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8A C  + 12A B C )a b + (8A C  - 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      A C a b  + (2A C  - 3A B C )a b  + (2A C  + 2B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - A C a b  + C a b
+--R             *
+--R                %%BM0
+--R            + 
+--R                    6   4
+--R                  4A a c
+--R                + 
+--R                         6 2        5      4 2
+--R                      - A b  + (- 4A C - 8A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      A C b  + (A C  + 8A B C)a b
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2A C a b  + (A C  + 8A B C )a b  + (- 4A C  - 8B C )a b
+--R                    + 
+--R                        6 4
+--R                      4C a
+--R                 *
+--R                    c
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  A C a b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                 5              4        3 3  2  3
+--R              (4A B a b + (- 12A B C + 4A B )a )c
+--R            + 
+--R                       4       3 3    2       3   2       5  2
+--R                  (- 7A B C - A B )a b  + (28A B C  - 4A B )a b
+--R                + 
+--R                        2   3       3 2     5   3
+--R                  (- 16A B C  - 4A B C  + 8B C)a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                 3   2   3         2   3      3 2  2 2          4 3        5 4
+--R              (3A B C a b  + (- 16A B C  + A B C )a b  + 16A B C a b - 4B C a )c
+--R            + 
+--R                   4 2 3      5 3 2
+--R              A B C a b  - B C a b
+--R     + 
+--R           -
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R                 +-+ |          2  +-+ |   |          2
+--R                \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12a c  + 3a b c)%%BM1  + (- 8a c  + 2a b c)%%BM0 %%BM1
+--R                     + 
+--R                             2 2       2       2     2                2
+--R                       (- 12a c  + 3a b c)%%BM0  + (A b + (- 4A C - 2B )a)c
+--R                     + 
+--R                        2
+--R                       C a b
+--R                  /
+--R                       2 2      2
+--R                     4a c  - a b c
+--R         + 
+--R           -
+--R                                       +--------------------+
+--R                     +-----------+     |   +-----------+
+--R                 +-+ |          2  +-+ |   |          2
+--R                \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b %%BM1
+--R         + 
+--R           -
+--R                                            +--------------------+
+--R                     +-----------+          |   +-----------+
+--R                 +-+ |          2  +-+      |   |          2
+--R                \|2 \|- 4a c + b  \|c %%BM0\|- \|- 4a c + b   + b
+--R             *
+--R                 +------------------+
+--R                 | +-----------+
+--R                 | |          2
+--R                \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R                                3 3         2          2  4  4
+--R                          (- 64A a b + (128A C - 256A B )a )c
+--R                        + 
+--R                                 3 2 3         2          2  3 2        2 4
+--R                              32A a b  + (- 64A C + 128A B )a b  + 64A C a b
+--R                            + 
+--R                                    3 5
+--R                              - 128C a
+--R                         *
+--R                             3
+--R                            c
+--R                        + 
+--R                                  3   5      2         2  2 4        2 3 3
+--R                              - 4A a b  + (8A C - 16A B )a b  - 32A C a b
+--R                            + 
+--R                                 3 4 2
+--R                              64C a b
+--R                         *
+--R                             2
+--R                            c
+--R                        + 
+--R                               2 2 5     3 3 4
+--R                          (4A C a b  - 8C a b )c
+--R                     *
+--R                        %%BM0
+--R                    + 
+--R                         3   3 4
+--R                      32A B a c
+--R                    + 
+--R                             2           3  3            2      3   4  3
+--R                      ((- 96A B C + 32A B )a b + (96A B C  - 64B C)a )c
+--R                    + 
+--R                              3     4       2          3  2 3      3   3 2
+--R                          - 2A B a b  + (24A B C - 8A B )a b  + 16B C a b
+--R                        + 
+--R                                 3 4
+--R                          - 32B C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                               2 2 4       3 3 3
+--R                      (- 6A B C a b  + 8B C a b )c
+--R                 *
+--R                    %%BM1
+--R                + 
+--R                         3   3 4
+--R                      32A B a c
+--R                    + 
+--R                             2           3  3            2      3   4  3
+--R                      ((- 96A B C + 32A B )a b + (96A B C  - 64B C)a )c
+--R                    + 
+--R                              3     4       2          3  2 3      3   3 2
+--R                          - 2A B a b  + (24A B C - 8A B )a b  + 16B C a b
+--R                        + 
+--R                                 3 4
+--R                          - 32B C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                               2 2 4       3 3 3
+--R                      (- 6A B C a b  + 8B C a b )c
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                      5 2 4
+--R                  - 8A a c
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2A a b  + (12A C + 4A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3A C - A B )a b  + (- 4A C  + 6A B C - 4A B )a b
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8A C  + 12A B C )a b + (8A C  - 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      A C a b  + (2A C  - 3A B C )a b  + (2A C  + 2B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - A C a b  + C a b
+--R             *
+--R                ROOT
+--R                             2 2       2       2        2 2       2
+--R                       (- 12a c  + 3a b c)%%BM1  + (- 8a c  + 2a b c)%%BM0 %%BM1
+--R                     + 
+--R                             2 2       2       2     2                2
+--R                       (- 12a c  + 3a b c)%%BM0  + (A b + (- 4A C - 2B )a)c
+--R                     + 
+--R                        2
+--R                       C a b
+--R                  /
+--R                       2 2      2
+--R                     4a c  - a b c
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64A a b + (- 128A C + 256A B )a )c
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32A a b  + (64A C - 128A B )a b  - 64A C a b
+--R                          + 
+--R                                3 5
+--R                            128C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4A a b  + (- 8A C + 16A B )a b  + 32A C a b
+--R                          + 
+--R                                 3 4 2
+--R                            - 64C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4A C a b  + 8C a b )c
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                       3   3 4
+--R                  - 32A B a c
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                      + 
+--R                             3 4
+--R                        32B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6A B C a b  - 8B C a b )c
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                          3 3           2          2  4  4
+--R                      (64A a b + (- 128A C + 256A B )a )c
+--R                    + 
+--R                                 3 2 3       2          2  3 2        2 4
+--R                            - 32A a b  + (64A C - 128A B )a b  - 64A C a b
+--R                          + 
+--R                                3 5
+--R                            128C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5        2         2  2 4        2 3 3
+--R                            4A a b  + (- 8A C + 16A B )a b  + 32A C a b
+--R                          + 
+--R                                 3 4 2
+--R                            - 64C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 5     3 3 4
+--R                      (- 4A C a b  + 8C a b )c
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                      5 2 4
+--R                  - 8A a c
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2A a b  + (12A C + 4A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3A C - A B )a b  + (- 4A C  + 6A B C - 4A B )a b
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8A C  + 12A B C )a b + (8A C  - 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      A C a b  + (2A C  - 3A B C )a b  + (2A C  + 2B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - A C a b  + C a b
+--R             *
+--R                %%BM1
+--R            + 
+--R                       3   3 4
+--R                  - 32A B a c
+--R                + 
+--R                       2           3  3              2      3   4  3
+--R                  ((96A B C - 32A B )a b + (- 96A B C  + 64B C)a )c
+--R                + 
+--R                          3     4         2          3  2 3      3   3 2
+--R                        2A B a b  + (- 24A B C + 8A B )a b  - 16B C a b
+--R                      + 
+--R                             3 4
+--R                        32B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                         2 2 4       3 3 3
+--R                  (6A B C a b  - 8B C a b )c
+--R             *
+--R                     2
+--R                %%BM0
+--R            + 
+--R                      5 2 4
+--R                  - 8A a c
+--R                + 
+--R                     5   2       4      3 2  2          2 2         4  3  3
+--R                  (2A a b  + (12A C + 4A B )a b + (- 24A B C + 16A B )a )c
+--R                + 
+--R                           4     3 2    3        3 2     2 2        4  2 2
+--R                      (- 3A C - A B )a b  + (- 4A C  + 6A B C - 4A B )a b
+--R                    + 
+--R                           2 3        2 2  3         4     2 3  4
+--R                      (- 8A C  + 12A B C )a b + (8A C  - 8B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                       3 2   4      2 3       2 2  2 3        4     2 3  3 2
+--R                      A C a b  + (2A C  - 3A B C )a b  + (2A C  + 2B C )a b
+--R                    + 
+--R                          5 4
+--R                      - 4C a b
+--R                 *
+--R                    c
+--R                + 
+--R                       4 2 4    5 3 3
+--R                  - A C a b  + C a b
+--R             *
+--R                %%BM0
+--R            + 
+--R                    6   4
+--R                  4A a c
+--R                + 
+--R                         6 2        5      4 2
+--R                      - A b  + (- 4A C - 8A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      A C b  + (A C  + 8A B C)a b
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2A C a b  + (A C  + 8A B C )a b  + (- 4A C  - 8B C )a b
+--R                    + 
+--R                        6 4
+--R                      4C a
+--R                 *
+--R                    c
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  A C a b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                 5              4        3 3  2  3
+--R              (4A B a b + (- 12A B C + 4A B )a )c
+--R            + 
+--R                       4       3 3    2       3   2       5  2
+--R                  (- 7A B C - A B )a b  + (28A B C  - 4A B )a b
+--R                + 
+--R                        2   3       3 2     5   3
+--R                  (- 16A B C  - 4A B C  + 8B C)a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                 3   2   3         2   3      3 2  2 2          4 3        5 4
+--R              (3A B C a b  + (- 16A B C  + A B C )a b  + 16A B C a b - 4B C a )c
+--R            + 
+--R                   4 2 3      5 3 2
+--R              A B C a b  - B C a b
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R         2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R      *
+--R         %%BM1
+--R      *
+--R         log
+--R                             3 3         2          2  4  4
+--R                      (- 128A a b + (256A C - 512A B )a )c
+--R                    + 
+--R                             3 2 3          2          2  3 2         2 4
+--R                          64A a b  + (- 128A C + 256A B )a b  + 128A C a b
+--R                        + 
+--R                                3 5
+--R                          - 256C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5       2         2  2 4        2 3 3
+--R                          - 8A a b  + (16A C - 32A B )a b  - 64A C a b
+--R                        + 
+--R                              3 4 2
+--R                          128C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                           2 2 5      3 3 4
+--R                      (8A C a b  - 16C a b )c
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                     3   3 4
+--R                  64A B a c
+--R                + 
+--R                          2           3  3             2       3   4  3
+--R                  ((- 192A B C + 64A B )a b + (192A B C  - 128B C)a )c
+--R                + 
+--R                          3     4       2           3  2 3      3   3 2
+--R                      - 4A B a b  + (48A B C - 16A B )a b  + 32B C a b
+--R                    + 
+--R                             3 4
+--R                      - 64B C a b
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                            2 2 4        3 3 3
+--R                  (- 12A B C a b  + 16B C a b )c
+--R             *
+--R                     2
+--R                %%BM1
+--R            + 
+--R                             3 3         2          2  4  4
+--R                      (- 128A a b + (256A C - 512A B )a )c
+--R                    + 
+--R                             3 2 3          2          2  3 2         2 4
+--R                          64A a b  + (- 128A C + 256A B )a b  + 128A C a b
+--R                        + 
+--R                                3 5
+--R                          - 256C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                              3   5       2         2  2 4        2 3 3
+--R                          - 8A a b  + (16A C - 32A B )a b  - 64A C a b
+--R                        + 
+--R                              3 4 2
+--R                          128C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                           2 2 5      3 3 4
+--R                      (8A C a b  - 16C a b )c
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                     5 2 4
+--R                  16A a c
+--R                + 
+--R                       5   2         4      3 2  2        2 2         4  3  3
+--R                  (- 4A a b  + (- 24A C - 8A B )a b + (48A B C - 32A B )a )c
+--R                + 
+--R                         4      3 2    3      3 2      2 2        4  2 2
+--R                      (6A C + 2A B )a b  + (8A C  - 12A B C + 8A B )a b
+--R                    + 
+--R                          2 3        2 2  3            4      2 3  4
+--R                      (16A C  - 24A B C )a b + (- 16A C  + 16B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3 2   4        2 3       2 2  2 3
+--R                      - 2A C a b  + (- 4A C  + 6A B C )a b
+--R                    + 
+--R                             4     2 3  3 2     5 4
+--R                      (- 4A C  - 4B C )a b  + 8C a b
+--R                 *
+--R                    c
+--R                + 
+--R                      4 2 4     5 3 3
+--R                  2A C a b  - 2C a b
+--R             *
+--R                %%BM1
+--R            + 
+--R                         3 3         2          2  4  4
+--R                  (- 128A a b + (256A C - 512A B )a )c
+--R                + 
+--R                      3 2 3          2          2  3 2         2 4        3 5  3
+--R                  (64A a b  + (- 128A C + 256A B )a b  + 128A C a b - 256C a )c
+--R                + 
+--R                       3   5       2         2  2 4        2 3 3       3 4 2  2
+--R                  (- 8A a b  + (16A C - 32A B )a b  - 64A C a b  + 128C a b )c
+--R                + 
+--R                       2 2 5      3 3 4
+--R                  (8A C a b  - 16C a b )c
+--R             *
+--R                     3
+--R                %%BM0
+--R            + 
+--R                        5   2         4       3 2  2
+--R                      8A a b  + (- 48A C + 16A B )a b
+--R                    + 
+--R                          3 2      2 2         4  3
+--R                      (64A C  - 96A B C - 64A B )a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          5 4       4      3 2    3
+--R                      - 2A b  + (12A C - 4A B )a b
+--R                    + 
+--R                            3 2      2 2         4  2 2       2 3        2 2  3
+--R                      (- 16A C  + 24A B C + 16A B )a b  + (32A C  + 48A B C )a b
+--R                    + 
+--R                              4      2 3  4
+--R                      (- 64A C  - 32B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                        2 3        2 2  2 3        4     2 3  3 2      5 4
+--R                  ((- 8A C  - 12A B C )a b  + (8A C  + 8B C )a b  + 16C a b)c
+--R                + 
+--R                      4 2 4     5 3 3
+--R                  2A C a b  - 4C a b
+--R             *
+--R                %%BM0
+--R            + 
+--R                    6   4
+--R                  4A a c
+--R                + 
+--R                         6 2        5      4 2
+--R                      - A b  + (- 4A C - 8A B )a b
+--R                    + 
+--R                           4 2      3 2       2 4  2
+--R                      (- 4A C  + 32A B C - 16A B )a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                       5   3     4 2     3 2     2
+--R                      A C b  + (A C  + 8A B C)a b
+--R                    + 
+--R                         3 3      2 2 2        4   2
+--R                      (8A C  - 48A B C  + 16A B C)a b
+--R                    + 
+--R                           2 4        2 3      4 2  3
+--R                      (- 4A C  + 32A B C  - 16B C )a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3 3   3     2 4       2 3  2 2          5     2 4  3
+--R                      - 2A C a b  + (A C  + 8A B C )a b  + (- 4A C  - 8B C )a b
+--R                    + 
+--R                        6 4
+--R                      4C a
+--R                 *
+--R                    c
+--R                + 
+--R                     5 2 3    6 3 2
+--R                  A C a b  - C a b
+--R             *
+--R                x
+--R            + 
+--R                 4         3 3  2 3
+--R              (4A B C + 12A B )a c
+--R            + 
+--R                     5   3      4        3 3    2         3   2       5  2
+--R                  - A B b  + (9A B C - 3A B )a b  + (- 36A B C  + 4A B )a b
+--R                + 
+--R                      2   3        3 2     5   3
+--R                  (32A B C  - 12A B C  - 8B C)a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                  3   2   3       2   3       3 2  2 2          4 3        5 4
+--R              (- A B C a b  + (12A B C  + 3A B C )a b  - 12A B C a b - 4B C a )c
+--R            + 
+--R                      4 2 3       5 3 2
+--R              - 2A B C a b  + 3B C a b
+--R     + 
+--R                                            +------------------+
+--R               +-----------+                | +-----------+
+--R               |          2                 | |          2
+--R         (- 2C\|- 4a c + b   - 4A c + 2C b)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R               +-----------+                |   +-----------+
+--R               |          2                 |   |          2
+--R         (- 2C\|- 4a c + b   + 4A c - 2C b)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                   +-----------+
+--R               +-+ |          2  +-+
+--R             2\|2 \|- 4a c + b  \|c %%BM0
+--R          *
+--R             log
+--R                           3 3           2          2  4  4
+--R                      (128A a b + (- 256A C + 512A B )a )c
+--R                    + 
+--R                               3 2 3        2          2  3 2         2 4
+--R                          - 64A a b  + (128A C - 256A B )a b  - 128A C a b
+--R                        + 
+--R                              3 5
+--R                          256C a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                            3   5         2         2  2 4        2 3 3
+--R                          8A a b  + (- 16A C + 32A B )a b  + 64A C a b
+--R                        + 
+--R                                3 4 2
+--R                          - 128C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                             2 2 5      3 3 4
+--R                      (- 8A C a b  + 16C a b )c
+--R                 *
+--R                         3
+--R                    %%BM0
+--R                + 
+--R                         3   3 4
+--R                      64A B a c
+--R                    + 
+--R                              2           3  3             2       3   4  3
+--R                      ((- 192A B C + 64A B )a b + (192A B C  - 128B C)a )c
+--R                    + 
+--R                              3     4       2           3  2 3      3   3 2
+--R                          - 4A B a b  + (48A B C - 16A B )a b  + 32B C a b
+--R                        + 
+--R                                 3 4
+--R                          - 64B C a b
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                2 2 4        3 3 3
+--R                      (- 12A B C a b  + 16B C a b )c
+--R                 *
+--R                         2
+--R                    %%BM0
+--R                + 
+--R                         5 2 4
+--R                      16A a c
+--R                    + 
+--R                               5   2       4       3 2  2
+--R                          - 12A a b  + (24A C - 24A B )a b
+--R                        + 
+--R                                3 2       2 2         4  3
+--R                          (- 64A C  + 144A B C + 32A B )a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                            5 4        4      3 2    3
+--R                          2A b  + (- 6A C + 6A B )a b
+--R                        + 
+--R                              3 2      2 2        4  2 2
+--R                          (24A C  - 36A B C - 8A B )a b
+--R                        + 
+--R                                2 3        2 2  3          4      2 3  4
+--R                          (- 16A C  - 72A B C )a b + (48A C  + 48B C )a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3 2   4      2 3        2 2  2 3
+--R                          - 2A C a b  + (4A C  + 18A B C )a b
+--R                        + 
+--R                                  4      2 3  3 2     5 4
+--R                          (- 12A C  - 12B C )a b  - 8C a b
+--R                     *
+--R                        c
+--R                    + 
+--R                        5 3 3
+--R                      2C a b
+--R                 *
+--R                    %%BM0
+--R                + 
+--R                        6   4
+--R                      4A a c
+--R                    + 
+--R                             6 2        5      4 2
+--R                          - A b  + (- 4A C - 8A B )a b
+--R                        + 
+--R                               4 2      3 2       2 4  2
+--R                          (- 4A C  + 32A B C - 16A B )a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                           5   3     4 2     3 2     2
+--R                          A C b  + (A C  + 8A B C)a b
+--R                        + 
+--R                             3 3      2 2 2        4   2
+--R                          (8A C  - 48A B C  + 16A B C)a b
+--R                        + 
+--R                               2 4        2 3      4 2  3
+--R                          (- 4A C  + 32A B C  - 16B C )a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3 3   3     2 4       2 3  2 2
+--R                          - 2A C a b  + (A C  + 8A B C )a b
+--R                        + 
+--R                                 5     2 4  3      6 4
+--R                          (- 4A C  - 8B C )a b + 4C a
+--R                     *
+--R                        c
+--R                    + 
+--R                         5 2 3    6 3 2
+--R                      A C a b  - C a b
+--R                 *
+--R                    x
+--R                + 
+--R                       5            4         3 3  2  3
+--R                  (- 8A B a b + (20A B C - 20A B )a )c
+--R                + 
+--R                       5   3      4        3 3    2         3   2       5  2
+--R                      A B b  + (5A B C + 5A B )a b  + (- 20A B C  + 4A B )a b
+--R                    + 
+--R                            3 2     5   3
+--R                      (20A B C  - 8B C)a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3   2   3       2   3       3 2  2 2          4 3
+--R                      - 5A B C a b  + (20A B C  - 5A B C )a b  - 20A B C a b
+--R                    + 
+--R                           5 4
+--R                      12B C a
+--R                 *
+--R                    c
+--R                + 
+--R                       5 3 2
+--R                  - B C a b
+--R         + 
+--R                                  2
+--R              +-+ +-+         2c x  + b
+--R           2B\|2 \|c atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     2\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 1070
+t0:=(A+B*x+C*x^2)/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          C x  + B x + A
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 499
+
+--S 500 of 1070
+r0:=A*log(x)/a-1/4*A*log(a+b*x^2+c*x^4)/a+1/2*(A*b-2*a*C)*atanh((b+_
+   2*c*x^2)/sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))+B*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*_
+   sqrt(b-sqrt(b^2-4*a*c)))-B*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                    +------------------+
+--R                    | +-----------+                   +-+ +-+
+--R            +-+ +-+ | |          2                  x\|2 \|c
+--R       4B a\|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                              +--------------------+
+--R                                              |   +-----------+
+--R                                              |   |          2
+--R                                             \|- \|- 4a c + b   + b
+--R     + 
+--R                      +--------------------+
+--R                      |   +-----------+                  +-+ +-+
+--R              +-+ +-+ |   |          2                 x\|2 \|c
+--R       - 4B a\|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                                  +------------------+
+--R                                                  | +-----------+
+--R                                                  | |          2
+--R                                                 \|\|- 4a c + b   + b
+--R     + 
+--R                                     2
+--R                                 2c x  + b
+--R           (2A b - 4C a)atanh(--------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R         + 
+--R                                                  +-----------+
+--R                       4      2                   |          2
+--R           (- A log(c x  + b x  + a) + 4A log(x))\|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R     4a\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 1070
+--a0:=integrate(t0,x)
+--E 501
+
+--S 502 of 1070
+--m0:=a0-r0
+--E 502
+
+--S 503 of 1070
+--d0:=normalize(D(m0,x))
+--E 503
+
+)clear all
+
+--S 504 of 1070
+t0:=(A+B*x+C*x^2)/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          C x  + B x + A
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 504
+
+--S 505 of 1070
+r0:=-A/(a*x)+B*log(x)/a-1/4*B*log(a+b*x^2+c*x^4)/a+1/2*b*B*atanh((b+_
+   2*c*x^2)/sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))-atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(A+(A*b-2*a*C)/sqrt(b^2-_
+   4*a*c))/(a*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(A+(-A*b+2*a*C)/sqrt(b^2-4*a*c))/_
+   (a*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                       +------------------+
+--R                 +-----------+                         | +-----------+
+--R                 |          2                      +-+ | |          2
+--R         (- 4A x\|- 4a c + b   + (- 4A b + 8C a)x)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                 +-----------+                       |   +-----------+
+--R                 |          2                    +-+ |   |          2
+--R         (- 4A x\|- 4a c + b   + (4A b - 8C a)x)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                  2
+--R                  +-+         2c x  + b
+--R           2B b x\|2 atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R         + 
+--R                                                                   +-----------+
+--R                +-+       4      2             +-+            +-+  |          2
+--R         (- B x\|2 log(c x  + b x  + a) + 4B x\|2 log(x) - 4A\|2 )\|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R     4a x\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 1070
+--a0:=integrate(t0,x)
+--E 506
+
+--S 507 of 1070
+--m0:=a0-r0
+--E 507
+
+--S 508 of 1070
+--d0:=normalize(D(m0,x))
+--E 508
+
+)clear all
+
+--S 509 of 1070
+t0:=(A+B*x+C*x^2)/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          C x  + B x + A
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 509
+
+--S 510 of 1070
+r0:=-1/2*A/(a*x^2)-B/(a*x)-(A*b-a*C)*log(x)/a^2+1/4*(A*b-a*C)*_
+   log(a+b*x^2+c*x^4)/a^2-1/2*(A*(b^2-2*a*c)-a*b*C)*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))-B*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(1+b/sqrt(b^2-4*a*c))/(a*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))-B*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(1-b/sqrt(b^2-4*a*c))/(a*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                   +------------------+
+--R                    +-----------+                  | +-----------+
+--R                  2 |          2            2  +-+ | |          2
+--R         (- 4B a x \|- 4a c + b   - 4B a b x )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                   +--------------------+
+--R                    +-----------+                  |   +-----------+
+--R                  2 |          2            2  +-+ |   |          2
+--R         (- 4B a x \|- 4a c + b   + 4B a b x )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                                       2
+--R                         2           2 +-+         2c x  + b
+--R           (4A a c - 2A b  + 2C a b)x \|2 atanh(--------------)
+--R                                                 +-----------+
+--R                                                 |          2
+--R                                                \|- 4a c + b
+--R         + 
+--R                           2 +-+       4      2
+--R               (A b - C a)x \|2 log(c x  + b x  + a)
+--R             + 
+--R                               2 +-+                           +-+
+--R               (- 4A b + 4C a)x \|2 log(x) + (- 4B a x - 2A a)\|2
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R       2 2 +-+ |          2  |   |          2       | |          2
+--R     4a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 510
+
+--S 511 of 1070
+--a0:=integrate(t0,x)
+--E 511
+
+--S 512 of 1070
+--m0:=a0-r0
+--E 512
+
+--S 513 of 1070
+--d0:=normalize(D(m0,x))
+--E 513
+
+)clear all
+
+--S 514 of 1070
+t0:=(e-2*f*x^2)/(e^2+4*d*f*x^2+4*e*f*x^2+4*f^2*x^4)
+--R 
+--R
+--R                      2
+--R                - 2f x  + e
+--R   (1)  --------------------------
+--R          2 4               2    2
+--R        4f x  + (4e + 4d)f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 514
+
+--S 515 of 1070
+r0:=1/2*atan((-2*f*x+sqrt(d+2*e)*sqrt(-f))/(sqrt(d)*sqrt(f)))/_
+   (sqrt(d)*sqrt(f))-1/2*atan((2*f*x+sqrt(d+2*e)*sqrt(-f))/_
+   (sqrt(d)*sqrt(f)))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                +---+ +------+                 +---+ +------+
+--R               \|- f \|2e + d  + 2f x         \|- f \|2e + d  - 2f x
+--R        - atan(----------------------) + atan(----------------------)
+--R                       +-+ +-+                        +-+ +-+
+--R                      \|d \|f                        \|d \|f
+--R   (2)  -------------------------------------------------------------
+--R                                    +-+ +-+
+--R                                  2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 4               2    2  +-----+       2 3
+--R        (4f x  + (4e - 4d)f x  + e )\|- d f  - 8d f x  - 4d e f x
+--R    log(---------------------------------------------------------)
+--R                          2 4               2    2
+--R                        4f x  + (4e + 4d)f x  + e
+--R   [--------------------------------------------------------------,
+--R                                 +-----+
+--R                               4\|- d f
+--R             +---+           2 3
+--R           x\|d f          2f x  + (e + 2d)f x
+--R    - atan(-------) + atan(-------------------)
+--R              d                    +---+
+--R                                 e\|d f
+--R    -------------------------------------------]
+--R                        +---+
+--R                      2\|d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 516
+
+--S 517 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2 4               2    2  +-----+       2 3
+--R        +-+ +-+    (4f x  + (4e - 4d)f x  + e )\|- d f  - 8d f x  - 4d e f x
+--R       \|d \|f log(---------------------------------------------------------)
+--R                                     2 4               2    2
+--R                                   4f x  + (4e + 4d)f x  + e
+--R     + 
+--R                      +---+ +------+
+--R         +-----+     \|- f \|2e + d  + 2f x
+--R       2\|- d f atan(----------------------)
+--R                             +-+ +-+
+--R                            \|d \|f
+--R     + 
+--R                        +---+ +------+
+--R           +-----+     \|- f \|2e + d  - 2f x
+--R       - 2\|- d f atan(----------------------)
+--R                               +-+ +-+
+--R                              \|d \|f
+--R  /
+--R       +-----+ +-+ +-+
+--R     4\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        +---+                +---+ +------+
+--R          +-+ +-+     x\|d f      +---+     \|- f \|2e + d  + 2f x
+--R       - \|d \|f atan(-------) + \|d f atan(----------------------)
+--R                         d                          +-+ +-+
+--R                                                   \|d \|f
+--R     + 
+--R                     +---+ +------+                          2 3
+--R          +---+     \|- f \|2e + d  - 2f x     +-+ +-+     2f x  + (e + 2d)f x
+--R       - \|d f atan(----------------------) + \|d \|f atan(-------------------)
+--R                            +-+ +-+                                +---+
+--R                           \|d \|f                               e\|d f
+--R  /
+--R       +-+ +-+ +---+
+--R     2\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 520
+
+)clear all
+
+--S 521 of 1070
+t0:=(e-2*f*x^2)/(e^2-4*d*f*x^2+4*e*f*x^2+4*f^2*x^4)
+--R 
+--R
+--R                      2
+--R                - 2f x  + e
+--R   (1)  --------------------------
+--R          2 4               2    2
+--R        4f x  + (4e - 4d)f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 521
+
+--S 522 of 1070
+r0:=-1/2*atanh((sqrt(d-2*e)-2*x*sqrt(f))/sqrt(d))/(sqrt(d)*sqrt(f))+_
+   1/2*atanh((sqrt(d-2*e)+2*x*sqrt(f))/sqrt(d))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                 +-+    +--------+             +-+    +--------+
+--R              2x\|f  + \|- 2e + d           2x\|f  - \|- 2e + d
+--R        atanh(--------------------) + atanh(--------------------)
+--R                       +-+                           +-+
+--R                      \|d                           \|d
+--R   (2)  ---------------------------------------------------------
+--R                                  +-+ +-+
+--R                                2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 4               2    2  +---+       2 3
+--R        (4f x  + (4e + 4d)f x  + e )\|d f  + 8d f x  + 4d e f x
+--R    log(-------------------------------------------------------)
+--R                         2 4               2    2
+--R                       4f x  + (4e - 4d)f x  + e
+--R   [------------------------------------------------------------,
+--R                                 +---+
+--R                               4\|d f
+--R           +-----+           2 3
+--R         x\|- d f          2f x  + (e - 2d)f x
+--R    atan(---------) + atan(-------------------)
+--R             d                    +-----+
+--R                                e\|- d f
+--R    -------------------------------------------]
+--R                       +-----+
+--R                     2\|- d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 523
+
+--S 524 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2 4               2    2  +---+       2 3
+--R        +-+ +-+    (4f x  + (4e + 4d)f x  + e )\|d f  + 8d f x  + 4d e f x
+--R       \|d \|f log(-------------------------------------------------------)
+--R                                    2 4               2    2
+--R                                  4f x  + (4e - 4d)f x  + e
+--R     + 
+--R                       +-+    +--------+                    +-+    +--------+
+--R         +---+      2x\|f  + \|- 2e + d       +---+      2x\|f  - \|- 2e + d
+--R     - 2\|d f atanh(--------------------) - 2\|d f atanh(--------------------)
+--R                             +-+                                  +-+
+--R                            \|d                                  \|d
+--R  /
+--R       +-+ +-+ +---+
+--R     4\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          +-+    +--------+
+--R          +-----+      2x\|f  + \|- 2e + d
+--R       - \|- d f atanh(--------------------)
+--R                                +-+
+--R                               \|d
+--R     + 
+--R                          +-+    +--------+                   +-----+
+--R          +-----+      2x\|f  - \|- 2e + d      +-+ +-+     x\|- d f
+--R       - \|- d f atanh(--------------------) + \|d \|f atan(---------)
+--R                                +-+                             d
+--R                               \|d
+--R     + 
+--R                      2 3
+--R        +-+ +-+     2f x  + (e - 2d)f x
+--R       \|d \|f atan(-------------------)
+--R                           +-----+
+--R                         e\|- d f
+--R  /
+--R       +-----+ +-+ +-+
+--R     2\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 527
+
+)clear all
+
+--S 528 of 1070
+t0:=(e-4*f*x^3)/(e^2+4*d*f*x^2+4*e*f*x^3+4*f^2*x^6)
+--R 
+--R
+--R                        3
+--R                  - 4f x  + e
+--R   (1)  ------------------------------
+--R          2 6         3         2    2
+--R        4f x  + 4e f x  + 4d f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 528
+
+--S 529 of 1070
+r0:=1/2*atan(2*x*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                +-+ +-+
+--R             2x\|d \|f
+--R        atan(----------)
+--R                  3
+--R              2f x  + e
+--R   (2)  ----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 6         3         2    2  +-----+       2 4
+--R        (4f x  + 4e f x  - 4d f x  + e )\|- d f  - 8d f x  - 4d e f x
+--R    log(-------------------------------------------------------------)
+--R                          2 6         3         2    2
+--R                        4f x  + 4e f x  + 4d f x  + e
+--R   [------------------------------------------------------------------,
+--R                                   +-----+
+--R                                 4\|- d f
+--R            2 +---+           2 5        2
+--R           x \|d f          2f x  + e f x  + 2d f x
+--R    - atan(--------) + atan(-----------------------)
+--R               d                      +---+
+--R                                    e\|d f
+--R    ------------------------------------------------]
+--R                           +---+
+--R                         2\|d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 530
+
+--S 531 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R                2 6         3         2    2  +-----+       2 4
+--R             (4f x  + 4e f x  - 4d f x  + e )\|- d f  - 8d f x  - 4d e f x
+--R         log(-------------------------------------------------------------)
+--R                               2 6         3         2    2
+--R                             4f x  + 4e f x  + 4d f x  + e
+--R     + 
+--R                          +-+ +-+
+--R           +-----+     2x\|d \|f
+--R       - 2\|- d f atan(----------)
+--R                            3
+--R                        2f x  + e
+--R  /
+--R       +-----+ +-+ +-+
+--R     4\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       2 +---+                  +-+ +-+
+--R          +-+ +-+     x \|d f      +---+     2x\|d \|f
+--R       - \|d \|f atan(--------) - \|d f atan(----------)
+--R                          d                       3
+--R                                              2f x  + e
+--R     + 
+--R                      2 5        2
+--R        +-+ +-+     2f x  + e f x  + 2d f x
+--R       \|d \|f atan(-----------------------)
+--R                              +---+
+--R                            e\|d f
+--R  /
+--R       +-+ +-+ +---+
+--R     2\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 534
+
+)clear all
+
+--S 535 of 1070
+t0:=(e-4*f*x^3)/(e^2-4*d*f*x^2+4*e*f*x^3+4*f^2*x^6)
+--R 
+--R
+--R                        3
+--R                  - 4f x  + e
+--R   (1)  ------------------------------
+--R          2 6         3         2    2
+--R        4f x  + 4e f x  - 4d f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 535
+
+--S 536 of 1070
+r0:=1/2*atanh(2*x*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                 +-+ +-+
+--R              2x\|d \|f
+--R        atanh(----------)
+--R                   3
+--R               2f x  + e
+--R   (2)  -----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 6         3         2    2  +---+       2 4
+--R        (4f x  + 4e f x  + 4d f x  + e )\|d f  + 8d f x  + 4d e f x
+--R    log(-----------------------------------------------------------)
+--R                         2 6         3         2    2
+--R                       4f x  + 4e f x  - 4d f x  + e
+--R   [----------------------------------------------------------------,
+--R                                   +---+
+--R                                 4\|d f
+--R          2 +-----+           2 5        2
+--R         x \|- d f          2f x  + e f x  - 2d f x
+--R    atan(----------) + atan(-----------------------)
+--R              d                      +-----+
+--R                                   e\|- d f
+--R    ------------------------------------------------]
+--R                          +-----+
+--R                        2\|- d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 537
+
+--S 538 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2 6         3         2    2  +---+       2 4
+--R        +-+ +-+    (4f x  + 4e f x  + 4d f x  + e )\|d f  + 8d f x  + 4d e f x
+--R       \|d \|f log(-----------------------------------------------------------)
+--R                                    2 6         3         2    2
+--R                                  4f x  + 4e f x  - 4d f x  + e
+--R     + 
+--R                         +-+ +-+
+--R           +---+      2x\|d \|f
+--R       - 2\|d f atanh(----------)
+--R                           3
+--R                       2f x  + e
+--R  /
+--R       +-+ +-+ +---+
+--R     4\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                          +-+ +-+                  2 +-----+
+--R          +-----+      2x\|d \|f      +-+ +-+     x \|- d f
+--R       - \|- d f atanh(----------) + \|d \|f atan(----------)
+--R                            3                          d
+--R                        2f x  + e
+--R     + 
+--R                      2 5        2
+--R        +-+ +-+     2f x  + e f x  - 2d f x
+--R       \|d \|f atan(-----------------------)
+--R                             +-----+
+--R                           e\|- d f
+--R  /
+--R       +-----+ +-+ +-+
+--R     2\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 540
+
+--S 541 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 541
+
+)clear all
+
+--S 542 of 1070
+t0:=(e-2*f*(-1+n)*x^n)/(e^2+4*d*f*x^2+4*e*f*x^n+4*f^2*x^(2*n))
+--R 
+--R
+--R                            n
+--R              (- 2f n + 2f)x  + e
+--R   (1)  -------------------------------
+--R          2 2n         n         2    2
+--R        4f x   + 4e f x  + 4d f x  + e
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 1070
+r0:=1/2*atan(2*x*sqrt(d)*sqrt(f)/(e+2*f*x^n))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                +-+ +-+
+--R             2x\|d \|f
+--R        atan(----------)
+--R                  n
+--R              2f x  + e
+--R   (2)  ----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 +-----+   n log(x) 2         +-----+       2    n log(x)
+--R              4f \|- d f (%e        )  + (4e f\|- d f  - 8d f x)%e
+--R            + 
+--R                       2    2  +-----+
+--R              (- 4d f x  + e )\|- d f  - 4d e f x
+--R         /
+--R              2   n log(x) 2          n log(x)         2    2
+--R            4f (%e        )  + 4e f %e         + 4d f x  + e
+--R    /
+--R         +-----+
+--R       4\|- d f
+--R     ,
+--R              +---+  n log(x)     +---+
+--R           2f\|d f %e         + e\|d f
+--R      atan(----------------------------)
+--R                      2d f x
+--R    - ----------------------------------]
+--R                      +---+
+--R                    2\|d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 544
+
+--S 545 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                  2 +-----+   n log(x) 2         +-----+       2    n log(x)
+--R                4f \|- d f (%e        )  + (4e f\|- d f  - 8d f x)%e
+--R              + 
+--R                         2    2  +-----+
+--R                (- 4d f x  + e )\|- d f  - 4d e f x
+--R           /
+--R                2   n log(x) 2          n log(x)         2    2
+--R              4f (%e        )  + 4e f %e         + 4d f x  + e
+--R     + 
+--R                          +-+ +-+
+--R           +-----+     2x\|d \|f
+--R       - 2\|- d f atan(----------)
+--R                            n
+--R                        2f x  + e
+--R  /
+--R       +-----+ +-+ +-+
+--R     4\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R            3 n     3     n - 1       2    n log(x) 2
+--R       (- 8f x  + 8f n x x      - 4e f )(%e        )
+--R     + 
+--R                3      3   n 2       2   n       2     n - 1
+--R           (- 8f n + 8f )(x )  - 8e f n x  + 8e f n x x
+--R         + 
+--R                  2        2  2     2        2
+--R           (- 8d f n + 8d f )x  - 2e f n - 2e f
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R           2  n 2          2 2     2   n        2   3     2       n - 1
+--R       4e f (x )  + (- 8d f x  + 2e f)x  + (8d f n x  + 2e f n x)x
+--R  /
+--R           4  n 2        3 n        3 2     2 2    n log(x) 2
+--R       (16f (x )  + 16e f x  + 16d f x  + 4e f )(%e        )
+--R     + 
+--R             3  n 2      2 2 n          2 2     3    n log(x)
+--R       (16e f (x )  + 16e f x  + 16d e f x  + 4e f)%e
+--R     + 
+--R           3 2     2 2   n 2           2 2     3   n      2 2 4       2   2    4
+--R     (16d f x  + 4e f )(x )  + (16d e f x  + 4e f)x  + 16d f x  + 8d e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                          +---+  n log(x)     +---+                  +-+ +-+
+--R           +-+ +-+     2f\|d f %e         + e\|d f      +---+     2x\|d \|f
+--R        - \|d \|f atan(----------------------------) - \|d f atan(----------)
+--R                                  2d f x                               n
+--R                                                                   2f x  + e
+--R   (6)  ---------------------------------------------------------------------
+--R                                     +-+ +-+ +---+
+--R                                   2\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R            3 n     3     n - 1       2    n log(x) 2
+--R       (- 8f x  + 8f n x x      - 4e f )(%e        )
+--R     + 
+--R                3      3   n 2       2   n       2     n - 1
+--R           (- 8f n + 8f )(x )  - 8e f n x  + 8e f n x x
+--R         + 
+--R                  2        2  2     2        2
+--R           (- 8d f n + 8d f )x  - 2e f n - 2e f
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R           2  n 2          2 2     2   n        2   3     2       n - 1
+--R       4e f (x )  + (- 8d f x  + 2e f)x  + (8d f n x  + 2e f n x)x
+--R  /
+--R           4  n 2        3 n        3 2     2 2    n log(x) 2
+--R       (16f (x )  + 16e f x  + 16d f x  + 4e f )(%e        )
+--R     + 
+--R             3  n 2      2 2 n          2 2     3    n log(x)
+--R       (16e f (x )  + 16e f x  + 16d e f x  + 4e f)%e
+--R     + 
+--R           3 2     2 2   n 2           2 2     3   n      2 2 4       2   2    4
+--R     (16d f x  + 4e f )(x )  + (16d e f x  + 4e f)x  + 16d f x  + 8d e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 548
+
+)clear all
+
+--S 549 of 1070
+t0:=(e-2*f*(-1+n)*x^n)/(e^2-4*d*f*x^2+4*e*f*x^n+4*f^2*x^(2*n))
+--R 
+--R
+--R                            n
+--R              (- 2f n + 2f)x  + e
+--R   (1)  -------------------------------
+--R          2 2n         n         2    2
+--R        4f x   + 4e f x  - 4d f x  + e
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 1070
+r0:=1/2*atanh(2*x*sqrt(d)*sqrt(f)/(e+2*f*x^n))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                 +-+ +-+
+--R              2x\|d \|f
+--R        atanh(----------)
+--R                   n
+--R               2f x  + e
+--R   (2)  -----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 +---+   n log(x) 2         +---+       2    n log(x)
+--R              4f \|d f (%e        )  + (4e f\|d f  + 8d f x)%e
+--R            + 
+--R                     2    2  +---+
+--R              (4d f x  + e )\|d f  + 4d e f x
+--R         /
+--R              2   n log(x) 2          n log(x)         2    2
+--R            4f (%e        )  + 4e f %e         - 4d f x  + e
+--R    /
+--R         +---+
+--R       4\|d f
+--R     ,
+--R            +-----+  n log(x)     +-----+
+--R         2f\|- d f %e         + e\|- d f
+--R    atan(--------------------------------)
+--R                      2d f x
+--R    --------------------------------------]
+--R                     +-----+
+--R                   2\|- d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 551
+
+--S 552 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                  2 +---+   n log(x) 2         +---+       2    n log(x)
+--R                4f \|d f (%e        )  + (4e f\|d f  + 8d f x)%e
+--R              + 
+--R                       2    2  +---+
+--R                (4d f x  + e )\|d f  + 4d e f x
+--R           /
+--R                2   n log(x) 2          n log(x)         2    2
+--R              4f (%e        )  + 4e f %e         - 4d f x  + e
+--R     + 
+--R                         +-+ +-+
+--R           +---+      2x\|d \|f
+--R       - 2\|d f atanh(----------)
+--R                           n
+--R                       2f x  + e
+--R  /
+--R       +-+ +-+ +---+
+--R     4\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R            3 n     3     n - 1       2    n log(x) 2
+--R       (- 8f x  + 8f n x x      - 4e f )(%e        )
+--R     + 
+--R                3      3   n 2       2   n       2     n - 1
+--R           (- 8f n + 8f )(x )  - 8e f n x  + 8e f n x x
+--R         + 
+--R                2        2  2     2        2
+--R           (8d f n - 8d f )x  - 2e f n - 2e f
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R           2  n 2        2 2     2   n          2   3     2       n - 1
+--R       4e f (x )  + (8d f x  + 2e f)x  + (- 8d f n x  + 2e f n x)x
+--R  /
+--R           4  n 2        3 n        3 2     2 2    n log(x) 2
+--R       (16f (x )  + 16e f x  - 16d f x  + 4e f )(%e        )
+--R     + 
+--R             3  n 2      2 2 n          2 2     3    n log(x)
+--R       (16e f (x )  + 16e f x  - 16d e f x  + 4e f)%e
+--R     + 
+--R               3 2     2 2   n 2             2 2     3   n      2 2 4
+--R       (- 16d f x  + 4e f )(x )  + (- 16d e f x  + 4e f)x  + 16d f x
+--R     + 
+--R             2   2    4
+--R       - 8d e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                   +-----+  n log(x)     +-----+                     +-+ +-+
+--R    +-+ +-+     2f\|- d f %e         + e\|- d f      +-----+      2x\|d \|f
+--R   \|d \|f atan(--------------------------------) - \|- d f atanh(----------)
+--R                             2d f x                                    n
+--R                                                                   2f x  + e
+--R   --------------------------------------------------------------------------
+--R                                  +-----+ +-+ +-+
+--R                                2\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R            3 n     3     n - 1       2    n log(x) 2
+--R       (- 8f x  + 8f n x x      - 4e f )(%e        )
+--R     + 
+--R                3      3   n 2       2   n       2     n - 1
+--R           (- 8f n + 8f )(x )  - 8e f n x  + 8e f n x x
+--R         + 
+--R                2        2  2     2        2
+--R           (8d f n - 8d f )x  - 2e f n - 2e f
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R           2  n 2        2 2     2   n          2   3     2       n - 1
+--R       4e f (x )  + (8d f x  + 2e f)x  + (- 8d f n x  + 2e f n x)x
+--R  /
+--R           4  n 2        3 n        3 2     2 2    n log(x) 2
+--R       (16f (x )  + 16e f x  - 16d f x  + 4e f )(%e        )
+--R     + 
+--R             3  n 2      2 2 n          2 2     3    n log(x)
+--R       (16e f (x )  + 16e f x  - 16d e f x  + 4e f)%e
+--R     + 
+--R               3 2     2 2   n 2             2 2     3   n      2 2 4
+--R       (- 16d f x  + 4e f )(x )  + (- 16d e f x  + 4e f)x  + 16d f x
+--R     + 
+--R             2   2    4
+--R       - 8d e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 1070
+t0:=x/(e^2+4*e*f*x^2+4*d*f*x^4+4*f^2*x^4)
+--R 
+--R
+--R                      x
+--R   (1)  -----------------------------
+--R           2         4         2    2
+--R        (4f  + 4d f)x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 556
+
+--S 557 of 1070
+r0:=1/4*atan((e+2*(d+f)*x^2)*sqrt(f)/(e*sqrt(d)))/(e*sqrt(d)*sqrt(f))
+--R 
+--R
+--R                        2      +-+
+--R             ((2f + 2d)x  + e)\|f
+--R        atan(---------------------)
+--R                       +-+
+--R                     e\|d
+--R   (2)  ---------------------------
+--R                    +-+ +-+
+--R                 4e\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                  3       2     2   4        2           2    2       2  +-----+
+--R              ((4f  + 8d f  + 4d f)x  + (4e f  + 4d e f)x  + e f - d e )\|- d f
+--R            + 
+--R                     2     2     2       2
+--R              (4d e f  + 4d e f)x  + 2d e f
+--R         /
+--R               2         4         2    2
+--R            (4f  + 4d f)x  + 4e f x  + e
+--R    /
+--R          +-----+
+--R       8e\|- d f
+--R     ,
+--R                    2      +---+
+--R         ((2f + 2d)x  + e)\|d f
+--R    atan(-----------------------)
+--R                   d e
+--R    -----------------------------]
+--R                  +---+
+--R               4e\|d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 558
+
+--S 559 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                      3       2     2   4        2           2    2       2
+--R                  ((4f  + 8d f  + 4d f)x  + (4e f  + 4d e f)x  + e f - d e )
+--R               *
+--R                   +-----+
+--R                  \|- d f
+--R              + 
+--R                       2     2     2       2
+--R                (4d e f  + 4d e f)x  + 2d e f
+--R           /
+--R                 2         4         2    2
+--R              (4f  + 4d f)x  + 4e f x  + e
+--R     + 
+--R                                  2      +-+
+--R           +-----+     ((2f + 2d)x  + e)\|f
+--R       - 2\|- d f atan(---------------------)
+--R                                 +-+
+--R                               e\|d
+--R  /
+--R        +-----+ +-+ +-+
+--R     8e\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                           2      +---+                          2      +-+
+--R    +-+ +-+     ((2f + 2d)x  + e)\|d f      +---+     ((2f + 2d)x  + e)\|f
+--R   \|d \|f atan(-----------------------) - \|d f atan(---------------------)
+--R                          d e                                   +-+
+--R                                                              e\|d
+--R   -------------------------------------------------------------------------
+--R                                   +-+ +-+ +---+
+--R                                4e\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 562
+
+)clear all
+
+--S 563 of 1070
+t0:=x/(e^2+4*e*f*x^2-4*d*f*x^4+4*f^2*x^4)
+--R 
+--R
+--R                      x
+--R   (1)  -----------------------------
+--R           2         4         2    2
+--R        (4f  - 4d f)x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 563
+
+--S 564 of 1070
+r0:=-1/4*atanh((e-2*(d-f)*x^2)*sqrt(f)/(e*sqrt(d)))/(e*sqrt(d)*sqrt(f))
+--R 
+--R
+--R                           2      +-+
+--R                ((2f - 2d)x  + e)\|f
+--R          atanh(---------------------)
+--R                          +-+
+--R                        e\|d
+--R   (2)  - ----------------------------
+--R                      +-+ +-+
+--R                   4e\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 564
+
+--S 565 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                  3       2     2   4        2           2    2       2  +---+
+--R              ((4f  - 8d f  + 4d f)x  + (4e f  - 4d e f)x  + e f + d e )\|d f
+--R            + 
+--R                       2     2     2       2
+--R              (- 4d e f  + 4d e f)x  - 2d e f
+--R         /
+--R               2         4         2    2
+--R            (4f  - 4d f)x  + 4e f x  + e
+--R    /
+--R          +---+
+--R       8e\|d f
+--R     ,
+--R                      2      +-----+
+--R           ((2f - 2d)x  + e)\|- d f
+--R      atan(-------------------------)
+--R                      d e
+--R    - -------------------------------]
+--R                    +-----+
+--R                 4e\|- d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 565
+
+--S 566 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                    3       2     2   4        2           2    2       2  +---+
+--R                ((4f  - 8d f  + 4d f)x  + (4e f  - 4d e f)x  + e f + d e )\|d f
+--R              + 
+--R                         2     2     2       2
+--R                (- 4d e f  + 4d e f)x  - 2d e f
+--R           /
+--R                 2         4         2    2
+--R              (4f  - 4d f)x  + 4e f x  + e
+--R     + 
+--R                               2      +-+
+--R         +---+      ((2f - 2d)x  + e)\|f
+--R       2\|d f atanh(---------------------)
+--R                              +-+
+--R                            e\|d
+--R  /
+--R        +-+ +-+ +---+
+--R     8e\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                2      +-+
+--R        +-----+      ((2f - 2d)x  + e)\|f
+--R       \|- d f atanh(---------------------)
+--R                               +-+
+--R                             e\|d
+--R     + 
+--R                                 2      +-----+
+--R          +-+ +-+     ((2f - 2d)x  + e)\|- d f
+--R       - \|d \|f atan(-------------------------)
+--R                                 d e
+--R  /
+--R        +-----+ +-+ +-+
+--R     4e\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 569
+
+)clear all
+
+--S 570 of 1070
+t0:=x^2*(3*e+2*f*x^2)/(e^2+4*e*f*x^2+4*f^2*x^4+4*d*f*x^6)
+--R 
+--R
+--R                     4       2
+--R                 2f x  + 3e x
+--R   (1)  ------------------------------
+--R              6     2 4         2    2
+--R        4d f x  + 4f x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 570
+
+--S 571 of 1070
+r0:=1/2*atan(2*x^3*sqrt(d)*sqrt(f)/(e+2*f*x^2))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R               3 +-+ +-+
+--R             2x \|d \|f
+--R        atan(-----------)
+--R                  2
+--R              2f x  + e
+--R   (2)  -----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               6     2 4         2    2  +-----+       2 5           3
+--R        (4d f x  - 4f x  - 4e f x  - e )\|- d f  + 8d f x  + 4d e f x
+--R    log(--------------------------------------------------------------)
+--R                              6     2 4         2    2
+--R                        4d f x  + 4f x  + 4e f x  + e
+--R   [-------------------------------------------------------------------,
+--R                                   +-----+
+--R                                 4\|- d f
+--R
+--R                +---+             2 5      3           3       2
+--R              x\|d f          4d f x  + (4f  - 2d e f)x  + 2e f x
+--R         atan(-------) - atan(-----------------------------------)
+--R                 f                           2 +---+
+--R                                            e \|d f
+--R       + 
+--R                    3      2
+--R              2d f x  + (2f  - d e)x
+--R         atan(----------------------)
+--R                        +---+
+--R                      e\|d f
+--R    /
+--R         +---+
+--R       2\|d f
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 572
+
+--S 573 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R                    6     2 4         2    2  +-----+       2 5           3
+--R             (4d f x  - 4f x  - 4e f x  - e )\|- d f  + 8d f x  + 4d e f x
+--R         log(--------------------------------------------------------------)
+--R                                   6     2 4         2    2
+--R                             4d f x  + 4f x  + 4e f x  + e
+--R     + 
+--R                         3 +-+ +-+
+--R           +-----+     2x \|d \|f
+--R       - 2\|- d f atan(-----------)
+--R                            2
+--R                        2f x  + e
+--R  /
+--R       +-----+ +-+ +-+
+--R     4\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                      +---+                 3 +-+ +-+
+--R        +-+ +-+     x\|d f      +---+     2x \|d \|f
+--R       \|d \|f atan(-------) - \|d f atan(-----------)
+--R                       f                       2
+--R                                           2f x  + e
+--R     + 
+--R                          2 5      3           3       2
+--R          +-+ +-+     4d f x  + (4f  - 2d e f)x  + 2e f x
+--R       - \|d \|f atan(-----------------------------------)
+--R                                     2 +---+
+--R                                    e \|d f
+--R     + 
+--R                          3      2
+--R        +-+ +-+     2d f x  + (2f  - d e)x
+--R       \|d \|f atan(----------------------)
+--R                              +---+
+--R                            e\|d f
+--R  /
+--R       +-+ +-+ +---+
+--R     2\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 1070
+t0:=x^2*(3*e+2*f*x^2)/(e^2+4*e*f*x^2+4*f^2*x^4-4*d*f*x^6)
+--R 
+--R
+--R                      4       2
+--R                - 2f x  - 3e x
+--R   (1)  ------------------------------
+--R              6     2 4         2    2
+--R        4d f x  - 4f x  - 4e f x  - e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 577
+
+--S 578 of 1070
+r0:=1/2*atanh(2*x^3*sqrt(d)*sqrt(f)/(e+2*f*x^2))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                3 +-+ +-+
+--R              2x \|d \|f
+--R        atanh(-----------)
+--R                   2
+--R               2f x  + e
+--R   (2)  ------------------
+--R               +-+ +-+
+--R             2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               6     2 4         2    2  +---+       2 5           3
+--R        (4d f x  + 4f x  + 4e f x  + e )\|d f  + 8d f x  + 4d e f x
+--R    log(------------------------------------------------------------)
+--R                             6     2 4         2    2
+--R                       4d f x  - 4f x  - 4e f x  - e
+--R   [-----------------------------------------------------------------,
+--R                                   +---+
+--R                                 4\|d f
+--R
+--R                +-----+             2 5        3           3       2
+--R              x\|- d f          4d f x  + (- 4f  - 2d e f)x  - 2e f x
+--R         atan(---------) + atan(-------------------------------------)
+--R                  f                            2 +-----+
+--R                                              e \|- d f
+--R       + 
+--R                      3        2
+--R                2d f x  + (- 2f  - d e)x
+--R         - atan(------------------------)
+--R                          +-----+
+--R                        e\|- d f
+--R    /
+--R         +-----+
+--R       2\|- d f
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 579
+
+--S 580 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                          6     2 4         2    2  +---+       2 5           3
+--R        +-+ +-+    (4d f x  + 4f x  + 4e f x  + e )\|d f  + 8d f x  + 4d e f x
+--R       \|d \|f log(------------------------------------------------------------)
+--R                                        6     2 4         2    2
+--R                                  4d f x  - 4f x  - 4e f x  - e
+--R     + 
+--R                        3 +-+ +-+
+--R           +---+      2x \|d \|f
+--R       - 2\|d f atanh(-----------)
+--R                           2
+--R                       2f x  + e
+--R  /
+--R       +-+ +-+ +---+
+--R     4\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         3 +-+ +-+                   +-----+
+--R          +-----+      2x \|d \|f      +-+ +-+     x\|- d f
+--R       - \|- d f atanh(-----------) + \|d \|f atan(---------)
+--R                            2                          f
+--R                        2f x  + e
+--R     + 
+--R                        2 5        3           3       2
+--R        +-+ +-+     4d f x  + (- 4f  - 2d e f)x  - 2e f x
+--R       \|d \|f atan(-------------------------------------)
+--R                                   2 +-----+
+--R                                  e \|- d f
+--R     + 
+--R                            3        2
+--R          +-+ +-+     2d f x  + (- 2f  - d e)x
+--R       - \|d \|f atan(------------------------)
+--R                                +-----+
+--R                              e\|- d f
+--R  /
+--R       +-----+ +-+ +-+
+--R     2\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 583
+
+)clear all
+
+--S 584 of 1070
+t0:=x^m*(e*(1+m)+2*f*(-1+m)*x^2)/(e^2+4*e*f*x^2+4*f^2*x^4+4*d*f*x^(2+2*m))
+--R 
+--R
+--R                         2            m
+--R            ((2f m - 2f)x  + e m + e)x
+--R   (1)  -----------------------------------
+--R              2m + 2     2 4         2    2
+--R        4d f x       + 4f x  + 4e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 1070
+r0:=1/2*atan(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^2))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R               m + 1 +-+ +-+
+--R             2x     \|d \|f
+--R        atan(---------------)
+--R                    2
+--R                2f x  + e
+--R   (2)  ---------------------
+--R                +-+ +-+
+--R              2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 585
+
+--S 586 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                    2 +-----+   m log(x) 2        2 3              m log(x)
+--R              4d f x \|- d f (%e        )  + (8d f x  + 4d e f x)%e
+--R            + 
+--R                   2 4         2    2  +-----+
+--R              (- 4f x  - 4e f x  - e )\|- d f
+--R         /
+--R                  2   m log(x) 2     2 4         2    2
+--R            4d f x (%e        )  + 4f x  + 4e f x  + e
+--R    /
+--R         +-----+
+--R       4\|- d f
+--R     ,
+--R            +---+  m log(x)
+--R         2x\|d f %e
+--R    atan(------------------)
+--R                  2
+--R              2f x  + e
+--R    ------------------------]
+--R               +---+
+--R             2\|d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 586
+
+--S 587 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                      2 +-----+   m log(x) 2        2 3              m log(x)
+--R                4d f x \|- d f (%e        )  + (8d f x  + 4d e f x)%e
+--R              + 
+--R                     2 4         2    2  +-----+
+--R                (- 4f x  - 4e f x  - e )\|- d f
+--R           /
+--R                    2   m log(x) 2     2 4         2    2
+--R              4d f x (%e        )  + 4f x  + 4e f x  + e
+--R     + 
+--R                         m + 1 +-+ +-+
+--R           +-----+     2x     \|d \|f
+--R       - 2\|- d f atan(---------------)
+--R                              2
+--R                          2f x  + e
+--R  /
+--R       +-----+ +-+ +-+
+--R     4\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R               2 3 m + 1           2        2  4                         2  m
+--R         (16d f x x      + ((- 8d f m - 8d f )x  + (- 4d e f m - 4d e f)x )x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                 2        2  2                       m + 1 2      3      3  6
+--R           ((8d f m - 8d f )x  + 4d e f m + 4d e f)(x     )  + (8f m - 8f )x
+--R         + 
+--R                 2        2  4      2        2   2    3     3
+--R           (12e f m - 4e f )x  + (6e f m + 2e f)x  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           3 5        2 3     2     m + 1
+--R       (16f x  + 16e f x  + 4e f x)x
+--R     + 
+--R                3      3  6           2         2  4        2        2   2    3
+--R           (- 8f m - 8f )x  + (- 12e f m - 12e f )x  + (- 6e f m - 6e f)x  - e m
+--R         + 
+--R              3
+--R           - e
+--R      *
+--R          m
+--R         x
+--R  /
+--R           2 2 2  m + 1 2        3 6          2 4       2   2    m log(x) 2
+--R       (16d f x (x     )  + 16d f x  + 16d e f x  + 4d e f x )(%e        )
+--R     + 
+--R             3 4          2 2       2    m + 1 2      4 8        3 6      2 2 4
+--R       (16d f x  + 16d e f x  + 4d e f)(x     )  + 16f x  + 32e f x  + 24e f x
+--R     + 
+--R         3   2    4
+--R       8e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 588
+
+--S 589 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+  m log(x)                 m + 1 +-+ +-+
+--R         +-+ +-+     2x\|d f %e             +---+     2x     \|d \|f
+--R        \|d \|f atan(------------------) - \|d f atan(---------------)
+--R                              2                              2
+--R                          2f x  + e                      2f x  + e
+--R   (6)  --------------------------------------------------------------
+--R                                  +-+ +-+ +---+
+--R                                2\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R               2 3 m + 1           2        2  4                         2  m
+--R         (16d f x x      + ((- 8d f m - 8d f )x  + (- 4d e f m - 4d e f)x )x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                 2        2  2                       m + 1 2      3      3  6
+--R           ((8d f m - 8d f )x  + 4d e f m + 4d e f)(x     )  + (8f m - 8f )x
+--R         + 
+--R                 2        2  4      2        2   2    3     3
+--R           (12e f m - 4e f )x  + (6e f m + 2e f)x  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           3 5        2 3     2     m + 1
+--R       (16f x  + 16e f x  + 4e f x)x
+--R     + 
+--R                3      3  6           2         2  4        2        2   2    3
+--R           (- 8f m - 8f )x  + (- 12e f m - 12e f )x  + (- 6e f m - 6e f)x  - e m
+--R         + 
+--R              3
+--R           - e
+--R      *
+--R          m
+--R         x
+--R  /
+--R           2 2 2  m + 1 2        3 6          2 4       2   2    m log(x) 2
+--R       (16d f x (x     )  + 16d f x  + 16d e f x  + 4d e f x )(%e        )
+--R     + 
+--R             3 4          2 2       2    m + 1 2      4 8        3 6      2 2 4
+--R       (16d f x  + 16d e f x  + 4d e f)(x     )  + 16f x  + 32e f x  + 24e f x
+--R     + 
+--R         3   2    4
+--R       8e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 590
+
+)clear all
+
+--S 591 of 1070
+t0:=x^m*(e*(1+m)+2*f*(-1+m)*x^2)/(e^2+4*e*f*x^2+4*f^2*x^4-4*d*f*x^(2+2*m))
+--R 
+--R
+--R                          2            m
+--R           ((- 2f m + 2f)x  - e m - e)x
+--R   (1)  -----------------------------------
+--R              2m + 2     2 4         2    2
+--R        4d f x       - 4f x  - 4e f x  - e
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 1070
+r0:=1/2*atanh(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^2))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                m + 1 +-+ +-+
+--R              2x     \|d \|f
+--R        atanh(---------------)
+--R                     2
+--R                 2f x  + e
+--R   (2)  ----------------------
+--R                 +-+ +-+
+--R               2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                    2 +---+   m log(x) 2        2 3              m log(x)
+--R              4d f x \|d f (%e        )  + (8d f x  + 4d e f x)%e
+--R            + 
+--R                 2 4         2    2  +---+
+--R              (4f x  + 4e f x  + e )\|d f
+--R         /
+--R                  2   m log(x) 2     2 4         2    2
+--R            4d f x (%e        )  - 4f x  - 4e f x  - e
+--R    /
+--R         +---+
+--R       4\|d f
+--R     ,
+--R            +-----+  m log(x)
+--R         2x\|- d f %e
+--R    atan(--------------------)
+--R                   2
+--R               2f x  + e
+--R    --------------------------]
+--R               +-----+
+--R             2\|- d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 593
+
+--S 594 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                      2 +---+   m log(x) 2        2 3              m log(x)
+--R                4d f x \|d f (%e        )  + (8d f x  + 4d e f x)%e
+--R              + 
+--R                   2 4         2    2  +---+
+--R                (4f x  + 4e f x  + e )\|d f
+--R           /
+--R                    2   m log(x) 2     2 4         2    2
+--R              4d f x (%e        )  - 4f x  - 4e f x  - e
+--R     + 
+--R                        m + 1 +-+ +-+
+--R           +---+      2x     \|d \|f
+--R       - 2\|d f atanh(---------------)
+--R                             2
+--R                         2f x  + e
+--R  /
+--R       +-+ +-+ +---+
+--R     4\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                 2 3 m + 1         2        2  4                       2  m
+--R         (- 16d f x x      + ((8d f m + 8d f )x  + (4d e f m + 4d e f)x )x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                   2        2  2                       m + 1 2      3      3  6
+--R           ((- 8d f m + 8d f )x  - 4d e f m - 4d e f)(x     )  + (8f m - 8f )x
+--R         + 
+--R                 2        2  4      2        2   2    3     3
+--R           (12e f m - 4e f )x  + (6e f m + 2e f)x  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           3 5        2 3     2     m + 1
+--R       (16f x  + 16e f x  + 4e f x)x
+--R     + 
+--R                3      3  6           2         2  4        2        2   2    3
+--R           (- 8f m - 8f )x  + (- 12e f m - 12e f )x  + (- 6e f m - 6e f)x  - e m
+--R         + 
+--R              3
+--R           - e
+--R      *
+--R          m
+--R         x
+--R  /
+--R           2 2 2  m + 1 2        3 6          2 4       2   2    m log(x) 2
+--R       (16d f x (x     )  - 16d f x  - 16d e f x  - 4d e f x )(%e        )
+--R     + 
+--R               3 4          2 2       2    m + 1 2      4 8        3 6
+--R       (- 16d f x  - 16d e f x  - 4d e f)(x     )  + 16f x  + 32e f x
+--R     + 
+--R          2 2 4     3   2    4
+--R       24e f x  + 8e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +-----+  m log(x)                    m + 1 +-+ +-+
+--R         +-+ +-+     2x\|- d f %e             +-----+      2x     \|d \|f
+--R        \|d \|f atan(--------------------) - \|- d f atanh(---------------)
+--R                               2                                  2
+--R                           2f x  + e                          2f x  + e
+--R   (6)  -------------------------------------------------------------------
+--R                                   +-----+ +-+ +-+
+--R                                 2\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                 2 3 m + 1         2        2  4                       2  m
+--R         (- 16d f x x      + ((8d f m + 8d f )x  + (4d e f m + 4d e f)x )x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                   2        2  2                       m + 1 2      3      3  6
+--R           ((- 8d f m + 8d f )x  - 4d e f m - 4d e f)(x     )  + (8f m - 8f )x
+--R         + 
+--R                 2        2  4      2        2   2    3     3
+--R           (12e f m - 4e f )x  + (6e f m + 2e f)x  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           3 5        2 3     2     m + 1
+--R       (16f x  + 16e f x  + 4e f x)x
+--R     + 
+--R                3      3  6           2         2  4        2        2   2    3
+--R           (- 8f m - 8f )x  + (- 12e f m - 12e f )x  + (- 6e f m - 6e f)x  - e m
+--R         + 
+--R              3
+--R           - e
+--R      *
+--R          m
+--R         x
+--R  /
+--R           2 2 2  m + 1 2        3 6          2 4       2   2    m log(x) 2
+--R       (16d f x (x     )  - 16d f x  - 16d e f x  - 4d e f x )(%e        )
+--R     + 
+--R               3 4          2 2       2    m + 1 2      4 8        3 6
+--R       (- 16d f x  - 16d e f x  - 4d e f)(x     )  + 16f x  + 32e f x
+--R     + 
+--R          2 2 4     3   2    4
+--R       24e f x  + 8e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 597
+
+)clear all
+
+--S 598 of 1070
+t0:=x*(2*e-2*f*x^3)/(e^2+4*e*f*x^3+4*d*f*x^4+4*f^2*x^6)
+--R 
+--R
+--R                      4
+--R                - 2f x  + 2e x
+--R   (1)  ------------------------------
+--R          2 6         4         3    2
+--R        4f x  + 4d f x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 598
+
+--S 599 of 1070
+r0:=1/2*atan(2*x^2*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R               2 +-+ +-+
+--R             2x \|d \|f
+--R        atan(-----------)
+--R                  3
+--R              2f x  + e
+--R   (2)  -----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 6         4         3    2  +-----+       2 5           2
+--R        (4f x  - 4d f x  + 4e f x  + e )\|- d f  - 8d f x  - 4d e f x
+--R    log(--------------------------------------------------------------)
+--R                          2 6         4         3    2
+--R                        4f x  + 4d f x  + 4e f x  + e
+--R   [-------------------------------------------------------------------,
+--R                                   +-----+
+--R                                 4\|- d f
+--R             +---+           2 4         2
+--R           x\|d f          2f x  + 2d f x  + e f x
+--R    - atan(-------) + atan(-----------------------)
+--R              d                      +---+
+--R                                   e\|d f
+--R    -----------------------------------------------]
+--R                          +---+
+--R                        2\|d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 600
+
+--S 601 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R                2 6         4         3    2  +-----+       2 5           2
+--R             (4f x  - 4d f x  + 4e f x  + e )\|- d f  - 8d f x  - 4d e f x
+--R         log(--------------------------------------------------------------)
+--R                               2 6         4         3    2
+--R                             4f x  + 4d f x  + 4e f x  + e
+--R     + 
+--R                         2 +-+ +-+
+--R           +-----+     2x \|d \|f
+--R       - 2\|- d f atan(-----------)
+--R                            3
+--R                        2f x  + e
+--R  /
+--R       +-----+ +-+ +-+
+--R     4\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                        +---+                 2 +-+ +-+
+--R          +-+ +-+     x\|d f      +---+     2x \|d \|f
+--R       - \|d \|f atan(-------) - \|d f atan(-----------)
+--R                         d                       3
+--R                                             2f x  + e
+--R     + 
+--R                      2 4         2
+--R        +-+ +-+     2f x  + 2d f x  + e f x
+--R       \|d \|f atan(-----------------------)
+--R                              +---+
+--R                            e\|d f
+--R  /
+--R       +-+ +-+ +---+
+--R     2\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 604
+
+)clear all
+
+--S 605 of 1070
+t0:=x*(2*e-2*f*x^3)/(e^2+4*e*f*x^3-4*d*f*x^4+4*f^2*x^6)
+--R 
+--R
+--R                      4
+--R                - 2f x  + 2e x
+--R   (1)  ------------------------------
+--R          2 6         4         3    2
+--R        4f x  - 4d f x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 605
+
+--S 606 of 1070
+r0:=1/2*atanh(2*x^2*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                2 +-+ +-+
+--R              2x \|d \|f
+--R        atanh(-----------)
+--R                   3
+--R               2f x  + e
+--R   (2)  ------------------
+--R               +-+ +-+
+--R             2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 6         4         3    2  +---+       2 5           2
+--R        (4f x  + 4d f x  + 4e f x  + e )\|d f  + 8d f x  + 4d e f x
+--R    log(------------------------------------------------------------)
+--R                         2 6         4         3    2
+--R                       4f x  - 4d f x  + 4e f x  + e
+--R   [-----------------------------------------------------------------,
+--R                                   +---+
+--R                                 4\|d f
+--R           +-----+           2 4         2
+--R         x\|- d f          2f x  - 2d f x  + e f x
+--R    atan(---------) + atan(-----------------------)
+--R             d                      +-----+
+--R                                  e\|- d f
+--R    -----------------------------------------------]
+--R                         +-----+
+--R                       2\|- d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 607
+
+--S 608 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                      2 6         4         3    2  +---+       2 5           2
+--R        +-+ +-+    (4f x  + 4d f x  + 4e f x  + e )\|d f  + 8d f x  + 4d e f x
+--R       \|d \|f log(------------------------------------------------------------)
+--R                                    2 6         4         3    2
+--R                                  4f x  - 4d f x  + 4e f x  + e
+--R     + 
+--R                        2 +-+ +-+
+--R           +---+      2x \|d \|f
+--R       - 2\|d f atanh(-----------)
+--R                           3
+--R                       2f x  + e
+--R  /
+--R       +-+ +-+ +---+
+--R     4\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         2 +-+ +-+                   +-----+
+--R          +-----+      2x \|d \|f      +-+ +-+     x\|- d f
+--R       - \|- d f atanh(-----------) + \|d \|f atan(---------)
+--R                            3                          d
+--R                        2f x  + e
+--R     + 
+--R                      2 4         2
+--R        +-+ +-+     2f x  - 2d f x  + e f x
+--R       \|d \|f atan(-----------------------)
+--R                             +-----+
+--R                           e\|- d f
+--R  /
+--R       +-----+ +-+ +-+
+--R     2\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 611
+
+)clear all
+
+--S 612 of 1070
+t0:=x^2/(e^2+4*e*f*x^3+4*d*f*x^6+4*f^2*x^6)
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R           2         6         3    2
+--R        (4f  + 4d f)x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 612
+
+--S 613 of 1070
+r0:=1/6*atan((e+2*(d+f)*x^3)*sqrt(f)/(e*sqrt(d)))/(e*sqrt(d)*sqrt(f))
+--R 
+--R
+--R                        3      +-+
+--R             ((2f + 2d)x  + e)\|f
+--R        atan(---------------------)
+--R                       +-+
+--R                     e\|d
+--R   (2)  ---------------------------
+--R                    +-+ +-+
+--R                 6e\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                  3       2     2   6        2           3    2       2  +-----+
+--R              ((4f  + 8d f  + 4d f)x  + (4e f  + 4d e f)x  + e f - d e )\|- d f
+--R            + 
+--R                     2     2     3       2
+--R              (4d e f  + 4d e f)x  + 2d e f
+--R         /
+--R               2         6         3    2
+--R            (4f  + 4d f)x  + 4e f x  + e
+--R    /
+--R           +-----+
+--R       12e\|- d f
+--R     ,
+--R                    3      +---+
+--R         ((2f + 2d)x  + e)\|d f
+--R    atan(-----------------------)
+--R                   d e
+--R    -----------------------------]
+--R                  +---+
+--R               6e\|d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 614
+
+--S 615 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                      3       2     2   6        2           3    2       2
+--R                  ((4f  + 8d f  + 4d f)x  + (4e f  + 4d e f)x  + e f - d e )
+--R               *
+--R                   +-----+
+--R                  \|- d f
+--R              + 
+--R                       2     2     3       2
+--R                (4d e f  + 4d e f)x  + 2d e f
+--R           /
+--R                 2         6         3    2
+--R              (4f  + 4d f)x  + 4e f x  + e
+--R     + 
+--R                                  3      +-+
+--R           +-----+     ((2f + 2d)x  + e)\|f
+--R       - 2\|- d f atan(---------------------)
+--R                                 +-+
+--R                               e\|d
+--R  /
+--R         +-----+ +-+ +-+
+--R     12e\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                           3      +---+                          3      +-+
+--R    +-+ +-+     ((2f + 2d)x  + e)\|d f      +---+     ((2f + 2d)x  + e)\|f
+--R   \|d \|f atan(-----------------------) - \|d f atan(---------------------)
+--R                          d e                                   +-+
+--R                                                              e\|d
+--R   -------------------------------------------------------------------------
+--R                                   +-+ +-+ +---+
+--R                                6e\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 618
+
+)clear all
+
+--S 619 of 1070
+t0:=x^2/(e^2+4*e*f*x^3-4*d*f*x^6+4*f^2*x^6)
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R           2         6         3    2
+--R        (4f  - 4d f)x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 619
+
+--S 620 of 1070
+r0:=-1/6*atanh((e-2*(d-f)*x^3)*sqrt(f)/(e*sqrt(d)))/(e*sqrt(d)*sqrt(f))
+--R 
+--R
+--R                           3      +-+
+--R                ((2f - 2d)x  + e)\|f
+--R          atanh(---------------------)
+--R                          +-+
+--R                        e\|d
+--R   (2)  - ----------------------------
+--R                      +-+ +-+
+--R                   6e\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                  3       2     2   6        2           3    2       2  +---+
+--R              ((4f  - 8d f  + 4d f)x  + (4e f  - 4d e f)x  + e f + d e )\|d f
+--R            + 
+--R                       2     2     3       2
+--R              (- 4d e f  + 4d e f)x  - 2d e f
+--R         /
+--R               2         6         3    2
+--R            (4f  - 4d f)x  + 4e f x  + e
+--R    /
+--R           +---+
+--R       12e\|d f
+--R     ,
+--R                      3      +-----+
+--R           ((2f - 2d)x  + e)\|- d f
+--R      atan(-------------------------)
+--R                      d e
+--R    - -------------------------------]
+--R                    +-----+
+--R                 6e\|- d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 621
+
+--S 622 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                    3       2     2   6        2           3    2       2  +---+
+--R                ((4f  - 8d f  + 4d f)x  + (4e f  - 4d e f)x  + e f + d e )\|d f
+--R              + 
+--R                         2     2     3       2
+--R                (- 4d e f  + 4d e f)x  - 2d e f
+--R           /
+--R                 2         6         3    2
+--R              (4f  - 4d f)x  + 4e f x  + e
+--R     + 
+--R                               3      +-+
+--R         +---+      ((2f - 2d)x  + e)\|f
+--R       2\|d f atanh(---------------------)
+--R                              +-+
+--R                            e\|d
+--R  /
+--R         +-+ +-+ +---+
+--R     12e\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                3      +-+
+--R        +-----+      ((2f - 2d)x  + e)\|f
+--R       \|- d f atanh(---------------------)
+--R                               +-+
+--R                             e\|d
+--R     + 
+--R                                 3      +-----+
+--R          +-+ +-+     ((2f - 2d)x  + e)\|- d f
+--R       - \|d \|f atan(-------------------------)
+--R                                 d e
+--R  /
+--R        +-----+ +-+ +-+
+--R     6e\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 624
+
+--S 625 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 625
+
+)clear all
+
+--S 626 of 1070
+t0:=x^m*(e*(1+m)+2*f*(-2+m)*x^3)/(e^2+4*e*f*x^3+4*f^2*x^6+4*d*f*x^(2+2*m))
+--R 
+--R
+--R                         3            m
+--R            ((2f m - 4f)x  + e m + e)x
+--R   (1)  -----------------------------------
+--R              2m + 2     2 6         3    2
+--R        4d f x       + 4f x  + 4e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 1070
+r0:=1/2*atan(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R               m + 1 +-+ +-+
+--R             2x     \|d \|f
+--R        atan(---------------)
+--R                    3
+--R                2f x  + e
+--R   (2)  ---------------------
+--R                +-+ +-+
+--R              2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                    2 +-----+   m log(x) 2        2 4              m log(x)
+--R              4d f x \|- d f (%e        )  + (8d f x  + 4d e f x)%e
+--R            + 
+--R                   2 6         3    2  +-----+
+--R              (- 4f x  - 4e f x  - e )\|- d f
+--R         /
+--R                  2   m log(x) 2     2 6         3    2
+--R            4d f x (%e        )  + 4f x  + 4e f x  + e
+--R    /
+--R         +-----+
+--R       4\|- d f
+--R     ,
+--R            +---+  m log(x)
+--R         2x\|d f %e
+--R    atan(------------------)
+--R                  3
+--R              2f x  + e
+--R    ------------------------]
+--R               +---+
+--R             2\|d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 628
+
+--S 629 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                      2 +-----+   m log(x) 2        2 4              m log(x)
+--R                4d f x \|- d f (%e        )  + (8d f x  + 4d e f x)%e
+--R              + 
+--R                     2 6         3    2  +-----+
+--R                (- 4f x  - 4e f x  - e )\|- d f
+--R           /
+--R                    2   m log(x) 2     2 6         3    2
+--R              4d f x (%e        )  + 4f x  + 4e f x  + e
+--R     + 
+--R                         m + 1 +-+ +-+
+--R           +-----+     2x     \|d \|f
+--R       - 2\|- d f atan(---------------)
+--R                              3
+--R                          2f x  + e
+--R  /
+--R       +-----+ +-+ +-+
+--R     4\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R               2 4 m + 1           2        2  5                         2  m
+--R         (24d f x x      + ((- 8d f m - 8d f )x  + (- 4d e f m - 4d e f)x )x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                 2         2  3                       m + 1 2      3       3  9
+--R           ((8d f m - 16d f )x  + 4d e f m + 4d e f)(x     )  + (8f m - 16f )x
+--R         + 
+--R                 2         2  6     2     3    3     3
+--R           (12e f m - 12e f )x  + 6e f m x  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           3 8        2 5     2   2  m + 1
+--R       (24f x  + 24e f x  + 6e f x )x
+--R     + 
+--R                3      3  9           2         2  6        2        2   3    3
+--R           (- 8f m - 8f )x  + (- 12e f m - 12e f )x  + (- 6e f m - 6e f)x  - e m
+--R         + 
+--R              3
+--R           - e
+--R      *
+--R          m
+--R         x
+--R  /
+--R           2 2 2  m + 1 2        3 8          2 5       2   2    m log(x) 2
+--R       (16d f x (x     )  + 16d f x  + 16d e f x  + 4d e f x )(%e        )
+--R     + 
+--R             3 6          2 3       2    m + 1 2      4 12        3 9      2 2 6
+--R       (16d f x  + 16d e f x  + 4d e f)(x     )  + 16f x   + 32e f x  + 24e f x
+--R     + 
+--R         3   3    4
+--R       8e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +---+  m log(x)                 m + 1 +-+ +-+
+--R         +-+ +-+     2x\|d f %e             +---+     2x     \|d \|f
+--R        \|d \|f atan(------------------) - \|d f atan(---------------)
+--R                              3                              3
+--R                          2f x  + e                      2f x  + e
+--R   (6)  --------------------------------------------------------------
+--R                                  +-+ +-+ +---+
+--R                                2\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R               2 4 m + 1           2        2  5                         2  m
+--R         (24d f x x      + ((- 8d f m - 8d f )x  + (- 4d e f m - 4d e f)x )x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                 2         2  3                       m + 1 2      3       3  9
+--R           ((8d f m - 16d f )x  + 4d e f m + 4d e f)(x     )  + (8f m - 16f )x
+--R         + 
+--R                 2         2  6     2     3    3     3
+--R           (12e f m - 12e f )x  + 6e f m x  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           3 8        2 5     2   2  m + 1
+--R       (24f x  + 24e f x  + 6e f x )x
+--R     + 
+--R                3      3  9           2         2  6        2        2   3    3
+--R           (- 8f m - 8f )x  + (- 12e f m - 12e f )x  + (- 6e f m - 6e f)x  - e m
+--R         + 
+--R              3
+--R           - e
+--R      *
+--R          m
+--R         x
+--R  /
+--R           2 2 2  m + 1 2        3 8          2 5       2   2    m log(x) 2
+--R       (16d f x (x     )  + 16d f x  + 16d e f x  + 4d e f x )(%e        )
+--R     + 
+--R             3 6          2 3       2    m + 1 2      4 12        3 9      2 2 6
+--R       (16d f x  + 16d e f x  + 4d e f)(x     )  + 16f x   + 32e f x  + 24e f x
+--R     + 
+--R         3   3    4
+--R       8e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 632
+
+)clear all
+
+--S 633 of 1070
+t0:=x^m*(e*(1+m)+2*f*(-2+m)*x^3)/(e^2+4*e*f*x^3+4*f^2*x^6-4*d*f*x^(2+2*m))
+--R 
+--R
+--R                          3            m
+--R           ((- 2f m + 4f)x  - e m - e)x
+--R   (1)  -----------------------------------
+--R              2m + 2     2 6         3    2
+--R        4d f x       - 4f x  - 4e f x  - e
+--R                                                    Type: Expression(Integer)
+--E 633
+
+--S 634 of 1070
+r0:=1/2*atanh(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                m + 1 +-+ +-+
+--R              2x     \|d \|f
+--R        atanh(---------------)
+--R                     3
+--R                 2f x  + e
+--R   (2)  ----------------------
+--R                 +-+ +-+
+--R               2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 634
+
+--S 635 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                    2 +---+   m log(x) 2        2 4              m log(x)
+--R              4d f x \|d f (%e        )  + (8d f x  + 4d e f x)%e
+--R            + 
+--R                 2 6         3    2  +---+
+--R              (4f x  + 4e f x  + e )\|d f
+--R         /
+--R                  2   m log(x) 2     2 6         3    2
+--R            4d f x (%e        )  - 4f x  - 4e f x  - e
+--R    /
+--R         +---+
+--R       4\|d f
+--R     ,
+--R            +-----+  m log(x)
+--R         2x\|- d f %e
+--R    atan(--------------------)
+--R                   3
+--R               2f x  + e
+--R    --------------------------]
+--R               +-----+
+--R             2\|- d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 635
+
+--S 636 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                      2 +---+   m log(x) 2        2 4              m log(x)
+--R                4d f x \|d f (%e        )  + (8d f x  + 4d e f x)%e
+--R              + 
+--R                   2 6         3    2  +---+
+--R                (4f x  + 4e f x  + e )\|d f
+--R           /
+--R                    2   m log(x) 2     2 6         3    2
+--R              4d f x (%e        )  - 4f x  - 4e f x  - e
+--R     + 
+--R                        m + 1 +-+ +-+
+--R           +---+      2x     \|d \|f
+--R       - 2\|d f atanh(---------------)
+--R                             3
+--R                         2f x  + e
+--R  /
+--R       +-+ +-+ +---+
+--R     4\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                 2 4 m + 1         2        2  5                       2  m
+--R         (- 24d f x x      + ((8d f m + 8d f )x  + (4d e f m + 4d e f)x )x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                   2         2  3                       m + 1 2
+--R           ((- 8d f m + 16d f )x  - 4d e f m - 4d e f)(x     )
+--R         + 
+--R              3       3  9         2         2  6     2     3    3     3
+--R           (8f m - 16f )x  + (12e f m - 12e f )x  + 6e f m x  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           3 8        2 5     2   2  m + 1
+--R       (24f x  + 24e f x  + 6e f x )x
+--R     + 
+--R                3      3  9           2         2  6        2        2   3    3
+--R           (- 8f m - 8f )x  + (- 12e f m - 12e f )x  + (- 6e f m - 6e f)x  - e m
+--R         + 
+--R              3
+--R           - e
+--R      *
+--R          m
+--R         x
+--R  /
+--R           2 2 2  m + 1 2        3 8          2 5       2   2    m log(x) 2
+--R       (16d f x (x     )  - 16d f x  - 16d e f x  - 4d e f x )(%e        )
+--R     + 
+--R               3 6          2 3       2    m + 1 2      4 12        3 9
+--R       (- 16d f x  - 16d e f x  - 4d e f)(x     )  + 16f x   + 32e f x
+--R     + 
+--R          2 2 6     3   3    4
+--R       24e f x  + 8e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                        +-----+  m log(x)                    m + 1 +-+ +-+
+--R         +-+ +-+     2x\|- d f %e             +-----+      2x     \|d \|f
+--R        \|d \|f atan(--------------------) - \|- d f atanh(---------------)
+--R                               3                                  3
+--R                           2f x  + e                          2f x  + e
+--R   (6)  -------------------------------------------------------------------
+--R                                   +-----+ +-+ +-+
+--R                                 2\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                 2 4 m + 1         2        2  5                       2  m
+--R         (- 24d f x x      + ((8d f m + 8d f )x  + (4d e f m + 4d e f)x )x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                   2         2  3                       m + 1 2
+--R           ((- 8d f m + 16d f )x  - 4d e f m - 4d e f)(x     )
+--R         + 
+--R              3       3  9         2         2  6     2     3    3     3
+--R           (8f m - 16f )x  + (12e f m - 12e f )x  + 6e f m x  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           3 8        2 5     2   2  m + 1
+--R       (24f x  + 24e f x  + 6e f x )x
+--R     + 
+--R                3      3  9           2         2  6        2        2   3    3
+--R           (- 8f m - 8f )x  + (- 12e f m - 12e f )x  + (- 6e f m - 6e f)x  - e m
+--R         + 
+--R              3
+--R           - e
+--R      *
+--R          m
+--R         x
+--R  /
+--R           2 2 2  m + 1 2        3 8          2 5       2   2    m log(x) 2
+--R       (16d f x (x     )  - 16d f x  - 16d e f x  - 4d e f x )(%e        )
+--R     + 
+--R               3 6          2 3       2    m + 1 2      4 12        3 9
+--R       (- 16d f x  - 16d e f x  - 4d e f)(x     )  + 16f x   + 32e f x
+--R     + 
+--R          2 2 6     3   3    4
+--R       24e f x  + 8e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 639
+
+)clear all
+
+--S 640 of 1070
+t0:=x^m*(e*(1+m)+2*f*(1+m-n)*x^n)/(e^2+4*d*f*x^(2+2*m)+4*e*f*x^n+4*f^2*x^(2*n))
+--R 
+--R
+--R                             m n             m
+--R        (- 2f n + 2f m + 2f)x x  + (e m + e)x
+--R   (1)  --------------------------------------
+--R           2 2n         n         2m + 2    2
+--R         4f x   + 4e f x  + 4d f x       + e
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 1070
+r0:=1/2*atan(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^n))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R               m + 1 +-+ +-+
+--R             2x     \|d \|f
+--R        atan(---------------)
+--R                    n
+--R                2f x  + e
+--R   (2)  ---------------------
+--R                +-+ +-+
+--R              2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 +-----+   n log(x) 2
+--R              4f \|- d f (%e        )
+--R            + 
+--R                     2    m log(x)        +-----+   n log(x)
+--R              (- 8d f x %e         + 4e f\|- d f )%e
+--R            + 
+--R                      2 +-----+   m log(x) 2              m log(x)    2 +-----+
+--R              - 4d f x \|- d f (%e        )  - 4d e f x %e         + e \|- d f
+--R         /
+--R              2   n log(x) 2          n log(x)         2   m log(x) 2    2
+--R            4f (%e        )  + 4e f %e         + 4d f x (%e        )  + e
+--R    /
+--R         +-----+
+--R       4\|- d f
+--R     ,
+--R              +---+  n log(x)     +---+
+--R           2f\|d f %e         + e\|d f
+--R      atan(----------------------------)
+--R                          m log(x)
+--R                 2d f x %e
+--R    - ----------------------------------]
+--R                      +---+
+--R                    2\|d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 642
+
+--S 643 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                  2 +-----+   n log(x) 2
+--R                4f \|- d f (%e        )
+--R              + 
+--R                       2    m log(x)        +-----+   n log(x)
+--R                (- 8d f x %e         + 4e f\|- d f )%e
+--R              + 
+--R                      2 +-----+   m log(x) 2              m log(x)    2 +-----+
+--R              - 4d f x \|- d f (%e        )  - 4d e f x %e         + e \|- d f
+--R           /
+--R                2   n log(x) 2          n log(x)         2   m log(x) 2    2
+--R              4f (%e        )  + 4e f %e         + 4d f x (%e        )  + e
+--R     + 
+--R                         m + 1 +-+ +-+
+--R           +-----+     2x     \|d \|f
+--R       - 2\|- d f atan(---------------)
+--R                              n
+--R                          2f x  + e
+--R  /
+--R       +-----+ +-+ +-+
+--R     4\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R               3      3  m n     3   m + 1 n - 1          2        2  m
+--R         ((- 8f m - 8f )x x  + 8f n x     x      + (- 4e f m - 4e f )x )
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R                    3      3      3   n 2          2        2        2  n
+--R               (- 8f n + 8f m + 8f )(x )  + (- 8e f n + 8e f m + 8e f )x
+--R             + 
+--R                      2        2        2   m + 1 2     2        2        2
+--R               (- 8d f n + 8d f m + 8d f )(x     )  - 2e f n + 2e f m + 2e f
+--R          *
+--R               m log(x)
+--R             %e
+--R         + 
+--R                  2        2  m n       2   m + 1 n - 1        2        2   m
+--R           (- 8e f m - 8e f )x x  + 8e f n x     x      + (- 4e f m - 4e f)x
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R                  2        2  2 m n       2   2 m + 1 n - 1
+--R           (- 8d f m - 8d f )x x x  + 8d f n x x     x
+--R         + 
+--R                                 2 m
+--R           (- 4d e f m - 4d e f)x x
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                2        2   n 2      2        2   n
+--R           (4e f m + 4e f )(x )  + (4e f m + 4e f)x
+--R         + 
+--R                                m + 1 2    3     3
+--R           (4d e f m + 4d e f)(x     )  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R            2        2   m n     2     m + 1 n - 1       3     3  m
+--R       (- 2e f m - 2e f)x x  + 2e f n x     x      + (- e m - e )x
+--R  /
+--R           4  n 2        3 n        3  m + 1 2     2 2    n log(x) 2
+--R       (16f (x )  + 16e f x  + 16d f (x     )  + 4e f )(%e        )
+--R     + 
+--R             3  n 2      2 2 n          2  m + 1 2     3    n log(x)
+--R       (16e f (x )  + 16e f x  + 16d e f (x     )  + 4e f)%e
+--R     + 
+--R               3 2  n 2          2 2 n      2 2 2  m + 1 2       2   2
+--R         (16d f x (x )  + 16d e f x x  + 16d f x (x     )  + 4d e f x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R         2 2  n 2     3   n       2    m + 1 2    4
+--R       4e f (x )  + 4e f x  + 4d e f (x     )  + e
+--R                                                    Type: Expression(Integer)
+--E 644
+
+--S 645 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                     +---+  n log(x)     +---+                 m + 1 +-+ +-+
+--R      +-+ +-+     2f\|d f %e         + e\|d f      +---+     2x     \|d \|f
+--R   - \|d \|f atan(----------------------------) - \|d f atan(---------------)
+--R                                 m log(x)                           n
+--R                        2d f x %e                               2f x  + e
+--R   --------------------------------------------------------------------------
+--R                                   +-+ +-+ +---+
+--R                                 2\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 645
+
+--S 646 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R               3      3  m n     3   m + 1 n - 1          2        2  m
+--R         ((- 8f m - 8f )x x  + 8f n x     x      + (- 4e f m - 4e f )x )
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R                    3      3      3   n 2          2        2        2  n
+--R               (- 8f n + 8f m + 8f )(x )  + (- 8e f n + 8e f m + 8e f )x
+--R             + 
+--R                      2        2        2   m + 1 2     2        2        2
+--R               (- 8d f n + 8d f m + 8d f )(x     )  - 2e f n + 2e f m + 2e f
+--R          *
+--R               m log(x)
+--R             %e
+--R         + 
+--R                  2        2  m n       2   m + 1 n - 1        2        2   m
+--R           (- 8e f m - 8e f )x x  + 8e f n x     x      + (- 4e f m - 4e f)x
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R                  2        2  2 m n       2   2 m + 1 n - 1
+--R           (- 8d f m - 8d f )x x x  + 8d f n x x     x
+--R         + 
+--R                                 2 m
+--R           (- 4d e f m - 4d e f)x x
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                2        2   n 2      2        2   n
+--R           (4e f m + 4e f )(x )  + (4e f m + 4e f)x
+--R         + 
+--R                                m + 1 2    3     3
+--R           (4d e f m + 4d e f)(x     )  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R            2        2   m n     2     m + 1 n - 1       3     3  m
+--R       (- 2e f m - 2e f)x x  + 2e f n x     x      + (- e m - e )x
+--R  /
+--R           4  n 2        3 n        3  m + 1 2     2 2    n log(x) 2
+--R       (16f (x )  + 16e f x  + 16d f (x     )  + 4e f )(%e        )
+--R     + 
+--R             3  n 2      2 2 n          2  m + 1 2     3    n log(x)
+--R       (16e f (x )  + 16e f x  + 16d e f (x     )  + 4e f)%e
+--R     + 
+--R               3 2  n 2          2 2 n      2 2 2  m + 1 2       2   2
+--R         (16d f x (x )  + 16d e f x x  + 16d f x (x     )  + 4d e f x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R         2 2  n 2     3   n       2    m + 1 2    4
+--R       4e f (x )  + 4e f x  + 4d e f (x     )  + e
+--R                                                    Type: Expression(Integer)
+--E 646
+
+)clear all
+
+--S 647 of 1070
+t0:=x^m*(e*(1+m)+2*f*(1+m-n)*x^n)/(e^2-4*d*f*x^(2+2*m)+4*e*f*x^n+4*f^2*x^(2*n))
+--R 
+--R
+--R                             m n             m
+--R        (- 2f n + 2f m + 2f)x x  + (e m + e)x
+--R   (1)  --------------------------------------
+--R           2 2n         n         2m + 2    2
+--R         4f x   + 4e f x  - 4d f x       + e
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 1070
+r0:=1/2*atanh(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^n))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                m + 1 +-+ +-+
+--R              2x     \|d \|f
+--R        atanh(---------------)
+--R                     n
+--R                 2f x  + e
+--R   (2)  ----------------------
+--R                 +-+ +-+
+--R               2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                2 +---+   n log(x) 2
+--R              4f \|d f (%e        )
+--R            + 
+--R                   2    m log(x)        +---+   n log(x)
+--R              (8d f x %e         + 4e f\|d f )%e
+--R            + 
+--R                    2 +---+   m log(x) 2              m log(x)    2 +---+
+--R              4d f x \|d f (%e        )  + 4d e f x %e         + e \|d f
+--R         /
+--R              2   n log(x) 2          n log(x)         2   m log(x) 2    2
+--R            4f (%e        )  + 4e f %e         - 4d f x (%e        )  + e
+--R    /
+--R         +---+
+--R       4\|d f
+--R     ,
+--R            +-----+  n log(x)     +-----+
+--R         2f\|- d f %e         + e\|- d f
+--R    atan(--------------------------------)
+--R                          m log(x)
+--R                 2d f x %e
+--R    --------------------------------------]
+--R                     +-----+
+--R                   2\|- d f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 649
+
+--S 650 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|d \|f
+--R      *
+--R         log
+--R                  2 +---+   n log(x) 2
+--R                4f \|d f (%e        )
+--R              + 
+--R                     2    m log(x)        +---+   n log(x)
+--R                (8d f x %e         + 4e f\|d f )%e
+--R              + 
+--R                      2 +---+   m log(x) 2              m log(x)    2 +---+
+--R                4d f x \|d f (%e        )  + 4d e f x %e         + e \|d f
+--R           /
+--R                2   n log(x) 2          n log(x)         2   m log(x) 2    2
+--R              4f (%e        )  + 4e f %e         - 4d f x (%e        )  + e
+--R     + 
+--R                        m + 1 +-+ +-+
+--R           +---+      2x     \|d \|f
+--R       - 2\|d f atanh(---------------)
+--R                             n
+--R                         2f x  + e
+--R  /
+--R       +-+ +-+ +---+
+--R     4\|d \|f \|d f
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R               3      3  m n     3   m + 1 n - 1          2        2  m
+--R         ((- 8f m - 8f )x x  + 8f n x     x      + (- 4e f m - 4e f )x )
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R                    3      3      3   n 2          2        2        2  n
+--R               (- 8f n + 8f m + 8f )(x )  + (- 8e f n + 8e f m + 8e f )x
+--R             + 
+--R                    2        2        2   m + 1 2     2        2        2
+--R               (8d f n - 8d f m - 8d f )(x     )  - 2e f n + 2e f m + 2e f
+--R          *
+--R               m log(x)
+--R             %e
+--R         + 
+--R                  2        2  m n       2   m + 1 n - 1        2        2   m
+--R           (- 8e f m - 8e f )x x  + 8e f n x     x      + (- 4e f m - 4e f)x
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R                2        2  2 m n       2   2 m + 1 n - 1
+--R           (8d f m + 8d f )x x x  - 8d f n x x     x
+--R         + 
+--R                               2 m
+--R           (4d e f m + 4d e f)x x
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                2        2   n 2      2        2   n
+--R           (4e f m + 4e f )(x )  + (4e f m + 4e f)x
+--R         + 
+--R                                  m + 1 2    3     3
+--R           (- 4d e f m - 4d e f)(x     )  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R            2        2   m n     2     m + 1 n - 1       3     3  m
+--R       (- 2e f m - 2e f)x x  + 2e f n x     x      + (- e m - e )x
+--R  /
+--R           4  n 2        3 n        3  m + 1 2     2 2    n log(x) 2
+--R       (16f (x )  + 16e f x  - 16d f (x     )  + 4e f )(%e        )
+--R     + 
+--R             3  n 2      2 2 n          2  m + 1 2     3    n log(x)
+--R       (16e f (x )  + 16e f x  - 16d e f (x     )  + 4e f)%e
+--R     + 
+--R                 3 2  n 2          2 2 n      2 2 2  m + 1 2       2   2
+--R         (- 16d f x (x )  - 16d e f x x  + 16d f x (x     )  - 4d e f x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R         2 2  n 2     3   n       2    m + 1 2    4
+--R       4e f (x )  + 4e f x  - 4d e f (x     )  + e
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                       +-----+  n log(x)     +-----+
+--R        +-+ +-+     2f\|- d f %e         + e\|- d f
+--R       \|d \|f atan(--------------------------------)
+--R                                     m log(x)
+--R                            2d f x %e
+--R     + 
+--R                         m + 1 +-+ +-+
+--R          +-----+      2x     \|d \|f
+--R       - \|- d f atanh(---------------)
+--R                              n
+--R                          2f x  + e
+--R  /
+--R       +-----+ +-+ +-+
+--R     2\|- d f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R               3      3  m n     3   m + 1 n - 1          2        2  m
+--R         ((- 8f m - 8f )x x  + 8f n x     x      + (- 4e f m - 4e f )x )
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R                    3      3      3   n 2          2        2        2  n
+--R               (- 8f n + 8f m + 8f )(x )  + (- 8e f n + 8e f m + 8e f )x
+--R             + 
+--R                    2        2        2   m + 1 2     2        2        2
+--R               (8d f n - 8d f m - 8d f )(x     )  - 2e f n + 2e f m + 2e f
+--R          *
+--R               m log(x)
+--R             %e
+--R         + 
+--R                  2        2  m n       2   m + 1 n - 1        2        2   m
+--R           (- 8e f m - 8e f )x x  + 8e f n x     x      + (- 4e f m - 4e f)x
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R                2        2  2 m n       2   2 m + 1 n - 1
+--R           (8d f m + 8d f )x x x  - 8d f n x x     x
+--R         + 
+--R                               2 m
+--R           (4d e f m + 4d e f)x x
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R                2        2   n 2      2        2   n
+--R           (4e f m + 4e f )(x )  + (4e f m + 4e f)x
+--R         + 
+--R                                  m + 1 2    3     3
+--R           (- 4d e f m - 4d e f)(x     )  + e m + e
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R            2        2   m n     2     m + 1 n - 1       3     3  m
+--R       (- 2e f m - 2e f)x x  + 2e f n x     x      + (- e m - e )x
+--R  /
+--R           4  n 2        3 n        3  m + 1 2     2 2    n log(x) 2
+--R       (16f (x )  + 16e f x  - 16d f (x     )  + 4e f )(%e        )
+--R     + 
+--R             3  n 2      2 2 n          2  m + 1 2     3    n log(x)
+--R       (16e f (x )  + 16e f x  - 16d e f (x     )  + 4e f)%e
+--R     + 
+--R                 3 2  n 2          2 2 n      2 2 2  m + 1 2       2   2
+--R         (- 16d f x (x )  - 16d e f x x  + 16d f x (x     )  - 4d e f x )
+--R      *
+--R            m log(x) 2
+--R         (%e        )
+--R     + 
+--R         2 2  n 2     3   n       2    m + 1 2    4
+--R       4e f (x )  + 4e f x  - 4d e f (x     )  + e
+--R                                                    Type: Expression(Integer)
+--E 653
+
+)clear all
+
+--S 654 of 1070
+t0:=(A+B*x+C*x^2+D*x^3)/(a+b*x+c*x^2+b*x^3+a*x^4)
+--R 
+--R
+--R               3      2
+--R            D x  + C x  + B x + A
+--R   (1)  ----------------------------
+--R           4      3      2
+--R        a x  + b x  + c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 654
+
+--S 655 of 1070
+r0:=-1/4*log(2*a+2*a*x^2+x*(b-sqrt(8*a^2+b^2-4*a*c)))*(2*a*(A-C)+_
+   D*(b-sqrt(8*a^2+b^2-4*a*c)))/(a*sqrt(8*a^2+b^2-4*a*c))+_
+   1/4*log(2*a+2*a*x^2+x*(b+sqrt(8*a^2+b^2-4*a*c)))*(2*a*(A-C)+_
+   D*(b+sqrt(8*a^2+b^2-4*a*c)))/(a*sqrt(8*a^2+b^2-4*a*c))+atan((b+4*a*x-_
+   sqrt(8*a^2+b^2-4*a*c))/(sqrt(2)*sqrt(4*a^2+2*a*c-b*(b-sqrt(8*a^2+b^2-_
+   4*a*c)))))*(4*a^2*B+b*D*(b-sqrt(8*a^2+b^2-4*a*c))-a*(b*C+2*c*D+_
+   A*(b-sqrt(8*a^2+b^2-4*a*c))-C*sqrt(8*a^2+b^2-4*a*c)))/(a*sqrt(2)*_
+   sqrt(8*a^2+b^2-4*a*c)*sqrt(4*a^2+2*a*c-b*(b-sqrt(8*a^2+b^2-4*a*c))))-_
+   atan((b+4*a*x+sqrt(8*a^2+b^2-4*a*c))/(sqrt(2)*sqrt(4*a^2+2*a*c-_
+   b*(b+sqrt(8*a^2+b^2-4*a*c)))))*(4*a^2*B+b*D*(b+sqrt(8*a^2+b^2-4*a*c))-_
+   a*(b*C+2*c*D+C*sqrt(8*a^2+b^2-4*a*c)+A*(b+sqrt(8*a^2+b^2-4*a*c))))/_
+   (a*sqrt(2)*sqrt(8*a^2+b^2-4*a*c)*sqrt(4*a^2+2*a*c-_
+   b*(b+sqrt(8*a^2+b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                                 +-----------------+
+--R                                 |          2     2                 2
+--R           (- 4D b + (4C + 4A)a)\|- 4a c + b  + 8a   + 8D a c - 4D b
+--R         + 
+--R                               2
+--R           (4C + 4A)a b - 16B a
+--R      *
+--R          +---------------------------------------+
+--R          |  +-----------------+
+--R          |  |          2     2            2     2
+--R         \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R                        +-----------------+
+--R                        |          2     2
+--R                       \|- 4a c + b  + 8a   + 4a x + b
+--R         atan(------------------------------------------------)
+--R                   +-----------------------------------------+
+--R                   |    +-----------------+
+--R               +-+ |    |          2     2            2     2
+--R              \|2 \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R     + 
+--R                                 +-----------------+
+--R                                 |          2     2                 2
+--R           (4D b + (- 4C - 4A)a)\|- 4a c + b  + 8a   + 8D a c - 4D b
+--R         + 
+--R                               2
+--R           (4C + 4A)a b - 16B a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------------+
+--R          |    |          2     2            2     2
+--R         \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R                       +-----------------+
+--R                       |          2     2
+--R                      \|- 4a c + b  + 8a   - 4a x - b
+--R         atan(----------------------------------------------)
+--R                   +---------------------------------------+
+--R                   |  +-----------------+
+--R               +-+ |  |          2     2            2     2
+--R              \|2 \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R     + 
+--R                    +-----------------+
+--R                +-+ |          2     2                         +-+
+--R             (D\|2 \|- 4a c + b  + 8a   + (D b + (- 2C + 2A)a)\|2 )
+--R          *
+--R                   +-----------------+
+--R                   |          2     2        2
+--R             log(x\|- 4a c + b  + 8a   + 2a x  + b x + 2a)
+--R         + 
+--R                    +-----------------+
+--R                +-+ |          2     2                         +-+
+--R             (D\|2 \|- 4a c + b  + 8a   + (- D b + (2C - 2A)a)\|2 )
+--R          *
+--R                     +-----------------+
+--R                     |          2     2        2
+--R             log(- x\|- 4a c + b  + 8a   + 2a x  + b x + 2a)
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------------+
+--R          |    |          2     2            2     2
+--R         \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R          +---------------------------------------+
+--R          |  +-----------------+
+--R          |  |          2     2            2     2
+--R         \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R  /
+--R                                  +-----------------------------------------+
+--R              +-----------------+ |    +-----------------+
+--R          +-+ |          2     2  |    |          2     2            2     2
+--R       4a\|2 \|- 4a c + b  + 8a  \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R    *
+--R        +---------------------------------------+
+--R        |  +-----------------+
+--R        |  |          2     2            2     2
+--R       \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                a
+--R             *
+--R                ROOT
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN1
+--R                     + 
+--R                                   3 3      2 2      4  2       3 2      5
+--R                               - 8a c  + (2a b  - 16a )c  + (40a b  + 32a )c
+--R                             + 
+--R                                   2 4      4 2      6
+--R                               - 8a b  - 56a b  + 64a
+--R                          *
+--R                             %%BN0
+--R                         + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN1
+--R                     + 
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN0
+--R                     + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN0
+--R                     + 
+--R                           2 2                          2     2  2  2
+--R                       (- D b  + 4C D a b + (- 8B D - 4C  - 4A )a )c
+--R                     + 
+--R                               2   2                               2
+--R                           - 4D a b  + ((20C + 4A)D + 4B C + 4A B)a b
+--R                         + 
+--R                              2             2             2     2  3
+--R                           (8D  - 16B D - 8C  + 16A C + 8B  - 8A )a
+--R                      *
+--R                         c
+--R                     + 
+--R                         2 4            3
+--R                       4D b  - 16C D a b
+--R                     + 
+--R                            2              2            2      2  2 2
+--R                       (- 8D  + 24B D + 12C  - 8A C - 4B  + 12A )a b
+--R                     + 
+--R                                                       3
+--R                       ((- 8C - 24A)D - 24B C - 24A B)a b
+--R                     + 
+--R                           2              2  4
+--R                       (16D  + 32A C + 16B )a
+--R                  /
+--R                         3 3       2 2     4  2         3 2      5       2 4
+--R                       4a c  + (- a b  + 8a )c  + (- 20a b  - 16a )c + 4a b
+--R                     + 
+--R                          4 2      6
+--R                       28a b  - 32a
+--R         + 
+--R           - a %%BN1 - a %%BN0 + D
+--R      *
+--R         log
+--R                               2 4 8
+--R                          32A D a c
+--R                        + 
+--R                                     2 3 2         3        2  4
+--R                              - 16A D a b  + (- 16D  - 16B D )a b
+--R                            + 
+--R                                     2                   2      3  5
+--R                              (128A D  - 128A B D - 32A C  + 32A )a
+--R                         *
+--R                             7
+--R                            c
+--R                        + 
+--R                                  2 2 4      3       2  3 3
+--R                              2A D a b  + (8D  + 8B D )a b
+--R                            + 
+--R                                            2                  2      3  4 2
+--R                              ((32C - 448A)D  + 64A B D + 16A C  - 16A )a b
+--R                            + 
+--R                                       3        2
+--R                                  - 32D  + 32B D
+--R                                + 
+--R                                        2               2       2          2
+--R                                  (- 48C  + 224A C + 64B  + 144A )D + 16B C
+--R                                + 
+--R                                               2
+--R                                  96A B C - 48A B
+--R                             *
+--R                                 5
+--R                                a b
+--R                            + 
+--R                                          2                 3         2      2
+--R                                  - 128A D  - 512A B D + 64C  - 128A C  - 64A C
+--R                                + 
+--R                                        2       3
+--R                                  128A B  + 128A
+--R                             *
+--R                                 6
+--R                                a
+--R                         *
+--R                             6
+--R                            c
+--R                        + 
+--R                                  3      2  2 5
+--R                              (- D  - B D )a b
+--R                            + 
+--R                                              2                2     3  3 4
+--R                              ((- 16C + 192A)D  - 8A B D - 2A C  + 2A )a b
+--R                            + 
+--R                                      3         2
+--R                                  160D  + 128B D
+--R                                + 
+--R                                      2               2      2         2
+--R                                  (24C  - 112A C - 32B  - 72A )D - 8B C
+--R                                + 
+--R                                                 2
+--R                                  - 48A B C + 24A B
+--R                             *
+--R                                 4 3
+--R                                a b
+--R                            + 
+--R                                               2                             3
+--R                                  (80C - 560A)D  + (- 96B C + 1312A B)D - 48C
+--R                                + 
+--R                                        2         2      2           2       3
+--R                                  304A C  + (- 48B  - 16A )C - 112A B  - 368A
+--R                             *
+--R                                 5 2
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  128D  + 256B D
+--R                                + 
+--R                                         2               2       2           2
+--R                                  (- 384C  + 512A C + 64B  + 384A )D - 128B C
+--R                                + 
+--R                                       3       2
+--R                                  - 64B  - 384A B
+--R                             *
+--R                                 6
+--R                                a b
+--R                            + 
+--R                                           2                  3         2
+--R                                  - 1024A D  + 512A B D + 256C  + 128A C
+--R                                + 
+--R                                        2          2       3
+--R                                  - 256A C + 512A B  - 128A
+--R                             *
+--R                                 7
+--R                                a
+--R                         *
+--R                             5
+--R                            c
+--R                        + 
+--R                                         2 2 6
+--R                              (2C - 22A)D a b
+--R                            + 
+--R                                       3        2        2             2     2
+--R                                  - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D
+--R                                + 
+--R                                     2              2
+--R                                  B C  + 6A B C - 3A B
+--R                             *
+--R                                 3 5
+--R                                a b
+--R                            + 
+--R                                                   2                          3
+--R                                  (- 328C + 1896A)D  + (48B C - 528A B)D + 12C
+--R                                + 
+--R                                          2       2      2          2       3
+--R                                  - 120A C  + (24B  + 20A )C + 32A B  + 152A
+--R                             *
+--R                                 4 4
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 224D  - 800B D
+--R                                + 
+--R                                       2                 2        2          2
+--R                                  (720C  - 2080A C - 512B  - 1392A )D + 16B C
+--R                                + 
+--R                                                  3       2
+--R                                  - 672A B C + 64B  + 720A B
+--R                             *
+--R                                 5 3
+--R                                a b
+--R                            + 
+--R                                                 2                             3
+--R                                  (160C + 2976A)D  + (576B C + 1088A B)D - 608C
+--R                                + 
+--R                                        2        2       2            2      3
+--R                                  416A C  + (288B  + 992A )C - 1120A B  - 32A
+--R                             *
+--R                                 6 2
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  256D  - 256B D
+--R                                + 
+--R                                         2                 2       2           2
+--R                                  (- 192C  - 1664A C - 640B  - 960A )D - 448B C
+--R                                + 
+--R                                                    3       2
+--R                                  - 1152A B C - 128B  - 192A B
+--R                             *
+--R                                 7
+--R                                a b
+--R                            + 
+--R                                          2                   3          2
+--R                                  - 512A D  + 4096A B D - 256C  + 1024A C
+--R                                + 
+--R                                      2          2        3
+--R                                  256A C - 512A B  - 1024A
+--R                             *
+--R                                 8
+--R                                a
+--R                         *
+--R                             4
+--R                            c
+--R                        + 
+--R                                 3       2  2 7
+--R                              (8D  + 8B D )a b
+--R                            + 
+--R                                                2                        3
+--R                                  (141C - 755A)D  + (- 6B C + 58A B)D - C
+--R                                + 
+--R                                       2        2     2         2      3
+--R                                  13A C  + (- 3B  - 3A )C - 3A B  - 17A
+--R                             *
+--R                                 3 6
+--R                                a b
+--R                            + 
+--R                                        3        2
+--R                                  - 284D  - 36B D
+--R                                + 
+--R                                         2                2       2          2
+--R                                  (- 276C  + 888A C + 228B  + 588A )D + 12B C
+--R                                + 
+--R                                                3       2
+--R                                  312A B C - 20B  - 276A B
+--R                             *
+--R                                 4 5
+--R                                a b
+--R                            + 
+--R                                                  2
+--R                                  (- 32C - 2016A)D  + (192B C - 3072A B)D
+--R                                + 
+--R                                      3         2       2       2           2
+--R                                  320C  - 720A C  + (96B  - 192A )C + 672A B
+--R                                + 
+--R                                      3
+--R                                  848A
+--R                             *
+--R                                 5 4
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 896D  - 384B D
+--R                                + 
+--R                                        2                 2       2            2
+--R                                  (1344C  + 1408A C + 896B  + 576A )D + 1088B C
+--R                                + 
+--R                                                  3        2
+--R                                  1920A B C + 384B  + 1344A B
+--R                             *
+--R                                 6 3
+--R                                a b
+--R                            + 
+--R                                                   2
+--R                                  (- 640C + 4224A)D  + (768B C - 8448A B)D
+--R                                + 
+--R                                        3          2        2       2
+--R                                  - 128C  - 1920A C  + (384B  + 640A )C
+--R                                + 
+--R                                          2        3
+--R                                  - 128A B  + 2432A
+--R                             *
+--R                                 7 2
+--R                                a b
+--R                            + 
+--R                                        3          2
+--R                                  - 256D  - 1280B D
+--R                                + 
+--R                                        2                 2        2
+--R                                  (3072C  - 4096A C - 512B  - 3072A )D
+--R                                + 
+--R                                         2       3        2
+--R                                  1024B C  + 512B  + 3072A B
+--R                             *
+--R                                 8
+--R                                a b
+--R                            + 
+--R                                         2                    3         2
+--R                                  2048A D  + 2048A B D - 2048C  + 512A C
+--R                                + 
+--R                                       2           2       3
+--R                                  2048A C - 4096A B  - 512A
+--R                             *
+--R                                 9
+--R                                a
+--R                         *
+--R                             3
+--R                            c
+--R                        + 
+--R                                            2 2 8
+--R                              (- 16C + 80A)D a b
+--R                            + 
+--R                                      3         2
+--R                                  146D  + 118B D
+--R                                + 
+--R                                      2               2      2         2
+--R                                  (30C  - 100A C - 26B  - 66A )D - 2B C
+--R                                + 
+--R                                                3      2
+--R                                  - 36A B C + 2B  + 30A B
+--R                             *
+--R                                 3 7
+--R                                a b
+--R                            + 
+--R                                                 2
+--R                                  (726C - 2090A)D  + (- 180B C + 1100A B)D
+--R                                + 
+--R                                       3         2         2      2           2
+--R                                  - 62C  + 230A C  + (- 90B  - 58A )C - 154A B
+--R                                + 
+--R                                        3
+--R                                  - 350A
+--R                             *
+--R                                 4 6
+--R                                a b
+--R                            + 
+--R                                       3          2
+--R                                  1752D  + 2760B D
+--R                                + 
+--R                                          2                 2        2
+--R                                  (- 2160C  + 3840A C + 696B  + 2736A )D
+--R                                + 
+--R                                          2                  3        2
+--R                                  - 528B C  + 576A B C - 312B  - 2160A B
+--R                             *
+--R                                 5 5
+--R                                a b
+--R                            + 
+--R                                           2                                3
+--R                                  - 8160A D  + (- 4608B C + 5376A B)D + 864C
+--R                                + 
+--R                                        2           2        2           2
+--R                                  192A C  + (- 2304B  - 3936A )C + 960A B
+--R                                + 
+--R                                         3
+--R                                  - 3264A
+--R                             *
+--R                                 6 4
+--R                                a b
+--R                            + 
+--R                                       3          2
+--R                                  1152D  + 4224B D
+--R                                + 
+--R                                          2                   2        2
+--R                                  (- 5760C  + 11520A C + 2304B  + 8064A )D
+--R                                + 
+--R                                           2                   3        2
+--R                                  - 1152B C  + 2304A B C - 768B  - 5760A B
+--R                             *
+--R                                 7 3
+--R                                a b
+--R                            + 
+--R                                                    2
+--R                                  (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D
+--R                                + 
+--R                                       3          2           2        2
+--R                                  3840C  - 3072A C  + (- 2304B  - 6912A )C
+--R                                + 
+--R                                         2
+--R                                  6912A B
+--R                             *
+--R                                 8 2
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 512D  + 512B D
+--R                                + 
+--R                                        2                  2       2
+--R                                  (3840C  + 2560A C + 2048B  + 768A )D
+--R                                + 
+--R                                         2                    3        2
+--R                                  2816B C  + 4608A B C + 1024B  + 3840A B
+--R                             *
+--R                                 9
+--R                                a b
+--R                            + 
+--R                                         2                    3          2
+--R                                  2048A D  - 8192A B D - 1024C  - 2048A C
+--R                                + 
+--R                                       2           2        3
+--R                                  1024A C - 2048A B  + 2048A
+--R                             *
+--R                                 10
+--R                                a
+--R                         *
+--R                             2
+--R                            c
+--R                        + 
+--R                                    3        2  2 9
+--R                              (- 16D  - 16B D )a b
+--R                            + 
+--R                                                  2                         3
+--R                                  (- 308C + 972A)D  + (24B C - 104A B)D + 4C
+--R                                + 
+--R                                         2       2      2          2      3
+--R                                  - 20A C  + (12B  + 12A )C + 12A B  + 36A
+--R                             *
+--R                                 3 8
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 456D  - 920B D
+--R                                + 
+--R                                       2                 2        2           2
+--R                                  (744C  - 1712A C - 376B  - 1176A )D + 104B C
+--R                                + 
+--R                                                  3       2
+--R                                  - 432A B C + 88B  + 744A B
+--R                             *
+--R                                 4 7
+--R                                a b
+--R                            + 
+--R                                                    2
+--R                                  (- 1668C + 8316A)D  + (1656B C - 136A B)D
+--R                                + 
+--R                                        3         2        2        2
+--R                                  - 364C  + 380A C  + (828B  + 1468A )C
+--R                                + 
+--R                                          2       3
+--R                                  - 452A B  + 724A
+--R                             *
+--R                                 5 6
+--R                                a b
+--R                            + 
+--R                                         3          2
+--R                                  - 2496D  - 6432B D
+--R                                + 
+--R                                        2                   2        2
+--R                                  (5328C  - 14304A C - 3408B  - 9648A )D
+--R                                + 
+--R                                        2                   3        2
+--R                                  336B C  - 4320A B C + 528B  + 5328A B
+--R                             *
+--R                                 6 5
+--R                                a b
+--R                            + 
+--R                                                  2
+--R                                  (6528C + 3456A)D  + (11520B C + 7296A B)D
+--R                                + 
+--R                                         3          2         2         2
+--R                                  - 3072C  + 4704A C  + (5760B  + 10752A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 4224A B  + 2976A
+--R                             *
+--R                                 7 4
+--R                                a b
+--R                            + 
+--R                                       3         2
+--R                                  1024D  - 512B D
+--R                                + 
+--R                                          2                  2        2
+--R                                  (- 5760C  - 3840A C - 3072B  - 1152A )D
+--R                                + 
+--R                                           2                    3        2
+--R                                  - 4224B C  - 6912A B C - 1536B  - 5760A B
+--R                             *
+--R                                 8 3
+--R                                a b
+--R                            + 
+--R                                                  2
+--R                                  (1280C - 6912A)D  + (- 1536B C + 12800A B)D
+--R                                + 
+--R                                       3          2          2        2
+--R                                  1280C  + 2816A C  + (- 768B  - 2304A )C
+--R                                + 
+--R                                         2        3
+--R                                  2304A B  - 3840A
+--R                             *
+--R                                 9 2
+--R                                a b
+--R                            + 
+--R                                         2
+--R                                  2048B D
+--R                                + 
+--R                                          2                  2        2
+--R                                  (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                                + 
+--R                                           2        3        2
+--R                                  - 2048B C  - 1024B  - 6144A B
+--R                             *
+--R                                 10
+--R                                a  b
+--R                            + 
+--R                                                     3          2        2
+--R                                  - 8192A B D + 4096C  - 2048A C  - 4096A C
+--R                                + 
+--R                                         2        3
+--R                                  8192A B  + 2048A
+--R                             *
+--R                                 11
+--R                                a
+--R                         *
+--R                            c
+--R                        + 
+--R                                      2 2 10
+--R                          (32C - 96A)D a b
+--R                        + 
+--R                                 3        2         2               2       2
+--R                              24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D
+--R                            + 
+--R                                    2               3      2
+--R                              - 8B C  + 48A B C - 8B  - 72A B
+--R                         *
+--R                             3 9
+--R                            a b
+--R                        + 
+--R                                             2                             3
+--R                              (376C - 1416A)D  + (- 144B C - 144A B)D + 40C
+--R                            + 
+--R                                     2         2       2          2      3
+--R                              - 72A C  + (- 72B  - 136A )C + 56A B  - 24A
+--R                         *
+--R                             4 8
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              360D  + 1080B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 936C  + 2608A C + 632B  + 1752A )D - 40B C
+--R                            + 
+--R                                            3       2
+--R                              816A B C - 88B  - 936A B
+--R                         *
+--R                             5 7
+--R                            a b
+--R                        + 
+--R                                              2                                3
+--R                              (- 24C - 4248A)D  + (- 2160B C - 2160A B)D + 536C
+--R                            + 
+--R                                     2           2        2           2       3
+--R                            - 1080A C  + (- 1080B  - 1976A )C + 712A B  - 360A
+--R                         *
+--R                             6 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1152D  + 3456B D
+--R                            + 
+--R                                      2                  2        2           2
+--R                              (- 1296C  + 7968A C + 2400B  + 5040A )D + 816B C
+--R                            + 
+--R                                             3        2
+--R                              3744A B C + 96B  - 1296A B
+--R                         *
+--R                             7 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D
+--R                            + 
+--R                                  3          2           2        2           2
+--R                              960C  - 3456A C  + (- 3456B  - 5568A )C + 768A B
+--R                            + 
+--R                                     3
+--R                              - 1152A
+--R                         *
+--R                             8 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1536D  - 4608B D
+--R                            + 
+--R                                     2                   2        2            2
+--R                              (11520C  - 12800A C - 1024B  - 9984A )D + 4352B C
+--R                            + 
+--R                                               3         2
+--R                              1536A B C + 2048B  + 11520A B
+--R                         *
+--R                             9 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (6656C - 1536A)D  + (9216B C + 9216A B)D - 5632C
+--R                            + 
+--R                                   2         2         2            2        3
+--R                            4608A C  + (4608B  + 11776A )C - 9728A B  + 1536A
+--R                         *
+--R                             10 2
+--R                            a  b
+--R                        + 
+--R                                      2                  2        2            2
+--R                              (- 9216C  + 2048A C - 2048B  + 3072A )D - 5120B C
+--R                            + 
+--R                                                 3        2
+--R                              - 6144A B C - 2048B  - 9216A B
+--R                         *
+--R                             11
+--R                            a  b
+--R                        + 
+--R                                3        2           2  12
+--R                          (4096C  - 4096A C + 8192A B )a
+--R                     *
+--R                        %%BN0
+--R                    + 
+--R                             3 3 8
+--R                      - 16A D a c
+--R                    + 
+--R                              3 2 2        3          2  3
+--R                          4A D a b  + (8B D  + 24A C D )a b
+--R                        + 
+--R                                       3          2           2      3    4
+--R                          ((16C - 64A)D  + 80A B D  + (- 16A C  - 16A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                 3         2  2 3
+--R                          (- 2B D  - 6A C D )a b
+--R                        + 
+--R                                             3                     2
+--R                              (- 12C + 188A)D  + (- 12B C - 52A B)D
+--R                            + 
+--R                                     2      3
+--R                              (- 4A C  + 12A )D
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 24D  + 16B D
+--R                            + 
+--R                                    2              2       2  2
+--R                              (- 24C  + 16A C - 40B  - 120A )D
+--R                            + 
+--R                                   2                2          3     3
+--R                              (8B C  - 48A B C + 24A B)D + 8A C  - 8A C
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                          3                      2
+--R                              (64C + 32A)D  + (- 96B C + 320A B)D
+--R                            + 
+--R                                  3        2       2          2      3
+--R                              (16C  - 64A C  + 112A C - 128A B  - 64A )D
+--R                            + 
+--R                                     2      3
+--R                              48A B C  + 16A B
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                      3                 2        2     3    2 4
+--R                          ((2C - 41A)D  + (3B C + 8A B)D  + (2A C  - 2A )D)a b
+--R                        + 
+--R                                 4        3       2               2      2  2
+--R                              14D  - 80B D  + (18C  - 224A C + 26B  + 66A )D
+--R                            + 
+--R                                   2                2          3     3
+--R                              (2B C  + 36A B C - 18A B)D - 2A C  + 2A C
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                              3                     2
+--R                              (- 144C + 232A)D  + (120B C - 808A B)D
+--R                            + 
+--R                                      3         2       2      2           2
+--R                                  - 4C  + 212A C  + (24B  - 20A )C + 112A B
+--R                                + 
+--R                                      3
+--R                                  196A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3          2      2        3
+--R                              - 4B C  - 36A B C  + 12A B C - 4A B
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 64D  + 96B D
+--R                            + 
+--R                                    2              2       2  2
+--R                              (- 24C  - 80A C - 64B  - 408A )D
+--R                            + 
+--R                                    2                3       2        4        3
+--R                              (80B C  - 96A B C + 64B  + 336A B)D - 8C  - 32A C
+--R                            + 
+--R                                    2      2  2           2      3        2 2
+--R                              (- 24B  - 48A )C  + (- 48A B  - 32A )C - 24A B
+--R                            + 
+--R                                  4
+--R                              - 8A
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    3                       2
+--R                              384A D  + (- 384B C - 128A B)D
+--R                            + 
+--R                                  3         2        2       2           2
+--R                              (64C  - 128A C  + (192B  + 448A )C - 512A B )D
+--R                            + 
+--R                                     3           2       2           3      3
+--R                              - 64B C  + 192A B C  - 192A B C + 64A B  + 64A B
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                  4        3        2             2     2  2
+--R                              - 2D  + 18B D  + (- 3C  + 52A C - 4B  - 9A )D
+--R                            + 
+--R                                    2              2
+--R                              (- B C  - 6A B C + 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                           3                    2
+--R                              (86C - 686A)D  + (54B C + 420A B)D
+--R                            + 
+--R                                      3       2         2      2          2
+--R                                  - 4C  + 9A C  + (- 18B  - 14A )C - 32A B
+--R                                + 
+--R                                        3
+--R                                  - 115A
+--R                             *
+--R                                D
+--R                            + 
+--R                                 3         2     2
+--R                              B C  + 6A B C  - 3A B C
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                  4        3
+--R                              224D  - 92B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (162C  + 280A C + 320B  + 1206A )D
+--R                            + 
+--R                                       2                 3       2        4
+--R                              (- 172B C  + 336A B C - 60B  - 492A B)D + 6C
+--R                            + 
+--R                                     3       2      2  2         2      3
+--R                              - 48A C  + (18B  + 24A )C  + (24A B  + 80A )C
+--R                            + 
+--R                                2 2     4
+--R                              6A B  + 2A
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                               3                     2
+--R                              (- 232C - 1128A)D  + (936B C - 584A B)D
+--R                            + 
+--R                                        3         2          2        2
+--R                                  - 208C  + 400A C  + (- 312B  - 1376A )C
+--R                                + 
+--R                                         2      3
+--R                                  1192A B  - 64A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2       3       2           3
+--R                              96B C  - 384A B C  + (24B  + 240A B)C - 24A B
+--R                            + 
+--R                                    3
+--R                              - 144A B
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                 4         3        2               2       2  2
+--R                              64D  + 256B D  + (144C  + 608A C - 32B  + 336A )D
+--R                            + 
+--R                                    2      3       2         4        3
+--R                              (64B C  + 64B  + 768A B)D + 48C  - 96A C
+--R                            + 
+--R                                  2      2  2           2       3        4
+--R                              (48B  + 96A )C  + (- 96A B  + 224A )C - 32B
+--R                            + 
+--R                                    2 2      4
+--R                              - 144A B  - 16A
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                              3            2
+--R                              (- 256C + 256A)D  - 1792A B D
+--R                            + 
+--R                                     3         2        2      2           2
+--R                                  64C  - 256A C  + (768B  - 64A )C + 128A B
+--R                                + 
+--R                                      3
+--R                                  256A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3       2
+--R                              - 256B C  + 192A B C  + (- 128B  - 768A B)C
+--R                            + 
+--R                                    3      3
+--R                              256A B  + 64A B
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                             3                     2
+--R                              (- 13C + 139A)D  + (- 18B C - 58A B)D
+--R                            + 
+--R                                3        2      2     2         2      3
+--R                              (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 109D  + 265B D
+--R                            + 
+--R                                     2                2       2  2
+--R                              (- 114C  + 591A C - 183B  - 543A )D
+--R                            + 
+--R                                    2                 3       2       4        3
+--R                              (27B C  - 228A B C + 19B  + 225A B)D - C  + 13A C
+--R                            + 
+--R                                   2     2  2          2      3
+--R                              (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                            3                        2
+--R                              (258C + 874A)D  + (- 978B C + 1542A B)D
+--R                            + 
+--R                                     3         2       2       2           2
+--R                                  94C  - 990A C  + (54B  + 426A )C - 714A B
+--R                                + 
+--R                                        3
+--R                                  - 346A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3           2         3       2          3
+--R                              - 10B C  + 234A B C  + (- 14B  - 174A B)C + 2A B
+--R                            + 
+--R                                 3
+--R                              30A B
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                      3          2               2       2  2
+--R                              - 768B D  + (- 192C  - 736A C - 80B  + 384A )D
+--R                            + 
+--R                                       2                 3        2            3
+--R                              (- 272B C  + 96A B C - 384B  - 1968A B)D + 368A C
+--R                            + 
+--R                                  2       2  2          2       3        4
+--R                              (48B  + 192A )C  + (288A B  - 112A )C + 16B
+--R                            + 
+--R                                  2 2      4
+--R                              240A B  + 64A
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (384C - 1536A)D  + (576B C + 4032A B)D
+--R                            + 
+--R                                        3         2           2        2
+--R                                  - 416C  + 672A C  + (- 2112B  - 1312A )C
+--R                                + 
+--R                                        2       3
+--R                                  512A B  - 992A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3        2            3
+--R                              480B C  - 672A B C  + (128B  + 1632A B)C - 512A B
+--R                            + 
+--R                                    3
+--R                              - 160A B
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              256D  - 384B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 192C  + 1024A C - 256B  + 2112A )D
+--R                            + 
+--R                                       2                  3        2          4
+--R                              (- 640B C  - 768A B C - 256B  - 1152A B)D + 192C
+--R                            + 
+--R                                   2       2  2          2       3         2 2
+--R                              (576B  + 384A )C  + (384A B  + 512A )C - 192A B
+--R                            + 
+--R                                   4
+--R                              - 64A
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                              3                       2
+--R                              (- 256C - 512A)D  + (1536B C - 1280A B)D
+--R                            + 
+--R                                     2        2           2       3         3
+--R                              (256A C  - 2048A C + 2560A B  + 256A )D - 512B C
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                 4        3       2               2      2  2
+--R                              14D  - 54B D  + (18C  - 140A C + 26B  + 66A )D
+--R                            + 
+--R                                   2               3      2
+--R                              (2B C  + 36A B C - 2B  - 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                              3                    2
+--R                              (- 142C + 688A)D  + (54B C - 800A B)D
+--R                            + 
+--R                                      3         2       2      2           2
+--R                                    6C  + 100A C  + (54B  + 22A )C + 160A B
+--R                                  + 
+--R                                        3
+--R                                    248A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3          2      3      2
+--R                              - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 416D  + 190B D
+--R                            + 
+--R                                    2                 2        2  2
+--R                              (- 84C  - 1254A C - 438B  - 2514A )D
+--R                            + 
+--R                                     2                  3        2         4
+--R                              (666B C  - 264A B C + 298B  + 1758A B)D - 20C
+--R                            + 
+--R                                   3         2       2  2            2       3
+--R                              22A C  + (- 66B  - 102A )C  + (- 114A B  - 158A )C
+--R                            + 
+--R                                  4      2 2      4
+--R                              - 2B  - 48A B  - 14A
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (284C + 2876A)D  + (- 588B C - 3516A B)D
+--R                            + 
+--R                                      3        2         2        2            2
+--R                                  788C  + 84A C  + (2292B  + 4428A )C - 1404A B
+--R                                + 
+--R                                       3
+--R                                  2252A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3        2
+--R                              - 532B C  + 492A B C  + (- 148B  - 1164A B)C
+--R                            + 
+--R                                    3       3
+--R                              140A B  + 308A B
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 608D  + 640B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (240C  - 3552A C + 960B  - 5232A )D
+--R                            + 
+--R                                      2                   3        2          4
+--R                              (1632B C  + 1536A B C + 928B  + 1632A B)D - 464C
+--R                            + 
+--R                                      3          2        2  2
+--R                              - 128A C  + (- 912B  - 1344A )C
+--R                            + 
+--R                                       2        3         4       2 2      4
+--R                              (- 384A B  - 1664A )C + 160B  + 528A B  + 16A
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                              3                         2
+--R                              (1280C + 1664A)D  + (- 1920B C + 3456A B)D
+--R                            + 
+--R                                      3         2          2        2
+--R                                  128C  + 576A C  + (- 192B  + 6144A )C
+--R                                + 
+--R                                           2       3
+--R                                  - 4800A B  + 704A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2        3       2
+--R                              - 256B C  - 768A B C  + (704B  + 384A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 448A B  + 128A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              128D  - 1280B D
+--R                            + 
+--R                                     2                 2       2  2
+--R                              (- 768C  - 2560A C + 640B  + 768A )D
+--R                            + 
+--R                                       2                   2          4
+--R                              (- 896B C  - 768A B C - 4224A B)D - 128C
+--R                            + 
+--R                                      3        2       2  2          2       3
+--R                              - 128A C  + (384B  - 768A )C  + (768A B  - 896A )C
+--R                            + 
+--R                                  4       2 2       4
+--R                              256B  + 384A B  - 128A
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                      3                       2
+--R                              - 512A D  + (1536B C + 2048A B)D
+--R                            + 
+--R                                        3          2           2        2
+--R                                  - 256C  + 2048A C  + (- 3072B  - 1792A )C
+--R                                + 
+--R                                         2
+--R                                  2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2        2             3       3
+--R                            1024B C  - 768A B C  + 3072A B C - 1024A B  - 256A B
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                           3                    2
+--R                              (20C - 156A)D  + (24B C + 104A B)D
+--R                            + 
+--R                                 3        2         2      2          2      3
+--R                            (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              204D  - 316B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (144C  - 364A C + 292B  + 1092A )D
+--R                            + 
+--R                                       2                 3       2        4
+--R                              (- 164B C  + 288A B C - 84B  - 636A B)D + 4C
+--R                            + 
+--R                                     3       2      2  2         2      3
+--R                              - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                              3                       2
+--R                              (- 36C - 3084A)D  + (1368B C + 1312A B)D
+--R                            + 
+--R                                        3          2          2        2
+--R                                  - 428C  + 1348A C  + (- 996B  - 1780A )C
+--R                                + 
+--R                                        2       3
+--R                                  644A B  - 996A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2       3       2          3
+--R                              128B C  - 312A B C  + (64B  + 528A B)C - 8A B
+--R                            + 
+--R                                   3
+--R                              - 56A B
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              924D  + 588B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 216C  + 5556A C + 60B  + 6156A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 2172B C  - 1584A B C - 444B  - 1332A B)D
+--R                            + 
+--R                                  4         3        2       2  2
+--R                              252C  - 708A C  + (540B  + 396A )C
+--R                            + 
+--R                                      2        3        4       2 2       4
+--R                              (- 36A B  + 1236A )C - 72B  - 576A B  - 120A
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                                3                        2
+--R                              (- 2184C - 2040A)D  + (- 648B C - 2616A B)D
+--R                            + 
+--R                                        3          2          2        2
+--R                                  - 408C  - 2760A C  + (- 504B  - 9096A )C
+--R                                + 
+--R                                         2        3
+--R                                  3720A B  - 2904A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3            2          3       2
+--R                              840B C  + 1656A B C  + (- 168B  - 360A B)C
+--R                            + 
+--R                                    3       3
+--R                              792A B  - 408A B
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 480D  + 1536B D
+--R                            + 
+--R                                   2                  2        2  2
+--R                              (864C  + 4992A C - 2400B  - 1440A )D
+--R                            + 
+--R                                      2                  3        2          4
+--R                              (1056B C  + 576A B C - 768B  + 6624A B)D + 384C
+--R                            + 
+--R                                    3          2        2  2
+--R                              864A C  + (- 576B  + 2304A )C
+--R                            + 
+--R                                        2        3         4       2 2       4
+--R                              (- 1152A B  + 2208A )C - 576B  - 576A B  + 384A
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                             3                         2
+--R                              (256C + 2688A)D  + (- 2688B C - 4736A B)D
+--R                            + 
+--R                                       3          2         2        2
+--R                                  1216C  - 4544A C  + (6528B  + 4032A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 2304A B  + 1344A
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3            2        2             3
+--R                              - 1344B C  + 1728A B C  - 5184A B C + 1536A B
+--R                            + 
+--R                                  3
+--R                              192A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                      3         2                  2        2  2
+--R                              - 512B D  + (1152C  - 4352A C + 2048B  - 1920A )D
+--R                            + 
+--R                                      2                   2          4         3
+--R                              (1280B C  + 4608A B C - 768A B)D - 640C  + 512A C
+--R                            + 
+--R                                      2       2  2            2        3
+--R                              (- 1920B  - 768A )C  + (- 768A B  - 1536A )C
+--R                            + 
+--R                                   2 2       4
+--R                              1152A B  + 384A
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2
+--R                              2048A B D
+--R                            + 
+--R                                         3          2           2        2
+--R                                  - 1024C  + 2048A C  + (- 3072B  + 1024A )C
+--R                                + 
+--R                                           2
+--R                                  - 2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3            2         3        2
+--R                              1024B C  - 3072A B C  + (2048B  + 3072A B)C
+--R                            + 
+--R                                       3        3
+--R                              - 1024A B  - 1024A B
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                               4        3         2               2       2  2
+--R                          - 24D  + 56B D  + (- 24C  + 112A C - 40B  - 120A )D
+--R                        + 
+--R                               2               3      2
+--R                          (8B C  - 48A B C + 8B  + 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                      3                      2
+--R                          (8C + 336A)D  + (- 216B C - 96A B)D
+--R                        + 
+--R                              3         2        2       2          2      3
+--R                          (56C  - 240A C  + (120B  + 184A )C - 80A B  + 96A )D
+--R                        + 
+--R                                3          2        3      2
+--R                          - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 216D  + 192B D
+--R                        + 
+--R                                2               2        2  2
+--R                          (- 72C  - 40A C - 176B  - 1248A )D
+--R                        + 
+--R                                 2                3       2         4         3
+--R                          (304B C  + 48A B C + 64B  + 384A B)D - 32C  + 120A C
+--R                        + 
+--R                                2      2  2         2       3       4      2 2
+--R                          (- 72B  - 24A )C  + (24A B  - 152A )C + 8B  + 96A B
+--R                        + 
+--R                             4
+--R                          24A
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                         3                        2
+--R                          (264C + 2304A)D  + (- 1080B C - 144A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              280C  - 1008A C  + (504B  + 1880A )C - 736A B
+--R                            + 
+--R                                  3
+--R                              864A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3          2        3       2            3
+--R                          - 120B C  - 96A B C  + (- 8B  - 216A B)C - 144A B
+--R                        + 
+--R                             3
+--R                          16A B
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 144D  - 1848B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (576C  - 6600A C + 984B  - 1800A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (1416B C  + 2304A B C + 120B  - 1800A B)D - 192C
+--R                        + 
+--R                                3          2       2  2          2        3
+--R                          648A C  + (- 216B  - 360A )C  + (360A B  - 1128A )C
+--R                        + 
+--R                              4       2 2      4
+--R                          120B  + 576A B  + 72A
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (1392C - 3024A)D  + (4752B C + 4464A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1104C  + 6624A C  + (- 3312B  + 2544A )C
+--R                            + 
+--R                                      2       3
+--R                              - 336A B  + 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3        2             3
+--R                          - 384B C  - 3024A B C  + (144B  + 2592A B)C - 1008A B
+--R                        + 
+--R                              3
+--R                          240A B
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          384D  + 1600B D
+--R                        + 
+--R                                  2                  2        2  2
+--R                          (- 2784C  + 7040A C - 1280B  + 3936A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 3776B C  - 8448A B C + 832B  - 1728A B)D + 480C
+--R                        + 
+--R                                   3         2        2  2           2       3
+--R                          - 2304A C  + (2592B  - 1152A )C  + (1152A B  + 768A )C
+--R                        + 
+--R                              4        2 2       4
+--R                          384B  - 1440A B  - 864A
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                           3                         2
+--R                          (- 1664C + 384A)D  + (- 3456B C - 4224A B)D
+--R                        + 
+--R                                   3          2         2        2            2
+--R                              1792C  - 5376A C  + (2688B  - 5632A )C + 3200A B
+--R                            + 
+--R                                     3
+--R                              - 1536A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2           3        2
+--R                          512B C  + 6144A B C  + (- 2176B  - 2304A B)C
+--R                        + 
+--R                                 3       3
+--R                          1152A B  + 768A B
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                2                2       2  2
+--R                          (2304C  - 512A C + 512B  - 768A )D
+--R                        + 
+--R                                  2                    3        2          4
+--R                          (2048B C  + 6144A B C - 1024B  + 3072A B)D - 256C
+--R                        + 
+--R                                 3           2        2  2
+--R                          1536A C  + (- 2304B  + 1536A )C
+--R                        + 
+--R                                    2       3         4       2 2       4
+--R                          (- 1536A B  + 512A )C - 512B  + 768A B  + 768A
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                                  3        2           2              2
+--R                          (- 1024C  + 1024A C - 2048A B )D - 3072A B C
+--R                        + 
+--R                               3         3
+--R                          2048B C - 1024A B
+--R                     *
+--R                         11
+--R                        a
+--R                 *
+--R                    %%BN1
+--R                + 
+--R                             3 3 8
+--R                      - 16A D a c
+--R                    + 
+--R                              3 2 2        3          2  3
+--R                          4A D a b  + (8B D  + 24A C D )a b
+--R                        + 
+--R                                       3          2           2      3    4
+--R                          ((16C - 64A)D  + 80A B D  + (- 16A C  - 16A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                 3         2  2 3
+--R                          (- 2B D  - 6A C D )a b
+--R                        + 
+--R                                             3                     2
+--R                              (- 12C + 188A)D  + (- 12B C - 52A B)D
+--R                            + 
+--R                                     2      3
+--R                              (- 4A C  + 12A )D
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 24D  + 16B D
+--R                            + 
+--R                                    2              2       2  2
+--R                              (- 24C  + 16A C - 40B  - 120A )D
+--R                            + 
+--R                                   2                2          3     3
+--R                              (8B C  - 48A B C + 24A B)D + 8A C  - 8A C
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                          3                      2
+--R                              (64C + 32A)D  + (- 96B C + 320A B)D
+--R                            + 
+--R                                  3        2       2          2      3
+--R                              (16C  - 64A C  + 112A C - 128A B  - 64A )D
+--R                            + 
+--R                                     2      3
+--R                              48A B C  + 16A B
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                      3                 2        2     3    2 4
+--R                          ((2C - 41A)D  + (3B C + 8A B)D  + (2A C  - 2A )D)a b
+--R                        + 
+--R                                 4        3       2               2      2  2
+--R                              14D  - 80B D  + (18C  - 224A C + 26B  + 66A )D
+--R                            + 
+--R                                   2                2          3     3
+--R                              (2B C  + 36A B C - 18A B)D - 2A C  + 2A C
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                              3                     2
+--R                              (- 144C + 232A)D  + (120B C - 808A B)D
+--R                            + 
+--R                                      3         2       2      2           2
+--R                                  - 4C  + 212A C  + (24B  - 20A )C + 112A B
+--R                                + 
+--R                                      3
+--R                                  196A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3          2      2        3
+--R                              - 4B C  - 36A B C  + 12A B C - 4A B
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 64D  + 96B D
+--R                            + 
+--R                                    2              2       2  2
+--R                              (- 24C  - 80A C - 64B  - 408A )D
+--R                            + 
+--R                                    2                3       2        4        3
+--R                              (80B C  - 96A B C + 64B  + 336A B)D - 8C  - 32A C
+--R                            + 
+--R                                    2      2  2           2      3        2 2
+--R                              (- 24B  - 48A )C  + (- 48A B  - 32A )C - 24A B
+--R                            + 
+--R                                  4
+--R                              - 8A
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    3                       2
+--R                              384A D  + (- 384B C - 128A B)D
+--R                            + 
+--R                                  3         2        2       2           2
+--R                              (64C  - 128A C  + (192B  + 448A )C - 512A B )D
+--R                            + 
+--R                                     3           2       2           3      3
+--R                              - 64B C  + 192A B C  - 192A B C + 64A B  + 64A B
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                  4        3        2             2     2  2
+--R                              - 2D  + 18B D  + (- 3C  + 52A C - 4B  - 9A )D
+--R                            + 
+--R                                    2              2
+--R                              (- B C  - 6A B C + 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                           3                    2
+--R                              (86C - 686A)D  + (54B C + 420A B)D
+--R                            + 
+--R                                      3       2         2      2          2
+--R                                  - 4C  + 9A C  + (- 18B  - 14A )C - 32A B
+--R                                + 
+--R                                        3
+--R                                  - 115A
+--R                             *
+--R                                D
+--R                            + 
+--R                                 3         2     2
+--R                              B C  + 6A B C  - 3A B C
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                  4        3
+--R                              224D  - 92B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (162C  + 280A C + 320B  + 1206A )D
+--R                            + 
+--R                                       2                 3       2        4
+--R                              (- 172B C  + 336A B C - 60B  - 492A B)D + 6C
+--R                            + 
+--R                                     3       2      2  2         2      3
+--R                              - 48A C  + (18B  + 24A )C  + (24A B  + 80A )C
+--R                            + 
+--R                                2 2     4
+--R                              6A B  + 2A
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                               3                     2
+--R                              (- 232C - 1128A)D  + (936B C - 584A B)D
+--R                            + 
+--R                                        3         2          2        2
+--R                                  - 208C  + 400A C  + (- 312B  - 1376A )C
+--R                                + 
+--R                                         2      3
+--R                                  1192A B  - 64A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2       3       2           3
+--R                              96B C  - 384A B C  + (24B  + 240A B)C - 24A B
+--R                            + 
+--R                                    3
+--R                              - 144A B
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                 4         3        2               2       2  2
+--R                              64D  + 256B D  + (144C  + 608A C - 32B  + 336A )D
+--R                            + 
+--R                                    2      3       2         4        3
+--R                              (64B C  + 64B  + 768A B)D + 48C  - 96A C
+--R                            + 
+--R                                  2      2  2           2       3        4
+--R                              (48B  + 96A )C  + (- 96A B  + 224A )C - 32B
+--R                            + 
+--R                                    2 2      4
+--R                              - 144A B  - 16A
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                              3            2
+--R                              (- 256C + 256A)D  - 1792A B D
+--R                            + 
+--R                                     3         2        2      2           2
+--R                                  64C  - 256A C  + (768B  - 64A )C + 128A B
+--R                                + 
+--R                                      3
+--R                                  256A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3       2
+--R                              - 256B C  + 192A B C  + (- 128B  - 768A B)C
+--R                            + 
+--R                                    3      3
+--R                              256A B  + 64A B
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                             3                     2
+--R                              (- 13C + 139A)D  + (- 18B C - 58A B)D
+--R                            + 
+--R                                3        2      2     2         2      3
+--R                              (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 109D  + 265B D
+--R                            + 
+--R                                     2                2       2  2
+--R                              (- 114C  + 591A C - 183B  - 543A )D
+--R                            + 
+--R                                    2                 3       2       4        3
+--R                              (27B C  - 228A B C + 19B  + 225A B)D - C  + 13A C
+--R                            + 
+--R                                   2     2  2          2      3
+--R                              (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                            3                        2
+--R                              (258C + 874A)D  + (- 978B C + 1542A B)D
+--R                            + 
+--R                                     3         2       2       2           2
+--R                                  94C  - 990A C  + (54B  + 426A )C - 714A B
+--R                                + 
+--R                                        3
+--R                                  - 346A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3           2         3       2          3
+--R                              - 10B C  + 234A B C  + (- 14B  - 174A B)C + 2A B
+--R                            + 
+--R                                 3
+--R                              30A B
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                      3          2               2       2  2
+--R                              - 768B D  + (- 192C  - 736A C - 80B  + 384A )D
+--R                            + 
+--R                                       2                 3        2            3
+--R                              (- 272B C  + 96A B C - 384B  - 1968A B)D + 368A C
+--R                            + 
+--R                                  2       2  2          2       3        4
+--R                              (48B  + 192A )C  + (288A B  - 112A )C + 16B
+--R                            + 
+--R                                  2 2      4
+--R                              240A B  + 64A
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (384C - 1536A)D  + (576B C + 4032A B)D
+--R                            + 
+--R                                        3         2           2        2
+--R                                  - 416C  + 672A C  + (- 2112B  - 1312A )C
+--R                                + 
+--R                                        2       3
+--R                                  512A B  - 992A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3        2            3
+--R                              480B C  - 672A B C  + (128B  + 1632A B)C - 512A B
+--R                            + 
+--R                                    3
+--R                              - 160A B
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              256D  - 384B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 192C  + 1024A C - 256B  + 2112A )D
+--R                            + 
+--R                                       2                  3        2          4
+--R                              (- 640B C  - 768A B C - 256B  - 1152A B)D + 192C
+--R                            + 
+--R                                   2       2  2          2       3         2 2
+--R                              (576B  + 384A )C  + (384A B  + 512A )C - 192A B
+--R                            + 
+--R                                   4
+--R                              - 64A
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                              3                       2
+--R                              (- 256C - 512A)D  + (1536B C - 1280A B)D
+--R                            + 
+--R                                     2        2           2       3         3
+--R                              (256A C  - 2048A C + 2560A B  + 256A )D - 512B C
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                 4        3       2               2      2  2
+--R                              14D  - 54B D  + (18C  - 140A C + 26B  + 66A )D
+--R                            + 
+--R                                   2               3      2
+--R                              (2B C  + 36A B C - 2B  - 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                              3                    2
+--R                              (- 142C + 688A)D  + (54B C - 800A B)D
+--R                            + 
+--R                                      3         2       2      2           2
+--R                                    6C  + 100A C  + (54B  + 22A )C + 160A B
+--R                                  + 
+--R                                        3
+--R                                    248A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3          2      3      2
+--R                              - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 416D  + 190B D
+--R                            + 
+--R                                    2                 2        2  2
+--R                              (- 84C  - 1254A C - 438B  - 2514A )D
+--R                            + 
+--R                                     2                  3        2         4
+--R                              (666B C  - 264A B C + 298B  + 1758A B)D - 20C
+--R                            + 
+--R                                   3         2       2  2            2       3
+--R                              22A C  + (- 66B  - 102A )C  + (- 114A B  - 158A )C
+--R                            + 
+--R                                  4      2 2      4
+--R                              - 2B  - 48A B  - 14A
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (284C + 2876A)D  + (- 588B C - 3516A B)D
+--R                            + 
+--R                                      3        2         2        2            2
+--R                                  788C  + 84A C  + (2292B  + 4428A )C - 1404A B
+--R                                + 
+--R                                       3
+--R                                  2252A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3        2
+--R                              - 532B C  + 492A B C  + (- 148B  - 1164A B)C
+--R                            + 
+--R                                    3       3
+--R                              140A B  + 308A B
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 608D  + 640B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (240C  - 3552A C + 960B  - 5232A )D
+--R                            + 
+--R                                      2                   3        2          4
+--R                              (1632B C  + 1536A B C + 928B  + 1632A B)D - 464C
+--R                            + 
+--R                                      3          2        2  2
+--R                              - 128A C  + (- 912B  - 1344A )C
+--R                            + 
+--R                                       2        3         4       2 2      4
+--R                              (- 384A B  - 1664A )C + 160B  + 528A B  + 16A
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                              3                         2
+--R                              (1280C + 1664A)D  + (- 1920B C + 3456A B)D
+--R                            + 
+--R                                      3         2          2        2
+--R                                  128C  + 576A C  + (- 192B  + 6144A )C
+--R                                + 
+--R                                           2       3
+--R                                  - 4800A B  + 704A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2        3       2
+--R                              - 256B C  - 768A B C  + (704B  + 384A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 448A B  + 128A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              128D  - 1280B D
+--R                            + 
+--R                                     2                 2       2  2
+--R                              (- 768C  - 2560A C + 640B  + 768A )D
+--R                            + 
+--R                                       2                   2          4
+--R                              (- 896B C  - 768A B C - 4224A B)D - 128C
+--R                            + 
+--R                                      3        2       2  2          2       3
+--R                              - 128A C  + (384B  - 768A )C  + (768A B  - 896A )C
+--R                            + 
+--R                                  4       2 2       4
+--R                              256B  + 384A B  - 128A
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                      3                       2
+--R                              - 512A D  + (1536B C + 2048A B)D
+--R                            + 
+--R                                        3          2           2        2
+--R                                  - 256C  + 2048A C  + (- 3072B  - 1792A )C
+--R                                + 
+--R                                         2
+--R                                  2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2        2             3       3
+--R                            1024B C  - 768A B C  + 3072A B C - 1024A B  - 256A B
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                           3                    2
+--R                              (20C - 156A)D  + (24B C + 104A B)D
+--R                            + 
+--R                                 3        2         2      2          2      3
+--R                            (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              204D  - 316B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (144C  - 364A C + 292B  + 1092A )D
+--R                            + 
+--R                                       2                 3       2        4
+--R                              (- 164B C  + 288A B C - 84B  - 636A B)D + 4C
+--R                            + 
+--R                                     3       2      2  2         2      3
+--R                              - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                              3                       2
+--R                              (- 36C - 3084A)D  + (1368B C + 1312A B)D
+--R                            + 
+--R                                        3          2          2        2
+--R                                  - 428C  + 1348A C  + (- 996B  - 1780A )C
+--R                                + 
+--R                                        2       3
+--R                                  644A B  - 996A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2       3       2          3
+--R                              128B C  - 312A B C  + (64B  + 528A B)C - 8A B
+--R                            + 
+--R                                   3
+--R                              - 56A B
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              924D  + 588B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 216C  + 5556A C + 60B  + 6156A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 2172B C  - 1584A B C - 444B  - 1332A B)D
+--R                            + 
+--R                                  4         3        2       2  2
+--R                              252C  - 708A C  + (540B  + 396A )C
+--R                            + 
+--R                                      2        3        4       2 2       4
+--R                              (- 36A B  + 1236A )C - 72B  - 576A B  - 120A
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                                3                        2
+--R                              (- 2184C - 2040A)D  + (- 648B C - 2616A B)D
+--R                            + 
+--R                                        3          2          2        2
+--R                                  - 408C  - 2760A C  + (- 504B  - 9096A )C
+--R                                + 
+--R                                         2        3
+--R                                  3720A B  - 2904A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3            2          3       2
+--R                              840B C  + 1656A B C  + (- 168B  - 360A B)C
+--R                            + 
+--R                                    3       3
+--R                              792A B  - 408A B
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 480D  + 1536B D
+--R                            + 
+--R                                   2                  2        2  2
+--R                              (864C  + 4992A C - 2400B  - 1440A )D
+--R                            + 
+--R                                      2                  3        2          4
+--R                              (1056B C  + 576A B C - 768B  + 6624A B)D + 384C
+--R                            + 
+--R                                    3          2        2  2
+--R                              864A C  + (- 576B  + 2304A )C
+--R                            + 
+--R                                        2        3         4       2 2       4
+--R                              (- 1152A B  + 2208A )C - 576B  - 576A B  + 384A
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                             3                         2
+--R                              (256C + 2688A)D  + (- 2688B C - 4736A B)D
+--R                            + 
+--R                                       3          2         2        2
+--R                                  1216C  - 4544A C  + (6528B  + 4032A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 2304A B  + 1344A
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3            2        2             3
+--R                              - 1344B C  + 1728A B C  - 5184A B C + 1536A B
+--R                            + 
+--R                                  3
+--R                              192A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                      3         2                  2        2  2
+--R                              - 512B D  + (1152C  - 4352A C + 2048B  - 1920A )D
+--R                            + 
+--R                                      2                   2          4         3
+--R                              (1280B C  + 4608A B C - 768A B)D - 640C  + 512A C
+--R                            + 
+--R                                      2       2  2            2        3
+--R                              (- 1920B  - 768A )C  + (- 768A B  - 1536A )C
+--R                            + 
+--R                                   2 2       4
+--R                              1152A B  + 384A
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2
+--R                              2048A B D
+--R                            + 
+--R                                         3          2           2        2
+--R                                  - 1024C  + 2048A C  + (- 3072B  + 1024A )C
+--R                                + 
+--R                                           2
+--R                                  - 2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3            2         3        2
+--R                              1024B C  - 3072A B C  + (2048B  + 3072A B)C
+--R                            + 
+--R                                       3        3
+--R                              - 1024A B  - 1024A B
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                               4        3         2               2       2  2
+--R                          - 24D  + 56B D  + (- 24C  + 112A C - 40B  - 120A )D
+--R                        + 
+--R                               2               3      2
+--R                          (8B C  - 48A B C + 8B  + 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                      3                      2
+--R                          (8C + 336A)D  + (- 216B C - 96A B)D
+--R                        + 
+--R                              3         2        2       2          2      3
+--R                          (56C  - 240A C  + (120B  + 184A )C - 80A B  + 96A )D
+--R                        + 
+--R                                3          2        3      2
+--R                          - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 216D  + 192B D
+--R                        + 
+--R                                2               2        2  2
+--R                          (- 72C  - 40A C - 176B  - 1248A )D
+--R                        + 
+--R                                 2                3       2         4         3
+--R                          (304B C  + 48A B C + 64B  + 384A B)D - 32C  + 120A C
+--R                        + 
+--R                                2      2  2         2       3       4      2 2
+--R                          (- 72B  - 24A )C  + (24A B  - 152A )C + 8B  + 96A B
+--R                        + 
+--R                             4
+--R                          24A
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                         3                        2
+--R                          (264C + 2304A)D  + (- 1080B C - 144A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              280C  - 1008A C  + (504B  + 1880A )C - 736A B
+--R                            + 
+--R                                  3
+--R                              864A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3          2        3       2            3
+--R                          - 120B C  - 96A B C  + (- 8B  - 216A B)C - 144A B
+--R                        + 
+--R                             3
+--R                          16A B
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 144D  - 1848B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (576C  - 6600A C + 984B  - 1800A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (1416B C  + 2304A B C + 120B  - 1800A B)D - 192C
+--R                        + 
+--R                                3          2       2  2          2        3
+--R                          648A C  + (- 216B  - 360A )C  + (360A B  - 1128A )C
+--R                        + 
+--R                              4       2 2      4
+--R                          120B  + 576A B  + 72A
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (1392C - 3024A)D  + (4752B C + 4464A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1104C  + 6624A C  + (- 3312B  + 2544A )C
+--R                            + 
+--R                                      2       3
+--R                              - 336A B  + 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3        2             3
+--R                          - 384B C  - 3024A B C  + (144B  + 2592A B)C - 1008A B
+--R                        + 
+--R                              3
+--R                          240A B
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          384D  + 1600B D
+--R                        + 
+--R                                  2                  2        2  2
+--R                          (- 2784C  + 7040A C - 1280B  + 3936A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 3776B C  - 8448A B C + 832B  - 1728A B)D + 480C
+--R                        + 
+--R                                   3         2        2  2           2       3
+--R                          - 2304A C  + (2592B  - 1152A )C  + (1152A B  + 768A )C
+--R                        + 
+--R                              4        2 2       4
+--R                          384B  - 1440A B  - 864A
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                           3                         2
+--R                          (- 1664C + 384A)D  + (- 3456B C - 4224A B)D
+--R                        + 
+--R                                   3          2         2        2            2
+--R                              1792C  - 5376A C  + (2688B  - 5632A )C + 3200A B
+--R                            + 
+--R                                     3
+--R                              - 1536A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2           3        2
+--R                          512B C  + 6144A B C  + (- 2176B  - 2304A B)C
+--R                        + 
+--R                                 3       3
+--R                          1152A B  + 768A B
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                2                2       2  2
+--R                          (2304C  - 512A C + 512B  - 768A )D
+--R                        + 
+--R                                  2                    3        2          4
+--R                          (2048B C  + 6144A B C - 1024B  + 3072A B)D - 256C
+--R                        + 
+--R                                 3           2        2  2
+--R                          1536A C  + (- 2304B  + 1536A )C
+--R                        + 
+--R                                    2       3         4       2 2       4
+--R                          (- 1536A B  + 512A )C - 512B  + 768A B  + 768A
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                                  3        2           2              2
+--R                          (- 1024C  + 1024A C - 2048A B )D - 3072A B C
+--R                        + 
+--R                               3         3
+--R                          2048B C - 1024A B
+--R                     *
+--R                         11
+--R                        a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                      4 2 8
+--R                  8A D a c
+--R                + 
+--R                            4   2          4          3  2
+--R                      - 2A D a b  + (- 4B D  - 16A C D )a b
+--R                    + 
+--R                                    4          3         2     3  2  3
+--R                      ((- 8C + 32A)D  - 48A B D  + (16A C  + 8A )D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                          4         3    3
+--R                      (B D  + 4A C D )a b
+--R                    + 
+--R                                  4                  3        2      3  2  2 2
+--R                      ((6C - 88A)D  + (8B C + 36A B)D  + (4A C  - 10A )D )a b
+--R                    + 
+--R                             5       4       2              2      2  3
+--R                          12D  - 4B D  + (16C  - 32A C + 24B  + 68A )D
+--R                        + 
+--R                                 2                2   2           3      3
+--R                          (- 8B C  + 24A B C - 12A B)D  + (- 16A C  + 16A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                       4                    3
+--R                          (- 32C - 8A)D  + (48B C - 192A B)D
+--R                        + 
+--R                                3        2      2          2      3  2
+--R                          (- 16C  + 64A C  - 64A C + 104A B  + 32A )D
+--R                        + 
+--R                                    2      3          4     3 2
+--R                          (- 48A B C  - 16A B)D + 8A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                     4                   3          2     3  2
+--R                        ((- C + 19A)D  + (- 2B C - 6A B)D  + (- 2A C  + 2A )D )a
+--R                     *
+--R                         4
+--R                        b
+--R                    + 
+--R                              5        4         2               2      2  3
+--R                          - 7D  + 35B D  + (- 12C  + 144A C - 18B  - 41A )D
+--R                        + 
+--R                                 2                2   2        3     3
+--R                          (- 2B C  - 30A B C + 15A B)D  + (4A C  - 4A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                       4                      3
+--R                          (56C - 114A)D  + (- 68B C + 496A B)D
+--R                        + 
+--R                             3         2         2     2          2       3  2
+--R                          (4C  - 152A C  + (- 12B  + 8A )C - 94A B  - 116A )D
+--R                        + 
+--R                               3          2      2        3          4     3 2
+--R                          (8B C  + 60A B C  - 24A B C + 4A B)D - 2A C  + 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                             5        4       2              2       2  3
+--R                          28D  - 44B D  + (56C  + 32A C + 20B  + 232A )D
+--R                        + 
+--R                                  2                3       2   2
+--R                          (- 32B C  + 48A B C - 52B  - 240A B)D
+--R                        + 
+--R                                 4        3       2      2  2         2      3
+--R                              16C  - 32A C  + (24B  + 60A )C  + (48A B  + 72A )C
+--R                            + 
+--R                                 2 2     4
+--R                              24A B  - 4A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      2   2
+--R                          - 4B C  - 24A B C  + 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                  4                    3
+--R                          - 160A D  + (192B C + 32A B)D
+--R                        + 
+--R                                     3        2         2       2           2
+--R                                - 64C  + 56A C  + (- 96B  - 256A )C + 416A B
+--R                              + 
+--R                                  3
+--R                                8A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                3           2       2           3      3
+--R                          (48B C  - 192A B C  + 144A B C - 96A B  - 64A B)D
+--R                        + 
+--R                              5        4      2 3         2      3  2      4
+--R                          - 8C  + 32A C  - 16A C  + (24A B  - 32A )C  + 24A C
+--R                        + 
+--R                            3 2
+--R                          8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           5       4      2             2     2  3
+--R                          D  - 8B D  + (2C  - 32A C + 3B  + 6A )D
+--R                        + 
+--R                              2              2   2
+--R                          (B C  + 6A B C - 3A B)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                         4                      3
+--R                          (- 33C + 297A)D  + (- 30B C - 286A B)D
+--R                        + 
+--R                             3        2       2      2          2      3  2
+--R                          (4C  - 24A C  + (15B  + 14A )C + 29A B  + 98A )D
+--R                        + 
+--R                                 3          2     2
+--R                          (- 2B C  - 12A B C  + 6A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               5        4          2               2       2  3
+--R                          - 97D  + 29B D  + (- 114C  - 40A C - 173B  - 672A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (112B C  - 192A B C + 49B  + 342A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 12C  + 120A C  + (- 30B  - 39A )C
+--R                            + 
+--R                                      2       3       2 2    4
+--R                              (- 36A B  - 162A )C - 6A B  + A
+--R                         *
+--R                            D
+--R                        + 
+--R                             4         3     2   2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                       4                       3
+--R                          (68C + 432A)D  + (- 488B C + 400A B)D
+--R                        + 
+--R                                    3         2        2       2            2
+--R                                112C  - 262A C  + (180B  + 740A )C - 1000A B
+--R                              + 
+--R                                   3
+--R                                74A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2           3
+--R                              - 92B C  + 480A B C  + (- 24B  - 300A B)C + 56A B
+--R                            + 
+--R                                  3
+--R                              168A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3        2      3  2
+--R                          6C  - 64A C  + (12B  + 16A )C  + (6A B  + 80A )C
+--R                        + 
+--R                              4      3 2
+--R                          - 6A C - 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                               5         4         2               2       2  3
+--R                          - 40D  - 136B D  + (- 28C  - 136A C - 24B  - 140A )D
+--R                        + 
+--R                                  2                3       2   2
+--R                          (- 52B C  - 24A B C - 40B  - 612A B)D
+--R                        + 
+--R                                 4        3         2      2  2
+--R                              44C  + 32A C  + (- 36B  + 48A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (168A B  - 176A )C + 48B  + 252A B  - 44A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3         3      2   2
+--R                          20B C  - 80A B C  + (- 12B  + 48A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                        4           3
+--R                          (128C - 128A)D  + 896A B D
+--R                        + 
+--R                                     3        2          2      2          2
+--R                                - 16C  - 32A C  + (- 384B  + 16A )C - 32A B
+--R                              + 
+--R                                     3
+--R                                - 96A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3          2       3       2            3
+--R                              192B C  - 96A B C  + (64B  + 576A B)C - 384A B
+--R                            + 
+--R                                   3
+--R                              - 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4         2      2  3        2 2
+--R                          - 32C  + 16A C  + (- 16B  - 64A )C  + 96A B C
+--R                        + 
+--R                                2 2      4          4      3 2      5
+--R                          (- 48A B  + 96A )C + 32A B  + 32A B  - 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                     4                   3
+--R                          (5C - 59A)D  + (10B C + 42A B)D
+--R                        + 
+--R                              3        2        2     2         2      3  2
+--R                          (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                             5         4       2                2       2  3
+--R                          47D  - 107B D  + (67C  - 352A C + 117B  + 325A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (- 15B C  + 198A B C - 17B  - 195A B)D
+--R                        + 
+--R                             4        3      2     2  2        2      3
+--R                          (2C  - 26A C  + (6B  + 6A )C  + (6A B  + 34A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         4                     3
+--R                          (- 29C - 315A)D  + (540B C - 958A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 30C  + 546A C  + (- 57B  - 213A )C + 621A B
+--R                            + 
+--R                                  3
+--R                              171A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     2       3       2          3      3       5
+--R                          (- 414A B C  + (22B  + 318A B)C - 8A B  - 36A B)D - C
+--R                        + 
+--R                               4        2     2  3          2      3  2
+--R                          13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5         4         2               2       2  3
+--R                          36D  + 428B D  + (- 45C  + 98A C + 196B  - 261A )D
+--R                        + 
+--R                                 2                3        2   2
+--R                          (149B C  + 6A B C + 316B  + 1605A B)D
+--R                        + 
+--R                                   4        3         2       2  2
+--R                              - 95C  - 56A C  + (- 51B  - 330A )C
+--R                            + 
+--R                                       2     3        4       2 2      4
+--R                              (- 354A B  - 8A )C - 32B  - 339A B  + 41A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4           3        3       2   2
+--R                          5B C  + 176A B C  + (- 5B  - 138A B)C
+--R                        + 
+--R                                3      3        2 3     4
+--R                          (10A B  + 16A B)C + 3A B  + 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                          4                        3
+--R                          (- 108C + 620A)D  + (- 160B C - 1984A B)D
+--R                        + 
+--R                                    3        2         2       2           2
+--R                                164C  - 36A C  + (1080B  + 796A )C - 584A B
+--R                              + 
+--R                                    3
+--R                                612A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 520B C  + 456A B C  + (- 128B  - 1464A B)C
+--R                            + 
+--R                                    3       3
+--R                              768A B  + 120A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4      2       2  3            2      3  2
+--R                          56C  - 80A C  + (4B  + 128A )C  + (- 132A B  + 64A )C
+--R                        + 
+--R                              4       2 2       4         4      3 2      5
+--R                          (20B  + 156A B  - 184A )C - 4A B  - 28A B  + 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 112D  + 208B D
+--R                        + 
+--R                                 2                2        2  3
+--R                          (- 176C  - 288A C + 192B  - 1072A )D
+--R                        + 
+--R                                 2                  3       2   2
+--R                          (112B C  + 288A B C + 256B  + 624A B)D
+--R                        + 
+--R                                   4        3          2       2  2
+--R                              - 64C  + 64A C  + (- 336B  - 288A )C
+--R                            + 
+--R                                      2       3        4       2 2      4
+--R                              (- 96A B  - 640A )C + 48B  + 432A B  + 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4       3      2   2            3      3
+--R                          96B C  + (16B  + 96A B)C  + (- 160A B  - 64A B)C
+--R                        + 
+--R                               5       2 3
+--R                          - 16B  - 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (128C + 128A)D  + (- 768B C + 768A B)D
+--R                        + 
+--R                               3         2        2           2       3  2
+--R                          (192C  - 256A C  + 1088A C - 1792A B  - 128A )D
+--R                        + 
+--R                                   2       3        3           4      2 3
+--R                          (384A B C  + 256B C + 128A B)D - 64A C  - 64B C
+--R                        + 
+--R                              3 2       2 2          4      5
+--R                          128A C  - 192A B C + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                              5        4         2              2      2  3
+--R                          - 6D  + 22B D  + (- 10C  + 76A C - 18B  - 42A )D
+--R                        + 
+--R                                 2               3      2   2
+--R                          (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                       4                      3
+--R                          (24C - 276A)D  + (- 52B C + 536A B)D
+--R                        + 
+--R                                     3       2         2      2           2
+--R                                - 16C  - 4A C  + (- 48B  - 40A )C - 148A B
+--R                              + 
+--R                                      3
+--R                                - 212A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                               3          2        3      2
+--R                          (4B C  + 72A B C  + (- 4B  - 60A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              5         4       2                2        2  3
+--R                          129D  - 160B D  + (56C  + 572A C + 130B  + 1334A )D
+--R                        + 
+--R                                   2                 3        2   2
+--R                          (- 426B C  + 96A B C - 248B  - 1344A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              55C  - 192A C  + (120B  + 180A )C
+--R                            + 
+--R                                     2       3       4      2 2     4
+--R                              (180A B  + 356A )C + 5B  + 66A B  - 7A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      3      2   2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                           4                     3
+--R                          (- 203C - 1051A)D  + (60B C + 1760A B)D
+--R                        + 
+--R                                    3         2           2        2
+--R                              - 216C  - 144A C  + (- 1356B  - 2418A )C
+--R                            + 
+--R                                     2        3
+--R                              1296A B  - 1594A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2        3        2            3
+--R                              624B C  - 612A B C  + (168B  + 1428A B)C - 300A B
+--R                            + 
+--R                                    3
+--R                              - 408A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5         4         2      2  3
+--R                          - 29C  + 119A C  + (- 54B  - 80A )C
+--R                        + 
+--R                                  2       3  2        4      2 2      4        4
+--R                          (- 30A B  - 188A )C  + (- 5B  - 36A B  + 37A )C - A B
+--R                        + 
+--R                            3 2     5
+--R                          4A B  - 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                              5         4        2                 2        2  3
+--R                          196D  - 508B D  + (226C  + 1068A C - 712B  + 2514A )D
+--R                        + 
+--R                                   2                  3       2   2
+--R                          (- 258B C  - 540A B C - 808B  - 930A B)D
+--R                        + 
+--R                                 4        3        2       2  2
+--R                              98C  - 64A C  + (894B  + 852A )C
+--R                            + 
+--R                                      2        3         4        2 2       4
+--R                              (- 12A B  + 1872A )C - 268B  - 1218A B  + 154A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4          3       3       2   2
+--R                          - 190B C  + 96A B C  + (34B  - 204A B)C
+--R                        + 
+--R                                 3       3        5      2 3      4
+--R                          (220A B  + 304A B)C + 4B  + 82A B  + 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                          4                       3
+--R                          (- 344C - 488A)D  + (1152B C - 1920A B)D
+--R                        + 
+--R                                    3         2         2        2            2
+--R                              - 104C  + 120A C  + (- 48B  - 3000A )C + 3408A B
+--R                            + 
+--R                                    3
+--R                              - 504A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2          3      2            3
+--R                              112B C  - 528A B C  + (- 384B  - 48A B)C + 512A B
+--R                            + 
+--R                                    3
+--R                              - 560A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2      2  3
+--R                          16C  + 80A C  + (- 8B  + 32A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 168A B  - 320A )C  + (40B  + 552A B  - 176A )C
+--R                        + 
+--R                                  4     3 2       5
+--R                          - 168A B  + 8A B  + 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                               5         4                  2       2  3
+--R                          - 32D  + 608B D  + (1024A C - 256B  - 576A )D
+--R                        + 
+--R                                 2                   2   2
+--R                          (512B C  + 384A B C + 2880A B)D
+--R                        + 
+--R                                    4         3            2       3         4
+--R                              - 224C  + 128A C  + (- 768A B  + 512A )C - 288B
+--R                            + 
+--R                                    2 2       4
+--R                              - 768A B  + 352A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3 2       3         5
+--R                          - 32B C  + 256A B C  + 128B C  + 384A B C - 32B
+--R                        + 
+--R                                2 3       4
+--R                          - 128A B  + 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                4                       3
+--R                          128A D  + (- 768B C - 512A B)D
+--R                        + 
+--R                                  3         2         2        2            2
+--R                              256C  - 896A C  + (1536B  + 1024A )C - 1664A B
+--R                            + 
+--R                                    3
+--R                              - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2        2             3
+--R                              - 768B C  + 768A B C  - 2304A B C + 1536A B
+--R                            + 
+--R                                  3
+--R                              256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4       2 3            2       3  2
+--R                          128C  - 128A C  + 256A C  + (- 384A B  + 128A )C
+--R                        + 
+--R                                4        3 2
+--R                          - 384A C - 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                       4                    3
+--R                          (- 4C + 60A)D  + (- 8B C - 72A B)D
+--R                        + 
+--R                             3        2       2      2          2      3  2
+--R                          (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                     *
+--R                           8
+--R                        a b
+--R                    + 
+--R                               5         4         2                2       2  3
+--R                          - 68D  + 148B D  + (- 52C  + 176A C - 156B  - 620A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (116B C  - 264A B C + 76B  + 564A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 8C  + 40A C  + (- 24B  - 24A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 24A B  - 72A )C
+--R                         *
+--R                            D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (24C + 1088A)D  + (- 504B C - 672A B)D
+--R                        + 
+--R                                  3         2        2        2           2
+--R                              132C  - 628A C  + (744B  + 1048A )C - 608A B
+--R                            + 
+--R                                  3
+--R                              912A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2          3       2
+--R                              - 176B C  + 600A B C  + (- 104B  - 936A B)C
+--R                            + 
+--R                                   3      3
+--R                              32A B  + 80A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3         2      3  2
+--R                          4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                                5        4        2                2        2  3
+--R                          - 288D  - 44B D  + (112C  - 1816A C + 60B  - 2928A )D
+--R                        + 
+--R                                 2                  3       2   2
+--R                          (792B C  + 672A B C + 348B  + 528A B)D
+--R                        + 
+--R                                   4         3          2       2  2
+--R                              - 64C  + 408A C  + (- 732B  - 240A )C
+--R                            + 
+--R                                     2        3         4        2 2      4
+--R                              (144A B  - 1576A )C + 148B  + 1044A B  - 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          68B C  - 272A B C  + (28B  + 384A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (656C + 664A)D  + (128B C + 1416A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 136C  + 792A C  + (636B  + 4356A )C - 2652A B
+--R                            + 
+--R                                   3
+--R                              1892A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3          2        3       2            3
+--R                              - 480B C  - 72A B C  + (152B  - 120A B)C - 848A B
+--R                            + 
+--R                                   3
+--R                              1008A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3
+--R                          - 8C  - 64A C  + (188B  - 28A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (252A B  + 412A )C  + (- 100B  - 768A B  + 308A )C
+--R                        + 
+--R                               4      3 2      5
+--R                          12A B  - 64A B  - 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          176D  - 592B D
+--R                        + 
+--R                                 2                  2        2  3
+--R                          (- 156C  - 1896A C + 1328B  + 1172A )D
+--R                        + 
+--R                                    2                  3        2   2
+--R                          (- 1188B C  - 216A B C + 560B  - 4596A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              252C  - 416A C  + (- 420B  - 792A )C
+--R                            + 
+--R                                      2        3         4        2 2       4
+--R                              (1128A B  - 1632A )C + 656B  + 1500A B  - 740A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3      2   2
+--R                          108B C  - 256A B C  + (- 252B  - 24A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (120A B  - 768A B)C + 80B  + 356A B  - 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                          4                      3
+--R                          (- 208C - 912A)D  + (960B C + 1280A B)D
+--R                        + 
+--R                                    3          2           2        2
+--R                              - 400C  + 1616A C  + (- 3360B  - 2352A )C
+--R                            + 
+--R                                     2       3
+--R                              2304A B  - 912A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3            2        3        2
+--R                              1568B C  - 1632A B C  + (256B  + 5088A B)C
+--R                            + 
+--R                                       3       3
+--R                              - 2304A B  - 160A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2       2  3
+--R                          - 160C  + 160A C  + (48B  - 384A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (336A B  - 160A )C  + (- 80B  - 432A B  + 544A )C
+--R                        + 
+--R                                  4      3 2
+--R                          - 112A B  + 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                4          2                  2       2  3
+--R                          128B D  + (- 192C  + 1664A C - 1088B  + 576A )D
+--R                        + 
+--R                                2                   3        2   2
+--R                          (64B C  - 1920A B C - 192B  + 1344A B)D
+--R                        + 
+--R                                    3        2       2  2
+--R                              256A C  + (960B  + 192A )C
+--R                            + 
+--R                                       2        3         4        2 2      4
+--R                              (- 384A B  + 1408A )C - 192B  - 2112A B  - 64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3         3       2   2
+--R                          - 320B C  + 384A B C  + (- 64B  - 576A B)C
+--R                        + 
+--R                                 3       3         5       2 3
+--R                          (640A B  + 256A B)C + 64B  + 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                    3
+--R                          - 512A B D
+--R                        + 
+--R                                  3         2         2       2           2
+--R                              256C  - 896A C  + (1536B  - 256A )C + 512A B
+--R                            + 
+--R                                    3
+--R                              - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2           3        2
+--R                              - 768B C  + 1536A B C  + (- 1024B  - 2304A B)C
+--R                            + 
+--R                                     3       3
+--R                              1536A B  + 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4        2       2  3         2 2
+--R                          128C  - 256A C  + (256B  + 256A )C  - 384A B C
+--R                        + 
+--R                               2 2       4           4       3 2       5
+--R                          (768A B  - 384A )C - 512A B  - 128A B  + 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                        5        4      2              2      2  3
+--R                      8D  - 24B D  + (8C  - 48A C + 24B  + 72A )D
+--R                    + 
+--R                             2               3      2   2
+--R                      (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                 *
+--R                       9
+--R                    a b
+--R                + 
+--R                              4                   3
+--R                      - 112A D  + (80B C + 32A B)D
+--R                    + 
+--R                            3        2         2       2          2      3  2
+--R                      (- 16C  + 96A C  + (- 96B  - 112A )C + 80A B  - 96A )D
+--R                    + 
+--R                            3          2       3       2
+--R                      (16B C  - 96A B C  + (16B  + 144A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                         5         4      2               2       2  3
+--R                      68D  - 104B D  + (8C  - 64A C + 112B  + 656A )D
+--R                    + 
+--R                               2                 3       2   2
+--R                      (- 112B C  + 144A B C - 56B  - 312A B)D
+--R                    + 
+--R                            4        3      2 2           2       3        4
+--R                          4C  - 32A C  + 96B C  + (- 48A B  + 176A )C - 20B
+--R                        + 
+--R                                2 2      4
+--R                          - 168A B  + 12A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4          3        3      2   2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     4                    3
+--R                      (- 52C - 772A)D  + (416B C + 32A B)D
+--R                    + 
+--R                                 3         2          2        2           2
+--R                            - 48C  + 480A C  + (- 528B  - 1016A )C + 592A B
+--R                          + 
+--R                                  3
+--R                            - 776A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                            3           2       3       2            3      3
+--R                      (80B C  - 432A B C  + (48B  + 672A B)C + 176A B  - 96A B)D
+--R                    + 
+--R                        5        4         2      2  3           2      3  2
+--R                      4C  - 12A C  + (- 24B  + 16A )C  + (- 24A B  - 32A )C
+--R                    + 
+--R                          4       2 2      4         4      3 2      5
+--R                      (20B  + 144A B  - 52A )C + 4A B  + 16A B  + 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                         5         4          2                 2       2  3
+--R                      20D  + 640B D  + (- 328C  + 2272A C - 568B  + 464A )D
+--R                    + 
+--R                               2                  3        2   2
+--R                      (- 240B C  - 1392A B C - 16B  + 2040A B)D
+--R                    + 
+--R                            4         3        2      2  2
+--R                          4C  - 224A C  + (600B  + 96A )C
+--R                        + 
+--R                                   2        3         4        2 2       4
+--R                          (- 384A B  + 1264A )C - 188B  - 1056A B  + 172A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3         3       2   2
+--R                      - 32B C  + 304A B C  + (- 16B  - 408A B)C
+--R                    + 
+--R                              3      3         5      2 3      4
+--R                      (- 80A B  + 64A B)C - 16B  - 88A B  + 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      4                         3
+--R                      (- 364C + 980A)D  + (- 1648B C - 1600A B)D
+--R                    + 
+--R                           3          2         2       2           2      3  2
+--R                      (544C  - 2112A C  + (1776B  - 696A )C - 480A B  + 40A )D
+--R                    + 
+--R                                  3            2          3        2
+--R                          - 352B C  + 2256A B C  + (- 448B  - 3504A B)C
+--R                        + 
+--R                                 3       3
+--R                          1232A B  - 736A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4          2       2  3
+--R                      28C  - 52A C  + (- 200B  + 112A )C
+--R                    + 
+--R                               2       3  2        4       2 2       4
+--R                      (- 168A B  - 224A )C  + (140B  + 912A B  - 364A )C
+--R                    + 
+--R                           4       3 2      5
+--R                      92A B  + 112A B  + 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                           5         4        2                 2        2  3
+--R                      - 96D  - 512B D  + (888C  - 2288A C + 560B  - 1384A )D
+--R                    + 
+--R                              2                   3       2   2
+--R                      (1064B C  + 3888A B C - 560B  - 696A B)D
+--R                    + 
+--R                                4         3           2       2  2
+--R                          - 200C  + 256A C  + (- 1272B  + 672A )C
+--R                        + 
+--R                                2        3         4        2 2       4
+--R                          (48A B  - 1184A )C - 176B  + 2184A B  + 520A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3        2   2
+--R                      232B C  - 608A B C  + (344B  + 1248A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 560A B  + 448A B)C - 112B  - 616A B  + 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                   4                       3
+--R                      (416C - 96A)D  + (1152B C + 1536A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 736C  + 1536A C  + (- 1152B  + 2080A )C - 704A B
+--R                        + 
+--R                              3
+--R                          832A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2         3        2             3
+--R                          256B C  - 3264A B C  + (1408B  + 2688A B)C - 1408A B
+--R                        + 
+--R                              3
+--R                          320A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4         2       2  3
+--R                      - 32C  + 320A C  + (- 32B  - 128A )C
+--R                    + 
+--R                             2       3  2          4        2 2       4
+--R                      (192A B  + 256A )C  + (- 160B  - 1824A B  + 416A )C
+--R                    + 
+--R                            4       3 2       5
+--R                      416A B  - 128A B  - 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                             2                2       2  3
+--R                      (- 576C  + 128A C - 128B  + 192A )D
+--R                    + 
+--R                               2                   3       2   2
+--R                      (- 704B C  - 2688A B C + 640B  - 960A B)D
+--R                    + 
+--R                              4        2       2  2          2       3         4
+--R                          192C  + (576B  - 768A )C  + (384A B  - 256A )C + 384B
+--R                        + 
+--R                                2 2       4
+--R                          - 960A B  - 704A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3       2   2
+--R                      - 192B C  + 256A B C  + (- 320B  - 768A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (640A B  - 512A B)C + 128B  + 704A B  - 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                           3       2          2  2
+--R                      (256C  - 256A C + 512A B )D
+--R                    + 
+--R                                2        3        3            4       2 3
+--R                      (1536A B C  - 1024B C + 512A B)D - 256A C  + 256B C
+--R                    + 
+--R                          2 2          4       5
+--R                      768A B C - 512A B  + 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                ROOT
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN1
+--R                     + 
+--R                                   3 3      2 2      4  2       3 2      5
+--R                               - 8a c  + (2a b  - 16a )c  + (40a b  + 32a )c
+--R                             + 
+--R                                   2 4      4 2      6
+--R                               - 8a b  - 56a b  + 64a
+--R                          *
+--R                             %%BN0
+--R                         + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN1
+--R                     + 
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN0
+--R                     + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN0
+--R                     + 
+--R                           2 2                          2     2  2  2
+--R                       (- D b  + 4C D a b + (- 8B D - 4C  - 4A )a )c
+--R                     + 
+--R                               2   2                               2
+--R                           - 4D a b  + ((20C + 4A)D + 4B C + 4A B)a b
+--R                         + 
+--R                              2             2             2     2  3
+--R                           (8D  - 16B D - 8C  + 16A C + 8B  - 8A )a
+--R                      *
+--R                         c
+--R                     + 
+--R                         2 4            3
+--R                       4D b  - 16C D a b
+--R                     + 
+--R                            2              2            2      2  2 2
+--R                       (- 8D  + 24B D + 12C  - 8A C - 4B  + 12A )a b
+--R                     + 
+--R                                                       3
+--R                       ((- 8C - 24A)D - 24B C - 24A B)a b
+--R                     + 
+--R                           2              2  4
+--R                       (16D  + 32A C + 16B )a
+--R                  /
+--R                         3 3       2 2     4  2         3 2      5       2 4
+--R                       4a c  + (- a b  + 8a )c  + (- 20a b  - 16a )c + 4a b
+--R                     + 
+--R                          4 2      6
+--R                       28a b  - 32a
+--R            + 
+--R                             2 4 8
+--R                      - 32A D a c
+--R                    + 
+--R                               2 3 2       3        2  4
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   2                   2      3  5
+--R                          (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                2 2 4        3       2  3 3
+--R                          - 2A D a b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          2                  2      3  4 2
+--R                          ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                        + 
+--R                                 3        2       2               2       2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                     2                2
+--R                              - 16B C  - 96A B C + 48A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    2                 3         2      2
+--R                              128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                            + 
+--R                                      2       3
+--R                              - 128A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3      2  2 5
+--R                          (D  + B D )a b
+--R                        + 
+--R                                        2                2     3  3 4
+--R                          ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                        + 
+--R                                    3         2
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 24C  + 112A C + 32B  + 72A )D + 8B C  + 48A B C
+--R                            + 
+--R                                   2
+--R                              - 24A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                           3
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2           2      3
+--R                              (384C  - 512A C - 64B  - 384A )D + 128B C  + 64B
+--R                            + 
+--R                                  2
+--R                              384A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                     2                  3         2       2
+--R                              1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                            + 
+--R                                      2       3
+--R                              - 512A B  + 128A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       2 2 6
+--R                          (- 2C + 22A)D a b
+--R                        + 
+--R                                 3        2      2             2     2        2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D - B C
+--R                            + 
+--R                                           2
+--R                              - 6A B C + 3A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                             2                            3
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                            + 
+--R                                    2         2      2          2       3
+--R                              120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                            + 
+--R                                            3       2
+--R                              672A B C - 64B  - 720A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                               3
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D + 608C
+--R                            + 
+--R                                      2          2       2            2      3
+--R                              - 416A C  + (- 288B  - 992A )C + 1120A B  + 32A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2           2
+--R                              (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                            + 
+--R                                              3       2
+--R                              1152A B C + 128B  + 192A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                    2                   3          2       2
+--R                              512A D  - 4096A B D + 256C  - 1024A C  - 256A C
+--R                            + 
+--R                                    2        3
+--R                              512A B  + 1024A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               3       2  2 7
+--R                          (- 8D  - 8B D )a b
+--R                        + 
+--R                                              2                      3        2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D + C  - 13A C
+--R                            + 
+--R                                 2     2         2      3
+--R                              (3B  + 3A )C + 3A B  + 17A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  3        2        2                2       2
+--R                              284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              - 12B C  - 312A B C + 20B  + 276A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                            2                               3
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D - 320C
+--R                            + 
+--R                                    2         2       2           2       3
+--R                              720A C  + (- 96B  + 192A )C - 672A B  - 848A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2            2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D - 1088B C
+--R                            + 
+--R                                                3        2
+--R                              - 1920A B C - 384B  - 1344A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                             2                               3
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D + 128C
+--R                            + 
+--R                                     2          2       2           2        3
+--R                              1920A C  + (- 384B  - 640A )C + 128A B  - 2432A
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2            2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D - 1024B C
+--R                            + 
+--R                                    3        2
+--R                              - 512B  - 3072A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2                    3         2
+--R                              - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                            + 
+--R                                     2           2       3
+--R                              - 2048A C + 4096A B  + 512A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      2 2 8
+--R                          (16C - 80A)D a b
+--R                        + 
+--R                                    3         2
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 30C  + 100A C + 26B  + 66A )D + 2B C  + 36A B C
+--R                            + 
+--R                                  3      2
+--R                              - 2B  - 30A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                               2                            3
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D + 62C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 230A C  + (90B  + 58A )C + 154A B  + 350A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2           2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                            + 
+--R                                               3        2
+--R                              - 576A B C + 312B  + 2160A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                     2                              3         2
+--R                              8160A D  + (4608B C - 5376A B)D - 864C  - 192A C
+--R                            + 
+--R                                    2        2           2        3
+--R                              (2304B  + 3936A )C - 960A B  + 3264A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2            2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D + 1152B C
+--R                            + 
+--R                                                3        2
+--R                              - 2304A B C + 768B  + 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D - 3840C
+--R                            + 
+--R                                     2         2        2            2
+--R                              3072A C  + (2304B  + 6912A )C - 6912A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2            2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D - 2816B C
+--R                            + 
+--R                                                 3        2
+--R                              - 4608A B C - 1024B  - 3840A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2                    3          2
+--R                              - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                            + 
+--R                                     2           2        3
+--R                              - 1024A C + 2048A B  - 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3        2  2 9
+--R                          (16D  + 16B D )a b
+--R                        + 
+--R                                            2                           3
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                            + 
+--R                                   2         2      2          2      3
+--R                              20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                         *
+--R                             3 8
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2           2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D - 104B C
+--R                            + 
+--R                                            3       2
+--R                              432A B C - 88B  - 744A B
+--R                         *
+--R                             4 7
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D + 364C
+--R                            + 
+--R                                      2          2        2           2       3
+--R                              - 380A C  + (- 828B  - 1468A )C + 452A B  - 724A
+--R                         *
+--R                             5 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2           2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D - 336B C
+--R                            + 
+--R                                              3        2
+--R                              4320A B C - 528B  - 5328A B
+--R                         *
+--R                             6 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                             7 4
+--R                            a b
+--R                        + 
+--R                                     3         2
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2            2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D + 4224B C
+--R                            + 
+--R                                               3        2
+--R                              6912A B C + 1536B  + 5760A B
+--R                         *
+--R                             8 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                             9 2
+--R                            a b
+--R                        + 
+--R                                       2         2                  2        2
+--R                              - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                     2        3        2
+--R                              2048B C  + 1024B  + 6144A B
+--R                         *
+--R                             10
+--R                            a  b
+--R                        + 
+--R                                               3          2        2           2
+--R                              8192A B D - 4096C  + 2048A C  + 4096A C - 8192A B
+--R                            + 
+--R                                     3
+--R                              - 2048A
+--R                         *
+--R                             11
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    2 2 10
+--R                      (- 32C + 96A)D a b
+--R                    + 
+--R                               3        2       2               2       2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                              2               3      2
+--R                          8B C  - 48A B C + 8B  + 72A B
+--R                     *
+--R                         3 9
+--R                        a b
+--R                    + 
+--R                                           2                           3
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                        + 
+--R                               2       2       2          2      3
+--R                          72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                     *
+--R                         4 8
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                        + 
+--R                                          3       2
+--R                          - 816A B C + 88B  + 936A B
+--R                     *
+--R                         5 7
+--R                        a b
+--R                    + 
+--R                                        2                              3
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                        + 
+--R                                 2         2        2           2       3
+--R                          1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                     *
+--R                         6 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2           2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                        + 
+--R                                           3        2
+--R                          - 3744A B C - 96B  + 1296A B
+--R                     *
+--R                         7 5
+--R                        a b
+--R                    + 
+--R                                          2                              3
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                        + 
+--R                                 2         2        2           2        3
+--R                          3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                     *
+--R                         8 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2            2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D - 4352B C
+--R                        + 
+--R                                             3         2
+--R                          - 1536A B C - 2048B  - 11520A B
+--R                     *
+--R                         9 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D + 5632C
+--R                        + 
+--R                                 2           2         2            2        3
+--R                        - 4608A C  + (- 4608B  - 11776A )C + 9728A B  - 1536A
+--R                     *
+--R                         10 2
+--R                        a  b
+--R                    + 
+--R                                2                  2        2            2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                        + 
+--R                                           3        2
+--R                          6144A B C + 2048B  + 9216A B
+--R                     *
+--R                         11
+--R                        a  b
+--R                    + 
+--R                              3        2           2  12
+--R                      (- 4096C  + 4096A C - 8192A B )a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                       3 3 8
+--R                  16A D a c
+--R                + 
+--R                            3 2 2          3          2  3
+--R                      - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                    + 
+--R                                     3          2         2      3    4
+--R                      ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           3         2  2 3
+--R                      (2B D  + 6A C D )a b
+--R                    + 
+--R                                    3                   2        2      3    3 2
+--R                      ((12C - 188A)D  + (12B C + 52A B)D  + (4A C  - 12A )D)a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 64C - 32A)D  + (96B C - 320A B)D
+--R                        + 
+--R                                3        2       2          2      3
+--R                          (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                        + 
+--R                                   2      3
+--R                          - 48A B C  - 16A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                      3                   2          2     3
+--R                        ((- 2C + 41A)D  + (- 3B C - 8A B)D  + (- 2A C  + 2A )D)
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 80B D  + (- 18C  + 224A C - 26B  - 66A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                        3                       2
+--R                          (144C - 232A)D  + (- 120B C + 808A B)D
+--R                        + 
+--R                             3         2         2      2           2       3
+--R                          (4C  - 212A C  + (- 24B  + 20A )C - 112A B  - 196A )D
+--R                        + 
+--R                              3          2      2        3
+--R                          4B C  + 36A B C  - 12A B C + 4A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                        + 
+--R                                  2                3       2        4        3
+--R                          (- 80B C  + 96A B C - 64B  - 336A B)D + 8C  + 32A C
+--R                        + 
+--R                              2      2  2         2      3        2 2     4
+--R                          (24B  + 48A )C  + (48A B  + 32A )C + 24A B  + 8A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                  3                     2
+--R                          - 384A D  + (384B C + 128A B)D
+--R                        + 
+--R                                3         2          2       2           2
+--R                          (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                        + 
+--R                               3           2       2           3      3
+--R                          64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4        3      2             2     2  2
+--R                          2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                        + 
+--R                              2              2
+--R                          (B C  + 6A B C - 3A B)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                        + 
+--R                             3       2       2      2          2       3
+--R                          (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                        + 
+--R                               3         2     2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                4        3
+--R                          - 224D  + 92B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 162C  - 280A C - 320B  - 1206A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (172B C  - 336A B C + 60B  + 492A B)D - 6C  + 48A C
+--R                        + 
+--R                                2      2  2           2      3       2 2     4
+--R                          (- 18B  - 24A )C  + (- 24A B  - 80A )C - 6A B  - 2A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                            + 
+--R                                 3
+--R                              64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2         3       2           3
+--R                          - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                        + 
+--R                              3
+--R                          144A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               4         3          2               2       2  2
+--R                          - 64D  - 256B D  + (- 144C  - 608A C + 32B  - 336A )D
+--R                        + 
+--R                                  2      3       2         4        3
+--R                          (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                        + 
+--R                                2      2  2         2       3        4       2 2
+--R                          (- 48B  - 96A )C  + (96A B  - 224A )C + 32B  + 144A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                        3            2
+--R                          (256C - 256A)D  + 1792A B D
+--R                        + 
+--R                                   3         2          2      2           2
+--R                              - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                            + 
+--R                                    3
+--R                              - 256A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3       2            3
+--R                          256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       3                   2
+--R                          (13C - 139A)D  + (18B C + 58A B)D
+--R                        + 
+--R                              3        2        2     2         2      3
+--R                          (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              4         3        2                2       2  2
+--R                          109D  - 265B D  + (114C  - 591A C + 183B  + 543A )D
+--R                        + 
+--R                                  2                 3       2       4        3
+--R                          (- 27B C  + 228A B C - 19B  - 225A B)D + C  - 13A C
+--R                        + 
+--R                             2     2  2        2      3
+--R                          (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                            + 
+--R                                  3
+--R                              346A
+--R                         *
+--R                            D
+--R                        + 
+--R                               3           2       3       2          3      3
+--R                          10B C  - 234A B C  + (14B  + 174A B)C - 2A B  - 30A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                3        2               2       2  2
+--R                          768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                        + 
+--R                                 2                 3        2            3
+--R                          (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                        + 
+--R                                2       2  2            2       3        4
+--R                          (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                        + 
+--R                                2 2      4
+--R                          - 240A B  - 64A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                           3                        2
+--R                          (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                        + 
+--R                                  3         2         2        2           2
+--R                              416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                            + 
+--R                                  3
+--R                              992A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 480B C  + 672A B C  + (- 128B  - 1632A B)C + 512A B
+--R                        + 
+--R                              3
+--R                          160A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 256D  + 384B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (192C  - 1024A C + 256B  - 2112A )D
+--R                        + 
+--R                                 2                  3        2          4
+--R                          (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                        + 
+--R                                 2       2  2            2       3         2 2
+--R                          (- 576B  - 384A )C  + (- 384A B  - 512A )C + 192A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                        + 
+--R                                   2        2           2       3         3
+--R                          (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 54B D  + (- 18C  + 140A C - 26B  - 66A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                        3                      2
+--R                          (142C - 688A)D  + (- 54B C + 800A B)D
+--R                        + 
+--R                                    3         2         2      2           2
+--R                                - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                              + 
+--R                                      3
+--R                                - 248A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2        3      2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              4         3       2                 2        2  2
+--R                          416D  - 190B D  + (84C  + 1254A C + 438B  + 2514A )D
+--R                        + 
+--R                                   2                  3        2         4
+--R                          (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                        + 
+--R                                 3       2       2  2          2       3       4
+--R                          - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C + 2B
+--R                        + 
+--R                             2 2      4
+--R                          48A B  + 14A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                        + 
+--R                                    3        2           2        2            2
+--R                              - 788C  - 84A C  + (- 2292B  - 4428A )C + 1404A B
+--R                            + 
+--R                                     3
+--R                              - 2252A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                        + 
+--R                                3
+--R                          - 308A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          608D  - 640B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 240C  + 3552A C - 960B  + 5232A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1632B C  - 1536A B C - 928B  - 1632A B)D + 464C
+--R                        + 
+--R                                3        2        2  2          2        3
+--R                          128A C  + (912B  + 1344A )C  + (384A B  + 1664A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 160B  - 528A B  - 16A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            3                       2
+--R                          (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 128C  - 576A C  + (192B  - 6144A )C + 4800A B
+--R                            + 
+--R                                    3
+--R                              - 704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2          3       2            3
+--R                          256B C  + 768A B C  + (- 704B  - 384A B)C + 448A B
+--R                        + 
+--R                                3
+--R                          - 128A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 128D  + 1280B D
+--R                        + 
+--R                               2                 2       2  2
+--R                          (768C  + 2560A C - 640B  - 768A )D
+--R                        + 
+--R                                 2                   2          4         3
+--R                          (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                        + 
+--R                                 2       2  2            2       3         4
+--R                          (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                        + 
+--R                                2 2       4
+--R                          - 384A B  + 128A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                3                         2
+--R                          512A D  + (- 1536B C - 2048A B)D
+--R                        + 
+--R                               3          2         2        2            2
+--R                          (256C  - 2048A C  + (3072B  + 1792A )C - 2048A B )D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                        - 1024B C  + 768A B C  - 3072A B C + 1024A B  + 256A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                         3                      2
+--R                          (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                        + 
+--R                             3        2       2      2          2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 204D  + 316B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 144C  + 364A C - 292B  - 1092A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (164B C  - 288A B C + 84B  + 636A B)D - 4C  + 20A C
+--R                        + 
+--R                                2      2  2           2      3
+--R                          (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                            + 
+--R                                  3
+--R                              996A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2         3       2          3
+--R                          - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                        + 
+--R                             3
+--R                          56A B
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 924D  - 588B D
+--R                        + 
+--R                               2                2        2  2
+--R                          (216C  - 5556A C - 60B  - 6156A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                        + 
+--R                                3          2       2  2         2        3
+--R                          708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                        + 
+--R                             4       2 2       4
+--R                          72B  + 576A B  + 120A
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                        + 
+--R                                  3          2        2        2            2
+--R                              408C  + 2760A C  + (504B  + 9096A )C - 3720A B
+--R                            + 
+--R                                   3
+--R                              2904A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3       2            3
+--R                          - 840B C  - 1656A B C  + (168B  + 360A B)C - 792A B
+--R                        + 
+--R                              3
+--R                          408A B
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          480D  - 1536B D
+--R                        + 
+--R                                 2                  2        2  2
+--R                          (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                        + 
+--R                                    2                  3        2          4
+--R                          (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                        + 
+--R                                  3        2        2  2           2        3
+--R                          - 864A C  + (576B  - 2304A )C  + (1152A B  - 2208A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          576B  + 576A B  - 384A
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                           3                       2
+--R                          (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                            + 
+--R                                     2        3
+--R                              2304A B  - 1344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                          1344B C  - 1728A B C  + 5184A B C - 1536A B  - 192A B
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                3           2                  2        2  2
+--R                          512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                        + 
+--R                                    2                   2          4         3
+--R                          (- 1280B C  - 4608A B C + 768A B)D + 640C  - 512A C
+--R                        + 
+--R                                2       2  2          2        3          2 2
+--R                          (1920B  + 768A )C  + (768A B  + 1536A )C - 1152A B
+--R                        + 
+--R                                4
+--R                          - 384A
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                     2
+--R                          - 2048A B D
+--R                        + 
+--R                                3          2         2        2            2
+--R                          (1024C  - 2048A C  + (3072B  - 1024A )C + 2048A B )D
+--R                        + 
+--R                                   3            2           3        2
+--R                          - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                        + 
+--R                                 3        3
+--R                          1024A B  + 1024A B
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                         4        3       2               2       2  2
+--R                      24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                    + 
+--R                             2               3      2
+--R                      (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                    3                    2
+--R                      (- 8C - 336A)D  + (216B C + 96A B)D
+--R                    + 
+--R                            3         2          2       2          2      3
+--R                      (- 56C  + 240A C  + (- 120B  - 184A )C + 80A B  - 96A )D
+--R                    + 
+--R                          3          2      3      2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                          4         3       2               2        2  2
+--R                      216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                    + 
+--R                               2                3       2         4         3
+--R                      (- 304B C  - 48A B C - 64B  - 384A B)D + 32C  - 120A C
+--R                    + 
+--R                        2      2  2           2       3       4      2 2      4
+--R                    (72B  + 24A )C  + (- 24A B  + 152A )C - 8B  - 96A B  - 24A
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                       3                      2
+--R                      (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                        + 
+--R                                3
+--R                          - 864A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3          2      3       2            3      3
+--R                      120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                          4          3          2                 2        2  2
+--R                      144D  + 1848B D  + (- 576C  + 6600A C - 984B  + 1800A )D
+--R                    + 
+--R                                2                   3        2          4
+--R                      (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                    + 
+--R                              3        2       2  2            2        3
+--R                      - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                    + 
+--R                            4       2 2      4
+--R                      - 120B  - 576A B  - 72A
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                    + 
+--R                                 3          2         2        2           2
+--R                            1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                          + 
+--R                                  3
+--R                            - 576A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3            2          3        2             3
+--R                      384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                    + 
+--R                            3
+--R                      - 240A B
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                            4          3
+--R                      - 384D  - 1600B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (2784C  - 7040A C + 1280B  - 3936A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                    + 
+--R                             3           2        2  2             2       3
+--R                      2304A C  + (- 2592B  + 1152A )C  + (- 1152A B  - 768A )C
+--R                    + 
+--R                            4        2 2       4
+--R                      - 384B  + 1440A B  + 864A
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                     3                       2
+--R                      (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                    + 
+--R                                 3          2           2        2            2
+--R                          - 1792C  + 5376A C  + (- 2688B  + 5632A )C - 3200A B
+--R                        + 
+--R                               3
+--R                          1536A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2         3        2             3
+--R                      - 512B C  - 6144A B C  + (2176B  + 2304A B)C - 1152A B
+--R                    + 
+--R                            3
+--R                      - 768A B
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                              2                2       2  2
+--R                      (- 2304C  + 512A C - 512B  + 768A )D
+--R                    + 
+--R                                2                    3        2          4
+--R                      (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                    + 
+--R                          4       2 2       4
+--R                      512B  - 768A B  - 768A
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                            3        2           2              2        3
+--R                      (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                    + 
+--R                           3
+--R                      1024A B
+--R                 *
+--R                     11
+--R                    a
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                             2 4 8
+--R                      - 32A D a c
+--R                    + 
+--R                               2 3 2       3        2  4
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   2                   2      3  5
+--R                          (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                2 2 4        3       2  3 3
+--R                          - 2A D a b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          2                  2      3  4 2
+--R                          ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                        + 
+--R                                 3        2       2               2       2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                     2                2
+--R                              - 16B C  - 96A B C + 48A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    2                 3         2      2
+--R                              128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                            + 
+--R                                      2       3
+--R                              - 128A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3      2  2 5
+--R                          (D  + B D )a b
+--R                        + 
+--R                                        2                2     3  3 4
+--R                          ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                        + 
+--R                                    3         2
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 24C  + 112A C + 32B  + 72A )D + 8B C  + 48A B C
+--R                            + 
+--R                                   2
+--R                              - 24A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                           3
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2           2      3
+--R                              (384C  - 512A C - 64B  - 384A )D + 128B C  + 64B
+--R                            + 
+--R                                  2
+--R                              384A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                     2                  3         2       2
+--R                              1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                            + 
+--R                                      2       3
+--R                              - 512A B  + 128A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       2 2 6
+--R                          (- 2C + 22A)D a b
+--R                        + 
+--R                                 3        2      2             2     2        2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D - B C
+--R                            + 
+--R                                           2
+--R                              - 6A B C + 3A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                             2                            3
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                            + 
+--R                                    2         2      2          2       3
+--R                              120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                            + 
+--R                                            3       2
+--R                              672A B C - 64B  - 720A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                               3
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D + 608C
+--R                            + 
+--R                                      2          2       2            2      3
+--R                              - 416A C  + (- 288B  - 992A )C + 1120A B  + 32A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2           2
+--R                              (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                            + 
+--R                                              3       2
+--R                              1152A B C + 128B  + 192A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                    2                   3          2       2
+--R                              512A D  - 4096A B D + 256C  - 1024A C  - 256A C
+--R                            + 
+--R                                    2        3
+--R                              512A B  + 1024A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               3       2  2 7
+--R                          (- 8D  - 8B D )a b
+--R                        + 
+--R                                              2                      3        2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D + C  - 13A C
+--R                            + 
+--R                                 2     2         2      3
+--R                              (3B  + 3A )C + 3A B  + 17A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  3        2        2                2       2
+--R                              284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              - 12B C  - 312A B C + 20B  + 276A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                            2                               3
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D - 320C
+--R                            + 
+--R                                    2         2       2           2       3
+--R                              720A C  + (- 96B  + 192A )C - 672A B  - 848A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2            2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D - 1088B C
+--R                            + 
+--R                                                3        2
+--R                              - 1920A B C - 384B  - 1344A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                             2                               3
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D + 128C
+--R                            + 
+--R                                     2          2       2           2        3
+--R                              1920A C  + (- 384B  - 640A )C + 128A B  - 2432A
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2            2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D - 1024B C
+--R                            + 
+--R                                    3        2
+--R                              - 512B  - 3072A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2                    3         2
+--R                              - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                            + 
+--R                                     2           2       3
+--R                              - 2048A C + 4096A B  + 512A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      2 2 8
+--R                          (16C - 80A)D a b
+--R                        + 
+--R                                    3         2
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 30C  + 100A C + 26B  + 66A )D + 2B C  + 36A B C
+--R                            + 
+--R                                  3      2
+--R                              - 2B  - 30A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                               2                            3
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D + 62C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 230A C  + (90B  + 58A )C + 154A B  + 350A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2           2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                            + 
+--R                                               3        2
+--R                              - 576A B C + 312B  + 2160A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                     2                              3         2
+--R                              8160A D  + (4608B C - 5376A B)D - 864C  - 192A C
+--R                            + 
+--R                                    2        2           2        3
+--R                              (2304B  + 3936A )C - 960A B  + 3264A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2            2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D + 1152B C
+--R                            + 
+--R                                                3        2
+--R                              - 2304A B C + 768B  + 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D - 3840C
+--R                            + 
+--R                                     2         2        2            2
+--R                              3072A C  + (2304B  + 6912A )C - 6912A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2            2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D - 2816B C
+--R                            + 
+--R                                                 3        2
+--R                              - 4608A B C - 1024B  - 3840A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2                    3          2
+--R                              - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                            + 
+--R                                     2           2        3
+--R                              - 1024A C + 2048A B  - 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3        2  2 9
+--R                          (16D  + 16B D )a b
+--R                        + 
+--R                                            2                           3
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                            + 
+--R                                   2         2      2          2      3
+--R                              20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                         *
+--R                             3 8
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2           2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D - 104B C
+--R                            + 
+--R                                            3       2
+--R                              432A B C - 88B  - 744A B
+--R                         *
+--R                             4 7
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D + 364C
+--R                            + 
+--R                                      2          2        2           2       3
+--R                              - 380A C  + (- 828B  - 1468A )C + 452A B  - 724A
+--R                         *
+--R                             5 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2           2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D - 336B C
+--R                            + 
+--R                                              3        2
+--R                              4320A B C - 528B  - 5328A B
+--R                         *
+--R                             6 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                             7 4
+--R                            a b
+--R                        + 
+--R                                     3         2
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2            2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D + 4224B C
+--R                            + 
+--R                                               3        2
+--R                              6912A B C + 1536B  + 5760A B
+--R                         *
+--R                             8 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                             9 2
+--R                            a b
+--R                        + 
+--R                                       2         2                  2        2
+--R                              - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                     2        3        2
+--R                              2048B C  + 1024B  + 6144A B
+--R                         *
+--R                             10
+--R                            a  b
+--R                        + 
+--R                                               3          2        2           2
+--R                              8192A B D - 4096C  + 2048A C  + 4096A C - 8192A B
+--R                            + 
+--R                                     3
+--R                              - 2048A
+--R                         *
+--R                             11
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    2 2 10
+--R                      (- 32C + 96A)D a b
+--R                    + 
+--R                               3        2       2               2       2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                              2               3      2
+--R                          8B C  - 48A B C + 8B  + 72A B
+--R                     *
+--R                         3 9
+--R                        a b
+--R                    + 
+--R                                           2                           3
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                        + 
+--R                               2       2       2          2      3
+--R                          72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                     *
+--R                         4 8
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                        + 
+--R                                          3       2
+--R                          - 816A B C + 88B  + 936A B
+--R                     *
+--R                         5 7
+--R                        a b
+--R                    + 
+--R                                        2                              3
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                        + 
+--R                                 2         2        2           2       3
+--R                          1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                     *
+--R                         6 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2           2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                        + 
+--R                                           3        2
+--R                          - 3744A B C - 96B  + 1296A B
+--R                     *
+--R                         7 5
+--R                        a b
+--R                    + 
+--R                                          2                              3
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                        + 
+--R                                 2         2        2           2        3
+--R                          3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                     *
+--R                         8 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2            2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D - 4352B C
+--R                        + 
+--R                                             3         2
+--R                          - 1536A B C - 2048B  - 11520A B
+--R                     *
+--R                         9 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D + 5632C
+--R                        + 
+--R                                 2           2         2            2        3
+--R                        - 4608A C  + (- 4608B  - 11776A )C + 9728A B  - 1536A
+--R                     *
+--R                         10 2
+--R                        a  b
+--R                    + 
+--R                                2                  2        2            2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                        + 
+--R                                           3        2
+--R                          6144A B C + 2048B  + 9216A B
+--R                     *
+--R                         11
+--R                        a  b
+--R                    + 
+--R                              3        2           2  12
+--R                      (- 4096C  + 4096A C - 8192A B )a
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                           3 3 8
+--R                      32A D a c
+--R                    + 
+--R                                 3 2 2         4        3  3
+--R                          - 16A D a b  + (- 16D  - 16B D )a b
+--R                        + 
+--R                                 3           2           2      3    4
+--R                          (128A D  - 128A B D  + (- 32A C  + 32A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              3   4      4       3  2 3
+--R                          2A D a b  + (8D  + 8B D )a b
+--R                        + 
+--R                                        3          2         2      3    3 2
+--R                          ((32C - 448A)D  + 64A B D  + (16A C  - 16A )D)a b
+--R                        + 
+--R                                   4        3
+--R                              - 32D  + 32B D
+--R                            + 
+--R                                    2               2       2  2
+--R                              (- 48C  + 224A C + 64B  + 144A )D
+--R                            + 
+--R                                    2                2
+--R                              (16B C  + 96A B C - 48A B)D
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                      3           2
+--R                              - 128A D  - 512A B D
+--R                            + 
+--R                                  3         2      2          2       3
+--R                              (64C  - 128A C  - 64A C + 128A B  + 128A )D
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              4      3    5
+--R                          (- D  - B D )a b
+--R                        + 
+--R                                          3         2          2     3    2 4
+--R                          ((- 16C + 192A)D  - 8A B D  + (- 2A C  + 2A )D)a b
+--R                        + 
+--R                                  4         3       2               2      2  2
+--R                              160D  + 128B D  + (24C  - 112A C - 32B  - 72A )D
+--R                            + 
+--R                                     2                2
+--R                              (- 8B C  - 48A B C + 24A B)D
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                           3                       2
+--R                              (80C - 560A)D  + (- 96B C + 1312A B)D
+--R                            + 
+--R                                       3         2         2      2           2
+--R                                  - 48C  + 304A C  + (- 48B  - 16A )C - 112A B
+--R                                + 
+--R                                        3
+--R                                  - 368A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              128D  + 256B D
+--R                            + 
+--R                                     2               2       2  2
+--R                              (- 384C  + 512A C + 64B  + 384A )D
+--R                            + 
+--R                                       2      3       2
+--R                              (- 128B C  - 64B  - 384A B)D
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                       3           2
+--R                              - 1024A D  + 512A B D
+--R                            + 
+--R                                   3         2       2          2       3
+--R                              (256C  + 128A C  - 256A C + 512A B  - 128A )D
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                     3   6
+--R                          (2C - 22A)D a b
+--R                        + 
+--R                                   4        3        2             2     2  2
+--R                              - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D
+--R                            + 
+--R                                  2              2
+--R                              (B C  + 6A B C - 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                               3                    2
+--R                              (- 328C + 1896A)D  + (48B C - 528A B)D
+--R                            + 
+--R                                3         2       2      2          2       3
+--R                            (12C  - 120A C  + (24B  + 20A )C + 32A B  + 152A )D
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 224D  - 800B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (720C  - 2080A C - 512B  - 1392A )D
+--R                            + 
+--R                                    2                 3       2
+--R                              (16B C  - 672A B C + 64B  + 720A B)D
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (160C + 2976A)D  + (576B C + 1088A B)D
+--R                            + 
+--R                                        3         2        2       2
+--R                                  - 608C  + 416A C  + (288B  + 992A )C
+--R                                + 
+--R                                           2      3
+--R                                  - 1120A B  - 32A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              256D  - 256B D
+--R                            + 
+--R                                     2                 2       2  2
+--R                              (- 192C  - 1664A C - 640B  - 960A )D
+--R                            + 
+--R                                       2                   3       2
+--R                              (- 448B C  - 1152A B C - 128B  - 192A B)D
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                      3            2
+--R                              - 512A D  + 4096A B D
+--R                            + 
+--R                                     3          2       2          2        3
+--R                              (- 256C  + 1024A C  + 256A C - 512A B  - 1024A )D
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             4       3    7
+--R                          (8D  + 8B D )a b
+--R                        + 
+--R                                            3                    2
+--R                              (141C - 755A)D  + (- 6B C + 58A B)D
+--R                            + 
+--R                                  3        2        2     2         2      3
+--R                              (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    4        3
+--R                              - 284D  - 36B D
+--R                            + 
+--R                                     2                2       2  2
+--R                              (- 276C  + 888A C + 228B  + 588A )D
+--R                            + 
+--R                                    2                 3       2
+--R                              (12B C  + 312A B C - 20B  - 276A B)D
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (- 32C - 2016A)D  + (192B C - 3072A B)D
+--R                            + 
+--R                                      3         2       2       2           2
+--R                                  320C  - 720A C  + (96B  - 192A )C + 672A B
+--R                                + 
+--R                                      3
+--R                                  848A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 896D  - 384B D
+--R                            + 
+--R                                    2                 2       2  2
+--R                              (1344C  + 1408A C + 896B  + 576A )D
+--R                            + 
+--R                                      2                   3        2
+--R                              (1088B C  + 1920A B C + 384B  + 1344A B)D
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 640C + 4224A)D  + (768B C - 8448A B)D
+--R                            + 
+--R                                        3          2        2       2
+--R                                  - 128C  - 1920A C  + (384B  + 640A )C
+--R                                + 
+--R                                          2        3
+--R                                  - 128A B  + 2432A
+--R                             *
+--R                                D
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 256D  - 1280B D
+--R                            + 
+--R                                    2                 2        2  2
+--R                              (3072C  - 4096A C - 512B  - 3072A )D
+--R                            + 
+--R                                      2       3        2
+--R                              (1024B C  + 512B  + 3072A B)D
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                     3            2
+--R                              2048A D  + 2048A B D
+--R                            + 
+--R                                    3         2        2           2       3
+--R                            (- 2048C  + 512A C  + 2048A C - 4096A B  - 512A )D
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                        3   8
+--R                          (- 16C + 80A)D a b
+--R                        + 
+--R                                  4         3       2               2      2  2
+--R                              146D  + 118B D  + (30C  - 100A C - 26B  - 66A )D
+--R                            + 
+--R                                     2               3      2
+--R                              (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (726C - 2090A)D  + (- 180B C + 1100A B)D
+--R                            + 
+--R                                       3         2         2      2           2
+--R                                  - 62C  + 230A C  + (- 90B  - 58A )C - 154A B
+--R                                + 
+--R                                        3
+--R                                  - 350A
+--R                             *
+--R                                D
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              1752D  + 2760B D
+--R                            + 
+--R                                      2                 2        2  2
+--R                              (- 2160C  + 3840A C + 696B  + 2736A )D
+--R                            + 
+--R                                       2                  3        2
+--R                              (- 528B C  + 576A B C - 312B  - 2160A B)D
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                       3                         2
+--R                              - 8160A D  + (- 4608B C + 5376A B)D
+--R                            + 
+--R                                      3         2           2        2
+--R                                  864C  + 192A C  + (- 2304B  - 3936A )C
+--R                                + 
+--R                                        2        3
+--R                                  960A B  - 3264A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              1152D  + 4224B D
+--R                            + 
+--R                                      2                   2        2  2
+--R                              (- 5760C  + 11520A C + 2304B  + 8064A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 1152B C  + 2304A B C - 768B  - 5760A B)D
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                3                         2
+--R                              (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D
+--R                            + 
+--R                                       3          2           2        2
+--R                                  3840C  - 3072A C  + (- 2304B  - 6912A )C
+--R                                + 
+--R                                         2
+--R                                  6912A B
+--R                             *
+--R                                D
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 512D  + 512B D
+--R                            + 
+--R                                    2                  2       2  2
+--R                              (3840C  + 2560A C + 2048B  + 768A )D
+--R                            + 
+--R                                      2                    3        2
+--R                              (2816B C  + 4608A B C + 1024B  + 3840A B)D
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                     3            2
+--R                              2048A D  - 8192A B D
+--R                            + 
+--R                                    3          2        2           2        3
+--R                            (- 1024C  - 2048A C  + 1024A C - 2048A B  + 2048A )D
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                4        3    9
+--R                          (- 16D  - 16B D )a b
+--R                        + 
+--R                                              3                    2
+--R                              (- 308C + 972A)D  + (24B C - 104A B)D
+--R                            + 
+--R                                 3        2       2      2          2      3
+--R                              (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 456D  - 920B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (744C  - 1712A C - 376B  - 1176A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              (104B C  - 432A B C + 88B  + 744A B)D
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                                3                      2
+--R                              (- 1668C + 8316A)D  + (1656B C - 136A B)D
+--R                            + 
+--R                                        3         2        2        2
+--R                                  - 364C  + 380A C  + (828B  + 1468A )C
+--R                                + 
+--R                                          2       3
+--R                                  - 452A B  + 724A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     4          3
+--R                              - 2496D  - 6432B D
+--R                            + 
+--R                                    2                   2        2  2
+--R                              (5328C  - 14304A C - 3408B  - 9648A )D
+--R                            + 
+--R                                     2                   3        2
+--R                              (336B C  - 4320A B C + 528B  + 5328A B)D
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              3                        2
+--R                              (6528C + 3456A)D  + (11520B C + 7296A B)D
+--R                            + 
+--R                                         3          2         2         2
+--R                                  - 3072C  + 4704A C  + (5760B  + 10752A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 4224A B  + 2976A
+--R                             *
+--R                                D
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                   4         3
+--R                              1024D  - 512B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 5760C  - 3840A C - 3072B  - 1152A )D
+--R                            + 
+--R                                        2                    3        2
+--R                              (- 4224B C  - 6912A B C - 1536B  - 5760A B)D
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              3                          2
+--R                              (1280C - 6912A)D  + (- 1536B C + 12800A B)D
+--R                            + 
+--R                                       3          2          2        2
+--R                                  1280C  + 2816A C  + (- 768B  - 2304A )C
+--R                                + 
+--R                                         2        3
+--R                                  2304A B  - 3840A
+--R                             *
+--R                                D
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                     3
+--R                              2048B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                            + 
+--R                                        2        3        2
+--R                              (- 2048B C  - 1024B  - 6144A B)D
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                         2
+--R                              - 8192A B D
+--R                            + 
+--R                                  3          2        2           2        3
+--R                            (4096C  - 2048A C  - 4096A C + 8192A B  + 2048A )D
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                  3   10
+--R                      (32C - 96A)D a b
+--R                    + 
+--R                             4        3         2               2       2  2
+--R                          24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (376C - 1416A)D  + (- 144B C - 144A B)D
+--R                        + 
+--R                              3        2         2       2          2      3
+--R                          (40C  - 72A C  + (- 72B  - 136A )C + 56A B  - 24A )D
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          360D  + 1080B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 936C  + 2608A C + 632B  + 1752A )D
+--R                        + 
+--R                                  2                 3       2
+--R                          (- 40B C  + 816A B C - 88B  - 936A B)D
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                          3                         2
+--R                          (- 24C - 4248A)D  + (- 2160B C - 2160A B)D
+--R                        + 
+--R                                  3          2           2        2           2
+--R                              536C  - 1080A C  + (- 1080B  - 1976A )C + 712A B
+--R                            + 
+--R                                    3
+--R                              - 360A
+--R                         *
+--R                            D
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                               4          3
+--R                          1152D  + 3456B D
+--R                        + 
+--R                                  2                  2        2  2
+--R                          (- 1296C  + 7968A C + 2400B  + 5040A )D
+--R                        + 
+--R                                 2                  3        2
+--R                          (816B C  + 3744A B C + 96B  - 1296A B)D
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D
+--R                        + 
+--R                                  3          2           2        2           2
+--R                              960C  - 3456A C  + (- 3456B  - 5568A )C + 768A B
+--R                            + 
+--R                                     3
+--R                              - 1152A
+--R                         *
+--R                            D
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1536D  - 4608B D
+--R                        + 
+--R                                 2                   2        2  2
+--R                          (11520C  - 12800A C - 1024B  - 9984A )D
+--R                        + 
+--R                                  2                    3         2
+--R                          (4352B C  + 1536A B C + 2048B  + 11520A B)D
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (6656C - 1536A)D  + (9216B C + 9216A B)D
+--R                        + 
+--R                                     3          2         2         2
+--R                              - 5632C  + 4608A C  + (4608B  + 11776A )C
+--R                            + 
+--R                                       2        3
+--R                              - 9728A B  + 1536A
+--R                         *
+--R                            D
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                  2        2  2
+--R                          (- 9216C  + 2048A C - 2048B  + 3072A )D
+--R                        + 
+--R                                    2                    3        2
+--R                          (- 5120B C  - 6144A B C - 2048B  - 9216A B)D
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                            3        2           2    11
+--R                      (4096C  - 4096A C + 8192A B )D a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                        4 2 8
+--R                  - 8A D a c
+--R                + 
+--R                          4   2        4         3  2
+--R                      2A D a b  + (4B D  + 8A C D )a b
+--R                    + 
+--R                                  4          3     3 2  3
+--R                      ((8C - 32A)D  + 32A B D  - 8A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            4         3    3
+--R                      (- B D  - 2A C D )a b
+--R                    + 
+--R                                     4                    3     3 2  2 2
+--R                      ((- 6C + 100A)D  + (- 4B C - 16A B)D  + 2A D )a b
+--R                    + 
+--R                               5        4        2              2      2  3
+--R                          - 12D  + 12B D  + (- 8C  - 16A C - 16B  - 52A )D
+--R                        + 
+--R                                          2   2          3     3
+--R                          (- 24A B C + 12A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      4                      3
+--R                          (32C + 24A)D  + (- 48B C + 128A B)D
+--R                        + 
+--R                              2         2      3  2       4     3 2
+--R                          (48A C - 24A B  - 32A )D  + 8A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 4                3    4
+--R                      ((C - 22A)D  + (B C + 2A B)D )a b
+--R                    + 
+--R                            5        4      2             2      2  3
+--R                          7D  - 45B D  + (6C  - 80A C + 8B  + 25A )D
+--R                        + 
+--R                                      2   2        3     3
+--R                          (6A B C - 3A B)D  + (2A C  - 2A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 88C + 118A)D  + (52B C - 312A B)D
+--R                        + 
+--R                                2       2      2          2      3  2
+--R                          (60A C  + (12B  - 12A )C + 18A B  + 80A )D
+--R                        + 
+--R                               3          2      2            4     3 2
+--R                          (4B C  + 24A B C  - 12A B C)D - 2A C  + 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5        4       2              2       2  3
+--R                          - 36D  + 52B D  + (32C  - 48A C - 44B  - 176A )D
+--R                        + 
+--R                                2                3      2   2
+--R                          (48B C  - 48A B C + 12B  + 96A B)D
+--R                        + 
+--R                             4        3      2 2      3       4         4
+--R                          (8C  - 64A C  + 12A C  + 40A C - 12A )D - 4B C
+--R                        + 
+--R                                   3      2   2
+--R                          - 24A B C  + 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4                      3
+--R                          224A D  + (- 192B C - 96A B)D
+--R                        + 
+--R                                  2       2       2          2     3  2
+--R                          (- 72A C  + (96B  + 192A )C - 96A B  + 8A )D
+--R                        + 
+--R                                  3      2           3       5        4      2 3
+--R                          (- 16B C  - 48A B C - 32A B )D - 8C  + 32A C  - 16A C
+--R                        + 
+--R                                2      3  2      4      3 2
+--R                          (24A B  - 32A )C  + 24A C + 8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          5        4       2            2     2  3    5
+--R                      (- D  + 10B D  + (- C  + 20A C - B  - 3A )D )a b
+--R                    + 
+--R                                       4                    3
+--R                          (53C - 389A)D  + (24B C + 134A B)D
+--R                        + 
+--R                                  2     2        2      3  2
+--R                          (- 15A C  - 3B C - 3A B  - 17A )D
+--R                        + 
+--R                                3         2     2
+--R                          (- B C  - 6A B C  + 3A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              5        4       2                2       2  3
+--R                          127D  - 63B D  + (48C  + 240A C + 147B  + 534A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (- 60B C  + 144A B C - 11B  - 150A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 6C  + 72A C  + (- 12B  - 15A )C
+--R                            + 
+--R                                      2      3       4
+--R                              (- 12A B  - 82A )C + 3A
+--R                         *
+--R                            D
+--R                        + 
+--R                             4         3     2   2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 164C - 696A)D  + (448B C - 184A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 96C  + 138A C  + (- 132B  - 636A )C + 192A B
+--R                            + 
+--R                                 3
+--R                              10A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                               3          2      2           3      3        5
+--R                          (4B C  + 96A B C  - 60A B C + 32A B  + 24A B)D + 6C
+--R                        + 
+--R                                 4       2      2  3        2      3  2     4
+--R                          - 64A C  + (12B  + 16A )C  + (6A B  + 80A )C  - 6A C
+--R                        + 
+--R                              3 2
+--R                          - 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             5         4        2               2       2  3
+--R                          24D  + 120B D  + (116C  + 472A C - 56B  + 196A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (12B C  - 24A B C + 24B  + 156A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              92C  - 64A C  + (12B  + 144A )C
+--R                            + 
+--R                                    2      3        4       2 2      4
+--R                              (72A B  + 48A )C + 16B  + 108A B  - 60A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3         3      2   2
+--R                          20B C  - 80A B C  + (- 12B  + 48A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          4           3
+--R                          (- 128C + 128A)D  - 896A B D
+--R                        + 
+--R                              3         2        2      2          2       3  2
+--R                          (48C  - 288A C  + (384B  - 48A )C + 96A B  + 160A )D
+--R                        + 
+--R                                     3          2         3       2            3
+--R                              - 64B C  + 96A B C  + (- 64B  - 192A B)C - 128A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4         2      2  3        2 2
+--R                          - 32C  + 16A C  + (- 16B  - 64A )C  + 96A B C
+--R                        + 
+--R                                2 2      4          4      3 2      5
+--R                          (- 48A B  + 96A )C + 32A B  + 32A B  - 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                    4                    3    6
+--R                      ((- 8C + 80A)D  + (- 8B C - 16A B)D )a b
+--R                    + 
+--R                               5         4         2               2       2  3
+--R                          - 62D  + 158B D  + (- 47C  + 239A C - 66B  - 218A )D
+--R                        + 
+--R                                2               3      2   2
+--R                          (12B C  - 30A B C + 2B  + 30A B)D
+--R                        + 
+--R                            4        3      2     2  2        2      3
+--R                          (C  - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (229C + 559A)D  + (- 438B C + 584A B)D
+--R                        + 
+--R                              3         2        2       2          2       3  2
+--R                          (64C  - 444A C  + (- 3B  + 213A )C - 93A B  - 175A )D
+--R                        + 
+--R                                     3           2      3       2          3
+--R                              - 10B C  - 180A B C  + (8B  + 144A B)C - 6A B
+--R                            + 
+--R                                  3
+--R                              - 6A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2     2  3          2      3  2
+--R                          - C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5         4          2                2       2  3
+--R                          36D  - 340B D  + (- 237C  - 638A C + 116B  + 123A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 123B C  + 102A B C - 68B  - 363A B)D
+--R                        + 
+--R                                   4         3        2       2  2
+--R                              - 95C  + 312A C  + (- 3B  - 138A )C
+--R                            + 
+--R                                      2       3        4      2 2       4
+--R                              (- 66A B  - 120A )C - 16B  - 99A B  + 105A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4           3        3       2   2
+--R                          5B C  + 176A B C  + (- 5B  - 138A B)C
+--R                        + 
+--R                                3      3        2 3     4
+--R                          (10A B  + 16A B)C + 3A B  + 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (276C - 916A)D  + (416B C + 2048A B)D
+--R                        + 
+--R                                    3         2           2       2          2
+--R                              - 252C  + 636A C  + (- 1032B  - 516A )C - 72A B
+--R                            + 
+--R                                    3
+--R                              - 380A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3           2       2            3      3
+--R                          (- 40B C  - 216A B C  + 168A B C + 256A B  - 40A B)D
+--R                        + 
+--R                             5        4      2       2  3            2      3  2
+--R                          56C  - 80A C  + (4B  + 128A )C  + (- 132A B  + 64A )C
+--R                        + 
+--R                              4       2 2       4         4      3 2      5
+--R                          (20B  + 156A B  - 184A )C - 4A B  - 28A B  + 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              5         4          2               2        2  3
+--R                          144D  - 176B D  + (- 368C  + 736A C - 64B  + 1040A )D
+--R                        + 
+--R                                   2                  2   2
+--R                          (- 528B C  - 480A B C - 528A B)D
+--R                        + 
+--R                                  4        3        2      2  2
+--R                              128C  + 64A C  + (240B  + 96A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (288A B  - 128A )C + 48B  + 240A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4       3      2   2            3      3
+--R                          96B C  + (16B  + 96A B)C  + (- 160A B  - 64A B)C
+--R                        + 
+--R                               5       2 3
+--R                          - 16B  - 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 128C - 384A)D  + (768B C - 512A B)D
+--R                        + 
+--R                               3       2          2       3  2
+--R                          (192C  - 960A C + 768A B  + 128A )D
+--R                        + 
+--R                                   2       3        3           4      2 3
+--R                          (384A B C  - 256B C + 128A B)D - 64A C  - 64B C
+--R                        + 
+--R                              3 2       2 2          4      5
+--R                          128A C  - 192A B C + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         5        4      2             2      2  3    7
+--R                      (8D  - 32B D  + (8C  - 64A C + 8B  + 24A )D )a b
+--R                    + 
+--R                                          4                   3
+--R                          (- 118C + 412A)D  + (2B C - 264A B)D
+--R                        + 
+--R                                3        2      2      2          2      3  2
+--R                          (- 10C  + 96A C  + (6B  - 18A )C + 12A B  + 36A )D
+--R                        + 
+--R                               3          2        3      2
+--R                          (2B C  + 36A B C  + (- 2B  - 30A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5        4
+--R                          - 287D  + 30B D
+--R                        + 
+--R                                2                2        2  3
+--R                          (- 28C  - 682A C - 308B  - 1180A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (240B C  - 168A B C + 50B  + 414A B)D
+--R                        + 
+--R                                 4         3       2      2  2
+--R                              35C  - 170A C  + (54B  + 78A )C
+--R                            + 
+--R                                    2       3       4      2 2      4
+--R                              (66A B  + 198A )C + 3B  + 18A B  - 21A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      3      2   2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (81C + 1825A)D  + (- 528B C - 1756A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                572C  - 60A C  + (936B  + 2010A )C - 108A B
+--R                              + 
+--R                                    3
+--R                                658A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2            3
+--R                              92B C  - 120A B C  + (20B  + 264A B)C - 160A B
+--R                            + 
+--R                                    3
+--R                              - 100A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5         4         2      2  3
+--R                          - 29C  + 119A C  + (- 54B  - 80A )C
+--R                        + 
+--R                                  2       3  2        4      2 2      4        4
+--R                          (- 30A B  - 188A )C  + (- 5B  - 36A B  + 37A )C - A B
+--R                        + 
+--R                            3 2     5
+--R                          4A B  - 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 412D  + 132B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (466C  - 2484A C + 248B  - 2718A )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (1374B C  + 996A B C + 120B  + 702A B)D
+--R                        + 
+--R                                    4         3         2       2  2
+--R                              - 366C  - 192A C  + (- 18B  - 492A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 396A B  + 208A )C - 108B  - 690A B  + 170A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4          3       3       2   2
+--R                          - 190B C  + 96A B C  + (34B  - 204A B)C
+--R                        + 
+--R                                 3       3        5      2 3      4
+--R                          (220A B  + 304A B)C + 4B  + 82A B  + 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         4                        3
+--R                          (936C + 1176A)D  + (- 768B C + 1536A B)D
+--R                        + 
+--R                                 3         2          2        2            2
+--R                              24C  + 696A C  + (- 240B  + 3144A )C - 1392A B
+--R                            + 
+--R                                  3
+--R                              200A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2        3       2
+--R                              - 144B C  - 1296A B C  + (320B  + 336A B)C
+--R                            + 
+--R                                   3       3
+--R                              64A B  - 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2      2  3
+--R                          16C  + 80A C  + (- 8B  + 32A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 168A B  - 320A )C  + (40B  + 552A B  - 176A )C
+--R                        + 
+--R                                  4     3 2       5
+--R                          - 168A B  + 8A B  + 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                             5         4          2                 2       2  3
+--R                          96D  - 672B D  + (- 768C  - 1536A C + 384B  + 192A )D
+--R                        + 
+--R                                   2                   2   2
+--R                          (- 384B C  - 384A B C - 1344A B)D
+--R                        + 
+--R                                    4        2       2  2       3       4
+--R                              - 352C  + (384B  - 768A )C  - 384A C - 32B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 224A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3 2       3         5
+--R                          - 32B C  + 256A B C  + 128B C  + 384A B C - 32B
+--R                        + 
+--R                                2 3       4
+--R                          - 128A B  + 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  4                      3
+--R                          - 384A D  + (768B C + 1536A B)D
+--R                        + 
+--R                                  2           2       2           2       3  2
+--R                          (1152A C  + (- 1536B  - 768A )C + 384A B  - 128A )D
+--R                        + 
+--R                                 3       2            3         5         4
+--R                          (256B C  + 768A B C + 512A B )D + 128C  - 128A C
+--R                        + 
+--R                              2 3            2       3  2       4        3 2
+--R                          256A C  + (- 384A B  + 128A )C  - 384A C - 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                   4                   3    8
+--R                      ((16C - 96A)D  + (16B C + 32A B)D )a b
+--R                    + 
+--R                              5         4       2                2       2  3
+--R                          136D  - 168B D  + (92C  - 188A C + 136B  + 472A )D
+--R                        + 
+--R                                  2               3      2   2
+--R                          (- 48B C  + 24A B C - 8B  - 72A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 20A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 36A )C
+--R                         *
+--R                            D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 12C - 1996A)D  + (864B C + 640A B)D
+--R                        + 
+--R                                    3         2          2       2          2
+--R                              - 296C  + 720A C  + (- 252B  - 732A )C + 36A B
+--R                            + 
+--R                                   3
+--R                              - 84A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2           3
+--R                              - 48B C  + 288A B C  + (- 40B  - 408A B)C + 24A B
+--R                            + 
+--R                                 3
+--R                              24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3         2      3  2
+--R                          4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          636D  + 544B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 104C  + 3740A C + 120B  + 3228A )D
+--R                        + 
+--R                                    2                 3       2   2
+--R                          (- 1380B C  - 912A B C - 96B  - 804A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              188C  - 300A C  + (- 192B  + 156A )C
+--R                            + 
+--R                                     2       3        4       2 2       4
+--R                              (108A B  - 340A )C + 76B  + 468A B  - 216A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          68B C  - 272A B C  + (28B  + 384A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            4                        3
+--R                          (- 1528C - 1376A)D  + (- 520B C - 1200A B)D
+--R                        + 
+--R                                    3          2        2        2            2
+--R                              - 544C  - 1968A C  + (132B  - 4740A )C + 1068A B
+--R                            + 
+--R                                     3
+--R                              - 1012A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2           3
+--R                              360B C  + 1584A B C  + (- 16B  - 480A B)C - 56A B
+--R                            + 
+--R                                  3
+--R                              600A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3
+--R                          - 8C  - 64A C  + (188B  - 28A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (252A B  + 412A )C  + (- 100B  - 768A B  + 308A )C
+--R                        + 
+--R                               4      3 2      5
+--R                          12A B  - 64A B  - 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 304D  + 944B D
+--R                        + 
+--R                               2                  2       2  3
+--R                          (708C  + 3096A C - 1072B  - 268A )D
+--R                        + 
+--R                                   2                  3        2   2
+--R                          (- 132B C  + 360A B C - 208B  + 2028A B)D
+--R                        + 
+--R                                  4         3          2        2  2
+--R                              636C  + 448A C  + (- 996B  + 1512A )C
+--R                            + 
+--R                                      2       3        4       2 2       4
+--R                              (- 24A B  + 576A )C + 80B  + 924A B  - 356A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3      2   2
+--R                          108B C  - 256A B C  + (- 252B  - 24A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (120A B  - 768A B)C + 80B  + 356A B  - 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                        4                         3
+--R                          (48C + 1776A)D  + (- 1728B C - 3456A B)D
+--R                        + 
+--R                               3          2         2        2         3  2
+--R                          (816C  - 2928A C  + (3168B  + 1680A )C + 432A )D
+--R                        + 
+--R                                    3          2        3      2            3
+--R                              224B C  + 96A B C  + (256B  - 96A B)C - 768A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2       2  3
+--R                          - 160C  + 160A C  + (48B  - 384A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (336A B  - 160A )C  + (- 80B  - 432A B  + 544A )C
+--R                        + 
+--R                                  4      3 2
+--R                          - 112A B  + 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  4        2                 2        2  3
+--R                          - 384B D  + (960C  - 2688A C + 960B  - 1344A )D
+--R                        + 
+--R                                  2                   3       2   2
+--R                          (1344B C  + 2688A B C - 192B  + 576A B)D
+--R                        + 
+--R                                    4         3          2       2  2
+--R                              - 640C  + 768A C  + (- 960B  - 576A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1152A B  - 128A )C - 192B  - 960A B  + 320A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3         3       2   2
+--R                          - 320B C  + 384A B C  + (- 64B  - 576A B)C
+--R                        + 
+--R                                 3       3         5       2 3
+--R                          (640A B  + 256A B)C + 64B  + 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   3
+--R                          1536A B D
+--R                        + 
+--R                                    3          2           2       2
+--R                              - 768C  + 1152A C  + (- 1536B  + 768A )C
+--R                            + 
+--R                                       2       3
+--R                              - 1536A B  - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2
+--R                              256B C  - 1536A B C  + (1024B  + 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4        2       2  3         2 2
+--R                          128C  - 256A C  + (256B  + 256A )C  - 384A B C
+--R                        + 
+--R                               2 2       4           4       3 2       5
+--R                          (768A B  - 384A )C - 512A B  - 128A B  + 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                        5        4         2              2      2  3    9
+--R                  (- 16D  + 32B D  + (- 16C  + 64A C - 16B  - 48A )D )a b
+--R                + 
+--R                                  4                      3
+--R                      (8C + 224A)D  + (- 136B C - 64A B)D
+--R                    + 
+--R                          3         2       2      2    2
+--R                      (40C  - 144A C  + (24B  + 72A )C)D
+--R                    + 
+--R                           3          2      3      2
+--R                      (8B C  - 48A B C  + (8B  + 72A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            5        4         2               2       2  3
+--R                      - 148D  + 88B D  + (- 64C  - 104A C - 64B  - 592A )D
+--R                    + 
+--R                             2                3      2   2
+--R                      (192B C  + 192A B C + 8B  + 72A B)D
+--R                    + 
+--R                               4        3       2      2  2           2      3
+--R                          - 28C  + 88A C  + (24B  - 24A )C  + (- 24A B  + 24A )C
+--R                        + 
+--R                               4      2 2      4
+--R                          - 12B  - 72A B  + 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4          3        3      2   2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (212C + 1532A)D  + (- 664B C - 112A B)D
+--R                    + 
+--R                           3         2         2       2           2      3  2
+--R                      (232C  - 528A C  + (- 24B  + 864A )C - 144A B  + 88A )D
+--R                    + 
+--R                                   3           2       3       2           3
+--R                            - 40B C  - 528A B C  + (40B  + 456A B)C + 32A B
+--R                          + 
+--R                                 3
+--R                            - 80A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        5        4         2      2  3           2      3  2
+--R                      4C  - 12A C  + (- 24B  + 16A )C  + (- 24A B  - 32A )C
+--R                    + 
+--R                          4       2 2      4         4      3 2      5
+--R                      (20B  + 144A B  - 52A )C + 4A B  + 16A B  + 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                            5          4        2                 2        2  3
+--R                      - 124D  - 1208B D  + (248C  - 4328A C + 416B  - 1336A )D
+--R                    + 
+--R                              2                  3       2   2
+--R                      (1176B C  + 912A B C + 104B  + 240A B)D
+--R                    + 
+--R                                4         3        2       2  2
+--R                          - 188C  + 424A C  + (384B  - 264A )C
+--R                        + 
+--R                                  2       3        4       2 2       4
+--R                          (- 24A B  + 136A )C - 68B  - 480A B  + 244A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3         3       2   2
+--R                      - 32B C  + 304A B C  + (- 16B  - 408A B)C
+--R                    + 
+--R                              3      3         5      2 3      4
+--R                      (- 80A B  + 64A B)C - 16B  - 88A B  + 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      4                       3
+--R                      (1028C - 2044A)D  + (3104B C + 2864A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 560C  + 4512A C  + (- 1536B  + 1848A )C - 816A B
+--R                        + 
+--R                              3
+--R                          616A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3           2          3       2            3
+--R                          - 736B C  - 768A B C  + (- 304B  - 912A B)C + 224A B
+--R                        + 
+--R                                3
+--R                          - 496A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4          2       2  3
+--R                      28C  - 52A C  + (- 200B  + 112A )C
+--R                    + 
+--R                               2       3  2        4       2 2       4
+--R                      (- 168A B  - 224A )C  + (140B  + 912A B  - 364A )C
+--R                    + 
+--R                           4       3 2      5
+--R                      92A B  + 112A B  + 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                          5          4           2                 2        2  3
+--R                      288D  + 1088B D  + (- 1896C  + 4752A C - 720B  + 2552A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 2712B C  - 4560A B C + 272B  - 2424A B)D
+--R                    + 
+--R                              4          3         2       2  2
+--R                          280C  - 2048A C  + (1320B  - 480A )C
+--R                        + 
+--R                                  2       3         4       2 2       4
+--R                          (1200A B  - 416A )C + 208B  + 744A B  - 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3        2   2
+--R                      232B C  - 608A B C  + (344B  + 1248A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 560A B  + 448A B)C - 112B  - 616A B  + 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                       4                         3
+--R                      (- 1248C + 288A)D  + (- 2304B C - 2688A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          1056C  - 3840A C  + (1536B  - 3552A )C + 2496A B
+--R                        + 
+--R                                3
+--R                          - 704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2          3       2            3
+--R                          768B C  + 2880A B C  + (- 768B  + 384A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          1088A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4         2       2  3
+--R                      - 32C  + 320A C  + (- 32B  - 128A )C
+--R                    + 
+--R                             2       3  2          4        2 2       4
+--R                      (192A B  + 256A )C  + (- 160B  - 1824A B  + 416A )C
+--R                    + 
+--R                            4       3 2       5
+--R                      416A B  - 128A B  - 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                2       2  3
+--R                      (1728C  - 384A C + 384B  - 576A )D
+--R                    + 
+--R                              2                   3        2   2
+--R                      (1344B C  + 3456A B C - 384B  + 2112A B)D
+--R                    + 
+--R                               4          3           2       2  2
+--R                          - 64C  + 1536A C  + (- 1728B  + 768A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1152A B  + 256A )C - 128B  - 192A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3       2   2
+--R                      - 192B C  + 256A B C  + (- 320B  - 768A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (640A B  - 512A B)C + 128B  + 704A B  - 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                             3       2           2  2
+--R                      (- 768C  + 768A C - 1536A B )D
+--R                    + 
+--R                                  2        3        3            4       2 3
+--R                      (- 1536A B C  + 1024B C - 512A B)D - 256A C  + 256B C
+--R                    + 
+--R                          2 2          4       5
+--R                      768A B C - 512A B  + 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                %%BN1
+--R            + 
+--R                       3 3 8
+--R                  16A D a c
+--R                + 
+--R                            3 2 2          3          2  3
+--R                      - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                    + 
+--R                                     3          2         2      3    4
+--R                      ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           3         2  2 3
+--R                      (2B D  + 6A C D )a b
+--R                    + 
+--R                                    3                   2        2      3    3 2
+--R                      ((12C - 188A)D  + (12B C + 52A B)D  + (4A C  - 12A )D)a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 64C - 32A)D  + (96B C - 320A B)D
+--R                        + 
+--R                                3        2       2          2      3
+--R                          (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                        + 
+--R                                   2      3
+--R                          - 48A B C  - 16A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                      3                   2          2     3
+--R                        ((- 2C + 41A)D  + (- 3B C - 8A B)D  + (- 2A C  + 2A )D)
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 80B D  + (- 18C  + 224A C - 26B  - 66A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                        3                       2
+--R                          (144C - 232A)D  + (- 120B C + 808A B)D
+--R                        + 
+--R                             3         2         2      2           2       3
+--R                          (4C  - 212A C  + (- 24B  + 20A )C - 112A B  - 196A )D
+--R                        + 
+--R                              3          2      2        3
+--R                          4B C  + 36A B C  - 12A B C + 4A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                        + 
+--R                                  2                3       2        4        3
+--R                          (- 80B C  + 96A B C - 64B  - 336A B)D + 8C  + 32A C
+--R                        + 
+--R                              2      2  2         2      3        2 2     4
+--R                          (24B  + 48A )C  + (48A B  + 32A )C + 24A B  + 8A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                  3                     2
+--R                          - 384A D  + (384B C + 128A B)D
+--R                        + 
+--R                                3         2          2       2           2
+--R                          (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                        + 
+--R                               3           2       2           3      3
+--R                          64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4        3      2             2     2  2
+--R                          2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                        + 
+--R                              2              2
+--R                          (B C  + 6A B C - 3A B)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                        + 
+--R                             3       2       2      2          2       3
+--R                          (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                        + 
+--R                               3         2     2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                4        3
+--R                          - 224D  + 92B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 162C  - 280A C - 320B  - 1206A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (172B C  - 336A B C + 60B  + 492A B)D - 6C  + 48A C
+--R                        + 
+--R                                2      2  2           2      3       2 2     4
+--R                          (- 18B  - 24A )C  + (- 24A B  - 80A )C - 6A B  - 2A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                            + 
+--R                                 3
+--R                              64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2         3       2           3
+--R                          - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                        + 
+--R                              3
+--R                          144A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               4         3          2               2       2  2
+--R                          - 64D  - 256B D  + (- 144C  - 608A C + 32B  - 336A )D
+--R                        + 
+--R                                  2      3       2         4        3
+--R                          (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                        + 
+--R                                2      2  2         2       3        4       2 2
+--R                          (- 48B  - 96A )C  + (96A B  - 224A )C + 32B  + 144A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                        3            2
+--R                          (256C - 256A)D  + 1792A B D
+--R                        + 
+--R                                   3         2          2      2           2
+--R                              - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                            + 
+--R                                    3
+--R                              - 256A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3       2            3
+--R                          256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       3                   2
+--R                          (13C - 139A)D  + (18B C + 58A B)D
+--R                        + 
+--R                              3        2        2     2         2      3
+--R                          (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              4         3        2                2       2  2
+--R                          109D  - 265B D  + (114C  - 591A C + 183B  + 543A )D
+--R                        + 
+--R                                  2                 3       2       4        3
+--R                          (- 27B C  + 228A B C - 19B  - 225A B)D + C  - 13A C
+--R                        + 
+--R                             2     2  2        2      3
+--R                          (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                            + 
+--R                                  3
+--R                              346A
+--R                         *
+--R                            D
+--R                        + 
+--R                               3           2       3       2          3      3
+--R                          10B C  - 234A B C  + (14B  + 174A B)C - 2A B  - 30A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                3        2               2       2  2
+--R                          768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                        + 
+--R                                 2                 3        2            3
+--R                          (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                        + 
+--R                                2       2  2            2       3        4
+--R                          (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                        + 
+--R                                2 2      4
+--R                          - 240A B  - 64A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                           3                        2
+--R                          (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                        + 
+--R                                  3         2         2        2           2
+--R                              416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                            + 
+--R                                  3
+--R                              992A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 480B C  + 672A B C  + (- 128B  - 1632A B)C + 512A B
+--R                        + 
+--R                              3
+--R                          160A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 256D  + 384B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (192C  - 1024A C + 256B  - 2112A )D
+--R                        + 
+--R                                 2                  3        2          4
+--R                          (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                        + 
+--R                                 2       2  2            2       3         2 2
+--R                          (- 576B  - 384A )C  + (- 384A B  - 512A )C + 192A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                        + 
+--R                                   2        2           2       3         3
+--R                          (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 54B D  + (- 18C  + 140A C - 26B  - 66A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                        3                      2
+--R                          (142C - 688A)D  + (- 54B C + 800A B)D
+--R                        + 
+--R                                    3         2         2      2           2
+--R                                - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                              + 
+--R                                      3
+--R                                - 248A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2        3      2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              4         3       2                 2        2  2
+--R                          416D  - 190B D  + (84C  + 1254A C + 438B  + 2514A )D
+--R                        + 
+--R                                   2                  3        2         4
+--R                          (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                        + 
+--R                                 3       2       2  2          2       3       4
+--R                          - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C + 2B
+--R                        + 
+--R                             2 2      4
+--R                          48A B  + 14A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                        + 
+--R                                    3        2           2        2            2
+--R                              - 788C  - 84A C  + (- 2292B  - 4428A )C + 1404A B
+--R                            + 
+--R                                     3
+--R                              - 2252A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                        + 
+--R                                3
+--R                          - 308A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          608D  - 640B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 240C  + 3552A C - 960B  + 5232A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1632B C  - 1536A B C - 928B  - 1632A B)D + 464C
+--R                        + 
+--R                                3        2        2  2          2        3
+--R                          128A C  + (912B  + 1344A )C  + (384A B  + 1664A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 160B  - 528A B  - 16A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            3                       2
+--R                          (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 128C  - 576A C  + (192B  - 6144A )C + 4800A B
+--R                            + 
+--R                                    3
+--R                              - 704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2          3       2            3
+--R                          256B C  + 768A B C  + (- 704B  - 384A B)C + 448A B
+--R                        + 
+--R                                3
+--R                          - 128A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 128D  + 1280B D
+--R                        + 
+--R                               2                 2       2  2
+--R                          (768C  + 2560A C - 640B  - 768A )D
+--R                        + 
+--R                                 2                   2          4         3
+--R                          (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                        + 
+--R                                 2       2  2            2       3         4
+--R                          (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                        + 
+--R                                2 2       4
+--R                          - 384A B  + 128A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                3                         2
+--R                          512A D  + (- 1536B C - 2048A B)D
+--R                        + 
+--R                               3          2         2        2            2
+--R                          (256C  - 2048A C  + (3072B  + 1792A )C - 2048A B )D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                        - 1024B C  + 768A B C  - 3072A B C + 1024A B  + 256A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                         3                      2
+--R                          (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                        + 
+--R                             3        2       2      2          2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 204D  + 316B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 144C  + 364A C - 292B  - 1092A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (164B C  - 288A B C + 84B  + 636A B)D - 4C  + 20A C
+--R                        + 
+--R                                2      2  2           2      3
+--R                          (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                            + 
+--R                                  3
+--R                              996A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2         3       2          3
+--R                          - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                        + 
+--R                             3
+--R                          56A B
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 924D  - 588B D
+--R                        + 
+--R                               2                2        2  2
+--R                          (216C  - 5556A C - 60B  - 6156A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                        + 
+--R                                3          2       2  2         2        3
+--R                          708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                        + 
+--R                             4       2 2       4
+--R                          72B  + 576A B  + 120A
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                        + 
+--R                                  3          2        2        2            2
+--R                              408C  + 2760A C  + (504B  + 9096A )C - 3720A B
+--R                            + 
+--R                                   3
+--R                              2904A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3       2            3
+--R                          - 840B C  - 1656A B C  + (168B  + 360A B)C - 792A B
+--R                        + 
+--R                              3
+--R                          408A B
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          480D  - 1536B D
+--R                        + 
+--R                                 2                  2        2  2
+--R                          (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                        + 
+--R                                    2                  3        2          4
+--R                          (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                        + 
+--R                                  3        2        2  2           2        3
+--R                          - 864A C  + (576B  - 2304A )C  + (1152A B  - 2208A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          576B  + 576A B  - 384A
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                           3                       2
+--R                          (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                            + 
+--R                                     2        3
+--R                              2304A B  - 1344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                          1344B C  - 1728A B C  + 5184A B C - 1536A B  - 192A B
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                3           2                  2        2  2
+--R                          512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                        + 
+--R                                    2                   2          4         3
+--R                          (- 1280B C  - 4608A B C + 768A B)D + 640C  - 512A C
+--R                        + 
+--R                                2       2  2          2        3          2 2
+--R                          (1920B  + 768A )C  + (768A B  + 1536A )C - 1152A B
+--R                        + 
+--R                                4
+--R                          - 384A
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                     2
+--R                          - 2048A B D
+--R                        + 
+--R                                3          2         2        2            2
+--R                          (1024C  - 2048A C  + (3072B  - 1024A )C + 2048A B )D
+--R                        + 
+--R                                   3            2           3        2
+--R                          - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                        + 
+--R                                 3        3
+--R                          1024A B  + 1024A B
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                         4        3       2               2       2  2
+--R                      24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                    + 
+--R                             2               3      2
+--R                      (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                    3                    2
+--R                      (- 8C - 336A)D  + (216B C + 96A B)D
+--R                    + 
+--R                            3         2          2       2          2      3
+--R                      (- 56C  + 240A C  + (- 120B  - 184A )C + 80A B  - 96A )D
+--R                    + 
+--R                          3          2      3      2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                          4         3       2               2        2  2
+--R                      216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                    + 
+--R                               2                3       2         4         3
+--R                      (- 304B C  - 48A B C - 64B  - 384A B)D + 32C  - 120A C
+--R                    + 
+--R                        2      2  2           2       3       4      2 2      4
+--R                    (72B  + 24A )C  + (- 24A B  + 152A )C - 8B  - 96A B  - 24A
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                       3                      2
+--R                      (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                        + 
+--R                                3
+--R                          - 864A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3          2      3       2            3      3
+--R                      120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                          4          3          2                 2        2  2
+--R                      144D  + 1848B D  + (- 576C  + 6600A C - 984B  + 1800A )D
+--R                    + 
+--R                                2                   3        2          4
+--R                      (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                    + 
+--R                              3        2       2  2            2        3
+--R                      - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                    + 
+--R                            4       2 2      4
+--R                      - 120B  - 576A B  - 72A
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                    + 
+--R                                 3          2         2        2           2
+--R                            1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                          + 
+--R                                  3
+--R                            - 576A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3            2          3        2             3
+--R                      384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                    + 
+--R                            3
+--R                      - 240A B
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                            4          3
+--R                      - 384D  - 1600B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (2784C  - 7040A C + 1280B  - 3936A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                    + 
+--R                             3           2        2  2             2       3
+--R                      2304A C  + (- 2592B  + 1152A )C  + (- 1152A B  - 768A )C
+--R                    + 
+--R                            4        2 2       4
+--R                      - 384B  + 1440A B  + 864A
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                     3                       2
+--R                      (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                    + 
+--R                                 3          2           2        2            2
+--R                          - 1792C  + 5376A C  + (- 2688B  + 5632A )C - 3200A B
+--R                        + 
+--R                               3
+--R                          1536A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2         3        2             3
+--R                      - 512B C  - 6144A B C  + (2176B  + 2304A B)C - 1152A B
+--R                    + 
+--R                            3
+--R                      - 768A B
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                              2                2       2  2
+--R                      (- 2304C  + 512A C - 512B  + 768A )D
+--R                    + 
+--R                                2                    3        2          4
+--R                      (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                    + 
+--R                          4       2 2       4
+--R                      512B  - 768A B  - 768A
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                            3        2           2              2        3
+--R                      (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                    + 
+--R                           3
+--R                      1024A B
+--R                 *
+--R                     11
+--R                    a
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                        4 2 8
+--R                  - 8A D a c
+--R                + 
+--R                          4   2        4         3  2
+--R                      2A D a b  + (4B D  + 8A C D )a b
+--R                    + 
+--R                                  4          3     3 2  3
+--R                      ((8C - 32A)D  + 32A B D  - 8A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            4         3    3
+--R                      (- B D  - 2A C D )a b
+--R                    + 
+--R                                     4                    3     3 2  2 2
+--R                      ((- 6C + 100A)D  + (- 4B C - 16A B)D  + 2A D )a b
+--R                    + 
+--R                               5        4        2              2      2  3
+--R                          - 12D  + 12B D  + (- 8C  - 16A C - 16B  - 52A )D
+--R                        + 
+--R                                          2   2          3     3
+--R                          (- 24A B C + 12A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      4                      3
+--R                          (32C + 24A)D  + (- 48B C + 128A B)D
+--R                        + 
+--R                              2         2      3  2       4     3 2
+--R                          (48A C - 24A B  - 32A )D  + 8A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 4                3    4
+--R                      ((C - 22A)D  + (B C + 2A B)D )a b
+--R                    + 
+--R                            5        4      2             2      2  3
+--R                          7D  - 45B D  + (6C  - 80A C + 8B  + 25A )D
+--R                        + 
+--R                                      2   2        3     3
+--R                          (6A B C - 3A B)D  + (2A C  - 2A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 88C + 118A)D  + (52B C - 312A B)D
+--R                        + 
+--R                                2       2      2          2      3  2
+--R                          (60A C  + (12B  - 12A )C + 18A B  + 80A )D
+--R                        + 
+--R                               3          2      2            4     3 2
+--R                          (4B C  + 24A B C  - 12A B C)D - 2A C  + 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5        4       2              2       2  3
+--R                          - 36D  + 52B D  + (32C  - 48A C - 44B  - 176A )D
+--R                        + 
+--R                                2                3      2   2
+--R                          (48B C  - 48A B C + 12B  + 96A B)D
+--R                        + 
+--R                             4        3      2 2      3       4         4
+--R                          (8C  - 64A C  + 12A C  + 40A C - 12A )D - 4B C
+--R                        + 
+--R                                   3      2   2
+--R                          - 24A B C  + 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4                      3
+--R                          224A D  + (- 192B C - 96A B)D
+--R                        + 
+--R                                  2       2       2          2     3  2
+--R                          (- 72A C  + (96B  + 192A )C - 96A B  + 8A )D
+--R                        + 
+--R                                  3      2           3       5        4      2 3
+--R                          (- 16B C  - 48A B C - 32A B )D - 8C  + 32A C  - 16A C
+--R                        + 
+--R                                2      3  2      4      3 2
+--R                          (24A B  - 32A )C  + 24A C + 8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          5        4       2            2     2  3    5
+--R                      (- D  + 10B D  + (- C  + 20A C - B  - 3A )D )a b
+--R                    + 
+--R                                       4                    3
+--R                          (53C - 389A)D  + (24B C + 134A B)D
+--R                        + 
+--R                                  2     2        2      3  2
+--R                          (- 15A C  - 3B C - 3A B  - 17A )D
+--R                        + 
+--R                                3         2     2
+--R                          (- B C  - 6A B C  + 3A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              5        4       2                2       2  3
+--R                          127D  - 63B D  + (48C  + 240A C + 147B  + 534A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (- 60B C  + 144A B C - 11B  - 150A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 6C  + 72A C  + (- 12B  - 15A )C
+--R                            + 
+--R                                      2      3       4
+--R                              (- 12A B  - 82A )C + 3A
+--R                         *
+--R                            D
+--R                        + 
+--R                             4         3     2   2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 164C - 696A)D  + (448B C - 184A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 96C  + 138A C  + (- 132B  - 636A )C + 192A B
+--R                            + 
+--R                                 3
+--R                              10A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                               3          2      2           3      3        5
+--R                          (4B C  + 96A B C  - 60A B C + 32A B  + 24A B)D + 6C
+--R                        + 
+--R                                 4       2      2  3        2      3  2     4
+--R                          - 64A C  + (12B  + 16A )C  + (6A B  + 80A )C  - 6A C
+--R                        + 
+--R                              3 2
+--R                          - 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             5         4        2               2       2  3
+--R                          24D  + 120B D  + (116C  + 472A C - 56B  + 196A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (12B C  - 24A B C + 24B  + 156A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              92C  - 64A C  + (12B  + 144A )C
+--R                            + 
+--R                                    2      3        4       2 2      4
+--R                              (72A B  + 48A )C + 16B  + 108A B  - 60A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3         3      2   2
+--R                          20B C  - 80A B C  + (- 12B  + 48A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          4           3
+--R                          (- 128C + 128A)D  - 896A B D
+--R                        + 
+--R                              3         2        2      2          2       3  2
+--R                          (48C  - 288A C  + (384B  - 48A )C + 96A B  + 160A )D
+--R                        + 
+--R                                     3          2         3       2            3
+--R                              - 64B C  + 96A B C  + (- 64B  - 192A B)C - 128A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4         2      2  3        2 2
+--R                          - 32C  + 16A C  + (- 16B  - 64A )C  + 96A B C
+--R                        + 
+--R                                2 2      4          4      3 2      5
+--R                          (- 48A B  + 96A )C + 32A B  + 32A B  - 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                    4                    3    6
+--R                      ((- 8C + 80A)D  + (- 8B C - 16A B)D )a b
+--R                    + 
+--R                               5         4         2               2       2  3
+--R                          - 62D  + 158B D  + (- 47C  + 239A C - 66B  - 218A )D
+--R                        + 
+--R                                2               3      2   2
+--R                          (12B C  - 30A B C + 2B  + 30A B)D
+--R                        + 
+--R                            4        3      2     2  2        2      3
+--R                          (C  - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (229C + 559A)D  + (- 438B C + 584A B)D
+--R                        + 
+--R                              3         2        2       2          2       3  2
+--R                          (64C  - 444A C  + (- 3B  + 213A )C - 93A B  - 175A )D
+--R                        + 
+--R                                     3           2      3       2          3
+--R                              - 10B C  - 180A B C  + (8B  + 144A B)C - 6A B
+--R                            + 
+--R                                  3
+--R                              - 6A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2     2  3          2      3  2
+--R                          - C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5         4          2                2       2  3
+--R                          36D  - 340B D  + (- 237C  - 638A C + 116B  + 123A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 123B C  + 102A B C - 68B  - 363A B)D
+--R                        + 
+--R                                   4         3        2       2  2
+--R                              - 95C  + 312A C  + (- 3B  - 138A )C
+--R                            + 
+--R                                      2       3        4      2 2       4
+--R                              (- 66A B  - 120A )C - 16B  - 99A B  + 105A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4           3        3       2   2
+--R                          5B C  + 176A B C  + (- 5B  - 138A B)C
+--R                        + 
+--R                                3      3        2 3     4
+--R                          (10A B  + 16A B)C + 3A B  + 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (276C - 916A)D  + (416B C + 2048A B)D
+--R                        + 
+--R                                    3         2           2       2          2
+--R                              - 252C  + 636A C  + (- 1032B  - 516A )C - 72A B
+--R                            + 
+--R                                    3
+--R                              - 380A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3           2       2            3      3
+--R                          (- 40B C  - 216A B C  + 168A B C + 256A B  - 40A B)D
+--R                        + 
+--R                             5        4      2       2  3            2      3  2
+--R                          56C  - 80A C  + (4B  + 128A )C  + (- 132A B  + 64A )C
+--R                        + 
+--R                              4       2 2       4         4      3 2      5
+--R                          (20B  + 156A B  - 184A )C - 4A B  - 28A B  + 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              5         4          2               2        2  3
+--R                          144D  - 176B D  + (- 368C  + 736A C - 64B  + 1040A )D
+--R                        + 
+--R                                   2                  2   2
+--R                          (- 528B C  - 480A B C - 528A B)D
+--R                        + 
+--R                                  4        3        2      2  2
+--R                              128C  + 64A C  + (240B  + 96A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (288A B  - 128A )C + 48B  + 240A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4       3      2   2            3      3
+--R                          96B C  + (16B  + 96A B)C  + (- 160A B  - 64A B)C
+--R                        + 
+--R                               5       2 3
+--R                          - 16B  - 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 128C - 384A)D  + (768B C - 512A B)D
+--R                        + 
+--R                               3       2          2       3  2
+--R                          (192C  - 960A C + 768A B  + 128A )D
+--R                        + 
+--R                                   2       3        3           4      2 3
+--R                          (384A B C  - 256B C + 128A B)D - 64A C  - 64B C
+--R                        + 
+--R                              3 2       2 2          4      5
+--R                          128A C  - 192A B C + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         5        4      2             2      2  3    7
+--R                      (8D  - 32B D  + (8C  - 64A C + 8B  + 24A )D )a b
+--R                    + 
+--R                                          4                   3
+--R                          (- 118C + 412A)D  + (2B C - 264A B)D
+--R                        + 
+--R                                3        2      2      2          2      3  2
+--R                          (- 10C  + 96A C  + (6B  - 18A )C + 12A B  + 36A )D
+--R                        + 
+--R                               3          2        3      2
+--R                          (2B C  + 36A B C  + (- 2B  - 30A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5        4
+--R                          - 287D  + 30B D
+--R                        + 
+--R                                2                2        2  3
+--R                          (- 28C  - 682A C - 308B  - 1180A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (240B C  - 168A B C + 50B  + 414A B)D
+--R                        + 
+--R                                 4         3       2      2  2
+--R                              35C  - 170A C  + (54B  + 78A )C
+--R                            + 
+--R                                    2       3       4      2 2      4
+--R                              (66A B  + 198A )C + 3B  + 18A B  - 21A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      3      2   2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (81C + 1825A)D  + (- 528B C - 1756A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                572C  - 60A C  + (936B  + 2010A )C - 108A B
+--R                              + 
+--R                                    3
+--R                                658A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2            3
+--R                              92B C  - 120A B C  + (20B  + 264A B)C - 160A B
+--R                            + 
+--R                                    3
+--R                              - 100A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5         4         2      2  3
+--R                          - 29C  + 119A C  + (- 54B  - 80A )C
+--R                        + 
+--R                                  2       3  2        4      2 2      4        4
+--R                          (- 30A B  - 188A )C  + (- 5B  - 36A B  + 37A )C - A B
+--R                        + 
+--R                            3 2     5
+--R                          4A B  - 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 412D  + 132B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (466C  - 2484A C + 248B  - 2718A )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (1374B C  + 996A B C + 120B  + 702A B)D
+--R                        + 
+--R                                    4         3         2       2  2
+--R                              - 366C  - 192A C  + (- 18B  - 492A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 396A B  + 208A )C - 108B  - 690A B  + 170A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4          3       3       2   2
+--R                          - 190B C  + 96A B C  + (34B  - 204A B)C
+--R                        + 
+--R                                 3       3        5      2 3      4
+--R                          (220A B  + 304A B)C + 4B  + 82A B  + 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         4                        3
+--R                          (936C + 1176A)D  + (- 768B C + 1536A B)D
+--R                        + 
+--R                                 3         2          2        2            2
+--R                              24C  + 696A C  + (- 240B  + 3144A )C - 1392A B
+--R                            + 
+--R                                  3
+--R                              200A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2        3       2
+--R                              - 144B C  - 1296A B C  + (320B  + 336A B)C
+--R                            + 
+--R                                   3       3
+--R                              64A B  - 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2      2  3
+--R                          16C  + 80A C  + (- 8B  + 32A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 168A B  - 320A )C  + (40B  + 552A B  - 176A )C
+--R                        + 
+--R                                  4     3 2       5
+--R                          - 168A B  + 8A B  + 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                             5         4          2                 2       2  3
+--R                          96D  - 672B D  + (- 768C  - 1536A C + 384B  + 192A )D
+--R                        + 
+--R                                   2                   2   2
+--R                          (- 384B C  - 384A B C - 1344A B)D
+--R                        + 
+--R                                    4        2       2  2       3       4
+--R                              - 352C  + (384B  - 768A )C  - 384A C - 32B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 224A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3 2       3         5
+--R                          - 32B C  + 256A B C  + 128B C  + 384A B C - 32B
+--R                        + 
+--R                                2 3       4
+--R                          - 128A B  + 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  4                      3
+--R                          - 384A D  + (768B C + 1536A B)D
+--R                        + 
+--R                                  2           2       2           2       3  2
+--R                          (1152A C  + (- 1536B  - 768A )C + 384A B  - 128A )D
+--R                        + 
+--R                                 3       2            3         5         4
+--R                          (256B C  + 768A B C + 512A B )D + 128C  - 128A C
+--R                        + 
+--R                              2 3            2       3  2       4        3 2
+--R                          256A C  + (- 384A B  + 128A )C  - 384A C - 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                   4                   3    8
+--R                      ((16C - 96A)D  + (16B C + 32A B)D )a b
+--R                    + 
+--R                              5         4       2                2       2  3
+--R                          136D  - 168B D  + (92C  - 188A C + 136B  + 472A )D
+--R                        + 
+--R                                  2               3      2   2
+--R                          (- 48B C  + 24A B C - 8B  - 72A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 20A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 36A )C
+--R                         *
+--R                            D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 12C - 1996A)D  + (864B C + 640A B)D
+--R                        + 
+--R                                    3         2          2       2          2
+--R                              - 296C  + 720A C  + (- 252B  - 732A )C + 36A B
+--R                            + 
+--R                                   3
+--R                              - 84A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2           3
+--R                              - 48B C  + 288A B C  + (- 40B  - 408A B)C + 24A B
+--R                            + 
+--R                                 3
+--R                              24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3         2      3  2
+--R                          4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          636D  + 544B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 104C  + 3740A C + 120B  + 3228A )D
+--R                        + 
+--R                                    2                 3       2   2
+--R                          (- 1380B C  - 912A B C - 96B  - 804A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              188C  - 300A C  + (- 192B  + 156A )C
+--R                            + 
+--R                                     2       3        4       2 2       4
+--R                              (108A B  - 340A )C + 76B  + 468A B  - 216A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          68B C  - 272A B C  + (28B  + 384A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            4                        3
+--R                          (- 1528C - 1376A)D  + (- 520B C - 1200A B)D
+--R                        + 
+--R                                    3          2        2        2            2
+--R                              - 544C  - 1968A C  + (132B  - 4740A )C + 1068A B
+--R                            + 
+--R                                     3
+--R                              - 1012A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2           3
+--R                              360B C  + 1584A B C  + (- 16B  - 480A B)C - 56A B
+--R                            + 
+--R                                  3
+--R                              600A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3
+--R                          - 8C  - 64A C  + (188B  - 28A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (252A B  + 412A )C  + (- 100B  - 768A B  + 308A )C
+--R                        + 
+--R                               4      3 2      5
+--R                          12A B  - 64A B  - 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 304D  + 944B D
+--R                        + 
+--R                               2                  2       2  3
+--R                          (708C  + 3096A C - 1072B  - 268A )D
+--R                        + 
+--R                                   2                  3        2   2
+--R                          (- 132B C  + 360A B C - 208B  + 2028A B)D
+--R                        + 
+--R                                  4         3          2        2  2
+--R                              636C  + 448A C  + (- 996B  + 1512A )C
+--R                            + 
+--R                                      2       3        4       2 2       4
+--R                              (- 24A B  + 576A )C + 80B  + 924A B  - 356A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3      2   2
+--R                          108B C  - 256A B C  + (- 252B  - 24A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (120A B  - 768A B)C + 80B  + 356A B  - 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                        4                         3
+--R                          (48C + 1776A)D  + (- 1728B C - 3456A B)D
+--R                        + 
+--R                               3          2         2        2         3  2
+--R                          (816C  - 2928A C  + (3168B  + 1680A )C + 432A )D
+--R                        + 
+--R                                    3          2        3      2            3
+--R                              224B C  + 96A B C  + (256B  - 96A B)C - 768A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2       2  3
+--R                          - 160C  + 160A C  + (48B  - 384A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (336A B  - 160A )C  + (- 80B  - 432A B  + 544A )C
+--R                        + 
+--R                                  4      3 2
+--R                          - 112A B  + 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  4        2                 2        2  3
+--R                          - 384B D  + (960C  - 2688A C + 960B  - 1344A )D
+--R                        + 
+--R                                  2                   3       2   2
+--R                          (1344B C  + 2688A B C - 192B  + 576A B)D
+--R                        + 
+--R                                    4         3          2       2  2
+--R                              - 640C  + 768A C  + (- 960B  - 576A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1152A B  - 128A )C - 192B  - 960A B  + 320A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3         3       2   2
+--R                          - 320B C  + 384A B C  + (- 64B  - 576A B)C
+--R                        + 
+--R                                 3       3         5       2 3
+--R                          (640A B  + 256A B)C + 64B  + 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   3
+--R                          1536A B D
+--R                        + 
+--R                                    3          2           2       2
+--R                              - 768C  + 1152A C  + (- 1536B  + 768A )C
+--R                            + 
+--R                                       2       3
+--R                              - 1536A B  - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2
+--R                              256B C  - 1536A B C  + (1024B  + 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4        2       2  3         2 2
+--R                          128C  - 256A C  + (256B  + 256A )C  - 384A B C
+--R                        + 
+--R                               2 2       4           4       3 2       5
+--R                          (768A B  - 384A )C - 512A B  - 128A B  + 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                        5        4         2              2      2  3    9
+--R                  (- 16D  + 32B D  + (- 16C  + 64A C - 16B  - 48A )D )a b
+--R                + 
+--R                                  4                      3
+--R                      (8C + 224A)D  + (- 136B C - 64A B)D
+--R                    + 
+--R                          3         2       2      2    2
+--R                      (40C  - 144A C  + (24B  + 72A )C)D
+--R                    + 
+--R                           3          2      3      2
+--R                      (8B C  - 48A B C  + (8B  + 72A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            5        4         2               2       2  3
+--R                      - 148D  + 88B D  + (- 64C  - 104A C - 64B  - 592A )D
+--R                    + 
+--R                             2                3      2   2
+--R                      (192B C  + 192A B C + 8B  + 72A B)D
+--R                    + 
+--R                               4        3       2      2  2           2      3
+--R                          - 28C  + 88A C  + (24B  - 24A )C  + (- 24A B  + 24A )C
+--R                        + 
+--R                               4      2 2      4
+--R                          - 12B  - 72A B  + 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4          3        3      2   2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (212C + 1532A)D  + (- 664B C - 112A B)D
+--R                    + 
+--R                           3         2         2       2           2      3  2
+--R                      (232C  - 528A C  + (- 24B  + 864A )C - 144A B  + 88A )D
+--R                    + 
+--R                                   3           2       3       2           3
+--R                            - 40B C  - 528A B C  + (40B  + 456A B)C + 32A B
+--R                          + 
+--R                                 3
+--R                            - 80A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        5        4         2      2  3           2      3  2
+--R                      4C  - 12A C  + (- 24B  + 16A )C  + (- 24A B  - 32A )C
+--R                    + 
+--R                          4       2 2      4         4      3 2      5
+--R                      (20B  + 144A B  - 52A )C + 4A B  + 16A B  + 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                            5          4        2                 2        2  3
+--R                      - 124D  - 1208B D  + (248C  - 4328A C + 416B  - 1336A )D
+--R                    + 
+--R                              2                  3       2   2
+--R                      (1176B C  + 912A B C + 104B  + 240A B)D
+--R                    + 
+--R                                4         3        2       2  2
+--R                          - 188C  + 424A C  + (384B  - 264A )C
+--R                        + 
+--R                                  2       3        4       2 2       4
+--R                          (- 24A B  + 136A )C - 68B  - 480A B  + 244A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3         3       2   2
+--R                      - 32B C  + 304A B C  + (- 16B  - 408A B)C
+--R                    + 
+--R                              3      3         5      2 3      4
+--R                      (- 80A B  + 64A B)C - 16B  - 88A B  + 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      4                       3
+--R                      (1028C - 2044A)D  + (3104B C + 2864A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 560C  + 4512A C  + (- 1536B  + 1848A )C - 816A B
+--R                        + 
+--R                              3
+--R                          616A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3           2          3       2            3
+--R                          - 736B C  - 768A B C  + (- 304B  - 912A B)C + 224A B
+--R                        + 
+--R                                3
+--R                          - 496A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4          2       2  3
+--R                      28C  - 52A C  + (- 200B  + 112A )C
+--R                    + 
+--R                               2       3  2        4       2 2       4
+--R                      (- 168A B  - 224A )C  + (140B  + 912A B  - 364A )C
+--R                    + 
+--R                           4       3 2      5
+--R                      92A B  + 112A B  + 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                          5          4           2                 2        2  3
+--R                      288D  + 1088B D  + (- 1896C  + 4752A C - 720B  + 2552A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 2712B C  - 4560A B C + 272B  - 2424A B)D
+--R                    + 
+--R                              4          3         2       2  2
+--R                          280C  - 2048A C  + (1320B  - 480A )C
+--R                        + 
+--R                                  2       3         4       2 2       4
+--R                          (1200A B  - 416A )C + 208B  + 744A B  - 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3        2   2
+--R                      232B C  - 608A B C  + (344B  + 1248A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 560A B  + 448A B)C - 112B  - 616A B  + 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                       4                         3
+--R                      (- 1248C + 288A)D  + (- 2304B C - 2688A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          1056C  - 3840A C  + (1536B  - 3552A )C + 2496A B
+--R                        + 
+--R                                3
+--R                          - 704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2          3       2            3
+--R                          768B C  + 2880A B C  + (- 768B  + 384A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          1088A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4         2       2  3
+--R                      - 32C  + 320A C  + (- 32B  - 128A )C
+--R                    + 
+--R                             2       3  2          4        2 2       4
+--R                      (192A B  + 256A )C  + (- 160B  - 1824A B  + 416A )C
+--R                    + 
+--R                            4       3 2       5
+--R                      416A B  - 128A B  - 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                2       2  3
+--R                      (1728C  - 384A C + 384B  - 576A )D
+--R                    + 
+--R                              2                   3        2   2
+--R                      (1344B C  + 3456A B C - 384B  + 2112A B)D
+--R                    + 
+--R                               4          3           2       2  2
+--R                          - 64C  + 1536A C  + (- 1728B  + 768A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1152A B  + 256A )C - 128B  - 192A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3       2   2
+--R                      - 192B C  + 256A B C  + (- 320B  - 768A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (640A B  - 512A B)C + 128B  + 704A B  - 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                             3       2           2  2
+--R                      (- 768C  + 768A C - 1536A B )D
+--R                    + 
+--R                                  2        3        3            4       2 3
+--R                      (- 1536A B C  + 1024B C - 512A B)D - 256A C  + 256B C
+--R                    + 
+--R                          2 2          4       5
+--R                      768A B C - 512A B  + 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                %%BN0
+--R            + 
+--R                       5            4 2  7
+--R                  (4A D a b - 8A C D a )c
+--R                + 
+--R                             5         4    2
+--R                      (- 2B D  - 8A C D )a b
+--R                    + 
+--R                                    5                  4         2     3  3  2
+--R                      ((- 4C + 20A)D  + (4B C - 28A B)D  + (24A C  + 8A )D )a b
+--R                    + 
+--R                             2             2  4            3
+--R                          (8C  - 32A C + 8A )D  + 64A B C D
+--R                        + 
+--R                                  3      3   2
+--R                          (- 16A C  - 16A C)D
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                  5                  4        2     3  3    3
+--R                      ((2C - 38A)D  + (4B C + 12A B)D  + (4A C  - 4A )D )a b
+--R                    + 
+--R                            6       5      2              2      2  4
+--R                          6D  - 4B D  + (4C  + 56A C + 14B  + 36A )D
+--R                        + 
+--R                                  2               2   3           3      3   2
+--R                          (- 12B C  - 8A B C - 12A B)D  + (- 16A C  + 16A C)D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                                        5                    4
+--R                          (- 32C + 16A)D  + (32B C - 160A B)D
+--R                        + 
+--R                                     3        2         2       2          2
+--R                                - 24C  + 56A C  + (- 32B  - 136A )C + 64A B
+--R                              + 
+--R                                   3
+--R                                40A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                               3          2      2         3   2
+--R                          (8B C  - 72A B C  + 24A B C - 24A B)D
+--R                        + 
+--R                                4      3 2     5
+--R                          (20A C  - 24A C  + 4A )D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                              2              2  4
+--R                          (32C  - 32A C + 32A )D
+--R                        + 
+--R                                  2                 2   3
+--R                          (- 64B C  + 256A B C - 64A B)D
+--R                        + 
+--R                                   4        3      2 2            2      3
+--R                                16C  - 64A C  + 96A C  + (- 192A B  - 64A )C
+--R                              + 
+--R                                   4
+--R                                16A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3      3            5      3 3     5
+--R                          (64A B C  + 64A B C)D - 8A C  + 16A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              6        5        2             2      2  4
+--R                          - 2D  + 16B D  + (- 4C  + 64A C - 6B  - 12A )D
+--R                        + 
+--R                                 2               2   3
+--R                          (- 2B C  - 12A B C + 6A B)D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                                      5                      4
+--R                          (28C - 92A)D  + (- 60B C + 260A B)D
+--R                        + 
+--R                             3         2      2      2          2      3  3
+--R                          (8C  - 192A C  + (4B  + 24A )C - 36A B  - 96A )D
+--R                        + 
+--R                               3          2      2     2
+--R                          (8B C  + 48A B C  - 24A B C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                             6        5         2               2       2  4
+--R                          20D  - 32B D  + (- 12C  + 152A C + 36B  + 116A )D
+--R                        + 
+--R                                2                 3       2   3
+--R                          (48B C  - 480A B C - 32B  - 144A B)D
+--R                        + 
+--R                                4         3       2      2  2
+--R                              8C  + 128A C  + (36B  + 48A )C
+--R                            + 
+--R                                     2       3        2 2     4
+--R                              (120A B  + 256A )C + 36A B  + 8A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  4          3      2   2     3         4
+--R                          (- 10B C  - 56A B C  + 36A B C  + 8A B C - 10A B)D
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                                        5                     4
+--R                          (- 48C - 16A)D  + (240B C - 144A B)D
+--R                        + 
+--R                                   3        2         2       2           2
+--R                              - 80C  + 80A C  + (- 96B  - 496A )C + 480A B
+--R                            + 
+--R                                  3
+--R                              112A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                   3           2       3       2           3
+--R                              80B C  - 144A B C  + (96B  + 624A B)C - 32A B
+--R                            + 
+--R                                    3
+--R                              - 176A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2      2  3       3 2
+--R                              - 20C  + 36A C  + (- 32B  - 72A )C  - 184A C
+--R                            + 
+--R                                    2 2      4        5
+--R                              (- 96A B  - 36A )C + 20A
+--R                         *
+--R                            D
+--R                        + 
+--R                            5          4      2   3      3   2      4        5
+--R                        4B C  + 20A B C  - 24A B C  - 24A B C  + 20A B C + 4A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                              2      2  4            2                  2   3
+--R                          (32C  + 32A )D  + (- 256B C  + 256A B C - 256A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              64C  - 128A C  + (192B  + 384A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 768A B  - 128A )C + 192A B  + 64A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4           3       2   2
+--R                              - 64B C  + 256A B C  - 384A B C
+--R                            + 
+--R                                     3       3         4
+--R                              (256A B  + 256A B)C - 64A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            6        5     2 4           2      3  3     4 2
+--R                          8C  - 32A C  - 8A C  + (- 64A B  + 64A )C  - 8A C
+--R                        + 
+--R                                3 2      5       6
+--R                          (- 64A B  - 32A )C + 8A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                         5                     4
+--R                          (- 10C + 118A)D  + (- 20B C - 84A B)D
+--R                        + 
+--R                             3        2      2     2         2      3  3
+--R                          (2C  - 26A C  + (6B  + 6A )C + 6A B  + 34A )D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                               6        5         2                2       2  4
+--R                          - 44D  + 28B D  + (- 28C  - 224A C - 100B  - 324A )D
+--R                        + 
+--R                                2                3       2   3
+--R                          (92B C  + 40A B C + 20B  + 204A B)D
+--R                        + 
+--R                                  4         3         2      2  2
+--R                              - 8C  + 104A C  + (- 24B  - 24A )C
+--R                            + 
+--R                                      2       3
+--R                              (- 24A B  - 136A )C
+--R                         *
+--R                             2
+--R                            D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                                       5                       4
+--R                          (144C + 80A)D  + (- 320B C + 576A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                132C  - 92A C  + (288B  + 1196A )C - 608A B
+--R                              + 
+--R                                      3
+--R                                - 116A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                        3           2         3       2
+--R                                - 160B C  + 528A B C  + (- 64B  - 672A B)C
+--R                              + 
+--R                                    3
+--R                                176A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4       2      2  3
+--R                              10C  - 134A C  + (28B  + 20A )C
+--R                            + 
+--R                                    2       3  2         2 2     4       3 2
+--R                              (12A B  + 196A )C  + (- 12A B  + 2A )C + 4A B
+--R                            + 
+--R                                   5
+--R                              - 30A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                  5          2               2  4
+--R                          - 160B D  + (- 128C  - 256A C + 16B )D
+--R                        + 
+--R                                 2                  3       2   3
+--R                          (416B C  - 960A B C - 128B  - 352A B)D
+--R                        + 
+--R                                   4         3          2        2  2
+--R                              - 82C  + 232A C  + (- 288B  - 1164A )C
+--R                            + 
+--R                                      2      3        4      2 2      4
+--R                              (1344A B  - 24A )C + 16B  + 96A B  - 82A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3       2   2
+--R                              100B C  - 656A B C  + 408A B C
+--R                            + 
+--R                                       3       3         4
+--R                              (- 128A B  - 400A B)C - 28A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              6        5         2     2  4        2       3  3
+--R                          - 4C  + 56A C  + (- 10B  + 4A )C  + (8A B  - 112A )C
+--R                        + 
+--R                              2 2     4  2      3 2      5        4 2     6
+--R                          (36A B  + 4A )C  + (8A B  + 56A )C - 10A B  - 4A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                            4
+--R                          (384B C + 128A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 32C  + 416A C  + (- 640B  - 352A )C + 512A B
+--R                            + 
+--R                                  3
+--R                              224A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2            3
+--R                              160B C  - 288A B C  + (128B  + 2016A B)C - 640A B
+--R                            + 
+--R                                    3
+--R                              - 608A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2       2  3
+--R                              - 48C  - 16A C  + (- 32B  + 288A )C
+--R                            + 
+--R                                      2       3  2          4       2 2      4
+--R                              (- 96A B  + 224A )C  + (- 128B  - 864A B  + 16A )C
+--R                            + 
+--R                                     4       3 2      5
+--R                              - 64A B  + 224A B  + 48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4       3      2   3
+--R                          - 16B C  + 176A B C  + (32B  + 96A B)C
+--R                        + 
+--R                              3      3   2       2 3       4         3 3      5
+--R                        (96A B  + 96A B)C  + (96A B  + 176A B)C + 32A B  - 16A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                   2       2   3
+--R                          (- 256B C  - 256A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              64C  - 256A C  + (768B  + 384A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 768A B  - 256A )C + 768A B  + 64A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 256B C  + 512A B C  + (- 256B  - 1536A B)C
+--R                            + 
+--R                                      3       3          2 3       4
+--R                              (1024A B  + 512A B)C - 256A B  - 256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6       2      2  4         2 3
+--R                          32C  + (64B  - 32A )C  - 256A B C
+--R                        + 
+--R                               2 2      4  2            4       3 2        4 2
+--R                          (384A B  - 32A )C  + (- 128A B  - 256A B )C + 64A B
+--R                        + 
+--R                             6
+--R                          32A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                             6        5       2               2      2  4
+--R                          12D  - 44B D  + (20C  - 152A C + 36B  + 84A )D
+--R                        + 
+--R                               2               3      2   3
+--R                          (4B C  + 72A B C - 4B  - 60A B)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                                        5                     4
+--R                          (- 36C + 12A)D  + (296B C - 520A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 44C  + 524A C  + (- 68B  - 228A )C + 204A B
+--R                            + 
+--R                                  3
+--R                              228A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                  3           2       3       2     2
+--R                          (- 16B C  - 288A B C  + (16B  + 240A B)C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                               6         5         2              2       2  4
+--R                          - 30D  + 272B D  + (- 16C  + 96A C - 44B  - 432A )D
+--R                        + 
+--R                                   2                  3       2   3
+--R                          (- 324B C  + 872A B C + 224B  + 972A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 22C  - 536A C  + (- 48B  - 36A )C
+--R                            + 
+--R                                       2       3       4       2 2      4
+--R                              (- 576A B  - 600A )C - 6B  - 240A B  - 54A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3         3       2   2
+--R                              24B C  + 368A B C  + (- 12B  - 288A B)C
+--R                            + 
+--R                                    3      3        2 3      4
+--R                              (24A B  - 48A B)C + 4A B  + 72A B
+--R                         *
+--R                            D
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                        5                       4
+--R                          (112C + 144A)D  + (- 928B C - 416A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              168C  - 600A C  + (896B  + 1816A )C - 1408A B
+--R                            + 
+--R                                 3
+--R                              24A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 416B C  + 672A B C  + (- 512B  - 3648A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  + 896A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              96C  + 144A C  + (184B  + 320A )C
+--R                            + 
+--R                                     2       3  2       4        2 2       4
+--R                              (216A B  + 544A )C  + (80B  + 1032A B  + 224A )C
+--R                            + 
+--R                                   4      3 2      5
+--R                              48A B  - 24A B  - 48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4       2   3
+--R                          - 12B C  - 156A B C  + 104A B C
+--R                        + 
+--R                                  3       3   2         2 3       4         5
+--R                          (- 32A B  + 104A B)C  + (- 32A B  - 156A B)C - 12A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                 2                2       2  4
+--R                          (- 144C  - 480A C + 480B  - 144A )D
+--R                        + 
+--R                                 2                   3       2   3
+--R                          (960B C  + 1152A B C + 192B  + 192A B)D
+--R                        + 
+--R                                    4         3           2        2  2
+--R                              - 196C  + 912A C  + (- 1536B  - 2136A )C
+--R                            + 
+--R                                      2       3         4      4
+--R                              (2304A B  - 624A )C + 224B  + 60A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4            3        3        2   2
+--R                              696B C  - 1120A B C  + (448B  + 3024A B)C
+--R                            + 
+--R                                        3       3         5       2 3       4
+--R                              (- 1408A B  - 608A B)C + 32B  + 192A B  + 184A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               6         2      2  4         2       3  3
+--R                          - 48C  + (- 84B  - 80A )C  + (80A B  - 256A )C
+--R                        + 
+--R                                4       2 2      4  2           4      3 2
+--R                          (- 48B  - 696A B  - 80A )C  + (- 32A B  + 80A B )C
+--R                        + 
+--R                               2 4      4 2      6
+--R                          - 48A B  - 84A B  - 48A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                 3         2           2       2           2
+--R                              64C  + 576A C  + (- 1152B  + 192A )C - 384A B
+--R                            + 
+--R                                  3
+--R                              192A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                     3            2        3        2
+--R                              - 64B C  - 1728A B C  + (640B  + 1344A B)C
+--R                            + 
+--R                                      3        3
+--R                              - 896A B  - 1088A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              64C  - 512A C  + (320B  + 640A )C
+--R                            + 
+--R                                     2        3  2
+--R                              (192A B  + 1024A )C
+--R                            + 
+--R                                    4        2 2       4           4        3 2
+--R                              (- 64B  - 2112A B  - 192A )C + 320A B  + 1088A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                  5          4         3       2   3
+--R                          - 192B C  + 64A B C  + (- 64B  - 384A B)C
+--R                        + 
+--R                                 3       3   2       5       2 3      4
+--R                          (320A B  - 384A B)C  + (64B  + 320A B  + 64A B)C
+--R                        + 
+--R                               5      3 3       5
+--R                          64A B  - 64A B  - 192A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                   3       2 2       3        2 2  2
+--R                          (- 256A C  + 768B C  - 256A C + 768A B )D
+--R                        + 
+--R                                      4            3           3        2   2
+--R                              - 256B C  + 1024A B C  + (- 1024B  - 1536A B)C
+--R                            + 
+--R                                      3        3           2 3       4
+--R                              (1024A B  + 1024A B)C - 1024A B  - 256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5       2 4            2       3  3
+--R                          128A C  + 256B C  + (- 512A B  - 256A )C
+--R                        + 
+--R                               4        2 2  2            4       3 2       5
+--R                          (128B  + 1536A B )C  + (- 512A B  - 512A B  + 128A )C
+--R                        + 
+--R                              2 4       4 2
+--R                          128A B  + 256A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                      5                    4
+--R                          (8C - 120A)D  + (16B C + 144A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  3
+--R                          (- 8C  + 40A C  + (- 24B  - 24A )C - 24A B  - 72A )D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                             6        5                 2       2  4
+--R                          64D  - 96B D  + (416A C + 128B  + 672A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 224B C  - 128A B C - 96B  - 672A B)D
+--R                        + 
+--R                            4         3       2      2  2         2       3    2
+--R                        (32C  - 160A C  + (96B  + 96A )C  + (96A B  + 288A )C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                          5                     4
+--R                          (- 290C - 354A)D  + (360B C + 168A B)D
+--R                        + 
+--R                                    3         2          2        2           2
+--R                              - 108C  - 356A C  + (- 916B  - 2884A )C + 940A B
+--R                            + 
+--R                                    3
+--R                              - 588A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2           3
+--R                              664B C  - 696A B C  + (280B  + 2376A B)C - 40A B
+--R                            + 
+--R                                    3
+--R                              - 360A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4          2       2  3
+--R                              - 42C  + 206A C  + (- 132B  - 100A )C
+--R                            + 
+--R                                       2       3  2         4      2 2      4
+--R                              (- 108A B  - 420A )C  + (- 10B  - 12A B  - 18A )C
+--R                            + 
+--R                                     4      3 2      5
+--R                              - 10A B  - 36A B  + 54A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                5        2                 2       2  4
+--R                          120B D  + (426C  + 1588A C - 560B  + 522A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 328B C  - 784A B C - 96B  + 696A B)D
+--R                        + 
+--R                                  4         3         2        2  2
+--R                              236C  - 112A C  + (1740B  + 4200A )C
+--R                            + 
+--R                                        2        3         4       2 2      4
+--R                              (- 1800A B  + 2512A )C - 208B  - 852A B  + 12A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 704B C  + 960A B C  + (- 248B  - 2112A B)C
+--R                            + 
+--R                                     3       3         5       2 3
+--R                              (208A B  + 320A B)C - 24B  - 184A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5       2      2  4         2       3  3
+--R                          18C  - 84A C  + (60B  + 14A )C  + (48A B  + 232A )C
+--R                        + 
+--R                              4      2 2      4  2         4      3 2      5
+--R                          (10B  - 24A B  + 14A )C  + (20A B  + 48A B  - 84A )C
+--R                        + 
+--R                             2 4      4 2      6
+--R                          10A B  + 60A B  + 18A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                              4
+--R                          (- 448B C - 576A B)D
+--R                        + 
+--R                                   3          2         2        2           2
+--R                              - 48C  - 2864A C  + (1984B  - 1424A )C + 704A B
+--R                            + 
+--R                                    3
+--R                              - 656A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3            2          3        2
+--R                              - 288B C  + 1632A B C  + (- 640B  - 3552A B)C
+--R                            + 
+--R                                     3       3
+--R                              1664A B  + 672A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    5         4          2        2  3
+--R                              - 184C  + 200A C  + (- 976B  - 2416A )C
+--R                            + 
+--R                                       2        3  2
+--R                              (- 336A B  - 3120A )C
+--R                            + 
+--R                                   4        2 2       4          4        3 2
+--R                              (352B  + 3216A B  - 344A )C - 32A B  - 1520A B
+--R                            + 
+--R                                   5
+--R                              - 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5           4       3       2   3
+--R                          240B C  - 208A B C  + (32B  + 224A B)C
+--R                        + 
+--R                                  3       3   2         2 3       4         3 3
+--R                          (- 32A B  + 224A B)C  + (- 32A B  - 208A B)C + 32A B
+--R                        + 
+--R                              5
+--R                          240A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                 2                   3       2   3
+--R                          (576B C  + 1920A B C - 640B  + 576A B)D
+--R                        + 
+--R                                    4          3           2        2  2
+--R                              - 472C  + 2528A C  + (- 2304B  + 1392A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1536A B  + 992A )C - 416B  - 768A B  + 552A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4            3         3        2   2
+--R                              560B C  - 1216A B C  + (1536B  + 4128A B)C
+--R                            + 
+--R                                        3       3          5       2 3      4
+--R                              (- 2560A B  - 192A B)C - 192B  + 512A B  + 48A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5      2       2  4
+--R                          48C  - 32A C  + (8B  + 464A )C
+--R                        + 
+--R                                  2        3  3          4        2 2       4  2
+--R                          (1120A B  + 1088A )C  + (- 192B  - 1872A B  + 464A )C
+--R                        + 
+--R                                 4        3 2      5        6       2 4     4 2
+--R                          (384A B  + 1120A B  - 32A )C - 32B  - 192A B  + 8A B
+--R                        + 
+--R                             6
+--R                          48A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                      3            2         3       2
+--R                              - 256B C  - 2304A B C  + (1536B  - 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 768A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  5          4        2       2  3          2 2
+--R                              448C  - 1024A C  + (640B  - 640A )C  + 1920A B C
+--R                            + 
+--R                                      2 2       4           4        3 2
+--R                              (- 1152A B  - 832A )C + 768A B  + 1664A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                  5          4          3       2   3
+--R                          - 192B C  + 64A B C  + (- 640B  - 896A B)C
+--R                        + 
+--R                                 3       3   2        2 3      4          3 3
+--R                          (128A B  - 896A B)C  + (128A B  + 64A B)C - 640A B
+--R                        + 
+--R                                5
+--R                          - 192A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                    3        3 2        3           2 3
+--R                          (1024A B C  - 1024B C  + 1024A B C - 1024A B )D
+--R                        + 
+--R                                6         5        2       2  4
+--R                          - 128C  + 128A C  + (256B  + 128A )C
+--R                        + 
+--R                                    2       3  3        4        2 2       4  2
+--R                          (- 1024A B  - 256A )C  + (512B  + 1536A B  + 128A )C
+--R                        + 
+--R                                   4        3 2       5         2 4       4 2
+--R                          (- 512A B  - 1024A B  + 128A )C + 512A B  + 256A B
+--R                        + 
+--R                                6
+--R                          - 128A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                           6        5         2              2       2  4
+--R                      - 16D  + 48B D  + (- 16C  + 96A C - 48B  - 144A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (16B C  - 96A B C + 16B  + 144A B)D
+--R                 *
+--R                       8
+--R                    a b
+--R                + 
+--R                                   5                      4
+--R                      (48C + 240A)D  + (- 288B C - 96A B)D
+--R                    + 
+--R                          3         2        2       2           2       3  3
+--R                      (80C  - 464A C  + (304B  + 624A )C - 144A B  + 144A )D
+--R                    + 
+--R                              3           2         3       2     2
+--R                      (- 64B C  + 384A B C  + (- 64B  - 576A B)C)D
+--R                 *
+--R                     2 7
+--R                    a b
+--R                + 
+--R                           6         5       2                 2       2  4
+--R                      - 20D  - 156B D  + (56C  - 1296A C + 168B  - 456A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (664B C  + 624A B C - 40B  - 168A B)D
+--R                    + 
+--R                                4         3          2       2  2
+--R                          - 148C  + 816A C  + (- 648B  - 888A )C
+--R                        + 
+--R                                 2       3        4       2 2       4
+--R                          (240A B  - 720A )C + 44B  + 504A B  + 108A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          84B C  - 496A B C  + (88B  + 696A B)C
+--R                        + 
+--R                                  3       3        5      2 3       4
+--R                          (- 16A B  + 144A B)C + 4B  + 24A B  - 108A B
+--R                     *
+--R                        D
+--R                 *
+--R                     3 6
+--R                    a b
+--R                + 
+--R                                   5                     4
+--R                      (168C - 24A)D  + (828B C + 636A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 416C  + 2848A C  + (- 752B  + 1824A )C - 432A B
+--R                        + 
+--R                              3
+--R                          608A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3            2        3       2            3
+--R                          - 712B C  - 1560A B C  + (392B  + 936A B)C - 696A B
+--R                        + 
+--R                                3
+--R                          - 264A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2       2  3
+--R                          120C  - 616A C  + (544B  + 432A )C
+--R                        + 
+--R                                 2        3  2          4        2 2       4
+--R                          (288A B  + 1072A )C  + (- 120B  - 1824A B  - 168A )C
+--R                        + 
+--R                              4       3 2      5
+--R                          8A B  + 480A B  - 72A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4         3       2   3
+--R                      - 36B C  + 204A B C  + (- 40B  - 232A B)C
+--R                    + 
+--R                           3       3   2        5     2 3       4          5
+--R                      (8A B  - 232A B)C  + (- 4B  + 8A B  + 204A B)C - 4A B
+--R                    + 
+--R                           3 3      5
+--R                      - 40A B  - 36A B
+--R                 *
+--R                     4 5
+--R                    a b
+--R                + 
+--R                             2                2      2  4
+--R                      (- 580C  + 120A C - 120B  + 60A )D
+--R                    + 
+--R                                2                   3        2   3
+--R                      (- 1760B C  - 2688A B C + 384B  - 1056A B)D
+--R                    + 
+--R                              4          3         2        2  2
+--R                          680C  - 3168A C  + (1224B  - 2832A )C
+--R                        + 
+--R                                  2        3         4      2 2       4
+--R                          (1680A B  - 1632A )C + 176B  + 72A B  - 600A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4            3          3        2   2
+--R                          336B C  + 1664A B C  + (- 800B  - 1248A B)C
+--R                        + 
+--R                                 3       5       2 3       4
+--R                          1664A B C + 64B  + 288A B  + 528A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5          2      2  4
+--R                      - 36C  + 168A C  + (- 144B  - 28A )C
+--R                    + 
+--R                               2       3  3       4        2 2      4  2
+--R                      (- 448A B  - 464A )C  + (92B  + 1440A B  - 28A )C
+--R                    + 
+--R                              4       3 2       5       6      2 4       4 2
+--R                      (- 72A B  - 448A B  + 168A )C + 8B  + 92A B  - 144A B
+--R                    + 
+--R                           6
+--R                      - 36A
+--R                 *
+--R                     5 4
+--R                    a b
+--R                + 
+--R                            3         2        2       2           2      3  3
+--R                      (1056C  - 224A C  + (448B  - 288A )C + 576A B  - 32A )D
+--R                    + 
+--R                                 3            2           3        2
+--R                          1856B C  + 4416A B C  + (- 1408B  + 2880A B)C
+--R                        + 
+--R                                  3        3
+--R                          - 384A B  + 1344A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5          4          2        2  3
+--R                          - 480C  + 1760A C  + (- 800B  + 2112A )C
+--R                        + 
+--R                                    2        3  2
+--R                          (- 2592A B  + 1216A )C
+--R                        + 
+--R                                 4        2 2        4           4        3 2
+--R                          (- 192B  + 1056A B  + 1440A )C - 832A B  - 1248A B
+--R                        + 
+--R                             5
+--R                          96A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4        3       2   3
+--R                      - 48B C  - 624A B C  + (448B  + 416A B)C
+--R                    + 
+--R                               3       3   2         5       2 3       4
+--R                      (- 832A B  + 416A B)C  + (- 64B  - 832A B  - 624A B)C
+--R                    + 
+--R                             5       3 3      5
+--R                      - 64A B  + 448A B  - 48A B
+--R                 *
+--R                     6 3
+--R                    a b
+--R                + 
+--R                                 4         3          2       2  2
+--R                          - 1072C  + 192A C  + (- 576B  + 480A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1920A B  + 192A )C + 320B  - 576A B  - 48A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3         3        2   2
+--R                          - 960B C  - 3328A B C  + (1792B  - 2688A B)C
+--R                        + 
+--R                                 3        3          5       2 3       4
+--R                          (512A B  - 2304A B)C + 256B  + 768A B  - 960A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6         5        2       2  4           2       3  3
+--R                      128C  - 384A C  + (144B  - 640A )C  + (1472A B  - 256A )C
+--R                    + 
+--R                            4        2 2       4  2
+--R                      (- 64B  - 1440A B  - 640A )C
+--R                    + 
+--R                              4        3 2       5        6      2 4       4 2
+--R                      (1152A B  + 1472A B  - 384A )C + 64B  - 64A B  + 144A B
+--R                    + 
+--R                          6
+--R                      128A
+--R                 *
+--R                     7 2
+--R                    a b
+--R                + 
+--R                              5        4        2       2  3
+--R                          576C  - 64A C  + (256B  - 384A )C
+--R                        + 
+--R                                  2       3  2          4       2 2       4
+--R                          (2304A B  - 128A )C  + (- 768B  + 768A B  - 192A )C
+--R                        + 
+--R                                  4       3 2       5
+--R                          - 256A B  + 768A B  + 192A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4          3       2   3
+--R                      192B C  + 960A B C  + (- 768B  + 896A B)C
+--R                    + 
+--R                               3       3   2          5       2 3       4
+--R                      (- 256A B  + 896A B)C  + (- 256B  - 256A B  + 960A B)C
+--R                    + 
+--R                              5       3 3       5
+--R                      - 256A B  - 768A B  + 192A B
+--R                 *
+--R                     8
+--R                    a b
+--R                + 
+--R                            6       2 4          2 3        4       4  2
+--R                      - 128C  + 128A C  - 1024A B C  + (512B  + 128A )C
+--R                    + 
+--R                             3 2        2 4       6
+--R                      - 1024A B C + 512A B  - 128A
+--R                 *
+--R                     9
+--R                    a
+--R             *
+--R                x
+--R            + 
+--R                   5 2         4            4 2  7
+--R              (2A D b  - 4A C D a b + 8A B D a )c
+--R            + 
+--R                        5         4  3
+--R                  (- B D  - 4A C D )b
+--R                + 
+--R                               5                  4         2     3  3    2
+--R                  ((- 2C + 8A)D  + (2B C - 16A B)D  + (12A C  + 6A )D )a b
+--R                + 
+--R                      2             2  4            3          3      3   2  2
+--R                  ((4C  - 20A C - 4B )D  + 24A B C D  + (- 8A C  - 20A C)D )a b
+--R                + 
+--R                            5                    4        2         2  3
+--R                      - 8A D  + (- 8B C + 32A B)D  + (- 8A C - 48A B )D
+--R                    + 
+--R                        3   2      3 2
+--R                      8A B D  + 16A C D
+--R                 *
+--R                     3
+--R                    a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                             5                 4        2     3  3  4
+--R                  ((C - 19A)D  + (2B C + 6A B)D  + (2A C  - 2A )D )b
+--R                + 
+--R                        6      5      2             2      2  4
+--R                      3D  - B D  + (2C  + 34A C + 8B  + 19A )D
+--R                    + 
+--R                             2              2   3          3     3   2
+--R                      (- 6B C  - 2A B C - 9A B)D  + (- 8A C  + 8A C)D
+--R                 *
+--R                       3
+--R                    a b
+--R                + 
+--R                                    5                    4
+--R                      (- 14C + 10A)D  + (24B C - 150A B)D
+--R                    + 
+--R                            3        2         2      2          2      3  3
+--R                      (- 12C  + 24A C  + (- 12B  - 68A )C + 54A B  + 34A )D
+--R                    + 
+--R                         3          2      2        3   2         4      3 2
+--R                    (4B C  - 36A B C  + 30A B C - 8A B)D  + (10A C  - 10A C )D
+--R                 *
+--R                     2 2
+--R                    a b
+--R                + 
+--R                           5       2             2      2  4
+--R                      16B D  + (20C  - 12A C - 8B  + 16A )D
+--R                    + 
+--R                              2                 3      2   3
+--R                      (- 24B C  + 184A B C + 24B  + 64A B)D
+--R                    + 
+--R                            4        3      2 2           2       3        2 2
+--R                          8C  - 24A C  + 96A C  + (- 60A B  - 104A )C - 12A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              3      2   2      3            5     3 3
+--R                      (40A B C  - 24A B C  + 24A B C)D - 4A C  + 4A C
+--R                 *
+--R                     3
+--R                    a b
+--R                + 
+--R                                 5                     4
+--R                      (8C - 32A)D  + (- 32B C + 56A B)D
+--R                    + 
+--R                            2       2      2           2  3
+--R                      (16A C  + (56B  - 32A )C - 192A B )D
+--R                    + 
+--R                             3      3   2
+--R                      (104A B  + 32A B)D
+--R                    + 
+--R                          2 3      3 2      4       3 2           4      3   2
+--R                    (- 56A C  + 64A C  - 40A C - 16A B )D - 8A B C  - 24A B C
+--R                 *
+--R                     4
+--R                    a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                         6       5        2             2     2  4
+--R                      - D  + 8B D  + (- 2C  + 32A C - 3B  - 6A )D
+--R                    + 
+--R                            2              2   3
+--R                      (- B C  - 6A B C + 3A B)D
+--R                 *
+--R                     5
+--R                    b
+--R                + 
+--R                                  5                      4
+--R                      (13C - 31A)D  + (- 34B C + 142A B)D
+--R                    + 
+--R                         3         2     2      2          2      3  3
+--R                      (4C  - 100A C  + (B  + 14A )C - 19A B  - 66A )D
+--R                    + 
+--R                           3          2      2     2
+--R                      (4B C  + 24A B C  - 12A B C)D
+--R                 *
+--R                       4
+--R                    a b
+--R                + 
+--R                        6        5         2               2      2  4
+--R                      7D  - 27B D  + (- 14C  + 110A C + 47B  + 82A )D
+--R                    + 
+--R                            2                 3       2   3
+--R                      (20B C  - 196A B C - 27B  - 126A B)D
+--R                    + 
+--R                            4        3       2     2  2         2       3
+--R                          4C  + 72A C  + (18B  + 3A )C  + (42A B  + 230A )C
+--R                        + 
+--R                             2 2    4
+--R                          12A B  - A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             4          3      2   2
+--R                      (- 5B C  - 30A B C  + 15A B C )D
+--R                 *
+--R                     2 3
+--R                    a b
+--R                + 
+--R                                    5                     4
+--R                      (- 36C + 74A)D  + (174B C - 216A B)D
+--R                    + 
+--R                            3        2          2       2           2      3  3
+--R                      (- 36C  - 30A C  + (- 132B  - 332A )C + 586A B  + 30A )D
+--R                    + 
+--R                                 3           2       3       2           3
+--R                            36B C  - 192A B C  + (30B  + 288A B)C - 80A B
+--R                          + 
+--R                                  3
+--R                            - 160A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         2      2  3           2       3  2
+--R                          - 10C  + (- 20B  - 24A )C  + (- 18A B  - 214A )C
+--R                        + 
+--R                                2 2     4       3 2     5
+--R                          (- 36A B  - 2A )C - 2A B  + 2A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4     2   3
+--R                      2B C  + 12A B C  - 6A B C
+--R                 *
+--R                     3 2
+--R                    a b
+--R                + 
+--R                           6        5       2              2      2  4
+--R                      - 12D  + 40B D  + (16C  - 48A C - 96B  - 24A )D
+--R                    + 
+--R                               2                 3      2   3
+--R                      (- 200B C  + 128A B C + 40B  + 96A B)D
+--R                    + 
+--R                             4         3       2       2  2
+--R                          24C  - 108A C  + (48B  + 492A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 528A B  - 172A )C - 52B  - 264A B  + 100A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4           3       2   2         3       3
+--R                          - 40B C  + 216A B C  - 240A B C  + (80A B  + 264A B)C
+--R                        + 
+--R                             2 3     4
+--R                          24A B  + 8A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6       5      2      2  4          2      3  3
+--R                      4C  - 4A C  + (4B  + 16A )C  + (- 4A B  + 40A )C
+--R                    + 
+--R                          2 2      4  2       3 2     5
+--R                      (36A B  + 12A )C  + (12A B  - 4A )C
+--R                 *
+--R                     4
+--R                    a b
+--R                + 
+--R                                  5                     4
+--R                      (32C - 16A)D  + (- 80B C + 96A B)D
+--R                    + 
+--R                           3        2        2     2           2  3
+--R                      (- 8C  + 64A C  + (224B  + 8A )C - 176A B )D
+--R                    + 
+--R                                2       3          3     3   2
+--R                      (- 24A B C  - 144B C + 416A B  - 8A B)D
+--R                    + 
+--R                               4      2       2  3       3 2       2 2       4
+--R                          72A C  + (8B  - 224A )C  + 160A C  + (24A B  - 160A )C
+--R                        + 
+--R                                 4      3 2      5
+--R                          - 96A B  - 64A B  + 24A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4       2   3          3      3   2
+--R                      8B C  - 32A B C  + 128A B C  + (- 8A B  - 96A B)C
+--R                    + 
+--R                         4        3 3
+--R                      56A B C + 8A B
+--R                 *
+--R                     5
+--R                    a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                                   5                     4
+--R                      (- 5C + 59A)D  + (- 10B C - 42A B)D
+--R                    + 
+--R                        3        2      2     2         2      3  3
+--R                      (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                 *
+--R                     6
+--R                    b
+--R                + 
+--R                           6       5         2               2       2  4
+--R                      - 21D  + 9B D  + (- 11C  - 154A C - 55B  - 167A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (49B C  + 10A B C + 11B  + 129A B)D
+--R                    + 
+--R                         4        3         2      2  2           2      3    2
+--R                    (- 4C  + 52A C  + (- 12B  - 12A )C  + (- 12A B  - 68A )C)D
+--R                 *
+--R                       5
+--R                    a b
+--R                + 
+--R                                  5                       4
+--R                      (75C - 13A)D  + (- 196B C + 452A B)D
+--R                    + 
+--R                          3        2        2       2           2      3  3
+--R                      (68C  - 10A C  + (143B  + 671A )C - 425A B  - 99A )D
+--R                    + 
+--R                                 3           2         3       2           3
+--R                          - 84B C  + 288A B C  + (- 26B  - 438A B)C + 14A B
+--R                        + 
+--R                             3
+--R                          70A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                         5        4       2      2  3         2      3  2
+--R                      (5C  - 65A C  + (15B  + 15A )C  + (15A B  + 85A )C )D
+--R                 *
+--R                     2 4
+--R                    a b
+--R                + 
+--R                         6         5         2               2      2  4
+--R                      12D  - 194B D  + (- 99C  - 164A C + 90B  + 29A )D
+--R                    + 
+--R                             2                  3       2   3
+--R                      (241B C  - 698A B C - 206B  - 737A B)D
+--R                    + 
+--R                               4         3         2       2  2
+--R                          - 45C  + 188A C  + (- 63B  - 966A )C
+--R                        + 
+--R                                 2       3        4       2 2       4
+--R                          (660A B  + 338A )C + 42B  + 357A B  - 127A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          65B C  - 336A B C  + (13B  + 432A B)C
+--R                        + 
+--R                                  3       3        2 3    4
+--R                          (- 22A B  - 192A B)C + 3A B  - A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6        5        2     2  4          2      3  3
+--R                      - 2C  + 26A C  + (- 6B  - 6A )C  + (- 6A B  - 34A )C
+--R                 *
+--R                     3 3
+--R                    a b
+--R                + 
+--R                                     5                    4
+--R                      (- 76C + 128A)D  + (500B C + 52A B)D
+--R                    + 
+--R                          3         2          2       2           2      3  3
+--R                      (72C  + 422A C  + (- 652B  - 256A )C + 812A B  + 98A )D
+--R                    + 
+--R                                3          2        3        2            3
+--R                          222B C  + 36A B C  + (348B  + 1410A B)C - 884A B
+--R                        + 
+--R                                3
+--R                          - 132A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2       2  3
+--R                          - 6C  - 120A C  + (- 8B  + 592A )C
+--R                        + 
+--R                                  2       3  2         4       2 2       4
+--R                          (- 30A B  - 172A )C  + (- 40B  - 384A B  + 278A )C
+--R                        + 
+--R                               4       3 2     5
+--R                          36A B  + 102A B  + 4A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5          4      3       2   3
+--R                      - 20B C  + 78A B C  + (2B  - 124A B)C
+--R                    + 
+--R                           3       3   2         2 3      4        3 3     5
+--R                      (4A B  + 144A B)C  + (- 18A B  - 16A B)C - 4A B  + 2A B
+--R                 *
+--R                     4 2
+--R                    a b
+--R                + 
+--R                           6        5       2               2       2  4
+--R                      - 32D  + 80B D  + (68C  - 88A C - 224B  - 172A )D
+--R                    + 
+--R                               2                  3      2   3
+--R                      (- 240B C  - 288A B C + 192B  - 16A B)D
+--R                    + 
+--R                             4         3        2       2  2
+--R                          40C  - 624A C  + (600B  + 576A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 336A B  - 368A )C - 64B  - 360A B  + 120A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4           3         3        2   2
+--R                          - 224B C  + 288A B C  + (- 80B  - 1344A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (672A B  + 480A B)C + 48B  + 336A B  - 160A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6       5      2       2  4            2      3  3
+--R                      4C  + 8A C  + (8B  - 100A )C  + (- 144A B  - 80A )C
+--R                    + 
+--R                         4      4  2           4       3 2      5        2 4
+--R                      (4B  - 36A )C  + (- 24A B  - 144A B  - 56A )C - 12A B
+--R                    + 
+--R                           4 2     6
+--R                      - 40A B  + 4A
+--R                 *
+--R                     5
+--R                    a b
+--R                + 
+--R                                  5                      4
+--R                      (32C + 64A)D  + (- 192B C + 32A B)D
+--R                    + 
+--R                            3        2       2          2  3
+--R                      (- 32C  + (320B  + 160A )C + 64A B )D
+--R                    + 
+--R                                2       3          3       3   2
+--R                      (- 96A B C  - 576B C + 320A B  - 160A B)D
+--R                    + 
+--R                               5         4       2       2  3       3 2
+--R                          - 32C  + 288A C  + (32B  - 320A )C  + 384A C
+--R                        + 
+--R                               4      2 2       4           4      5
+--R                          (160B  + 96A B  - 160A )C - 384A B  + 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       2   3           3       3   2
+--R                      32B C  - 160A B C  + 512A B C  + (- 32A B  - 320A B)C
+--R                    + 
+--R                          4           5      3 3      5
+--R                      224A B C + 32A B  + 32A B  - 32A B
+--R                 *
+--R                     6
+--R                    a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                        6        5       2              2      2  4
+--R                      6D  - 22B D  + (10C  - 76A C + 18B  + 42A )D
+--R                    + 
+--R                           2               3      2   3
+--R                      (2B C  + 36A B C - 2B  - 30A B)D
+--R                 *
+--R                     7
+--R                    b
+--R                + 
+--R                                    5                     4
+--R                      (- 16C - 24A)D  + (168B C - 272A B)D
+--R                    + 
+--R                            3         2         2       2           2       3  3
+--R                      (- 24C  + 288A C  + (- 32B  - 136A )C + 104A B  + 160A )D
+--R                    + 
+--R                             3           2      3       2     2
+--R                      (- 8B C  - 144A B C  + (8B  + 120A B)C)D
+--R                 *
+--R                       6
+--R                    a b
+--R                + 
+--R                          6         5       2              2       2  4
+--R                      - 5D  + 208B D  + (28C  + 52A C - 90B  - 258A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 166B C  + 352A B C + 168B  + 696A B)D
+--R                    + 
+--R                              4         3         2       2  2
+--R                          - 7C  - 344A C  + (- 36B  + 108A )C
+--R                        + 
+--R                                   2       3       4       2 2     4
+--R                          (- 228A B  - 572A )C - 9B  - 126A B  + 7A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                            4           3         3       2   2
+--R                      (10B C  + 180A B C  + (- 10B  - 150A B)C )D
+--R                 *
+--R                     2 5
+--R                    a b
+--R                + 
+--R                                    5                       4
+--R                      (155C - 103A)D  + (- 600B C - 212A B)D
+--R                    + 
+--R                          3         2        2        2            2       3  3
+--R                      (36C  - 308A C  + (816B  + 1470A )C - 1208A B  + 210A )D
+--R                    + 
+--R                                  3           2          3        2            3
+--R                          - 296B C  + 624A B C  + (- 332B  - 1848A B)C + 432A B
+--R                        + 
+--R                              3
+--R                          516A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5         4       2      2  3         2       3  2
+--R                          37C  + 171A C  + (62B  + 16A )C  + (54A B  + 548A )C
+--R                        + 
+--R                              4       2 2      4         4     3 2      5
+--R                          (17B  + 300A B  + 11A )C - 5A B  + 8A B  - 15A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5          4      3      2   3
+--R                      - 4B C  - 72A B C  + (4B  + 60A B)C
+--R                 *
+--R                     3 4
+--R                    a b
+--R                + 
+--R                         6         5          2                2       2  4
+--R                      94D  - 130B D  + (- 210C  - 318A C + 752B  + 284A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (494B C  + 940A B C - 88B  - 118A B)D
+--R                    + 
+--R                                4         3           2        2  2
+--R                          - 204C  + 880A C  + (- 1170B  - 2592A )C
+--R                        + 
+--R                                  2       3         4        2 2       4
+--R                          (1284A B  - 380A )C + 306B  + 1434A B  - 352A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3        3        2   2
+--R                          380B C  - 936A B C  + (102B  + 1596A B)C
+--R                        + 
+--R                                   3        3         5       2 3      4
+--R                          (- 700A B  - 1272A B)C - 22B  - 302A B  - 24A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6        5         2      2  4         2       3  3
+--R                      - 16C  - 38A C  + (- 12B  - 38A )C  + (76A B  - 112A )C
+--R                    + 
+--R                           4       2 2      4  2         4      3 2      5
+--R                      (- 8B  - 192A B  - 56A )C  + (10A B  - 16A B  + 38A )C
+--R                    + 
+--R                        2 4     4 2     6
+--R                      6A B  + 8A B  - 2A
+--R                 *
+--R                     4 3
+--R                    a b
+--R                + 
+--R                                      5                    4
+--R                      (- 220C - 244A)D  + (324B C - 60A B)D
+--R                    + 
+--R                                3         2           2       2            2
+--R                          - 112C  + 948A C  + (- 1776B  - 288A )C - 1008A B
+--R                        + 
+--R                              3
+--R                          188A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3           2         3       2             3
+--R                          - 108B C  - 936A B C  + (1104B  + 876A B)C - 1312A B
+--R                        + 
+--R                              3
+--R                          104A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2        2  3
+--R                          160C  - 668A C  + (176B  + 1512A )C
+--R                        + 
+--R                                2      3  2          4        2 2       4
+--R                          (60A B  + 80A )C  + (- 372B  - 1248A B  + 344A )C
+--R                        + 
+--R                                4      3 2      5
+--R                          484A B  + 84A B  - 84A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4       3       2   3
+--R                      - 84B C  + 360A B C  + (12B  - 592A B)C
+--R                    + 
+--R                             3       3   2       5       2 3       4          5
+--R                      (280A B  + 712A B)C  + (12B  + 276A B  - 124A B)C - 4A B
+--R                    + 
+--R                         3 3      5
+--R                      40A B  + 48A B
+--R                 *
+--R                     5 2
+--R                    a b
+--R                + 
+--R                           6         5        2                2      2  4
+--R                      - 16D  + 160B D  + (168C  + 368A C - 176B  - 24A )D
+--R                    + 
+--R                              2                  3      2   3
+--R                      (- 32B C  - 192A B C + 448B  + 96A B)D
+--R                    + 
+--R                              4         3         2       2  2
+--R                          288C  - 832A C  + (1008B  + 384A )C
+--R                        + 
+--R                                  2       3         4       2 2      4
+--R                          (1248A B  - 512A )C - 112B  + 432A B  - 32A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3          3        2   2
+--R                          - 192B C  + 1024A B C  + (- 928B  - 1536A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (320A B  + 768A B)C + 32B  + 352A B  - 448A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5       2       2  4           2      3  3
+--R                      - 24C  + 144A C  + (96B  - 168A )C  + (- 64A B  - 96A )C
+--R                    + 
+--R                          4       2 2       4  2            4       3 2      5
+--R                      (40B  + 384A B  + 152A )C  + (- 272A B  - 192A B  - 48A )C
+--R                    + 
+--R                           6       2 4      4 2      6
+--R                      - 16B  - 152A B  + 32A B  + 40A
+--R                 *
+--R                     6
+--R                    a b
+--R                + 
+--R                           5                       4
+--R                      64A D  + (- 192B C - 256A B)D
+--R                    + 
+--R                               2        2       2           2  3
+--R                      (- 256A C  + (384B  + 128A )C + 128A B )D
+--R                    + 
+--R                             3          3       3   2
+--R                      (- 640B C - 384A B  - 128A B)D
+--R                    + 
+--R                                5         4       2 3       3 2       4
+--R                          - 128C  + 320A C  - 384A C  + 384A C  + 640B C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 320A B  + 256A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       2   3       3   2
+--R                      64B C  - 512A B C  + 640A B C  - 896A B C
+--R                    + 
+--R                            5       4            5       5
+--R                      (- 64B  + 320A B)C + 128A B  - 128A B
+--R                 *
+--R                     7
+--R                    a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                                 5                  4
+--R                      (4C - 60A)D  + (8B C + 72A B)D
+--R                    + 
+--R                           3        2         2      2          2      3  3
+--R                      (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                 *
+--R                     8
+--R                    b
+--R                + 
+--R                         6        5         2               2       2  4
+--R                      28D  - 44B D  + (- 12C  + 280A C + 68B  + 340A )D
+--R                    + 
+--R                               2                3       2   3
+--R                      (- 124B C  - 56A B C - 52B  - 396A B)D
+--R                    + 
+--R                          4        3       2      2  2         2       3    2
+--R                      (16C  - 80A C  + (48B  + 48A )C  + (48A B  + 144A )C)D
+--R                 *
+--R                       7
+--R                    a b
+--R                + 
+--R                                     5                   4
+--R                      (- 208C - 16A)D  + (168B C + 8A B)D
+--R                    + 
+--R                                 3         2          2        2           2
+--R                            - 60C  - 252A C  + (- 512B  - 1728A )C + 608A B
+--R                          + 
+--R                                  3
+--R                            - 352A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                3           2        3        2           3
+--R                          368B C  - 384A B C  + (136B  + 1368A B)C - 56A B
+--R                        + 
+--R                                3
+--R                          - 152A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         4         2      2  3
+--R                          - 20C  + 100A C  + (- 60B  - 60A )C
+--R                        + 
+--R                                  2       3  2
+--R                          (- 60A B  - 180A )C
+--R                     *
+--R                        D
+--R                 *
+--R                     2 6
+--R                    a b
+--R                + 
+--R                            6         5        2                 2      2  4
+--R                      - 102D  + 166B D  + (276C  + 1024A C - 552B  + 12A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 204B C  - 280A B C + 136B  + 724A B)D
+--R                    + 
+--R                              4         3        2        2  2
+--R                          210C  - 280A C  + (888B  + 3060A )C
+--R                        + 
+--R                                   2        3         4        2 2       4
+--R                          (- 984A B  + 1120A )C - 194B  - 1296A B  + 258A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4           3         3        2   2
+--R                          - 370B C  + 504A B C  + (- 72B  - 1404A B)C
+--R                        + 
+--R                                 3       3        5     2 3      4
+--R                          (128A B  + 424A B)C + 2B  + 8A B  + 14A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6        5       2      2  4         2      3  3
+--R                      8C  - 40A C  + (24B  + 24A )C  + (24A B  + 72A )C
+--R                 *
+--R                     3 5
+--R                    a b
+--R                + 
+--R                                    5                       4
+--R                      (158C + 262A)D  + (- 842B C - 602A B)D
+--R                    + 
+--R                                3          2         2       2            2
+--R                            156C  - 2876A C  + (1688B  - 808A )C + 1080A B
+--R                          + 
+--R                                  3
+--R                            - 736A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                3           2          3        2             3
+--R                          - 4B C  + 540A B C  + (- 988B  - 2484A B)C + 1332A B
+--R                        + 
+--R                                3
+--R                          - 644A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5         4          2        2  3
+--R                          - 194C  + 414A C  + (- 360B  - 2216A )C
+--R                        + 
+--R                                 2        3  2        4        2 2       4
+--R                          (120A B  - 1200A )C  + (338B  + 2124A B  - 422A )C
+--R                        + 
+--R                                 4     3 2     5
+--R                          - 54A B  - 4A B  + 2A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4         3       2   3
+--R                      118B C  - 138A B C  + (- 12B  + 444A B)C
+--R                    + 
+--R                              3       3   2        5      2 3      4          5
+--R                      (- 76A B  - 292A B)C  + (- 2B  + 12A B  + 14A B)C - 2A B
+--R                    + 
+--R                          3 3      5
+--R                      - 4A B  - 18A B
+--R                 *
+--R                     4 4
+--R                    a b
+--R                + 
+--R                         6         5        2                2       2  4
+--R                      60D  - 264B D  + (240C  - 576A C + 356B  + 152A )D
+--R                    + 
+--R                              2                    3       2   3
+--R                      (1244B C  + 2472A B C - 1032B  + 596A B)D
+--R                    + 
+--R                                4          3           2        2  2
+--R                          - 520C  + 3168A C  + (- 1692B  + 1200A )C
+--R                        + 
+--R                                    2        3         4       2 2       4
+--R                          (- 2352A B  + 2152A )C - 148B  - 732A B  + 544A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3         3        2   2
+--R                          316B C  - 832A B C  + (1292B  + 3936A B)C
+--R                        + 
+--R                                    3       3          5        2 3       4
+--R                          (- 1224A B  + 384A B)C - 160B  - 1100A B  + 932A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6         5         2       2  4          2       3  3
+--R                      52C  - 104A C  + (- 60B  + 532A )C  + (104A B  + 520A )C
+--R                    + 
+--R                             4       2 2     4  2         4       3 2       5
+--R                      (- 108B  - 696A B  + 4A )C  + (16A B  + 176A B  + 128A )C
+--R                    + 
+--R                        6      2 4      4 2      6
+--R                      4B  + 12A B  + 12A B  - 44A
+--R                 *
+--R                     5 3
+--R                    a b
+--R                + 
+--R                                     5                     4
+--R                      (- 32C - 336A)D  + (576B C + 736A B)D
+--R                    + 
+--R                                  3         2          2       2           2
+--R                            - 672C  + 520A C  + (- 816B  - 768A )C - 432A B
+--R                          + 
+--R                                 3
+--R                            - 72A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3            2         3        2
+--R                          - 664B C  - 3024A B C  + (2416B  - 1800A B)C
+--R                        + 
+--R                                 3       3
+--R                          1712A B  - 496A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5          4        2       2  3
+--R                          360C  - 1680A C  + (608B  - 352A )C
+--R                        + 
+--R                                 2        3  2          4       2 2       4
+--R                          (984A B  - 1680A )C  + (- 528B  - 192A B  - 904A )C
+--R                        + 
+--R                                 4       3 2      5
+--R                          1088A B  - 120A B  - 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                              5           4          3        2   3
+--R                      - 192B C  + 344A B C  + (- 296B  - 1904A B)C
+--R                    + 
+--R                              3       3   2        5       2 3       4
+--R                      (- 16A B  + 288A B)C  + (144B  + 360A B  - 848A B)C
+--R                    + 
+--R                             5      3 3     5
+--R                      - 48A B  + 16A B  + 8A B
+--R                 *
+--R                     6 2
+--R                    a b
+--R                + 
+--R                           5          2                2       2  4
+--R                      64B D  + (- 144C  + 544A C - 256B  + 240A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 448B C  - 768A B C + 128B  - 192A B)D
+--R                    + 
+--R                              4         3        2       2  2
+--R                          480C  - 192A C  + (288B  + 768A )C
+--R                        + 
+--R                                 2      3         4       2 2      4
+--R                          (768A B  + 64A )C - 384B  + 480A B  + 32A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                   3           3       2   2
+--R                          1792A B C  + (- 1472B  + 384A B)C
+--R                        + 
+--R                                    3        3         5       2 3       4
+--R                          (- 1664A B  + 1280A B)C - 64B  - 576A B  - 256A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5       2      2  4         2       3  3
+--R                      - 80C  + 288A C  + (96B  + 80A )C  + (64A B  + 256A )C
+--R                    + 
+--R                           4       2 2       4  2            4      3 2      5
+--R                      (432B  + 768A B  + 464A )C  + (- 160A B  + 64A B  - 32A )C
+--R                    + 
+--R                            2 4       4 2      6
+--R                      - 144A B  + 288A B  + 48A
+--R                 *
+--R                     7
+--R                    a b
+--R                + 
+--R                                4
+--R                      - 256A B D
+--R                    + 
+--R                           3         2        2       2           2  3
+--R                      (128C  - 256A C  + (384B  - 128A )C + 256A B )D
+--R                    + 
+--R                               2       3          3       3   2
+--R                      (384A B C  - 256B C - 384A B  + 128A B)D
+--R                    + 
+--R                                5         4          2       2  3
+--R                          - 128C  + 128A C  + (- 128B  - 384A )C
+--R                        + 
+--R                               4       2 2           4       3 2       5
+--R                          (640B  - 384A B )C + 256A B  + 256A B  - 128A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4       2   3          3       3   2
+--R                      128B C  - 512A B C  + 512A B C  + (128A B  - 896A B)C
+--R                    + 
+--R                             5       4            5       3 3       5
+--R                      (- 256B  + 384A B)C + 128A B  - 128A B  - 128A B
+--R                 *
+--R                     8
+--R                    a
+--R             *
+--R                c
+--R            + 
+--R                      6        5        2              2      2  4
+--R                  - 8D  + 24B D  + (- 8C  + 48A C - 24B  - 72A )D
+--R                + 
+--R                       2               3      2   3
+--R                  (8B C  - 48A B C + 8B  + 72A B)D
+--R             *
+--R                 9
+--R                b
+--R            + 
+--R                               5                      4
+--R                  (32C + 128A)D  + (- 160B C - 64A B)D
+--R                + 
+--R                      3         2        2       2          2      3  3
+--R                  (48C  - 272A C  + (160B  + 368A )C - 64A B  + 48A )D
+--R                + 
+--R                          3           2         3       2     2
+--R                  (- 32B C  + 192A B C  + (- 32B  - 288A B)C)D
+--R             *
+--R                   8
+--R                a b
+--R            + 
+--R                     6         5       2                2       2  4
+--R                  12D  - 152B D  + (40C  - 896A C + 176B  - 160A )D
+--R                + 
+--R                         2                 3      2   3
+--R                  (400B C  + 432A B C - 72B  - 72A B)D
+--R                + 
+--R                            4         3          2       2  2
+--R                      - 100C  + 544A C  + (- 336B  - 672A )C
+--R                    + 
+--R                            2       3        4       2 2      4
+--R                      (48A B  - 176A )C + 36B  + 312A B  - 12A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                        4           3       3       2   2
+--R                  (40B C  - 240A B C  + (40B  + 360A B)C )D
+--R             *
+--R                 2 7
+--R                a b
+--R            + 
+--R                               5                     4
+--R                  (96C - 280A)D  + (752B C + 608A B)D
+--R                + 
+--R                         3          2          2       2           2       3  3
+--R                  (- 296C  + 2152A C  + (- 728B  + 816A )C - 504A B  + 432A )D
+--R                + 
+--R                           3            2        3       2            3  2
+--R                  (- 464B C  - 1008A B C  + (384B  + 240A B)C - 304A B )D
+--R                + 
+--R                         5         4        2       2  3          2       3  2
+--R                      88C  - 464A C  + (272B  + 520A )C  + (192A B  + 248A )C
+--R                    + 
+--R                            4       2 2      4        3 2      5
+--R                      (- 88B  - 744A B  - 32A )C - 40A B  + 24A
+--R                 *
+--R                    D
+--R                + 
+--R                         5          4         3       2   3
+--R                  - 16B C  + 96A B C  + (- 16B  - 144A B)C
+--R             *
+--R                 3 6
+--R                a b
+--R            + 
+--R                    6         5          2                2      2  4
+--R                  8D  + 220B D  + (- 524C  + 800A C - 320B  + 68A )D
+--R                + 
+--R                            2                   3        2   3
+--R                  (- 1368B C  - 2496A B C + 408B  - 1008A B)D
+--R                + 
+--R                          4          3         2        2  2
+--R                      464C  - 2480A C  + (1176B  - 1224A )C
+--R                    + 
+--R                              2        3        4       2 2       4
+--R                      (1728A B  - 1392A )C + 24B  + 576A B  - 296A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                            4            3          3       2   2
+--R                      220B C  + 1152A B C  + (- 600B  - 624A B)C
+--R                    + 
+--R                             3       3         5       2 3       4
+--R                      (448A B  + 304A B)C + 44B  + 512A B  - 188A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6         5         2       2  4            2       3  3
+--R                  - 28C  + 144A C  + (- 72B  - 140A )C  + (- 176A B  - 144A )C
+--R                + 
+--R                      4       2 2      4  2       3 2      5       2 4     4 2
+--R                  (52B  + 432A B  + 92A )C  + (32A B  - 64A )C - 4A B  + 8A B
+--R                + 
+--R                     6
+--R                  12A
+--R             *
+--R                 4 5
+--R                a b
+--R            + 
+--R                                  5                       4
+--R                  (- 120C + 416A)D  + (- 484B C - 532A B)D
+--R                + 
+--R                       3         2         2       2           2       3  3
+--R                  (968C  - 824A C  + (1144B  + 400A )C + 856A B  + 128A )D
+--R                + 
+--R                             3            2           3        2             3
+--R                      1144B C  + 3768A B C  + (- 1336B  + 2760A B)C - 1096A B
+--R                    + 
+--R                           3
+--R                      1112A B
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                            5          4          2       2  3
+--R                      - 320C  + 1464A C  + (- 912B  + 712A )C
+--R                    + 
+--R                                2        3  2        4       2 2       4
+--R                      (- 1968A B  + 1304A )C  + (176B  - 984A B  + 760A )C
+--R                    + 
+--R                              4       3 2      5
+--R                      - 584A B  - 232A B  - 80A
+--R                 *
+--R                    D
+--R                + 
+--R                         5           4        3       2   3
+--R                  - 20B C  - 516A B C  + (280B  + 488A B)C
+--R                + 
+--R                          3       3   2         5       2 3       4           5
+--R                  (- 88A B  - 360A B)C  + (- 52B  - 552A B  + 204A B)C + 12A B
+--R                + 
+--R                       3 3      5
+--R                  - 72A B  + 12A B
+--R             *
+--R                 5 4
+--R                a b
+--R            + 
+--R                       6         5        2                 2       2  4
+--R                  - 48D  - 200B D  + (240C  - 1096A C + 232B  - 472A )D
+--R                + 
+--R                         2                  3       2   3
+--R                  (136B C  + 720A B C - 112B  + 312A B)D
+--R                + 
+--R                            4         3           2        2  2
+--R                      - 904C  + 352A C  + (- 1416B  - 1152A )C
+--R                    + 
+--R                                2       3         4        2 2       4
+--R                      (- 2160A B  - 528A )C + 480B  - 1080A B  - 296A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                              4            3         3        2   2
+--R                      - 416B C  - 2688A B C  + (1512B  - 2208A B)C
+--R                    + 
+--R                              3        3          5       2 3       4
+--R                      (2224A B  - 2336A B)C + 152B  + 824A B  - 224A B
+--R                 *
+--R                    D
+--R                + 
+--R                     6         5        2       2  4          2       3  3
+--R                  88C  - 360A C  + (264B  - 176A )C  + (880A B  - 320A )C
+--R                + 
+--R                         4       2 2       4  2          4       3 2       5
+--R                  (- 248B  + 144A B  - 472A )C  + (504A B  + 416A B  + 104A )C
+--R                + 
+--R                    6       2 4       4 2      6
+--R                  8B  + 320A B  - 136A B  - 16A
+--R             *
+--R                 6 3
+--R                a b
+--R            + 
+--R                               5                     4
+--R                  (208C - 48A)D  + (432B C + 528A B)D
+--R                + 
+--R                         3          2          2       2           2       3  3
+--R                  (- 128C  + 1104A C  + (- 576B  + 704A )C - 544A B  + 112A )D
+--R                + 
+--R                         3          2        3       2            3       3   2
+--R                  (432B C  - 96A B C  + (160B  + 528A B)C + 320A B  - 160A B)D
+--R                + 
+--R                          5        4        2       2  3           2       3  2
+--R                      448C  - 48A C  + (768B  + 928A )C  + (1776A B  + 608A )C
+--R                    + 
+--R                            4        2 2       4           4       3 2       5
+--R                    (- 1168B  + 2112A B  + 352A )C - 752A B  + 272A B  + 400A
+--R                 *
+--R                    D
+--R                + 
+--R                       5           4          3       2   3
+--R                  16B C  + 960A B C  + (- 624B  + 224A B)C
+--R                + 
+--R                            3        3   2         5       2 3      4
+--R                  (- 1120A B  + 1440A B)C  + (- 16B  - 528A B  - 48A B)C
+--R                + 
+--R                          5       3 3      5
+--R                  - 336A B  - 160A B  + 96A B
+--R             *
+--R                 7 2
+--R                a b
+--R            + 
+--R                         2              2      2  4
+--R                  (- 288C  + 64A C - 64B  + 96A )D
+--R                + 
+--R                           2                  3       2   3
+--R                  (- 256B C  - 768A B C + 128B  - 384A B)D
+--R                + 
+--R                              3        2       2  2          2      3
+--R                      - 576A C  + (576B  - 192A )C  + (384A B  - 64A )C
+--R                    + 
+--R                          2 2      4
+--R                      192A B  + 64A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                              4           3        3       2   2
+--R                      - 384B C  - 384A B C  + (128B  - 768A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 512A B  - 128A B)C + 128B  - 256A B  - 128A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6          2       2  4            2       3  3
+--R                  - 96C  + (- 192B  - 224A )C  + (- 704A B  - 256A )C
+--R                + 
+--R                       4       2 2       4  2          4       3 2       5
+--R                  (736B  - 576A B  - 160A )C  + (576A B  - 448A B  - 256A )C
+--R                + 
+--R                     6       2 4       4 2      6
+--R                  64B  + 224A B  + 128A B  - 32A
+--R             *
+--R                 8
+--R                a b
+--R            + 
+--R                       3       2          2  3            2       3        3   2
+--R                  (128C  - 128A C + 256A B )D  + (384A B C  - 256B C + 128A B)D
+--R                + 
+--R                         4       2 3       2 2          4       5           5
+--R                  (128A C  - 128B C  - 384A B C + 256A B  - 128A )D + 128B C
+--R                + 
+--R                      2   3         3 2          5       4          3 3
+--R                  512A B C  + 128A B C  + (- 256B  + 384A B)C - 128A B
+--R             *
+--R                 9
+--R                a
+--R     + 
+--R             a
+--R          *
+--R             ROOT
+--R                             3 3      2 2      4  2       3 2      5        2 4
+--R                        - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c - 12a b
+--R                      + 
+--R                             4 2      6
+--R                        - 84a b  + 96a
+--R                   *
+--R                           2
+--R                      %%BN1
+--R                  + 
+--R                                3 3      2 2      4  2       3 2      5
+--R                            - 8a c  + (2a b  - 16a )c  + (40a b  + 32a )c
+--R                          + 
+--R                                2 4      4 2      6
+--R                            - 8a b  - 56a b  + 64a
+--R                       *
+--R                          %%BN0
+--R                      + 
+--R                            2 3            2        3  2
+--R                        8D a c  + (- 2D a b  + 16D a )c
+--R                      + 
+--R                                2 2        4           4        3 2        5
+--R                        (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                   *
+--R                      %%BN1
+--R                  + 
+--R                             3 3      2 2      4  2       3 2      5        2 4
+--R                        - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c - 12a b
+--R                      + 
+--R                             4 2      6
+--R                        - 84a b  + 96a
+--R                   *
+--R                           2
+--R                      %%BN0
+--R                  + 
+--R                            2 3            2        3  2
+--R                        8D a c  + (- 2D a b  + 16D a )c
+--R                      + 
+--R                                2 2        4           4        3 2        5
+--R                        (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                   *
+--R                      %%BN0
+--R                  + 
+--R                        2 2                          2     2  2  2
+--R                    (- D b  + 4C D a b + (- 8B D - 4C  - 4A )a )c
+--R                  + 
+--R                            2   2                               2
+--R                        - 4D a b  + ((20C + 4A)D + 4B C + 4A B)a b
+--R                      + 
+--R                           2             2             2     2  3
+--R                        (8D  - 16B D - 8C  + 16A C + 8B  - 8A )a
+--R                   *
+--R                      c
+--R                  + 
+--R                      2 4            3
+--R                    4D b  - 16C D a b
+--R                  + 
+--R                         2              2            2      2  2 2
+--R                    (- 8D  + 24B D + 12C  - 8A C - 4B  + 12A )a b
+--R                  + 
+--R                                                  3        2              2  4
+--R                  ((- 8C - 24A)D - 24B C - 24A B)a b + (16D  + 32A C + 16B )a
+--R               /
+--R                      3 3       2 2     4  2         3 2      5       2 4
+--R                    4a c  + (- a b  + 8a )c  + (- 20a b  - 16a )c + 4a b
+--R                  + 
+--R                       4 2      6
+--R                    28a b  - 32a
+--R         + 
+--R           - a %%BN1 - a %%BN0 + D
+--R      *
+--R         log
+--R                                 2 4 8
+--R                          - 32A D a c
+--R                        + 
+--R                                   2 3 2       3        2  4
+--R                              16A D a b  + (16D  + 16B D )a b
+--R                            + 
+--R                                       2                   2      3  5
+--R                              (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                         *
+--R                             7
+--R                            c
+--R                        + 
+--R                                    2 2 4        3       2  3 3
+--R                              - 2A D a b  + (- 8D  - 8B D )a b
+--R                            + 
+--R                                              2                  2      3  4 2
+--R                              ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                            + 
+--R                                     3        2
+--R                                  32D  - 32B D
+--R                                + 
+--R                                      2               2       2          2
+--R                                  (48C  - 224A C - 64B  - 144A )D - 16B C
+--R                                + 
+--R                                                 2
+--R                                  - 96A B C + 48A B
+--R                             *
+--R                                 5
+--R                                a b
+--R                            + 
+--R                                        2                 3         2      2
+--R                                  128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                                + 
+--R                                          2       3
+--R                                  - 128A B  - 128A
+--R                             *
+--R                                 6
+--R                                a
+--R                         *
+--R                             6
+--R                            c
+--R                        + 
+--R                                3      2  2 5
+--R                              (D  + B D )a b
+--R                            + 
+--R                                            2                2     3  3 4
+--R                              ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                            + 
+--R                                        3         2
+--R                                  - 160D  - 128B D
+--R                                + 
+--R                                        2               2      2         2
+--R                                  (- 24C  + 112A C + 32B  + 72A )D + 8B C
+--R                                + 
+--R                                               2
+--R                                  48A B C - 24A B
+--R                             *
+--R                                 4 3
+--R                                a b
+--R                            + 
+--R                                                 2                           3
+--R                                  (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                                + 
+--R                                          2       2      2           2       3
+--R                                  - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                             *
+--R                                 5 2
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 128D  - 256B D
+--R                                + 
+--R                                       2               2       2           2
+--R                                  (384C  - 512A C - 64B  - 384A )D + 128B C
+--R                                + 
+--R                                     3       2
+--R                                  64B  + 384A B
+--R                             *
+--R                                 6
+--R                                a b
+--R                            + 
+--R                                         2                  3         2       2
+--R                                  1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                                + 
+--R                                          2       3
+--R                                  - 512A B  + 128A
+--R                             *
+--R                                 7
+--R                                a
+--R                         *
+--R                             5
+--R                            c
+--R                        + 
+--R                                           2 2 6
+--R                              (- 2C + 22A)D a b
+--R                            + 
+--R                                     3        2      2             2     2
+--R                                  70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D
+--R                                + 
+--R                                       2              2
+--R                                  - B C  - 6A B C + 3A B
+--R                             *
+--R                                 3 5
+--R                                a b
+--R                            + 
+--R                                                 2                            3
+--R                                  (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                                + 
+--R                                        2         2      2          2       3
+--R                                  120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                             *
+--R                                 4 4
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  224D  + 800B D
+--R                                + 
+--R                                         2                 2        2          2
+--R                                  (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                                + 
+--R                                                3       2
+--R                                  672A B C - 64B  - 720A B
+--R                             *
+--R                                 5 3
+--R                                a b
+--R                            + 
+--R                                                   2
+--R                                  (- 160C - 2976A)D  + (- 576B C - 1088A B)D
+--R                                + 
+--R                                      3         2          2       2
+--R                                  608C  - 416A C  + (- 288B  - 992A )C
+--R                                + 
+--R                                         2      3
+--R                                  1120A B  + 32A
+--R                             *
+--R                                 6 2
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 256D  + 256B D
+--R                                + 
+--R                                       2                 2       2           2
+--R                                  (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                                + 
+--R                                                  3       2
+--R                                  1152A B C + 128B  + 192A B
+--R                             *
+--R                                 7
+--R                                a b
+--R                            + 
+--R                                        2                   3          2
+--R                                  512A D  - 4096A B D + 256C  - 1024A C
+--R                                + 
+--R                                        2          2        3
+--R                                  - 256A C + 512A B  + 1024A
+--R                             *
+--R                                 8
+--R                                a
+--R                         *
+--R                             4
+--R                            c
+--R                        + 
+--R                                   3       2  2 7
+--R                              (- 8D  - 8B D )a b
+--R                            + 
+--R                                                  2                      3
+--R                                  (- 141C + 755A)D  + (6B C - 58A B)D + C
+--R                                + 
+--R                                         2      2     2         2      3
+--R                                  - 13A C  + (3B  + 3A )C + 3A B  + 17A
+--R                             *
+--R                                 3 6
+--R                                a b
+--R                            + 
+--R                                      3        2
+--R                                  284D  + 36B D
+--R                                + 
+--R                                       2                2       2          2
+--R                                  (276C  - 888A C - 228B  - 588A )D - 12B C
+--R                                + 
+--R                                                  3       2
+--R                                  - 312A B C + 20B  + 276A B
+--R                             *
+--R                                 4 5
+--R                                a b
+--R                            + 
+--R                                                2
+--R                                  (32C + 2016A)D  + (- 192B C + 3072A B)D
+--R                                + 
+--R                                        3         2         2       2
+--R                                  - 320C  + 720A C  + (- 96B  + 192A )C
+--R                                + 
+--R                                          2       3
+--R                                  - 672A B  - 848A
+--R                             *
+--R                                 5 4
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  896D  + 384B D
+--R                                + 
+--R                                          2                 2       2
+--R                                  (- 1344C  - 1408A C - 896B  - 576A )D
+--R                                + 
+--R                                           2                   3        2
+--R                                  - 1088B C  - 1920A B C - 384B  - 1344A B
+--R                             *
+--R                                 6 3
+--R                                a b
+--R                            + 
+--R                                                 2
+--R                                  (640C - 4224A)D  + (- 768B C + 8448A B)D
+--R                                + 
+--R                                      3          2          2       2
+--R                                  128C  + 1920A C  + (- 384B  - 640A )C
+--R                                + 
+--R                                        2        3
+--R                                  128A B  - 2432A
+--R                             *
+--R                                 7 2
+--R                                a b
+--R                            + 
+--R                                      3          2
+--R                                  256D  + 1280B D
+--R                                + 
+--R                                          2                 2        2
+--R                                  (- 3072C  + 4096A C + 512B  + 3072A )D
+--R                                + 
+--R                                           2       3        2
+--R                                  - 1024B C  - 512B  - 3072A B
+--R                             *
+--R                                 8
+--R                                a b
+--R                            + 
+--R                                           2                    3         2
+--R                                  - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                                + 
+--R                                         2           2       3
+--R                                  - 2048A C + 4096A B  + 512A
+--R                             *
+--R                                 9
+--R                                a
+--R                         *
+--R                             3
+--R                            c
+--R                        + 
+--R                                          2 2 8
+--R                              (16C - 80A)D a b
+--R                            + 
+--R                                        3         2
+--R                                  - 146D  - 118B D
+--R                                + 
+--R                                        2               2      2         2
+--R                                  (- 30C  + 100A C + 26B  + 66A )D + 2B C
+--R                                + 
+--R                                              3      2
+--R                                  36A B C - 2B  - 30A B
+--R                             *
+--R                                 3 7
+--R                                a b
+--R                            + 
+--R                                                   2
+--R                                  (- 726C + 2090A)D  + (180B C - 1100A B)D
+--R                                + 
+--R                                     3         2       2      2           2
+--R                                  62C  - 230A C  + (90B  + 58A )C + 154A B
+--R                                + 
+--R                                      3
+--R                                  350A
+--R                             *
+--R                                 4 6
+--R                                a b
+--R                            + 
+--R                                         3          2
+--R                                  - 1752D  - 2760B D
+--R                                + 
+--R                                        2                 2        2           2
+--R                                  (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                                + 
+--R                                                   3        2
+--R                                  - 576A B C + 312B  + 2160A B
+--R                             *
+--R                                 5 5
+--R                                a b
+--R                            + 
+--R                                         2                              3
+--R                                  8160A D  + (4608B C - 5376A B)D - 864C
+--R                                + 
+--R                                          2         2        2           2
+--R                                  - 192A C  + (2304B  + 3936A )C - 960A B
+--R                                + 
+--R                                       3
+--R                                  3264A
+--R                             *
+--R                                 6 4
+--R                                a b
+--R                            + 
+--R                                         3          2
+--R                                  - 1152D  - 4224B D
+--R                                + 
+--R                                        2                   2        2
+--R                                  (5760C  - 11520A C - 2304B  - 8064A )D
+--R                                + 
+--R                                         2                   3        2
+--R                                  1152B C  - 2304A B C + 768B  + 5760A B
+--R                             *
+--R                                 7 3
+--R                                a b
+--R                            + 
+--R                                                  2
+--R                                  (2816C + 4352A)D  + (4608B C + 7680A B)D
+--R                                + 
+--R                                         3          2         2        2
+--R                                  - 3840C  + 3072A C  + (2304B  + 6912A )C
+--R                                + 
+--R                                           2
+--R                                  - 6912A B
+--R                             *
+--R                                 8 2
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  512D  - 512B D
+--R                                + 
+--R                                          2                  2       2
+--R                                  (- 3840C  - 2560A C - 2048B  - 768A )D
+--R                                + 
+--R                                           2                    3        2
+--R                                  - 2816B C  - 4608A B C - 1024B  - 3840A B
+--R                             *
+--R                                 9
+--R                                a b
+--R                            + 
+--R                                           2                    3          2
+--R                                  - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                                + 
+--R                                         2           2        3
+--R                                  - 1024A C + 2048A B  - 2048A
+--R                             *
+--R                                 10
+--R                                a
+--R                         *
+--R                             2
+--R                            c
+--R                        + 
+--R                                  3        2  2 9
+--R                              (16D  + 16B D )a b
+--R                            + 
+--R                                                2                           3
+--R                                  (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                                + 
+--R                                       2         2      2          2      3
+--R                                  20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                             *
+--R                                 3 8
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  456D  + 920B D
+--R                                + 
+--R                                         2                 2        2
+--R                                  (- 744C  + 1712A C + 376B  + 1176A )D
+--R                                + 
+--R                                          2                 3       2
+--R                                  - 104B C  + 432A B C - 88B  - 744A B
+--R                             *
+--R                                 4 7
+--R                                a b
+--R                            + 
+--R                                                  2
+--R                                  (1668C - 8316A)D  + (- 1656B C + 136A B)D
+--R                                + 
+--R                                      3         2          2        2
+--R                                  364C  - 380A C  + (- 828B  - 1468A )C
+--R                                + 
+--R                                        2       3
+--R                                  452A B  - 724A
+--R                             *
+--R                                 5 6
+--R                                a b
+--R                            + 
+--R                                       3          2
+--R                                  2496D  + 6432B D
+--R                                + 
+--R                                          2                   2        2
+--R                                  (- 5328C  + 14304A C + 3408B  + 9648A )D
+--R                                + 
+--R                                          2                   3        2
+--R                                  - 336B C  + 4320A B C - 528B  - 5328A B
+--R                             *
+--R                                 6 5
+--R                                a b
+--R                            + 
+--R                                                    2
+--R                                  (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                                + 
+--R                                       3          2           2         2
+--R                                  3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                                + 
+--R                                         2        3
+--R                                  4224A B  - 2976A
+--R                             *
+--R                                 7 4
+--R                                a b
+--R                            + 
+--R                                         3         2
+--R                                  - 1024D  + 512B D
+--R                                + 
+--R                                        2                  2        2
+--R                                  (5760C  + 3840A C + 3072B  + 1152A )D
+--R                                + 
+--R                                         2                    3        2
+--R                                  4224B C  + 6912A B C + 1536B  + 5760A B
+--R                             *
+--R                                 8 3
+--R                                a b
+--R                            + 
+--R                                                    2
+--R                                  (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                                + 
+--R                                         3          2        2        2
+--R                                  - 1280C  - 2816A C  + (768B  + 2304A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 2304A B  + 3840A
+--R                             *
+--R                                 9 2
+--R                                a b
+--R                            + 
+--R                                           2
+--R                                  - 2048B D
+--R                                + 
+--R                                        2                  2        2
+--R                                  (6144C  - 8192A C - 1024B  - 6144A )D
+--R                                + 
+--R                                         2        3        2
+--R                                  2048B C  + 1024B  + 6144A B
+--R                             *
+--R                                 10
+--R                                a  b
+--R                            + 
+--R                                                   3          2        2
+--R                                  8192A B D - 4096C  + 2048A C  + 4096A C
+--R                                + 
+--R                                           2        3
+--R                                  - 8192A B  - 2048A
+--R                             *
+--R                                 11
+--R                                a
+--R                         *
+--R                            c
+--R                        + 
+--R                                        2 2 10
+--R                          (- 32C + 96A)D a b
+--R                        + 
+--R                                   3        2       2               2       2
+--R                              - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                            + 
+--R                                  2               3      2
+--R                              8B C  - 48A B C + 8B  + 72A B
+--R                         *
+--R                             3 9
+--R                            a b
+--R                        + 
+--R                                               2                           3
+--R                              (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                            + 
+--R                                   2       2       2          2      3
+--R                              72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                         *
+--R                             4 8
+--R                            a b
+--R                        + 
+--R                                    3          2
+--R                              - 360D  - 1080B D
+--R                            + 
+--R                                   2                 2        2          2
+--R                              (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                            + 
+--R                                              3       2
+--R                              - 816A B C + 88B  + 936A B
+--R                         *
+--R                             5 7
+--R                            a b
+--R                        + 
+--R                                            2                              3
+--R                              (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                            + 
+--R                                     2         2        2           2       3
+--R                              1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                         *
+--R                             6 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 3456B D
+--R                            + 
+--R                                    2                  2        2           2
+--R                              (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                            + 
+--R                                               3        2
+--R                              - 3744A B C - 96B  + 1296A B
+--R                         *
+--R                             7 5
+--R                            a b
+--R                        + 
+--R                                              2                              3
+--R                              (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                            + 
+--R                                     2         2        2           2        3
+--R                              3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                         *
+--R                             8 4
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1536D  + 4608B D
+--R                            + 
+--R                                       2                   2        2
+--R                              (- 11520C  + 12800A C + 1024B  + 9984A )D
+--R                            + 
+--R                                       2                    3         2
+--R                              - 4352B C  - 1536A B C - 2048B  - 11520A B
+--R                         *
+--R                             9 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              5632C  - 4608A C  + (- 4608B  - 11776A )C
+--R                            + 
+--R                                     2        3
+--R                              9728A B  - 1536A
+--R                         *
+--R                             10 2
+--R                            a  b
+--R                        + 
+--R                                    2                  2        2            2
+--R                              (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                            + 
+--R                                               3        2
+--R                              6144A B C + 2048B  + 9216A B
+--R                         *
+--R                             11
+--R                            a  b
+--R                        + 
+--R                                  3        2           2  12
+--R                          (- 4096C  + 4096A C - 8192A B )a
+--R                     *
+--R                        %%BN0
+--R                    + 
+--R                           3 3 8
+--R                      16A D a c
+--R                    + 
+--R                                3 2 2          3          2  3
+--R                          - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                        + 
+--R                                         3          2         2      3    4
+--R                          ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                               3         2  2 3
+--R                          (2B D  + 6A C D )a b
+--R                        + 
+--R                                             3                   2
+--R                                (12C - 188A)D  + (12B C + 52A B)D
+--R                              + 
+--R                                     2      3
+--R                                (4A C  - 12A )D
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                 4        3       2              2       2  2
+--R                              24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                            + 
+--R                                     2                2          3     3
+--R                              (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                            3                    2
+--R                              (- 64C - 32A)D  + (96B C - 320A B)D
+--R                            + 
+--R                                    3        2       2          2      3
+--R                              (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                            + 
+--R                                       2      3
+--R                              - 48A B C  - 16A B
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                           3                   2
+--R                              (- 2C + 41A)D  + (- 3B C - 8A B)D
+--R                            + 
+--R                                     2     3
+--R                              (- 2A C  + 2A )D
+--R                         *
+--R                             2 4
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 14D  + 80B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 18C  + 224A C - 26B  - 66A )D
+--R                            + 
+--R                                     2                2          3     3
+--R                              (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                            3                       2
+--R                              (144C - 232A)D  + (- 120B C + 808A B)D
+--R                            + 
+--R                                    3         2         2      2           2
+--R                                  4C  - 212A C  + (- 24B  + 20A )C - 112A B
+--R                                + 
+--R                                        3
+--R                                  - 196A
+--R                             *
+--R                                D
+--R                            + 
+--R                                  3          2      2        3
+--R                              4B C  + 36A B C  - 12A B C + 4A B
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                 4        3       2              2       2  2
+--R                              64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                            + 
+--R                                      2                3       2        4
+--R                              (- 80B C  + 96A B C - 64B  - 336A B)D + 8C
+--R                            + 
+--R                                   3       2      2  2         2      3
+--R                              32A C  + (24B  + 48A )C  + (48A B  + 32A )C
+--R                            + 
+--R                                 2 2     4
+--R                              24A B  + 8A
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                      3                     2
+--R                              - 384A D  + (384B C + 128A B)D
+--R                            + 
+--R                                    3         2          2       2           2
+--R                              (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                            + 
+--R                                   3           2       2           3      3
+--R                              64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                4        3      2             2     2  2
+--R                              2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                            + 
+--R                                  2              2
+--R                              (B C  + 6A B C - 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                            + 
+--R                                 3       2       2      2          2       3
+--R                              (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                            + 
+--R                                   3         2     2
+--R                              - B C  - 6A B C  + 3A B C
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    4        3
+--R                              - 224D  + 92B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 162C  - 280A C - 320B  - 1206A )D
+--R                            + 
+--R                                     2                 3       2        4
+--R                              (172B C  - 336A B C + 60B  + 492A B)D - 6C
+--R                            + 
+--R                                   3         2      2  2           2      3
+--R                              48A C  + (- 18B  - 24A )C  + (- 24A B  - 80A )C
+--R                            + 
+--R                                  2 2     4
+--R                              - 6A B  - 2A
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             3                       2
+--R                              (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                            + 
+--R                                      3         2        2        2            2
+--R                                  208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                                + 
+--R                                     3
+--R                                  64A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3           2         3       2           3
+--R                              - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                            + 
+--R                                  3
+--R                              144A B
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                   4         3
+--R                              - 64D  - 256B D
+--R                            + 
+--R                                     2               2       2  2
+--R                              (- 144C  - 608A C + 32B  - 336A )D
+--R                            + 
+--R                                      2      3       2         4        3
+--R                              (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                            + 
+--R                                    2      2  2         2       3        4
+--R                              (- 48B  - 96A )C  + (96A B  - 224A )C + 32B
+--R                            + 
+--R                                  2 2      4
+--R                              144A B  + 16A
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                            3            2
+--R                              (256C - 256A)D  + 1792A B D
+--R                            + 
+--R                                       3         2          2      2           2
+--R                                  - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                                + 
+--R                                        3
+--R                                  - 256A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3       2            3
+--R                              256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                            + 
+--R                                   3
+--R                              - 64A B
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                           3                   2
+--R                              (13C - 139A)D  + (18B C + 58A B)D
+--R                            + 
+--R                                  3        2        2     2         2      3
+--R                              (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              109D  - 265B D
+--R                            + 
+--R                                   2                2       2  2
+--R                              (114C  - 591A C + 183B  + 543A )D
+--R                            + 
+--R                                      2                 3       2       4
+--R                              (- 27B C  + 228A B C - 19B  - 225A B)D + C
+--R                            + 
+--R                                     3      2     2  2        2      3
+--R                              - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                            + 
+--R                                       3         2         2       2           2
+--R                                  - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                                + 
+--R                                      3
+--R                                  346A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2       3       2          3
+--R                              10B C  - 234A B C  + (14B  + 174A B)C - 2A B
+--R                            + 
+--R                                   3
+--R                              - 30A B
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    3        2               2       2  2
+--R                              768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                            + 
+--R                                     2                 3        2            3
+--R                              (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                            + 
+--R                                    2       2  2            2       3        4
+--R                              (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                            + 
+--R                                    2 2      4
+--R                              - 240A B  - 64A
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               3                        2
+--R                              (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                            + 
+--R                                      3         2         2        2           2
+--R                                  416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                                + 
+--R                                      3
+--R                                  992A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3        2
+--R                              - 480B C  + 672A B C  + (- 128B  - 1632A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  + 160A B
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 256D  + 384B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (192C  - 1024A C + 256B  - 2112A )D
+--R                            + 
+--R                                     2                  3        2          4
+--R                              (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                            + 
+--R                                     2       2  2            2       3
+--R                              (- 576B  - 384A )C  + (- 384A B  - 512A )C
+--R                            + 
+--R                                  2 2      4
+--R                              192A B  + 64A
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                            3                         2
+--R                              (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                            + 
+--R                                     2        2           2       3         3
+--R                            (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                   4        3
+--R                              - 14D  + 54B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 18C  + 140A C - 26B  - 66A )D
+--R                            + 
+--R                                     2               3      2
+--R                              (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                            3                      2
+--R                              (142C - 688A)D  + (- 54B C + 800A B)D
+--R                            + 
+--R                                      3         2         2      2           2
+--R                                  - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                                + 
+--R                                        3
+--R                                  - 248A
+--R                             *
+--R                                D
+--R                            + 
+--R                                  3          2        3      2
+--R                              2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              416D  - 190B D
+--R                            + 
+--R                                  2                 2        2  2
+--R                              (84C  + 1254A C + 438B  + 2514A )D
+--R                            + 
+--R                                       2                  3        2         4
+--R                              (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                            + 
+--R                                     3       2       2  2          2       3
+--R                              - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C
+--R                            + 
+--R                                4      2 2      4
+--R                              2B  + 48A B  + 14A
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                            + 
+--R                                        3        2           2        2
+--R                                  - 788C  - 84A C  + (- 2292B  - 4428A )C
+--R                                + 
+--R                                         2        3
+--R                                  1404A B  - 2252A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3        2            3
+--R                              532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                            + 
+--R                                    3
+--R                              - 308A B
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              608D  - 640B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 240C  + 3552A C - 960B  + 5232A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 1632B C  - 1536A B C - 928B  - 1632A B)D
+--R                            + 
+--R                                  4         3        2        2  2
+--R                              464C  + 128A C  + (912B  + 1344A )C
+--R                            + 
+--R                                     2        3         4       2 2      4
+--R                              (384A B  + 1664A )C - 160B  - 528A B  - 16A
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                3                       2
+--R                              (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                            + 
+--R                                        3         2        2        2
+--R                                  - 128C  - 576A C  + (192B  - 6144A )C
+--R                                + 
+--R                                         2       3
+--R                                  4800A B  - 704A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2          3       2
+--R                              256B C  + 768A B C  + (- 704B  - 384A B)C
+--R                            + 
+--R                                    3       3
+--R                              448A B  - 128A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 128D  + 1280B D
+--R                            + 
+--R                                   2                 2       2  2
+--R                              (768C  + 2560A C - 640B  - 768A )D
+--R                            + 
+--R                                     2                   2          4         3
+--R                              (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                            + 
+--R                                     2       2  2            2       3         4
+--R                              (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 128A
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                    3                         2
+--R                              512A D  + (- 1536B C - 2048A B)D
+--R                            + 
+--R                                        3          2         2        2
+--R                                    256C  - 2048A C  + (3072B  + 1792A )C
+--R                                  + 
+--R                                             2
+--R                                    - 2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3           2        2             3
+--R                              - 1024B C  + 768A B C  - 3072A B C + 1024A B
+--R                            + 
+--R                                  3
+--R                              256A B
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                             3                      2
+--R                              (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                            + 
+--R                                 3        2       2      2          2      3
+--R                              (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 204D  + 316B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 144C  + 364A C - 292B  - 1092A )D
+--R                            + 
+--R                                     2                 3       2        4
+--R                              (164B C  - 288A B C + 84B  + 636A B)D - 4C
+--R                            + 
+--R                                   3         2      2  2           2      3
+--R                              20A C  + (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                            3                         2
+--R                              (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                            + 
+--R                                      3          2        2        2           2
+--R                                  428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                                + 
+--R                                      3
+--R                                  996A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2         3       2          3
+--R                              - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                            + 
+--R                                 3
+--R                              56A B
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 924D  - 588B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (216C  - 5556A C - 60B  - 6156A )D
+--R                            + 
+--R                                      2                   3        2          4
+--R                              (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                            + 
+--R                                    3          2       2  2         2        3
+--R                              708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                            + 
+--R                                 4       2 2       4
+--R                              72B  + 576A B  + 120A
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                            + 
+--R                                      3          2        2        2
+--R                                  408C  + 2760A C  + (504B  + 9096A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 3720A B  + 2904A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3            2        3       2
+--R                              - 840B C  - 1656A B C  + (168B  + 360A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 792A B  + 408A B
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              480D  - 1536B D
+--R                            + 
+--R                                     2                  2        2  2
+--R                              (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                            + 
+--R                                        2                  3        2          4
+--R                              (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                            + 
+--R                                      3        2        2  2
+--R                              - 864A C  + (576B  - 2304A )C
+--R                            + 
+--R                                      2        3         4       2 2       4
+--R                              (1152A B  - 2208A )C + 576B  + 576A B  - 384A
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                               3                       2
+--R                              (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                            + 
+--R                                         3          2           2        2
+--R                                  - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                                + 
+--R                                         2        3
+--R                                  2304A B  - 1344A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3            2        2             3
+--R                              1344B C  - 1728A B C  + 5184A B C - 1536A B
+--R                            + 
+--R                                    3
+--R                              - 192A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                    3           2                  2        2  2
+--R                              512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                            + 
+--R                                        2                   2          4
+--R                              (- 1280B C  - 4608A B C + 768A B)D + 640C
+--R                            + 
+--R                                      3         2       2  2
+--R                              - 512A C  + (1920B  + 768A )C
+--R                            + 
+--R                                     2        3          2 2       4
+--R                              (768A B  + 1536A )C - 1152A B  - 384A
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                         2
+--R                              - 2048A B D
+--R                            + 
+--R                                       3          2         2        2
+--R                                  1024C  - 2048A C  + (3072B  - 1024A )C
+--R                                + 
+--R                                         2
+--R                                  2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3            2           3        2
+--R                              - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                            + 
+--R                                     3        3
+--R                              1024A B  + 1024A B
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                             4        3       2               2       2  2
+--R                          24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 8C - 336A)D  + (216B C + 96A B)D
+--R                        + 
+--R                                   3         2          2       2          2
+--R                              - 56C  + 240A C  + (- 120B  - 184A )C + 80A B
+--R                            + 
+--R                                   3
+--R                              - 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2      3      2
+--R                          8B C  - 48A B C  + (8B  + 72A B)C
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              4         3       2               2        2  2
+--R                          216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                        + 
+--R                                   2                3       2         4
+--R                          (- 304B C  - 48A B C - 64B  - 384A B)D + 32C
+--R                        + 
+--R                                  3       2      2  2           2       3
+--R                          - 120A C  + (72B  + 24A )C  + (- 24A B  + 152A )C
+--R                        + 
+--R                              4      2 2      4
+--R                          - 8B  - 96A B  - 24A
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                        + 
+--R                                    3          2          2        2           2
+--R                              - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                            + 
+--R                                    3
+--R                              - 864A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2      3       2            3      3
+--R                        120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          144D  + 1848B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 576C  + 6600A C - 984B  + 1800A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                        + 
+--R                                  3        2       2  2            2        3
+--R                          - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 120B  - 576A B  - 72A
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                        + 
+--R                                   3          2         2        2           2
+--R                              1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                            + 
+--R                                    3
+--R                              - 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2          3        2             3
+--R                          384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                        + 
+--R                                3
+--R                          - 240A B
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 384D  - 1600B D
+--R                        + 
+--R                                2                  2        2  2
+--R                          (2784C  - 7040A C + 1280B  - 3936A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                        + 
+--R                                 3           2        2  2
+--R                          2304A C  + (- 2592B  + 1152A )C
+--R                        + 
+--R                                    2       3         4        2 2       4
+--R                          (- 1152A B  - 768A )C - 384B  + 1440A B  + 864A
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1792C  + 5376A C  + (- 2688B  + 5632A )C
+--R                            + 
+--R                                       2        3
+--R                              - 3200A B  + 1536A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2         3        2
+--R                          - 512B C  - 6144A B C  + (2176B  + 2304A B)C
+--R                        + 
+--R                                   3       3
+--R                          - 1152A B  - 768A B
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                2       2  2
+--R                          (- 2304C  + 512A C - 512B  + 768A )D
+--R                        + 
+--R                                    2                    3        2          4
+--R                          (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                        + 
+--R                                   3         2        2  2           2       3
+--R                          - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          512B  - 768A B  - 768A
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                                3        2           2              2        3
+--R                          (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                        + 
+--R                               3
+--R                          1024A B
+--R                     *
+--R                         11
+--R                        a
+--R                 *
+--R                    %%BN1
+--R                + 
+--R                           3 3 8
+--R                      16A D a c
+--R                    + 
+--R                                3 2 2          3          2  3
+--R                          - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                        + 
+--R                                         3          2         2      3    4
+--R                          ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                               3         2  2 3
+--R                          (2B D  + 6A C D )a b
+--R                        + 
+--R                                             3                   2
+--R                                (12C - 188A)D  + (12B C + 52A B)D
+--R                              + 
+--R                                     2      3
+--R                                (4A C  - 12A )D
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                 4        3       2              2       2  2
+--R                              24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                            + 
+--R                                     2                2          3     3
+--R                              (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                            3                    2
+--R                              (- 64C - 32A)D  + (96B C - 320A B)D
+--R                            + 
+--R                                    3        2       2          2      3
+--R                              (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                            + 
+--R                                       2      3
+--R                              - 48A B C  - 16A B
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                           3                   2
+--R                              (- 2C + 41A)D  + (- 3B C - 8A B)D
+--R                            + 
+--R                                     2     3
+--R                              (- 2A C  + 2A )D
+--R                         *
+--R                             2 4
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 14D  + 80B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 18C  + 224A C - 26B  - 66A )D
+--R                            + 
+--R                                     2                2          3     3
+--R                              (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                            3                       2
+--R                              (144C - 232A)D  + (- 120B C + 808A B)D
+--R                            + 
+--R                                    3         2         2      2           2
+--R                                  4C  - 212A C  + (- 24B  + 20A )C - 112A B
+--R                                + 
+--R                                        3
+--R                                  - 196A
+--R                             *
+--R                                D
+--R                            + 
+--R                                  3          2      2        3
+--R                              4B C  + 36A B C  - 12A B C + 4A B
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                 4        3       2              2       2  2
+--R                              64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                            + 
+--R                                      2                3       2        4
+--R                              (- 80B C  + 96A B C - 64B  - 336A B)D + 8C
+--R                            + 
+--R                                   3       2      2  2         2      3
+--R                              32A C  + (24B  + 48A )C  + (48A B  + 32A )C
+--R                            + 
+--R                                 2 2     4
+--R                              24A B  + 8A
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                      3                     2
+--R                              - 384A D  + (384B C + 128A B)D
+--R                            + 
+--R                                    3         2          2       2           2
+--R                              (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                            + 
+--R                                   3           2       2           3      3
+--R                              64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                4        3      2             2     2  2
+--R                              2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                            + 
+--R                                  2              2
+--R                              (B C  + 6A B C - 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                            + 
+--R                                 3       2       2      2          2       3
+--R                              (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                            + 
+--R                                   3         2     2
+--R                              - B C  - 6A B C  + 3A B C
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    4        3
+--R                              - 224D  + 92B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 162C  - 280A C - 320B  - 1206A )D
+--R                            + 
+--R                                     2                 3       2        4
+--R                              (172B C  - 336A B C + 60B  + 492A B)D - 6C
+--R                            + 
+--R                                   3         2      2  2           2      3
+--R                              48A C  + (- 18B  - 24A )C  + (- 24A B  - 80A )C
+--R                            + 
+--R                                  2 2     4
+--R                              - 6A B  - 2A
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             3                       2
+--R                              (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                            + 
+--R                                      3         2        2        2            2
+--R                                  208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                                + 
+--R                                     3
+--R                                  64A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3           2         3       2           3
+--R                              - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                            + 
+--R                                  3
+--R                              144A B
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                   4         3
+--R                              - 64D  - 256B D
+--R                            + 
+--R                                     2               2       2  2
+--R                              (- 144C  - 608A C + 32B  - 336A )D
+--R                            + 
+--R                                      2      3       2         4        3
+--R                              (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                            + 
+--R                                    2      2  2         2       3        4
+--R                              (- 48B  - 96A )C  + (96A B  - 224A )C + 32B
+--R                            + 
+--R                                  2 2      4
+--R                              144A B  + 16A
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                            3            2
+--R                              (256C - 256A)D  + 1792A B D
+--R                            + 
+--R                                       3         2          2      2           2
+--R                                  - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                                + 
+--R                                        3
+--R                                  - 256A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3       2            3
+--R                              256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                            + 
+--R                                   3
+--R                              - 64A B
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                           3                   2
+--R                              (13C - 139A)D  + (18B C + 58A B)D
+--R                            + 
+--R                                  3        2        2     2         2      3
+--R                              (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              109D  - 265B D
+--R                            + 
+--R                                   2                2       2  2
+--R                              (114C  - 591A C + 183B  + 543A )D
+--R                            + 
+--R                                      2                 3       2       4
+--R                              (- 27B C  + 228A B C - 19B  - 225A B)D + C
+--R                            + 
+--R                                     3      2     2  2        2      3
+--R                              - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                            + 
+--R                                       3         2         2       2           2
+--R                                  - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                                + 
+--R                                      3
+--R                                  346A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2       3       2          3
+--R                              10B C  - 234A B C  + (14B  + 174A B)C - 2A B
+--R                            + 
+--R                                   3
+--R                              - 30A B
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    3        2               2       2  2
+--R                              768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                            + 
+--R                                     2                 3        2            3
+--R                              (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                            + 
+--R                                    2       2  2            2       3        4
+--R                              (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                            + 
+--R                                    2 2      4
+--R                              - 240A B  - 64A
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               3                        2
+--R                              (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                            + 
+--R                                      3         2         2        2           2
+--R                                  416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                                + 
+--R                                      3
+--R                                  992A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3        2
+--R                              - 480B C  + 672A B C  + (- 128B  - 1632A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  + 160A B
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 256D  + 384B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (192C  - 1024A C + 256B  - 2112A )D
+--R                            + 
+--R                                     2                  3        2          4
+--R                              (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                            + 
+--R                                     2       2  2            2       3
+--R                              (- 576B  - 384A )C  + (- 384A B  - 512A )C
+--R                            + 
+--R                                  2 2      4
+--R                              192A B  + 64A
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                            3                         2
+--R                              (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                            + 
+--R                                     2        2           2       3         3
+--R                            (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                   4        3
+--R                              - 14D  + 54B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 18C  + 140A C - 26B  - 66A )D
+--R                            + 
+--R                                     2               3      2
+--R                              (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                            3                      2
+--R                              (142C - 688A)D  + (- 54B C + 800A B)D
+--R                            + 
+--R                                      3         2         2      2           2
+--R                                  - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                                + 
+--R                                        3
+--R                                  - 248A
+--R                             *
+--R                                D
+--R                            + 
+--R                                  3          2        3      2
+--R                              2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              416D  - 190B D
+--R                            + 
+--R                                  2                 2        2  2
+--R                              (84C  + 1254A C + 438B  + 2514A )D
+--R                            + 
+--R                                       2                  3        2         4
+--R                              (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                            + 
+--R                                     3       2       2  2          2       3
+--R                              - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C
+--R                            + 
+--R                                4      2 2      4
+--R                              2B  + 48A B  + 14A
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                            + 
+--R                                        3        2           2        2
+--R                                  - 788C  - 84A C  + (- 2292B  - 4428A )C
+--R                                + 
+--R                                         2        3
+--R                                  1404A B  - 2252A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3        2            3
+--R                              532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                            + 
+--R                                    3
+--R                              - 308A B
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              608D  - 640B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 240C  + 3552A C - 960B  + 5232A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 1632B C  - 1536A B C - 928B  - 1632A B)D
+--R                            + 
+--R                                  4         3        2        2  2
+--R                              464C  + 128A C  + (912B  + 1344A )C
+--R                            + 
+--R                                     2        3         4       2 2      4
+--R                              (384A B  + 1664A )C - 160B  - 528A B  - 16A
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                3                       2
+--R                              (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                            + 
+--R                                        3         2        2        2
+--R                                  - 128C  - 576A C  + (192B  - 6144A )C
+--R                                + 
+--R                                         2       3
+--R                                  4800A B  - 704A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2          3       2
+--R                              256B C  + 768A B C  + (- 704B  - 384A B)C
+--R                            + 
+--R                                    3       3
+--R                              448A B  - 128A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 128D  + 1280B D
+--R                            + 
+--R                                   2                 2       2  2
+--R                              (768C  + 2560A C - 640B  - 768A )D
+--R                            + 
+--R                                     2                   2          4         3
+--R                              (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                            + 
+--R                                     2       2  2            2       3         4
+--R                              (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 128A
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                    3                         2
+--R                              512A D  + (- 1536B C - 2048A B)D
+--R                            + 
+--R                                        3          2         2        2
+--R                                    256C  - 2048A C  + (3072B  + 1792A )C
+--R                                  + 
+--R                                             2
+--R                                    - 2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3           2        2             3
+--R                              - 1024B C  + 768A B C  - 3072A B C + 1024A B
+--R                            + 
+--R                                  3
+--R                              256A B
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                             3                      2
+--R                              (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                            + 
+--R                                 3        2       2      2          2      3
+--R                              (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 204D  + 316B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 144C  + 364A C - 292B  - 1092A )D
+--R                            + 
+--R                                     2                 3       2        4
+--R                              (164B C  - 288A B C + 84B  + 636A B)D - 4C
+--R                            + 
+--R                                   3         2      2  2           2      3
+--R                              20A C  + (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                            3                         2
+--R                              (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                            + 
+--R                                      3          2        2        2           2
+--R                                  428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                                + 
+--R                                      3
+--R                                  996A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2         3       2          3
+--R                              - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                            + 
+--R                                 3
+--R                              56A B
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 924D  - 588B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (216C  - 5556A C - 60B  - 6156A )D
+--R                            + 
+--R                                      2                   3        2          4
+--R                              (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                            + 
+--R                                    3          2       2  2         2        3
+--R                              708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                            + 
+--R                                 4       2 2       4
+--R                              72B  + 576A B  + 120A
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                            + 
+--R                                      3          2        2        2
+--R                                  408C  + 2760A C  + (504B  + 9096A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 3720A B  + 2904A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3            2        3       2
+--R                              - 840B C  - 1656A B C  + (168B  + 360A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 792A B  + 408A B
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              480D  - 1536B D
+--R                            + 
+--R                                     2                  2        2  2
+--R                              (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                            + 
+--R                                        2                  3        2          4
+--R                              (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                            + 
+--R                                      3        2        2  2
+--R                              - 864A C  + (576B  - 2304A )C
+--R                            + 
+--R                                      2        3         4       2 2       4
+--R                              (1152A B  - 2208A )C + 576B  + 576A B  - 384A
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                               3                       2
+--R                              (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                            + 
+--R                                         3          2           2        2
+--R                                  - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                                + 
+--R                                         2        3
+--R                                  2304A B  - 1344A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3            2        2             3
+--R                              1344B C  - 1728A B C  + 5184A B C - 1536A B
+--R                            + 
+--R                                    3
+--R                              - 192A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                    3           2                  2        2  2
+--R                              512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                            + 
+--R                                        2                   2          4
+--R                              (- 1280B C  - 4608A B C + 768A B)D + 640C
+--R                            + 
+--R                                      3         2       2  2
+--R                              - 512A C  + (1920B  + 768A )C
+--R                            + 
+--R                                     2        3          2 2       4
+--R                              (768A B  + 1536A )C - 1152A B  - 384A
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                         2
+--R                              - 2048A B D
+--R                            + 
+--R                                       3          2         2        2
+--R                                  1024C  - 2048A C  + (3072B  - 1024A )C
+--R                                + 
+--R                                         2
+--R                                  2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3            2           3        2
+--R                              - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                            + 
+--R                                     3        3
+--R                              1024A B  + 1024A B
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                             4        3       2               2       2  2
+--R                          24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 8C - 336A)D  + (216B C + 96A B)D
+--R                        + 
+--R                                   3         2          2       2          2
+--R                              - 56C  + 240A C  + (- 120B  - 184A )C + 80A B
+--R                            + 
+--R                                   3
+--R                              - 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2      3      2
+--R                          8B C  - 48A B C  + (8B  + 72A B)C
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              4         3       2               2        2  2
+--R                          216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                        + 
+--R                                   2                3       2         4
+--R                          (- 304B C  - 48A B C - 64B  - 384A B)D + 32C
+--R                        + 
+--R                                  3       2      2  2           2       3
+--R                          - 120A C  + (72B  + 24A )C  + (- 24A B  + 152A )C
+--R                        + 
+--R                              4      2 2      4
+--R                          - 8B  - 96A B  - 24A
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                        + 
+--R                                    3          2          2        2           2
+--R                              - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                            + 
+--R                                    3
+--R                              - 864A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2      3       2            3      3
+--R                        120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          144D  + 1848B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 576C  + 6600A C - 984B  + 1800A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                        + 
+--R                                  3        2       2  2            2        3
+--R                          - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 120B  - 576A B  - 72A
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                        + 
+--R                                   3          2         2        2           2
+--R                              1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                            + 
+--R                                    3
+--R                              - 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2          3        2             3
+--R                          384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                        + 
+--R                                3
+--R                          - 240A B
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 384D  - 1600B D
+--R                        + 
+--R                                2                  2        2  2
+--R                          (2784C  - 7040A C + 1280B  - 3936A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                        + 
+--R                                 3           2        2  2
+--R                          2304A C  + (- 2592B  + 1152A )C
+--R                        + 
+--R                                    2       3         4        2 2       4
+--R                          (- 1152A B  - 768A )C - 384B  + 1440A B  + 864A
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1792C  + 5376A C  + (- 2688B  + 5632A )C
+--R                            + 
+--R                                       2        3
+--R                              - 3200A B  + 1536A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2         3        2
+--R                          - 512B C  - 6144A B C  + (2176B  + 2304A B)C
+--R                        + 
+--R                                   3       3
+--R                          - 1152A B  - 768A B
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                2       2  2
+--R                          (- 2304C  + 512A C - 512B  + 768A )D
+--R                        + 
+--R                                    2                    3        2          4
+--R                          (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                        + 
+--R                                   3         2        2  2           2       3
+--R                          - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          512B  - 768A B  - 768A
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                                3        2           2              2        3
+--R                          (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                        + 
+--R                               3
+--R                          1024A B
+--R                     *
+--R                         11
+--R                        a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                        4 2 8
+--R                  - 8A D a c
+--R                + 
+--R                          4   2        4          3  2
+--R                      2A D a b  + (4B D  + 16A C D )a b
+--R                    + 
+--R                                  4          3           2     3  2  3
+--R                      ((8C - 32A)D  + 48A B D  + (- 16A C  - 8A )D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            4         3    3
+--R                      (- B D  - 4A C D )a b
+--R                    + 
+--R                                         4                    3
+--R                            (- 6C + 88A)D  + (- 8B C - 36A B)D
+--R                          + 
+--R                                   2      3  2
+--R                            (- 4A C  + 10A )D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                               5       4         2              2      2  3
+--R                          - 12D  + 4B D  + (- 16C  + 32A C - 24B  - 68A )D
+--R                        + 
+--R                               2                2   2         3      3
+--R                          (8B C  - 24A B C + 12A B)D  + (16A C  - 16A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                     4                      3
+--R                          (32C + 8A)D  + (- 48B C + 192A B)D
+--R                        + 
+--R                              3        2      2          2      3  2
+--R                          (16C  - 64A C  + 64A C - 104A B  - 32A )D
+--R                        + 
+--R                                  2      3          4     3 2
+--R                          (48A B C  + 16A B)D - 8A C  + 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 4                 3        2     3  2    4
+--R                      ((C - 19A)D  + (2B C + 6A B)D  + (2A C  - 2A )D )a b
+--R                    + 
+--R                            5        4       2               2      2  3
+--R                          7D  - 35B D  + (12C  - 144A C + 18B  + 41A )D
+--R                        + 
+--R                               2                2   2          3     3
+--R                          (2B C  + 30A B C - 15A B)D  + (- 4A C  + 4A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 56C + 114A)D  + (68B C - 496A B)D
+--R                        + 
+--R                               3         2       2     2          2       3  2
+--R                          (- 4C  + 152A C  + (12B  - 8A )C + 94A B  + 116A )D
+--R                        + 
+--R                               3          2      2        3          4     3 2
+--R                        (- 8B C  - 60A B C  + 24A B C - 4A B)D + 2A C  - 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5        4         2              2       2  3
+--R                          - 28D  + 44B D  + (- 56C  - 32A C - 20B  - 232A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (32B C  - 48A B C + 52B  + 240A B)D
+--R                        + 
+--R                                   4        3         2      2  2
+--R                              - 16C  + 32A C  + (- 24B  - 60A )C
+--R                            + 
+--R                                      2      3        2 2     4
+--R                              (- 48A B  - 72A )C - 24A B  + 4A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4          3      2   2
+--R                          4B C  + 24A B C  - 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4                      3
+--R                          160A D  + (- 192B C - 32A B)D
+--R                        + 
+--R                              3        2       2       2           2     3  2
+--R                          (64C  - 56A C  + (96B  + 256A )C - 416A B  - 8A )D
+--R                        + 
+--R                                  3           2       2           3      3
+--R                          (- 48B C  + 192A B C  - 144A B C + 96A B  + 64A B)D
+--R                        + 
+--R                            5        4      2 3           2      3  2      4
+--R                          8C  - 32A C  + 16A C  + (- 24A B  + 32A )C  - 24A C
+--R                        + 
+--R                              3 2
+--R                          - 8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                             5       4        2             2     2  3
+--R                          - D  + 8B D  + (- 2C  + 32A C - 3B  - 6A )D
+--R                        + 
+--R                                2              2   2
+--R                          (- B C  - 6A B C + 3A B)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                       4                    3
+--R                          (33C - 297A)D  + (30B C + 286A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  2
+--R                          (- 4C  + 24A C  + (- 15B  - 14A )C - 29A B  - 98A )D
+--R                        + 
+--R                               3          2     2
+--R                          (2B C  + 12A B C  - 6A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                             5        4        2               2       2  3
+--R                          97D  - 29B D  + (114C  + 40A C + 173B  + 672A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 112B C  + 192A B C - 49B  - 342A B)D
+--R                        + 
+--R                                 4         3       2      2  2
+--R                              12C  - 120A C  + (30B  + 39A )C
+--R                            + 
+--R                                    2       3       2 2    4
+--R                              (36A B  + 162A )C + 6A B  - A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4         3     2   2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                         4                     3
+--R                          (- 68C - 432A)D  + (488B C - 400A B)D
+--R                        + 
+--R                                    3         2          2       2            2
+--R                              - 112C  + 262A C  + (- 180B  - 740A )C + 1000A B
+--R                            + 
+--R                                   3
+--R                              - 74A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2           3
+--R                              92B C  - 480A B C  + (24B  + 300A B)C - 56A B
+--R                            + 
+--R                                    3
+--R                              - 168A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4         2      2  3
+--R                          - 6C  + 64A C  + (- 12B  - 16A )C
+--R                        + 
+--R                                 2      3  2     4      3 2
+--R                          (- 6A B  - 80A )C  + 6A C + 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             5         4       2               2       2  3
+--R                          40D  + 136B D  + (28C  + 136A C + 24B  + 140A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (52B C  + 24A B C + 40B  + 612A B)D
+--R                        + 
+--R                                   4        3       2      2  2
+--R                              - 44C  - 32A C  + (36B  - 48A )C
+--R                            + 
+--R                                       2       3        4       2 2      4
+--R                              (- 168A B  + 176A )C - 48B  - 252A B  + 44A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4          3       3      2   2
+--R                          - 20B C  + 80A B C  + (12B  - 48A B)C
+--R                        + 
+--R                                3      3         2 3      4
+--R                          (40A B  + 64A B)C + 12A B  + 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          4           3
+--R                          (- 128C + 128A)D  - 896A B D
+--R                        + 
+--R                              3        2        2      2          2      3  2
+--R                          (16C  + 32A C  + (384B  - 16A )C + 32A B  + 96A )D
+--R                        + 
+--R                                      3          2         3       2
+--R                              - 192B C  + 96A B C  + (- 64B  - 576A B)C
+--R                            + 
+--R                                    3      3
+--R                              384A B  + 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4       2      2  3        2 2
+--R                          32C  - 16A C  + (16B  + 64A )C  - 96A B C
+--R                        + 
+--R                              2 2      4          4      3 2      5
+--R                          (48A B  - 96A )C - 32A B  - 32A B  + 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       4                     3
+--R                          (- 5C + 59A)D  + (- 10B C - 42A B)D
+--R                        + 
+--R                            3        2      2     2         2      3  2
+--R                          (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                               5         4         2                2       2  3
+--R                          - 47D  + 107B D  + (- 67C  + 352A C - 117B  - 325A )D
+--R                        + 
+--R                                2                 3       2   2
+--R                          (15B C  - 198A B C + 17B  + 195A B)D
+--R                        + 
+--R                             4        3        2     2  2          2      3
+--R                        (- 2C  + 26A C  + (- 6B  - 6A )C  + (- 6A B  - 34A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                       4                       3
+--R                          (29C + 315A)D  + (- 540B C + 958A B)D
+--R                        + 
+--R                              3         2       2       2           2       3  2
+--R                          (30C  - 546A C  + (57B  + 213A )C - 621A B  - 171A )D
+--R                        + 
+--R                                   2         3       2          3      3       5
+--R                          (414A B C  + (- 22B  - 318A B)C + 8A B  + 36A B)D + C
+--R                        + 
+--R                                 4      2     2  3        2      3  2
+--R                          - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                               5         4       2               2       2  3
+--R                          - 36D  - 428B D  + (45C  - 98A C - 196B  + 261A )D
+--R                        + 
+--R                                   2                3        2   2
+--R                          (- 149B C  - 6A B C - 316B  - 1605A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              95C  + 56A C  + (51B  + 330A )C
+--R                            + 
+--R                                     2     3        4       2 2      4
+--R                              (354A B  + 8A )C + 32B  + 339A B  - 41A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3      3       2   2
+--R                          - 5B C  - 176A B C  + (5B  + 138A B)C
+--R                        + 
+--R                                  3      3        2 3     4
+--R                          (- 10A B  - 16A B)C - 3A B  - 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (108C - 620A)D  + (160B C + 1984A B)D
+--R                        + 
+--R                                    3        2           2       2           2
+--R                              - 164C  + 36A C  + (- 1080B  - 796A )C + 584A B
+--R                            + 
+--R                                    3
+--R                              - 612A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2        3        2            3
+--R                              520B C  - 456A B C  + (128B  + 1464A B)C - 768A B
+--R                            + 
+--R                                    3
+--R                              - 120A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4        2       2  3
+--R                          - 56C  + 80A C  + (- 4B  - 128A )C
+--R                        + 
+--R                                 2      3  2         4       2 2       4
+--R                          (132A B  - 64A )C  + (- 20B  - 156A B  + 184A )C
+--R                        + 
+--R                              4      3 2      5
+--R                          4A B  + 28A B  - 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              5         4        2                2        2  3
+--R                          112D  - 208B D  + (176C  + 288A C - 192B  + 1072A )D
+--R                        + 
+--R                                   2                  3       2   2
+--R                          (- 112B C  - 288A B C - 256B  - 624A B)D
+--R                        + 
+--R                                 4        3        2       2  2
+--R                              64C  - 64A C  + (336B  + 288A )C
+--R                            + 
+--R                                    2       3        4       2 2      4
+--R                              (96A B  + 640A )C - 48B  - 432A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4         3      2   2          3      3
+--R                          - 96B C  + (- 16B  - 96A B)C  + (160A B  + 64A B)C
+--R                        + 
+--R                             5       2 3
+--R                          16B  + 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 128C - 128A)D  + (768B C - 768A B)D
+--R                        + 
+--R                                 3         2        2           2       3  2
+--R                          (- 192C  + 256A C  - 1088A C + 1792A B  + 128A )D
+--R                        + 
+--R                                     2       3        3           4      2 3
+--R                          (- 384A B C  - 256B C - 128A B)D + 64A C  + 64B C
+--R                        + 
+--R                                3 2       2 2          4      5
+--R                          - 128A C  + 192A B C - 128A B  + 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            5        4       2              2      2  3
+--R                          6D  - 22B D  + (10C  - 76A C + 18B  + 42A )D
+--R                        + 
+--R                               2               3      2   2
+--R                          (2B C  + 36A B C - 2B  - 30A B)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 24C + 276A)D  + (52B C - 536A B)D
+--R                        + 
+--R                              3       2       2      2           2       3  2
+--R                          (16C  + 4A C  + (48B  + 40A )C + 148A B  + 212A )D
+--R                        + 
+--R                                 3          2      3      2
+--R                          (- 4B C  - 72A B C  + (4B  + 60A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 129D  + 160B D
+--R                        + 
+--R                                2                2        2  3
+--R                          (- 56C  - 572A C - 130B  - 1334A )D
+--R                        + 
+--R                                 2                 3        2   2
+--R                          (426B C  - 96A B C + 248B  + 1344A B)D
+--R                        + 
+--R                                   4         3          2       2  2
+--R                              - 55C  + 192A C  + (- 120B  - 180A )C
+--R                            + 
+--R                                       2       3       4      2 2     4
+--R                              (- 180A B  - 356A )C - 5B  - 66A B  + 7A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4          3        3      2   2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                         4                       3
+--R                          (203C + 1051A)D  + (- 60B C - 1760A B)D
+--R                        + 
+--R                                  3         2         2        2            2
+--R                              216C  + 144A C  + (1356B  + 2418A )C - 1296A B
+--R                            + 
+--R                                   3
+--R                              1594A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 624B C  + 612A B C  + (- 168B  - 1428A B)C
+--R                            + 
+--R                                    3       3
+--R                              300A B  + 408A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5         4       2      2  3         2       3  2
+--R                          29C  - 119A C  + (54B  + 80A )C  + (30A B  + 188A )C
+--R                        + 
+--R                             4      2 2      4        4     3 2     5
+--R                          (5B  + 36A B  - 37A )C + A B  - 4A B  + 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 196D  + 508B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 226C  - 1068A C + 712B  - 2514A )D
+--R                        + 
+--R                                 2                  3       2   2
+--R                          (258B C  + 540A B C + 808B  + 930A B)D
+--R                        + 
+--R                                   4        3          2       2  2
+--R                              - 98C  + 64A C  + (- 894B  - 852A )C
+--R                            + 
+--R                                    2        3         4        2 2       4
+--R                              (12A B  - 1872A )C + 268B  + 1218A B  - 154A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3         3       2   2
+--R                          190B C  - 96A B C  + (- 34B  + 204A B)C
+--R                        + 
+--R                                   3       3        5      2 3      4
+--R                          (- 220A B  - 304A B)C - 4B  - 82A B  - 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                        4                         3
+--R                          (344C + 488A)D  + (- 1152B C + 1920A B)D
+--R                        + 
+--R                                  3         2       2        2            2
+--R                              104C  - 120A C  + (48B  + 3000A )C - 3408A B
+--R                            + 
+--R                                  3
+--R                              504A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2        3      2            3
+--R                              - 112B C  + 528A B C  + (384B  + 48A B)C - 512A B
+--R                            + 
+--R                                  3
+--R                              560A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4      2      2  3          2       3  2
+--R                          - 16C  - 80A C  + (8B  - 32A )C  + (168A B  + 320A )C
+--R                        + 
+--R                                4       2 2       4           4     3 2       5
+--R                          (- 40B  - 552A B  + 176A )C + 168A B  - 8A B  - 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                             5         4                    2       2  3
+--R                          32D  - 608B D  + (- 1024A C + 256B  + 576A )D
+--R                        + 
+--R                                   2                   2   2
+--R                          (- 512B C  - 384A B C - 2880A B)D
+--R                        + 
+--R                                  4         3          2       3         4
+--R                              224C  - 128A C  + (768A B  - 512A )C + 288B
+--R                            + 
+--R                                  2 2       4
+--R                              768A B  - 352A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3 2       3         5
+--R                          32B C  - 256A B C  - 128B C  - 384A B C + 32B
+--R                        + 
+--R                              2 3       4
+--R                          128A B  - 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  4                     3
+--R                          - 128A D  + (768B C + 512A B)D
+--R                        + 
+--R                                    3         2           2        2
+--R                              - 256C  + 896A C  + (- 1536B  - 1024A )C
+--R                            + 
+--R                                     2       3
+--R                              1664A B  + 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                          (768B C  - 768A B C  + 2304A B C - 1536A B  - 256A B)D
+--R                        + 
+--R                                5         4       2 3          2       3  2
+--R                          - 128C  + 128A C  - 256A C  + (384A B  - 128A )C
+--R                        + 
+--R                              4        3 2
+--R                          384A C + 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                     4                  3
+--R                          (4C - 60A)D  + (8B C + 72A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  2
+--R                          (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                     *
+--R                           8
+--R                        a b
+--R                    + 
+--R                             5         4       2                2       2  3
+--R                          68D  - 148B D  + (52C  - 176A C + 156B  + 620A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 116B C  + 264A B C - 76B  - 564A B)D
+--R                        + 
+--R                             4        3       2      2  2         2      3
+--R                          (8C  - 40A C  + (24B  + 24A )C  + (24A B  + 72A )C)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 24C - 1088A)D  + (504B C + 672A B)D
+--R                        + 
+--R                                    3         2          2        2           2
+--R                              - 132C  + 628A C  + (- 744B  - 1048A )C + 608A B
+--R                            + 
+--R                                    3
+--R                              - 912A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2        3       2           3
+--R                              176B C  - 600A B C  + (104B  + 936A B)C - 32A B
+--R                            + 
+--R                                   3
+--R                              - 80A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4         2      2  3           2      3  2
+--R                        - 4C  + 20A C  + (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              5        4          2                2        2  3
+--R                          288D  + 44B D  + (- 112C  + 1816A C - 60B  + 2928A )D
+--R                        + 
+--R                                   2                  3       2   2
+--R                          (- 792B C  - 672A B C - 348B  - 528A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              64C  - 408A C  + (732B  + 240A )C
+--R                            + 
+--R                                       2        3         4        2 2      4
+--R                              (- 144A B  + 1576A )C - 148B  - 1044A B  + 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3         3       2   2
+--R                          - 68B C  + 272A B C  + (- 28B  - 384A B)C
+--R                        + 
+--R                                3      3         2 3      4
+--R                          (40A B  + 64A B)C + 12A B  + 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                          4                        3
+--R                          (- 656C - 664A)D  + (- 128B C - 1416A B)D
+--R                        + 
+--R                                  3         2          2        2            2
+--R                              136C  - 792A C  + (- 636B  - 4356A )C + 2652A B
+--R                            + 
+--R                                     3
+--R                              - 1892A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3          2          3       2            3
+--R                              480B C  + 72A B C  + (- 152B  + 120A B)C + 848A B
+--R                            + 
+--R                                     3
+--R                              - 1008A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4          2      2  3
+--R                          8C  + 64A C  + (- 188B  + 28A )C
+--R                        + 
+--R                                   2       3  2        4       2 2       4
+--R                          (- 252A B  - 412A )C  + (100B  + 768A B  - 308A )C
+--R                        + 
+--R                                 4      3 2      5
+--R                          - 12A B  + 64A B  + 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 176D  + 592B D
+--R                        + 
+--R                               2                  2        2  3
+--R                          (156C  + 1896A C - 1328B  - 1172A )D
+--R                        + 
+--R                                  2                  3        2   2
+--R                          (1188B C  + 216A B C - 560B  + 4596A B)D
+--R                        + 
+--R                                    4         3        2       2  2
+--R                              - 252C  + 416A C  + (420B  + 792A )C
+--R                            + 
+--R                                        2        3         4        2 2       4
+--R                              (- 1128A B  + 1632A )C - 656B  - 1500A B  + 740A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3        3      2   2
+--R                          - 108B C  + 256A B C  + (252B  + 24A B)C
+--R                        + 
+--R                                   3       3         5       2 3       4
+--R                          (- 120A B  + 768A B)C - 80B  - 356A B  + 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (208C + 912A)D  + (- 960B C - 1280A B)D
+--R                        + 
+--R                                  3          2         2        2            2
+--R                              400C  - 1616A C  + (3360B  + 2352A )C - 2304A B
+--R                            + 
+--R                                  3
+--R                              912A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                       3            2          3        2
+--R                              - 1568B C  + 1632A B C  + (- 256B  - 5088A B)C
+--R                            + 
+--R                                     3       3
+--R                              2304A B  + 160A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4         2       2  3
+--R                          160C  - 160A C  + (- 48B  + 384A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 336A B  + 160A )C  + (80B  + 432A B  - 544A )C
+--R                        + 
+--R                                4      3 2
+--R                          112A B  - 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  4        2                  2       2  3
+--R                          - 128B D  + (192C  - 1664A C + 1088B  - 576A )D
+--R                        + 
+--R                                  2                   3        2   2
+--R                          (- 64B C  + 1920A B C + 192B  - 1344A B)D
+--R                        + 
+--R                                      3          2       2  2
+--R                              - 256A C  + (- 960B  - 192A )C
+--R                            + 
+--R                                     2        3         4        2 2      4
+--R                              (384A B  - 1408A )C + 192B  + 2112A B  + 64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3       3       2   2
+--R                          320B C  - 384A B C  + (64B  + 576A B)C
+--R                        + 
+--R                                   3       3         5       2 3
+--R                          (- 640A B  - 256A B)C - 64B  - 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                  3
+--R                          512A B D
+--R                        + 
+--R                                    3         2           2       2           2
+--R                              - 256C  + 896A C  + (- 1536B  + 256A )C - 512A B
+--R                            + 
+--R                                  3
+--R                              128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3        2
+--R                              768B C  - 1536A B C  + (1024B  + 2304A B)C
+--R                            + 
+--R                                       3       3
+--R                              - 1536A B  - 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4          2       2  3         2 2
+--R                          - 128C  + 256A C  + (- 256B  - 256A )C  + 384A B C
+--R                        + 
+--R                                 2 2       4           4       3 2       5
+--R                          (- 768A B  + 384A )C + 512A B  + 128A B  - 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                          5        4        2              2      2  3
+--R                      - 8D  + 24B D  + (- 8C  + 48A C - 24B  - 72A )D
+--R                    + 
+--R                           2               3      2   2
+--R                      (8B C  - 48A B C + 8B  + 72A B)D
+--R                 *
+--R                       9
+--R                    a b
+--R                + 
+--R                            4                     3
+--R                      112A D  + (- 80B C - 32A B)D
+--R                    + 
+--R                          3        2       2       2          2      3  2
+--R                      (16C  - 96A C  + (96B  + 112A )C - 80A B  + 96A )D
+--R                    + 
+--R                              3          2         3       2
+--R                      (- 16B C  + 96A B C  + (- 16B  - 144A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                           5         4        2               2       2  3
+--R                      - 68D  + 104B D  + (- 8C  + 64A C - 112B  - 656A )D
+--R                    + 
+--R                             2                 3       2   2
+--R                      (112B C  - 144A B C + 56B  + 312A B)D
+--R                    + 
+--R                              4        3      2 2         2       3        4
+--R                          - 4C  + 32A C  - 96B C  + (48A B  - 176A )C + 20B
+--R                        + 
+--R                              2 2      4
+--R                          168A B  - 12A
+--R                     *
+--R                        D
+--R                    + 
+--R                          4          3      3      2   2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                   4                      3
+--R                      (52C + 772A)D  + (- 416B C - 32A B)D
+--R                    + 
+--R                          3         2        2        2           2       3  2
+--R                      (48C  - 480A C  + (528B  + 1016A )C - 592A B  + 776A )D
+--R                    + 
+--R                                 3           2         3       2            3
+--R                          - 80B C  + 432A B C  + (- 48B  - 672A B)C - 176A B
+--R                        + 
+--R                             3
+--R                          96A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          5        4       2      2  3         2      3  2
+--R                      - 4C  + 12A C  + (24B  - 16A )C  + (24A B  + 32A )C
+--R                    + 
+--R                            4       2 2      4         4      3 2      5
+--R                      (- 20B  - 144A B  + 52A )C - 4A B  - 16A B  - 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                           5         4        2                 2       2  3
+--R                      - 20D  - 640B D  + (328C  - 2272A C + 568B  - 464A )D
+--R                    + 
+--R                             2                  3        2   2
+--R                      (240B C  + 1392A B C + 16B  - 2040A B)D
+--R                    + 
+--R                              4         3          2      2  2
+--R                          - 4C  + 224A C  + (- 600B  - 96A )C
+--R                        + 
+--R                                 2        3         4        2 2       4
+--R                          (384A B  - 1264A )C + 188B  + 1056A B  - 172A
+--R                     *
+--R                        D
+--R                    + 
+--R                           4           3       3       2   2         3      3
+--R                      32B C  - 304A B C  + (16B  + 408A B)C  + (80A B  - 64A B)C
+--R                    + 
+--R                         5      2 3      4
+--R                      16B  + 88A B  - 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                    4                       3
+--R                      (364C - 980A)D  + (1648B C + 1600A B)D
+--R                    + 
+--R                                3          2           2       2           2
+--R                          - 544C  + 2112A C  + (- 1776B  + 696A )C + 480A B
+--R                        + 
+--R                               3
+--R                          - 40A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2        3        2             3
+--R                          352B C  - 2256A B C  + (448B  + 3504A B)C - 1232A B
+--R                        + 
+--R                              3
+--R                          736A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5        4        2       2  3          2       3  2
+--R                      - 28C  + 52A C  + (200B  - 112A )C  + (168A B  + 224A )C
+--R                    + 
+--R                             4       2 2       4          4       3 2      5
+--R                      (- 140B  - 912A B  + 364A )C - 92A B  - 112A B  - 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                         5         4          2                 2        2  3
+--R                      96D  + 512B D  + (- 888C  + 2288A C - 560B  + 1384A )D
+--R                    + 
+--R                                2                   3       2   2
+--R                      (- 1064B C  - 3888A B C + 560B  + 696A B)D
+--R                    + 
+--R                              4         3         2       2  2
+--R                          200C  - 256A C  + (1272B  - 672A )C
+--R                        + 
+--R                                  2        3         4        2 2       4
+--R                          (- 48A B  + 1184A )C + 176B  - 2184A B  - 520A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3        2   2
+--R                      - 232B C  + 608A B C  + (- 344B  - 1248A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (560A B  - 448A B)C + 112B  + 616A B  - 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                     4                         3
+--R                      (- 416C + 96A)D  + (- 1152B C - 1536A B)D
+--R                    + 
+--R                                3          2         2        2           2
+--R                            736C  - 1536A C  + (1152B  - 2080A )C + 704A B
+--R                          + 
+--R                                  3
+--R                            - 832A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3            2           3        2
+--R                          - 256B C  + 3264A B C  + (- 1408B  - 2688A B)C
+--R                        + 
+--R                                 3       3
+--R                          1408A B  - 320A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5         4       2       2  3            2       3  2
+--R                      32C  - 320A C  + (32B  + 128A )C  + (- 192A B  - 256A )C
+--R                    + 
+--R                           4        2 2       4           4       3 2       5
+--R                      (160B  + 1824A B  - 416A )C - 416A B  + 128A B  + 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                           2                2       2  3
+--R                      (576C  - 128A C + 128B  - 192A )D
+--R                    + 
+--R                             2                   3       2   2
+--R                      (704B C  + 2688A B C - 640B  + 960A B)D
+--R                    + 
+--R                                4          2       2  2            2       3
+--R                          - 192C  + (- 576B  + 768A )C  + (- 384A B  + 256A )C
+--R                        + 
+--R                                4       2 2       4
+--R                          - 384B  + 960A B  + 704A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3       2   2
+--R                      192B C  - 256A B C  + (320B  + 768A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 640A B  + 512A B)C - 128B  - 704A B  + 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                             3       2          2  2
+--R                      (- 256C  + 256A C - 512A B )D
+--R                    + 
+--R                                  2        3        3            4       2 3
+--R                      (- 1536A B C  + 1024B C - 512A B)D + 256A C  - 256B C
+--R                    + 
+--R                            2 2          4       5
+--R                      - 768A B C + 512A B  - 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                ROOT
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN1
+--R                     + 
+--R                                   3 3      2 2      4  2       3 2      5
+--R                               - 8a c  + (2a b  - 16a )c  + (40a b  + 32a )c
+--R                             + 
+--R                                   2 4      4 2      6
+--R                               - 8a b  - 56a b  + 64a
+--R                          *
+--R                             %%BN0
+--R                         + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN1
+--R                     + 
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN0
+--R                     + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN0
+--R                     + 
+--R                           2 2                          2     2  2  2
+--R                       (- D b  + 4C D a b + (- 8B D - 4C  - 4A )a )c
+--R                     + 
+--R                               2   2                               2
+--R                           - 4D a b  + ((20C + 4A)D + 4B C + 4A B)a b
+--R                         + 
+--R                              2             2             2     2  3
+--R                           (8D  - 16B D - 8C  + 16A C + 8B  - 8A )a
+--R                      *
+--R                         c
+--R                     + 
+--R                         2 4            3
+--R                       4D b  - 16C D a b
+--R                     + 
+--R                            2              2            2      2  2 2
+--R                       (- 8D  + 24B D + 12C  - 8A C - 4B  + 12A )a b
+--R                     + 
+--R                                                       3
+--R                       ((- 8C - 24A)D - 24B C - 24A B)a b
+--R                     + 
+--R                           2              2  4
+--R                       (16D  + 32A C + 16B )a
+--R                  /
+--R                         3 3       2 2     4  2         3 2      5       2 4
+--R                       4a c  + (- a b  + 8a )c  + (- 20a b  - 16a )c + 4a b
+--R                     + 
+--R                          4 2      6
+--R                       28a b  - 32a
+--R            + 
+--R                             2 4 8
+--R                      - 32A D a c
+--R                    + 
+--R                               2 3 2       3        2  4
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   2                   2      3  5
+--R                          (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                2 2 4        3       2  3 3
+--R                          - 2A D a b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          2                  2      3  4 2
+--R                          ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                        + 
+--R                                 3        2       2               2       2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                     2                2
+--R                              - 16B C  - 96A B C + 48A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    2                 3         2      2
+--R                              128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                            + 
+--R                                      2       3
+--R                              - 128A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3      2  2 5
+--R                          (D  + B D )a b
+--R                        + 
+--R                                        2                2     3  3 4
+--R                          ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                        + 
+--R                                    3         2
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 24C  + 112A C + 32B  + 72A )D + 8B C  + 48A B C
+--R                            + 
+--R                                   2
+--R                              - 24A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                           3
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2           2      3
+--R                              (384C  - 512A C - 64B  - 384A )D + 128B C  + 64B
+--R                            + 
+--R                                  2
+--R                              384A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                     2                  3         2       2
+--R                              1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                            + 
+--R                                      2       3
+--R                              - 512A B  + 128A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       2 2 6
+--R                          (- 2C + 22A)D a b
+--R                        + 
+--R                                 3        2      2             2     2        2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D - B C
+--R                            + 
+--R                                           2
+--R                              - 6A B C + 3A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                             2                            3
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                            + 
+--R                                    2         2      2          2       3
+--R                              120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                            + 
+--R                                            3       2
+--R                              672A B C - 64B  - 720A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                               3
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D + 608C
+--R                            + 
+--R                                      2          2       2            2      3
+--R                              - 416A C  + (- 288B  - 992A )C + 1120A B  + 32A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2           2
+--R                              (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                            + 
+--R                                              3       2
+--R                              1152A B C + 128B  + 192A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                    2                   3          2       2
+--R                              512A D  - 4096A B D + 256C  - 1024A C  - 256A C
+--R                            + 
+--R                                    2        3
+--R                              512A B  + 1024A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               3       2  2 7
+--R                          (- 8D  - 8B D )a b
+--R                        + 
+--R                                              2                      3        2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D + C  - 13A C
+--R                            + 
+--R                                 2     2         2      3
+--R                              (3B  + 3A )C + 3A B  + 17A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  3        2        2                2       2
+--R                              284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              - 12B C  - 312A B C + 20B  + 276A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                            2                               3
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D - 320C
+--R                            + 
+--R                                    2         2       2           2       3
+--R                              720A C  + (- 96B  + 192A )C - 672A B  - 848A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2            2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D - 1088B C
+--R                            + 
+--R                                                3        2
+--R                              - 1920A B C - 384B  - 1344A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                             2                               3
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D + 128C
+--R                            + 
+--R                                     2          2       2           2        3
+--R                              1920A C  + (- 384B  - 640A )C + 128A B  - 2432A
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2            2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D - 1024B C
+--R                            + 
+--R                                    3        2
+--R                              - 512B  - 3072A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2                    3         2
+--R                              - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                            + 
+--R                                     2           2       3
+--R                              - 2048A C + 4096A B  + 512A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      2 2 8
+--R                          (16C - 80A)D a b
+--R                        + 
+--R                                    3         2
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 30C  + 100A C + 26B  + 66A )D + 2B C  + 36A B C
+--R                            + 
+--R                                  3      2
+--R                              - 2B  - 30A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                               2                            3
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D + 62C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 230A C  + (90B  + 58A )C + 154A B  + 350A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2           2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                            + 
+--R                                               3        2
+--R                              - 576A B C + 312B  + 2160A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                     2                              3         2
+--R                              8160A D  + (4608B C - 5376A B)D - 864C  - 192A C
+--R                            + 
+--R                                    2        2           2        3
+--R                              (2304B  + 3936A )C - 960A B  + 3264A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2            2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D + 1152B C
+--R                            + 
+--R                                                3        2
+--R                              - 2304A B C + 768B  + 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D - 3840C
+--R                            + 
+--R                                     2         2        2            2
+--R                              3072A C  + (2304B  + 6912A )C - 6912A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2            2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D - 2816B C
+--R                            + 
+--R                                                 3        2
+--R                              - 4608A B C - 1024B  - 3840A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2                    3          2
+--R                              - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                            + 
+--R                                     2           2        3
+--R                              - 1024A C + 2048A B  - 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3        2  2 9
+--R                          (16D  + 16B D )a b
+--R                        + 
+--R                                            2                           3
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                            + 
+--R                                   2         2      2          2      3
+--R                              20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                         *
+--R                             3 8
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2           2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D - 104B C
+--R                            + 
+--R                                            3       2
+--R                              432A B C - 88B  - 744A B
+--R                         *
+--R                             4 7
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D + 364C
+--R                            + 
+--R                                      2          2        2           2       3
+--R                              - 380A C  + (- 828B  - 1468A )C + 452A B  - 724A
+--R                         *
+--R                             5 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2           2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D - 336B C
+--R                            + 
+--R                                              3        2
+--R                              4320A B C - 528B  - 5328A B
+--R                         *
+--R                             6 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                             7 4
+--R                            a b
+--R                        + 
+--R                                     3         2
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2            2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D + 4224B C
+--R                            + 
+--R                                               3        2
+--R                              6912A B C + 1536B  + 5760A B
+--R                         *
+--R                             8 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                             9 2
+--R                            a b
+--R                        + 
+--R                                       2         2                  2        2
+--R                              - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                     2        3        2
+--R                              2048B C  + 1024B  + 6144A B
+--R                         *
+--R                             10
+--R                            a  b
+--R                        + 
+--R                                               3          2        2           2
+--R                              8192A B D - 4096C  + 2048A C  + 4096A C - 8192A B
+--R                            + 
+--R                                     3
+--R                              - 2048A
+--R                         *
+--R                             11
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    2 2 10
+--R                      (- 32C + 96A)D a b
+--R                    + 
+--R                               3        2       2               2       2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                              2               3      2
+--R                          8B C  - 48A B C + 8B  + 72A B
+--R                     *
+--R                         3 9
+--R                        a b
+--R                    + 
+--R                                           2                           3
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                        + 
+--R                               2       2       2          2      3
+--R                          72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                     *
+--R                         4 8
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                        + 
+--R                                          3       2
+--R                          - 816A B C + 88B  + 936A B
+--R                     *
+--R                         5 7
+--R                        a b
+--R                    + 
+--R                                        2                              3
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                        + 
+--R                                 2         2        2           2       3
+--R                          1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                     *
+--R                         6 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2           2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                        + 
+--R                                           3        2
+--R                          - 3744A B C - 96B  + 1296A B
+--R                     *
+--R                         7 5
+--R                        a b
+--R                    + 
+--R                                          2                              3
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                        + 
+--R                                 2         2        2           2        3
+--R                          3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                     *
+--R                         8 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2            2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D - 4352B C
+--R                        + 
+--R                                             3         2
+--R                          - 1536A B C - 2048B  - 11520A B
+--R                     *
+--R                         9 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D + 5632C
+--R                        + 
+--R                                 2           2         2            2        3
+--R                        - 4608A C  + (- 4608B  - 11776A )C + 9728A B  - 1536A
+--R                     *
+--R                         10 2
+--R                        a  b
+--R                    + 
+--R                                2                  2        2            2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                        + 
+--R                                           3        2
+--R                          6144A B C + 2048B  + 9216A B
+--R                     *
+--R                         11
+--R                        a  b
+--R                    + 
+--R                              3        2           2  12
+--R                      (- 4096C  + 4096A C - 8192A B )a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                       3 3 8
+--R                  16A D a c
+--R                + 
+--R                            3 2 2          3          2  3
+--R                      - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                    + 
+--R                                     3          2         2      3    4
+--R                      ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           3         2  2 3
+--R                      (2B D  + 6A C D )a b
+--R                    + 
+--R                                    3                   2        2      3    3 2
+--R                      ((12C - 188A)D  + (12B C + 52A B)D  + (4A C  - 12A )D)a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 64C - 32A)D  + (96B C - 320A B)D
+--R                        + 
+--R                                3        2       2          2      3
+--R                          (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                        + 
+--R                                   2      3
+--R                          - 48A B C  - 16A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                      3                   2          2     3
+--R                        ((- 2C + 41A)D  + (- 3B C - 8A B)D  + (- 2A C  + 2A )D)
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 80B D  + (- 18C  + 224A C - 26B  - 66A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                        3                       2
+--R                          (144C - 232A)D  + (- 120B C + 808A B)D
+--R                        + 
+--R                             3         2         2      2           2       3
+--R                          (4C  - 212A C  + (- 24B  + 20A )C - 112A B  - 196A )D
+--R                        + 
+--R                              3          2      2        3
+--R                          4B C  + 36A B C  - 12A B C + 4A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                        + 
+--R                                  2                3       2        4        3
+--R                          (- 80B C  + 96A B C - 64B  - 336A B)D + 8C  + 32A C
+--R                        + 
+--R                              2      2  2         2      3        2 2     4
+--R                          (24B  + 48A )C  + (48A B  + 32A )C + 24A B  + 8A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                  3                     2
+--R                          - 384A D  + (384B C + 128A B)D
+--R                        + 
+--R                                3         2          2       2           2
+--R                          (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                        + 
+--R                               3           2       2           3      3
+--R                          64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4        3      2             2     2  2
+--R                          2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                        + 
+--R                              2              2
+--R                          (B C  + 6A B C - 3A B)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                        + 
+--R                             3       2       2      2          2       3
+--R                          (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                        + 
+--R                               3         2     2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                4        3
+--R                          - 224D  + 92B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 162C  - 280A C - 320B  - 1206A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (172B C  - 336A B C + 60B  + 492A B)D - 6C  + 48A C
+--R                        + 
+--R                                2      2  2           2      3       2 2     4
+--R                          (- 18B  - 24A )C  + (- 24A B  - 80A )C - 6A B  - 2A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                            + 
+--R                                 3
+--R                              64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2         3       2           3
+--R                          - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                        + 
+--R                              3
+--R                          144A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               4         3          2               2       2  2
+--R                          - 64D  - 256B D  + (- 144C  - 608A C + 32B  - 336A )D
+--R                        + 
+--R                                  2      3       2         4        3
+--R                          (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                        + 
+--R                                2      2  2         2       3        4       2 2
+--R                          (- 48B  - 96A )C  + (96A B  - 224A )C + 32B  + 144A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                        3            2
+--R                          (256C - 256A)D  + 1792A B D
+--R                        + 
+--R                                   3         2          2      2           2
+--R                              - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                            + 
+--R                                    3
+--R                              - 256A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3       2            3
+--R                          256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       3                   2
+--R                          (13C - 139A)D  + (18B C + 58A B)D
+--R                        + 
+--R                              3        2        2     2         2      3
+--R                          (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              4         3        2                2       2  2
+--R                          109D  - 265B D  + (114C  - 591A C + 183B  + 543A )D
+--R                        + 
+--R                                  2                 3       2       4        3
+--R                          (- 27B C  + 228A B C - 19B  - 225A B)D + C  - 13A C
+--R                        + 
+--R                             2     2  2        2      3
+--R                          (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                            + 
+--R                                  3
+--R                              346A
+--R                         *
+--R                            D
+--R                        + 
+--R                               3           2       3       2          3      3
+--R                          10B C  - 234A B C  + (14B  + 174A B)C - 2A B  - 30A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                3        2               2       2  2
+--R                          768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                        + 
+--R                                 2                 3        2            3
+--R                          (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                        + 
+--R                                2       2  2            2       3        4
+--R                          (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                        + 
+--R                                2 2      4
+--R                          - 240A B  - 64A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                           3                        2
+--R                          (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                        + 
+--R                                  3         2         2        2           2
+--R                              416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                            + 
+--R                                  3
+--R                              992A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 480B C  + 672A B C  + (- 128B  - 1632A B)C + 512A B
+--R                        + 
+--R                              3
+--R                          160A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 256D  + 384B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (192C  - 1024A C + 256B  - 2112A )D
+--R                        + 
+--R                                 2                  3        2          4
+--R                          (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                        + 
+--R                                 2       2  2            2       3         2 2
+--R                          (- 576B  - 384A )C  + (- 384A B  - 512A )C + 192A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                        + 
+--R                                   2        2           2       3         3
+--R                          (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 54B D  + (- 18C  + 140A C - 26B  - 66A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                        3                      2
+--R                          (142C - 688A)D  + (- 54B C + 800A B)D
+--R                        + 
+--R                                    3         2         2      2           2
+--R                                - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                              + 
+--R                                      3
+--R                                - 248A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2        3      2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              4         3       2                 2        2  2
+--R                          416D  - 190B D  + (84C  + 1254A C + 438B  + 2514A )D
+--R                        + 
+--R                                   2                  3        2         4
+--R                          (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                        + 
+--R                                 3       2       2  2          2       3       4
+--R                          - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C + 2B
+--R                        + 
+--R                             2 2      4
+--R                          48A B  + 14A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                        + 
+--R                                    3        2           2        2            2
+--R                              - 788C  - 84A C  + (- 2292B  - 4428A )C + 1404A B
+--R                            + 
+--R                                     3
+--R                              - 2252A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                        + 
+--R                                3
+--R                          - 308A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          608D  - 640B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 240C  + 3552A C - 960B  + 5232A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1632B C  - 1536A B C - 928B  - 1632A B)D + 464C
+--R                        + 
+--R                                3        2        2  2          2        3
+--R                          128A C  + (912B  + 1344A )C  + (384A B  + 1664A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 160B  - 528A B  - 16A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            3                       2
+--R                          (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 128C  - 576A C  + (192B  - 6144A )C + 4800A B
+--R                            + 
+--R                                    3
+--R                              - 704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2          3       2            3
+--R                          256B C  + 768A B C  + (- 704B  - 384A B)C + 448A B
+--R                        + 
+--R                                3
+--R                          - 128A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 128D  + 1280B D
+--R                        + 
+--R                               2                 2       2  2
+--R                          (768C  + 2560A C - 640B  - 768A )D
+--R                        + 
+--R                                 2                   2          4         3
+--R                          (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                        + 
+--R                                 2       2  2            2       3         4
+--R                          (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                        + 
+--R                                2 2       4
+--R                          - 384A B  + 128A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                3                         2
+--R                          512A D  + (- 1536B C - 2048A B)D
+--R                        + 
+--R                               3          2         2        2            2
+--R                          (256C  - 2048A C  + (3072B  + 1792A )C - 2048A B )D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                        - 1024B C  + 768A B C  - 3072A B C + 1024A B  + 256A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                         3                      2
+--R                          (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                        + 
+--R                             3        2       2      2          2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 204D  + 316B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 144C  + 364A C - 292B  - 1092A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (164B C  - 288A B C + 84B  + 636A B)D - 4C  + 20A C
+--R                        + 
+--R                                2      2  2           2      3
+--R                          (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                            + 
+--R                                  3
+--R                              996A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2         3       2          3
+--R                          - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                        + 
+--R                             3
+--R                          56A B
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 924D  - 588B D
+--R                        + 
+--R                               2                2        2  2
+--R                          (216C  - 5556A C - 60B  - 6156A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                        + 
+--R                                3          2       2  2         2        3
+--R                          708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                        + 
+--R                             4       2 2       4
+--R                          72B  + 576A B  + 120A
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                        + 
+--R                                  3          2        2        2            2
+--R                              408C  + 2760A C  + (504B  + 9096A )C - 3720A B
+--R                            + 
+--R                                   3
+--R                              2904A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3       2            3
+--R                          - 840B C  - 1656A B C  + (168B  + 360A B)C - 792A B
+--R                        + 
+--R                              3
+--R                          408A B
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          480D  - 1536B D
+--R                        + 
+--R                                 2                  2        2  2
+--R                          (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                        + 
+--R                                    2                  3        2          4
+--R                          (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                        + 
+--R                                  3        2        2  2           2        3
+--R                          - 864A C  + (576B  - 2304A )C  + (1152A B  - 2208A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          576B  + 576A B  - 384A
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                           3                       2
+--R                          (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                            + 
+--R                                     2        3
+--R                              2304A B  - 1344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                          1344B C  - 1728A B C  + 5184A B C - 1536A B  - 192A B
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                3           2                  2        2  2
+--R                          512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                        + 
+--R                                    2                   2          4         3
+--R                          (- 1280B C  - 4608A B C + 768A B)D + 640C  - 512A C
+--R                        + 
+--R                                2       2  2          2        3          2 2
+--R                          (1920B  + 768A )C  + (768A B  + 1536A )C - 1152A B
+--R                        + 
+--R                                4
+--R                          - 384A
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                     2
+--R                          - 2048A B D
+--R                        + 
+--R                                3          2         2        2            2
+--R                          (1024C  - 2048A C  + (3072B  - 1024A )C + 2048A B )D
+--R                        + 
+--R                                   3            2           3        2
+--R                          - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                        + 
+--R                                 3        3
+--R                          1024A B  + 1024A B
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                         4        3       2               2       2  2
+--R                      24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                    + 
+--R                             2               3      2
+--R                      (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                    3                    2
+--R                      (- 8C - 336A)D  + (216B C + 96A B)D
+--R                    + 
+--R                            3         2          2       2          2      3
+--R                      (- 56C  + 240A C  + (- 120B  - 184A )C + 80A B  - 96A )D
+--R                    + 
+--R                          3          2      3      2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                          4         3       2               2        2  2
+--R                      216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                    + 
+--R                               2                3       2         4         3
+--R                      (- 304B C  - 48A B C - 64B  - 384A B)D + 32C  - 120A C
+--R                    + 
+--R                        2      2  2           2       3       4      2 2      4
+--R                    (72B  + 24A )C  + (- 24A B  + 152A )C - 8B  - 96A B  - 24A
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                       3                      2
+--R                      (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                        + 
+--R                                3
+--R                          - 864A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3          2      3       2            3      3
+--R                      120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                          4          3          2                 2        2  2
+--R                      144D  + 1848B D  + (- 576C  + 6600A C - 984B  + 1800A )D
+--R                    + 
+--R                                2                   3        2          4
+--R                      (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                    + 
+--R                              3        2       2  2            2        3
+--R                      - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                    + 
+--R                            4       2 2      4
+--R                      - 120B  - 576A B  - 72A
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                    + 
+--R                                 3          2         2        2           2
+--R                            1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                          + 
+--R                                  3
+--R                            - 576A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3            2          3        2             3
+--R                      384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                    + 
+--R                            3
+--R                      - 240A B
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                            4          3
+--R                      - 384D  - 1600B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (2784C  - 7040A C + 1280B  - 3936A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                    + 
+--R                             3           2        2  2             2       3
+--R                      2304A C  + (- 2592B  + 1152A )C  + (- 1152A B  - 768A )C
+--R                    + 
+--R                            4        2 2       4
+--R                      - 384B  + 1440A B  + 864A
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                     3                       2
+--R                      (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                    + 
+--R                                 3          2           2        2            2
+--R                          - 1792C  + 5376A C  + (- 2688B  + 5632A )C - 3200A B
+--R                        + 
+--R                               3
+--R                          1536A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2         3        2             3
+--R                      - 512B C  - 6144A B C  + (2176B  + 2304A B)C - 1152A B
+--R                    + 
+--R                            3
+--R                      - 768A B
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                              2                2       2  2
+--R                      (- 2304C  + 512A C - 512B  + 768A )D
+--R                    + 
+--R                                2                    3        2          4
+--R                      (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                    + 
+--R                          4       2 2       4
+--R                      512B  - 768A B  - 768A
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                            3        2           2              2        3
+--R                      (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                    + 
+--R                           3
+--R                      1024A B
+--R                 *
+--R                     11
+--R                    a
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                             2 4 8
+--R                      - 32A D a c
+--R                    + 
+--R                               2 3 2       3        2  4
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   2                   2      3  5
+--R                          (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                2 2 4        3       2  3 3
+--R                          - 2A D a b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          2                  2      3  4 2
+--R                          ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                        + 
+--R                                 3        2       2               2       2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                     2                2
+--R                              - 16B C  - 96A B C + 48A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    2                 3         2      2
+--R                              128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                            + 
+--R                                      2       3
+--R                              - 128A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3      2  2 5
+--R                          (D  + B D )a b
+--R                        + 
+--R                                        2                2     3  3 4
+--R                          ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                        + 
+--R                                    3         2
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 24C  + 112A C + 32B  + 72A )D + 8B C  + 48A B C
+--R                            + 
+--R                                   2
+--R                              - 24A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                           3
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2           2      3
+--R                              (384C  - 512A C - 64B  - 384A )D + 128B C  + 64B
+--R                            + 
+--R                                  2
+--R                              384A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                     2                  3         2       2
+--R                              1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                            + 
+--R                                      2       3
+--R                              - 512A B  + 128A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       2 2 6
+--R                          (- 2C + 22A)D a b
+--R                        + 
+--R                                 3        2      2             2     2        2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D - B C
+--R                            + 
+--R                                           2
+--R                              - 6A B C + 3A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                             2                            3
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                            + 
+--R                                    2         2      2          2       3
+--R                              120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                            + 
+--R                                            3       2
+--R                              672A B C - 64B  - 720A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                               3
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D + 608C
+--R                            + 
+--R                                      2          2       2            2      3
+--R                              - 416A C  + (- 288B  - 992A )C + 1120A B  + 32A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2           2
+--R                              (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                            + 
+--R                                              3       2
+--R                              1152A B C + 128B  + 192A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                    2                   3          2       2
+--R                              512A D  - 4096A B D + 256C  - 1024A C  - 256A C
+--R                            + 
+--R                                    2        3
+--R                              512A B  + 1024A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               3       2  2 7
+--R                          (- 8D  - 8B D )a b
+--R                        + 
+--R                                              2                      3        2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D + C  - 13A C
+--R                            + 
+--R                                 2     2         2      3
+--R                              (3B  + 3A )C + 3A B  + 17A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  3        2        2                2       2
+--R                              284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              - 12B C  - 312A B C + 20B  + 276A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                            2                               3
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D - 320C
+--R                            + 
+--R                                    2         2       2           2       3
+--R                              720A C  + (- 96B  + 192A )C - 672A B  - 848A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2            2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D - 1088B C
+--R                            + 
+--R                                                3        2
+--R                              - 1920A B C - 384B  - 1344A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                             2                               3
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D + 128C
+--R                            + 
+--R                                     2          2       2           2        3
+--R                              1920A C  + (- 384B  - 640A )C + 128A B  - 2432A
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2            2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D - 1024B C
+--R                            + 
+--R                                    3        2
+--R                              - 512B  - 3072A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2                    3         2
+--R                              - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                            + 
+--R                                     2           2       3
+--R                              - 2048A C + 4096A B  + 512A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      2 2 8
+--R                          (16C - 80A)D a b
+--R                        + 
+--R                                    3         2
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 30C  + 100A C + 26B  + 66A )D + 2B C  + 36A B C
+--R                            + 
+--R                                  3      2
+--R                              - 2B  - 30A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                               2                            3
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D + 62C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 230A C  + (90B  + 58A )C + 154A B  + 350A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2           2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                            + 
+--R                                               3        2
+--R                              - 576A B C + 312B  + 2160A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                     2                              3         2
+--R                              8160A D  + (4608B C - 5376A B)D - 864C  - 192A C
+--R                            + 
+--R                                    2        2           2        3
+--R                              (2304B  + 3936A )C - 960A B  + 3264A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2            2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D + 1152B C
+--R                            + 
+--R                                                3        2
+--R                              - 2304A B C + 768B  + 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D - 3840C
+--R                            + 
+--R                                     2         2        2            2
+--R                              3072A C  + (2304B  + 6912A )C - 6912A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2            2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D - 2816B C
+--R                            + 
+--R                                                 3        2
+--R                              - 4608A B C - 1024B  - 3840A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2                    3          2
+--R                              - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                            + 
+--R                                     2           2        3
+--R                              - 1024A C + 2048A B  - 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3        2  2 9
+--R                          (16D  + 16B D )a b
+--R                        + 
+--R                                            2                           3
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                            + 
+--R                                   2         2      2          2      3
+--R                              20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                         *
+--R                             3 8
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2           2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D - 104B C
+--R                            + 
+--R                                            3       2
+--R                              432A B C - 88B  - 744A B
+--R                         *
+--R                             4 7
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D + 364C
+--R                            + 
+--R                                      2          2        2           2       3
+--R                              - 380A C  + (- 828B  - 1468A )C + 452A B  - 724A
+--R                         *
+--R                             5 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2           2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D - 336B C
+--R                            + 
+--R                                              3        2
+--R                              4320A B C - 528B  - 5328A B
+--R                         *
+--R                             6 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                             7 4
+--R                            a b
+--R                        + 
+--R                                     3         2
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2            2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D + 4224B C
+--R                            + 
+--R                                               3        2
+--R                              6912A B C + 1536B  + 5760A B
+--R                         *
+--R                             8 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                             9 2
+--R                            a b
+--R                        + 
+--R                                       2         2                  2        2
+--R                              - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                     2        3        2
+--R                              2048B C  + 1024B  + 6144A B
+--R                         *
+--R                             10
+--R                            a  b
+--R                        + 
+--R                                               3          2        2           2
+--R                              8192A B D - 4096C  + 2048A C  + 4096A C - 8192A B
+--R                            + 
+--R                                     3
+--R                              - 2048A
+--R                         *
+--R                             11
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    2 2 10
+--R                      (- 32C + 96A)D a b
+--R                    + 
+--R                               3        2       2               2       2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                              2               3      2
+--R                          8B C  - 48A B C + 8B  + 72A B
+--R                     *
+--R                         3 9
+--R                        a b
+--R                    + 
+--R                                           2                           3
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                        + 
+--R                               2       2       2          2      3
+--R                          72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                     *
+--R                         4 8
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                        + 
+--R                                          3       2
+--R                          - 816A B C + 88B  + 936A B
+--R                     *
+--R                         5 7
+--R                        a b
+--R                    + 
+--R                                        2                              3
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                        + 
+--R                                 2         2        2           2       3
+--R                          1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                     *
+--R                         6 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2           2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                        + 
+--R                                           3        2
+--R                          - 3744A B C - 96B  + 1296A B
+--R                     *
+--R                         7 5
+--R                        a b
+--R                    + 
+--R                                          2                              3
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                        + 
+--R                                 2         2        2           2        3
+--R                          3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                     *
+--R                         8 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2            2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D - 4352B C
+--R                        + 
+--R                                             3         2
+--R                          - 1536A B C - 2048B  - 11520A B
+--R                     *
+--R                         9 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D + 5632C
+--R                        + 
+--R                                 2           2         2            2        3
+--R                        - 4608A C  + (- 4608B  - 11776A )C + 9728A B  - 1536A
+--R                     *
+--R                         10 2
+--R                        a  b
+--R                    + 
+--R                                2                  2        2            2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                        + 
+--R                                           3        2
+--R                          6144A B C + 2048B  + 9216A B
+--R                     *
+--R                         11
+--R                        a  b
+--R                    + 
+--R                              3        2           2  12
+--R                      (- 4096C  + 4096A C - 8192A B )a
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                           3 3 8
+--R                      32A D a c
+--R                    + 
+--R                                 3 2 2         4        3  3
+--R                          - 16A D a b  + (- 16D  - 16B D )a b
+--R                        + 
+--R                                 3           2           2      3    4
+--R                          (128A D  - 128A B D  + (- 32A C  + 32A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              3   4      4       3  2 3
+--R                          2A D a b  + (8D  + 8B D )a b
+--R                        + 
+--R                                        3          2         2      3    3 2
+--R                          ((32C - 448A)D  + 64A B D  + (16A C  - 16A )D)a b
+--R                        + 
+--R                                   4        3
+--R                              - 32D  + 32B D
+--R                            + 
+--R                                    2               2       2  2
+--R                              (- 48C  + 224A C + 64B  + 144A )D
+--R                            + 
+--R                                    2                2
+--R                              (16B C  + 96A B C - 48A B)D
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                      3           2
+--R                              - 128A D  - 512A B D
+--R                            + 
+--R                                  3         2      2          2       3
+--R                              (64C  - 128A C  - 64A C + 128A B  + 128A )D
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              4      3    5
+--R                          (- D  - B D )a b
+--R                        + 
+--R                                          3         2          2     3    2 4
+--R                          ((- 16C + 192A)D  - 8A B D  + (- 2A C  + 2A )D)a b
+--R                        + 
+--R                                  4         3       2               2      2  2
+--R                              160D  + 128B D  + (24C  - 112A C - 32B  - 72A )D
+--R                            + 
+--R                                     2                2
+--R                              (- 8B C  - 48A B C + 24A B)D
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                           3                       2
+--R                              (80C - 560A)D  + (- 96B C + 1312A B)D
+--R                            + 
+--R                                       3         2         2      2           2
+--R                                  - 48C  + 304A C  + (- 48B  - 16A )C - 112A B
+--R                                + 
+--R                                        3
+--R                                  - 368A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              128D  + 256B D
+--R                            + 
+--R                                     2               2       2  2
+--R                              (- 384C  + 512A C + 64B  + 384A )D
+--R                            + 
+--R                                       2      3       2
+--R                              (- 128B C  - 64B  - 384A B)D
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                       3           2
+--R                              - 1024A D  + 512A B D
+--R                            + 
+--R                                   3         2       2          2       3
+--R                              (256C  + 128A C  - 256A C + 512A B  - 128A )D
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                     3   6
+--R                          (2C - 22A)D a b
+--R                        + 
+--R                                   4        3        2             2     2  2
+--R                              - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D
+--R                            + 
+--R                                  2              2
+--R                              (B C  + 6A B C - 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                               3                    2
+--R                              (- 328C + 1896A)D  + (48B C - 528A B)D
+--R                            + 
+--R                                3         2       2      2          2       3
+--R                            (12C  - 120A C  + (24B  + 20A )C + 32A B  + 152A )D
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 224D  - 800B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (720C  - 2080A C - 512B  - 1392A )D
+--R                            + 
+--R                                    2                 3       2
+--R                              (16B C  - 672A B C + 64B  + 720A B)D
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (160C + 2976A)D  + (576B C + 1088A B)D
+--R                            + 
+--R                                        3         2        2       2
+--R                                  - 608C  + 416A C  + (288B  + 992A )C
+--R                                + 
+--R                                           2      3
+--R                                  - 1120A B  - 32A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              256D  - 256B D
+--R                            + 
+--R                                     2                 2       2  2
+--R                              (- 192C  - 1664A C - 640B  - 960A )D
+--R                            + 
+--R                                       2                   3       2
+--R                              (- 448B C  - 1152A B C - 128B  - 192A B)D
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                      3            2
+--R                              - 512A D  + 4096A B D
+--R                            + 
+--R                                     3          2       2          2        3
+--R                              (- 256C  + 1024A C  + 256A C - 512A B  - 1024A )D
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             4       3    7
+--R                          (8D  + 8B D )a b
+--R                        + 
+--R                                            3                    2
+--R                              (141C - 755A)D  + (- 6B C + 58A B)D
+--R                            + 
+--R                                  3        2        2     2         2      3
+--R                              (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    4        3
+--R                              - 284D  - 36B D
+--R                            + 
+--R                                     2                2       2  2
+--R                              (- 276C  + 888A C + 228B  + 588A )D
+--R                            + 
+--R                                    2                 3       2
+--R                              (12B C  + 312A B C - 20B  - 276A B)D
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (- 32C - 2016A)D  + (192B C - 3072A B)D
+--R                            + 
+--R                                      3         2       2       2           2
+--R                                  320C  - 720A C  + (96B  - 192A )C + 672A B
+--R                                + 
+--R                                      3
+--R                                  848A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 896D  - 384B D
+--R                            + 
+--R                                    2                 2       2  2
+--R                              (1344C  + 1408A C + 896B  + 576A )D
+--R                            + 
+--R                                      2                   3        2
+--R                              (1088B C  + 1920A B C + 384B  + 1344A B)D
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 640C + 4224A)D  + (768B C - 8448A B)D
+--R                            + 
+--R                                        3          2        2       2
+--R                                  - 128C  - 1920A C  + (384B  + 640A )C
+--R                                + 
+--R                                          2        3
+--R                                  - 128A B  + 2432A
+--R                             *
+--R                                D
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 256D  - 1280B D
+--R                            + 
+--R                                    2                 2        2  2
+--R                              (3072C  - 4096A C - 512B  - 3072A )D
+--R                            + 
+--R                                      2       3        2
+--R                              (1024B C  + 512B  + 3072A B)D
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                     3            2
+--R                              2048A D  + 2048A B D
+--R                            + 
+--R                                    3         2        2           2       3
+--R                            (- 2048C  + 512A C  + 2048A C - 4096A B  - 512A )D
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                        3   8
+--R                          (- 16C + 80A)D a b
+--R                        + 
+--R                                  4         3       2               2      2  2
+--R                              146D  + 118B D  + (30C  - 100A C - 26B  - 66A )D
+--R                            + 
+--R                                     2               3      2
+--R                              (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (726C - 2090A)D  + (- 180B C + 1100A B)D
+--R                            + 
+--R                                       3         2         2      2           2
+--R                                  - 62C  + 230A C  + (- 90B  - 58A )C - 154A B
+--R                                + 
+--R                                        3
+--R                                  - 350A
+--R                             *
+--R                                D
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              1752D  + 2760B D
+--R                            + 
+--R                                      2                 2        2  2
+--R                              (- 2160C  + 3840A C + 696B  + 2736A )D
+--R                            + 
+--R                                       2                  3        2
+--R                              (- 528B C  + 576A B C - 312B  - 2160A B)D
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                       3                         2
+--R                              - 8160A D  + (- 4608B C + 5376A B)D
+--R                            + 
+--R                                      3         2           2        2
+--R                                  864C  + 192A C  + (- 2304B  - 3936A )C
+--R                                + 
+--R                                        2        3
+--R                                  960A B  - 3264A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              1152D  + 4224B D
+--R                            + 
+--R                                      2                   2        2  2
+--R                              (- 5760C  + 11520A C + 2304B  + 8064A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 1152B C  + 2304A B C - 768B  - 5760A B)D
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                3                         2
+--R                              (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D
+--R                            + 
+--R                                       3          2           2        2
+--R                                  3840C  - 3072A C  + (- 2304B  - 6912A )C
+--R                                + 
+--R                                         2
+--R                                  6912A B
+--R                             *
+--R                                D
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 512D  + 512B D
+--R                            + 
+--R                                    2                  2       2  2
+--R                              (3840C  + 2560A C + 2048B  + 768A )D
+--R                            + 
+--R                                      2                    3        2
+--R                              (2816B C  + 4608A B C + 1024B  + 3840A B)D
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                     3            2
+--R                              2048A D  - 8192A B D
+--R                            + 
+--R                                    3          2        2           2        3
+--R                            (- 1024C  - 2048A C  + 1024A C - 2048A B  + 2048A )D
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                4        3    9
+--R                          (- 16D  - 16B D )a b
+--R                        + 
+--R                                              3                    2
+--R                              (- 308C + 972A)D  + (24B C - 104A B)D
+--R                            + 
+--R                                 3        2       2      2          2      3
+--R                              (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 456D  - 920B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (744C  - 1712A C - 376B  - 1176A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              (104B C  - 432A B C + 88B  + 744A B)D
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                                3                      2
+--R                              (- 1668C + 8316A)D  + (1656B C - 136A B)D
+--R                            + 
+--R                                        3         2        2        2
+--R                                  - 364C  + 380A C  + (828B  + 1468A )C
+--R                                + 
+--R                                          2       3
+--R                                  - 452A B  + 724A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     4          3
+--R                              - 2496D  - 6432B D
+--R                            + 
+--R                                    2                   2        2  2
+--R                              (5328C  - 14304A C - 3408B  - 9648A )D
+--R                            + 
+--R                                     2                   3        2
+--R                              (336B C  - 4320A B C + 528B  + 5328A B)D
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              3                        2
+--R                              (6528C + 3456A)D  + (11520B C + 7296A B)D
+--R                            + 
+--R                                         3          2         2         2
+--R                                  - 3072C  + 4704A C  + (5760B  + 10752A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 4224A B  + 2976A
+--R                             *
+--R                                D
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                   4         3
+--R                              1024D  - 512B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 5760C  - 3840A C - 3072B  - 1152A )D
+--R                            + 
+--R                                        2                    3        2
+--R                              (- 4224B C  - 6912A B C - 1536B  - 5760A B)D
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              3                          2
+--R                              (1280C - 6912A)D  + (- 1536B C + 12800A B)D
+--R                            + 
+--R                                       3          2          2        2
+--R                                  1280C  + 2816A C  + (- 768B  - 2304A )C
+--R                                + 
+--R                                         2        3
+--R                                  2304A B  - 3840A
+--R                             *
+--R                                D
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                     3
+--R                              2048B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                            + 
+--R                                        2        3        2
+--R                              (- 2048B C  - 1024B  - 6144A B)D
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                         2
+--R                              - 8192A B D
+--R                            + 
+--R                                  3          2        2           2        3
+--R                            (4096C  - 2048A C  - 4096A C + 8192A B  + 2048A )D
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                  3   10
+--R                      (32C - 96A)D a b
+--R                    + 
+--R                             4        3         2               2       2  2
+--R                          24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (376C - 1416A)D  + (- 144B C - 144A B)D
+--R                        + 
+--R                              3        2         2       2          2      3
+--R                          (40C  - 72A C  + (- 72B  - 136A )C + 56A B  - 24A )D
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          360D  + 1080B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 936C  + 2608A C + 632B  + 1752A )D
+--R                        + 
+--R                                  2                 3       2
+--R                          (- 40B C  + 816A B C - 88B  - 936A B)D
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                          3                         2
+--R                          (- 24C - 4248A)D  + (- 2160B C - 2160A B)D
+--R                        + 
+--R                                  3          2           2        2           2
+--R                              536C  - 1080A C  + (- 1080B  - 1976A )C + 712A B
+--R                            + 
+--R                                    3
+--R                              - 360A
+--R                         *
+--R                            D
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                               4          3
+--R                          1152D  + 3456B D
+--R                        + 
+--R                                  2                  2        2  2
+--R                          (- 1296C  + 7968A C + 2400B  + 5040A )D
+--R                        + 
+--R                                 2                  3        2
+--R                          (816B C  + 3744A B C + 96B  - 1296A B)D
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D
+--R                        + 
+--R                                  3          2           2        2           2
+--R                              960C  - 3456A C  + (- 3456B  - 5568A )C + 768A B
+--R                            + 
+--R                                     3
+--R                              - 1152A
+--R                         *
+--R                            D
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1536D  - 4608B D
+--R                        + 
+--R                                 2                   2        2  2
+--R                          (11520C  - 12800A C - 1024B  - 9984A )D
+--R                        + 
+--R                                  2                    3         2
+--R                          (4352B C  + 1536A B C + 2048B  + 11520A B)D
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (6656C - 1536A)D  + (9216B C + 9216A B)D
+--R                        + 
+--R                                     3          2         2         2
+--R                              - 5632C  + 4608A C  + (4608B  + 11776A )C
+--R                            + 
+--R                                       2        3
+--R                              - 9728A B  + 1536A
+--R                         *
+--R                            D
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                  2        2  2
+--R                          (- 9216C  + 2048A C - 2048B  + 3072A )D
+--R                        + 
+--R                                    2                    3        2
+--R                          (- 5120B C  - 6144A B C - 2048B  - 9216A B)D
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                            3        2           2    11
+--R                      (4096C  - 4096A C + 8192A B )D a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                        4 2 8
+--R                  - 8A D a c
+--R                + 
+--R                          4   2        4         3  2
+--R                      2A D a b  + (4B D  + 8A C D )a b
+--R                    + 
+--R                                  4          3     3 2  3
+--R                      ((8C - 32A)D  + 32A B D  - 8A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            4         3    3
+--R                      (- B D  - 2A C D )a b
+--R                    + 
+--R                                     4                    3     3 2  2 2
+--R                      ((- 6C + 100A)D  + (- 4B C - 16A B)D  + 2A D )a b
+--R                    + 
+--R                               5        4        2              2      2  3
+--R                          - 12D  + 12B D  + (- 8C  - 16A C - 16B  - 52A )D
+--R                        + 
+--R                                          2   2          3     3
+--R                          (- 24A B C + 12A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      4                      3
+--R                          (32C + 24A)D  + (- 48B C + 128A B)D
+--R                        + 
+--R                              2         2      3  2       4     3 2
+--R                          (48A C - 24A B  - 32A )D  + 8A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 4                3    4
+--R                      ((C - 22A)D  + (B C + 2A B)D )a b
+--R                    + 
+--R                            5        4      2             2      2  3
+--R                          7D  - 45B D  + (6C  - 80A C + 8B  + 25A )D
+--R                        + 
+--R                                      2   2        3     3
+--R                          (6A B C - 3A B)D  + (2A C  - 2A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 88C + 118A)D  + (52B C - 312A B)D
+--R                        + 
+--R                                2       2      2          2      3  2
+--R                          (60A C  + (12B  - 12A )C + 18A B  + 80A )D
+--R                        + 
+--R                               3          2      2            4     3 2
+--R                          (4B C  + 24A B C  - 12A B C)D - 2A C  + 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5        4       2              2       2  3
+--R                          - 36D  + 52B D  + (32C  - 48A C - 44B  - 176A )D
+--R                        + 
+--R                                2                3      2   2
+--R                          (48B C  - 48A B C + 12B  + 96A B)D
+--R                        + 
+--R                             4        3      2 2      3       4         4
+--R                          (8C  - 64A C  + 12A C  + 40A C - 12A )D - 4B C
+--R                        + 
+--R                                   3      2   2
+--R                          - 24A B C  + 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4                      3
+--R                          224A D  + (- 192B C - 96A B)D
+--R                        + 
+--R                                  2       2       2          2     3  2
+--R                          (- 72A C  + (96B  + 192A )C - 96A B  + 8A )D
+--R                        + 
+--R                                  3      2           3       5        4      2 3
+--R                          (- 16B C  - 48A B C - 32A B )D - 8C  + 32A C  - 16A C
+--R                        + 
+--R                                2      3  2      4      3 2
+--R                          (24A B  - 32A )C  + 24A C + 8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          5        4       2            2     2  3    5
+--R                      (- D  + 10B D  + (- C  + 20A C - B  - 3A )D )a b
+--R                    + 
+--R                                       4                    3
+--R                          (53C - 389A)D  + (24B C + 134A B)D
+--R                        + 
+--R                                  2     2        2      3  2
+--R                          (- 15A C  - 3B C - 3A B  - 17A )D
+--R                        + 
+--R                                3         2     2
+--R                          (- B C  - 6A B C  + 3A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              5        4       2                2       2  3
+--R                          127D  - 63B D  + (48C  + 240A C + 147B  + 534A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (- 60B C  + 144A B C - 11B  - 150A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 6C  + 72A C  + (- 12B  - 15A )C
+--R                            + 
+--R                                      2      3       4
+--R                              (- 12A B  - 82A )C + 3A
+--R                         *
+--R                            D
+--R                        + 
+--R                             4         3     2   2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 164C - 696A)D  + (448B C - 184A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 96C  + 138A C  + (- 132B  - 636A )C + 192A B
+--R                            + 
+--R                                 3
+--R                              10A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                               3          2      2           3      3        5
+--R                          (4B C  + 96A B C  - 60A B C + 32A B  + 24A B)D + 6C
+--R                        + 
+--R                                 4       2      2  3        2      3  2     4
+--R                          - 64A C  + (12B  + 16A )C  + (6A B  + 80A )C  - 6A C
+--R                        + 
+--R                              3 2
+--R                          - 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             5         4        2               2       2  3
+--R                          24D  + 120B D  + (116C  + 472A C - 56B  + 196A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (12B C  - 24A B C + 24B  + 156A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              92C  - 64A C  + (12B  + 144A )C
+--R                            + 
+--R                                    2      3        4       2 2      4
+--R                              (72A B  + 48A )C + 16B  + 108A B  - 60A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3         3      2   2
+--R                          20B C  - 80A B C  + (- 12B  + 48A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          4           3
+--R                          (- 128C + 128A)D  - 896A B D
+--R                        + 
+--R                              3         2        2      2          2       3  2
+--R                          (48C  - 288A C  + (384B  - 48A )C + 96A B  + 160A )D
+--R                        + 
+--R                                     3          2         3       2            3
+--R                              - 64B C  + 96A B C  + (- 64B  - 192A B)C - 128A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4         2      2  3        2 2
+--R                          - 32C  + 16A C  + (- 16B  - 64A )C  + 96A B C
+--R                        + 
+--R                                2 2      4          4      3 2      5
+--R                          (- 48A B  + 96A )C + 32A B  + 32A B  - 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                    4                    3    6
+--R                      ((- 8C + 80A)D  + (- 8B C - 16A B)D )a b
+--R                    + 
+--R                               5         4         2               2       2  3
+--R                          - 62D  + 158B D  + (- 47C  + 239A C - 66B  - 218A )D
+--R                        + 
+--R                                2               3      2   2
+--R                          (12B C  - 30A B C + 2B  + 30A B)D
+--R                        + 
+--R                            4        3      2     2  2        2      3
+--R                          (C  - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (229C + 559A)D  + (- 438B C + 584A B)D
+--R                        + 
+--R                              3         2        2       2          2       3  2
+--R                          (64C  - 444A C  + (- 3B  + 213A )C - 93A B  - 175A )D
+--R                        + 
+--R                                     3           2      3       2          3
+--R                              - 10B C  - 180A B C  + (8B  + 144A B)C - 6A B
+--R                            + 
+--R                                  3
+--R                              - 6A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2     2  3          2      3  2
+--R                          - C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5         4          2                2       2  3
+--R                          36D  - 340B D  + (- 237C  - 638A C + 116B  + 123A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 123B C  + 102A B C - 68B  - 363A B)D
+--R                        + 
+--R                                   4         3        2       2  2
+--R                              - 95C  + 312A C  + (- 3B  - 138A )C
+--R                            + 
+--R                                      2       3        4      2 2       4
+--R                              (- 66A B  - 120A )C - 16B  - 99A B  + 105A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4           3        3       2   2
+--R                          5B C  + 176A B C  + (- 5B  - 138A B)C
+--R                        + 
+--R                                3      3        2 3     4
+--R                          (10A B  + 16A B)C + 3A B  + 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (276C - 916A)D  + (416B C + 2048A B)D
+--R                        + 
+--R                                    3         2           2       2          2
+--R                              - 252C  + 636A C  + (- 1032B  - 516A )C - 72A B
+--R                            + 
+--R                                    3
+--R                              - 380A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3           2       2            3      3
+--R                          (- 40B C  - 216A B C  + 168A B C + 256A B  - 40A B)D
+--R                        + 
+--R                             5        4      2       2  3            2      3  2
+--R                          56C  - 80A C  + (4B  + 128A )C  + (- 132A B  + 64A )C
+--R                        + 
+--R                              4       2 2       4         4      3 2      5
+--R                          (20B  + 156A B  - 184A )C - 4A B  - 28A B  + 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              5         4          2               2        2  3
+--R                          144D  - 176B D  + (- 368C  + 736A C - 64B  + 1040A )D
+--R                        + 
+--R                                   2                  2   2
+--R                          (- 528B C  - 480A B C - 528A B)D
+--R                        + 
+--R                                  4        3        2      2  2
+--R                              128C  + 64A C  + (240B  + 96A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (288A B  - 128A )C + 48B  + 240A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4       3      2   2            3      3
+--R                          96B C  + (16B  + 96A B)C  + (- 160A B  - 64A B)C
+--R                        + 
+--R                               5       2 3
+--R                          - 16B  - 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 128C - 384A)D  + (768B C - 512A B)D
+--R                        + 
+--R                               3       2          2       3  2
+--R                          (192C  - 960A C + 768A B  + 128A )D
+--R                        + 
+--R                                   2       3        3           4      2 3
+--R                          (384A B C  - 256B C + 128A B)D - 64A C  - 64B C
+--R                        + 
+--R                              3 2       2 2          4      5
+--R                          128A C  - 192A B C + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         5        4      2             2      2  3    7
+--R                      (8D  - 32B D  + (8C  - 64A C + 8B  + 24A )D )a b
+--R                    + 
+--R                                          4                   3
+--R                          (- 118C + 412A)D  + (2B C - 264A B)D
+--R                        + 
+--R                                3        2      2      2          2      3  2
+--R                          (- 10C  + 96A C  + (6B  - 18A )C + 12A B  + 36A )D
+--R                        + 
+--R                               3          2        3      2
+--R                          (2B C  + 36A B C  + (- 2B  - 30A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5        4
+--R                          - 287D  + 30B D
+--R                        + 
+--R                                2                2        2  3
+--R                          (- 28C  - 682A C - 308B  - 1180A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (240B C  - 168A B C + 50B  + 414A B)D
+--R                        + 
+--R                                 4         3       2      2  2
+--R                              35C  - 170A C  + (54B  + 78A )C
+--R                            + 
+--R                                    2       3       4      2 2      4
+--R                              (66A B  + 198A )C + 3B  + 18A B  - 21A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      3      2   2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (81C + 1825A)D  + (- 528B C - 1756A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                572C  - 60A C  + (936B  + 2010A )C - 108A B
+--R                              + 
+--R                                    3
+--R                                658A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2            3
+--R                              92B C  - 120A B C  + (20B  + 264A B)C - 160A B
+--R                            + 
+--R                                    3
+--R                              - 100A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5         4         2      2  3
+--R                          - 29C  + 119A C  + (- 54B  - 80A )C
+--R                        + 
+--R                                  2       3  2        4      2 2      4        4
+--R                          (- 30A B  - 188A )C  + (- 5B  - 36A B  + 37A )C - A B
+--R                        + 
+--R                            3 2     5
+--R                          4A B  - 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 412D  + 132B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (466C  - 2484A C + 248B  - 2718A )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (1374B C  + 996A B C + 120B  + 702A B)D
+--R                        + 
+--R                                    4         3         2       2  2
+--R                              - 366C  - 192A C  + (- 18B  - 492A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 396A B  + 208A )C - 108B  - 690A B  + 170A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4          3       3       2   2
+--R                          - 190B C  + 96A B C  + (34B  - 204A B)C
+--R                        + 
+--R                                 3       3        5      2 3      4
+--R                          (220A B  + 304A B)C + 4B  + 82A B  + 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         4                        3
+--R                          (936C + 1176A)D  + (- 768B C + 1536A B)D
+--R                        + 
+--R                                 3         2          2        2            2
+--R                              24C  + 696A C  + (- 240B  + 3144A )C - 1392A B
+--R                            + 
+--R                                  3
+--R                              200A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2        3       2
+--R                              - 144B C  - 1296A B C  + (320B  + 336A B)C
+--R                            + 
+--R                                   3       3
+--R                              64A B  - 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2      2  3
+--R                          16C  + 80A C  + (- 8B  + 32A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 168A B  - 320A )C  + (40B  + 552A B  - 176A )C
+--R                        + 
+--R                                  4     3 2       5
+--R                          - 168A B  + 8A B  + 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                             5         4          2                 2       2  3
+--R                          96D  - 672B D  + (- 768C  - 1536A C + 384B  + 192A )D
+--R                        + 
+--R                                   2                   2   2
+--R                          (- 384B C  - 384A B C - 1344A B)D
+--R                        + 
+--R                                    4        2       2  2       3       4
+--R                              - 352C  + (384B  - 768A )C  - 384A C - 32B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 224A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3 2       3         5
+--R                          - 32B C  + 256A B C  + 128B C  + 384A B C - 32B
+--R                        + 
+--R                                2 3       4
+--R                          - 128A B  + 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  4                      3
+--R                          - 384A D  + (768B C + 1536A B)D
+--R                        + 
+--R                                  2           2       2           2       3  2
+--R                          (1152A C  + (- 1536B  - 768A )C + 384A B  - 128A )D
+--R                        + 
+--R                                 3       2            3         5         4
+--R                          (256B C  + 768A B C + 512A B )D + 128C  - 128A C
+--R                        + 
+--R                              2 3            2       3  2       4        3 2
+--R                          256A C  + (- 384A B  + 128A )C  - 384A C - 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                   4                   3    8
+--R                      ((16C - 96A)D  + (16B C + 32A B)D )a b
+--R                    + 
+--R                              5         4       2                2       2  3
+--R                          136D  - 168B D  + (92C  - 188A C + 136B  + 472A )D
+--R                        + 
+--R                                  2               3      2   2
+--R                          (- 48B C  + 24A B C - 8B  - 72A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 20A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 36A )C
+--R                         *
+--R                            D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 12C - 1996A)D  + (864B C + 640A B)D
+--R                        + 
+--R                                    3         2          2       2          2
+--R                              - 296C  + 720A C  + (- 252B  - 732A )C + 36A B
+--R                            + 
+--R                                   3
+--R                              - 84A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2           3
+--R                              - 48B C  + 288A B C  + (- 40B  - 408A B)C + 24A B
+--R                            + 
+--R                                 3
+--R                              24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3         2      3  2
+--R                          4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          636D  + 544B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 104C  + 3740A C + 120B  + 3228A )D
+--R                        + 
+--R                                    2                 3       2   2
+--R                          (- 1380B C  - 912A B C - 96B  - 804A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              188C  - 300A C  + (- 192B  + 156A )C
+--R                            + 
+--R                                     2       3        4       2 2       4
+--R                              (108A B  - 340A )C + 76B  + 468A B  - 216A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          68B C  - 272A B C  + (28B  + 384A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            4                        3
+--R                          (- 1528C - 1376A)D  + (- 520B C - 1200A B)D
+--R                        + 
+--R                                    3          2        2        2            2
+--R                              - 544C  - 1968A C  + (132B  - 4740A )C + 1068A B
+--R                            + 
+--R                                     3
+--R                              - 1012A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2           3
+--R                              360B C  + 1584A B C  + (- 16B  - 480A B)C - 56A B
+--R                            + 
+--R                                  3
+--R                              600A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3
+--R                          - 8C  - 64A C  + (188B  - 28A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (252A B  + 412A )C  + (- 100B  - 768A B  + 308A )C
+--R                        + 
+--R                               4      3 2      5
+--R                          12A B  - 64A B  - 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 304D  + 944B D
+--R                        + 
+--R                               2                  2       2  3
+--R                          (708C  + 3096A C - 1072B  - 268A )D
+--R                        + 
+--R                                   2                  3        2   2
+--R                          (- 132B C  + 360A B C - 208B  + 2028A B)D
+--R                        + 
+--R                                  4         3          2        2  2
+--R                              636C  + 448A C  + (- 996B  + 1512A )C
+--R                            + 
+--R                                      2       3        4       2 2       4
+--R                              (- 24A B  + 576A )C + 80B  + 924A B  - 356A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3      2   2
+--R                          108B C  - 256A B C  + (- 252B  - 24A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (120A B  - 768A B)C + 80B  + 356A B  - 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                        4                         3
+--R                          (48C + 1776A)D  + (- 1728B C - 3456A B)D
+--R                        + 
+--R                               3          2         2        2         3  2
+--R                          (816C  - 2928A C  + (3168B  + 1680A )C + 432A )D
+--R                        + 
+--R                                    3          2        3      2            3
+--R                              224B C  + 96A B C  + (256B  - 96A B)C - 768A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2       2  3
+--R                          - 160C  + 160A C  + (48B  - 384A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (336A B  - 160A )C  + (- 80B  - 432A B  + 544A )C
+--R                        + 
+--R                                  4      3 2
+--R                          - 112A B  + 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  4        2                 2        2  3
+--R                          - 384B D  + (960C  - 2688A C + 960B  - 1344A )D
+--R                        + 
+--R                                  2                   3       2   2
+--R                          (1344B C  + 2688A B C - 192B  + 576A B)D
+--R                        + 
+--R                                    4         3          2       2  2
+--R                              - 640C  + 768A C  + (- 960B  - 576A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1152A B  - 128A )C - 192B  - 960A B  + 320A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3         3       2   2
+--R                          - 320B C  + 384A B C  + (- 64B  - 576A B)C
+--R                        + 
+--R                                 3       3         5       2 3
+--R                          (640A B  + 256A B)C + 64B  + 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   3
+--R                          1536A B D
+--R                        + 
+--R                                    3          2           2       2
+--R                              - 768C  + 1152A C  + (- 1536B  + 768A )C
+--R                            + 
+--R                                       2       3
+--R                              - 1536A B  - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2
+--R                              256B C  - 1536A B C  + (1024B  + 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4        2       2  3         2 2
+--R                          128C  - 256A C  + (256B  + 256A )C  - 384A B C
+--R                        + 
+--R                               2 2       4           4       3 2       5
+--R                          (768A B  - 384A )C - 512A B  - 128A B  + 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                        5        4         2              2      2  3    9
+--R                  (- 16D  + 32B D  + (- 16C  + 64A C - 16B  - 48A )D )a b
+--R                + 
+--R                                  4                      3
+--R                      (8C + 224A)D  + (- 136B C - 64A B)D
+--R                    + 
+--R                          3         2       2      2    2
+--R                      (40C  - 144A C  + (24B  + 72A )C)D
+--R                    + 
+--R                           3          2      3      2
+--R                      (8B C  - 48A B C  + (8B  + 72A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            5        4         2               2       2  3
+--R                      - 148D  + 88B D  + (- 64C  - 104A C - 64B  - 592A )D
+--R                    + 
+--R                             2                3      2   2
+--R                      (192B C  + 192A B C + 8B  + 72A B)D
+--R                    + 
+--R                               4        3       2      2  2           2      3
+--R                          - 28C  + 88A C  + (24B  - 24A )C  + (- 24A B  + 24A )C
+--R                        + 
+--R                               4      2 2      4
+--R                          - 12B  - 72A B  + 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4          3        3      2   2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (212C + 1532A)D  + (- 664B C - 112A B)D
+--R                    + 
+--R                           3         2         2       2           2      3  2
+--R                      (232C  - 528A C  + (- 24B  + 864A )C - 144A B  + 88A )D
+--R                    + 
+--R                                   3           2       3       2           3
+--R                            - 40B C  - 528A B C  + (40B  + 456A B)C + 32A B
+--R                          + 
+--R                                 3
+--R                            - 80A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        5        4         2      2  3           2      3  2
+--R                      4C  - 12A C  + (- 24B  + 16A )C  + (- 24A B  - 32A )C
+--R                    + 
+--R                          4       2 2      4         4      3 2      5
+--R                      (20B  + 144A B  - 52A )C + 4A B  + 16A B  + 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                            5          4        2                 2        2  3
+--R                      - 124D  - 1208B D  + (248C  - 4328A C + 416B  - 1336A )D
+--R                    + 
+--R                              2                  3       2   2
+--R                      (1176B C  + 912A B C + 104B  + 240A B)D
+--R                    + 
+--R                                4         3        2       2  2
+--R                          - 188C  + 424A C  + (384B  - 264A )C
+--R                        + 
+--R                                  2       3        4       2 2       4
+--R                          (- 24A B  + 136A )C - 68B  - 480A B  + 244A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3         3       2   2
+--R                      - 32B C  + 304A B C  + (- 16B  - 408A B)C
+--R                    + 
+--R                              3      3         5      2 3      4
+--R                      (- 80A B  + 64A B)C - 16B  - 88A B  + 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      4                       3
+--R                      (1028C - 2044A)D  + (3104B C + 2864A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 560C  + 4512A C  + (- 1536B  + 1848A )C - 816A B
+--R                        + 
+--R                              3
+--R                          616A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3           2          3       2            3
+--R                          - 736B C  - 768A B C  + (- 304B  - 912A B)C + 224A B
+--R                        + 
+--R                                3
+--R                          - 496A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4          2       2  3
+--R                      28C  - 52A C  + (- 200B  + 112A )C
+--R                    + 
+--R                               2       3  2        4       2 2       4
+--R                      (- 168A B  - 224A )C  + (140B  + 912A B  - 364A )C
+--R                    + 
+--R                           4       3 2      5
+--R                      92A B  + 112A B  + 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                          5          4           2                 2        2  3
+--R                      288D  + 1088B D  + (- 1896C  + 4752A C - 720B  + 2552A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 2712B C  - 4560A B C + 272B  - 2424A B)D
+--R                    + 
+--R                              4          3         2       2  2
+--R                          280C  - 2048A C  + (1320B  - 480A )C
+--R                        + 
+--R                                  2       3         4       2 2       4
+--R                          (1200A B  - 416A )C + 208B  + 744A B  - 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3        2   2
+--R                      232B C  - 608A B C  + (344B  + 1248A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 560A B  + 448A B)C - 112B  - 616A B  + 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                       4                         3
+--R                      (- 1248C + 288A)D  + (- 2304B C - 2688A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          1056C  - 3840A C  + (1536B  - 3552A )C + 2496A B
+--R                        + 
+--R                                3
+--R                          - 704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2          3       2            3
+--R                          768B C  + 2880A B C  + (- 768B  + 384A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          1088A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4         2       2  3
+--R                      - 32C  + 320A C  + (- 32B  - 128A )C
+--R                    + 
+--R                             2       3  2          4        2 2       4
+--R                      (192A B  + 256A )C  + (- 160B  - 1824A B  + 416A )C
+--R                    + 
+--R                            4       3 2       5
+--R                      416A B  - 128A B  - 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                2       2  3
+--R                      (1728C  - 384A C + 384B  - 576A )D
+--R                    + 
+--R                              2                   3        2   2
+--R                      (1344B C  + 3456A B C - 384B  + 2112A B)D
+--R                    + 
+--R                               4          3           2       2  2
+--R                          - 64C  + 1536A C  + (- 1728B  + 768A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1152A B  + 256A )C - 128B  - 192A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3       2   2
+--R                      - 192B C  + 256A B C  + (- 320B  - 768A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (640A B  - 512A B)C + 128B  + 704A B  - 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                             3       2           2  2
+--R                      (- 768C  + 768A C - 1536A B )D
+--R                    + 
+--R                                  2        3        3            4       2 3
+--R                      (- 1536A B C  + 1024B C - 512A B)D - 256A C  + 256B C
+--R                    + 
+--R                          2 2          4       5
+--R                      768A B C - 512A B  + 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                %%BN1
+--R            + 
+--R                       3 3 8
+--R                  16A D a c
+--R                + 
+--R                            3 2 2          3          2  3
+--R                      - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                    + 
+--R                                     3          2         2      3    4
+--R                      ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           3         2  2 3
+--R                      (2B D  + 6A C D )a b
+--R                    + 
+--R                                    3                   2        2      3    3 2
+--R                      ((12C - 188A)D  + (12B C + 52A B)D  + (4A C  - 12A )D)a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 64C - 32A)D  + (96B C - 320A B)D
+--R                        + 
+--R                                3        2       2          2      3
+--R                          (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                        + 
+--R                                   2      3
+--R                          - 48A B C  - 16A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                      3                   2          2     3
+--R                        ((- 2C + 41A)D  + (- 3B C - 8A B)D  + (- 2A C  + 2A )D)
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 80B D  + (- 18C  + 224A C - 26B  - 66A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                        3                       2
+--R                          (144C - 232A)D  + (- 120B C + 808A B)D
+--R                        + 
+--R                             3         2         2      2           2       3
+--R                          (4C  - 212A C  + (- 24B  + 20A )C - 112A B  - 196A )D
+--R                        + 
+--R                              3          2      2        3
+--R                          4B C  + 36A B C  - 12A B C + 4A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                        + 
+--R                                  2                3       2        4        3
+--R                          (- 80B C  + 96A B C - 64B  - 336A B)D + 8C  + 32A C
+--R                        + 
+--R                              2      2  2         2      3        2 2     4
+--R                          (24B  + 48A )C  + (48A B  + 32A )C + 24A B  + 8A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                  3                     2
+--R                          - 384A D  + (384B C + 128A B)D
+--R                        + 
+--R                                3         2          2       2           2
+--R                          (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                        + 
+--R                               3           2       2           3      3
+--R                          64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4        3      2             2     2  2
+--R                          2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                        + 
+--R                              2              2
+--R                          (B C  + 6A B C - 3A B)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                        + 
+--R                             3       2       2      2          2       3
+--R                          (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                        + 
+--R                               3         2     2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                4        3
+--R                          - 224D  + 92B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 162C  - 280A C - 320B  - 1206A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (172B C  - 336A B C + 60B  + 492A B)D - 6C  + 48A C
+--R                        + 
+--R                                2      2  2           2      3       2 2     4
+--R                          (- 18B  - 24A )C  + (- 24A B  - 80A )C - 6A B  - 2A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                            + 
+--R                                 3
+--R                              64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2         3       2           3
+--R                          - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                        + 
+--R                              3
+--R                          144A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               4         3          2               2       2  2
+--R                          - 64D  - 256B D  + (- 144C  - 608A C + 32B  - 336A )D
+--R                        + 
+--R                                  2      3       2         4        3
+--R                          (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                        + 
+--R                                2      2  2         2       3        4       2 2
+--R                          (- 48B  - 96A )C  + (96A B  - 224A )C + 32B  + 144A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                        3            2
+--R                          (256C - 256A)D  + 1792A B D
+--R                        + 
+--R                                   3         2          2      2           2
+--R                              - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                            + 
+--R                                    3
+--R                              - 256A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3       2            3
+--R                          256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       3                   2
+--R                          (13C - 139A)D  + (18B C + 58A B)D
+--R                        + 
+--R                              3        2        2     2         2      3
+--R                          (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              4         3        2                2       2  2
+--R                          109D  - 265B D  + (114C  - 591A C + 183B  + 543A )D
+--R                        + 
+--R                                  2                 3       2       4        3
+--R                          (- 27B C  + 228A B C - 19B  - 225A B)D + C  - 13A C
+--R                        + 
+--R                             2     2  2        2      3
+--R                          (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                            + 
+--R                                  3
+--R                              346A
+--R                         *
+--R                            D
+--R                        + 
+--R                               3           2       3       2          3      3
+--R                          10B C  - 234A B C  + (14B  + 174A B)C - 2A B  - 30A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                3        2               2       2  2
+--R                          768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                        + 
+--R                                 2                 3        2            3
+--R                          (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                        + 
+--R                                2       2  2            2       3        4
+--R                          (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                        + 
+--R                                2 2      4
+--R                          - 240A B  - 64A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                           3                        2
+--R                          (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                        + 
+--R                                  3         2         2        2           2
+--R                              416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                            + 
+--R                                  3
+--R                              992A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 480B C  + 672A B C  + (- 128B  - 1632A B)C + 512A B
+--R                        + 
+--R                              3
+--R                          160A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 256D  + 384B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (192C  - 1024A C + 256B  - 2112A )D
+--R                        + 
+--R                                 2                  3        2          4
+--R                          (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                        + 
+--R                                 2       2  2            2       3         2 2
+--R                          (- 576B  - 384A )C  + (- 384A B  - 512A )C + 192A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                        + 
+--R                                   2        2           2       3         3
+--R                          (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 54B D  + (- 18C  + 140A C - 26B  - 66A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                        3                      2
+--R                          (142C - 688A)D  + (- 54B C + 800A B)D
+--R                        + 
+--R                                    3         2         2      2           2
+--R                                - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                              + 
+--R                                      3
+--R                                - 248A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2        3      2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              4         3       2                 2        2  2
+--R                          416D  - 190B D  + (84C  + 1254A C + 438B  + 2514A )D
+--R                        + 
+--R                                   2                  3        2         4
+--R                          (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                        + 
+--R                                 3       2       2  2          2       3       4
+--R                          - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C + 2B
+--R                        + 
+--R                             2 2      4
+--R                          48A B  + 14A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                        + 
+--R                                    3        2           2        2            2
+--R                              - 788C  - 84A C  + (- 2292B  - 4428A )C + 1404A B
+--R                            + 
+--R                                     3
+--R                              - 2252A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                        + 
+--R                                3
+--R                          - 308A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          608D  - 640B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 240C  + 3552A C - 960B  + 5232A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1632B C  - 1536A B C - 928B  - 1632A B)D + 464C
+--R                        + 
+--R                                3        2        2  2          2        3
+--R                          128A C  + (912B  + 1344A )C  + (384A B  + 1664A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 160B  - 528A B  - 16A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            3                       2
+--R                          (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 128C  - 576A C  + (192B  - 6144A )C + 4800A B
+--R                            + 
+--R                                    3
+--R                              - 704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2          3       2            3
+--R                          256B C  + 768A B C  + (- 704B  - 384A B)C + 448A B
+--R                        + 
+--R                                3
+--R                          - 128A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 128D  + 1280B D
+--R                        + 
+--R                               2                 2       2  2
+--R                          (768C  + 2560A C - 640B  - 768A )D
+--R                        + 
+--R                                 2                   2          4         3
+--R                          (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                        + 
+--R                                 2       2  2            2       3         4
+--R                          (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                        + 
+--R                                2 2       4
+--R                          - 384A B  + 128A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                3                         2
+--R                          512A D  + (- 1536B C - 2048A B)D
+--R                        + 
+--R                               3          2         2        2            2
+--R                          (256C  - 2048A C  + (3072B  + 1792A )C - 2048A B )D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                        - 1024B C  + 768A B C  - 3072A B C + 1024A B  + 256A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                         3                      2
+--R                          (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                        + 
+--R                             3        2       2      2          2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 204D  + 316B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 144C  + 364A C - 292B  - 1092A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (164B C  - 288A B C + 84B  + 636A B)D - 4C  + 20A C
+--R                        + 
+--R                                2      2  2           2      3
+--R                          (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                            + 
+--R                                  3
+--R                              996A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2         3       2          3
+--R                          - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                        + 
+--R                             3
+--R                          56A B
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 924D  - 588B D
+--R                        + 
+--R                               2                2        2  2
+--R                          (216C  - 5556A C - 60B  - 6156A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                        + 
+--R                                3          2       2  2         2        3
+--R                          708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                        + 
+--R                             4       2 2       4
+--R                          72B  + 576A B  + 120A
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                        + 
+--R                                  3          2        2        2            2
+--R                              408C  + 2760A C  + (504B  + 9096A )C - 3720A B
+--R                            + 
+--R                                   3
+--R                              2904A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3       2            3
+--R                          - 840B C  - 1656A B C  + (168B  + 360A B)C - 792A B
+--R                        + 
+--R                              3
+--R                          408A B
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          480D  - 1536B D
+--R                        + 
+--R                                 2                  2        2  2
+--R                          (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                        + 
+--R                                    2                  3        2          4
+--R                          (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                        + 
+--R                                  3        2        2  2           2        3
+--R                          - 864A C  + (576B  - 2304A )C  + (1152A B  - 2208A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          576B  + 576A B  - 384A
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                           3                       2
+--R                          (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                            + 
+--R                                     2        3
+--R                              2304A B  - 1344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                          1344B C  - 1728A B C  + 5184A B C - 1536A B  - 192A B
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                3           2                  2        2  2
+--R                          512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                        + 
+--R                                    2                   2          4         3
+--R                          (- 1280B C  - 4608A B C + 768A B)D + 640C  - 512A C
+--R                        + 
+--R                                2       2  2          2        3          2 2
+--R                          (1920B  + 768A )C  + (768A B  + 1536A )C - 1152A B
+--R                        + 
+--R                                4
+--R                          - 384A
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                     2
+--R                          - 2048A B D
+--R                        + 
+--R                                3          2         2        2            2
+--R                          (1024C  - 2048A C  + (3072B  - 1024A )C + 2048A B )D
+--R                        + 
+--R                                   3            2           3        2
+--R                          - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                        + 
+--R                                 3        3
+--R                          1024A B  + 1024A B
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                         4        3       2               2       2  2
+--R                      24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                    + 
+--R                             2               3      2
+--R                      (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                    3                    2
+--R                      (- 8C - 336A)D  + (216B C + 96A B)D
+--R                    + 
+--R                            3         2          2       2          2      3
+--R                      (- 56C  + 240A C  + (- 120B  - 184A )C + 80A B  - 96A )D
+--R                    + 
+--R                          3          2      3      2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                          4         3       2               2        2  2
+--R                      216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                    + 
+--R                               2                3       2         4         3
+--R                      (- 304B C  - 48A B C - 64B  - 384A B)D + 32C  - 120A C
+--R                    + 
+--R                        2      2  2           2       3       4      2 2      4
+--R                    (72B  + 24A )C  + (- 24A B  + 152A )C - 8B  - 96A B  - 24A
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                       3                      2
+--R                      (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                        + 
+--R                                3
+--R                          - 864A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3          2      3       2            3      3
+--R                      120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                          4          3          2                 2        2  2
+--R                      144D  + 1848B D  + (- 576C  + 6600A C - 984B  + 1800A )D
+--R                    + 
+--R                                2                   3        2          4
+--R                      (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                    + 
+--R                              3        2       2  2            2        3
+--R                      - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                    + 
+--R                            4       2 2      4
+--R                      - 120B  - 576A B  - 72A
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                    + 
+--R                                 3          2         2        2           2
+--R                            1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                          + 
+--R                                  3
+--R                            - 576A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3            2          3        2             3
+--R                      384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                    + 
+--R                            3
+--R                      - 240A B
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                            4          3
+--R                      - 384D  - 1600B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (2784C  - 7040A C + 1280B  - 3936A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                    + 
+--R                             3           2        2  2             2       3
+--R                      2304A C  + (- 2592B  + 1152A )C  + (- 1152A B  - 768A )C
+--R                    + 
+--R                            4        2 2       4
+--R                      - 384B  + 1440A B  + 864A
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                     3                       2
+--R                      (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                    + 
+--R                                 3          2           2        2            2
+--R                          - 1792C  + 5376A C  + (- 2688B  + 5632A )C - 3200A B
+--R                        + 
+--R                               3
+--R                          1536A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2         3        2             3
+--R                      - 512B C  - 6144A B C  + (2176B  + 2304A B)C - 1152A B
+--R                    + 
+--R                            3
+--R                      - 768A B
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                              2                2       2  2
+--R                      (- 2304C  + 512A C - 512B  + 768A )D
+--R                    + 
+--R                                2                    3        2          4
+--R                      (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                    + 
+--R                          4       2 2       4
+--R                      512B  - 768A B  - 768A
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                            3        2           2              2        3
+--R                      (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                    + 
+--R                           3
+--R                      1024A B
+--R                 *
+--R                     11
+--R                    a
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                        4 2 8
+--R                  - 8A D a c
+--R                + 
+--R                          4   2        4         3  2
+--R                      2A D a b  + (4B D  + 8A C D )a b
+--R                    + 
+--R                                  4          3     3 2  3
+--R                      ((8C - 32A)D  + 32A B D  - 8A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            4         3    3
+--R                      (- B D  - 2A C D )a b
+--R                    + 
+--R                                     4                    3     3 2  2 2
+--R                      ((- 6C + 100A)D  + (- 4B C - 16A B)D  + 2A D )a b
+--R                    + 
+--R                               5        4        2              2      2  3
+--R                          - 12D  + 12B D  + (- 8C  - 16A C - 16B  - 52A )D
+--R                        + 
+--R                                          2   2          3     3
+--R                          (- 24A B C + 12A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      4                      3
+--R                          (32C + 24A)D  + (- 48B C + 128A B)D
+--R                        + 
+--R                              2         2      3  2       4     3 2
+--R                          (48A C - 24A B  - 32A )D  + 8A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 4                3    4
+--R                      ((C - 22A)D  + (B C + 2A B)D )a b
+--R                    + 
+--R                            5        4      2             2      2  3
+--R                          7D  - 45B D  + (6C  - 80A C + 8B  + 25A )D
+--R                        + 
+--R                                      2   2        3     3
+--R                          (6A B C - 3A B)D  + (2A C  - 2A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 88C + 118A)D  + (52B C - 312A B)D
+--R                        + 
+--R                                2       2      2          2      3  2
+--R                          (60A C  + (12B  - 12A )C + 18A B  + 80A )D
+--R                        + 
+--R                               3          2      2            4     3 2
+--R                          (4B C  + 24A B C  - 12A B C)D - 2A C  + 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5        4       2              2       2  3
+--R                          - 36D  + 52B D  + (32C  - 48A C - 44B  - 176A )D
+--R                        + 
+--R                                2                3      2   2
+--R                          (48B C  - 48A B C + 12B  + 96A B)D
+--R                        + 
+--R                             4        3      2 2      3       4         4
+--R                          (8C  - 64A C  + 12A C  + 40A C - 12A )D - 4B C
+--R                        + 
+--R                                   3      2   2
+--R                          - 24A B C  + 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4                      3
+--R                          224A D  + (- 192B C - 96A B)D
+--R                        + 
+--R                                  2       2       2          2     3  2
+--R                          (- 72A C  + (96B  + 192A )C - 96A B  + 8A )D
+--R                        + 
+--R                                  3      2           3       5        4      2 3
+--R                          (- 16B C  - 48A B C - 32A B )D - 8C  + 32A C  - 16A C
+--R                        + 
+--R                                2      3  2      4      3 2
+--R                          (24A B  - 32A )C  + 24A C + 8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          5        4       2            2     2  3    5
+--R                      (- D  + 10B D  + (- C  + 20A C - B  - 3A )D )a b
+--R                    + 
+--R                                       4                    3
+--R                          (53C - 389A)D  + (24B C + 134A B)D
+--R                        + 
+--R                                  2     2        2      3  2
+--R                          (- 15A C  - 3B C - 3A B  - 17A )D
+--R                        + 
+--R                                3         2     2
+--R                          (- B C  - 6A B C  + 3A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              5        4       2                2       2  3
+--R                          127D  - 63B D  + (48C  + 240A C + 147B  + 534A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (- 60B C  + 144A B C - 11B  - 150A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 6C  + 72A C  + (- 12B  - 15A )C
+--R                            + 
+--R                                      2      3       4
+--R                              (- 12A B  - 82A )C + 3A
+--R                         *
+--R                            D
+--R                        + 
+--R                             4         3     2   2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 164C - 696A)D  + (448B C - 184A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 96C  + 138A C  + (- 132B  - 636A )C + 192A B
+--R                            + 
+--R                                 3
+--R                              10A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                               3          2      2           3      3        5
+--R                          (4B C  + 96A B C  - 60A B C + 32A B  + 24A B)D + 6C
+--R                        + 
+--R                                 4       2      2  3        2      3  2     4
+--R                          - 64A C  + (12B  + 16A )C  + (6A B  + 80A )C  - 6A C
+--R                        + 
+--R                              3 2
+--R                          - 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             5         4        2               2       2  3
+--R                          24D  + 120B D  + (116C  + 472A C - 56B  + 196A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (12B C  - 24A B C + 24B  + 156A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              92C  - 64A C  + (12B  + 144A )C
+--R                            + 
+--R                                    2      3        4       2 2      4
+--R                              (72A B  + 48A )C + 16B  + 108A B  - 60A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3         3      2   2
+--R                          20B C  - 80A B C  + (- 12B  + 48A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          4           3
+--R                          (- 128C + 128A)D  - 896A B D
+--R                        + 
+--R                              3         2        2      2          2       3  2
+--R                          (48C  - 288A C  + (384B  - 48A )C + 96A B  + 160A )D
+--R                        + 
+--R                                     3          2         3       2            3
+--R                              - 64B C  + 96A B C  + (- 64B  - 192A B)C - 128A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4         2      2  3        2 2
+--R                          - 32C  + 16A C  + (- 16B  - 64A )C  + 96A B C
+--R                        + 
+--R                                2 2      4          4      3 2      5
+--R                          (- 48A B  + 96A )C + 32A B  + 32A B  - 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                    4                    3    6
+--R                      ((- 8C + 80A)D  + (- 8B C - 16A B)D )a b
+--R                    + 
+--R                               5         4         2               2       2  3
+--R                          - 62D  + 158B D  + (- 47C  + 239A C - 66B  - 218A )D
+--R                        + 
+--R                                2               3      2   2
+--R                          (12B C  - 30A B C + 2B  + 30A B)D
+--R                        + 
+--R                            4        3      2     2  2        2      3
+--R                          (C  - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (229C + 559A)D  + (- 438B C + 584A B)D
+--R                        + 
+--R                              3         2        2       2          2       3  2
+--R                          (64C  - 444A C  + (- 3B  + 213A )C - 93A B  - 175A )D
+--R                        + 
+--R                                     3           2      3       2          3
+--R                              - 10B C  - 180A B C  + (8B  + 144A B)C - 6A B
+--R                            + 
+--R                                  3
+--R                              - 6A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2     2  3          2      3  2
+--R                          - C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5         4          2                2       2  3
+--R                          36D  - 340B D  + (- 237C  - 638A C + 116B  + 123A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 123B C  + 102A B C - 68B  - 363A B)D
+--R                        + 
+--R                                   4         3        2       2  2
+--R                              - 95C  + 312A C  + (- 3B  - 138A )C
+--R                            + 
+--R                                      2       3        4      2 2       4
+--R                              (- 66A B  - 120A )C - 16B  - 99A B  + 105A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4           3        3       2   2
+--R                          5B C  + 176A B C  + (- 5B  - 138A B)C
+--R                        + 
+--R                                3      3        2 3     4
+--R                          (10A B  + 16A B)C + 3A B  + 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (276C - 916A)D  + (416B C + 2048A B)D
+--R                        + 
+--R                                    3         2           2       2          2
+--R                              - 252C  + 636A C  + (- 1032B  - 516A )C - 72A B
+--R                            + 
+--R                                    3
+--R                              - 380A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3           2       2            3      3
+--R                          (- 40B C  - 216A B C  + 168A B C + 256A B  - 40A B)D
+--R                        + 
+--R                             5        4      2       2  3            2      3  2
+--R                          56C  - 80A C  + (4B  + 128A )C  + (- 132A B  + 64A )C
+--R                        + 
+--R                              4       2 2       4         4      3 2      5
+--R                          (20B  + 156A B  - 184A )C - 4A B  - 28A B  + 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              5         4          2               2        2  3
+--R                          144D  - 176B D  + (- 368C  + 736A C - 64B  + 1040A )D
+--R                        + 
+--R                                   2                  2   2
+--R                          (- 528B C  - 480A B C - 528A B)D
+--R                        + 
+--R                                  4        3        2      2  2
+--R                              128C  + 64A C  + (240B  + 96A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (288A B  - 128A )C + 48B  + 240A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4       3      2   2            3      3
+--R                          96B C  + (16B  + 96A B)C  + (- 160A B  - 64A B)C
+--R                        + 
+--R                               5       2 3
+--R                          - 16B  - 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 128C - 384A)D  + (768B C - 512A B)D
+--R                        + 
+--R                               3       2          2       3  2
+--R                          (192C  - 960A C + 768A B  + 128A )D
+--R                        + 
+--R                                   2       3        3           4      2 3
+--R                          (384A B C  - 256B C + 128A B)D - 64A C  - 64B C
+--R                        + 
+--R                              3 2       2 2          4      5
+--R                          128A C  - 192A B C + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         5        4      2             2      2  3    7
+--R                      (8D  - 32B D  + (8C  - 64A C + 8B  + 24A )D )a b
+--R                    + 
+--R                                          4                   3
+--R                          (- 118C + 412A)D  + (2B C - 264A B)D
+--R                        + 
+--R                                3        2      2      2          2      3  2
+--R                          (- 10C  + 96A C  + (6B  - 18A )C + 12A B  + 36A )D
+--R                        + 
+--R                               3          2        3      2
+--R                          (2B C  + 36A B C  + (- 2B  - 30A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5        4
+--R                          - 287D  + 30B D
+--R                        + 
+--R                                2                2        2  3
+--R                          (- 28C  - 682A C - 308B  - 1180A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (240B C  - 168A B C + 50B  + 414A B)D
+--R                        + 
+--R                                 4         3       2      2  2
+--R                              35C  - 170A C  + (54B  + 78A )C
+--R                            + 
+--R                                    2       3       4      2 2      4
+--R                              (66A B  + 198A )C + 3B  + 18A B  - 21A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      3      2   2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (81C + 1825A)D  + (- 528B C - 1756A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                572C  - 60A C  + (936B  + 2010A )C - 108A B
+--R                              + 
+--R                                    3
+--R                                658A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2            3
+--R                              92B C  - 120A B C  + (20B  + 264A B)C - 160A B
+--R                            + 
+--R                                    3
+--R                              - 100A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5         4         2      2  3
+--R                          - 29C  + 119A C  + (- 54B  - 80A )C
+--R                        + 
+--R                                  2       3  2        4      2 2      4        4
+--R                          (- 30A B  - 188A )C  + (- 5B  - 36A B  + 37A )C - A B
+--R                        + 
+--R                            3 2     5
+--R                          4A B  - 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 412D  + 132B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (466C  - 2484A C + 248B  - 2718A )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (1374B C  + 996A B C + 120B  + 702A B)D
+--R                        + 
+--R                                    4         3         2       2  2
+--R                              - 366C  - 192A C  + (- 18B  - 492A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 396A B  + 208A )C - 108B  - 690A B  + 170A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4          3       3       2   2
+--R                          - 190B C  + 96A B C  + (34B  - 204A B)C
+--R                        + 
+--R                                 3       3        5      2 3      4
+--R                          (220A B  + 304A B)C + 4B  + 82A B  + 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         4                        3
+--R                          (936C + 1176A)D  + (- 768B C + 1536A B)D
+--R                        + 
+--R                                 3         2          2        2            2
+--R                              24C  + 696A C  + (- 240B  + 3144A )C - 1392A B
+--R                            + 
+--R                                  3
+--R                              200A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2        3       2
+--R                              - 144B C  - 1296A B C  + (320B  + 336A B)C
+--R                            + 
+--R                                   3       3
+--R                              64A B  - 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2      2  3
+--R                          16C  + 80A C  + (- 8B  + 32A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 168A B  - 320A )C  + (40B  + 552A B  - 176A )C
+--R                        + 
+--R                                  4     3 2       5
+--R                          - 168A B  + 8A B  + 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                             5         4          2                 2       2  3
+--R                          96D  - 672B D  + (- 768C  - 1536A C + 384B  + 192A )D
+--R                        + 
+--R                                   2                   2   2
+--R                          (- 384B C  - 384A B C - 1344A B)D
+--R                        + 
+--R                                    4        2       2  2       3       4
+--R                              - 352C  + (384B  - 768A )C  - 384A C - 32B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 224A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3 2       3         5
+--R                          - 32B C  + 256A B C  + 128B C  + 384A B C - 32B
+--R                        + 
+--R                                2 3       4
+--R                          - 128A B  + 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  4                      3
+--R                          - 384A D  + (768B C + 1536A B)D
+--R                        + 
+--R                                  2           2       2           2       3  2
+--R                          (1152A C  + (- 1536B  - 768A )C + 384A B  - 128A )D
+--R                        + 
+--R                                 3       2            3         5         4
+--R                          (256B C  + 768A B C + 512A B )D + 128C  - 128A C
+--R                        + 
+--R                              2 3            2       3  2       4        3 2
+--R                          256A C  + (- 384A B  + 128A )C  - 384A C - 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                   4                   3    8
+--R                      ((16C - 96A)D  + (16B C + 32A B)D )a b
+--R                    + 
+--R                              5         4       2                2       2  3
+--R                          136D  - 168B D  + (92C  - 188A C + 136B  + 472A )D
+--R                        + 
+--R                                  2               3      2   2
+--R                          (- 48B C  + 24A B C - 8B  - 72A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 20A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 36A )C
+--R                         *
+--R                            D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 12C - 1996A)D  + (864B C + 640A B)D
+--R                        + 
+--R                                    3         2          2       2          2
+--R                              - 296C  + 720A C  + (- 252B  - 732A )C + 36A B
+--R                            + 
+--R                                   3
+--R                              - 84A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2           3
+--R                              - 48B C  + 288A B C  + (- 40B  - 408A B)C + 24A B
+--R                            + 
+--R                                 3
+--R                              24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3         2      3  2
+--R                          4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          636D  + 544B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 104C  + 3740A C + 120B  + 3228A )D
+--R                        + 
+--R                                    2                 3       2   2
+--R                          (- 1380B C  - 912A B C - 96B  - 804A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              188C  - 300A C  + (- 192B  + 156A )C
+--R                            + 
+--R                                     2       3        4       2 2       4
+--R                              (108A B  - 340A )C + 76B  + 468A B  - 216A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          68B C  - 272A B C  + (28B  + 384A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            4                        3
+--R                          (- 1528C - 1376A)D  + (- 520B C - 1200A B)D
+--R                        + 
+--R                                    3          2        2        2            2
+--R                              - 544C  - 1968A C  + (132B  - 4740A )C + 1068A B
+--R                            + 
+--R                                     3
+--R                              - 1012A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2           3
+--R                              360B C  + 1584A B C  + (- 16B  - 480A B)C - 56A B
+--R                            + 
+--R                                  3
+--R                              600A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3
+--R                          - 8C  - 64A C  + (188B  - 28A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (252A B  + 412A )C  + (- 100B  - 768A B  + 308A )C
+--R                        + 
+--R                               4      3 2      5
+--R                          12A B  - 64A B  - 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 304D  + 944B D
+--R                        + 
+--R                               2                  2       2  3
+--R                          (708C  + 3096A C - 1072B  - 268A )D
+--R                        + 
+--R                                   2                  3        2   2
+--R                          (- 132B C  + 360A B C - 208B  + 2028A B)D
+--R                        + 
+--R                                  4         3          2        2  2
+--R                              636C  + 448A C  + (- 996B  + 1512A )C
+--R                            + 
+--R                                      2       3        4       2 2       4
+--R                              (- 24A B  + 576A )C + 80B  + 924A B  - 356A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3      2   2
+--R                          108B C  - 256A B C  + (- 252B  - 24A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (120A B  - 768A B)C + 80B  + 356A B  - 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                        4                         3
+--R                          (48C + 1776A)D  + (- 1728B C - 3456A B)D
+--R                        + 
+--R                               3          2         2        2         3  2
+--R                          (816C  - 2928A C  + (3168B  + 1680A )C + 432A )D
+--R                        + 
+--R                                    3          2        3      2            3
+--R                              224B C  + 96A B C  + (256B  - 96A B)C - 768A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2       2  3
+--R                          - 160C  + 160A C  + (48B  - 384A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (336A B  - 160A )C  + (- 80B  - 432A B  + 544A )C
+--R                        + 
+--R                                  4      3 2
+--R                          - 112A B  + 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  4        2                 2        2  3
+--R                          - 384B D  + (960C  - 2688A C + 960B  - 1344A )D
+--R                        + 
+--R                                  2                   3       2   2
+--R                          (1344B C  + 2688A B C - 192B  + 576A B)D
+--R                        + 
+--R                                    4         3          2       2  2
+--R                              - 640C  + 768A C  + (- 960B  - 576A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1152A B  - 128A )C - 192B  - 960A B  + 320A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3         3       2   2
+--R                          - 320B C  + 384A B C  + (- 64B  - 576A B)C
+--R                        + 
+--R                                 3       3         5       2 3
+--R                          (640A B  + 256A B)C + 64B  + 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   3
+--R                          1536A B D
+--R                        + 
+--R                                    3          2           2       2
+--R                              - 768C  + 1152A C  + (- 1536B  + 768A )C
+--R                            + 
+--R                                       2       3
+--R                              - 1536A B  - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2
+--R                              256B C  - 1536A B C  + (1024B  + 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4        2       2  3         2 2
+--R                          128C  - 256A C  + (256B  + 256A )C  - 384A B C
+--R                        + 
+--R                               2 2       4           4       3 2       5
+--R                          (768A B  - 384A )C - 512A B  - 128A B  + 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                        5        4         2              2      2  3    9
+--R                  (- 16D  + 32B D  + (- 16C  + 64A C - 16B  - 48A )D )a b
+--R                + 
+--R                                  4                      3
+--R                      (8C + 224A)D  + (- 136B C - 64A B)D
+--R                    + 
+--R                          3         2       2      2    2
+--R                      (40C  - 144A C  + (24B  + 72A )C)D
+--R                    + 
+--R                           3          2      3      2
+--R                      (8B C  - 48A B C  + (8B  + 72A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            5        4         2               2       2  3
+--R                      - 148D  + 88B D  + (- 64C  - 104A C - 64B  - 592A )D
+--R                    + 
+--R                             2                3      2   2
+--R                      (192B C  + 192A B C + 8B  + 72A B)D
+--R                    + 
+--R                               4        3       2      2  2           2      3
+--R                          - 28C  + 88A C  + (24B  - 24A )C  + (- 24A B  + 24A )C
+--R                        + 
+--R                               4      2 2      4
+--R                          - 12B  - 72A B  + 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4          3        3      2   2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (212C + 1532A)D  + (- 664B C - 112A B)D
+--R                    + 
+--R                           3         2         2       2           2      3  2
+--R                      (232C  - 528A C  + (- 24B  + 864A )C - 144A B  + 88A )D
+--R                    + 
+--R                                   3           2       3       2           3
+--R                            - 40B C  - 528A B C  + (40B  + 456A B)C + 32A B
+--R                          + 
+--R                                 3
+--R                            - 80A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        5        4         2      2  3           2      3  2
+--R                      4C  - 12A C  + (- 24B  + 16A )C  + (- 24A B  - 32A )C
+--R                    + 
+--R                          4       2 2      4         4      3 2      5
+--R                      (20B  + 144A B  - 52A )C + 4A B  + 16A B  + 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                            5          4        2                 2        2  3
+--R                      - 124D  - 1208B D  + (248C  - 4328A C + 416B  - 1336A )D
+--R                    + 
+--R                              2                  3       2   2
+--R                      (1176B C  + 912A B C + 104B  + 240A B)D
+--R                    + 
+--R                                4         3        2       2  2
+--R                          - 188C  + 424A C  + (384B  - 264A )C
+--R                        + 
+--R                                  2       3        4       2 2       4
+--R                          (- 24A B  + 136A )C - 68B  - 480A B  + 244A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3         3       2   2
+--R                      - 32B C  + 304A B C  + (- 16B  - 408A B)C
+--R                    + 
+--R                              3      3         5      2 3      4
+--R                      (- 80A B  + 64A B)C - 16B  - 88A B  + 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      4                       3
+--R                      (1028C - 2044A)D  + (3104B C + 2864A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 560C  + 4512A C  + (- 1536B  + 1848A )C - 816A B
+--R                        + 
+--R                              3
+--R                          616A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3           2          3       2            3
+--R                          - 736B C  - 768A B C  + (- 304B  - 912A B)C + 224A B
+--R                        + 
+--R                                3
+--R                          - 496A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4          2       2  3
+--R                      28C  - 52A C  + (- 200B  + 112A )C
+--R                    + 
+--R                               2       3  2        4       2 2       4
+--R                      (- 168A B  - 224A )C  + (140B  + 912A B  - 364A )C
+--R                    + 
+--R                           4       3 2      5
+--R                      92A B  + 112A B  + 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                          5          4           2                 2        2  3
+--R                      288D  + 1088B D  + (- 1896C  + 4752A C - 720B  + 2552A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 2712B C  - 4560A B C + 272B  - 2424A B)D
+--R                    + 
+--R                              4          3         2       2  2
+--R                          280C  - 2048A C  + (1320B  - 480A )C
+--R                        + 
+--R                                  2       3         4       2 2       4
+--R                          (1200A B  - 416A )C + 208B  + 744A B  - 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3        2   2
+--R                      232B C  - 608A B C  + (344B  + 1248A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 560A B  + 448A B)C - 112B  - 616A B  + 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                       4                         3
+--R                      (- 1248C + 288A)D  + (- 2304B C - 2688A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          1056C  - 3840A C  + (1536B  - 3552A )C + 2496A B
+--R                        + 
+--R                                3
+--R                          - 704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2          3       2            3
+--R                          768B C  + 2880A B C  + (- 768B  + 384A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          1088A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4         2       2  3
+--R                      - 32C  + 320A C  + (- 32B  - 128A )C
+--R                    + 
+--R                             2       3  2          4        2 2       4
+--R                      (192A B  + 256A )C  + (- 160B  - 1824A B  + 416A )C
+--R                    + 
+--R                            4       3 2       5
+--R                      416A B  - 128A B  - 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                2       2  3
+--R                      (1728C  - 384A C + 384B  - 576A )D
+--R                    + 
+--R                              2                   3        2   2
+--R                      (1344B C  + 3456A B C - 384B  + 2112A B)D
+--R                    + 
+--R                               4          3           2       2  2
+--R                          - 64C  + 1536A C  + (- 1728B  + 768A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1152A B  + 256A )C - 128B  - 192A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3       2   2
+--R                      - 192B C  + 256A B C  + (- 320B  - 768A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (640A B  - 512A B)C + 128B  + 704A B  - 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                             3       2           2  2
+--R                      (- 768C  + 768A C - 1536A B )D
+--R                    + 
+--R                                  2        3        3            4       2 3
+--R                      (- 1536A B C  + 1024B C - 512A B)D - 256A C  + 256B C
+--R                    + 
+--R                          2 2          4       5
+--R                      768A B C - 512A B  + 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                %%BN0
+--R            + 
+--R                       5            4 2  7
+--R                  (4A D a b - 8A C D a )c
+--R                + 
+--R                             5         4    2
+--R                      (- 2B D  - 8A C D )a b
+--R                    + 
+--R                                    5                  4         2     3  3  2
+--R                      ((- 4C + 20A)D  + (4B C - 28A B)D  + (24A C  + 8A )D )a b
+--R                    + 
+--R                             2             2  4            3
+--R                          (8C  - 32A C + 8A )D  + 64A B C D
+--R                        + 
+--R                                  3      3   2
+--R                          (- 16A C  - 16A C)D
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                  5                  4        2     3  3    3
+--R                      ((2C - 38A)D  + (4B C + 12A B)D  + (4A C  - 4A )D )a b
+--R                    + 
+--R                            6       5      2              2      2  4
+--R                          6D  - 4B D  + (4C  + 56A C + 14B  + 36A )D
+--R                        + 
+--R                                  2               2   3           3      3   2
+--R                          (- 12B C  - 8A B C - 12A B)D  + (- 16A C  + 16A C)D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                                        5                    4
+--R                          (- 32C + 16A)D  + (32B C - 160A B)D
+--R                        + 
+--R                                     3        2         2       2          2
+--R                                - 24C  + 56A C  + (- 32B  - 136A )C + 64A B
+--R                              + 
+--R                                   3
+--R                                40A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                               3          2      2         3   2
+--R                          (8B C  - 72A B C  + 24A B C - 24A B)D
+--R                        + 
+--R                                4      3 2     5
+--R                          (20A C  - 24A C  + 4A )D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                              2              2  4
+--R                          (32C  - 32A C + 32A )D
+--R                        + 
+--R                                  2                 2   3
+--R                          (- 64B C  + 256A B C - 64A B)D
+--R                        + 
+--R                                   4        3      2 2            2      3
+--R                                16C  - 64A C  + 96A C  + (- 192A B  - 64A )C
+--R                              + 
+--R                                   4
+--R                                16A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3      3            5      3 3     5
+--R                          (64A B C  + 64A B C)D - 8A C  + 16A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              6        5        2             2      2  4
+--R                          - 2D  + 16B D  + (- 4C  + 64A C - 6B  - 12A )D
+--R                        + 
+--R                                 2               2   3
+--R                          (- 2B C  - 12A B C + 6A B)D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                                      5                      4
+--R                          (28C - 92A)D  + (- 60B C + 260A B)D
+--R                        + 
+--R                             3         2      2      2          2      3  3
+--R                          (8C  - 192A C  + (4B  + 24A )C - 36A B  - 96A )D
+--R                        + 
+--R                               3          2      2     2
+--R                          (8B C  + 48A B C  - 24A B C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                             6        5         2               2       2  4
+--R                          20D  - 32B D  + (- 12C  + 152A C + 36B  + 116A )D
+--R                        + 
+--R                                2                 3       2   3
+--R                          (48B C  - 480A B C - 32B  - 144A B)D
+--R                        + 
+--R                                4         3       2      2  2
+--R                              8C  + 128A C  + (36B  + 48A )C
+--R                            + 
+--R                                     2       3        2 2     4
+--R                              (120A B  + 256A )C + 36A B  + 8A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  4          3      2   2     3         4
+--R                          (- 10B C  - 56A B C  + 36A B C  + 8A B C - 10A B)D
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                                        5                     4
+--R                          (- 48C - 16A)D  + (240B C - 144A B)D
+--R                        + 
+--R                                   3        2         2       2           2
+--R                              - 80C  + 80A C  + (- 96B  - 496A )C + 480A B
+--R                            + 
+--R                                  3
+--R                              112A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                   3           2       3       2           3
+--R                              80B C  - 144A B C  + (96B  + 624A B)C - 32A B
+--R                            + 
+--R                                    3
+--R                              - 176A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2      2  3       3 2
+--R                              - 20C  + 36A C  + (- 32B  - 72A )C  - 184A C
+--R                            + 
+--R                                    2 2      4        5
+--R                              (- 96A B  - 36A )C + 20A
+--R                         *
+--R                            D
+--R                        + 
+--R                            5          4      2   3      3   2      4        5
+--R                        4B C  + 20A B C  - 24A B C  - 24A B C  + 20A B C + 4A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                              2      2  4            2                  2   3
+--R                          (32C  + 32A )D  + (- 256B C  + 256A B C - 256A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              64C  - 128A C  + (192B  + 384A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 768A B  - 128A )C + 192A B  + 64A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4           3       2   2
+--R                              - 64B C  + 256A B C  - 384A B C
+--R                            + 
+--R                                     3       3         4
+--R                              (256A B  + 256A B)C - 64A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            6        5     2 4           2      3  3     4 2
+--R                          8C  - 32A C  - 8A C  + (- 64A B  + 64A )C  - 8A C
+--R                        + 
+--R                                3 2      5       6
+--R                          (- 64A B  - 32A )C + 8A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                         5                     4
+--R                          (- 10C + 118A)D  + (- 20B C - 84A B)D
+--R                        + 
+--R                             3        2      2     2         2      3  3
+--R                          (2C  - 26A C  + (6B  + 6A )C + 6A B  + 34A )D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                               6        5         2                2       2  4
+--R                          - 44D  + 28B D  + (- 28C  - 224A C - 100B  - 324A )D
+--R                        + 
+--R                                2                3       2   3
+--R                          (92B C  + 40A B C + 20B  + 204A B)D
+--R                        + 
+--R                                  4         3         2      2  2
+--R                              - 8C  + 104A C  + (- 24B  - 24A )C
+--R                            + 
+--R                                      2       3
+--R                              (- 24A B  - 136A )C
+--R                         *
+--R                             2
+--R                            D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                                       5                       4
+--R                          (144C + 80A)D  + (- 320B C + 576A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                132C  - 92A C  + (288B  + 1196A )C - 608A B
+--R                              + 
+--R                                      3
+--R                                - 116A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                        3           2         3       2
+--R                                - 160B C  + 528A B C  + (- 64B  - 672A B)C
+--R                              + 
+--R                                    3
+--R                                176A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4       2      2  3
+--R                              10C  - 134A C  + (28B  + 20A )C
+--R                            + 
+--R                                    2       3  2         2 2     4       3 2
+--R                              (12A B  + 196A )C  + (- 12A B  + 2A )C + 4A B
+--R                            + 
+--R                                   5
+--R                              - 30A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                  5          2               2  4
+--R                          - 160B D  + (- 128C  - 256A C + 16B )D
+--R                        + 
+--R                                 2                  3       2   3
+--R                          (416B C  - 960A B C - 128B  - 352A B)D
+--R                        + 
+--R                                   4         3          2        2  2
+--R                              - 82C  + 232A C  + (- 288B  - 1164A )C
+--R                            + 
+--R                                      2      3        4      2 2      4
+--R                              (1344A B  - 24A )C + 16B  + 96A B  - 82A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3       2   2
+--R                              100B C  - 656A B C  + 408A B C
+--R                            + 
+--R                                       3       3         4
+--R                              (- 128A B  - 400A B)C - 28A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              6        5         2     2  4        2       3  3
+--R                          - 4C  + 56A C  + (- 10B  + 4A )C  + (8A B  - 112A )C
+--R                        + 
+--R                              2 2     4  2      3 2      5        4 2     6
+--R                          (36A B  + 4A )C  + (8A B  + 56A )C - 10A B  - 4A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                            4
+--R                          (384B C + 128A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 32C  + 416A C  + (- 640B  - 352A )C + 512A B
+--R                            + 
+--R                                  3
+--R                              224A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2            3
+--R                              160B C  - 288A B C  + (128B  + 2016A B)C - 640A B
+--R                            + 
+--R                                    3
+--R                              - 608A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2       2  3
+--R                              - 48C  - 16A C  + (- 32B  + 288A )C
+--R                            + 
+--R                                      2       3  2          4       2 2      4
+--R                              (- 96A B  + 224A )C  + (- 128B  - 864A B  + 16A )C
+--R                            + 
+--R                                     4       3 2      5
+--R                              - 64A B  + 224A B  + 48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4       3      2   3
+--R                          - 16B C  + 176A B C  + (32B  + 96A B)C
+--R                        + 
+--R                              3      3   2       2 3       4         3 3      5
+--R                        (96A B  + 96A B)C  + (96A B  + 176A B)C + 32A B  - 16A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                   2       2   3
+--R                          (- 256B C  - 256A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              64C  - 256A C  + (768B  + 384A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 768A B  - 256A )C + 768A B  + 64A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 256B C  + 512A B C  + (- 256B  - 1536A B)C
+--R                            + 
+--R                                      3       3          2 3       4
+--R                              (1024A B  + 512A B)C - 256A B  - 256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6       2      2  4         2 3
+--R                          32C  + (64B  - 32A )C  - 256A B C
+--R                        + 
+--R                               2 2      4  2            4       3 2        4 2
+--R                          (384A B  - 32A )C  + (- 128A B  - 256A B )C + 64A B
+--R                        + 
+--R                             6
+--R                          32A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                             6        5       2               2      2  4
+--R                          12D  - 44B D  + (20C  - 152A C + 36B  + 84A )D
+--R                        + 
+--R                               2               3      2   3
+--R                          (4B C  + 72A B C - 4B  - 60A B)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                                        5                     4
+--R                          (- 36C + 12A)D  + (296B C - 520A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 44C  + 524A C  + (- 68B  - 228A )C + 204A B
+--R                            + 
+--R                                  3
+--R                              228A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                  3           2       3       2     2
+--R                          (- 16B C  - 288A B C  + (16B  + 240A B)C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                               6         5         2              2       2  4
+--R                          - 30D  + 272B D  + (- 16C  + 96A C - 44B  - 432A )D
+--R                        + 
+--R                                   2                  3       2   3
+--R                          (- 324B C  + 872A B C + 224B  + 972A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 22C  - 536A C  + (- 48B  - 36A )C
+--R                            + 
+--R                                       2       3       4       2 2      4
+--R                              (- 576A B  - 600A )C - 6B  - 240A B  - 54A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3         3       2   2
+--R                              24B C  + 368A B C  + (- 12B  - 288A B)C
+--R                            + 
+--R                                    3      3        2 3      4
+--R                              (24A B  - 48A B)C + 4A B  + 72A B
+--R                         *
+--R                            D
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                        5                       4
+--R                          (112C + 144A)D  + (- 928B C - 416A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              168C  - 600A C  + (896B  + 1816A )C - 1408A B
+--R                            + 
+--R                                 3
+--R                              24A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 416B C  + 672A B C  + (- 512B  - 3648A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  + 896A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              96C  + 144A C  + (184B  + 320A )C
+--R                            + 
+--R                                     2       3  2       4        2 2       4
+--R                              (216A B  + 544A )C  + (80B  + 1032A B  + 224A )C
+--R                            + 
+--R                                   4      3 2      5
+--R                              48A B  - 24A B  - 48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4       2   3
+--R                          - 12B C  - 156A B C  + 104A B C
+--R                        + 
+--R                                  3       3   2         2 3       4         5
+--R                          (- 32A B  + 104A B)C  + (- 32A B  - 156A B)C - 12A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                 2                2       2  4
+--R                          (- 144C  - 480A C + 480B  - 144A )D
+--R                        + 
+--R                                 2                   3       2   3
+--R                          (960B C  + 1152A B C + 192B  + 192A B)D
+--R                        + 
+--R                                    4         3           2        2  2
+--R                              - 196C  + 912A C  + (- 1536B  - 2136A )C
+--R                            + 
+--R                                      2       3         4      4
+--R                              (2304A B  - 624A )C + 224B  + 60A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4            3        3        2   2
+--R                              696B C  - 1120A B C  + (448B  + 3024A B)C
+--R                            + 
+--R                                        3       3         5       2 3       4
+--R                              (- 1408A B  - 608A B)C + 32B  + 192A B  + 184A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               6         2      2  4         2       3  3
+--R                          - 48C  + (- 84B  - 80A )C  + (80A B  - 256A )C
+--R                        + 
+--R                                4       2 2      4  2           4      3 2
+--R                          (- 48B  - 696A B  - 80A )C  + (- 32A B  + 80A B )C
+--R                        + 
+--R                               2 4      4 2      6
+--R                          - 48A B  - 84A B  - 48A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                 3         2           2       2           2
+--R                              64C  + 576A C  + (- 1152B  + 192A )C - 384A B
+--R                            + 
+--R                                  3
+--R                              192A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                     3            2        3        2
+--R                              - 64B C  - 1728A B C  + (640B  + 1344A B)C
+--R                            + 
+--R                                      3        3
+--R                              - 896A B  - 1088A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              64C  - 512A C  + (320B  + 640A )C
+--R                            + 
+--R                                     2        3  2
+--R                              (192A B  + 1024A )C
+--R                            + 
+--R                                    4        2 2       4           4        3 2
+--R                              (- 64B  - 2112A B  - 192A )C + 320A B  + 1088A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                  5          4         3       2   3
+--R                          - 192B C  + 64A B C  + (- 64B  - 384A B)C
+--R                        + 
+--R                                 3       3   2       5       2 3      4
+--R                          (320A B  - 384A B)C  + (64B  + 320A B  + 64A B)C
+--R                        + 
+--R                               5      3 3       5
+--R                          64A B  - 64A B  - 192A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                   3       2 2       3        2 2  2
+--R                          (- 256A C  + 768B C  - 256A C + 768A B )D
+--R                        + 
+--R                                      4            3           3        2   2
+--R                              - 256B C  + 1024A B C  + (- 1024B  - 1536A B)C
+--R                            + 
+--R                                      3        3           2 3       4
+--R                              (1024A B  + 1024A B)C - 1024A B  - 256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5       2 4            2       3  3
+--R                          128A C  + 256B C  + (- 512A B  - 256A )C
+--R                        + 
+--R                               4        2 2  2            4       3 2       5
+--R                          (128B  + 1536A B )C  + (- 512A B  - 512A B  + 128A )C
+--R                        + 
+--R                              2 4       4 2
+--R                          128A B  + 256A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                      5                    4
+--R                          (8C - 120A)D  + (16B C + 144A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  3
+--R                          (- 8C  + 40A C  + (- 24B  - 24A )C - 24A B  - 72A )D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                             6        5                 2       2  4
+--R                          64D  - 96B D  + (416A C + 128B  + 672A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 224B C  - 128A B C - 96B  - 672A B)D
+--R                        + 
+--R                            4         3       2      2  2         2       3    2
+--R                        (32C  - 160A C  + (96B  + 96A )C  + (96A B  + 288A )C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                          5                     4
+--R                          (- 290C - 354A)D  + (360B C + 168A B)D
+--R                        + 
+--R                                    3         2          2        2           2
+--R                              - 108C  - 356A C  + (- 916B  - 2884A )C + 940A B
+--R                            + 
+--R                                    3
+--R                              - 588A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2           3
+--R                              664B C  - 696A B C  + (280B  + 2376A B)C - 40A B
+--R                            + 
+--R                                    3
+--R                              - 360A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4          2       2  3
+--R                              - 42C  + 206A C  + (- 132B  - 100A )C
+--R                            + 
+--R                                       2       3  2         4      2 2      4
+--R                              (- 108A B  - 420A )C  + (- 10B  - 12A B  - 18A )C
+--R                            + 
+--R                                     4      3 2      5
+--R                              - 10A B  - 36A B  + 54A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                5        2                 2       2  4
+--R                          120B D  + (426C  + 1588A C - 560B  + 522A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 328B C  - 784A B C - 96B  + 696A B)D
+--R                        + 
+--R                                  4         3         2        2  2
+--R                              236C  - 112A C  + (1740B  + 4200A )C
+--R                            + 
+--R                                        2        3         4       2 2      4
+--R                              (- 1800A B  + 2512A )C - 208B  - 852A B  + 12A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 704B C  + 960A B C  + (- 248B  - 2112A B)C
+--R                            + 
+--R                                     3       3         5       2 3
+--R                              (208A B  + 320A B)C - 24B  - 184A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5       2      2  4         2       3  3
+--R                          18C  - 84A C  + (60B  + 14A )C  + (48A B  + 232A )C
+--R                        + 
+--R                              4      2 2      4  2         4      3 2      5
+--R                          (10B  - 24A B  + 14A )C  + (20A B  + 48A B  - 84A )C
+--R                        + 
+--R                             2 4      4 2      6
+--R                          10A B  + 60A B  + 18A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                              4
+--R                          (- 448B C - 576A B)D
+--R                        + 
+--R                                   3          2         2        2           2
+--R                              - 48C  - 2864A C  + (1984B  - 1424A )C + 704A B
+--R                            + 
+--R                                    3
+--R                              - 656A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3            2          3        2
+--R                              - 288B C  + 1632A B C  + (- 640B  - 3552A B)C
+--R                            + 
+--R                                     3       3
+--R                              1664A B  + 672A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    5         4          2        2  3
+--R                              - 184C  + 200A C  + (- 976B  - 2416A )C
+--R                            + 
+--R                                       2        3  2
+--R                              (- 336A B  - 3120A )C
+--R                            + 
+--R                                   4        2 2       4          4        3 2
+--R                              (352B  + 3216A B  - 344A )C - 32A B  - 1520A B
+--R                            + 
+--R                                   5
+--R                              - 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5           4       3       2   3
+--R                          240B C  - 208A B C  + (32B  + 224A B)C
+--R                        + 
+--R                                  3       3   2         2 3       4         3 3
+--R                          (- 32A B  + 224A B)C  + (- 32A B  - 208A B)C + 32A B
+--R                        + 
+--R                              5
+--R                          240A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                 2                   3       2   3
+--R                          (576B C  + 1920A B C - 640B  + 576A B)D
+--R                        + 
+--R                                    4          3           2        2  2
+--R                              - 472C  + 2528A C  + (- 2304B  + 1392A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1536A B  + 992A )C - 416B  - 768A B  + 552A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4            3         3        2   2
+--R                              560B C  - 1216A B C  + (1536B  + 4128A B)C
+--R                            + 
+--R                                        3       3          5       2 3      4
+--R                              (- 2560A B  - 192A B)C - 192B  + 512A B  + 48A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5      2       2  4
+--R                          48C  - 32A C  + (8B  + 464A )C
+--R                        + 
+--R                                  2        3  3          4        2 2       4  2
+--R                          (1120A B  + 1088A )C  + (- 192B  - 1872A B  + 464A )C
+--R                        + 
+--R                                 4        3 2      5        6       2 4     4 2
+--R                          (384A B  + 1120A B  - 32A )C - 32B  - 192A B  + 8A B
+--R                        + 
+--R                             6
+--R                          48A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                      3            2         3       2
+--R                              - 256B C  - 2304A B C  + (1536B  - 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 768A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  5          4        2       2  3          2 2
+--R                              448C  - 1024A C  + (640B  - 640A )C  + 1920A B C
+--R                            + 
+--R                                      2 2       4           4        3 2
+--R                              (- 1152A B  - 832A )C + 768A B  + 1664A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                  5          4          3       2   3
+--R                          - 192B C  + 64A B C  + (- 640B  - 896A B)C
+--R                        + 
+--R                                 3       3   2        2 3      4          3 3
+--R                          (128A B  - 896A B)C  + (128A B  + 64A B)C - 640A B
+--R                        + 
+--R                                5
+--R                          - 192A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                    3        3 2        3           2 3
+--R                          (1024A B C  - 1024B C  + 1024A B C - 1024A B )D
+--R                        + 
+--R                                6         5        2       2  4
+--R                          - 128C  + 128A C  + (256B  + 128A )C
+--R                        + 
+--R                                    2       3  3        4        2 2       4  2
+--R                          (- 1024A B  - 256A )C  + (512B  + 1536A B  + 128A )C
+--R                        + 
+--R                                   4        3 2       5         2 4       4 2
+--R                          (- 512A B  - 1024A B  + 128A )C + 512A B  + 256A B
+--R                        + 
+--R                                6
+--R                          - 128A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                           6        5         2              2       2  4
+--R                      - 16D  + 48B D  + (- 16C  + 96A C - 48B  - 144A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (16B C  - 96A B C + 16B  + 144A B)D
+--R                 *
+--R                       8
+--R                    a b
+--R                + 
+--R                                   5                      4
+--R                      (48C + 240A)D  + (- 288B C - 96A B)D
+--R                    + 
+--R                          3         2        2       2           2       3  3
+--R                      (80C  - 464A C  + (304B  + 624A )C - 144A B  + 144A )D
+--R                    + 
+--R                              3           2         3       2     2
+--R                      (- 64B C  + 384A B C  + (- 64B  - 576A B)C)D
+--R                 *
+--R                     2 7
+--R                    a b
+--R                + 
+--R                           6         5       2                 2       2  4
+--R                      - 20D  - 156B D  + (56C  - 1296A C + 168B  - 456A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (664B C  + 624A B C - 40B  - 168A B)D
+--R                    + 
+--R                                4         3          2       2  2
+--R                          - 148C  + 816A C  + (- 648B  - 888A )C
+--R                        + 
+--R                                 2       3        4       2 2       4
+--R                          (240A B  - 720A )C + 44B  + 504A B  + 108A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          84B C  - 496A B C  + (88B  + 696A B)C
+--R                        + 
+--R                                  3       3        5      2 3       4
+--R                          (- 16A B  + 144A B)C + 4B  + 24A B  - 108A B
+--R                     *
+--R                        D
+--R                 *
+--R                     3 6
+--R                    a b
+--R                + 
+--R                                   5                     4
+--R                      (168C - 24A)D  + (828B C + 636A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 416C  + 2848A C  + (- 752B  + 1824A )C - 432A B
+--R                        + 
+--R                              3
+--R                          608A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3            2        3       2            3
+--R                          - 712B C  - 1560A B C  + (392B  + 936A B)C - 696A B
+--R                        + 
+--R                                3
+--R                          - 264A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2       2  3
+--R                          120C  - 616A C  + (544B  + 432A )C
+--R                        + 
+--R                                 2        3  2          4        2 2       4
+--R                          (288A B  + 1072A )C  + (- 120B  - 1824A B  - 168A )C
+--R                        + 
+--R                              4       3 2      5
+--R                          8A B  + 480A B  - 72A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4         3       2   3
+--R                      - 36B C  + 204A B C  + (- 40B  - 232A B)C
+--R                    + 
+--R                           3       3   2        5     2 3       4          5
+--R                      (8A B  - 232A B)C  + (- 4B  + 8A B  + 204A B)C - 4A B
+--R                    + 
+--R                           3 3      5
+--R                      - 40A B  - 36A B
+--R                 *
+--R                     4 5
+--R                    a b
+--R                + 
+--R                             2                2      2  4
+--R                      (- 580C  + 120A C - 120B  + 60A )D
+--R                    + 
+--R                                2                   3        2   3
+--R                      (- 1760B C  - 2688A B C + 384B  - 1056A B)D
+--R                    + 
+--R                              4          3         2        2  2
+--R                          680C  - 3168A C  + (1224B  - 2832A )C
+--R                        + 
+--R                                  2        3         4      2 2       4
+--R                          (1680A B  - 1632A )C + 176B  + 72A B  - 600A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4            3          3        2   2
+--R                          336B C  + 1664A B C  + (- 800B  - 1248A B)C
+--R                        + 
+--R                                 3       5       2 3       4
+--R                          1664A B C + 64B  + 288A B  + 528A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5          2      2  4
+--R                      - 36C  + 168A C  + (- 144B  - 28A )C
+--R                    + 
+--R                               2       3  3       4        2 2      4  2
+--R                      (- 448A B  - 464A )C  + (92B  + 1440A B  - 28A )C
+--R                    + 
+--R                              4       3 2       5       6      2 4       4 2
+--R                      (- 72A B  - 448A B  + 168A )C + 8B  + 92A B  - 144A B
+--R                    + 
+--R                           6
+--R                      - 36A
+--R                 *
+--R                     5 4
+--R                    a b
+--R                + 
+--R                            3         2        2       2           2      3  3
+--R                      (1056C  - 224A C  + (448B  - 288A )C + 576A B  - 32A )D
+--R                    + 
+--R                                 3            2           3        2
+--R                          1856B C  + 4416A B C  + (- 1408B  + 2880A B)C
+--R                        + 
+--R                                  3        3
+--R                          - 384A B  + 1344A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5          4          2        2  3
+--R                          - 480C  + 1760A C  + (- 800B  + 2112A )C
+--R                        + 
+--R                                    2        3  2
+--R                          (- 2592A B  + 1216A )C
+--R                        + 
+--R                                 4        2 2        4           4        3 2
+--R                          (- 192B  + 1056A B  + 1440A )C - 832A B  - 1248A B
+--R                        + 
+--R                             5
+--R                          96A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4        3       2   3
+--R                      - 48B C  - 624A B C  + (448B  + 416A B)C
+--R                    + 
+--R                               3       3   2         5       2 3       4
+--R                      (- 832A B  + 416A B)C  + (- 64B  - 832A B  - 624A B)C
+--R                    + 
+--R                             5       3 3      5
+--R                      - 64A B  + 448A B  - 48A B
+--R                 *
+--R                     6 3
+--R                    a b
+--R                + 
+--R                                 4         3          2       2  2
+--R                          - 1072C  + 192A C  + (- 576B  + 480A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1920A B  + 192A )C + 320B  - 576A B  - 48A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3         3        2   2
+--R                          - 960B C  - 3328A B C  + (1792B  - 2688A B)C
+--R                        + 
+--R                                 3        3          5       2 3       4
+--R                          (512A B  - 2304A B)C + 256B  + 768A B  - 960A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6         5        2       2  4           2       3  3
+--R                      128C  - 384A C  + (144B  - 640A )C  + (1472A B  - 256A )C
+--R                    + 
+--R                            4        2 2       4  2
+--R                      (- 64B  - 1440A B  - 640A )C
+--R                    + 
+--R                              4        3 2       5        6      2 4       4 2
+--R                      (1152A B  + 1472A B  - 384A )C + 64B  - 64A B  + 144A B
+--R                    + 
+--R                          6
+--R                      128A
+--R                 *
+--R                     7 2
+--R                    a b
+--R                + 
+--R                              5        4        2       2  3
+--R                          576C  - 64A C  + (256B  - 384A )C
+--R                        + 
+--R                                  2       3  2          4       2 2       4
+--R                          (2304A B  - 128A )C  + (- 768B  + 768A B  - 192A )C
+--R                        + 
+--R                                  4       3 2       5
+--R                          - 256A B  + 768A B  + 192A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4          3       2   3
+--R                      192B C  + 960A B C  + (- 768B  + 896A B)C
+--R                    + 
+--R                               3       3   2          5       2 3       4
+--R                      (- 256A B  + 896A B)C  + (- 256B  - 256A B  + 960A B)C
+--R                    + 
+--R                              5       3 3       5
+--R                      - 256A B  - 768A B  + 192A B
+--R                 *
+--R                     8
+--R                    a b
+--R                + 
+--R                            6       2 4          2 3        4       4  2
+--R                      - 128C  + 128A C  - 1024A B C  + (512B  + 128A )C
+--R                    + 
+--R                             3 2        2 4       6
+--R                      - 1024A B C + 512A B  - 128A
+--R                 *
+--R                     9
+--R                    a
+--R             *
+--R                x
+--R            + 
+--R                   5 2         4            4 2  7
+--R              (2A D b  - 4A C D a b + 8A B D a )c
+--R            + 
+--R                        5         4  3
+--R                  (- B D  - 4A C D )b
+--R                + 
+--R                               5                  4         2     3  3    2
+--R                  ((- 2C + 8A)D  + (2B C - 16A B)D  + (12A C  + 6A )D )a b
+--R                + 
+--R                      2             2  4            3          3      3   2  2
+--R                  ((4C  - 20A C - 4B )D  + 24A B C D  + (- 8A C  - 20A C)D )a b
+--R                + 
+--R                            5                    4        2         2  3
+--R                      - 8A D  + (- 8B C + 32A B)D  + (- 8A C - 48A B )D
+--R                    + 
+--R                        3   2      3 2
+--R                      8A B D  + 16A C D
+--R                 *
+--R                     3
+--R                    a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                             5                 4        2     3  3  4
+--R                  ((C - 19A)D  + (2B C + 6A B)D  + (2A C  - 2A )D )b
+--R                + 
+--R                        6      5      2             2      2  4
+--R                      3D  - B D  + (2C  + 34A C + 8B  + 19A )D
+--R                    + 
+--R                             2              2   3          3     3   2
+--R                      (- 6B C  - 2A B C - 9A B)D  + (- 8A C  + 8A C)D
+--R                 *
+--R                       3
+--R                    a b
+--R                + 
+--R                                    5                    4
+--R                      (- 14C + 10A)D  + (24B C - 150A B)D
+--R                    + 
+--R                            3        2         2      2          2      3  3
+--R                      (- 12C  + 24A C  + (- 12B  - 68A )C + 54A B  + 34A )D
+--R                    + 
+--R                         3          2      2        3   2         4      3 2
+--R                    (4B C  - 36A B C  + 30A B C - 8A B)D  + (10A C  - 10A C )D
+--R                 *
+--R                     2 2
+--R                    a b
+--R                + 
+--R                           5       2             2      2  4
+--R                      16B D  + (20C  - 12A C - 8B  + 16A )D
+--R                    + 
+--R                              2                 3      2   3
+--R                      (- 24B C  + 184A B C + 24B  + 64A B)D
+--R                    + 
+--R                            4        3      2 2           2       3        2 2
+--R                          8C  - 24A C  + 96A C  + (- 60A B  - 104A )C - 12A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              3      2   2      3            5     3 3
+--R                      (40A B C  - 24A B C  + 24A B C)D - 4A C  + 4A C
+--R                 *
+--R                     3
+--R                    a b
+--R                + 
+--R                                 5                     4
+--R                      (8C - 32A)D  + (- 32B C + 56A B)D
+--R                    + 
+--R                            2       2      2           2  3
+--R                      (16A C  + (56B  - 32A )C - 192A B )D
+--R                    + 
+--R                             3      3   2
+--R                      (104A B  + 32A B)D
+--R                    + 
+--R                          2 3      3 2      4       3 2           4      3   2
+--R                    (- 56A C  + 64A C  - 40A C - 16A B )D - 8A B C  - 24A B C
+--R                 *
+--R                     4
+--R                    a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                         6       5        2             2     2  4
+--R                      - D  + 8B D  + (- 2C  + 32A C - 3B  - 6A )D
+--R                    + 
+--R                            2              2   3
+--R                      (- B C  - 6A B C + 3A B)D
+--R                 *
+--R                     5
+--R                    b
+--R                + 
+--R                                  5                      4
+--R                      (13C - 31A)D  + (- 34B C + 142A B)D
+--R                    + 
+--R                         3         2     2      2          2      3  3
+--R                      (4C  - 100A C  + (B  + 14A )C - 19A B  - 66A )D
+--R                    + 
+--R                           3          2      2     2
+--R                      (4B C  + 24A B C  - 12A B C)D
+--R                 *
+--R                       4
+--R                    a b
+--R                + 
+--R                        6        5         2               2      2  4
+--R                      7D  - 27B D  + (- 14C  + 110A C + 47B  + 82A )D
+--R                    + 
+--R                            2                 3       2   3
+--R                      (20B C  - 196A B C - 27B  - 126A B)D
+--R                    + 
+--R                            4        3       2     2  2         2       3
+--R                          4C  + 72A C  + (18B  + 3A )C  + (42A B  + 230A )C
+--R                        + 
+--R                             2 2    4
+--R                          12A B  - A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             4          3      2   2
+--R                      (- 5B C  - 30A B C  + 15A B C )D
+--R                 *
+--R                     2 3
+--R                    a b
+--R                + 
+--R                                    5                     4
+--R                      (- 36C + 74A)D  + (174B C - 216A B)D
+--R                    + 
+--R                            3        2          2       2           2      3  3
+--R                      (- 36C  - 30A C  + (- 132B  - 332A )C + 586A B  + 30A )D
+--R                    + 
+--R                                 3           2       3       2           3
+--R                            36B C  - 192A B C  + (30B  + 288A B)C - 80A B
+--R                          + 
+--R                                  3
+--R                            - 160A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         2      2  3           2       3  2
+--R                          - 10C  + (- 20B  - 24A )C  + (- 18A B  - 214A )C
+--R                        + 
+--R                                2 2     4       3 2     5
+--R                          (- 36A B  - 2A )C - 2A B  + 2A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4     2   3
+--R                      2B C  + 12A B C  - 6A B C
+--R                 *
+--R                     3 2
+--R                    a b
+--R                + 
+--R                           6        5       2              2      2  4
+--R                      - 12D  + 40B D  + (16C  - 48A C - 96B  - 24A )D
+--R                    + 
+--R                               2                 3      2   3
+--R                      (- 200B C  + 128A B C + 40B  + 96A B)D
+--R                    + 
+--R                             4         3       2       2  2
+--R                          24C  - 108A C  + (48B  + 492A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 528A B  - 172A )C - 52B  - 264A B  + 100A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4           3       2   2         3       3
+--R                          - 40B C  + 216A B C  - 240A B C  + (80A B  + 264A B)C
+--R                        + 
+--R                             2 3     4
+--R                          24A B  + 8A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6       5      2      2  4          2      3  3
+--R                      4C  - 4A C  + (4B  + 16A )C  + (- 4A B  + 40A )C
+--R                    + 
+--R                          2 2      4  2       3 2     5
+--R                      (36A B  + 12A )C  + (12A B  - 4A )C
+--R                 *
+--R                     4
+--R                    a b
+--R                + 
+--R                                  5                     4
+--R                      (32C - 16A)D  + (- 80B C + 96A B)D
+--R                    + 
+--R                           3        2        2     2           2  3
+--R                      (- 8C  + 64A C  + (224B  + 8A )C - 176A B )D
+--R                    + 
+--R                                2       3          3     3   2
+--R                      (- 24A B C  - 144B C + 416A B  - 8A B)D
+--R                    + 
+--R                               4      2       2  3       3 2       2 2       4
+--R                          72A C  + (8B  - 224A )C  + 160A C  + (24A B  - 160A )C
+--R                        + 
+--R                                 4      3 2      5
+--R                          - 96A B  - 64A B  + 24A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4       2   3          3      3   2
+--R                      8B C  - 32A B C  + 128A B C  + (- 8A B  - 96A B)C
+--R                    + 
+--R                         4        3 3
+--R                      56A B C + 8A B
+--R                 *
+--R                     5
+--R                    a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                                   5                     4
+--R                      (- 5C + 59A)D  + (- 10B C - 42A B)D
+--R                    + 
+--R                        3        2      2     2         2      3  3
+--R                      (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                 *
+--R                     6
+--R                    b
+--R                + 
+--R                           6       5         2               2       2  4
+--R                      - 21D  + 9B D  + (- 11C  - 154A C - 55B  - 167A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (49B C  + 10A B C + 11B  + 129A B)D
+--R                    + 
+--R                         4        3         2      2  2           2      3    2
+--R                    (- 4C  + 52A C  + (- 12B  - 12A )C  + (- 12A B  - 68A )C)D
+--R                 *
+--R                       5
+--R                    a b
+--R                + 
+--R                                  5                       4
+--R                      (75C - 13A)D  + (- 196B C + 452A B)D
+--R                    + 
+--R                          3        2        2       2           2      3  3
+--R                      (68C  - 10A C  + (143B  + 671A )C - 425A B  - 99A )D
+--R                    + 
+--R                                 3           2         3       2           3
+--R                          - 84B C  + 288A B C  + (- 26B  - 438A B)C + 14A B
+--R                        + 
+--R                             3
+--R                          70A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                         5        4       2      2  3         2      3  2
+--R                      (5C  - 65A C  + (15B  + 15A )C  + (15A B  + 85A )C )D
+--R                 *
+--R                     2 4
+--R                    a b
+--R                + 
+--R                         6         5         2               2      2  4
+--R                      12D  - 194B D  + (- 99C  - 164A C + 90B  + 29A )D
+--R                    + 
+--R                             2                  3       2   3
+--R                      (241B C  - 698A B C - 206B  - 737A B)D
+--R                    + 
+--R                               4         3         2       2  2
+--R                          - 45C  + 188A C  + (- 63B  - 966A )C
+--R                        + 
+--R                                 2       3        4       2 2       4
+--R                          (660A B  + 338A )C + 42B  + 357A B  - 127A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          65B C  - 336A B C  + (13B  + 432A B)C
+--R                        + 
+--R                                  3       3        2 3    4
+--R                          (- 22A B  - 192A B)C + 3A B  - A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6        5        2     2  4          2      3  3
+--R                      - 2C  + 26A C  + (- 6B  - 6A )C  + (- 6A B  - 34A )C
+--R                 *
+--R                     3 3
+--R                    a b
+--R                + 
+--R                                     5                    4
+--R                      (- 76C + 128A)D  + (500B C + 52A B)D
+--R                    + 
+--R                          3         2          2       2           2      3  3
+--R                      (72C  + 422A C  + (- 652B  - 256A )C + 812A B  + 98A )D
+--R                    + 
+--R                                3          2        3        2            3
+--R                          222B C  + 36A B C  + (348B  + 1410A B)C - 884A B
+--R                        + 
+--R                                3
+--R                          - 132A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2       2  3
+--R                          - 6C  - 120A C  + (- 8B  + 592A )C
+--R                        + 
+--R                                  2       3  2         4       2 2       4
+--R                          (- 30A B  - 172A )C  + (- 40B  - 384A B  + 278A )C
+--R                        + 
+--R                               4       3 2     5
+--R                          36A B  + 102A B  + 4A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5          4      3       2   3
+--R                      - 20B C  + 78A B C  + (2B  - 124A B)C
+--R                    + 
+--R                           3       3   2         2 3      4        3 3     5
+--R                      (4A B  + 144A B)C  + (- 18A B  - 16A B)C - 4A B  + 2A B
+--R                 *
+--R                     4 2
+--R                    a b
+--R                + 
+--R                           6        5       2               2       2  4
+--R                      - 32D  + 80B D  + (68C  - 88A C - 224B  - 172A )D
+--R                    + 
+--R                               2                  3      2   3
+--R                      (- 240B C  - 288A B C + 192B  - 16A B)D
+--R                    + 
+--R                             4         3        2       2  2
+--R                          40C  - 624A C  + (600B  + 576A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 336A B  - 368A )C - 64B  - 360A B  + 120A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4           3         3        2   2
+--R                          - 224B C  + 288A B C  + (- 80B  - 1344A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (672A B  + 480A B)C + 48B  + 336A B  - 160A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6       5      2       2  4            2      3  3
+--R                      4C  + 8A C  + (8B  - 100A )C  + (- 144A B  - 80A )C
+--R                    + 
+--R                         4      4  2           4       3 2      5        2 4
+--R                      (4B  - 36A )C  + (- 24A B  - 144A B  - 56A )C - 12A B
+--R                    + 
+--R                           4 2     6
+--R                      - 40A B  + 4A
+--R                 *
+--R                     5
+--R                    a b
+--R                + 
+--R                                  5                      4
+--R                      (32C + 64A)D  + (- 192B C + 32A B)D
+--R                    + 
+--R                            3        2       2          2  3
+--R                      (- 32C  + (320B  + 160A )C + 64A B )D
+--R                    + 
+--R                                2       3          3       3   2
+--R                      (- 96A B C  - 576B C + 320A B  - 160A B)D
+--R                    + 
+--R                               5         4       2       2  3       3 2
+--R                          - 32C  + 288A C  + (32B  - 320A )C  + 384A C
+--R                        + 
+--R                               4      2 2       4           4      5
+--R                          (160B  + 96A B  - 160A )C - 384A B  + 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       2   3           3       3   2
+--R                      32B C  - 160A B C  + 512A B C  + (- 32A B  - 320A B)C
+--R                    + 
+--R                          4           5      3 3      5
+--R                      224A B C + 32A B  + 32A B  - 32A B
+--R                 *
+--R                     6
+--R                    a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                        6        5       2              2      2  4
+--R                      6D  - 22B D  + (10C  - 76A C + 18B  + 42A )D
+--R                    + 
+--R                           2               3      2   3
+--R                      (2B C  + 36A B C - 2B  - 30A B)D
+--R                 *
+--R                     7
+--R                    b
+--R                + 
+--R                                    5                     4
+--R                      (- 16C - 24A)D  + (168B C - 272A B)D
+--R                    + 
+--R                            3         2         2       2           2       3  3
+--R                      (- 24C  + 288A C  + (- 32B  - 136A )C + 104A B  + 160A )D
+--R                    + 
+--R                             3           2      3       2     2
+--R                      (- 8B C  - 144A B C  + (8B  + 120A B)C)D
+--R                 *
+--R                       6
+--R                    a b
+--R                + 
+--R                          6         5       2              2       2  4
+--R                      - 5D  + 208B D  + (28C  + 52A C - 90B  - 258A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 166B C  + 352A B C + 168B  + 696A B)D
+--R                    + 
+--R                              4         3         2       2  2
+--R                          - 7C  - 344A C  + (- 36B  + 108A )C
+--R                        + 
+--R                                   2       3       4       2 2     4
+--R                          (- 228A B  - 572A )C - 9B  - 126A B  + 7A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                            4           3         3       2   2
+--R                      (10B C  + 180A B C  + (- 10B  - 150A B)C )D
+--R                 *
+--R                     2 5
+--R                    a b
+--R                + 
+--R                                    5                       4
+--R                      (155C - 103A)D  + (- 600B C - 212A B)D
+--R                    + 
+--R                          3         2        2        2            2       3  3
+--R                      (36C  - 308A C  + (816B  + 1470A )C - 1208A B  + 210A )D
+--R                    + 
+--R                                  3           2          3        2            3
+--R                          - 296B C  + 624A B C  + (- 332B  - 1848A B)C + 432A B
+--R                        + 
+--R                              3
+--R                          516A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5         4       2      2  3         2       3  2
+--R                          37C  + 171A C  + (62B  + 16A )C  + (54A B  + 548A )C
+--R                        + 
+--R                              4       2 2      4         4     3 2      5
+--R                          (17B  + 300A B  + 11A )C - 5A B  + 8A B  - 15A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5          4      3      2   3
+--R                      - 4B C  - 72A B C  + (4B  + 60A B)C
+--R                 *
+--R                     3 4
+--R                    a b
+--R                + 
+--R                         6         5          2                2       2  4
+--R                      94D  - 130B D  + (- 210C  - 318A C + 752B  + 284A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (494B C  + 940A B C - 88B  - 118A B)D
+--R                    + 
+--R                                4         3           2        2  2
+--R                          - 204C  + 880A C  + (- 1170B  - 2592A )C
+--R                        + 
+--R                                  2       3         4        2 2       4
+--R                          (1284A B  - 380A )C + 306B  + 1434A B  - 352A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3        3        2   2
+--R                          380B C  - 936A B C  + (102B  + 1596A B)C
+--R                        + 
+--R                                   3        3         5       2 3      4
+--R                          (- 700A B  - 1272A B)C - 22B  - 302A B  - 24A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6        5         2      2  4         2       3  3
+--R                      - 16C  - 38A C  + (- 12B  - 38A )C  + (76A B  - 112A )C
+--R                    + 
+--R                           4       2 2      4  2         4      3 2      5
+--R                      (- 8B  - 192A B  - 56A )C  + (10A B  - 16A B  + 38A )C
+--R                    + 
+--R                        2 4     4 2     6
+--R                      6A B  + 8A B  - 2A
+--R                 *
+--R                     4 3
+--R                    a b
+--R                + 
+--R                                      5                    4
+--R                      (- 220C - 244A)D  + (324B C - 60A B)D
+--R                    + 
+--R                                3         2           2       2            2
+--R                          - 112C  + 948A C  + (- 1776B  - 288A )C - 1008A B
+--R                        + 
+--R                              3
+--R                          188A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3           2         3       2             3
+--R                          - 108B C  - 936A B C  + (1104B  + 876A B)C - 1312A B
+--R                        + 
+--R                              3
+--R                          104A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2        2  3
+--R                          160C  - 668A C  + (176B  + 1512A )C
+--R                        + 
+--R                                2      3  2          4        2 2       4
+--R                          (60A B  + 80A )C  + (- 372B  - 1248A B  + 344A )C
+--R                        + 
+--R                                4      3 2      5
+--R                          484A B  + 84A B  - 84A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4       3       2   3
+--R                      - 84B C  + 360A B C  + (12B  - 592A B)C
+--R                    + 
+--R                             3       3   2       5       2 3       4          5
+--R                      (280A B  + 712A B)C  + (12B  + 276A B  - 124A B)C - 4A B
+--R                    + 
+--R                         3 3      5
+--R                      40A B  + 48A B
+--R                 *
+--R                     5 2
+--R                    a b
+--R                + 
+--R                           6         5        2                2      2  4
+--R                      - 16D  + 160B D  + (168C  + 368A C - 176B  - 24A )D
+--R                    + 
+--R                              2                  3      2   3
+--R                      (- 32B C  - 192A B C + 448B  + 96A B)D
+--R                    + 
+--R                              4         3         2       2  2
+--R                          288C  - 832A C  + (1008B  + 384A )C
+--R                        + 
+--R                                  2       3         4       2 2      4
+--R                          (1248A B  - 512A )C - 112B  + 432A B  - 32A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3          3        2   2
+--R                          - 192B C  + 1024A B C  + (- 928B  - 1536A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (320A B  + 768A B)C + 32B  + 352A B  - 448A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5       2       2  4           2      3  3
+--R                      - 24C  + 144A C  + (96B  - 168A )C  + (- 64A B  - 96A )C
+--R                    + 
+--R                          4       2 2       4  2            4       3 2      5
+--R                      (40B  + 384A B  + 152A )C  + (- 272A B  - 192A B  - 48A )C
+--R                    + 
+--R                           6       2 4      4 2      6
+--R                      - 16B  - 152A B  + 32A B  + 40A
+--R                 *
+--R                     6
+--R                    a b
+--R                + 
+--R                           5                       4
+--R                      64A D  + (- 192B C - 256A B)D
+--R                    + 
+--R                               2        2       2           2  3
+--R                      (- 256A C  + (384B  + 128A )C + 128A B )D
+--R                    + 
+--R                             3          3       3   2
+--R                      (- 640B C - 384A B  - 128A B)D
+--R                    + 
+--R                                5         4       2 3       3 2       4
+--R                          - 128C  + 320A C  - 384A C  + 384A C  + 640B C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 320A B  + 256A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       2   3       3   2
+--R                      64B C  - 512A B C  + 640A B C  - 896A B C
+--R                    + 
+--R                            5       4            5       5
+--R                      (- 64B  + 320A B)C + 128A B  - 128A B
+--R                 *
+--R                     7
+--R                    a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                                 5                  4
+--R                      (4C - 60A)D  + (8B C + 72A B)D
+--R                    + 
+--R                           3        2         2      2          2      3  3
+--R                      (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                 *
+--R                     8
+--R                    b
+--R                + 
+--R                         6        5         2               2       2  4
+--R                      28D  - 44B D  + (- 12C  + 280A C + 68B  + 340A )D
+--R                    + 
+--R                               2                3       2   3
+--R                      (- 124B C  - 56A B C - 52B  - 396A B)D
+--R                    + 
+--R                          4        3       2      2  2         2       3    2
+--R                      (16C  - 80A C  + (48B  + 48A )C  + (48A B  + 144A )C)D
+--R                 *
+--R                       7
+--R                    a b
+--R                + 
+--R                                     5                   4
+--R                      (- 208C - 16A)D  + (168B C + 8A B)D
+--R                    + 
+--R                                 3         2          2        2           2
+--R                            - 60C  - 252A C  + (- 512B  - 1728A )C + 608A B
+--R                          + 
+--R                                  3
+--R                            - 352A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                3           2        3        2           3
+--R                          368B C  - 384A B C  + (136B  + 1368A B)C - 56A B
+--R                        + 
+--R                                3
+--R                          - 152A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         4         2      2  3
+--R                          - 20C  + 100A C  + (- 60B  - 60A )C
+--R                        + 
+--R                                  2       3  2
+--R                          (- 60A B  - 180A )C
+--R                     *
+--R                        D
+--R                 *
+--R                     2 6
+--R                    a b
+--R                + 
+--R                            6         5        2                 2      2  4
+--R                      - 102D  + 166B D  + (276C  + 1024A C - 552B  + 12A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 204B C  - 280A B C + 136B  + 724A B)D
+--R                    + 
+--R                              4         3        2        2  2
+--R                          210C  - 280A C  + (888B  + 3060A )C
+--R                        + 
+--R                                   2        3         4        2 2       4
+--R                          (- 984A B  + 1120A )C - 194B  - 1296A B  + 258A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4           3         3        2   2
+--R                          - 370B C  + 504A B C  + (- 72B  - 1404A B)C
+--R                        + 
+--R                                 3       3        5     2 3      4
+--R                          (128A B  + 424A B)C + 2B  + 8A B  + 14A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6        5       2      2  4         2      3  3
+--R                      8C  - 40A C  + (24B  + 24A )C  + (24A B  + 72A )C
+--R                 *
+--R                     3 5
+--R                    a b
+--R                + 
+--R                                    5                       4
+--R                      (158C + 262A)D  + (- 842B C - 602A B)D
+--R                    + 
+--R                                3          2         2       2            2
+--R                            156C  - 2876A C  + (1688B  - 808A )C + 1080A B
+--R                          + 
+--R                                  3
+--R                            - 736A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                3           2          3        2             3
+--R                          - 4B C  + 540A B C  + (- 988B  - 2484A B)C + 1332A B
+--R                        + 
+--R                                3
+--R                          - 644A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5         4          2        2  3
+--R                          - 194C  + 414A C  + (- 360B  - 2216A )C
+--R                        + 
+--R                                 2        3  2        4        2 2       4
+--R                          (120A B  - 1200A )C  + (338B  + 2124A B  - 422A )C
+--R                        + 
+--R                                 4     3 2     5
+--R                          - 54A B  - 4A B  + 2A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4         3       2   3
+--R                      118B C  - 138A B C  + (- 12B  + 444A B)C
+--R                    + 
+--R                              3       3   2        5      2 3      4          5
+--R                      (- 76A B  - 292A B)C  + (- 2B  + 12A B  + 14A B)C - 2A B
+--R                    + 
+--R                          3 3      5
+--R                      - 4A B  - 18A B
+--R                 *
+--R                     4 4
+--R                    a b
+--R                + 
+--R                         6         5        2                2       2  4
+--R                      60D  - 264B D  + (240C  - 576A C + 356B  + 152A )D
+--R                    + 
+--R                              2                    3       2   3
+--R                      (1244B C  + 2472A B C - 1032B  + 596A B)D
+--R                    + 
+--R                                4          3           2        2  2
+--R                          - 520C  + 3168A C  + (- 1692B  + 1200A )C
+--R                        + 
+--R                                    2        3         4       2 2       4
+--R                          (- 2352A B  + 2152A )C - 148B  - 732A B  + 544A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3         3        2   2
+--R                          316B C  - 832A B C  + (1292B  + 3936A B)C
+--R                        + 
+--R                                    3       3          5        2 3       4
+--R                          (- 1224A B  + 384A B)C - 160B  - 1100A B  + 932A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6         5         2       2  4          2       3  3
+--R                      52C  - 104A C  + (- 60B  + 532A )C  + (104A B  + 520A )C
+--R                    + 
+--R                             4       2 2     4  2         4       3 2       5
+--R                      (- 108B  - 696A B  + 4A )C  + (16A B  + 176A B  + 128A )C
+--R                    + 
+--R                        6      2 4      4 2      6
+--R                      4B  + 12A B  + 12A B  - 44A
+--R                 *
+--R                     5 3
+--R                    a b
+--R                + 
+--R                                     5                     4
+--R                      (- 32C - 336A)D  + (576B C + 736A B)D
+--R                    + 
+--R                                  3         2          2       2           2
+--R                            - 672C  + 520A C  + (- 816B  - 768A )C - 432A B
+--R                          + 
+--R                                 3
+--R                            - 72A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3            2         3        2
+--R                          - 664B C  - 3024A B C  + (2416B  - 1800A B)C
+--R                        + 
+--R                                 3       3
+--R                          1712A B  - 496A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5          4        2       2  3
+--R                          360C  - 1680A C  + (608B  - 352A )C
+--R                        + 
+--R                                 2        3  2          4       2 2       4
+--R                          (984A B  - 1680A )C  + (- 528B  - 192A B  - 904A )C
+--R                        + 
+--R                                 4       3 2      5
+--R                          1088A B  - 120A B  - 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                              5           4          3        2   3
+--R                      - 192B C  + 344A B C  + (- 296B  - 1904A B)C
+--R                    + 
+--R                              3       3   2        5       2 3       4
+--R                      (- 16A B  + 288A B)C  + (144B  + 360A B  - 848A B)C
+--R                    + 
+--R                             5      3 3     5
+--R                      - 48A B  + 16A B  + 8A B
+--R                 *
+--R                     6 2
+--R                    a b
+--R                + 
+--R                           5          2                2       2  4
+--R                      64B D  + (- 144C  + 544A C - 256B  + 240A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 448B C  - 768A B C + 128B  - 192A B)D
+--R                    + 
+--R                              4         3        2       2  2
+--R                          480C  - 192A C  + (288B  + 768A )C
+--R                        + 
+--R                                 2      3         4       2 2      4
+--R                          (768A B  + 64A )C - 384B  + 480A B  + 32A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                   3           3       2   2
+--R                          1792A B C  + (- 1472B  + 384A B)C
+--R                        + 
+--R                                    3        3         5       2 3       4
+--R                          (- 1664A B  + 1280A B)C - 64B  - 576A B  - 256A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5       2      2  4         2       3  3
+--R                      - 80C  + 288A C  + (96B  + 80A )C  + (64A B  + 256A )C
+--R                    + 
+--R                           4       2 2       4  2            4      3 2      5
+--R                      (432B  + 768A B  + 464A )C  + (- 160A B  + 64A B  - 32A )C
+--R                    + 
+--R                            2 4       4 2      6
+--R                      - 144A B  + 288A B  + 48A
+--R                 *
+--R                     7
+--R                    a b
+--R                + 
+--R                                4
+--R                      - 256A B D
+--R                    + 
+--R                           3         2        2       2           2  3
+--R                      (128C  - 256A C  + (384B  - 128A )C + 256A B )D
+--R                    + 
+--R                               2       3          3       3   2
+--R                      (384A B C  - 256B C - 384A B  + 128A B)D
+--R                    + 
+--R                                5         4          2       2  3
+--R                          - 128C  + 128A C  + (- 128B  - 384A )C
+--R                        + 
+--R                               4       2 2           4       3 2       5
+--R                          (640B  - 384A B )C + 256A B  + 256A B  - 128A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4       2   3          3       3   2
+--R                      128B C  - 512A B C  + 512A B C  + (128A B  - 896A B)C
+--R                    + 
+--R                             5       4            5       3 3       5
+--R                      (- 256B  + 384A B)C + 128A B  - 128A B  - 128A B
+--R                 *
+--R                     8
+--R                    a
+--R             *
+--R                c
+--R            + 
+--R                      6        5        2              2      2  4
+--R                  - 8D  + 24B D  + (- 8C  + 48A C - 24B  - 72A )D
+--R                + 
+--R                       2               3      2   3
+--R                  (8B C  - 48A B C + 8B  + 72A B)D
+--R             *
+--R                 9
+--R                b
+--R            + 
+--R                               5                      4
+--R                  (32C + 128A)D  + (- 160B C - 64A B)D
+--R                + 
+--R                      3         2        2       2          2      3  3
+--R                  (48C  - 272A C  + (160B  + 368A )C - 64A B  + 48A )D
+--R                + 
+--R                          3           2         3       2     2
+--R                  (- 32B C  + 192A B C  + (- 32B  - 288A B)C)D
+--R             *
+--R                   8
+--R                a b
+--R            + 
+--R                     6         5       2                2       2  4
+--R                  12D  - 152B D  + (40C  - 896A C + 176B  - 160A )D
+--R                + 
+--R                         2                 3      2   3
+--R                  (400B C  + 432A B C - 72B  - 72A B)D
+--R                + 
+--R                            4         3          2       2  2
+--R                      - 100C  + 544A C  + (- 336B  - 672A )C
+--R                    + 
+--R                            2       3        4       2 2      4
+--R                      (48A B  - 176A )C + 36B  + 312A B  - 12A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                        4           3       3       2   2
+--R                  (40B C  - 240A B C  + (40B  + 360A B)C )D
+--R             *
+--R                 2 7
+--R                a b
+--R            + 
+--R                               5                     4
+--R                  (96C - 280A)D  + (752B C + 608A B)D
+--R                + 
+--R                         3          2          2       2           2       3  3
+--R                  (- 296C  + 2152A C  + (- 728B  + 816A )C - 504A B  + 432A )D
+--R                + 
+--R                           3            2        3       2            3  2
+--R                  (- 464B C  - 1008A B C  + (384B  + 240A B)C - 304A B )D
+--R                + 
+--R                         5         4        2       2  3          2       3  2
+--R                      88C  - 464A C  + (272B  + 520A )C  + (192A B  + 248A )C
+--R                    + 
+--R                            4       2 2      4        3 2      5
+--R                      (- 88B  - 744A B  - 32A )C - 40A B  + 24A
+--R                 *
+--R                    D
+--R                + 
+--R                         5          4         3       2   3
+--R                  - 16B C  + 96A B C  + (- 16B  - 144A B)C
+--R             *
+--R                 3 6
+--R                a b
+--R            + 
+--R                    6         5          2                2      2  4
+--R                  8D  + 220B D  + (- 524C  + 800A C - 320B  + 68A )D
+--R                + 
+--R                            2                   3        2   3
+--R                  (- 1368B C  - 2496A B C + 408B  - 1008A B)D
+--R                + 
+--R                          4          3         2        2  2
+--R                      464C  - 2480A C  + (1176B  - 1224A )C
+--R                    + 
+--R                              2        3        4       2 2       4
+--R                      (1728A B  - 1392A )C + 24B  + 576A B  - 296A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                            4            3          3       2   2
+--R                      220B C  + 1152A B C  + (- 600B  - 624A B)C
+--R                    + 
+--R                             3       3         5       2 3       4
+--R                      (448A B  + 304A B)C + 44B  + 512A B  - 188A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6         5         2       2  4            2       3  3
+--R                  - 28C  + 144A C  + (- 72B  - 140A )C  + (- 176A B  - 144A )C
+--R                + 
+--R                      4       2 2      4  2       3 2      5       2 4     4 2
+--R                  (52B  + 432A B  + 92A )C  + (32A B  - 64A )C - 4A B  + 8A B
+--R                + 
+--R                     6
+--R                  12A
+--R             *
+--R                 4 5
+--R                a b
+--R            + 
+--R                                  5                       4
+--R                  (- 120C + 416A)D  + (- 484B C - 532A B)D
+--R                + 
+--R                       3         2         2       2           2       3  3
+--R                  (968C  - 824A C  + (1144B  + 400A )C + 856A B  + 128A )D
+--R                + 
+--R                             3            2           3        2             3
+--R                      1144B C  + 3768A B C  + (- 1336B  + 2760A B)C - 1096A B
+--R                    + 
+--R                           3
+--R                      1112A B
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                            5          4          2       2  3
+--R                      - 320C  + 1464A C  + (- 912B  + 712A )C
+--R                    + 
+--R                                2        3  2        4       2 2       4
+--R                      (- 1968A B  + 1304A )C  + (176B  - 984A B  + 760A )C
+--R                    + 
+--R                              4       3 2      5
+--R                      - 584A B  - 232A B  - 80A
+--R                 *
+--R                    D
+--R                + 
+--R                         5           4        3       2   3
+--R                  - 20B C  - 516A B C  + (280B  + 488A B)C
+--R                + 
+--R                          3       3   2         5       2 3       4           5
+--R                  (- 88A B  - 360A B)C  + (- 52B  - 552A B  + 204A B)C + 12A B
+--R                + 
+--R                       3 3      5
+--R                  - 72A B  + 12A B
+--R             *
+--R                 5 4
+--R                a b
+--R            + 
+--R                       6         5        2                 2       2  4
+--R                  - 48D  - 200B D  + (240C  - 1096A C + 232B  - 472A )D
+--R                + 
+--R                         2                  3       2   3
+--R                  (136B C  + 720A B C - 112B  + 312A B)D
+--R                + 
+--R                            4         3           2        2  2
+--R                      - 904C  + 352A C  + (- 1416B  - 1152A )C
+--R                    + 
+--R                                2       3         4        2 2       4
+--R                      (- 2160A B  - 528A )C + 480B  - 1080A B  - 296A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                              4            3         3        2   2
+--R                      - 416B C  - 2688A B C  + (1512B  - 2208A B)C
+--R                    + 
+--R                              3        3          5       2 3       4
+--R                      (2224A B  - 2336A B)C + 152B  + 824A B  - 224A B
+--R                 *
+--R                    D
+--R                + 
+--R                     6         5        2       2  4          2       3  3
+--R                  88C  - 360A C  + (264B  - 176A )C  + (880A B  - 320A )C
+--R                + 
+--R                         4       2 2       4  2          4       3 2       5
+--R                  (- 248B  + 144A B  - 472A )C  + (504A B  + 416A B  + 104A )C
+--R                + 
+--R                    6       2 4       4 2      6
+--R                  8B  + 320A B  - 136A B  - 16A
+--R             *
+--R                 6 3
+--R                a b
+--R            + 
+--R                               5                     4
+--R                  (208C - 48A)D  + (432B C + 528A B)D
+--R                + 
+--R                         3          2          2       2           2       3  3
+--R                  (- 128C  + 1104A C  + (- 576B  + 704A )C - 544A B  + 112A )D
+--R                + 
+--R                         3          2        3       2            3       3   2
+--R                  (432B C  - 96A B C  + (160B  + 528A B)C + 320A B  - 160A B)D
+--R                + 
+--R                          5        4        2       2  3           2       3  2
+--R                      448C  - 48A C  + (768B  + 928A )C  + (1776A B  + 608A )C
+--R                    + 
+--R                            4        2 2       4           4       3 2       5
+--R                    (- 1168B  + 2112A B  + 352A )C - 752A B  + 272A B  + 400A
+--R                 *
+--R                    D
+--R                + 
+--R                       5           4          3       2   3
+--R                  16B C  + 960A B C  + (- 624B  + 224A B)C
+--R                + 
+--R                            3        3   2         5       2 3      4
+--R                  (- 1120A B  + 1440A B)C  + (- 16B  - 528A B  - 48A B)C
+--R                + 
+--R                          5       3 3      5
+--R                  - 336A B  - 160A B  + 96A B
+--R             *
+--R                 7 2
+--R                a b
+--R            + 
+--R                         2              2      2  4
+--R                  (- 288C  + 64A C - 64B  + 96A )D
+--R                + 
+--R                           2                  3       2   3
+--R                  (- 256B C  - 768A B C + 128B  - 384A B)D
+--R                + 
+--R                              3        2       2  2          2      3
+--R                      - 576A C  + (576B  - 192A )C  + (384A B  - 64A )C
+--R                    + 
+--R                          2 2      4
+--R                      192A B  + 64A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                              4           3        3       2   2
+--R                      - 384B C  - 384A B C  + (128B  - 768A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 512A B  - 128A B)C + 128B  - 256A B  - 128A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6          2       2  4            2       3  3
+--R                  - 96C  + (- 192B  - 224A )C  + (- 704A B  - 256A )C
+--R                + 
+--R                       4       2 2       4  2          4       3 2       5
+--R                  (736B  - 576A B  - 160A )C  + (576A B  - 448A B  - 256A )C
+--R                + 
+--R                     6       2 4       4 2      6
+--R                  64B  + 224A B  + 128A B  - 32A
+--R             *
+--R                 8
+--R                a b
+--R            + 
+--R                       3       2          2  3            2       3        3   2
+--R                  (128C  - 128A C + 256A B )D  + (384A B C  - 256B C + 128A B)D
+--R                + 
+--R                         4       2 3       2 2          4       5           5
+--R                  (128A C  - 128B C  - 384A B C + 256A B  - 128A )D + 128B C
+--R                + 
+--R                      2   3         3 2          5       4          3 3
+--R                  512A B C  + 128A B C  + (- 256B  + 384A B)C - 128A B
+--R             *
+--R                 9
+--R                a
+--R     + 
+--R         2a %%BN1
+--R      *
+--R         log
+--R                           2 3 8
+--R                      32A D a c
+--R                    + 
+--R                                 2 2 2         3        2  3
+--R                          - 16A D a b  + (- 16D  - 16B D )a b
+--R                        + 
+--R                                 2                   2      3  4
+--R                          (128A D  - 128A B D - 32A C  + 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              2   4      3       2  2 3
+--R                          2A D a b  + (8D  + 8B D )a b
+--R                        + 
+--R                                        2                  2      3  3 2
+--R                          ((32C - 448A)D  + 64A B D + 16A C  - 16A )a b
+--R                        + 
+--R                                   3        2
+--R                              - 32D  + 32B D
+--R                            + 
+--R                                    2               2       2          2
+--R                              (- 48C  + 224A C + 64B  + 144A )D + 16B C
+--R                            + 
+--R                                           2
+--R                              96A B C - 48A B
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                      2                 3         2      2
+--R                              - 128A D  - 512A B D + 64C  - 128A C  - 64A C
+--R                            + 
+--R                                    2       3
+--R                              128A B  + 128A
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              3      2    5
+--R                          (- D  - B D )a b
+--R                        + 
+--R                                          2                2     3  2 4
+--R                          ((- 16C + 192A)D  - 8A B D - 2A C  + 2A )a b
+--R                        + 
+--R                                  3         2       2               2      2
+--R                              160D  + 128B D  + (24C  - 112A C - 32B  - 72A )D
+--R                            + 
+--R                                    2                2
+--R                              - 8B C  - 48A B C + 24A B
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                           2                             3
+--R                              (80C - 560A)D  + (- 96B C + 1312A B)D - 48C
+--R                            + 
+--R                                    2         2      2           2       3
+--R                              304A C  + (- 48B  - 16A )C - 112A B  - 368A
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              128D  + 256B D
+--R                            + 
+--R                                     2               2       2           2
+--R                              (- 384C  + 512A C + 64B  + 384A )D - 128B C
+--R                            + 
+--R                                   3       2
+--R                              - 64B  - 384A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                       2                  3         2       2
+--R                              - 1024A D  + 512A B D + 256C  + 128A C  - 256A C
+--R                            + 
+--R                                    2       3
+--R                              512A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                     2   6
+--R                          (2C - 22A)D a b
+--R                        + 
+--R                                   3        2        2             2     2
+--R                              - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D
+--R                            + 
+--R                                 2              2
+--R                              B C  + 6A B C - 3A B
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                               2                          3
+--R                              (- 328C + 1896A)D  + (48B C - 528A B)D + 12C
+--R                            + 
+--R                                      2       2      2          2       3
+--R                              - 120A C  + (24B  + 20A )C + 32A B  + 152A
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 224D  - 800B D
+--R                            + 
+--R                                   2                 2        2          2
+--R                              (720C  - 2080A C - 512B  - 1392A )D + 16B C
+--R                            + 
+--R                                              3       2
+--R                              - 672A B C + 64B  + 720A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                             3
+--R                              (160C + 2976A)D  + (576B C + 1088A B)D - 608C
+--R                            + 
+--R                                    2        2       2            2      3
+--R                              416A C  + (288B  + 992A )C - 1120A B  - 32A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              256D  - 256B D
+--R                            + 
+--R                                     2                 2       2           2
+--R                              (- 192C  - 1664A C - 640B  - 960A )D - 448B C
+--R                            + 
+--R                                                3       2
+--R                              - 1152A B C - 128B  - 192A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                      2                   3          2       2
+--R                              - 512A D  + 4096A B D - 256C  + 1024A C  + 256A C
+--R                            + 
+--R                                      2        3
+--R                              - 512A B  - 1024A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             3       2    7
+--R                          (8D  + 8B D )a b
+--R                        + 
+--R                                            2                        3        2
+--R                              (141C - 755A)D  + (- 6B C + 58A B)D - C  + 13A C
+--R                            + 
+--R                                   2     2         2      3
+--R                              (- 3B  - 3A )C - 3A B  - 17A
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    3        2
+--R                              - 284D  - 36B D
+--R                            + 
+--R                                     2                2       2          2
+--R                              (- 276C  + 888A C + 228B  + 588A )D + 12B C
+--R                            + 
+--R                                            3       2
+--R                              312A B C - 20B  - 276A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              2                             3
+--R                              (- 32C - 2016A)D  + (192B C - 3072A B)D + 320C
+--R                            + 
+--R                                      2       2       2           2       3
+--R                              - 720A C  + (96B  - 192A )C + 672A B  + 848A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 896D  - 384B D
+--R                            + 
+--R                                    2                 2       2            2
+--R                              (1344C  + 1408A C + 896B  + 576A )D + 1088B C
+--R                            + 
+--R                                              3        2
+--R                              1920A B C + 384B  + 1344A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                             3
+--R                              (- 640C + 4224A)D  + (768B C - 8448A B)D - 128C
+--R                            + 
+--R                                       2        2       2           2        3
+--R                              - 1920A C  + (384B  + 640A )C - 128A B  + 2432A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3          2
+--R                              - 256D  - 1280B D
+--R                            + 
+--R                                    2                 2        2            2
+--R                              (3072C  - 4096A C - 512B  - 3072A )D + 1024B C
+--R                            + 
+--R                                  3        2
+--R                              512B  + 3072A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                     2                    3         2        2
+--R                              2048A D  + 2048A B D - 2048C  + 512A C  + 2048A C
+--R                            + 
+--R                                       2       3
+--R                              - 4096A B  - 512A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                        2   8
+--R                          (- 16C + 80A)D a b
+--R                        + 
+--R                                  3         2       2               2      2
+--R                              146D  + 118B D  + (30C  - 100A C - 26B  - 66A )D
+--R                            + 
+--R                                    2               3      2
+--R                              - 2B C  - 36A B C + 2B  + 30A B
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                             2                              3
+--R                              (726C - 2090A)D  + (- 180B C + 1100A B)D - 62C
+--R                            + 
+--R                                    2         2      2           2       3
+--R                              230A C  + (- 90B  - 58A )C - 154A B  - 350A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1752D  + 2760B D
+--R                            + 
+--R                                      2                 2        2           2
+--R                              (- 2160C  + 3840A C + 696B  + 2736A )D - 528B C
+--R                            + 
+--R                                             3        2
+--R                              576A B C - 312B  - 2160A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                       2                                3
+--R                              - 8160A D  + (- 4608B C + 5376A B)D + 864C
+--R                            + 
+--R                                    2           2        2           2        3
+--R                              192A C  + (- 2304B  - 3936A )C + 960A B  - 3264A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1152D  + 4224B D
+--R                            + 
+--R                                      2                   2        2
+--R                              (- 5760C  + 11520A C + 2304B  + 8064A )D
+--R                            + 
+--R                                       2                   3        2
+--R                              - 1152B C  + 2304A B C - 768B  - 5760A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D
+--R                            + 
+--R                                 3          2           2        2            2
+--R                            3840C  - 3072A C  + (- 2304B  - 6912A )C + 6912A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 512D  + 512B D
+--R                            + 
+--R                                    2                  2       2            2
+--R                              (3840C  + 2560A C + 2048B  + 768A )D + 2816B C
+--R                            + 
+--R                                               3        2
+--R                              4608A B C + 1024B  + 3840A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                     2                    3          2        2
+--R                              2048A D  - 8192A B D - 1024C  - 2048A C  + 1024A C
+--R                            + 
+--R                                       2        3
+--R                              - 2048A B  + 2048A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                3        2    9
+--R                          (- 16D  - 16B D )a b
+--R                        + 
+--R                                              2                         3
+--R                              (- 308C + 972A)D  + (24B C - 104A B)D + 4C
+--R                            + 
+--R                                     2       2      2          2      3
+--R                              - 20A C  + (12B  + 12A )C + 12A B  + 36A
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 456D  - 920B D
+--R                            + 
+--R                                   2                 2        2           2
+--R                              (744C  - 1712A C - 376B  - 1176A )D + 104B C
+--R                            + 
+--R                                              3       2
+--R                              - 432A B C + 88B  + 744A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                                2                             3
+--R                              (- 1668C + 8316A)D  + (1656B C - 136A B)D - 364C
+--R                            + 
+--R                                    2        2        2           2       3
+--R                              380A C  + (828B  + 1468A )C - 452A B  + 724A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 2496D  - 6432B D
+--R                            + 
+--R                                    2                   2        2           2
+--R                              (5328C  - 14304A C - 3408B  - 9648A )D + 336B C
+--R                            + 
+--R                                                3        2
+--R                              - 4320A B C + 528B  + 5328A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              2                                3
+--R                              (6528C + 3456A)D  + (11520B C + 7296A B)D - 3072C
+--R                            + 
+--R                                   2         2         2            2        3
+--R                            4704A C  + (5760B  + 10752A )C - 4224A B  + 2976A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                   3         2
+--R                              1024D  - 512B D
+--R                            + 
+--R                                      2                  2        2            2
+--R                              (- 5760C  - 3840A C - 3072B  - 1152A )D - 4224B C
+--R                            + 
+--R                                                 3        2
+--R                              - 6912A B C - 1536B  - 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2
+--R                              (1280C - 6912A)D  + (- 1536B C + 12800A B)D
+--R                            + 
+--R                                   3          2          2        2            2
+--R                              1280C  + 2816A C  + (- 768B  - 2304A )C + 2304A B
+--R                            + 
+--R                                     3
+--R                              - 3840A
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                     2           2                  2        2
+--R                              2048B D  + (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                            + 
+--R                                       2        3        2
+--R                              - 2048B C  - 1024B  - 6144A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                                 3          2        2
+--R                              - 8192A B D + 4096C  - 2048A C  - 4096A C
+--R                            + 
+--R                                     2        3
+--R                              8192A B  + 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                  2   10
+--R                      (32C - 96A)D a b
+--R                    + 
+--R                             3        2         2               2       2
+--R                          24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D
+--R                        + 
+--R                                2               3      2
+--R                          - 8B C  + 48A B C - 8B  - 72A B
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                         2                             3
+--R                          (376C - 1416A)D  + (- 144B C - 144A B)D + 40C
+--R                        + 
+--R                                 2         2       2          2      3
+--R                          - 72A C  + (- 72B  - 136A )C + 56A B  - 24A
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              3          2
+--R                          360D  + 1080B D
+--R                        + 
+--R                                 2                 2        2          2
+--R                          (- 936C  + 2608A C + 632B  + 1752A )D - 40B C
+--R                        + 
+--R                                        3       2
+--R                          816A B C - 88B  - 936A B
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                          2                                3
+--R                          (- 24C - 4248A)D  + (- 2160B C - 2160A B)D + 536C
+--R                        + 
+--R                                   2           2        2           2       3
+--R                          - 1080A C  + (- 1080B  - 1976A )C + 712A B  - 360A
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1152D  + 3456B D
+--R                        + 
+--R                                  2                  2        2           2
+--R                          (- 1296C  + 7968A C + 2400B  + 5040A )D + 816B C
+--R                        + 
+--R                                         3        2
+--R                          3744A B C + 96B  - 1296A B
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            2                                3
+--R                          (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D + 960C
+--R                        + 
+--R                                   2           2        2           2        3
+--R                          - 3456A C  + (- 3456B  - 5568A )C + 768A B  - 1152A
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1536D  - 4608B D
+--R                        + 
+--R                                 2                   2        2            2
+--R                          (11520C  - 12800A C - 1024B  - 9984A )D + 4352B C
+--R                        + 
+--R                                           3         2
+--R                          1536A B C + 2048B  + 11520A B
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                          2                               3
+--R                          (6656C - 1536A)D  + (9216B C + 9216A B)D - 5632C
+--R                        + 
+--R                                 2         2         2            2        3
+--R                          4608A C  + (4608B  + 11776A )C - 9728A B  + 1536A
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                  2        2            2
+--R                          (- 9216C  + 2048A C - 2048B  + 3072A )D - 5120B C
+--R                        + 
+--R                                             3        2
+--R                          - 6144A B C - 2048B  - 9216A B
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                            3        2           2  11
+--R                      (4096C  - 4096A C + 8192A B )a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                         3 2 8
+--R                  - 16A D a c
+--R                + 
+--R                          3   2        3          2  2
+--R                      4A D a b  + (8B D  + 24A C D )a b
+--R                    + 
+--R                                   3          2           2      3    3
+--R                      ((16C - 64A)D  + 80A B D  + (- 16A C  - 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                             3         2    3
+--R                      (- 2B D  - 6A C D )a b
+--R                    + 
+--R                                         3                     2
+--R                          (- 12C + 188A)D  + (- 12B C - 52A B)D
+--R                        + 
+--R                                 2      3
+--R                          (- 4A C  + 12A )D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                               4        3         2              2       2  2
+--R                          - 24D  + 16B D  + (- 24C  + 16A C - 40B  - 120A )D
+--R                        + 
+--R                               2                2          3     3
+--R                          (8B C  - 48A B C + 24A B)D + 8A C  - 8A C
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      3                      2
+--R                          (64C + 32A)D  + (- 96B C + 320A B)D
+--R                        + 
+--R                              3        2       2          2      3            2
+--R                          (16C  - 64A C  + 112A C - 128A B  - 64A )D + 48A B C
+--R                        + 
+--R                             3
+--R                          16A B
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                  3                 2        2     3      4
+--R                      ((2C - 41A)D  + (3B C + 8A B)D  + (2A C  - 2A )D)a b
+--R                    + 
+--R                             4        3       2               2      2  2
+--R                          14D  - 80B D  + (18C  - 224A C + 26B  + 66A )D
+--R                        + 
+--R                               2                2          3     3
+--R                          (2B C  + 36A B C - 18A B)D - 2A C  + 2A C
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                          3                     2
+--R                          (- 144C + 232A)D  + (120B C - 808A B)D
+--R                        + 
+--R                               3         2       2      2           2       3
+--R                          (- 4C  + 212A C  + (24B  - 20A )C + 112A B  + 196A )D
+--R                        + 
+--R                                3          2      2        3
+--R                          - 4B C  - 36A B C  + 12A B C - 4A B
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               4        3         2              2       2  2
+--R                          - 64D  + 96B D  + (- 24C  - 80A C - 64B  - 408A )D
+--R                        + 
+--R                                2                3       2        4        3
+--R                          (80B C  - 96A B C + 64B  + 336A B)D - 8C  - 32A C
+--R                        + 
+--R                                2      2  2           2      3        2 2     4
+--R                          (- 24B  - 48A )C  + (- 48A B  - 32A )C - 24A B  - 8A
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                3                       2
+--R                          384A D  + (- 384B C - 128A B)D
+--R                        + 
+--R                              3         2        2       2           2
+--R                          (64C  - 128A C  + (192B  + 448A )C - 512A B )D
+--R                        + 
+--R                                 3           2       2           3      3
+--R                          - 64B C  + 192A B C  - 192A B C + 64A B  + 64A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              4        3        2             2     2  2
+--R                          - 2D  + 18B D  + (- 3C  + 52A C - 4B  - 9A )D
+--R                        + 
+--R                                2              2
+--R                          (- B C  - 6A B C + 3A B)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                       3                    2
+--R                          (86C - 686A)D  + (54B C + 420A B)D
+--R                        + 
+--R                               3       2         2      2          2       3
+--R                          (- 4C  + 9A C  + (- 18B  - 14A )C - 32A B  - 115A )D
+--R                        + 
+--R                             3         2     2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              4        3        2                2        2  2
+--R                          224D  - 92B D  + (162C  + 280A C + 320B  + 1206A )D
+--R                        + 
+--R                                   2                 3       2        4        3
+--R                          (- 172B C  + 336A B C - 60B  - 492A B)D + 6C  - 48A C
+--R                        + 
+--R                              2      2  2         2      3       2 2     4
+--R                          (18B  + 24A )C  + (24A B  + 80A )C + 6A B  + 2A
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                           3                     2
+--R                          (- 232C - 1128A)D  + (936B C - 584A B)D
+--R                        + 
+--R                                    3         2          2        2            2
+--R                              - 208C  + 400A C  + (- 312B  - 1376A )C + 1192A B
+--R                            + 
+--R                                   3
+--R                              - 64A
+--R                         *
+--R                            D
+--R                        + 
+--R                             3           2       3       2           3       3
+--R                        96B C  - 384A B C  + (24B  + 240A B)C - 24A B  - 144A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             4         3        2               2       2  2
+--R                          64D  + 256B D  + (144C  + 608A C - 32B  + 336A )D
+--R                        + 
+--R                                2      3       2         4        3
+--R                          (64B C  + 64B  + 768A B)D + 48C  - 96A C
+--R                        + 
+--R                              2      2  2           2       3        4       2 2
+--R                          (48B  + 96A )C  + (- 96A B  + 224A )C - 32B  - 144A B
+--R                        + 
+--R                               4
+--R                          - 16A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          3            2
+--R                          (- 256C + 256A)D  - 1792A B D
+--R                        + 
+--R                              3         2        2      2           2       3
+--R                          (64C  - 256A C  + (768B  - 64A )C + 128A B  + 256A )D
+--R                        + 
+--R                                  3           2          3       2            3
+--R                          - 256B C  + 192A B C  + (- 128B  - 768A B)C + 256A B
+--R                        + 
+--R                             3
+--R                          64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                         3                     2
+--R                          (- 13C + 139A)D  + (- 18B C - 58A B)D
+--R                        + 
+--R                            3        2      2     2         2      3
+--R                          (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 109D  + 265B D
+--R                        + 
+--R                                 2                2       2  2
+--R                          (- 114C  + 591A C - 183B  - 543A )D
+--R                        + 
+--R                                2                 3       2       4        3
+--R                          (27B C  - 228A B C + 19B  + 225A B)D - C  + 13A C
+--R                        + 
+--R                               2     2  2          2      3
+--R                          (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        3                        2
+--R                          (258C + 874A)D  + (- 978B C + 1542A B)D
+--R                        + 
+--R                              3         2       2       2           2       3
+--R                          (94C  - 990A C  + (54B  + 426A )C - 714A B  - 346A )D
+--R                        + 
+--R                                 3           2         3       2          3
+--R                          - 10B C  + 234A B C  + (- 14B  - 174A B)C + 2A B
+--R                        + 
+--R                             3
+--R                          30A B
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                  3          2               2       2  2
+--R                          - 768B D  + (- 192C  - 736A C - 80B  + 384A )D
+--R                        + 
+--R                                   2                 3        2            3
+--R                          (- 272B C  + 96A B C - 384B  - 1968A B)D + 368A C
+--R                        + 
+--R                              2       2  2          2       3        4       2 2
+--R                          (48B  + 192A )C  + (288A B  - 112A )C + 16B  + 240A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (384C - 1536A)D  + (576B C + 4032A B)D
+--R                        + 
+--R                                    3         2           2        2           2
+--R                              - 416C  + 672A C  + (- 2112B  - 1312A )C + 512A B
+--R                            + 
+--R                                    3
+--R                              - 992A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          480B C  - 672A B C  + (128B  + 1632A B)C - 512A B
+--R                        + 
+--R                                3
+--R                          - 160A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          256D  - 384B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 192C  + 1024A C - 256B  + 2112A )D
+--R                        + 
+--R                                   2                  3        2          4
+--R                          (- 640B C  - 768A B C - 256B  - 1152A B)D + 192C
+--R                        + 
+--R                             2       2  2          2       3         2 2      4
+--R                        (576B  + 384A )C  + (384A B  + 512A )C - 192A B  - 64A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (- 256C - 512A)D  + (1536B C - 1280A B)D
+--R                        + 
+--R                                 2        2           2       3         3
+--R                          (256A C  - 2048A C + 2560A B  + 256A )D - 512B C
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                             4        3       2               2      2  2
+--R                          14D  - 54B D  + (18C  - 140A C + 26B  + 66A )D
+--R                        + 
+--R                               2               3      2
+--R                          (2B C  + 36A B C - 2B  - 30A B)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                          3                    2
+--R                          (- 142C + 688A)D  + (54B C - 800A B)D
+--R                        + 
+--R                             3         2       2      2           2       3
+--R                          (6C  + 100A C  + (54B  + 22A )C + 160A B  + 248A )D
+--R                        + 
+--R                                3          2      3      2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 416D  + 190B D
+--R                        + 
+--R                                2                 2        2  2
+--R                          (- 84C  - 1254A C - 438B  - 2514A )D
+--R                        + 
+--R                                 2                  3        2         4
+--R                          (666B C  - 264A B C + 298B  + 1758A B)D - 20C
+--R                        + 
+--R                               3         2       2  2            2       3
+--R                          22A C  + (- 66B  - 102A )C  + (- 114A B  - 158A )C
+--R                        + 
+--R                              4      2 2      4
+--R                          - 2B  - 48A B  - 14A
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                         3                        2
+--R                          (284C + 2876A)D  + (- 588B C - 3516A B)D
+--R                        + 
+--R                                  3        2         2        2            2
+--R                              788C  + 84A C  + (2292B  + 4428A )C - 1404A B
+--R                            + 
+--R                                   3
+--R                              2252A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 532B C  + 492A B C  + (- 148B  - 1164A B)C + 140A B
+--R                        + 
+--R                              3
+--R                          308A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 608D  + 640B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (240C  - 3552A C + 960B  - 5232A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (1632B C  + 1536A B C + 928B  + 1632A B)D - 464C
+--R                        + 
+--R                                  3          2        2  2
+--R                          - 128A C  + (- 912B  - 1344A )C
+--R                        + 
+--R                                   2        3         4       2 2      4
+--R                          (- 384A B  - 1664A )C + 160B  + 528A B  + 16A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                          3                         2
+--R                          (1280C + 1664A)D  + (- 1920B C + 3456A B)D
+--R                        + 
+--R                                  3         2          2        2            2
+--R                              128C  + 576A C  + (- 192B  + 6144A )C - 4800A B
+--R                            + 
+--R                                  3
+--R                              704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2        3       2            3
+--R                          - 256B C  - 768A B C  + (704B  + 384A B)C - 448A B
+--R                        + 
+--R                              3
+--R                          128A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          128D  - 1280B D
+--R                        + 
+--R                                 2                 2       2  2
+--R                          (- 768C  - 2560A C + 640B  + 768A )D
+--R                        + 
+--R                                   2                   2          4         3
+--R                          (- 896B C  - 768A B C - 4224A B)D - 128C  - 128A C
+--R                        + 
+--R                               2       2  2          2       3         4
+--R                          (384B  - 768A )C  + (768A B  - 896A )C + 256B
+--R                        + 
+--R                              2 2       4
+--R                          384A B  - 128A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  3                       2
+--R                          - 512A D  + (1536B C + 2048A B)D
+--R                        + 
+--R                                      3          2           2        2
+--R                                - 256C  + 2048A C  + (- 3072B  - 1792A )C
+--R                              + 
+--R                                       2
+--R                                2048A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                          1024B C  - 768A B C  + 3072A B C - 1024A B  - 256A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                       3                    2
+--R                          (20C - 156A)D  + (24B C + 104A B)D
+--R                        + 
+--R                               3        2         2      2          2      3
+--R                          (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                     *
+--R                           8
+--R                        a b
+--R                    + 
+--R                              4         3        2                2        2  2
+--R                          204D  - 316B D  + (144C  - 364A C + 292B  + 1092A )D
+--R                        + 
+--R                                   2                 3       2        4        3
+--R                          (- 164B C  + 288A B C - 84B  - 636A B)D + 4C  - 20A C
+--R                        + 
+--R                              2      2  2         2      3
+--R                          (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (- 36C - 3084A)D  + (1368B C + 1312A B)D
+--R                        + 
+--R                                    3          2          2        2           2
+--R                              - 428C  + 1348A C  + (- 996B  - 1780A )C + 644A B
+--R                            + 
+--R                                    3
+--R                              - 996A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3           2       3       2          3      3
+--R                        128B C  - 312A B C  + (64B  + 528A B)C - 8A B  - 56A B
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          924D  + 588B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 216C  + 5556A C + 60B  + 6156A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 2172B C  - 1584A B C - 444B  - 1332A B)D + 252C
+--R                        + 
+--R                                  3        2       2  2           2        3
+--R                          - 708A C  + (540B  + 396A )C  + (- 36A B  + 1236A )C
+--R                        + 
+--R                               4       2 2       4
+--R                          - 72B  - 576A B  - 120A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            3                        2
+--R                          (- 2184C - 2040A)D  + (- 648B C - 2616A B)D
+--R                        + 
+--R                                    3          2          2        2
+--R                              - 408C  - 2760A C  + (- 504B  - 9096A )C
+--R                            + 
+--R                                     2        3
+--R                              3720A B  - 2904A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2          3       2            3
+--R                          840B C  + 1656A B C  + (- 168B  - 360A B)C + 792A B
+--R                        + 
+--R                                3
+--R                          - 408A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 480D  + 1536B D
+--R                        + 
+--R                               2                  2        2  2
+--R                          (864C  + 4992A C - 2400B  - 1440A )D
+--R                        + 
+--R                                  2                  3        2          4
+--R                          (1056B C  + 576A B C - 768B  + 6624A B)D + 384C
+--R                        + 
+--R                                3          2        2  2
+--R                          864A C  + (- 576B  + 2304A )C
+--R                        + 
+--R                                    2        3         4       2 2       4
+--R                          (- 1152A B  + 2208A )C - 576B  - 576A B  + 384A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                         3                         2
+--R                          (256C + 2688A)D  + (- 2688B C - 4736A B)D
+--R                        + 
+--R                                   3          2         2        2            2
+--R                              1216C  - 4544A C  + (6528B  + 4032A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              1344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                        - 1344B C  + 1728A B C  - 5184A B C + 1536A B  + 192A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  3         2                  2        2  2
+--R                          - 512B D  + (1152C  - 4352A C + 2048B  - 1920A )D
+--R                        + 
+--R                                  2                   2          4         3
+--R                          (1280B C  + 4608A B C - 768A B)D - 640C  + 512A C
+--R                        + 
+--R                                  2       2  2            2        3
+--R                          (- 1920B  - 768A )C  + (- 768A B  - 1536A )C
+--R                        + 
+--R                               2 2       4
+--R                          1152A B  + 384A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   2
+--R                          2048A B D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1024C  + 2048A C  + (- 3072B  + 1024A )C
+--R                            + 
+--R                                       2
+--R                              - 2048A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2         3        2             3
+--R                          1024B C  - 3072A B C  + (2048B  + 3072A B)C - 1024A B
+--R                        + 
+--R                                 3
+--R                          - 1024A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                           4        3         2               2       2  2
+--R                      - 24D  + 56B D  + (- 24C  + 112A C - 40B  - 120A )D
+--R                    + 
+--R                           2               3      2
+--R                      (8B C  - 48A B C + 8B  + 72A B)D
+--R                 *
+--R                       9
+--R                    a b
+--R                + 
+--R                                  3                      2
+--R                      (8C + 336A)D  + (- 216B C - 96A B)D
+--R                    + 
+--R                          3         2        2       2          2      3
+--R                      (56C  - 240A C  + (120B  + 184A )C - 80A B  + 96A )D
+--R                    + 
+--R                            3          2        3      2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            4         3         2               2        2  2
+--R                      - 216D  + 192B D  + (- 72C  - 40A C - 176B  - 1248A )D
+--R                    + 
+--R                             2                3       2         4         3
+--R                      (304B C  + 48A B C + 64B  + 384A B)D - 32C  + 120A C
+--R                    + 
+--R                          2      2  2         2       3       4      2 2      4
+--R                    (- 72B  - 24A )C  + (24A B  - 152A )C + 8B  + 96A B  + 24A
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     3                        2
+--R                      (264C + 2304A)D  + (- 1080B C - 144A B)D
+--R                    + 
+--R                           3          2        2        2           2       3
+--R                      (280C  - 1008A C  + (504B  + 1880A )C - 736A B  + 864A )D
+--R                    + 
+--R                            3          2        3       2            3      3
+--R                    - 120B C  - 96A B C  + (- 8B  - 216A B)C - 144A B  + 16A B
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                            4          3        2                 2        2  2
+--R                      - 144D  - 1848B D  + (576C  - 6600A C + 984B  - 1800A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (1416B C  + 2304A B C + 120B  - 1800A B)D - 192C
+--R                    + 
+--R                            3          2       2  2          2        3
+--R                      648A C  + (- 216B  - 360A )C  + (360A B  - 1128A )C
+--R                    + 
+--R                          4       2 2      4
+--R                      120B  + 576A B  + 72A
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      3                       2
+--R                      (1392C - 3024A)D  + (4752B C + 4464A B)D
+--R                    + 
+--R                                 3          2           2        2           2
+--R                          - 1104C  + 6624A C  + (- 3312B  + 2544A )C - 336A B
+--R                        + 
+--R                              3
+--R                          576A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2        3        2             3
+--R                      - 384B C  - 3024A B C  + (144B  + 2592A B)C - 1008A B
+--R                    + 
+--R                          3
+--R                      240A B
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                          4          3
+--R                      384D  + 1600B D
+--R                    + 
+--R                              2                  2        2  2
+--R                      (- 2784C  + 7040A C - 1280B  + 3936A )D
+--R                    + 
+--R                                2                   3        2          4
+--R                      (- 3776B C  - 8448A B C + 832B  - 1728A B)D + 480C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 2304A C  + (2592B  - 1152A )C  + (1152A B  + 768A )C
+--R                    + 
+--R                          4        2 2       4
+--R                      384B  - 1440A B  - 864A
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                       3                         2
+--R                      (- 1664C + 384A)D  + (- 3456B C - 4224A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          1792C  - 5376A C  + (2688B  - 5632A )C + 3200A B
+--R                        + 
+--R                                 3
+--R                          - 1536A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3            2           3        2             3
+--R                      512B C  + 6144A B C  + (- 2176B  - 2304A B)C + 1152A B
+--R                    + 
+--R                          3
+--R                      768A B
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                2       2  2
+--R                      (2304C  - 512A C + 512B  - 768A )D
+--R                    + 
+--R                              2                    3        2          4
+--R                      (2048B C  + 6144A B C - 1024B  + 3072A B)D - 256C
+--R                    + 
+--R                             3           2        2  2             2       3
+--R                      1536A C  + (- 2304B  + 1536A )C  + (- 1536A B  + 512A )C
+--R                    + 
+--R                            4       2 2       4
+--R                      - 512B  + 768A B  + 768A
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                              3        2           2              2        3
+--R                      (- 1024C  + 1024A C - 2048A B )D - 3072A B C  + 2048B C
+--R                    + 
+--R                             3
+--R                      - 1024A B
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                           2 3 8
+--R                      32A D a c
+--R                    + 
+--R                                 2 2 2         3        2  3
+--R                          - 16A D a b  + (- 16D  - 16B D )a b
+--R                        + 
+--R                                 2                   2      3  4
+--R                          (128A D  - 128A B D - 32A C  + 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              2   4      3       2  2 3
+--R                          2A D a b  + (8D  + 8B D )a b
+--R                        + 
+--R                                        2                  2      3  3 2
+--R                          ((32C - 448A)D  + 64A B D + 16A C  - 16A )a b
+--R                        + 
+--R                                   3        2
+--R                              - 32D  + 32B D
+--R                            + 
+--R                                    2               2       2          2
+--R                              (- 48C  + 224A C + 64B  + 144A )D + 16B C
+--R                            + 
+--R                                           2
+--R                              96A B C - 48A B
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                      2                 3         2      2
+--R                              - 128A D  - 512A B D + 64C  - 128A C  - 64A C
+--R                            + 
+--R                                    2       3
+--R                              128A B  + 128A
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              3      2    5
+--R                          (- D  - B D )a b
+--R                        + 
+--R                                          2                2     3  2 4
+--R                          ((- 16C + 192A)D  - 8A B D - 2A C  + 2A )a b
+--R                        + 
+--R                                  3         2       2               2      2
+--R                              160D  + 128B D  + (24C  - 112A C - 32B  - 72A )D
+--R                            + 
+--R                                    2                2
+--R                              - 8B C  - 48A B C + 24A B
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                           2                             3
+--R                              (80C - 560A)D  + (- 96B C + 1312A B)D - 48C
+--R                            + 
+--R                                    2         2      2           2       3
+--R                              304A C  + (- 48B  - 16A )C - 112A B  - 368A
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              128D  + 256B D
+--R                            + 
+--R                                     2               2       2           2
+--R                              (- 384C  + 512A C + 64B  + 384A )D - 128B C
+--R                            + 
+--R                                   3       2
+--R                              - 64B  - 384A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                       2                  3         2       2
+--R                              - 1024A D  + 512A B D + 256C  + 128A C  - 256A C
+--R                            + 
+--R                                    2       3
+--R                              512A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                     2   6
+--R                          (2C - 22A)D a b
+--R                        + 
+--R                                   3        2        2             2     2
+--R                              - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D
+--R                            + 
+--R                                 2              2
+--R                              B C  + 6A B C - 3A B
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                               2                          3
+--R                              (- 328C + 1896A)D  + (48B C - 528A B)D + 12C
+--R                            + 
+--R                                      2       2      2          2       3
+--R                              - 120A C  + (24B  + 20A )C + 32A B  + 152A
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 224D  - 800B D
+--R                            + 
+--R                                   2                 2        2          2
+--R                              (720C  - 2080A C - 512B  - 1392A )D + 16B C
+--R                            + 
+--R                                              3       2
+--R                              - 672A B C + 64B  + 720A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                             3
+--R                              (160C + 2976A)D  + (576B C + 1088A B)D - 608C
+--R                            + 
+--R                                    2        2       2            2      3
+--R                              416A C  + (288B  + 992A )C - 1120A B  - 32A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              256D  - 256B D
+--R                            + 
+--R                                     2                 2       2           2
+--R                              (- 192C  - 1664A C - 640B  - 960A )D - 448B C
+--R                            + 
+--R                                                3       2
+--R                              - 1152A B C - 128B  - 192A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                      2                   3          2       2
+--R                              - 512A D  + 4096A B D - 256C  + 1024A C  + 256A C
+--R                            + 
+--R                                      2        3
+--R                              - 512A B  - 1024A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             3       2    7
+--R                          (8D  + 8B D )a b
+--R                        + 
+--R                                            2                        3        2
+--R                              (141C - 755A)D  + (- 6B C + 58A B)D - C  + 13A C
+--R                            + 
+--R                                   2     2         2      3
+--R                              (- 3B  - 3A )C - 3A B  - 17A
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    3        2
+--R                              - 284D  - 36B D
+--R                            + 
+--R                                     2                2       2          2
+--R                              (- 276C  + 888A C + 228B  + 588A )D + 12B C
+--R                            + 
+--R                                            3       2
+--R                              312A B C - 20B  - 276A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              2                             3
+--R                              (- 32C - 2016A)D  + (192B C - 3072A B)D + 320C
+--R                            + 
+--R                                      2       2       2           2       3
+--R                              - 720A C  + (96B  - 192A )C + 672A B  + 848A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 896D  - 384B D
+--R                            + 
+--R                                    2                 2       2            2
+--R                              (1344C  + 1408A C + 896B  + 576A )D + 1088B C
+--R                            + 
+--R                                              3        2
+--R                              1920A B C + 384B  + 1344A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                             3
+--R                              (- 640C + 4224A)D  + (768B C - 8448A B)D - 128C
+--R                            + 
+--R                                       2        2       2           2        3
+--R                              - 1920A C  + (384B  + 640A )C - 128A B  + 2432A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3          2
+--R                              - 256D  - 1280B D
+--R                            + 
+--R                                    2                 2        2            2
+--R                              (3072C  - 4096A C - 512B  - 3072A )D + 1024B C
+--R                            + 
+--R                                  3        2
+--R                              512B  + 3072A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                     2                    3         2        2
+--R                              2048A D  + 2048A B D - 2048C  + 512A C  + 2048A C
+--R                            + 
+--R                                       2       3
+--R                              - 4096A B  - 512A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                        2   8
+--R                          (- 16C + 80A)D a b
+--R                        + 
+--R                                  3         2       2               2      2
+--R                              146D  + 118B D  + (30C  - 100A C - 26B  - 66A )D
+--R                            + 
+--R                                    2               3      2
+--R                              - 2B C  - 36A B C + 2B  + 30A B
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                             2                              3
+--R                              (726C - 2090A)D  + (- 180B C + 1100A B)D - 62C
+--R                            + 
+--R                                    2         2      2           2       3
+--R                              230A C  + (- 90B  - 58A )C - 154A B  - 350A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1752D  + 2760B D
+--R                            + 
+--R                                      2                 2        2           2
+--R                              (- 2160C  + 3840A C + 696B  + 2736A )D - 528B C
+--R                            + 
+--R                                             3        2
+--R                              576A B C - 312B  - 2160A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                       2                                3
+--R                              - 8160A D  + (- 4608B C + 5376A B)D + 864C
+--R                            + 
+--R                                    2           2        2           2        3
+--R                              192A C  + (- 2304B  - 3936A )C + 960A B  - 3264A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1152D  + 4224B D
+--R                            + 
+--R                                      2                   2        2
+--R                              (- 5760C  + 11520A C + 2304B  + 8064A )D
+--R                            + 
+--R                                       2                   3        2
+--R                              - 1152B C  + 2304A B C - 768B  - 5760A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D
+--R                            + 
+--R                                 3          2           2        2            2
+--R                            3840C  - 3072A C  + (- 2304B  - 6912A )C + 6912A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 512D  + 512B D
+--R                            + 
+--R                                    2                  2       2            2
+--R                              (3840C  + 2560A C + 2048B  + 768A )D + 2816B C
+--R                            + 
+--R                                               3        2
+--R                              4608A B C + 1024B  + 3840A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                     2                    3          2        2
+--R                              2048A D  - 8192A B D - 1024C  - 2048A C  + 1024A C
+--R                            + 
+--R                                       2        3
+--R                              - 2048A B  + 2048A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                3        2    9
+--R                          (- 16D  - 16B D )a b
+--R                        + 
+--R                                              2                         3
+--R                              (- 308C + 972A)D  + (24B C - 104A B)D + 4C
+--R                            + 
+--R                                     2       2      2          2      3
+--R                              - 20A C  + (12B  + 12A )C + 12A B  + 36A
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 456D  - 920B D
+--R                            + 
+--R                                   2                 2        2           2
+--R                              (744C  - 1712A C - 376B  - 1176A )D + 104B C
+--R                            + 
+--R                                              3       2
+--R                              - 432A B C + 88B  + 744A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                                2                             3
+--R                              (- 1668C + 8316A)D  + (1656B C - 136A B)D - 364C
+--R                            + 
+--R                                    2        2        2           2       3
+--R                              380A C  + (828B  + 1468A )C - 452A B  + 724A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 2496D  - 6432B D
+--R                            + 
+--R                                    2                   2        2           2
+--R                              (5328C  - 14304A C - 3408B  - 9648A )D + 336B C
+--R                            + 
+--R                                                3        2
+--R                              - 4320A B C + 528B  + 5328A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              2                                3
+--R                              (6528C + 3456A)D  + (11520B C + 7296A B)D - 3072C
+--R                            + 
+--R                                   2         2         2            2        3
+--R                            4704A C  + (5760B  + 10752A )C - 4224A B  + 2976A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                   3         2
+--R                              1024D  - 512B D
+--R                            + 
+--R                                      2                  2        2            2
+--R                              (- 5760C  - 3840A C - 3072B  - 1152A )D - 4224B C
+--R                            + 
+--R                                                 3        2
+--R                              - 6912A B C - 1536B  - 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2
+--R                              (1280C - 6912A)D  + (- 1536B C + 12800A B)D
+--R                            + 
+--R                                   3          2          2        2            2
+--R                              1280C  + 2816A C  + (- 768B  - 2304A )C + 2304A B
+--R                            + 
+--R                                     3
+--R                              - 3840A
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                     2           2                  2        2
+--R                              2048B D  + (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                            + 
+--R                                       2        3        2
+--R                              - 2048B C  - 1024B  - 6144A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                                 3          2        2
+--R                              - 8192A B D + 4096C  - 2048A C  - 4096A C
+--R                            + 
+--R                                     2        3
+--R                              8192A B  + 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                  2   10
+--R                      (32C - 96A)D a b
+--R                    + 
+--R                             3        2         2               2       2
+--R                          24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D
+--R                        + 
+--R                                2               3      2
+--R                          - 8B C  + 48A B C - 8B  - 72A B
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                         2                             3
+--R                          (376C - 1416A)D  + (- 144B C - 144A B)D + 40C
+--R                        + 
+--R                                 2         2       2          2      3
+--R                          - 72A C  + (- 72B  - 136A )C + 56A B  - 24A
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              3          2
+--R                          360D  + 1080B D
+--R                        + 
+--R                                 2                 2        2          2
+--R                          (- 936C  + 2608A C + 632B  + 1752A )D - 40B C
+--R                        + 
+--R                                        3       2
+--R                          816A B C - 88B  - 936A B
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                          2                                3
+--R                          (- 24C - 4248A)D  + (- 2160B C - 2160A B)D + 536C
+--R                        + 
+--R                                   2           2        2           2       3
+--R                          - 1080A C  + (- 1080B  - 1976A )C + 712A B  - 360A
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1152D  + 3456B D
+--R                        + 
+--R                                  2                  2        2           2
+--R                          (- 1296C  + 7968A C + 2400B  + 5040A )D + 816B C
+--R                        + 
+--R                                         3        2
+--R                          3744A B C + 96B  - 1296A B
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            2                                3
+--R                          (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D + 960C
+--R                        + 
+--R                                   2           2        2           2        3
+--R                          - 3456A C  + (- 3456B  - 5568A )C + 768A B  - 1152A
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1536D  - 4608B D
+--R                        + 
+--R                                 2                   2        2            2
+--R                          (11520C  - 12800A C - 1024B  - 9984A )D + 4352B C
+--R                        + 
+--R                                           3         2
+--R                          1536A B C + 2048B  + 11520A B
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                          2                               3
+--R                          (6656C - 1536A)D  + (9216B C + 9216A B)D - 5632C
+--R                        + 
+--R                                 2         2         2            2        3
+--R                          4608A C  + (4608B  + 11776A )C - 9728A B  + 1536A
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                  2        2            2
+--R                          (- 9216C  + 2048A C - 2048B  + 3072A )D - 5120B C
+--R                        + 
+--R                                             3        2
+--R                          - 6144A B C - 2048B  - 9216A B
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                            3        2           2  11
+--R                      (4096C  - 4096A C + 8192A B )a
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                             3 2 8
+--R                      - 32A D a c
+--R                    + 
+--R                               3   2       4        3  2
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   3           2         2      3    3
+--R                          (- 128A D  + 128A B D  + (32A C  - 32A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                3 4        4       3    3
+--R                          - 2A D b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          3          2           2      3    2 2
+--R                          ((- 32C + 448A)D  - 64A B D  + (- 16A C  + 16A )D)a b
+--R                        + 
+--R                                 4        3       2               2       2  2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                      2                2
+--R                              (- 16B C  - 96A B C + 48A B)D
+--R                         *
+--R                             3
+--R                            a b
+--R                        + 
+--R                                    3           2
+--R                              128A D  + 512A B D
+--R                            + 
+--R                                    3         2      2          2       3
+--R                              (- 64C  + 128A C  + 64A C - 128A B  - 128A )D
+--R                         *
+--R                             4
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            4      3  5
+--R                          (D  + B D )b
+--R                        + 
+--R                                        3         2        2     3      4
+--R                          ((16C - 192A)D  + 8A B D  + (2A C  - 2A )D)a b
+--R                        + 
+--R                                    4         3
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 24C  + 112A C + 32B  + 72A )D
+--R                            + 
+--R                                   2                2
+--R                              (8B C  + 48A B C - 24A B)D
+--R                         *
+--R                             2 3
+--R                            a b
+--R                        + 
+--R                                             3                     2
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D
+--R                            + 
+--R                                3         2       2      2           2       3
+--R                            (48C  - 304A C  + (48B  + 16A )C + 112A B  + 368A )D
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2  2
+--R                              (384C  - 512A C - 64B  - 384A )D
+--R                            + 
+--R                                     2      3       2
+--R                              (128B C  + 64B  + 384A B)D
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                     3           2
+--R                              1024A D  - 512A B D
+--R                            + 
+--R                                     3         2       2          2       3
+--R                              (- 256C  - 128A C  + 256A C - 512A B  + 128A )D
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       3 6
+--R                          (- 2C + 22A)D b
+--R                        + 
+--R                                 4        3      2             2     2  2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D
+--R                            + 
+--R                                    2              2
+--R                              (- B C  - 6A B C + 3A B)D
+--R                         *
+--R                               5
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D
+--R                            + 
+--R                                       3         2         2      2          2
+--R                                  - 12C  + 120A C  + (- 24B  - 20A )C - 32A B
+--R                                + 
+--R                                        3
+--R                                  - 152A
+--R                             *
+--R                                D
+--R                         *
+--R                             2 4
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D
+--R                            + 
+--R                                      2                 3       2
+--R                              (- 16B C  + 672A B C - 64B  - 720A B)D
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                               3                        2
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D
+--R                            + 
+--R                                      3         2          2       2
+--R                                  608C  - 416A C  + (- 288B  - 992A )C
+--R                                + 
+--R                                         2      3
+--R                                  1120A B  + 32A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2  2
+--R                              (192C  + 1664A C + 640B  + 960A )D
+--R                            + 
+--R                                     2                   3       2
+--R                              (448B C  + 1152A B C + 128B  + 192A B)D
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    3            2
+--R                              512A D  - 4096A B D
+--R                            + 
+--R                                   3          2       2          2        3
+--R                              (256C  - 1024A C  - 256A C + 512A B  + 1024A )D
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               4       3  7
+--R                          (- 8D  - 8B D )b
+--R                        + 
+--R                                              3                  2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D
+--R                            + 
+--R                                3        2      2     2         2      3
+--R                              (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                         *
+--R                               6
+--R                            a b
+--R                        + 
+--R                                  4        3
+--R                              284D  + 36B D
+--R                            + 
+--R                                   2                2       2  2
+--R                              (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                      2                 3       2
+--R                              (- 12B C  - 312A B C + 20B  + 276A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                            3                        2
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D
+--R                            + 
+--R                                        3         2         2       2
+--R                                  - 320C  + 720A C  + (- 96B  + 192A )C
+--R                                + 
+--R                                          2       3
+--R                                  - 672A B  - 848A
+--R                             *
+--R                                D
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2  2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 1088B C  - 1920A B C - 384B  - 1344A B)D
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D
+--R                            + 
+--R                                      3          2          2       2
+--R                                  128C  + 1920A C  + (- 384B  - 640A )C
+--R                                + 
+--R                                        2        3
+--R                                  128A B  - 2432A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2  2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D
+--R                            + 
+--R                                        2       3        2
+--R                              (- 1024B C  - 512B  - 3072A B)D
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                       3            2
+--R                              - 2048A D  - 2048A B D
+--R                            + 
+--R                                    3         2        2           2       3
+--R                              (2048C  - 512A C  - 2048A C + 4096A B  + 512A )D
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      3 8
+--R                          (16C - 80A)D b
+--R                        + 
+--R                                    4         3
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 30C  + 100A C + 26B  + 66A )D
+--R                            + 
+--R                                   2               3      2
+--R                              (2B C  + 36A B C - 2B  - 30A B)D
+--R                         *
+--R                               7
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D
+--R                            + 
+--R                                3         2       2      2           2       3
+--R                            (62C  - 230A C  + (90B  + 58A )C + 154A B  + 350A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                     4          3
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2  2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D
+--R                            + 
+--R                                     2                  3        2
+--R                              (528B C  - 576A B C + 312B  + 2160A B)D
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                     3                       2
+--R                              8160A D  + (4608B C - 5376A B)D
+--R                            + 
+--R                                        3         2         2        2
+--R                                  - 864C  - 192A C  + (2304B  + 3936A )C
+--R                                + 
+--R                                          2        3
+--R                                  - 960A B  + 3264A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                     4          3
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2  2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D
+--R                            + 
+--R                                      2                   3        2
+--R                              (1152B C  - 2304A B C + 768B  + 5760A B)D
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                              3                       2
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D
+--R                            + 
+--R                                         3          2         2        2
+--R                                  - 3840C  + 3072A C  + (2304B  + 6912A )C
+--R                                + 
+--R                                           2
+--R                                  - 6912A B
+--R                             *
+--R                                D
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2  2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D
+--R                            + 
+--R                                        2                    3        2
+--R                              (- 2816B C  - 4608A B C - 1024B  - 3840A B)D
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                       3            2
+--R                              - 2048A D  + 8192A B D
+--R                            + 
+--R                                  3          2        2           2        3
+--R                            (1024C  + 2048A C  - 1024A C + 2048A B  - 2048A )D
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              4        3  9
+--R                          (16D  + 16B D )b
+--R                        + 
+--R                                            3                      2
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D
+--R                            + 
+--R                                 3        2         2      2          2      3
+--R                            (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                         *
+--R                               8
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D
+--R                            + 
+--R                                       2                 3       2
+--R                              (- 104B C  + 432A B C - 88B  - 744A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                              3                        2
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D
+--R                            + 
+--R                                      3         2          2        2
+--R                                  364C  - 380A C  + (- 828B  - 1468A )C
+--R                                + 
+--R                                        2       3
+--R                                  452A B  - 724A
+--R                             *
+--R                                D
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2  2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D
+--R                            + 
+--R                                       2                   3        2
+--R                              (- 336B C  + 4320A B C - 528B  - 5328A B)D
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                                3                          2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                       3          2           2         2
+--R                                  3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                                + 
+--R                                         2        3
+--R                                  4224A B  - 2976A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                     4         3
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2  2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D
+--R                            + 
+--R                                      2                    3        2
+--R                              (4224B C  + 6912A B C + 1536B  + 5760A B)D
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                3                        2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                         3          2        2        2
+--R                                  - 1280C  - 2816A C  + (768B  + 2304A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 2304A B  + 3840A
+--R                             *
+--R                                D
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                       3
+--R                              - 2048B D
+--R                            + 
+--R                                    2                  2        2  2
+--R                              (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                      2        3        2
+--R                              (2048B C  + 1024B  + 6144A B)D
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2
+--R                              8192A B D
+--R                            + 
+--R                                    3          2        2           2        3
+--R                            (- 4096C  + 2048A C  + 4096A C - 8192A B  - 2048A )D
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    3 10
+--R                      (- 32C + 96A)D b
+--R                    + 
+--R                               4        3       2               2       2  2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                               2               3      2
+--R                          (8B C  - 48A B C + 8B  + 72A B)D
+--R                     *
+--R                           9
+--R                        a b
+--R                    + 
+--R                                           3                     2
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D
+--R                        + 
+--R                                3        2       2       2          2      3
+--R                          (- 40C  + 72A C  + (72B  + 136A )C - 56A B  + 24A )D
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (936C  - 2608A C - 632B  - 1752A )D
+--R                        + 
+--R                                2                 3       2
+--R                          (40B C  - 816A B C + 88B  + 936A B)D
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                        3                       2
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D
+--R                        + 
+--R                                    3          2         2        2           2
+--R                              - 536C  + 1080A C  + (1080B  + 1976A )C - 712A B
+--R                            + 
+--R                                  3
+--R                              360A
+--R                         *
+--R                            D
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2  2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D
+--R                        + 
+--R                                   2                  3        2
+--R                          (- 816B C  - 3744A B C - 96B  + 1296A B)D
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D
+--R                        + 
+--R                                    3          2         2        2           2
+--R                              - 960C  + 3456A C  + (3456B  + 5568A )C - 768A B
+--R                            + 
+--R                                   3
+--R                              1152A
+--R                         *
+--R                            D
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                               4          3
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2  2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D
+--R                        + 
+--R                                    2                    3         2
+--R                          (- 4352B C  - 1536A B C - 2048B  - 11520A B)D
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D
+--R                        + 
+--R                                   3          2           2         2
+--R                              5632C  - 4608A C  + (- 4608B  - 11776A )C
+--R                            + 
+--R                                     2        3
+--R                              9728A B  - 1536A
+--R                         *
+--R                            D
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                2                  2        2  2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D
+--R                        + 
+--R                                  2                    3        2
+--R                          (5120B C  + 6144A B C + 2048B  + 9216A B)D
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                              3        2           2    10
+--R                      (- 4096C  + 4096A C - 8192A B )D a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                      4   8
+--R                  8A D a c
+--R                + 
+--R                            4 2          4         3
+--R                      - 2A D b  + (- 4B D  - 8A C D )a b
+--R                    + 
+--R                                    4          3     3 2  2
+--R                      ((- 8C + 32A)D  - 32A B D  + 8A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                          4         3  3
+--R                      (B D  + 2A C D )b
+--R                    + 
+--R                                   4                  3     3 2    2
+--R                      ((6C - 100A)D  + (4B C + 16A B)D  - 2A D )a b
+--R                    + 
+--R                             5        4      2              2      2  3
+--R                          12D  - 12B D  + (8C  + 16A C + 16B  + 52A )D
+--R                        + 
+--R                                        2   2        3     3
+--R                          (24A B C - 12A B)D  + (8A C  - 8A C)D
+--R                     *
+--R                         2
+--R                        a b
+--R                    + 
+--R                                        4                    3
+--R                          (- 32C - 24A)D  + (48B C - 128A B)D
+--R                        + 
+--R                                2         2      3  2       4     3 2
+--R                          (- 48A C + 24A B  + 32A )D  - 8A C  + 8A C
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                   4                  3  4
+--R                      ((- C + 22A)D  + (- B C - 2A B)D )b
+--R                    + 
+--R                              5        4        2             2      2  3
+--R                          - 7D  + 45B D  + (- 6C  + 80A C - 8B  - 25A )D
+--R                        + 
+--R                                        2   2          3     3
+--R                          (- 6A B C + 3A B)D  + (- 2A C  + 2A C)D
+--R                     *
+--R                           3
+--R                        a b
+--R                    + 
+--R                                       4                      3
+--R                          (88C - 118A)D  + (- 52B C + 312A B)D
+--R                        + 
+--R                                  2         2      2          2      3  2
+--R                          (- 60A C  + (- 12B  + 12A )C - 18A B  - 80A )D
+--R                        + 
+--R                                 3          2      2            4     3 2
+--R                          (- 4B C  - 24A B C  + 12A B C)D + 2A C  - 2A C
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                             5        4         2              2       2  3
+--R                          36D  - 52B D  + (- 32C  + 48A C + 44B  + 176A )D
+--R                        + 
+--R                                  2                3      2   2
+--R                          (- 48B C  + 48A B C - 12B  - 96A B)D
+--R                        + 
+--R                               4        3      2 2      3       4         4
+--R                          (- 8C  + 64A C  - 12A C  - 40A C + 12A )D + 4B C
+--R                        + 
+--R                                 3      2   2
+--R                          24A B C  - 12A B C
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                  4                    3
+--R                          - 224A D  + (192B C + 96A B)D
+--R                        + 
+--R                                2         2       2          2     3  2
+--R                          (72A C  + (- 96B  - 192A )C + 96A B  - 8A )D
+--R                        + 
+--R                                3      2           3       5        4      2 3
+--R                          (16B C  + 48A B C + 32A B )D + 8C  - 32A C  + 16A C
+--R                        + 
+--R                                  2      3  2      4      3 2
+--R                          (- 24A B  + 32A )C  - 24A C - 8A B
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        5        4     2            2     2  3  5
+--R                      (D  - 10B D  + (C  - 20A C + B  + 3A )D )b
+--R                    + 
+--R                                         4                      3
+--R                          (- 53C + 389A)D  + (- 24B C - 134A B)D
+--R                        + 
+--R                                2     2        2      3  2
+--R                          (15A C  + 3B C + 3A B  + 17A )D
+--R                        + 
+--R                              3         2     2
+--R                          (B C  + 6A B C  - 3A B C)D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                                5        4         2                2       2  3
+--R                          - 127D  + 63B D  + (- 48C  - 240A C - 147B  - 534A )D
+--R                        + 
+--R                                2                 3       2   2
+--R                          (60B C  - 144A B C + 11B  + 150A B)D
+--R                        + 
+--R                                4        3       2      2  2         2      3
+--R                              6C  - 72A C  + (12B  + 15A )C  + (12A B  + 82A )C
+--R                            + 
+--R                                  4
+--R                              - 3A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4         3     2   2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (164C + 696A)D  + (- 448B C + 184A B)D
+--R                        + 
+--R                              3         2        2       2           2      3  2
+--R                          (96C  - 138A C  + (132B  + 636A )C - 192A B  - 10A )D
+--R                        + 
+--R                                 3          2      2           3      3        5
+--R                          (- 4B C  - 96A B C  + 60A B C - 32A B  - 24A B)D - 6C
+--R                        + 
+--R                               4         2      2  3          2      3  2     4
+--R                          64A C  + (- 12B  - 16A )C  + (- 6A B  - 80A )C  + 6A C
+--R                        + 
+--R                            3 2
+--R                          2A B
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5         4          2               2       2  3
+--R                          - 24D  - 120B D  + (- 116C  - 472A C + 56B  - 196A )D
+--R                        + 
+--R                                  2                3       2   2
+--R                          (- 12B C  + 24A B C - 24B  - 156A B)D
+--R                        + 
+--R                                   4        3         2       2  2
+--R                              - 92C  + 64A C  + (- 12B  - 144A )C
+--R                            + 
+--R                                      2      3        4       2 2      4
+--R                              (- 72A B  - 48A )C - 16B  - 108A B  + 60A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4          3       3      2   2
+--R                          - 20B C  + 80A B C  + (12B  - 48A B)C
+--R                        + 
+--R                                3      3         2 3      4
+--R                          (40A B  + 64A B)C + 12A B  + 20A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        4           3
+--R                          (128C - 128A)D  + 896A B D
+--R                        + 
+--R                                   3         2          2      2          2
+--R                              - 48C  + 288A C  + (- 384B  + 48A )C - 96A B
+--R                            + 
+--R                                    3
+--R                              - 160A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3          2       3       2            3
+--R                              64B C  - 96A B C  + (64B  + 192A B)C + 128A B
+--R                            + 
+--R                                   3
+--R                              - 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4       2      2  3        2 2
+--R                          32C  - 16A C  + (16B  + 64A )C  - 96A B C
+--R                        + 
+--R                              2 2      4          4      3 2      5
+--R                          (48A B  - 96A )C - 32A B  - 32A B  + 16A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                  4                  3  6
+--R                      ((8C - 80A)D  + (8B C + 16A B)D )b
+--R                    + 
+--R                             5         4       2               2       2  3
+--R                          62D  - 158B D  + (47C  - 239A C + 66B  + 218A )D
+--R                        + 
+--R                                  2               3      2   2
+--R                          (- 12B C  + 30A B C - 2B  - 30A B)D
+--R                        + 
+--R                            4        3        2     2  2          2      3
+--R                        (- C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 229C - 559A)D  + (438B C - 584A B)D
+--R                        + 
+--R                                3         2      2       2          2       3  2
+--R                          (- 64C  + 444A C  + (3B  - 213A )C + 93A B  + 175A )D
+--R                        + 
+--R                                   3           2        3       2          3
+--R                              10B C  + 180A B C  + (- 8B  - 144A B)C + 6A B
+--R                            + 
+--R                                3
+--R                              6A B
+--R                         *
+--R                            D
+--R                        + 
+--R                           5        4      2     2  3        2      3  2
+--R                          C  - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               5         4        2                2       2  3
+--R                          - 36D  + 340B D  + (237C  + 638A C - 116B  - 123A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (123B C  - 102A B C + 68B  + 363A B)D
+--R                        + 
+--R                                 4         3      2       2  2
+--R                              95C  - 312A C  + (3B  + 138A )C
+--R                            + 
+--R                                    2       3        4      2 2       4
+--R                              (66A B  + 120A )C + 16B  + 99A B  - 105A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3      3       2   2
+--R                          - 5B C  - 176A B C  + (5B  + 138A B)C
+--R                        + 
+--R                                  3      3        2 3     4
+--R                          (- 10A B  - 16A B)C - 3A B  - 5A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          4                        3
+--R                          (- 276C + 916A)D  + (- 416B C - 2048A B)D
+--R                        + 
+--R                                    3         2         2       2          2
+--R                                252C  - 636A C  + (1032B  + 516A )C + 72A B
+--R                              + 
+--R                                    3
+--R                                380A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                3           2       2            3      3
+--R                          (40B C  + 216A B C  - 168A B C - 256A B  + 40A B)D
+--R                        + 
+--R                               5        4        2       2  3
+--R                          - 56C  + 80A C  + (- 4B  - 128A )C
+--R                        + 
+--R                                 2      3  2         4       2 2       4
+--R                          (132A B  - 64A )C  + (- 20B  - 156A B  + 184A )C
+--R                        + 
+--R                              4      3 2      5
+--R                          4A B  + 28A B  - 16A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                5         4        2               2        2  3
+--R                          - 144D  + 176B D  + (368C  - 736A C + 64B  - 1040A )D
+--R                        + 
+--R                                 2                  2   2
+--R                          (528B C  + 480A B C + 528A B)D
+--R                        + 
+--R                                    4        3          2      2  2
+--R                              - 128C  - 64A C  + (- 240B  - 96A )C
+--R                            + 
+--R                                       2       3        4       2 2      4
+--R                              (- 288A B  + 128A )C - 48B  - 240A B  + 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4         3      2   2          3      3
+--R                          - 96B C  + (- 16B  - 96A B)C  + (160A B  + 64A B)C
+--R                        + 
+--R                             5       2 3
+--R                          16B  + 112A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (128C + 384A)D  + (- 768B C + 512A B)D
+--R                        + 
+--R                                 3       2          2       3  2
+--R                          (- 192C  + 960A C - 768A B  - 128A )D
+--R                        + 
+--R                                     2       3        3           4      2 3
+--R                          (- 384A B C  + 256B C - 128A B)D + 64A C  + 64B C
+--R                        + 
+--R                                3 2       2 2          4      5
+--R                          - 128A C  + 192A B C - 128A B  + 64A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           5        4        2             2      2  3  7
+--R                      (- 8D  + 32B D  + (- 8C  + 64A C - 8B  - 24A )D )b
+--R                    + 
+--R                                        4                     3
+--R                          (118C - 412A)D  + (- 2B C + 264A B)D
+--R                        + 
+--R                              3        2        2      2          2      3  2
+--R                          (10C  - 96A C  + (- 6B  + 18A )C - 12A B  - 36A )D
+--R                        + 
+--R                                 3          2      3      2
+--R                          (- 2B C  - 36A B C  + (2B  + 30A B)C)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                              5        4       2                2        2  3
+--R                          287D  - 30B D  + (28C  + 682A C + 308B  + 1180A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 240B C  + 168A B C - 50B  - 414A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 35C  + 170A C  + (- 54B  - 78A )C
+--R                            + 
+--R                                      2       3       4      2 2      4
+--R                              (- 66A B  - 198A )C - 3B  - 18A B  + 21A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4          3        3      2   2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                          4                      3
+--R                          (- 81C - 1825A)D  + (528B C + 1756A B)D
+--R                        + 
+--R                                    3        2          2        2           2
+--R                              - 572C  + 60A C  + (- 936B  - 2010A )C + 108A B
+--R                            + 
+--R                                    3
+--R                              - 658A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2
+--R                              - 92B C  + 120A B C  + (- 20B  - 264A B)C
+--R                            + 
+--R                                    3       3
+--R                              160A B  + 100A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5         4       2      2  3         2       3  2
+--R                          29C  - 119A C  + (54B  + 80A )C  + (30A B  + 188A )C
+--R                        + 
+--R                             4      2 2      4        4     3 2     5
+--R                          (5B  + 36A B  - 37A )C + A B  - 4A B  + 3A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          412D  - 132B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 466C  + 2484A C - 248B  + 2718A )D
+--R                        + 
+--R                                    2                  3       2   2
+--R                          (- 1374B C  - 996A B C - 120B  - 702A B)D
+--R                        + 
+--R                                  4         3       2       2  2
+--R                              366C  + 192A C  + (18B  + 492A )C
+--R                            + 
+--R                                     2       3         4       2 2       4
+--R                              (396A B  - 208A )C + 108B  + 690A B  - 170A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3         3       2   2
+--R                          190B C  - 96A B C  + (- 34B  + 204A B)C
+--R                        + 
+--R                                   3       3        5      2 3      4
+--R                          (- 220A B  - 304A B)C - 4B  - 82A B  - 90A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                           4                      3
+--R                          (- 936C - 1176A)D  + (768B C - 1536A B)D
+--R                        + 
+--R                                   3         2        2        2            2
+--R                              - 24C  - 696A C  + (240B  - 3144A )C + 1392A B
+--R                            + 
+--R                                    3
+--R                              - 200A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2          3       2
+--R                              144B C  + 1296A B C  + (- 320B  - 336A B)C
+--R                            + 
+--R                                     3       3
+--R                              - 64A B  + 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4      2      2  3          2       3  2
+--R                          - 16C  - 80A C  + (8B  - 32A )C  + (168A B  + 320A )C
+--R                        + 
+--R                                4       2 2       4           4     3 2       5
+--R                          (- 40B  - 552A B  + 176A )C + 168A B  - 8A B  - 112A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               5         4        2                 2       2  3
+--R                          - 96D  + 672B D  + (768C  + 1536A C - 384B  - 192A )D
+--R                        + 
+--R                                 2                   2   2
+--R                          (384B C  + 384A B C + 1344A B)D
+--R                        + 
+--R                                  4          2       2  2       3       4
+--R                              352C  + (- 384B  + 768A )C  + 384A C + 32B
+--R                            + 
+--R                                  2 2       4
+--R                              384A B  - 224A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3 2       3         5
+--R                          32B C  - 256A B C  - 128B C  - 384A B C + 32B
+--R                        + 
+--R                              2 3       4
+--R                          128A B  - 160A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                4                        3
+--R                          384A D  + (- 768B C - 1536A B)D
+--R                        + 
+--R                                    2         2       2           2       3  2
+--R                          (- 1152A C  + (1536B  + 768A )C - 384A B  + 128A )D
+--R                        + 
+--R                                   3       2            3         5         4
+--R                          (- 256B C  - 768A B C - 512A B )D - 128C  + 128A C
+--R                        + 
+--R                                2 3          2       3  2       4        3 2
+--R                          - 256A C  + (384A B  - 128A )C  + 384A C + 128A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                     4                     3  8
+--R                      ((- 16C + 96A)D  + (- 16B C - 32A B)D )b
+--R                    + 
+--R                                5         4
+--R                          - 136D  + 168B D
+--R                        + 
+--R                                2                2       2  3
+--R                          (- 92C  + 188A C - 136B  - 472A )D
+--R                        + 
+--R                                2               3      2   2
+--R                          (48B C  - 24A B C + 8B  + 72A B)D
+--R                        + 
+--R                             4        3       2      2  2         2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (12C + 1996A)D  + (- 864B C - 640A B)D
+--R                        + 
+--R                               3         2        2       2          2      3  2
+--R                          (296C  - 720A C  + (252B  + 732A )C - 36A B  + 84A )D
+--R                        + 
+--R                                   3           2       3       2           3
+--R                              48B C  - 288A B C  + (40B  + 408A B)C - 24A B
+--R                            + 
+--R                                   3
+--R                              - 24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4         2      2  3           2      3  2
+--R                        - 4C  + 20A C  + (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 636D  - 544B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (104C  - 3740A C - 120B  - 3228A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (1380B C  + 912A B C + 96B  + 804A B)D
+--R                        + 
+--R                                    4         3        2       2  2
+--R                              - 188C  + 300A C  + (192B  - 156A )C
+--R                            + 
+--R                                       2       3        4       2 2       4
+--R                              (- 108A B  + 340A )C - 76B  - 468A B  + 216A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3         3       2   2
+--R                          - 68B C  + 272A B C  + (- 28B  - 384A B)C
+--R                        + 
+--R                                3      3         2 3      4
+--R                          (40A B  + 64A B)C + 12A B  + 20A B
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          4                      3
+--R                          (1528C + 1376A)D  + (520B C + 1200A B)D
+--R                        + 
+--R                                  3          2          2        2            2
+--R                              544C  + 1968A C  + (- 132B  + 4740A )C - 1068A B
+--R                            + 
+--R                                   3
+--R                              1012A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2       3       2           3
+--R                              - 360B C  - 1584A B C  + (16B  + 480A B)C + 56A B
+--R                            + 
+--R                                    3
+--R                              - 600A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4          2      2  3
+--R                          8C  + 64A C  + (- 188B  + 28A )C
+--R                        + 
+--R                                   2       3  2        4       2 2       4
+--R                          (- 252A B  - 412A )C  + (100B  + 768A B  - 308A )C
+--R                        + 
+--R                                 4      3 2      5
+--R                          - 12A B  + 64A B  + 76A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          304D  - 944B D
+--R                        + 
+--R                                 2                  2       2  3
+--R                          (- 708C  - 3096A C + 1072B  + 268A )D
+--R                        + 
+--R                                 2                  3        2   2
+--R                          (132B C  - 360A B C + 208B  - 2028A B)D
+--R                        + 
+--R                                    4         3        2        2  2
+--R                              - 636C  - 448A C  + (996B  - 1512A )C
+--R                            + 
+--R                                    2       3        4       2 2       4
+--R                              (24A B  - 576A )C - 80B  - 924A B  + 356A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3        3      2   2
+--R                          - 108B C  + 256A B C  + (252B  + 24A B)C
+--R                        + 
+--R                                   3       3         5       2 3       4
+--R                          (- 120A B  + 768A B)C - 80B  - 356A B  + 340A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                          4                       3
+--R                          (- 48C - 1776A)D  + (1728B C + 3456A B)D
+--R                        + 
+--R                                 3          2           2        2         3  2
+--R                          (- 816C  + 2928A C  + (- 3168B  - 1680A )C - 432A )D
+--R                        + 
+--R                                      3          2          3      2
+--R                              - 224B C  - 96A B C  + (- 256B  + 96A B)C
+--R                            + 
+--R                                    3      3
+--R                              768A B  - 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4         2       2  3
+--R                          160C  - 160A C  + (- 48B  + 384A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 336A B  + 160A )C  + (80B  + 432A B  - 544A )C
+--R                        + 
+--R                                4      3 2
+--R                          112A B  - 48A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4          2                 2        2  3
+--R                          384B D  + (- 960C  + 2688A C - 960B  + 1344A )D
+--R                        + 
+--R                                    2                   3       2   2
+--R                          (- 1344B C  - 2688A B C + 192B  - 576A B)D
+--R                        + 
+--R                                  4         3        2       2  2
+--R                              640C  - 768A C  + (960B  + 576A )C
+--R                            + 
+--R                                      2       3         4       2 2       4
+--R                              (1152A B  + 128A )C + 192B  + 960A B  - 320A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3       3       2   2
+--R                          320B C  - 384A B C  + (64B  + 576A B)C
+--R                        + 
+--R                                   3       3         5       2 3
+--R                          (- 640A B  - 256A B)C - 64B  - 448A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                     3
+--R                          - 1536A B D
+--R                        + 
+--R                                  3          2         2       2            2
+--R                              768C  - 1152A C  + (1536B  - 768A )C + 1536A B
+--R                            + 
+--R                                  3
+--R                              128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2           3       2
+--R                              - 256B C  + 1536A B C  + (- 1024B  - 768A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 512A B  + 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4          2       2  3         2 2
+--R                          - 128C  + 256A C  + (- 256B  - 256A )C  + 384A B C
+--R                        + 
+--R                                 2 2       4           4       3 2       5
+--R                          (- 768A B  + 384A )C + 512A B  + 128A B  - 256A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                      5        4       2              2      2  3  9
+--R                  (16D  - 32B D  + (16C  - 64A C + 16B  + 48A )D )b
+--R                + 
+--R                                    4                    3
+--R                      (- 8C - 224A)D  + (136B C + 64A B)D
+--R                    + 
+--R                            3         2         2      2    2
+--R                      (- 40C  + 144A C  + (- 24B  - 72A )C)D
+--R                    + 
+--R                             3          2        3      2
+--R                      (- 8B C  + 48A B C  + (- 8B  - 72A B)C)D
+--R                 *
+--R                       8
+--R                    a b
+--R                + 
+--R                          5        4       2               2       2  3
+--R                      148D  - 88B D  + (64C  + 104A C + 64B  + 592A )D
+--R                    + 
+--R                               2                3      2   2
+--R                      (- 192B C  - 192A B C - 8B  - 72A B)D
+--R                    + 
+--R                             4        3         2      2  2         2      3
+--R                          28C  - 88A C  + (- 24B  + 24A )C  + (24A B  - 24A )C
+--R                        + 
+--R                             4      2 2      4
+--R                          12B  + 72A B  - 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                          4          3      3      2   2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     2 7
+--R                    a b
+--R                + 
+--R                                       4                     3
+--R                      (- 212C - 1532A)D  + (664B C + 112A B)D
+--R                    + 
+--R                             3         2       2       2           2      3  2
+--R                      (- 232C  + 528A C  + (24B  - 864A )C + 144A B  - 88A )D
+--R                    + 
+--R                                 3           2         3       2           3
+--R                            40B C  + 528A B C  + (- 40B  - 456A B)C - 32A B
+--R                          + 
+--R                               3
+--R                            80A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          5        4       2      2  3         2      3  2
+--R                      - 4C  + 12A C  + (24B  - 16A )C  + (24A B  + 32A )C
+--R                    + 
+--R                            4       2 2      4         4      3 2      5
+--R                      (- 20B  - 144A B  + 52A )C - 4A B  - 16A B  - 12A
+--R                 *
+--R                     3 6
+--R                    a b
+--R                + 
+--R                          5          4          2                 2        2  3
+--R                      124D  + 1208B D  + (- 248C  + 4328A C - 416B  + 1336A )D
+--R                    + 
+--R                                2                  3       2   2
+--R                      (- 1176B C  - 912A B C - 104B  - 240A B)D
+--R                    + 
+--R                              4         3          2       2  2
+--R                          188C  - 424A C  + (- 384B  + 264A )C
+--R                        + 
+--R                                2       3        4       2 2       4
+--R                          (24A B  - 136A )C + 68B  + 480A B  - 244A
+--R                     *
+--R                        D
+--R                    + 
+--R                           4           3       3       2   2         3      3
+--R                      32B C  - 304A B C  + (16B  + 408A B)C  + (80A B  - 64A B)C
+--R                    + 
+--R                         5      2 3      4
+--R                      16B  + 88A B  - 40A B
+--R                 *
+--R                     4 5
+--R                    a b
+--R                + 
+--R                                        4                         3
+--R                      (- 1028C + 2044A)D  + (- 3104B C - 2864A B)D
+--R                    + 
+--R                                3          2         2        2           2
+--R                            560C  - 4512A C  + (1536B  - 1848A )C + 816A B
+--R                          + 
+--R                                  3
+--R                            - 616A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3           2        3       2            3
+--R                          736B C  + 768A B C  + (304B  + 912A B)C - 224A B
+--R                        + 
+--R                              3
+--R                          496A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5        4        2       2  3          2       3  2
+--R                      - 28C  + 52A C  + (200B  - 112A )C  + (168A B  + 224A )C
+--R                    + 
+--R                             4       2 2       4          4       3 2      5
+--R                      (- 140B  - 912A B  + 364A )C - 92A B  - 112A B  - 52A
+--R                 *
+--R                     5 4
+--R                    a b
+--R                + 
+--R                            5          4         2                 2        2  3
+--R                      - 288D  - 1088B D  + (1896C  - 4752A C + 720B  - 2552A )D
+--R                    + 
+--R                              2                   3        2   2
+--R                      (2712B C  + 4560A B C - 272B  + 2424A B)D
+--R                    + 
+--R                                4          3           2       2  2
+--R                          - 280C  + 2048A C  + (- 1320B  + 480A )C
+--R                        + 
+--R                                    2       3         4       2 2       4
+--R                          (- 1200A B  + 416A )C - 208B  - 744A B  + 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3        2   2
+--R                      - 232B C  + 608A B C  + (- 344B  - 1248A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (560A B  - 448A B)C + 112B  + 616A B  - 280A B
+--R                 *
+--R                     6 3
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (1248C - 288A)D  + (2304B C + 2688A B)D
+--R                    + 
+--R                                 3          2           2        2            2
+--R                          - 1056C  + 3840A C  + (- 1536B  + 3552A )C - 2496A B
+--R                        + 
+--R                              3
+--R                          704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3            2        3       2            3
+--R                          - 768B C  - 2880A B C  + (768B  - 384A B)C + 256A B
+--R                        + 
+--R                                 3
+--R                          - 1088A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5         4       2       2  3            2       3  2
+--R                      32C  - 320A C  + (32B  + 128A )C  + (- 192A B  - 256A )C
+--R                    + 
+--R                           4        2 2       4           4       3 2       5
+--R                      (160B  + 1824A B  - 416A )C - 416A B  + 128A B  + 320A
+--R                 *
+--R                     7 2
+--R                    a b
+--R                + 
+--R                              2                2       2  3
+--R                      (- 1728C  + 384A C - 384B  + 576A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 1344B C  - 3456A B C + 384B  - 2112A B)D
+--R                    + 
+--R                             4          3         2       2  2
+--R                          64C  - 1536A C  + (1728B  - 768A )C
+--R                        + 
+--R                                  2       3         4       2 2      4
+--R                          (1152A B  - 256A )C + 128B  + 192A B  - 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3       2   2
+--R                      192B C  - 256A B C  + (320B  + 768A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 640A B  + 512A B)C - 128B  - 704A B  + 320A B
+--R                 *
+--R                     8
+--R                    a b
+--R                + 
+--R                           3       2           2  2
+--R                      (768C  - 768A C + 1536A B )D
+--R                    + 
+--R                                2        3        3            4       2 3
+--R                      (1536A B C  - 1024B C + 512A B)D + 256A C  - 256B C
+--R                    + 
+--R                            2 2          4       5
+--R                      - 768A B C + 512A B  - 256A
+--R                 *
+--R                     9
+--R                    a
+--R             *
+--R                %%BN1
+--R            + 
+--R                       2 3 8
+--R                  32A D a c
+--R                + 
+--R                             2 2 2         3        2  3
+--R                      - 16A D a b  + (- 16D  - 16B D )a b
+--R                    + 
+--R                             2                   2      3  4
+--R                      (128A D  - 128A B D - 32A C  + 32A )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                          2   4      3       2  2 3
+--R                      2A D a b  + (8D  + 8B D )a b
+--R                    + 
+--R                                    2                  2      3  3 2
+--R                      ((32C - 448A)D  + 64A B D + 16A C  - 16A )a b
+--R                    + 
+--R                               3        2         2               2       2
+--R                          - 32D  + 32B D  + (- 48C  + 224A C + 64B  + 144A )D
+--R                        + 
+--R                               2                2
+--R                          16B C  + 96A B C - 48A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                  2                 3         2      2
+--R                          - 128A D  - 512A B D + 64C  - 128A C  - 64A C
+--R                        + 
+--R                                2       3
+--R                          128A B  + 128A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                          3      2    5
+--R                      (- D  - B D )a b
+--R                    + 
+--R                                      2                2     3  2 4
+--R                      ((- 16C + 192A)D  - 8A B D - 2A C  + 2A )a b
+--R                    + 
+--R                              3         2       2               2      2
+--R                          160D  + 128B D  + (24C  - 112A C - 32B  - 72A )D
+--R                        + 
+--R                                2                2
+--R                          - 8B C  - 48A B C + 24A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                       2                             3         2
+--R                          (80C - 560A)D  + (- 96B C + 1312A B)D - 48C  + 304A C
+--R                        + 
+--R                                2      2           2       3
+--R                          (- 48B  - 16A )C - 112A B  - 368A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                              3         2          2               2       2
+--R                          128D  + 256B D  + (- 384C  + 512A C + 64B  + 384A )D
+--R                        + 
+--R                                  2      3       2
+--R                          - 128B C  - 64B  - 384A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                   2                  3         2       2
+--R                          - 1024A D  + 512A B D + 256C  + 128A C  - 256A C
+--R                        + 
+--R                                2       3
+--R                          512A B  - 128A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                                 2   6
+--R                      (2C - 22A)D a b
+--R                    + 
+--R                               3        2        2             2     2        2
+--R                          - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D + B C
+--R                        + 
+--R                                     2
+--R                          6A B C - 3A B
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                           2                          3
+--R                          (- 328C + 1896A)D  + (48B C - 528A B)D + 12C
+--R                        + 
+--R                                  2       2      2          2       3
+--R                          - 120A C  + (24B  + 20A )C + 32A B  + 152A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                3         2
+--R                          - 224D  - 800B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (720C  - 2080A C - 512B  - 1392A )D + 16B C
+--R                        + 
+--R                                          3       2
+--R                          - 672A B C + 64B  + 720A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         2                             3
+--R                          (160C + 2976A)D  + (576B C + 1088A B)D - 608C
+--R                        + 
+--R                                2        2       2            2      3
+--R                          416A C  + (288B  + 992A )C - 1120A B  - 32A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              3         2          2                 2       2
+--R                          256D  - 256B D  + (- 192C  - 1664A C - 640B  - 960A )D
+--R                        + 
+--R                                  2                   3       2
+--R                          - 448B C  - 1152A B C - 128B  - 192A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                  2                   3          2       2
+--R                          - 512A D  + 4096A B D - 256C  + 1024A C  + 256A C
+--R                        + 
+--R                                  2        3
+--R                          - 512A B  - 1024A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3       2    7
+--R                      (8D  + 8B D )a b
+--R                    + 
+--R                                        2                        3        2
+--R                          (141C - 755A)D  + (- 6B C + 58A B)D - C  + 13A C
+--R                        + 
+--R                               2     2         2      3
+--R                          (- 3B  - 3A )C - 3A B  - 17A
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                3        2          2                2       2
+--R                          - 284D  - 36B D  + (- 276C  + 888A C + 228B  + 588A )D
+--R                        + 
+--R                               2                 3       2
+--R                          12B C  + 312A B C - 20B  - 276A B
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          2                             3
+--R                          (- 32C - 2016A)D  + (192B C - 3072A B)D + 320C
+--R                        + 
+--R                                  2       2       2           2       3
+--R                          - 720A C  + (96B  - 192A )C + 672A B  + 848A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                3         2
+--R                          - 896D  - 384B D
+--R                        + 
+--R                                2                 2       2            2
+--R                          (1344C  + 1408A C + 896B  + 576A )D + 1088B C
+--R                        + 
+--R                                          3        2
+--R                          1920A B C + 384B  + 1344A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                           2                             3
+--R                          (- 640C + 4224A)D  + (768B C - 8448A B)D - 128C
+--R                        + 
+--R                                   2        2       2           2        3
+--R                          - 1920A C  + (384B  + 640A )C - 128A B  + 2432A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 256D  - 1280B D
+--R                        + 
+--R                                2                 2        2            2
+--R                          (3072C  - 4096A C - 512B  - 3072A )D + 1024B C
+--R                        + 
+--R                              3        2
+--R                          512B  + 3072A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                 2                    3         2        2
+--R                          2048A D  + 2048A B D - 2048C  + 512A C  + 2048A C
+--R                        + 
+--R                                   2       3
+--R                          - 4096A B  - 512A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                                    2   8
+--R                      (- 16C + 80A)D a b
+--R                    + 
+--R                              3         2       2               2      2
+--R                          146D  + 118B D  + (30C  - 100A C - 26B  - 66A )D
+--R                        + 
+--R                                2               3      2
+--R                          - 2B C  - 36A B C + 2B  + 30A B
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                         2                              3
+--R                          (726C - 2090A)D  + (- 180B C + 1100A B)D - 62C
+--R                        + 
+--R                                2         2      2           2       3
+--R                          230A C  + (- 90B  - 58A )C - 154A B  - 350A
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1752D  + 2760B D
+--R                        + 
+--R                                  2                 2        2           2
+--R                          (- 2160C  + 3840A C + 696B  + 2736A )D - 528B C
+--R                        + 
+--R                                         3        2
+--R                          576A B C - 312B  - 2160A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                   2                                3         2
+--R                          - 8160A D  + (- 4608B C + 5376A B)D + 864C  + 192A C
+--R                        + 
+--R                                  2        2           2        3
+--R                          (- 2304B  - 3936A )C + 960A B  - 3264A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1152D  + 4224B D
+--R                        + 
+--R                                  2                   2        2            2
+--R                          (- 5760C  + 11520A C + 2304B  + 8064A )D - 1152B C
+--R                        + 
+--R                                          3        2
+--R                          2304A B C - 768B  - 5760A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D + 3840C
+--R                        + 
+--R                                   2           2        2            2
+--R                          - 3072A C  + (- 2304B  - 6912A )C + 6912A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                3         2
+--R                          - 512D  + 512B D
+--R                        + 
+--R                                2                  2       2            2
+--R                          (3840C  + 2560A C + 2048B  + 768A )D + 2816B C
+--R                        + 
+--R                                           3        2
+--R                          4608A B C + 1024B  + 3840A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                 2                    3          2        2
+--R                          2048A D  - 8192A B D - 1024C  - 2048A C  + 1024A C
+--R                        + 
+--R                                   2        3
+--R                          - 2048A B  + 2048A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                            3        2    9
+--R                      (- 16D  - 16B D )a b
+--R                    + 
+--R                                          2                         3        2
+--R                          (- 308C + 972A)D  + (24B C - 104A B)D + 4C  - 20A C
+--R                        + 
+--R                              2      2          2      3
+--R                          (12B  + 12A )C + 12A B  + 36A
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                3         2
+--R                          - 456D  - 920B D
+--R                        + 
+--R                               2                 2        2           2
+--R                          (744C  - 1712A C - 376B  - 1176A )D + 104B C
+--R                        + 
+--R                                          3       2
+--R                          - 432A B C + 88B  + 744A B
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                            2                             3
+--R                          (- 1668C + 8316A)D  + (1656B C - 136A B)D - 364C
+--R                        + 
+--R                                2        2        2           2       3
+--R                          380A C  + (828B  + 1468A )C - 452A B  + 724A
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 2496D  - 6432B D
+--R                        + 
+--R                                2                   2        2           2
+--R                          (5328C  - 14304A C - 3408B  - 9648A )D + 336B C
+--R                        + 
+--R                                            3        2
+--R                          - 4320A B C + 528B  + 5328A B
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          2                                3
+--R                          (6528C + 3456A)D  + (11520B C + 7296A B)D - 3072C
+--R                        + 
+--R                                 2         2         2            2        3
+--R                          4704A C  + (5760B  + 10752A )C - 4224A B  + 2976A
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                               3         2
+--R                          1024D  - 512B D
+--R                        + 
+--R                                  2                  2        2            2
+--R                          (- 5760C  - 3840A C - 3072B  - 1152A )D - 4224B C
+--R                        + 
+--R                                             3        2
+--R                          - 6912A B C - 1536B  - 5760A B
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                          2                                  3
+--R                          (1280C - 6912A)D  + (- 1536B C + 12800A B)D + 1280C
+--R                        + 
+--R                                 2          2        2            2        3
+--R                          2816A C  + (- 768B  - 2304A )C + 2304A B  - 3840A
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                 2           2                  2        2
+--R                          2048B D  + (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                        + 
+--R                                   2        3        2
+--R                          - 2048B C  - 1024B  - 6144A B
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                             3          2        2           2
+--R                          - 8192A B D + 4096C  - 2048A C  - 4096A C + 8192A B
+--R                        + 
+--R                               3
+--R                          2048A
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                              2   10
+--R                  (32C - 96A)D a b
+--R                + 
+--R                         3        2         2               2       2         2
+--R                      24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D - 8B C
+--R                    + 
+--R                                  3      2
+--R                      48A B C - 8B  - 72A B
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                     2                             3        2
+--R                      (376C - 1416A)D  + (- 144B C - 144A B)D + 40C  - 72A C
+--R                    + 
+--R                            2       2          2      3
+--R                      (- 72B  - 136A )C + 56A B  - 24A
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                          3          2          2                 2        2
+--R                      360D  + 1080B D  + (- 936C  + 2608A C + 632B  + 1752A )D
+--R                    + 
+--R                             2                 3       2
+--R                      - 40B C  + 816A B C - 88B  - 936A B
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                      2                                3
+--R                      (- 24C - 4248A)D  + (- 2160B C - 2160A B)D + 536C
+--R                    + 
+--R                               2           2        2           2       3
+--R                      - 1080A C  + (- 1080B  - 1976A )C + 712A B  - 360A
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                           3          2
+--R                      1152D  + 3456B D
+--R                    + 
+--R                              2                  2        2           2
+--R                      (- 1296C  + 7968A C + 2400B  + 5040A )D + 816B C
+--R                    + 
+--R                                     3        2
+--R                      3744A B C + 96B  - 1296A B
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                        2                                3
+--R                      (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D + 960C
+--R                    + 
+--R                               2           2        2           2        3
+--R                      - 3456A C  + (- 3456B  - 5568A )C + 768A B  - 1152A
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                             3          2
+--R                      - 1536D  - 4608B D
+--R                    + 
+--R                             2                   2        2            2
+--R                      (11520C  - 12800A C - 1024B  - 9984A )D + 4352B C
+--R                    + 
+--R                                       3         2
+--R                      1536A B C + 2048B  + 11520A B
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                      2                               3
+--R                      (6656C - 1536A)D  + (9216B C + 9216A B)D - 5632C
+--R                    + 
+--R                             2         2         2            2        3
+--R                      4608A C  + (4608B  + 11776A )C - 9728A B  + 1536A
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                              2                  2        2            2
+--R                      (- 9216C  + 2048A C - 2048B  + 3072A )D - 5120B C
+--R                    + 
+--R                                         3        2
+--R                      - 6144A B C - 2048B  - 9216A B
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                        3        2           2  11
+--R                  (4096C  - 4096A C + 8192A B )a
+--R             *
+--R                     3
+--R                %%BN0
+--R            + 
+--R                         3 2 8
+--R                  - 32A D a c
+--R                + 
+--R                           3   2       4        3  2
+--R                      16A D a b  + (16D  + 16B D )a b
+--R                    + 
+--R                               3           2         2      3    3
+--R                      (- 128A D  + 128A B D  + (32A C  - 32A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            3 4        4       3    3
+--R                      - 2A D b  + (- 8D  - 8B D )a b
+--R                    + 
+--R                                      3          2           2      3    2 2
+--R                      ((- 32C + 448A)D  - 64A B D  + (- 16A C  + 16A )D)a b
+--R                    + 
+--R                             4        3       2               2       2  2
+--R                          32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                        + 
+--R                                  2                2
+--R                          (- 16B C  - 96A B C + 48A B)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                3           2
+--R                          128A D  + 512A B D
+--R                        + 
+--R                                3         2      2          2       3
+--R                          (- 64C  + 128A C  + 64A C - 128A B  - 128A )D
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4      3  5
+--R                      (D  + B D )b
+--R                    + 
+--R                                    3         2        2     3      4
+--R                      ((16C - 192A)D  + 8A B D  + (2A C  - 2A )D)a b
+--R                    + 
+--R                                4         3         2               2      2  2
+--R                          - 160D  - 128B D  + (- 24C  + 112A C + 32B  + 72A )D
+--R                        + 
+--R                               2                2
+--R                          (8B C  + 48A B C - 24A B)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         3                     2
+--R                          (- 80C + 560A)D  + (96B C - 1312A B)D
+--R                        + 
+--R                              3         2       2      2           2       3
+--R                          (48C  - 304A C  + (48B  + 16A )C + 112A B  + 368A )D
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                                4         3        2               2       2  2
+--R                          - 128D  - 256B D  + (384C  - 512A C - 64B  - 384A )D
+--R                        + 
+--R                                 2      3       2
+--R                          (128B C  + 64B  + 384A B)D
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                 3           2
+--R                          1024A D  - 512A B D
+--R                        + 
+--R                                 3         2       2          2       3
+--R                          (- 256C  - 128A C  + 256A C - 512A B  + 128A )D
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                                   3 6
+--R                      (- 2C + 22A)D b
+--R                    + 
+--R                             4        3      2             2     2  2
+--R                          70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D
+--R                        + 
+--R                                2              2
+--R                          (- B C  - 6A B C + 3A B)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (328C - 1896A)D  + (- 48B C + 528A B)D
+--R                        + 
+--R                              3         2         2      2          2       3
+--R                        (- 12C  + 120A C  + (- 24B  - 20A )C - 32A B  - 152A )D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          224D  + 800B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 720C  + 2080A C + 512B  + 1392A )D
+--R                        + 
+--R                                  2                 3       2
+--R                          (- 16B C  + 672A B C - 64B  - 720A B)D
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                           3                        2
+--R                          (- 160C - 2976A)D  + (- 576B C - 1088A B)D
+--R                        + 
+--R                                  3         2          2       2            2
+--R                              608C  - 416A C  + (- 288B  - 992A )C + 1120A B
+--R                            + 
+--R                                 3
+--R                              32A
+--R                         *
+--R                            D
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 256D  + 256B D
+--R                        + 
+--R                               2                 2       2  2
+--R                          (192C  + 1664A C + 640B  + 960A )D
+--R                        + 
+--R                                 2                   3       2
+--R                          (448B C  + 1152A B C + 128B  + 192A B)D
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                3            2
+--R                          512A D  - 4096A B D
+--R                        + 
+--R                               3          2       2          2        3
+--R                          (256C  - 1024A C  - 256A C + 512A B  + 1024A )D
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           4       3  7
+--R                      (- 8D  - 8B D )b
+--R                    + 
+--R                                          3                  2
+--R                          (- 141C + 755A)D  + (6B C - 58A B)D
+--R                        + 
+--R                            3        2      2     2         2      3
+--R                          (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                              4        3        2                2       2  2
+--R                          284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                        + 
+--R                                  2                 3       2
+--R                          (- 12B C  - 312A B C + 20B  + 276A B)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        3                        2
+--R                          (32C + 2016A)D  + (- 192B C + 3072A B)D
+--R                        + 
+--R                                    3         2         2       2           2
+--R                              - 320C  + 720A C  + (- 96B  + 192A )C - 672A B
+--R                            + 
+--R                                    3
+--R                              - 848A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          896D  + 384B D
+--R                        + 
+--R                                  2                 2       2  2
+--R                          (- 1344C  - 1408A C - 896B  - 576A )D
+--R                        + 
+--R                                    2                   3        2
+--R                          (- 1088B C  - 1920A B C - 384B  - 1344A B)D
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                        2
+--R                          (640C - 4224A)D  + (- 768B C + 8448A B)D
+--R                        + 
+--R                                  3          2          2       2           2
+--R                              128C  + 1920A C  + (- 384B  - 640A )C + 128A B
+--R                            + 
+--R                                     3
+--R                              - 2432A
+--R                         *
+--R                            D
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          256D  + 1280B D
+--R                        + 
+--R                                  2                 2        2  2
+--R                          (- 3072C  + 4096A C + 512B  + 3072A )D
+--R                        + 
+--R                                    2       3        2
+--R                          (- 1024B C  - 512B  - 3072A B)D
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                   3            2
+--R                          - 2048A D  - 2048A B D
+--R                        + 
+--R                                3         2        2           2       3
+--R                          (2048C  - 512A C  - 2048A C + 4096A B  + 512A )D
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                                  3 8
+--R                      (16C - 80A)D b
+--R                    + 
+--R                                4         3         2               2      2  2
+--R                          - 146D  - 118B D  + (- 30C  + 100A C + 26B  + 66A )D
+--R                        + 
+--R                               2               3      2
+--R                          (2B C  + 36A B C - 2B  - 30A B)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 726C + 2090A)D  + (180B C - 1100A B)D
+--R                        + 
+--R                              3         2       2      2           2       3
+--R                          (62C  - 230A C  + (90B  + 58A )C + 154A B  + 350A )D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1752D  - 2760B D
+--R                        + 
+--R                                2                 2        2  2
+--R                          (2160C  - 3840A C - 696B  - 2736A )D
+--R                        + 
+--R                                 2                  3        2
+--R                          (528B C  - 576A B C + 312B  + 2160A B)D
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                 3                       2
+--R                          8160A D  + (4608B C - 5376A B)D
+--R                        + 
+--R                                    3         2         2        2           2
+--R                              - 864C  - 192A C  + (2304B  + 3936A )C - 960A B
+--R                            + 
+--R                                   3
+--R                              3264A
+--R                         *
+--R                            D
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1152D  - 4224B D
+--R                        + 
+--R                                2                   2        2  2
+--R                          (5760C  - 11520A C - 2304B  - 8064A )D
+--R                        + 
+--R                                  2                   3        2
+--R                          (1152B C  - 2304A B C + 768B  + 5760A B)D
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (2816C + 4352A)D  + (4608B C + 7680A B)D
+--R                        + 
+--R                                3          2         2        2            2
+--R                        (- 3840C  + 3072A C  + (2304B  + 6912A )C - 6912A B )D
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          512D  - 512B D
+--R                        + 
+--R                                  2                  2       2  2
+--R                          (- 3840C  - 2560A C - 2048B  - 768A )D
+--R                        + 
+--R                                    2                    3        2
+--R                          (- 2816B C  - 4608A B C - 1024B  - 3840A B)D
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                   3            2
+--R                          - 2048A D  + 8192A B D
+--R                        + 
+--R                                3          2        2           2        3
+--R                          (1024C  + 2048A C  - 1024A C + 2048A B  - 2048A )D
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          4        3  9
+--R                      (16D  + 16B D )b
+--R                    + 
+--R                                        3                      2
+--R                          (308C - 972A)D  + (- 24B C + 104A B)D
+--R                        + 
+--R                               3        2         2      2          2      3
+--R                          (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                     *
+--R                           8
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          456D  + 920B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 744C  + 1712A C + 376B  + 1176A )D
+--R                        + 
+--R                                   2                 3       2
+--R                          (- 104B C  + 432A B C - 88B  - 744A B)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          3                        2
+--R                          (1668C - 8316A)D  + (- 1656B C + 136A B)D
+--R                        + 
+--R                                  3         2          2        2           2
+--R                              364C  - 380A C  + (- 828B  - 1468A )C + 452A B
+--R                            + 
+--R                                    3
+--R                              - 724A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                               4          3
+--R                          2496D  + 6432B D
+--R                        + 
+--R                                  2                   2        2  2
+--R                          (- 5328C  + 14304A C + 3408B  + 9648A )D
+--R                        + 
+--R                                   2                   3        2
+--R                          (- 336B C  + 4320A B C - 528B  - 5328A B)D
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            3                          2
+--R                          (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                        + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                            D
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                 4         3
+--R                          - 1024D  + 512B D
+--R                        + 
+--R                                2                  2        2  2
+--R                          (5760C  + 3840A C + 3072B  + 1152A )D
+--R                        + 
+--R                                  2                    3        2
+--R                          (4224B C  + 6912A B C + 1536B  + 5760A B)D
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            3                        2
+--R                          (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                        + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                            D
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                   3         2                  2        2  2
+--R                          - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                        + 
+--R                                  2        3        2
+--R                          (2048B C  + 1024B  + 6144A B)D
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   2
+--R                          8192A B D
+--R                        + 
+--R                                  3          2        2           2        3
+--R                          (- 4096C  + 2048A C  + 4096A C - 8192A B  - 2048A )D
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                                3 10
+--R                  (- 32C + 96A)D b
+--R                + 
+--R                           4        3       2               2       2  2
+--R                      - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                    + 
+--R                           2               3      2
+--R                      (8B C  - 48A B C + 8B  + 72A B)D
+--R                 *
+--R                       9
+--R                    a b
+--R                + 
+--R                                       3                     2
+--R                      (- 376C + 1416A)D  + (144B C + 144A B)D
+--R                    + 
+--R                            3        2       2       2          2      3
+--R                      (- 40C  + 72A C  + (72B  + 136A )C - 56A B  + 24A )D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            4          3        2                 2        2  2
+--R                      - 360D  - 1080B D  + (936C  - 2608A C - 632B  - 1752A )D
+--R                    + 
+--R                            2                 3       2
+--R                      (40B C  - 816A B C + 88B  + 936A B)D
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                    3                       2
+--R                      (24C + 4248A)D  + (2160B C + 2160A B)D
+--R                    + 
+--R                           3          2         2        2           2       3
+--R                    (- 536C  + 1080A C  + (1080B  + 1976A )C - 712A B  + 360A )D
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                             4          3
+--R                      - 1152D  - 3456B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (1296C  - 7968A C - 2400B  - 5040A )D
+--R                    + 
+--R                               2                  3        2
+--R                      (- 816B C  - 3744A B C - 96B  + 1296A B)D
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      3                       2
+--R                      (7040C - 7296A)D  + (6912B C + 6912A B)D
+--R                    + 
+--R                                3          2         2        2           2
+--R                          - 960C  + 3456A C  + (3456B  + 5568A )C - 768A B
+--R                        + 
+--R                               3
+--R                          1152A
+--R                     *
+--R                        D
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                           4          3
+--R                      1536D  + 4608B D
+--R                    + 
+--R                               2                   2        2  2
+--R                      (- 11520C  + 12800A C + 1024B  + 9984A )D
+--R                    + 
+--R                                2                    3         2
+--R                      (- 4352B C  - 1536A B C - 2048B  - 11520A B)D
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D
+--R                    + 
+--R                               3          2           2         2            2
+--R                          5632C  - 4608A C  + (- 4608B  - 11776A )C + 9728A B
+--R                        + 
+--R                                 3
+--R                          - 1536A
+--R                     *
+--R                        D
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                  2        2  2
+--R                      (9216C  - 2048A C + 2048B  - 3072A )D
+--R                    + 
+--R                              2                    3        2
+--R                      (5120B C  + 6144A B C + 2048B  + 9216A B)D
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                          3        2           2    10
+--R                  (- 4096C  + 4096A C - 8192A B )D a
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                      4   8
+--R                  8A D a c
+--R                + 
+--R                            4 2        5       4         3
+--R                      - 2A D b  + (- 4D  - 4B D  - 8A C D )a b
+--R                    + 
+--R                            4          3      3 2  2
+--R                      (32A D  - 16A B D  + 16A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        5      4         3  3
+--R                      (D  + B D  + 2A C D )b
+--R                    + 
+--R                                    4                 3     3 2    2
+--R                      ((12C - 100A)D  + (4B C + 4A B)D  - 4A D )a b
+--R                    + 
+--R                              5         2     2      2  3                 2   2
+--R                          - 8D  + (- 16C  + 8B  + 24A )D  + (48A B C - 24A B)D
+--R                        + 
+--R                               3     3
+--R                          (8A C  - 8A C)D
+--R                     *
+--R                         2
+--R                        a b
+--R                    + 
+--R                                 4          3       3      2         2      3  2
+--R                          - 48A D  - 64A B D  + (16C  - 48A C - 48A B  + 64A )D
+--R                        + 
+--R                                    2      3          4     5
+--R                          (- 48A B C  - 16A B)D - 8A C  + 8A
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                    4        3  4
+--R                      ((- 3C + 22A)D  - B C D )b
+--R                    + 
+--R                             5        4        2             2     2  3
+--R                          36D  + 34B D  + (- 4C  + 92A C - 2B  - 6A )D
+--R                        + 
+--R                                         2   2          3     3
+--R                          (- 12A B C + 6A B)D  + (- 2A C  + 2A C)D
+--R                     *
+--R                           3
+--R                        a b
+--R                    + 
+--R                                       4           3
+--R                          (40C - 108A)D  + 104A B D
+--R                        + 
+--R                              3        2         2      2          2       3  2
+--R                          (12C  - 84A C  + (- 24B  - 12A )C + 12A B  - 172A )D
+--R                        + 
+--R                                 3          2      2        3          4     5
+--R                          (- 4B C  - 12A B C  + 12A B C + 4A B)D + 2A C  - 2A
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                             5        4          2               2       2  3
+--R                          40D  + 56B D  + (- 104C  + 112A C + 40B  + 120A )D
+--R                        + 
+--R                                  2                 3      2   2
+--R                          (- 48B C  + 384A B C + 24B  + 48A B)D
+--R                        + 
+--R                                   4         3       2      2  2        2
+--R                              - 28C  + 112A C  + (24B  + 48A )C  + 48A B C
+--R                            + 
+--R                                 2 2      4
+--R                              24A B  + 28A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4          3      3         4
+--R                          4B C  + 32A B C  + 16A B C - 20A B
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                  4           3
+--R                          - 320A D  + 192A B D
+--R                        + 
+--R                              3        2       2          2      3  2
+--R                          (64C  + 48A C  - 192A C - 192A B  - 48A )D
+--R                        + 
+--R                                3           2      2            3      3
+--R                          (32B C  - 192A B C  + 96A B C + 128A B  - 64A B)D
+--R                        + 
+--R                             5        4      2 3        2 2      4       3 2
+--R                          16C  - 32A C  + 32A C  + 48A B C  - 48A C + 16A B
+--R                        + 
+--R                             5
+--R                          32A
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           5       4      2          3  5
+--R                      (- 8D  - 8B D  + (2C  - 22A C)D )b
+--R                    + 
+--R                                          4                     3
+--R                          (- 112C + 388A)D  + (- 34B C - 20A B)D
+--R                        + 
+--R                               3        2      2     2        3  2
+--R                          (- 4C  + 21A C  + (6B  + 6A )C + 37A )D
+--R                        + 
+--R                              3         2     2
+--R                          (B C  + 6A B C  - 3A B C)D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                               5         4        2              2       2  3
+--R                          - 62D  - 126B D  + (138C  - 96A C - 66B  - 222A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (48B C  - 456A B C - 2B  + 204A B)D
+--R                        + 
+--R                              4        3     2 2      3      2 2     4        4
+--R                          (11C  - 84A C  + 6B C  + 72A C - 6A B  - 7A )D - B C
+--R                        + 
+--R                                  3     3        4
+--R                          - 8A B C  - 4A B C + 5A B
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                4                    3
+--R                          840A D  + (56B C - 264A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                                24C  - 420A C  + (- 96B  + 288A )C + 360A B
+--R                              + 
+--R                                      3
+--R                                - 196A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2         3       2            3
+--R                              - 8B C  + 240A B C  + (- 24B  - 120A B)C - 104A B
+--R                            + 
+--R                                 3
+--R                              80A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4         2      2  3
+--R                          - 8C  + 56A C  + (- 16B  - 40A )C
+--R                        + 
+--R                                2      3  2         2 2      4       3 2      5
+--R                        (- 60A B  - 16A )C  + (- 24A B  + 16A )C + 4A B  - 72A
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                             5        4        2               2       2  3
+--R                          80D  - 48B D  + (- 8C  - 240A C - 80B  - 168A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 264B C  + 144A B C - 16B  + 216A B)D
+--R                        + 
+--R                                    4         3         2       2  2
+--R                              - 208C  + 192A C  + (- 24B  - 144A )C
+--R                            + 
+--R                                       2      3        4       2 2       4
+--R                              (- 528A B  - 32A )C - 64B  - 408A B  + 128A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4          3         3       2   2
+--R                          - 48B C  - 64A B C  + (- 24B  - 240A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 80A B  + 96A B)C - 24A B  - 64A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                  4            3
+--R                          - 128A D  + 1024A B D
+--R                        + 
+--R                                3         2      2          2       3  2
+--R                          (- 96C  + 192A C  + 96A C - 192A B  - 448A )D
+--R                        + 
+--R                                 3       2            3        5        4
+--R                          (128B C  + 384A B C + 512A B )D + 64C  - 64A C
+--R                        + 
+--R                                2       2  3          2      3  2
+--R                          (- 32B  + 128A )C  + (192A B  + 64A )C
+--R                        + 
+--R                                2 2       4          4      3 2
+--R                          (- 96A B  - 192A )C - 64A B  + 64A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                   4         3  6
+--R                      ((24C - 80A)D  + 8B C D )b
+--R                    + 
+--R                               5        4       2               2      2  3
+--R                          - 65D  - 51B D  + (42C  - 345A C + 13B  + 45A )D
+--R                        + 
+--R                                 2              3      2   2
+--R                          (- 9B C  + 84A B C - B  - 51A B)D
+--R                        + 
+--R                            4        3        2     2  2          2      3
+--R                        (- C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                  4                    3
+--R                          - 596A D  + (38B C + 106A B)D
+--R                        + 
+--R                                    3         2        2       2          2
+--R                              - 180C  + 744A C  + (180B  + 102A )C - 96A B
+--R                            + 
+--R                                  3
+--R                              522A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2        3       2           3
+--R                              10B C  + 114A B C  + (- 2B  - 102A B)C + 18A B
+--R                            + 
+--R                                   3
+--R                              - 14A B
+--R                         *
+--R                            D
+--R                        + 
+--R                           5        4      2     2  3         2     3  2
+--R                          C  - 11A C  + (4B  + 8A )C  + (12A B  + 4A )C
+--R                        + 
+--R                             2 2    4       3 2      5
+--R                          (6A B  - A )C - 2A B  + 15A
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                                5         4        2              2       2  3
+--R                          - 248D  - 136B D  + (158C  - 12A C - 72B  - 178A )D
+--R                        + 
+--R                                 2                   3       2   2
+--R                          (354B C  - 1572A B C - 136B  - 894A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              290C  - 672A C  + (- 126B  - 180A )C
+--R                            + 
+--R                                     2      3        4       2 2       4
+--R                              (108A B  - 96A )C + 48B  + 162A B  - 238A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          10B C  - 128A B C  + (30B  + 204A B)C
+--R                        + 
+--R                                3       3         2 3       4
+--R                          (68A B  - 128A B)C + 14A B  + 170A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                           4                      3
+--R                          (- 280C + 1176A)D  + (384B C - 1728A B)D
+--R                        + 
+--R                                  3        2        2        2            2
+--R                              392C  - 72A C  + (624B  + 1080A )C + 1392A B
+--R                            + 
+--R                                   3
+--R                              1160A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2        3       2            3
+--R                              144B C  + 1584A B C  + (384B  + 816A B)C - 640A B
+--R                            + 
+--R                                  3
+--R                              528A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4        2      2  3
+--R                          - 112C  + 208A C  + (168B  - 64A )C
+--R                        + 
+--R                                2      3  2       4       2 2       4          4
+--R                          (24A B  + 96A )C  + (40B  + 408A B  + 432A )C + 88A B
+--R                        + 
+--R                               3 2      5
+--R                          - 88A B  - 48A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                               5         4
+--R                          - 96D  - 352B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (992C  - 1088A C - 256B  - 1056A )D
+--R                        + 
+--R                                2                   3      2   2
+--R                          (96B C  - 1728A B C - 128B  + 96A B)D
+--R                        + 
+--R                                    4         2       2  2
+--R                              - 160C  + (- 96B  - 768A )C
+--R                            + 
+--R                                        2       3        4       2 2      4
+--R                              (- 1344A B  - 384A )C - 96B  - 864A B  + 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3       2   2
+--R                          - 32B C  - 128A B C  + (32B  - 384A B)C
+--R                        + 
+--R                                 3       3         5       2 3      4
+--R                          (192A B  + 256A B)C + 32B  + 288A B  + 32A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                4           3          3        2        3  2
+--R                          768A D  + 256A B D  + (- 640C  + 1152A C - 256A )D
+--R                        + 
+--R                                   2       3            4       2 3       3 2
+--R                          (768A B C  + 256A B)D - 128A C  - 128B C  + 256A C
+--R                        + 
+--R                                2 2          4       5
+--R                          - 384A B C - 256A B  - 128A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          5        4         2          3  7
+--R                      (16D  + 16B D  + (- 16C  + 80A C)D )b
+--R                    + 
+--R                                        4                   3
+--R                          (232C - 410A)D  + (66B C - 20A B)D
+--R                        + 
+--R                              3         2         2      2         2       3  2
+--R                          (40C  - 150A C  + (- 36B  - 36A )C + 6A B  - 102A )D
+--R                        + 
+--R                                 3          2      3      2
+--R                          (- 2B C  - 36A B C  + (2B  + 30A B)C)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                              5         4          2                2       2  3
+--R                          422D  + 522B D  + (- 290C  + 454A C + 122B  + 460A )D
+--R                        + 
+--R                                   2                  3       2   2
+--R                          (- 228B C  + 1068A B C + 14B  - 324A B)D
+--R                        + 
+--R                                   4         3         2     2  2
+--R                              - 74C  + 246A C  + (- 24B  - 6A )C
+--R                            + 
+--R                                      2       3       4      2 2      4
+--R                              (- 54A B  - 150A )C - 8B  - 18A B  + 48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3        3      2   2           3      3
+--R                          32A B C  + (- 6B  - 36A B)C  + (- 12A B  + 24A B)C
+--R                        + 
+--R                              2 3      4
+--R                          - 2A B  - 36A B
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         4                        3
+--R                          (434C - 1918A)D  + (- 516B C + 1940A B)D
+--R                        + 
+--R                                    3         2          2       2           2
+--R                              - 568C  + 984A C  + (- 108B  - 828A )C - 996A B
+--R                            + 
+--R                                    3
+--R                              - 652A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2         3      2
+--R                              - 204B C  - 852A B C  + (- 84B  - 12A B)C
+--R                            + 
+--R                                    3       3
+--R                              356A B  - 196A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5         4        2       2  3         2     3  2
+--R                          36C  - 132A C  + (- 8B  + 108A )C  + (72A B  + 4A )C
+--R                        + 
+--R                                4       2 2       4          4      3 2       5
+--R                          (- 30B  - 108A B  - 128A )C - 38A B  - 60A B  + 144A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          360D  + 968B D
+--R                        + 
+--R                                  2                 2        2  3
+--R                          (- 1884C  + 1944A C + 400B  + 1892A )D
+--R                        + 
+--R                                   2                  3        2   2
+--R                          (- 660B C  + 1320A B C + 48B  - 1428A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              588C  - 544A C  + (- 612B  + 504A )C
+--R                            + 
+--R                                      2       3         4        2 2       4
+--R                              (1800A B  - 256A )C + 216B  + 1788A B  - 484A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3       2   2
+--R                          156B C  + 160A B C  + (- 172B  + 504A B)C
+--R                        + 
+--R                                   3       3         5       2 3      4
+--R                          (- 232A B  - 960A B)C - 40B  - 268A B  - 52A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                           4                        3
+--R                          (- 816C - 1488A)D  + (- 1152B C - 384A B)D
+--R                        + 
+--R                                  3         2          2        2          2
+--R                              304C  + 240A C  + (- 288B  - 1776A )C + 96A B
+--R                            + 
+--R                                  3
+--R                              784A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2          3       2
+--R                              - 800B C  - 1824A B C  + (- 320B  - 480A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 960A B  - 480A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4         2       2  3
+--R                          - 128C  + 160A C  + (- 16B  - 256A )C
+--R                        + 
+--R                                    2       3  2          4       2 2       4
+--R                          (- 1104A B  - 640A )C  + (- 240B  - 432A B  + 128A )C
+--R                        + 
+--R                                4       3 2       5
+--R                          176A B  - 752A B  + 224A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                5         4         2                2  3
+--R                          - 192D  + 192B D  + (1152C  + 768A C + 384B )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (1536B C  - 768A B C + 256B  + 384A B)D
+--R                        + 
+--R                                  4         3        2       2  2
+--R                              896C  - 128A C  + (384B  + 384A )C
+--R                            + 
+--R                                      2       3         4        2 2       4
+--R                              (2304A B  - 128A )C + 320B  + 1920A B  - 512A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3        3        2   2          3
+--R                          384B C  + 768A B C  + (256B  + 1152A B)C  + 1024A B C
+--R                        + 
+--R                             5       2 3       4
+--R                          64B  + 768A B  + 256A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                4            3
+--R                          768A D  - 3072A B D
+--R                        + 
+--R                                 3         2       2          2       3  2
+--R                          (- 256C  - 768A C  + 768A C + 768A B  + 768A )D
+--R                        + 
+--R                                      3           2        2             3
+--R                              - 512B C  + 768A B C  - 1536A B C - 2048A B
+--R                            + 
+--R                                  3
+--R                              256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2 3         2 2       4
+--R                          - 256C  + 128A C  - 512A C  - 768A B C  + 768A C
+--R                        + 
+--R                                3 2       5
+--R                          - 256A B  - 128A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                     4          3  8
+--R                      ((- 48C + 96A)D  - 16B C D )b
+--R                    + 
+--R                               5        4          2               2      2  3
+--R                          - 60D  - 84B D  + (- 104C  + 420A C - 20B  - 84A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (36B C  - 144A B C + 4B  + 108A B)D
+--R                        + 
+--R                             4        3       2      2  2         2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                           4                       3
+--R                          (- 795C + 1965A)D  + (- 124B C - 996A B)D
+--R                        + 
+--R                                  3          2          2       2           2
+--R                              570C  - 1530A C  + (- 258B  - 138A )C + 246A B
+--R                            + 
+--R                                    3
+--R                              - 342A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2           3
+--R                              68B C  - 156A B C  + (36B  + 300A B)C - 52A B
+--R                            + 
+--R                                 3
+--R                              12A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3           2     3  2
+--R                          - 3C  + 17A C  + (- 6B  - 22A )C  + (- 18A B  - 6A )C
+--R                        + 
+--R                             4     2 2     4         4      3 2      5
+--R                          (5B  + 6A B  + 9A )C + 5A B  + 18A B  - 27A
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5          4
+--R                          - 684D  - 1284B D
+--R                        + 
+--R                                2                 2        2  3
+--R                          (1576C  - 1932A C - 116B  - 1284A )D
+--R                        + 
+--R                                 2                  3        2   2
+--R                          (564B C  + 912A B C + 324B  + 3564A B)D
+--R                        + 
+--R                                    4          3        2       2  2
+--R                              - 564C  + 1212A C  + (732B  + 444A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 420A B  + 756A )C - 144B  - 816A B  + 552A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3       2   2       3
+--R                          - 56B C  + 192A B C  + (16B  - 480A B)C  + 544A B C
+--R                        + 
+--R                             5      2 3       4
+--R                          16B  + 96A B  - 264A B
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                         4                       3
+--R                          (1272C + 792A)D  + (1208B C - 1704A B)D
+--R                        + 
+--R                                 3          2           2       2            2
+--R                              48C  - 1920A C  + (- 1248B  - 792A )C - 2064A B
+--R                            + 
+--R                                     3
+--R                              - 1128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2          3        2
+--R                              312B C  - 1704A B C  + (- 696B  - 3720A B)C
+--R                            + 
+--R                                    3       3
+--R                              312A B  - 936A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4          2       2  3
+--R                          164C  - 300A C  + (- 304B  - 240A )C
+--R                        + 
+--R                                 2      3  2        4      2 2       4
+--R                          (240A B  + 32A )C  + (200B  - 24A B  - 468A )C
+--R                        + 
+--R                                 4       3 2       5
+--R                          - 24A B  + 968A B  - 276A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                              5        4       2                2       2  3
+--R                          384D  + 96B D  + (40C  - 336A C + 256B  + 648A )D
+--R                        + 
+--R                                  2                   3        2   2
+--R                          (1176B C  + 6672A B C + 480B  + 2232A B)D
+--R                        + 
+--R                                     4          3         2        2  2
+--R                              - 1032C  + 1824A C  + (2712B  + 2640A )C
+--R                            + 
+--R                                      2        3        4       2 2        4
+--R                              (2064A B  + 2784A )C - 96B  - 744A B  + 1464A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3        3        2   2
+--R                          - 296B C  + 384A B C  + (616B  + 1104A B)C
+--R                        + 
+--R                                3        3         5       2 3       4
+--R                          (48A B  + 2176A B)C - 32B  - 600A B  + 216A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         4                         3
+--R                          (480C - 2592A)D  + (- 1536B C + 4224A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1632C  + 1248A C  + (- 2112B  - 3744A )C
+--R                            + 
+--R                                       2        3
+--R                              - 4224A B  - 2016A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2           3        2
+--R                              - 768B C  - 5376A B C  + (- 1536B  - 4224A B)C
+--R                            + 
+--R                                     3        3
+--R                              1536A B  - 1920A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4       2 3            2       3  2
+--R                          320C  - 480A C  - 544B C  + (- 480A B  - 640A )C
+--R                        + 
+--R                               4        2 2        4          4       3 2      5
+--R                        (- 160B  - 1248A B  - 1344A )C - 96A B  + 224A B  + 96A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4           2                 2        2  3
+--R                          768B D  + (- 2304C  + 3072A C + 384B  + 2304A )D
+--R                        + 
+--R                                 2                  3        2   2
+--R                          (384B C  + 768A B C + 128B  - 1152A B)D
+--R                        + 
+--R                                   4          3        2 2
+--R                              1088C  - 1792A C  + 2304A C
+--R                            + 
+--R                                      2        3         4        2 2       4
+--R                              (4608A B  + 1536A )C + 384B  + 3072A B  - 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3        2   2
+--R                          64B C  + (- 128B  + 1536A B)C
+--R                        + 
+--R                                   3        3          5        2 3       4
+--R                          (- 768A B  - 1280A B)C - 128B  - 1152A B  + 192A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                     3
+--R                          - 3072A B D
+--R                        + 
+--R                                3         2        2           2       3  2
+--R                          (1536C  - 768A C  - 1536A C + 3072A B  + 768A )D
+--R                        + 
+--R                                   3        2             3         5          4
+--R                          (- 512B C  - 1536A B C - 2048A B )D - 256C  + 1024A C
+--R                        + 
+--R                               2       2  3            2        3  2
+--R                          (512B  - 512A )C  + (- 768A B  - 1024A )C
+--R                        + 
+--R                                2 2       4            4       3 2
+--R                          (1536A B  + 768A )C + 1024A B  - 256A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                      2          3 9
+--R                  (32C  - 96A C)D b
+--R                + 
+--R                                   4                    3
+--R                      (96C - 216A)D  + (24B C + 144A B)D
+--R                    + 
+--R                            3         2       2      2          2      3  2
+--R                      (- 96C  + 264A C  + (48B  + 48A )C - 24A B  + 72A )D
+--R                    + 
+--R                             3          2        3      2
+--R                      (- 8B C  + 48A B C  + (- 8B  - 72A B)C)D
+--R                 *
+--R                       8
+--R                    a b
+--R                + 
+--R                         5         4         2               2       2  3
+--R                      54D  + 126B D  + (- 12C  - 336A C - 12B  + 108A )D
+--R                    + 
+--R                              2                 3       2   2
+--R                      (- 60B C  - 360A B C - 60B  - 540A B)D
+--R                    + 
+--R                             4         3          2      2  2         2      3
+--R                          94C  - 240A C  + (- 108B  - 84A )C  + (48A B  - 96A )C
+--R                        + 
+--R                             4       2 2      4
+--R                          22B  + 108A B  - 90A
+--R                     *
+--R                        D
+--R                    + 
+--R                          4          3      3      2   2        3      3
+--R                      6B C  - 40A B C  + (4B  + 84A B)C  + (8A B  - 72A B)C
+--R                    + 
+--R                          5      2 3      4
+--R                      - 2B  - 12A B  + 54A B
+--R                 *
+--R                     2 7
+--R                    a b
+--R                + 
+--R                                     4                    3
+--R                      (450C - 1350A)D  + (96B C + 936A B)D
+--R                    + 
+--R                                  3          2        2       2           2
+--R                            - 492C  + 1764A C  + (540B  + 636A )C + 420A B
+--R                          + 
+--R                                3
+--R                            684A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 3           2       3       2           3
+--R                          - 48B C  + 792A B C  + (96B  + 288A B)C - 72A B
+--R                        + 
+--R                              3
+--R                          216A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5        4       2      2  3           2     3  2
+--R                      - 30C  + 74A C  + (52B  + 36A )C  + (- 36A B  + 4A )C
+--R                    + 
+--R                            4      2 2      4         4       3 2      5
+--R                      (- 30B  + 12A B  + 90A )C + 2A B  - 156A B  + 18A
+--R                 *
+--R                     3 6
+--R                    a b
+--R                + 
+--R                          5         4           2                 2       2  3
+--R                      360D  + 792B D  + (- 1656C  + 2664A C - 168B  + 432A )D
+--R                    + 
+--R                               2                   3        2   2
+--R                      (- 720B C  - 3312A B C - 504B  - 3888A B)D
+--R                    + 
+--R                              4          3           2        2  2
+--R                          600C  - 1656A C  + (- 1152B  - 1224A )C
+--R                        + 
+--R                                   2        3        4       2 2       4
+--R                          (- 648A B  - 1224A )C + 96B  + 360A B  - 720A
+--R                     *
+--R                        D
+--R                    + 
+--R                           4           3         3       2   2
+--R                      48B C  - 384A B C  + (- 72B  + 144A B)C
+--R                    + 
+--R                            3       3         2 3       4
+--R                      (48A B  - 672A B)C + 72A B  + 288A B
+--R                 *
+--R                     4 5
+--R                    a b
+--R                + 
+--R                                        4                        3
+--R                      (- 2232C + 2952A)D  + (- 336B C - 1296A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          2016C  - 2160A C  + (1584B  + 2448A )C + 4464A B
+--R                        + 
+--R                              3
+--R                          864A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2         3        2            3
+--R                          480B C  + 3888A B C  + (1488B  + 7200A B)C - 144A B
+--R                        + 
+--R                               3
+--R                          1872A B
+--R                     *
+--R                        D
+--R                    + 
+--R                            5         4        2       2  3
+--R                      - 192C  + 480A C  + (480B  + 432A )C
+--R                    + 
+--R                             2       3  2          4       2 2       4
+--R                      (288A B  + 336A )C  + (- 120B  + 432A B  + 720A )C
+--R                    + 
+--R                             4       3 2       5
+--R                      - 24A B  - 912A B  + 144A
+--R                 *
+--R                     5 4
+--R                    a b
+--R                + 
+--R                            5          4         2                 2        2  3
+--R                      - 576D  - 1728B D  + (3472C  - 6240A C - 672B  - 3312A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 2160B C  - 3744A B C - 288B  + 3024A B)D
+--R                    + 
+--R                                 4          3           2        2  2
+--R                          - 1248C  + 1728A C  + (- 2448B  - 4320A )C
+--R                        + 
+--R                                    2        3         4        2 2
+--R                          (- 8352A B  - 3456A )C - 672B  - 4176A B
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3          3        2   2
+--R                      - 96B C  - 768A B C  + (- 912B  - 4320A B)C
+--R                    + 
+--R                               3       3         5        2 3        4
+--R                      (- 480A B  - 960A B)C + 96B  + 1008A B  - 1152A B
+--R                 *
+--R                     6 3
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (2496C - 576A)D  + (3456B C + 3456A B)D
+--R                    + 
+--R                              3          2         2        2            2  2
+--R                      (- 1344C  + 4992A C  + (2688B  + 3264A )C - 3072A B )D
+--R                    + 
+--R                                 3            2         3        2             3
+--R                          2816B C  + 4992A B C  + (1664B  + 2304A B)C + 3456A B
+--R                        + 
+--R                               3
+--R                          1152A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          5         4        2        2  3
+--R                      384C  - 768A C  + (576B  + 1152A )C
+--R                    + 
+--R                              2        3  2        4        2 2           4
+--R                      (4608A B  + 2304A )C  + (960B  + 2880A B )C - 192A B
+--R                    + 
+--R                           3 2
+--R                      2688A B
+--R                 *
+--R                     7 2
+--R                    a b
+--R                + 
+--R                              2                2        2  3
+--R                      (- 3456C  + 768A C - 768B  + 1152A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 1920B C  - 2304A B C - 768B  - 3456A B)D
+--R                    + 
+--R                                4          3           2       2  2
+--R                          - 256C  - 3072A C  + (- 1152B  + 768A )C
+--R                        + 
+--R                                   2        3         4        2 2
+--R                          (- 768A B  + 1536A )C - 256B  - 1152A B
+--R                     *
+--R                        D
+--R                    + 
+--R                              4            3          3       2   2
+--R                      - 768B C  - 2048A B C  + (- 640B  - 768A B)C
+--R                    + 
+--R                                3        3          5        2 3
+--R                      (- 2816A B  - 1536A B)C - 256B  - 2688A B
+--R                 *
+--R                     8
+--R                    a b
+--R                + 
+--R                            3        2           2  2          4       2 3
+--R                      (1536C  - 1536A C + 3072A B )D  + 1024A C  + 512B C
+--R                    + 
+--R                             3 2        2 2           4
+--R                      - 1024A C  + 1536A B C + 1024A B
+--R                 *
+--R                     9
+--R                    a
+--R             *
+--R                %%BN0
+--R            + 
+--R                       5          4   7
+--R                  (2A D b - 4A C D a)c
+--R                + 
+--R                            5         4  2
+--R                      (- B D  - 4A C D )b
+--R                    + 
+--R                                    5                  4         2     3  3
+--R                      ((- 2C + 10A)D  + (2B C - 14A B)D  + (12A C  + 4A )D )a b
+--R                    + 
+--R                        2             2  4            3          3     3   2  2
+--R                    ((4C  - 16A C + 4A )D  + 32A B C D  + (- 8A C  - 8A C)D )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 5                 4        2     3  3  3
+--R                      ((C - 19A)D  + (2B C + 6A B)D  + (2A C  - 2A )D )b
+--R                    + 
+--R                            6       5      2             2      2  4
+--R                          3D  - 2B D  + (2C  + 28A C + 7B  + 18A )D
+--R                        + 
+--R                                 2              2   3          3     3   2
+--R                          (- 6B C  - 4A B C - 6A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                           2
+--R                        a b
+--R                    + 
+--R                                       5                   4
+--R                          (- 16C + 8A)D  + (16B C - 80A B)D
+--R                        + 
+--R                                3        2         2      2          2      3  3
+--R                          (- 12C  + 28A C  + (- 16B  - 68A )C + 32A B  + 20A )D
+--R                        + 
+--R                               3          2      2         3   2
+--R                          (4B C  - 36A B C  + 12A B C - 12A B)D
+--R                        + 
+--R                                4      3 2     5
+--R                          (10A C  - 12A C  + 2A )D
+--R                     *
+--R                         2
+--R                        a b
+--R                    + 
+--R                              2              2  4
+--R                          (16C  - 16A C + 16A )D
+--R                        + 
+--R                                  2                 2   3
+--R                          (- 32B C  + 128A B C - 32A B)D
+--R                        + 
+--R                             4        3      2 2           2      3       4  2
+--R                          (8C  - 32A C  + 48A C  + (- 96A B  - 32A )C + 8A )D
+--R                        + 
+--R                                  3      3            5     3 3     5
+--R                          (32A B C  + 32A B C)D - 4A C  + 8A C  - 4A C
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                             6       5        2             2     2  4
+--R                          - D  + 8B D  + (- 2C  + 32A C - 3B  - 6A )D
+--R                        + 
+--R                                2              2   3
+--R                          (- B C  - 6A B C + 3A B)D
+--R                     *
+--R                         4
+--R                        b
+--R                    + 
+--R                                      5                      4
+--R                          (14C - 46A)D  + (- 30B C + 130A B)D
+--R                        + 
+--R                             3        2      2      2          2      3  3
+--R                          (4C  - 96A C  + (2B  + 12A )C - 18A B  - 48A )D
+--R                        + 
+--R                               3          2      2     2
+--R                          (4B C  + 24A B C  - 12A B C)D
+--R                     *
+--R                           3
+--R                        a b
+--R                    + 
+--R                             6        5        2              2      2  4
+--R                          10D  - 16B D  + (- 6C  + 76A C + 18B  + 58A )D
+--R                        + 
+--R                                2                 3      2   3
+--R                          (24B C  - 240A B C - 16B  - 72A B)D
+--R                        + 
+--R                                4        3       2      2  2         2       3
+--R                              4C  + 64A C  + (18B  + 24A )C  + (60A B  + 128A )C
+--R                            + 
+--R                                 2 2     4
+--R                              18A B  + 4A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 4          3      2   2     3        4
+--R                          (- 5B C  - 28A B C  + 18A B C  + 4A B C - 5A B)D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                                       5                    4
+--R                          (- 24C - 8A)D  + (120B C - 72A B)D
+--R                        + 
+--R                                     3        2         2       2           2
+--R                                - 40C  + 40A C  + (- 48B  - 248A )C + 240A B
+--R                              + 
+--R                                   3
+--R                                56A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                   3          2       3       2           3
+--R                              40B C  - 72A B C  + (48B  + 312A B)C - 16A B
+--R                            + 
+--R                                   3
+--R                              - 88A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2      2  3      3 2
+--R                              - 10C  + 18A C  + (- 16B  - 36A )C  - 92A C
+--R                            + 
+--R                                    2 2      4        5
+--R                              (- 48A B  - 18A )C + 10A
+--R                         *
+--R                            D
+--R                        + 
+--R                            5          4      2   3      3   2      4        5
+--R                        2B C  + 10A B C  - 12A B C  - 12A B C  + 10A B C + 2A B
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                              2      2  4            2                  2   3
+--R                          (16C  + 16A )D  + (- 128B C  + 128A B C - 128A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              32C  - 64A C  + (96B  + 192A )C
+--R                            + 
+--R                                       2      3        2 2      4
+--R                              (- 384A B  - 64A )C + 96A B  + 32A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4           3       2   2
+--R                              - 32B C  + 128A B C  - 192A B C
+--R                            + 
+--R                                     3       3         4
+--R                              (128A B  + 128A B)C - 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            6        5     2 4           2      3  3     4 2
+--R                          4C  - 16A C  - 4A C  + (- 32A B  + 32A )C  - 4A C
+--R                        + 
+--R                                3 2      5       6
+--R                          (- 32A B  - 16A )C + 4A
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       5                     4
+--R                          (- 5C + 59A)D  + (- 10B C - 42A B)D
+--R                        + 
+--R                            3        2      2     2         2      3  3
+--R                          (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                     *
+--R                         5
+--R                        b
+--R                    + 
+--R                               6        5         2               2       2  4
+--R                          - 22D  + 14B D  + (- 14C  - 112A C - 50B  - 162A )D
+--R                        + 
+--R                                2                3       2   3
+--R                          (46B C  + 20A B C + 10B  + 102A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 52A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 68A )C
+--R                         *
+--R                             2
+--R                            D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                                      5                       4
+--R                          (72C + 40A)D  + (- 160B C + 288A B)D
+--R                        + 
+--R                              3        2        2       2           2      3  3
+--R                          (66C  - 46A C  + (144B  + 598A )C - 304A B  - 58A )D
+--R                        + 
+--R                                  3           2         3       2         3   2
+--R                          (- 80B C  + 264A B C  + (- 32B  - 336A B)C + 88A B)D
+--R                        + 
+--R                                5        4       2      2  3        2      3  2
+--R                              5C  - 67A C  + (14B  + 10A )C  + (6A B  + 98A )C
+--R                            + 
+--R                                   2 2    4       3 2      5
+--R                              (- 6A B  + A )C + 2A B  - 15A
+--R                         *
+--R                            D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                 5         2              2  4
+--R                          - 80B D  + (- 64C  - 128A C + 8B )D
+--R                        + 
+--R                                 2                 3       2   3
+--R                          (208B C  - 480A B C - 64B  - 176A B)D
+--R                        + 
+--R                                   4         3          2       2  2
+--R                              - 41C  + 116A C  + (- 144B  - 582A )C
+--R                            + 
+--R                                     2      3       4      2 2      4
+--R                              (672A B  - 12A )C + 8B  + 48A B  - 41A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3       2   2
+--R                              50B C  - 328A B C  + 204A B C
+--R                            + 
+--R                                      3       3         4
+--R                              (- 64A B  - 200A B)C - 14A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              6        5        2     2  4        2      3  3
+--R                          - 2C  + 28A C  + (- 5B  + 2A )C  + (4A B  - 56A )C
+--R                        + 
+--R                              2 2     4  2      3 2      5       4 2     6
+--R                          (18A B  + 2A )C  + (4A B  + 28A )C - 5A B  - 2A
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                                           4
+--R                          (192B C + 64A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 16C  + 208A C  + (- 320B  - 176A )C + 256A B
+--R                            + 
+--R                                  3
+--R                              112A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                   3           2       3        2            3
+--R                              80B C  - 144A B C  + (64B  + 1008A B)C - 320A B
+--R                            + 
+--R                                    3
+--R                              - 304A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5       4         2       2  3
+--R                              - 24C  - 8A C  + (- 16B  + 144A )C
+--R                            + 
+--R                                      2       3  2         4       2 2     4
+--R                              (- 48A B  + 112A )C  + (- 64B  - 432A B  + 8A )C
+--R                            + 
+--R                                     4       3 2      5
+--R                              - 32A B  + 112A B  + 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5          4       3      2   3
+--R                          - 8B C  + 88A B C  + (16B  + 48A B)C
+--R                        + 
+--R                              3      3   2       2 3      4         3 3     5
+--R                        (48A B  + 48A B)C  + (48A B  + 88A B)C + 16A B  - 8A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                   2       2   3
+--R                          (- 128B C  - 128A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              32C  - 128A C  + (384B  + 192A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 384A B  - 128A )C + 384A B  + 32A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3       2   2
+--R                              - 128B C  + 256A B C  + (- 128B  - 768A B)C
+--R                            + 
+--R                                     3       3          2 3       4
+--R                              (512A B  + 256A B)C - 128A B  - 128A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6       2      2  4         2 3
+--R                          16C  + (32B  - 16A )C  - 128A B C
+--R                        + 
+--R                               2 2      4  2           4       3 2        4 2
+--R                          (192A B  - 16A )C  + (- 64A B  - 128A B )C + 32A B
+--R                        + 
+--R                             6
+--R                          16A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            6        5       2              2      2  4
+--R                          6D  - 22B D  + (10C  - 76A C + 18B  + 42A )D
+--R                        + 
+--R                               2               3      2   3
+--R                          (2B C  + 36A B C - 2B  - 30A B)D
+--R                     *
+--R                         6
+--R                        b
+--R                    + 
+--R                                       5                     4
+--R                          (- 18C + 6A)D  + (148B C - 260A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 22C  + 262A C  + (- 34B  - 114A )C + 102A B
+--R                            + 
+--R                                  3
+--R                              114A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                 3           2      3       2     2
+--R                          (- 8B C  - 144A B C  + (8B  + 120A B)C)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                               6         5        2              2       2  4
+--R                          - 15D  + 136B D  + (- 8C  + 48A C - 22B  - 216A )D
+--R                        + 
+--R                                   2                  3       2   3
+--R                          (- 162B C  + 436A B C + 112B  + 486A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 11C  - 268A C  + (- 24B  - 18A )C
+--R                            + 
+--R                                       2       3       4       2 2      4
+--R                              (- 288A B  - 300A )C - 3B  - 120A B  - 27A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3        3       2   2
+--R                              12B C  + 184A B C  + (- 6B  - 144A B)C
+--R                            + 
+--R                                    3      3        2 3      4
+--R                              (12A B  - 24A B)C + 2A B  + 36A B
+--R                         *
+--R                            D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                                      5                       4
+--R                          (56C + 72A)D  + (- 464B C - 208A B)D
+--R                        + 
+--R                              3         2        2       2           2      3  3
+--R                          (84C  - 300A C  + (448B  + 908A )C - 704A B  + 12A )D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 208B C  + 336A B C  + (- 256B  - 1824A B)C
+--R                            + 
+--R                                    3       3
+--R                              256A B  + 448A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5        4       2       2  3
+--R                              48C  + 72A C  + (92B  + 160A )C
+--R                            + 
+--R                                     2       3  2       4       2 2       4
+--R                              (108A B  + 272A )C  + (40B  + 516A B  + 112A )C
+--R                            + 
+--R                                   4      3 2      5
+--R                              24A B  - 12A B  - 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5          4      2   3           3      3   2
+--R                          - 6B C  - 78A B C  + 52A B C  + (- 16A B  + 52A B)C
+--R                        + 
+--R                                2 3      4        5
+--R                          (- 16A B  - 78A B)C - 6A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                2                2      2  4
+--R                          (- 72C  - 240A C + 240B  - 72A )D
+--R                        + 
+--R                                 2                 3      2   3
+--R                          (480B C  + 576A B C + 96B  + 96A B)D
+--R                        + 
+--R                                   4         3          2        2  2
+--R                              - 98C  + 456A C  + (- 768B  - 1068A )C
+--R                            + 
+--R                                      2       3         4      4
+--R                              (1152A B  - 312A )C + 112B  + 30A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3        3        2   2
+--R                              348B C  - 560A B C  + (224B  + 1512A B)C
+--R                            + 
+--R                                       3       3         5      2 3      4
+--R                              (- 704A B  - 304A B)C + 16B  + 96A B  + 92A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               6         2      2  4         2       3  3
+--R                          - 24C  + (- 42B  - 40A )C  + (40A B  - 128A )C
+--R                        + 
+--R                                4       2 2      4  2           4      3 2
+--R                          (- 24B  - 348A B  - 40A )C  + (- 16A B  + 40A B )C
+--R                        + 
+--R                               2 4      4 2      6
+--R                          - 24A B  - 42A B  - 24A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                   3         2          2      2           2
+--R                                32C  + 288A C  + (- 576B  + 96A )C - 192A B
+--R                              + 
+--R                                   3
+--R                                96A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                     3           2        3       2            3
+--R                              - 32B C  - 864A B C  + (320B  + 672A B)C - 448A B
+--R                            + 
+--R                                    3
+--R                              - 544A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              32C  - 256A C  + (160B  + 320A )C
+--R                            + 
+--R                                    2       3  2         4        2 2      4
+--R                              (96A B  + 512A )C  + (- 32B  - 1056A B  - 96A )C
+--R                            + 
+--R                                    4       3 2
+--R                              160A B  + 544A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5          4         3       2   3
+--R                          - 96B C  + 32A B C  + (- 32B  - 192A B)C
+--R                        + 
+--R                                 3       3   2       5       2 3      4
+--R                          (160A B  - 192A B)C  + (32B  + 160A B  + 32A B)C
+--R                        + 
+--R                               5      3 3      5
+--R                          32A B  - 32A B  - 96A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                   3       2 2       3        2 2  2
+--R                          (- 128A C  + 384B C  - 128A C + 384A B )D
+--R                        + 
+--R                                      4           3          3       2   2
+--R                              - 128B C  + 512A B C  + (- 512B  - 768A B)C
+--R                            + 
+--R                                     3       3          2 3       4
+--R                              (512A B  + 512A B)C - 512A B  - 128A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5       2 4            2       3  3
+--R                          64A C  + 128B C  + (- 256A B  - 128A )C
+--R                        + 
+--R                              4       2 2  2            4       3 2      5
+--R                          (64B  + 768A B )C  + (- 256A B  - 256A B  + 64A )C
+--R                        + 
+--R                             2 4       4 2
+--R                          64A B  + 128A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                     5                  4
+--R                          (4C - 60A)D  + (8B C + 72A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  3
+--R                          (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                     *
+--R                         7
+--R                        b
+--R                    + 
+--R                             6        5                2       2  4
+--R                          32D  - 48B D  + (208A C + 64B  + 336A )D
+--R                        + 
+--R                                   2                3       2   3
+--R                          (- 112B C  - 64A B C - 48B  - 336A B)D
+--R                        + 
+--R                            4        3       2      2  2         2       3    2
+--R                        (16C  - 80A C  + (48B  + 48A )C  + (48A B  + 144A )C)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                                          5                    4
+--R                          (- 145C - 177A)D  + (180B C + 84A B)D
+--R                        + 
+--R                                   3         2          2        2           2
+--R                              - 54C  - 178A C  + (- 458B  - 1442A )C + 470A B
+--R                            + 
+--R                                    3
+--R                              - 294A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2           3
+--R                              332B C  - 348A B C  + (140B  + 1188A B)C - 20A B
+--R                            + 
+--R                                    3
+--R                              - 180A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4         2      2  3
+--R                              - 21C  + 103A C  + (- 66B  - 50A )C
+--R                            + 
+--R                                      2       3  2        4     2 2     4
+--R                              (- 54A B  - 210A )C  + (- 5B  - 6A B  - 9A )C
+--R                            + 
+--R                                    4      3 2      5
+--R                              - 5A B  - 18A B  + 27A
+--R                         *
+--R                            D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                               5        2                2       2  4
+--R                          60B D  + (213C  + 794A C - 280B  + 261A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 164B C  - 392A B C - 48B  + 348A B)D
+--R                        + 
+--R                                  4        3        2        2  2
+--R                              118C  - 56A C  + (870B  + 2100A )C
+--R                            + 
+--R                                       2        3         4       2 2     4
+--R                              (- 900A B  + 1256A )C - 104B  - 426A B  + 6A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 352B C  + 480A B C  + (- 124B  - 1056A B)C
+--R                            + 
+--R                                     3       3         5      2 3
+--R                              (104A B  + 160A B)C - 12B  - 92A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            6        5       2     2  4         2       3  3
+--R                          9C  - 42A C  + (30B  + 7A )C  + (24A B  + 116A )C
+--R                        + 
+--R                             4      2 2     4  2         4      3 2      5
+--R                          (5B  - 12A B  + 7A )C  + (10A B  + 24A B  - 42A )C
+--R                        + 
+--R                            2 4      4 2     6
+--R                          5A B  + 30A B  + 9A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                              4
+--R                          (- 224B C - 288A B)D
+--R                        + 
+--R                                   3          2        2       2           2
+--R                              - 24C  - 1432A C  + (992B  - 712A )C + 352A B
+--R                            + 
+--R                                    3
+--R                              - 328A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 144B C  + 816A B C  + (- 320B  - 1776A B)C
+--R                            + 
+--R                                    3       3
+--R                              832A B  + 336A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4          2        2  3
+--R                              - 92C  + 100A C  + (- 488B  - 1208A )C
+--R                            + 
+--R                                       2        3  2
+--R                              (- 168A B  - 1560A )C
+--R                            + 
+--R                                   4        2 2       4          4       3 2
+--R                              (176B  + 1608A B  - 172A )C - 16A B  - 760A B
+--R                            + 
+--R                                   5
+--R                              - 12A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5           4       3       2   3
+--R                          120B C  - 104A B C  + (16B  + 112A B)C
+--R                        + 
+--R                                  3       3   2         2 3       4         3 3
+--R                          (- 16A B  + 112A B)C  + (- 16A B  - 104A B)C + 16A B
+--R                        + 
+--R                              5
+--R                          120A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                 2                  3       2   3
+--R                          (288B C  + 960A B C - 320B  + 288A B)D
+--R                        + 
+--R                                    4          3           2       2  2
+--R                              - 236C  + 1264A C  + (- 1152B  + 696A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 768A B  + 496A )C - 208B  - 384A B  + 276A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3        3        2   2
+--R                              280B C  - 608A B C  + (768B  + 2064A B)C
+--R                            + 
+--R                                        3      3         5       2 3      4
+--R                              (- 1280A B  - 96A B)C - 96B  + 256A B  + 24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5      2       2  4          2       3  3
+--R                          24C  - 16A C  + (4B  + 232A )C  + (560A B  + 544A )C
+--R                        + 
+--R                                4       2 2       4  2
+--R                          (- 96B  - 936A B  + 232A )C
+--R                        + 
+--R                                 4       3 2      5        6      2 4     4 2
+--R                          (192A B  + 560A B  - 16A )C - 16B  - 96A B  + 4A B
+--R                        + 
+--R                             6
+--R                          24A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                      3            2        3       2
+--R                              - 128B C  - 1152A B C  + (768B  - 384A B)C
+--R                            + 
+--R                                    3       3
+--R                              256A B  - 384A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  5         4        2       2  3         2 2
+--R                              224C  - 512A C  + (320B  - 320A )C  + 960A B C
+--R                            + 
+--R                                     2 2       4           4       3 2
+--R                              (- 576A B  - 416A )C + 384A B  + 832A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5          4          3       2   3
+--R                          - 96B C  + 32A B C  + (- 320B  - 448A B)C
+--R                        + 
+--R                                3       3   2       2 3      4          3 3
+--R                          (64A B  - 448A B)C  + (64A B  + 32A B)C - 320A B
+--R                        + 
+--R                               5
+--R                          - 96A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                   3       3 2       3          2 3        6
+--R                          (512A B C  - 512B C  + 512A B C - 512A B )D - 64C
+--R                        + 
+--R                               5        2      2  4            2       3  3
+--R                          64A C  + (128B  + 64A )C  + (- 512A B  - 128A )C
+--R                        + 
+--R                               4       2 2      4  2
+--R                          (256B  + 768A B  + 64A )C
+--R                        + 
+--R                                 4       3 2      5         2 4       4 2      6
+--R                        (- 256A B  - 512A B  + 64A )C + 256A B  + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                          6        5        2              2      2  4
+--R                      - 8D  + 24B D  + (- 8C  + 48A C - 24B  - 72A )D
+--R                    + 
+--R                           2               3      2   3
+--R                      (8B C  - 48A B C + 8B  + 72A B)D
+--R                 *
+--R                     8
+--R                    b
+--R                + 
+--R                                   5                      4
+--R                      (24C + 120A)D  + (- 144B C - 48A B)D
+--R                    + 
+--R                          3         2        2       2          2      3  3
+--R                      (40C  - 232A C  + (152B  + 312A )C - 72A B  + 72A )D
+--R                    + 
+--R                              3           2         3       2     2
+--R                      (- 32B C  + 192A B C  + (- 32B  - 288A B)C)D
+--R                 *
+--R                       7
+--R                    a b
+--R                + 
+--R                           6        5       2               2       2  4
+--R                      - 10D  - 78B D  + (28C  - 648A C + 84B  - 228A )D
+--R                    + 
+--R                             2                 3      2   3
+--R                      (332B C  + 312A B C - 20B  - 84A B)D
+--R                    + 
+--R                               4         3          2       2  2
+--R                          - 74C  + 408A C  + (- 324B  - 444A )C
+--R                        + 
+--R                                 2       3        4       2 2      4
+--R                          (120A B  - 360A )C + 22B  + 252A B  + 54A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          42B C  - 248A B C  + (44B  + 348A B)C
+--R                        + 
+--R                                 3      3        5      2 3      4
+--R                          (- 8A B  + 72A B)C + 2B  + 12A B  - 54A B
+--R                     *
+--R                        D
+--R                 *
+--R                     2 6
+--R                    a b
+--R                + 
+--R                                  5                     4
+--R                      (84C - 12A)D  + (414B C + 318A B)D
+--R                    + 
+--R                                3          2          2       2           2
+--R                          - 208C  + 1424A C  + (- 376B  + 912A )C - 216A B
+--R                        + 
+--R                              3
+--R                          304A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3           2        3       2            3
+--R                          - 356B C  - 780A B C  + (196B  + 468A B)C - 348A B
+--R                        + 
+--R                                3
+--R                          - 132A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5         4        2       2  3
+--R                          60C  - 308A C  + (272B  + 216A )C
+--R                        + 
+--R                                 2       3  2         4       2 2      4
+--R                          (144A B  + 536A )C  + (- 60B  - 912A B  - 84A )C
+--R                        + 
+--R                              4       3 2      5
+--R                          4A B  + 240A B  - 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4         3       2   3
+--R                      - 18B C  + 102A B C  + (- 20B  - 116A B)C
+--R                    + 
+--R                           3       3   2        5     2 3       4          5
+--R                      (4A B  - 116A B)C  + (- 2B  + 4A B  + 102A B)C - 2A B
+--R                    + 
+--R                           3 3      5
+--R                      - 20A B  - 18A B
+--R                 *
+--R                     3 5
+--R                    a b
+--R                + 
+--R                             2              2      2  4
+--R                      (- 290C  + 60A C - 60B  + 30A )D
+--R                    + 
+--R                               2                   3       2   3
+--R                      (- 880B C  - 1344A B C + 192B  - 528A B)D
+--R                    + 
+--R                              4          3        2        2  2
+--R                          340C  - 1584A C  + (612B  - 1416A )C
+--R                        + 
+--R                                 2       3        4      2 2       4
+--R                          (840A B  - 816A )C + 88B  + 36A B  - 300A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3          3       2   2         3
+--R                          168B C  + 832A B C  + (- 400B  - 624A B)C  + 832A B C
+--R                        + 
+--R                             5       2 3       4
+--R                          32B  + 144A B  + 264A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6        5         2      2  4
+--R                      - 18C  + 84A C  + (- 72B  - 14A )C
+--R                    + 
+--R                               2       3  3       4       2 2      4  2
+--R                      (- 224A B  - 232A )C  + (46B  + 720A B  - 14A )C
+--R                    + 
+--R                            4       3 2      5       6      2 4      4 2      6
+--R                    (- 36A B  - 224A B  + 84A )C + 4B  + 46A B  - 72A B  - 18A
+--R                 *
+--R                     4 4
+--R                    a b
+--R                + 
+--R                           3         2        2       2           2      3  3
+--R                      (528C  - 112A C  + (224B  - 144A )C + 288A B  - 16A )D
+--R                    + 
+--R                                3            2          3        2            3
+--R                          928B C  + 2208A B C  + (- 704B  + 1440A B)C - 192A B
+--R                        + 
+--R                              3
+--R                          672A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5         4          2        2  3
+--R                          - 240C  + 880A C  + (- 400B  + 1056A )C
+--R                        + 
+--R                                    2       3  2         4       2 2       4
+--R                          (- 1296A B  + 608A )C  + (- 96B  + 528A B  + 720A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 416A B  - 624A B  + 48A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4        3       2   3
+--R                      - 24B C  - 312A B C  + (224B  + 208A B)C
+--R                    + 
+--R                               3       3   2         5       2 3       4
+--R                      (- 416A B  + 208A B)C  + (- 32B  - 416A B  - 312A B)C
+--R                    + 
+--R                             5       3 3      5
+--R                      - 32A B  + 224A B  - 24A B
+--R                 *
+--R                     5 3
+--R                    a b
+--R                + 
+--R                                4        3          2       2  2
+--R                          - 536C  + 96A C  + (- 288B  + 240A )C
+--R                        + 
+--R                                   2      3         4       2 2      4
+--R                          (- 960A B  + 96A )C + 160B  - 288A B  - 24A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3        3        2   2
+--R                          - 480B C  - 1664A B C  + (896B  - 1344A B)C
+--R                        + 
+--R                                 3        3          5       2 3       4
+--R                          (256A B  - 1152A B)C + 128B  + 384A B  - 480A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6         5       2       2  4          2       3  3
+--R                      64C  - 192A C  + (72B  - 320A )C  + (736A B  - 128A )C
+--R                    + 
+--R                            4       2 2       4  2
+--R                      (- 32B  - 720A B  - 320A )C
+--R                    + 
+--R                           4       3 2       5        6      2 4      4 2      6
+--R                    (576A B  + 736A B  - 192A )C + 32B  - 32A B  + 72A B  + 64A
+--R                 *
+--R                     6 2
+--R                    a b
+--R                + 
+--R                              5        4        2       2  3
+--R                          288C  - 32A C  + (128B  - 192A )C
+--R                        + 
+--R                                  2      3  2          4       2 2      4
+--R                          (1152A B  - 64A )C  + (- 384B  + 384A B  - 96A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 128A B  + 384A B  + 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4          3       2   3
+--R                      96B C  + 480A B C  + (- 384B  + 448A B)C
+--R                    + 
+--R                               3       3   2          5       2 3       4
+--R                      (- 128A B  + 448A B)C  + (- 128B  - 128A B  + 480A B)C
+--R                    + 
+--R                              5       3 3      5
+--R                      - 128A B  - 384A B  + 96A B
+--R                 *
+--R                     7
+--R                    a b
+--R                + 
+--R                           6      2 4         2 3        4      4  2       3 2
+--R                      - 64C  + 64A C  - 512A B C  + (256B  + 64A )C  - 512A B C
+--R                    + 
+--R                          2 4      6
+--R                      256A B  - 64A
+--R                 *
+--R                     8
+--R                    a
+--R             *
+--R                x
+--R            + 
+--R                       4     3 3    7
+--R              (- 8A B D  - 4A D )a c
+--R            + 
+--R                      5         4  2
+--R                  (A D  + 2A B D )b
+--R                + 
+--R                         5             2     2  4               2   3     3   2
+--R                    (2B D  + (6A C + 4B  + 8A )D  + (8A B C + 6A B)D  + 6A C D )
+--R                 *
+--R                    a b
+--R                + 
+--R                          5                  4       2         2      3  3
+--R                      8A D  + (4B C - 32A B)D  + (12A C + 44A B  - 16A )D
+--R                    + 
+--R                         3   2        3 2     5
+--R                      12A B D  + (- 4A C  - 4A )D
+--R                 *
+--R                     2
+--R                    a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                        5              2     2  4           3  3
+--R                  (- B D  + (- 4A C - B  - 2A )D  - 2A B C D )b
+--R                + 
+--R                                  5                     4
+--R                      (- 3C - 8A)D  + (- 12B C + 73A B)D
+--R                    + 
+--R                             2        2      2          2      3  3
+--R                      (- 2A C  + (- 4B  - 14A )C - 22A B  + 39A )D
+--R                    + 
+--R                           2        3   2        3 2     5
+--R                      (- 9A B C - 6A B)D  + (- 2A C  + 2A )D
+--R                 *
+--R                       2
+--R                    a b
+--R                + 
+--R                          6       5        2            2  4
+--R                      - 2D  - 6B D  + (- 2C  - 2A C - 2B )D
+--R                    + 
+--R                           2                3      2   3
+--R                      (4B C  - 68A B C - 22B  - 96A B)D
+--R                    + 
+--R                             3      2 2           2     3        2 2      4  2
+--R                      (- 4A C  - 18A C  + (- 42A B  + 8A )C - 18A B  - 22A )D
+--R                    + 
+--R                               3     2   2     3         4        3 3     5
+--R                      (- 8A B C  + 6A B C  - 4A B C + 10A B)D + 2A C  - 2A C
+--R                 *
+--R                     2
+--R                    a b
+--R                + 
+--R                                   5                   4
+--R                      (- 4C + 32A)D  + (16B C - 44A B)D
+--R                    + 
+--R                              2         2      2           2     3  3
+--R                      (- 12A C  + (- 28B  + 48A )C + 176A B  + 4A )D
+--R                    + 
+--R                             3      2           3      3   2
+--R                      (- 8B C  - 24A B C - 84A B  + 48A B)D
+--R                    + 
+--R                          2 3         2      3  2      4       3 2      5
+--R                      (12A C  + (12A B  - 16A )C  + 36A C - 20A B  - 16A )D
+--R                    + 
+--R                            4     3   2     5
+--R                      8A B C  + 4A B C  + 4A B
+--R                 *
+--R                     3
+--R                    a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                               5                  4
+--R                      (C - 6A)D  + (4B C - 14A B)D
+--R                    + 
+--R                           2     2     2         2    3  3
+--R                      (3A C  + (B  + 2A )C + 2A B  - A )D
+--R                 *
+--R                     4
+--R                    b
+--R                + 
+--R                        6       5       2              2      2  4
+--R                      4D  - 6B D  + (10C  - 39A C - 24B  - 57A )D
+--R                    + 
+--R                           2                3     2   3
+--R                      (6B C  - 34A B C + 10B  - 6A B)D
+--R                    + 
+--R                             3     2 2         2      3       2 2     4  2
+--R                      (- 4A C  + 9A C  + (15A B  - 44A )C + 9A B  + 7A )D
+--R                    + 
+--R                             3     2   2     3        4
+--R                      (2A B C  + 3A B C  + 4A B C - 5A B)D
+--R                 *
+--R                       3
+--R                    a b
+--R                + 
+--R                                  5                      4
+--R                      (12C - 77A)D  + (- 27B C + 196A B)D
+--R                    + 
+--R                            3        2       2     2           2       3  3
+--R                      (- 10C  + 60A C  + (72B  - 4A )C - 297A B  + 118A )D
+--R                    + 
+--R                                  3           2       3       2           3
+--R                            - 4B C  + 120A B C  + (21B  + 126A B)C + 72A B
+--R                          + 
+--R                                 3
+--R                            - 76A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4      2     2  3         2      3  2
+--R                          13A C  + (4B  + 8A )C  + (24A B  + 29A )C
+--R                        + 
+--R                             2 2      4       3 2      5
+--R                          (6A B  - 14A )C + 4A B  + 40A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4     2   3     3   2     4
+--R                      - 2A B C  - 3A B C  - 4A B C  + 5A B C
+--R                 *
+--R                     2 2
+--R                    a b
+--R                + 
+--R                        6        5        2              2      2  4
+--R                      2D  - 24B D  + (- 6C  + 20A C + 28B  - 10A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (90B C  - 76A B C - 24B  - 226A B)D
+--R                    + 
+--R                             4        3       2      2  2          2      3
+--R                          12C  + 22A C  + (30B  - 42A )C  + (108A B  + 14A )C
+--R                        + 
+--R                             4       2 2      4
+--R                          42B  + 282A B  - 94A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4          3        3      2   2
+--R                          18B C  - 84A B C  + (- 6B  + 24A B)C
+--R                        + 
+--R                                3      3         2 3      4
+--R                          (36A B  - 36A B)C + 30A B  + 54A B
+--R                     *
+--R                        D
+--R                    + 
+--R                             5        2      2  4           2     3  3     2 2 2
+--R                      - 10A C  + (- 4B  - 14A )C  + (- 30A B  + 4A )C  - 6A B C
+--R                    + 
+--R                           3 2      5        4 2     6
+--R                      (- 6A B  - 10A )C - 10A B  - 2A
+--R                 *
+--R                     3
+--R                    a b
+--R                + 
+--R                                   5                   4
+--R                      (- 16C + 8A)D  + (40B C - 48A B)D
+--R                    + 
+--R                          3        2          2      2           2      3  3
+--R                      (12C  - 48A C  + (- 112B  - 12A )C + 104A B  + 80A )D
+--R                    + 
+--R                              3          2       3      2            3     3   2
+--R                      (- 32B C  + 12A B C  + (72B  - 96A B)C - 336A B  + 4A B)D
+--R                    + 
+--R                                 4      2      2  3         2      3  2
+--R                          - 20A C  + (4B  + 48A )C  + (48A B  - 96A )C
+--R                        + 
+--R                              2 2       4          4      3 2      5
+--R                          (12A B  + 144A )C + 64A B  - 80A B  - 12A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5          4      2   3           3      3   2
+--R                      - 12B C  + 32A B C  - 48A B C  + (- 12A B  + 16A B)C
+--R                    + 
+--R                           4         3 3      5
+--R                      - 36A B C + 12A B  + 16A B
+--R                 *
+--R                     4
+--R                    a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                         6       5        2             2      2  4
+--R                      - D  + 5B D  + (- 3C  + 26A C + 5B  + 13A )D
+--R                    + 
+--R                             2              3     2   3
+--R                      (- 3B C  + 10A B C - B  - 3A B)D
+--R                 *
+--R                     5
+--R                    b
+--R                + 
+--R                                 5                    4
+--R                      (2C + 73A)D  + (62B C - 213A B)D
+--R                    + 
+--R                           3       2        2      2           2       3  3
+--R                      (- 3C  - 2A C  + (- 2B  + 62A )C + 123A B  - 155A )D
+--R                    + 
+--R                           3          2        3      2           3      3   2
+--R                      (4B C  - 27A B C  + (- 6B  + 24A B)C - 15A B  + 31A B)D
+--R                    + 
+--R                                4       2     2  3          2      3  2
+--R                          - 2A C  + (- B  - 5A )C  + (- 9A B  + 13A )C
+--R                        + 
+--R                               2 2    4       3 2      5
+--R                          (- 6A B  + A )C + 2A B  - 15A
+--R                     *
+--R                        D
+--R                 *
+--R                       4
+--R                    a b
+--R                + 
+--R                        6        5       2              2      2  4
+--R                      4D  + 67B D  + (23C  + 23A C + 17B  + 67A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 110B C  + 304A B C + 113B  + 663A B)D
+--R                    + 
+--R                            4        3         2     2  2        2      3
+--R                          8C  - 68A C  + (- 66B  + 6A )C  + (9A B  - 15A )C
+--R                        + 
+--R                               4       2 2       4
+--R                          - 33B  - 108A B  + 191A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4         3         3       2   2
+--R                          - 15B C  + 8A B C  + (- 13B  - 123A B)C
+--R                        + 
+--R                                  3      3         2 3       4
+--R                          (- 48A B  + 40A B)C - 16A B  - 102A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          5     2     2  4        2      3  3      2 2    4  2
+--R                      2A C  + (B  + 5A )C  + (9A B  - 13A )C  + (6A B  - A )C
+--R                    + 
+--R                           3 2      5
+--R                      (- 2A B  + 15A )C
+--R                 *
+--R                     2 3
+--R                    a b
+--R                + 
+--R                                   5                      4
+--R                      (56C - 106A)D  + (- 194B C - 18A B)D
+--R                    + 
+--R                            3        2       2       2           2       3  3
+--R                      (- 86C  - 85A C  + (90B  - 174A )C - 594A B  - 207A )D
+--R                    + 
+--R                                 3           2          3       2            3
+--R                          - 83B C  - 138A B C  + (- 198B  - 333A B)C + 418A B
+--R                        + 
+--R                                3
+--R                          - 438A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5        4         2      2  3
+--R                          - 23C  + 62A C  + (- 22B  - 60A )C
+--R                        + 
+--R                                  2      3  2         4       2 2       4
+--R                          (- 99A B  + 66A )C  + (- 18B  - 246A B  - 349A )C
+--R                        + 
+--R                                 4       3 2      5
+--R                          - 76A B  + 111A B  + 16A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4       3      2   3         3      3   2
+--R                      12B C  + 3A B C  + (15B  + 90A B)C  + (42A B  - 28A B)C
+--R                    + 
+--R                         2 3      4        3 3      5
+--R                      (9A B  + 42A B)C + 6A B  - 23A B
+--R                 *
+--R                     3 2
+--R                    a b
+--R                + 
+--R                         6        5         2                2       2  4
+--R                      24D  - 32B D  + (- 82C  + 108A C + 144B  + 134A )D
+--R                    + 
+--R                            2                 3       2   3
+--R                      (80B C  + 352A B C - 32B  + 160A B)D
+--R                    + 
+--R                            4         3       2 2          2       3        4
+--R                          4C  + 152A C  - 132B C  + (216A B  + 312A )C + 56B
+--R                        + 
+--R                              2 2      4
+--R                          732A B  - 20A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3         3       2   2
+--R                          112B C  - 144A B C  + (- 48B  + 240A B)C
+--R                        + 
+--R                                  3      3         5       2 3      4
+--R                          (- 96A B  - 16A B)C - 32B  - 256A B  + 96A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6       5       2      2  4        2      3  3
+--R                      14C  - 4A C  + (36B  + 18A )C  + (8A B  + 40A )C
+--R                    + 
+--R                         4       2 2      4  2          4     3 2      5
+--R                      (6B  + 144A B  + 34A )C  + (- 4A B  + 8A B  + 28A )C
+--R                    + 
+--R                           2 4      4 2     6
+--R                      - 18A B  - 36A B  - 2A
+--R                 *
+--R                     4
+--R                    a b
+--R                + 
+--R                                    5                   4
+--R                      (- 16C - 96A)D  + (96B C + 48A B)D
+--R                    + 
+--R                          3          2       2           2      3  3
+--R                      (48C  + (- 160B  - 240A )C - 288A B  + 64A )D
+--R                    + 
+--R                              2       3          3       3   2
+--R                      (48A B C  + 288B C - 160A B  - 176A B)D
+--R                    + 
+--R                             5        4       2       2  3       3 2
+--R                          16C  - 80A C  + (16B  + 160A )C  - 320A C
+--R                        + 
+--R                                4      2 2      4           4      5
+--R                          (- 80B  + 48A B  + 80A )C + 256A B  + 16A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5          4       2   3           3       3   2
+--R                      - 48B C  + 80A B C  - 192A B C  + (- 48A B  + 160A B)C
+--R                    + 
+--R                            4           5      3 3      5
+--R                      - 144A B C - 16A B  + 48A B  + 16A B
+--R                 *
+--R                     5
+--R                    a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                                  5                     4
+--R                      (- 2C + 6A)D  + (- 20B C + 28A B)D
+--R                    + 
+--R                         3        2        2      2          2      3  3
+--R                      (2C  - 18A C  + (- 2B  - 10A )C - 10A B  + 10A )D
+--R                 *
+--R                     6
+--R                    b
+--R                + 
+--R                           6        5         2              2      2  4
+--R                      - 16D  - 26B D  + (- 46C  + 22A C + 34B  + 94A )D
+--R                    + 
+--R                             2                3      2   3
+--R                      (- 6B C  + 28A B C - 46B  - 96A B)D
+--R                    + 
+--R                              4        3       2      2  2           2       3
+--R                          - 4C  + 46A C  + (12B  - 24A )C  + (- 30A B  + 102A )C
+--R                        + 
+--R                            4      2 2      4
+--R                          6B  - 12A B  - 48A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              4         3      3     2   2         3      3
+--R                          2B C  + 4A B C  + (4B  + 6A B)C  + (12A B  - 24A B)C
+--R                        + 
+--R                            2 3      4
+--R                          2A B  + 36A B
+--R                     *
+--R                        D
+--R                 *
+--R                       5
+--R                    a b
+--R                + 
+--R                                      5                    4
+--R                      (- 109C + 110A)D  + (14B C - 254A B)D
+--R                    + 
+--R                          3         2          2       2           2       3  3
+--R                      (82C  - 100A C  + (- 278B  - 256A )C + 412A B  - 176A )D
+--R                    + 
+--R                                3           2       3       2            3
+--R                          126B C  - 282A B C  + (38B  - 312A B)C - 214A B
+--R                        + 
+--R                              3
+--R                          222A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5        4       2      2  3         2      3  2
+--R                          11C  - 60A C  + (30B  + 12A )C  + (24A B  - 48A )C
+--R                        + 
+--R                              4       2 2       4          4      3 2      5
+--R                          (23B  + 168A B  + 117A )C + 34A B  + 12A B  - 72A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5         4        3     2   3
+--R                      - 2B C  - 4A B C  + (- 4B  - 6A B)C
+--R                    + 
+--R                              3      3   2        2 3      4
+--R                      (- 12A B  + 24A B)C  + (- 2A B  - 36A B)C
+--R                 *
+--R                     2 4
+--R                    a b
+--R                + 
+--R                           6        5        2             2       2  4
+--R                      - 65D  + 63B D  + (178C  + A C - 236B  - 113A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (48B C  - 68A B C + 40B  + 186A B)D
+--R                    + 
+--R                             4        3        2       2  2
+--R                          71C  - 52A C  + (432B  + 414A )C
+--R                        + 
+--R                                   2      3         4        2 2       4
+--R                          (- 120A B  + 74A )C - 139B  - 1278A B  + 369A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4           3        3       2   2
+--R                          - 83B C  + 452A B C  + (158B  + 168A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (140A B  + 548A B)C + 33B  + 168A B  - 109A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6        5         2      2  4         2      3  3
+--R                      - 8C  + 29A C  + (- 32B  + 13A )C  + (14A B  - 44A )C
+--R                    + 
+--R                            4       2 2      4  2           4     3 2     5
+--R                      (- 20B  - 144A B  - 24A )C  + (- 17A B  - 4A B  + 7A )C
+--R                    + 
+--R                       2 4      4 2      6
+--R                      A B  + 58A B  + 11A
+--R                 *
+--R                     3 3
+--R                    a b
+--R                + 
+--R                                    5                      4
+--R                      (138C + 222A)D  + (- 90B C - 282A B)D
+--R                    + 
+--R                          3         2        2       2           2       3  3
+--R                      (92C  - 174A C  + (576B  + 348A )C + 672A B  - 458A )D
+--R                    + 
+--R                               3           2          3       2            3
+--R                          94B C  + 180A B C  + (- 360B  - 222A B)C + 592A B
+--R                        + 
+--R                             3
+--R                          44A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5        4          2       2  3
+--R                          - 116C  + 66A C  + (- 180B  - 396A )C
+--R                        + 
+--R                                2       3  2        4       2 2       4
+--R                          (30A B  + 544A )C  + (198B  + 156A B  - 304A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 206A B  + 650A B  - 82A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5           4         3      2   3
+--R                      6B C  - 256A B C  + (- 86B  + 48A B)C
+--R                    + 
+--R                              3       3   2      5      2 3       4           5
+--R                      (- 20A B  - 396A B)C  + (2B  - 26A B  + 218A B)C + 26A B
+--R                    + 
+--R                           3 3      5
+--R                      - 44A B  - 36A B
+--R                 *
+--R                     4 2
+--R                    a b
+--R                + 
+--R                         6        5          2                2      2  4
+--R                      24D  - 96B D  + (- 132C  - 216A C + 120B  + 60A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 240B C  + 288A B C - 224B  + 240A B)D
+--R                    + 
+--R                                4         3          2       2  2
+--R                          - 192C  + 160A C  + (- 408B  - 576A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 816A B  + 448A )C - 24B  - 504A B  + 256A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3        3       2   2
+--R                          48B C  - 256A B C  + (208B  + 192A B)C
+--R                        + 
+--R                                  3       3         5       2 3       4
+--R                          (- 32A B  - 320A B)C - 32B  - 816A B  - 112A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6       5       2      2  4         2      3  3
+--R                      28C  - 8A C  + (80B  + 68A )C  + (32A B  - 80A )C
+--R                    + 
+--R                          4       2 2      4  2         4       3 2      5
+--R                      (28B  + 192A B  - 92A )C  + (40A B  - 160A B  + 88A )C
+--R                    + 
+--R                        6      2 4      4 2     6
+--R                      8B  + 60A B  - 16A B  - 4A
+--R                 *
+--R                     5
+--R                    a b
+--R                + 
+--R                             5                    4
+--R                      - 96A D  + (96B C + 384A B)D
+--R                    + 
+--R                             2          2       2           2      3  3
+--R                      (192A C  + (- 192B  - 192A )C - 384A B  - 64A )D
+--R                    + 
+--R                             3        3       2            3       3   2
+--R                      (128B C  + (320B  + 384A B)C + 704A B  - 192A B)D
+--R                    + 
+--R                             5         4       2 3            2       3  2
+--R                          64C  - 160A C  + 448A C  + (- 192A B  - 256A )C
+--R                        + 
+--R                                 4       4           4       3 2      5
+--R                          (- 320B  - 256A )C + 160A B  + 320A B  + 32A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4       2   3       3   2
+--R                      - 32B C  + 192A B C  - 320A B C  + 576A B C
+--R                    + 
+--R                          5       4           5
+--R                      (32B  - 160A B)C - 64A B
+--R                 *
+--R                     6
+--R                    a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                        6       5       2             2      2  4
+--R                      4D  - 4B D  + (12C  - 40A C - 4B  - 20A )D
+--R                    + 
+--R                            2              3      2   3
+--R                      (12B C  - 8A B C + 4B  + 12A B)D
+--R                 *
+--R                     7
+--R                    b
+--R                + 
+--R                                   5                      4
+--R                      (59C - 145A)D  + (- 28B C + 224A B)D
+--R                    + 
+--R                          3        2       2      2           2       3  3
+--R                      (10C  + 34A C  + (66B  - 30A )C - 146A B  + 250A )D
+--R                    + 
+--R                              3          2      3      2           3      3   2
+--R                      (- 36B C  + 48A B C  + (4B  - 12A B)C + 40A B  - 48A B)D
+--R                    + 
+--R                             5       4        2      2  3        2      3  2
+--R                          - C  + 3A C  + (- 6B  + 10A )C  + (6A B  - 30A )C
+--R                        + 
+--R                               4     2 2     4         4      3 2      5
+--R                          (- 5B  - 6A B  - 9A )C - 5A B  - 18A B  + 27A
+--R                     *
+--R                        D
+--R                 *
+--R                       6
+--R                    a b
+--R                + 
+--R                         6        5         2              2       2  4
+--R                      78D  - 54B D  + (- 23C  - 15A C + 60B  - 156A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (180B C  - 188A B C - 92B  - 924A B)D
+--R                    + 
+--R                                4         3         2      2  2
+--R                          - 108C  + 142A C  + (- 78B  + 66A )C
+--R                        + 
+--R                                 2       3        4       2 2       4
+--R                          (186A B  - 186A )C + 86B  + 540A B  - 450A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4          3         3       2   2
+--R                          18B C  - 44A B C  + (- 52B  + 156A B)C
+--R                        + 
+--R                                  3       3         5      2 3       4
+--R                          (- 20A B  - 324A B)C - 14B  - 68A B  + 162A B
+--R                     *
+--R                        D
+--R                    + 
+--R                       6       5      2      2  4          2      3  3
+--R                      C  - 3A C  + (6B  - 10A )C  + (- 6A B  + 30A )C
+--R                    + 
+--R                         4     2 2     4  2        4      3 2      5
+--R                      (5B  + 6A B  + 9A )C  + (5A B  + 18A B  - 27A )C
+--R                 *
+--R                     2 5
+--R                    a b
+--R                + 
+--R                                    5                     4
+--R                      (- 77C - 89A)D  + (379B C + 883A B)D
+--R                    + 
+--R                                  3         2          2       2          2
+--R                            - 222C  + 542A C  + (- 114B  + 570A )C + 50A B
+--R                          + 
+--R                                3
+--R                            998A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3           2        3        2            3
+--R                          - 322B C  - 102A B C  + (318B  + 1602A B)C - 190A B
+--R                        + 
+--R                              3
+--R                          862A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4         2      2  3
+--R                          123C  - 173A C  + (- 42B  + 42A )C
+--R                        + 
+--R                                   2       3  2          4      2 2       4
+--R                          (- 354A B  - 366A )C  + (- 161B  + 30A B  + 523A )C
+--R                        + 
+--R                               4       3 2       5
+--R                          55A B  - 722A B  + 203A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4       3       2   3
+--R                      3B C  + 15A B C  + (34B  - 130A B)C
+--R                    + 
+--R                             3       3   2      5      2 3      4          5
+--R                      (- 6A B  + 246A B)C  + (7B  + 46A B  - 97A B)C - 5A B
+--R                    + 
+--R                           3 3      5
+--R                      - 34A B  + 27A B
+--R                 *
+--R                     3 4
+--R                    a b
+--R                + 
+--R                           6        5          2               2       2  4
+--R                      - 62D  + 76B D  + (- 238C  + 28A C - 386B  - 346A )D
+--R                    + 
+--R                               2                   3        2   3
+--R                      (- 576B C  - 2048A B C + 204B  - 1236A B)D
+--R                    + 
+--R                              4         3        2       2  2
+--R                          206C  - 664A C  + (108B  - 132A )C
+--R                        + 
+--R                                  2        3        4       2 2       4
+--R                          (- 36A B  - 2012A )C + 10B  + 108A B  - 830A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3          3        2   2
+--R                          76B C  + 384A B C  + (- 212B  - 1188A B)C
+--R                        + 
+--R                                   3        3         5       2 3       4
+--R                          (- 288A B  - 1088A B)C + 40B  + 888A B  - 488A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6        5       2      2  4          2       3  3
+--R                      - 38C  + 40A C  + (38B  - 18A )C  + (276A B  + 148A )C
+--R                    + 
+--R                          4       2 2      4  2        4       3 2       5
+--R                      (46B  - 156A B  + 50A )C  + (8A B  + 144A B  - 204A )C
+--R                    + 
+--R                           6      2 4      4 2      6
+--R                      - 10B  - 14A B  + 26A B  - 10A
+--R                 *
+--R                     4 3
+--R                    a b
+--R                + 
+--R                                     5           4
+--R                      (- 24C + 384A)D  - 624A B D
+--R                    + 
+--R                           3         2        2        2            2       3  3
+--R                      (472C  - 252A C  + (744B  + 1368A )C + 1272A B  + 252A )D
+--R                    + 
+--R                                3            2          3        2             3
+--R                          380B C  + 1128A B C  + (- 600B  + 1428A B)C - 1016A B
+--R                        + 
+--R                               3
+--R                          1272A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         4          2       2  3
+--R                          - 12C  + 496A C  + (- 104B  - 512A )C
+--R                        + 
+--R                                 2        3  2        4       2 2       4
+--R                          (252A B  + 1160A )C  + (288B  + 600A B  + 972A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 248A B  + 276A B  + 72A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4         3       2   3
+--R                      56B C  - 180A B C  + (- 44B  + 648A B)C
+--R                    + 
+--R                            3       3   2         5      2 3       4           5
+--R                      (24A B  - 384A B)C  + (- 72B  - 52A B  + 512A B)C + 24A B
+--R                    + 
+--R                            3 3      5
+--R                      - 216A B  - 12A B
+--R                 *
+--R                     5 2
+--R                    a b
+--R                + 
+--R                             5        2               2       2  4
+--R                      - 96B D  + (264C  - 528A C + 96B  - 312A )D
+--R                    + 
+--R                                      3  3
+--R                      (192A B C - 160B )D
+--R                    + 
+--R                                4         3         2        2  2
+--R                          - 272C  + 480A C  + (- 48B  - 1248A )C
+--R                        + 
+--R                                   2       3        4        2 2       4
+--R                          (- 960A B  - 352A )C + 96B  - 1296A B  + 176A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4          3        3      2   2
+--R                          - 256B C  - 64A B C  + (576B  + 96A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (896A B  - 640A B)C + 64B  + 128A B  - 352A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5         2      2  4
+--R                      - 24C  - 112A C  + (- 80B  + 88A )C
+--R                    + 
+--R                               2       3  3          4       2 2       4  2
+--R                      (- 288A B  - 192A )C  + (- 120B  - 192A B  - 296A )C
+--R                    + 
+--R                               4       3 2      5         2 4       4 2      6
+--R                      (- 112A B  - 288A B  + 48A )C + 296A B  + 208A B  - 24A
+--R                 *
+--R                     6
+--R                    a b
+--R                + 
+--R                              4
+--R                      384A B D
+--R                    + 
+--R                                  3         2          2       2           2
+--R                            - 192C  + 192A C  + (- 192B  + 192A )C - 384A B
+--R                          + 
+--R                                 3
+--R                            - 64A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                3           2        3       2            3
+--R                          128B C  - 192A B C  + (128B  + 384A B)C + 704A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5         4         2       2  3
+--R                          64C  - 320A C  + (- 64B  + 448A )C
+--R                        + 
+--R                                   2       3  2          4       2 2       4
+--R                          (- 192A B  + 256A )C  + (- 320B  - 192A B  - 256A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 384A B  + 320A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       2   3          3       3   2
+--R                      64B C  + 192A B C  - 512A B C  + (192A B  + 576A B)C
+--R                    + 
+--R                           5      4           5       3 3
+--R                      (128B  - 64A B)C - 64A B  - 192A B
+--R                 *
+--R                     7
+--R                    a
+--R             *
+--R                c
+--R            + 
+--R                              5                   4
+--R                  (- 8C + 8A)D  + (16B C - 16A B)D
+--R                + 
+--R                       3        2        2     2         2      3  3
+--R                  (- 8C  + 24A C  + (- 8B  + 8A )C + 8A B  - 24A )D
+--R             *
+--R                 8
+--R                b
+--R            + 
+--R                       6        5        2              2     2  4
+--R                  - 14D  + 34B D  + (- 4C  + 96A C - 36B  - 4A )D
+--R                + 
+--R                          2                3       2   3
+--R                  (- 60B C  - 56A B C + 28B  + 108A B)D
+--R                + 
+--R                         4        3       2      2  2      3       4      2 2
+--R                      26C  - 80A C  + (12B  + 12A )C  - 48A C - 14B  - 36A B
+--R                    + 
+--R                         4
+--R                      90A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                          4         3      3      2   2          3      3
+--R                      2B C  - 8A B C  + (4B  - 12A B)C  + (- 8A B  + 72A B)C
+--R                    + 
+--R                        5      2 3      4
+--R                      2B  + 12A B  - 54A B
+--R                 *
+--R                    D
+--R             *
+--R                   7
+--R                a b
+--R            + 
+--R                                 5                       4
+--R                  (- 20C + 194A)D  + (- 122B C - 352A B)D
+--R                + 
+--R                      3         2        2       2           2       3  3
+--R                  (32C  - 276A C  + (136B  + 176A )C + 116A B  - 388A )D
+--R                + 
+--R                        3           2         3      2           3       3   2
+--R                  (84B C  + 216A B C  + (- 84B  - 36A B)C - 16A B  - 192A B)D
+--R                + 
+--R                           5        4      2 3         2       3  2
+--R                      - 28C  + 90A C  - 56A C  + (36A B  + 156A )C
+--R                    + 
+--R                          4       2 2       4         4       3 2      5
+--R                      (28B  - 144A B  - 108A )C - 6A B  + 180A B  - 54A
+--R                 *
+--R                    D
+--R                + 
+--R                        5         4        3      2   3        3      3   2
+--R                  - 2B C  + 8A B C  + (- 4B  + 12A B)C  + (8A B  - 72A B)C
+--R                + 
+--R                       5      2 3      4
+--R                  (- 2B  - 12A B  + 54A B)C
+--R             *
+--R                 2 6
+--R                a b
+--R            + 
+--R                       6         5        2                2       2  4
+--R                  - 22D  - 116B D  + (110C  - 498A C + 222B  + 248A )D
+--R                + 
+--R                        2                 3        2   3
+--R                  (72B C  + 760A B C - 72B  + 1152A B)D
+--R                + 
+--R                        4         3          2       2  2            2       3
+--R                      6C  + 268A C  + (- 276B  - 696A )C  + (- 540A B  + 764A )C
+--R                    + 
+--R                           4       2 2       4
+--R                      - 10B  - 168A B  + 442A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                             4           3       3      2   2
+--R                      - 28B C  - 328A B C  + (72B  - 48A B)C
+--R                    + 
+--R                             3       3        5       2 3       4
+--R                      (184A B  + 248A B)C - 4B  - 160A B  + 124A B
+--R                 *
+--R                    D
+--R                + 
+--R                     6        5        2      2  4           2      3  3
+--R                  10C  - 34A C  + (- 2B  + 32A )C  + (- 52A B  - 60A )C
+--R                + 
+--R                        4       2 2      4  2          4       3 2      5
+--R                  (- 10B  + 168A B  - 30A )C  + (- 2A B  - 100A B  + 94A )C
+--R                + 
+--R                    6      2 4      4 2      6
+--R                  2B  + 16A B  - 62A B  - 12A
+--R             *
+--R                 3 5
+--R                a b
+--R            + 
+--R                                5                    4
+--R                  (178C - 490A)D  + (70B C + 110A B)D
+--R                + 
+--R                        3         2          2        2            2       3  3
+--R                  (- 60C  + 684A C  + (- 572B  - 1564A )C - 1252A B  - 348A )D
+--R                + 
+--R                              3           2        3        2            3
+--R                        132B C  - 156A B C  + (356B  - 1980A B)C + 404A B
+--R                      + 
+--R                               3
+--R                        - 1252A B
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                           5         4        2       2  3          2       3  2
+--R                      - 46C  - 146A C  + (332B  + 844A )C  + (756A B  - 356A )C
+--R                    + 
+--R                            4       2 2       4          4      3 2       5
+--R                      (- 38B  + 204A B  - 654A )C + 30A B  - 36A B  - 122A
+--R                 *
+--R                    D
+--R                + 
+--R                         5           4         3      2   3
+--R                  - 10B C  + 182A B C  + (- 12B  - 92A B)C
+--R                + 
+--R                           3       3   2      5      2 3       4           5
+--R                  (- 124A B  + 156A B)C  + (6B  - 60A B  - 298A B)C - 18A B
+--R                + 
+--R                      3 3      5
+--R                  220A B  + 30A B
+--R             *
+--R                 4 4
+--R                a b
+--R            + 
+--R                     6         5          2                2       2  4
+--R                  72D  + 244B D  + (- 268C  + 1308A C - 12B  + 440A )D
+--R                + 
+--R                         2                  3       2   3
+--R                  (240B C  + 880A B C + 224B  - 120A B)D
+--R                + 
+--R                           4         3        2        2  2
+--R                      - 96C  - 704A C  + (264B  + 2400A )C
+--R                    + 
+--R                              2        3        4        2 2      4
+--R                      (2160A B  + 1256A )C - 40B  + 1632A B  + 40A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                              4           3          3       2   2
+--R                      - 148B C  - 496A B C  + (- 648B  + 528A B)C
+--R                    + 
+--R                               3        3         5       2 3       4
+--R                      (- 752A B  + 1520A B)C - 52B  - 304A B  + 772A B
+--R                 *
+--R                    D
+--R                + 
+--R                     6        5          2       2  4            2      3  3
+--R                  20C  + 44A C  + (- 140B  - 304A )C  + (- 328A B  - 16A )C
+--R                + 
+--R                      4       2 2       4  2          4       3 2     5        6
+--R                  (44B  - 264A B  + 252A )C  + (148A B  + 416A B  + 4A )C + 12B
+--R                + 
+--R                        2 4      4 2      6
+--R                  - 224A B  - 20A B  + 64A
+--R             *
+--R                 5 3
+--R                a b
+--R            + 
+--R                                 5                       4
+--R                  (- 312C + 72A)D  + (- 504B C - 552A B)D
+--R                + 
+--R                      3          2         2       2           2      3  3
+--R                  (48C  - 1512A C  + (- 96B  - 432A )C + 432A B  + 40A )D
+--R                + 
+--R                              3            2          3        2            3
+--R                      - 216B C  - 1488A B C  + (- 400B  - 1224A B)C - 928A B
+--R                    + 
+--R                            3
+--R                      - 112A B
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                          5         4        2        2  3
+--R                      128C  + 376A C  + (272B  - 1328A )C
+--R                    + 
+--R                               2        3  2        4        2 2      4
+--R                      (- 792A B  - 1136A )C  + (280B  - 1488A B  - 48A )C
+--R                    + 
+--R                            4        3 2       5
+--R                      360A B  - 1224A B  - 104A
+--R                 *
+--R                    D
+--R                + 
+--R                       5          4        3       2   3          3       3   2
+--R                  56B C  + 80A B C  + (376B  + 592A B)C  + (464A B  - 624A B)C
+--R                + 
+--R                        5      2 3       4           5       3 3       5
+--R                  (- 24B  + 72A B  - 232A B)C + 72A B  - 208A B  - 192A B
+--R             *
+--R                 6 2
+--R                a b
+--R            + 
+--R                       2              2       2  4
+--R                  (432C  - 96A C + 96B  - 144A )D
+--R                + 
+--R                         2                  2   3
+--R                  (288B C  + 576A B C + 480A B)D
+--R                + 
+--R                      4          3      2 2       3       4       2 2      4  2
+--R                  (64C  + 1056A C  - 96A C  - 352A C + 64B  + 192A B  - 32A )D
+--R                + 
+--R                             4           3       3        2   2
+--R                      - 96B C  + 832A B C  + (32B  + 1152A B)C
+--R                    + 
+--R                             3       3          2 3      4
+--R                      (576A B  + 320A B)C + 992A B  - 32A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6        5          2       2  4            2       3  3
+--R                  - 48C  - 64A C  + (- 128B  + 272A )C  + (- 160A B  + 256A )C
+--R                + 
+--R                         4      2 2      4  2            4       3 2      5
+--R                  (- 304B  + 96A B  + 48A )C  + (- 416A B  + 224A B  + 64A )C
+--R                + 
+--R                       6       2 4       4 2      6
+--R                  - 32B  + 208A B  + 352A B  - 16A
+--R             *
+--R                 7
+--R                a b
+--R            + 
+--R                         3       2          2  3
+--R                  (- 192C  + 192A C - 384A B )D
+--R                + 
+--R                             2       3       3   2
+--R                  (- 192A B C  + 128B C - 64A B)D
+--R                + 
+--R                           4      2 3       3 2       2 2          4      5
+--R                  (- 320A C  - 64B C  + 256A C  - 192A B C - 384A B  + 64A )D
+--R                + 
+--R                       5       2   3         3 2        5      4          3 3
+--R                  64B C  - 512A B C  + 192A B C  + (128B  - 64A B)C - 192A B
+--R             *
+--R                 8
+--R                a
+--R     + 
+--R         2a %%BN0
+--R      *
+--R         log
+--R                         2 3 8
+--R                  - 32A D a c
+--R                + 
+--R                           2 2 2       3        2  3
+--R                      16A D a b  + (16D  + 16B D )a b
+--R                    + 
+--R                               2                   2      3  4
+--R                      (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            2   4        3       2  2 3
+--R                      - 2A D a b  + (- 8D  - 8B D )a b
+--R                    + 
+--R                                      2                  2      3  3 2
+--R                      ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                    + 
+--R                             3        2       2               2       2
+--R                          32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                        + 
+--R                                 2                2
+--R                          - 16B C  - 96A B C + 48A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                2                 3         2      2          2
+--R                          128A D  + 512A B D - 64C  + 128A C  + 64A C - 128A B
+--R                        + 
+--R                                3
+--R                          - 128A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        3      2    5
+--R                      (D  + B D )a b
+--R                    + 
+--R                                    2                2     3  2 4
+--R                      ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                    + 
+--R                                3         2         2               2      2
+--R                          - 160D  - 128B D  + (- 24C  + 112A C + 32B  + 72A )D
+--R                        + 
+--R                              2                2
+--R                          8B C  + 48A B C - 24A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                         2                           3         2
+--R                          (- 80C + 560A)D  + (96B C - 1312A B)D + 48C  - 304A C
+--R                        + 
+--R                              2      2           2       3
+--R                          (48B  + 16A )C + 112A B  + 368A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                3         2        2               2       2
+--R                          - 128D  - 256B D  + (384C  - 512A C - 64B  - 384A )D
+--R                        + 
+--R                                2      3       2
+--R                          128B C  + 64B  + 384A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                 2                  3         2       2
+--R                          1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                        + 
+--R                                  2       3
+--R                          - 512A B  + 128A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                                   2   6
+--R                      (- 2C + 22A)D a b
+--R                    + 
+--R                             3        2      2             2     2        2
+--R                          70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D - B C
+--R                        + 
+--R                                       2
+--R                          - 6A B C + 3A B
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         2                            3
+--R                          (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                        + 
+--R                                2         2      2          2       3
+--R                          120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                              3         2
+--R                          224D  + 800B D
+--R                        + 
+--R                                 2                 2        2          2
+--R                          (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                        + 
+--R                                        3       2
+--R                          672A B C - 64B  - 720A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                           2                               3
+--R                          (- 160C - 2976A)D  + (- 576B C - 1088A B)D + 608C
+--R                        + 
+--R                                  2          2       2            2      3
+--R                          - 416A C  + (- 288B  - 992A )C + 1120A B  + 32A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                3         2        2                 2       2
+--R                          - 256D  + 256B D  + (192C  + 1664A C + 640B  + 960A )D
+--R                        + 
+--R                                2                   3       2
+--R                          448B C  + 1152A B C + 128B  + 192A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                2                   3          2       2
+--R                          512A D  - 4096A B D + 256C  - 1024A C  - 256A C
+--R                        + 
+--R                                2        3
+--R                          512A B  + 1024A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           3       2    7
+--R                      (- 8D  - 8B D )a b
+--R                    + 
+--R                                          2                      3        2
+--R                          (- 141C + 755A)D  + (6B C - 58A B)D + C  - 13A C
+--R                        + 
+--R                             2     2         2      3
+--R                          (3B  + 3A )C + 3A B  + 17A
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              3        2        2                2       2
+--R                          284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                        + 
+--R                                 2                 3       2
+--R                          - 12B C  - 312A B C + 20B  + 276A B
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                        2                               3
+--R                          (32C + 2016A)D  + (- 192B C + 3072A B)D - 320C
+--R                        + 
+--R                                2         2       2           2       3
+--R                          720A C  + (- 96B  + 192A )C - 672A B  - 848A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                              3         2
+--R                          896D  + 384B D
+--R                        + 
+--R                                  2                 2       2            2
+--R                          (- 1344C  - 1408A C - 896B  - 576A )D - 1088B C
+--R                        + 
+--R                                            3        2
+--R                          - 1920A B C - 384B  - 1344A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         2                               3
+--R                          (640C - 4224A)D  + (- 768B C + 8448A B)D + 128C
+--R                        + 
+--R                                 2          2       2           2        3
+--R                          1920A C  + (- 384B  - 640A )C + 128A B  - 2432A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                              3          2
+--R                          256D  + 1280B D
+--R                        + 
+--R                                  2                 2        2            2
+--R                          (- 3072C  + 4096A C + 512B  + 3072A )D - 1024B C
+--R                        + 
+--R                                3        2
+--R                          - 512B  - 3072A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                   2                    3         2        2
+--R                          - 2048A D  - 2048A B D + 2048C  - 512A C  - 2048A C
+--R                        + 
+--R                                 2       3
+--R                          4096A B  + 512A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                                  2   8
+--R                      (16C - 80A)D a b
+--R                    + 
+--R                                3         2         2               2      2
+--R                          - 146D  - 118B D  + (- 30C  + 100A C + 26B  + 66A )D
+--R                        + 
+--R                              2               3      2
+--R                          2B C  + 36A B C - 2B  - 30A B
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                           2                            3
+--R                          (- 726C + 2090A)D  + (180B C - 1100A B)D + 62C
+--R                        + 
+--R                                  2       2      2           2       3
+--R                          - 230A C  + (90B  + 58A )C + 154A B  + 350A
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1752D  - 2760B D
+--R                        + 
+--R                                2                 2        2           2
+--R                          (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                        + 
+--R                                           3        2
+--R                          - 576A B C + 312B  + 2160A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                 2                              3         2
+--R                          8160A D  + (4608B C - 5376A B)D - 864C  - 192A C
+--R                        + 
+--R                                2        2           2        3
+--R                          (2304B  + 3936A )C - 960A B  + 3264A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1152D  - 4224B D
+--R                        + 
+--R                                2                   2        2            2
+--R                          (5760C  - 11520A C - 2304B  - 8064A )D + 1152B C
+--R                        + 
+--R                                            3        2
+--R                          - 2304A B C + 768B  + 5760A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                          2                               3
+--R                          (2816C + 4352A)D  + (4608B C + 7680A B)D - 3840C
+--R                        + 
+--R                                 2         2        2            2
+--R                          3072A C  + (2304B  + 6912A )C - 6912A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                              3         2
+--R                          512D  - 512B D
+--R                        + 
+--R                                  2                  2       2            2
+--R                          (- 3840C  - 2560A C - 2048B  - 768A )D - 2816B C
+--R                        + 
+--R                                             3        2
+--R                          - 4608A B C - 1024B  - 3840A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   2                    3          2        2
+--R                          - 2048A D  + 8192A B D + 1024C  + 2048A C  - 1024A C
+--R                        + 
+--R                                 2        3
+--R                          2048A B  - 2048A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          3        2    9
+--R                      (16D  + 16B D )a b
+--R                    + 
+--R                                        2                           3        2
+--R                          (308C - 972A)D  + (- 24B C + 104A B)D - 4C  + 20A C
+--R                        + 
+--R                                2      2          2      3
+--R                          (- 12B  - 12A )C - 12A B  - 36A
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                              3         2
+--R                          456D  + 920B D
+--R                        + 
+--R                                 2                 2        2           2
+--R                          (- 744C  + 1712A C + 376B  + 1176A )D - 104B C
+--R                        + 
+--R                                        3       2
+--R                          432A B C - 88B  - 744A B
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                          2                               3
+--R                          (1668C - 8316A)D  + (- 1656B C + 136A B)D + 364C
+--R                        + 
+--R                                  2          2        2           2       3
+--R                          - 380A C  + (- 828B  - 1468A )C + 452A B  - 724A
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          2496D  + 6432B D
+--R                        + 
+--R                                  2                   2        2           2
+--R                          (- 5328C  + 14304A C + 3408B  + 9648A )D - 336B C
+--R                        + 
+--R                                          3        2
+--R                          4320A B C - 528B  - 5328A B
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                            2                                  3
+--R                          (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D + 3072C
+--R                        + 
+--R                                 2           2         2            2        3
+--R                        - 4704A C  + (- 5760B  - 10752A )C + 4224A B  - 2976A
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                                 3         2
+--R                          - 1024D  + 512B D
+--R                        + 
+--R                                2                  2        2            2
+--R                          (5760C  + 3840A C + 3072B  + 1152A )D + 4224B C
+--R                        + 
+--R                                           3        2
+--R                          6912A B C + 1536B  + 5760A B
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                            2                                3
+--R                          (- 1280C + 6912A)D  + (1536B C - 12800A B)D - 1280C
+--R                        + 
+--R                                   2        2        2            2        3
+--R                          - 2816A C  + (768B  + 2304A )C - 2304A B  + 3840A
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                   2         2                  2        2
+--R                          - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                        + 
+--R                                 2        3        2
+--R                          2048B C  + 1024B  + 6144A B
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                           3          2        2           2
+--R                          8192A B D - 4096C  + 2048A C  + 4096A C - 8192A B
+--R                        + 
+--R                                 3
+--R                          - 2048A
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                                2   10
+--R                  (- 32C + 96A)D a b
+--R                + 
+--R                           3        2       2               2       2         2
+--R                      - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D + 8B C
+--R                    + 
+--R                                    3      2
+--R                      - 48A B C + 8B  + 72A B
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                       2                           3        2
+--R                      (- 376C + 1416A)D  + (144B C + 144A B)D - 40C  + 72A C
+--R                    + 
+--R                          2       2          2      3
+--R                      (72B  + 136A )C - 56A B  + 24A
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                            3          2        2                 2        2
+--R                      - 360D  - 1080B D  + (936C  - 2608A C - 632B  - 1752A )D
+--R                    + 
+--R                           2                 3       2
+--R                      40B C  - 816A B C + 88B  + 936A B
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                    2                              3          2
+--R                      (24C + 4248A)D  + (2160B C + 2160A B)D - 536C  + 1080A C
+--R                    + 
+--R                            2        2           2       3
+--R                      (1080B  + 1976A )C - 712A B  + 360A
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                             3          2
+--R                      - 1152D  - 3456B D
+--R                    + 
+--R                            2                  2        2           2
+--R                      (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                    + 
+--R                                       3        2
+--R                      - 3744A B C - 96B  + 1296A B
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                      2                              3
+--R                      (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                    + 
+--R                             2         2        2           2        3
+--R                      3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                           3          2
+--R                      1536D  + 4608B D
+--R                    + 
+--R                               2                   2        2            2
+--R                      (- 11520C  + 12800A C + 1024B  + 9984A )D - 4352B C
+--R                    + 
+--R                                         3         2
+--R                      - 1536A B C - 2048B  - 11520A B
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                        2                                 3
+--R                      (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D + 5632C
+--R                    + 
+--R                               2           2         2            2        3
+--R                      - 4608A C  + (- 4608B  - 11776A )C + 9728A B  - 1536A
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                            2                  2        2            2
+--R                      (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                    + 
+--R                                       3        2
+--R                      6144A B C + 2048B  + 9216A B
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                          3        2           2  11
+--R                  (- 4096C  + 4096A C - 8192A B )a
+--R             *
+--R                     3
+--R                %%BN0
+--R            + 
+--R                       3 2 8
+--R                  16A D a c
+--R                + 
+--R                             3   2         4       3          2  2
+--R                      - 12A D a b  + (- 16D  - 8B D  + 24A C D )a b
+--R                    + 
+--R                                   3          2           2      3    3
+--R                      ((16C + 64A)D  - 48A B D  + (- 48A C  + 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                          3 4      4       3         2    3
+--R                      2A D b  + (8D  + 6B D  - 6A C D )a b
+--R                    + 
+--R                                      3                     2         2     3
+--R                        ((20C - 260A)D  + (- 12B C + 12A B)D  + (12A C  - 4A )D)
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                               4        3         2               2      2  2
+--R                          - 56D  + 48B D  + (- 72C  + 240A C + 24B  + 24A )D
+--R                        + 
+--R                                2                2          3     3
+--R                          (24B C  + 48A B C - 24A B)D + 8A C  - 8A C
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      3                      2
+--R                          (64C - 96A)D  + (- 96B C - 192A B)D
+--R                        + 
+--R                              3         2      2       3            2      3
+--R                          (80C  - 192A C  + 48A C + 64A )D + 48A B C  + 16A B
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                          4      3  5                   3         2    4
+--R                      (- D  - B D )b  + ((- 14C + 151A)D  + 3B C D )a b
+--R                    + 
+--R                              4        3       2              2     2  2
+--R                          174D  + 48B D  + (42C  - 336A C - 6B  - 6A )D
+--R                        + 
+--R                                 2               2          3     3
+--R                          (- 6B C  - 12A B C + 6A B)D - 2A C  + 2A C
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         3                    2
+--R                          (- 64C - 328A)D  + (24B C + 504A B)D
+--R                        + 
+--R                                3         2         2      2         3         3
+--R                          (- 52C  + 516A C  + (- 24B  - 36A )C - 172A )D - 4B C
+--R                        + 
+--R                                   2      2        3
+--R                          - 36A B C  + 12A B C - 4A B
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                             4         3          2               2  2
+--R                          64D  + 352B D  + (- 408C  + 432A C - 24A )D
+--R                        + 
+--R                                  2                2        4        3
+--R                          (- 48B C  - 96A B C - 48A B)D - 8C  - 32A C
+--R                        + 
+--R                                2      2  2           2      3        2 2     4
+--R                          (- 24B  - 48A )C  + (- 48A B  - 32A )C - 24A B  - 8A
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                  3                       2
+--R                          - 640A D  + (- 384B C + 384A B)D
+--R                        + 
+--R                               3        2       2         3          3
+--R                          (320C  + (192B  + 192A )C - 128A )D - 64B C
+--R                        + 
+--R                                  2       2           3      3
+--R                          192A B C  - 192A B C + 64A B  + 64A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                                 3 6         4        3        2          2    5
+--R                      (2C - 22A)D b  + (- 72D  - 48B D  + (- 6C  + 66A C)D )a b
+--R                    + 
+--R                                           3                     2
+--R                          (- 242C + 1210A)D  + (102B C - 108A B)D
+--R                        + 
+--R                             3         2      2     2        3        3
+--R                          (8C  - 111A C  + (6B  + 6A )C + 37A )D + B C
+--R                        + 
+--R                                2     2
+--R                          6A B C  - 3A B C
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                                  3        2                 2       2  2
+--R                          - 892B D  + (882C  - 1800A C - 192B  - 186A )D
+--R                        + 
+--R                                   2                3       2        4        3
+--R                          (- 156B C  - 336A B C + 4B  + 228A B)D + 6C  - 48A C
+--R                        + 
+--R                              2      2  2         2      3       2 2     4
+--R                          (18B  + 24A )C  + (24A B  + 80A )C + 6A B  + 2A
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (- 72C + 1848A)D  + (1512B C + 504A B)D
+--R                        + 
+--R                                    3         2         2       2          2
+--R                              - 816C  + 816A C  + (- 24B  - 384A )C + 72A B
+--R                            + 
+--R                                   3
+--R                              - 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                             3           2       3       2           3       3
+--R                        96B C  - 384A B C  + (24B  + 240A B)C - 24A B  - 144A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                              4         2                 2       2  2
+--R                          320D  + (- 48C  - 1056A C - 672B  - 624A )D
+--R                        + 
+--R                                   2                  3       2         4
+--R                          (- 384B C  - 1152A B C - 64B  + 576A B)D + 48C
+--R                        + 
+--R                                 3       2      2  2           2       3
+--R                          - 96A C  + (48B  + 96A )C  + (- 96A B  + 224A )C
+--R                        + 
+--R                               4       2 2      4
+--R                          - 32B  - 144A B  - 16A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          3            2
+--R                          (- 256C - 256A)D  + 2304A B D
+--R                        + 
+--R                                    3         2        2       2           2
+--R                              - 192C  + 768A C  + (768B  + 192A )C - 384A B
+--R                            + 
+--R                                    3
+--R                              - 768A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3       2            3
+--R                          - 256B C  + 192A B C  + (- 128B  - 768A B)C + 256A B
+--R                        + 
+--R                             3
+--R                          64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         4       3  7                  3          2    6
+--R                      (8D  + 8B D )b  + ((128C - 616A)D  - 24B C D )a b
+--R                    + 
+--R                                4         3
+--R                          - 393D  + 229B D
+--R                        + 
+--R                                 2                2      2  2
+--R                          (- 390C  + 1479A C + 45B  + 45A )D
+--R                        + 
+--R                                2              3      2       4        3
+--R                          (39B C  + 84A B C - B  - 51A B)D - C  + 13A C
+--R                        + 
+--R                               2     2  2          2      3
+--R                          (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         3                        2
+--R                          (226C - 1142A)D  + (- 786B C - 1530A B)D
+--R                        + 
+--R                                    3          2        2       2          2
+--R                                414C  - 1710A C  + (150B  + 234A )C - 42A B
+--R                              + 
+--R                                    3
+--R                                502A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2         3       2          3
+--R                          - 10B C  + 234A B C  + (- 14B  - 174A B)C + 2A B
+--R                        + 
+--R                             3
+--R                          30A B
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 896D  - 1152B D
+--R                        + 
+--R                                2                2       2  2
+--R                          (1152C  + 672A C + 816B  + 960A )D
+--R                        + 
+--R                                 2                   2            3
+--R                          (816B C  + 2016A B C - 624A B)D + 368A C
+--R                        + 
+--R                              2       2  2          2       3        4       2 2
+--R                          (48B  + 192A )C  + (288A B  - 112A )C + 16B  + 240A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                           3                       2
+--R                          (- 256C + 2688A)D  + (1344B C - 4416A B)D
+--R                        + 
+--R                                    3          2           2       2           2
+--R                              - 544C  - 1248A C  + (- 1728B  - 672A )C + 384A B
+--R                            + 
+--R                                   3
+--R                              1440A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          480B C  - 672A B C  + (128B  + 1632A B)C - 512A B
+--R                        + 
+--R                                3
+--R                          - 160A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                   3         2                 2       2  2
+--R                          - 1664B D  + (2880C  - 3072A C - 768B  - 960A )D
+--R                        + 
+--R                                 2                  3        2          4
+--R                          (384B C  - 768A B C + 256B  + 1920A B)D + 192C
+--R                        + 
+--R                             2       2  2          2       3         2 2      4
+--R                        (576B  + 384A )C  + (384A B  + 512A )C - 192A B  - 64A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 256C + 1536A)D  + (1536B C + 768A B)D
+--R                        + 
+--R                                  3         2          2       3         3
+--R                          (- 2048C  + 768A C  - 1536A B  - 256A )D - 512B C
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                                    3 8
+--R                      (- 16C + 80A)D b
+--R                    + 
+--R                           4        3       2           2    7
+--R                      (160D  + 64B D  + (48C  - 240A C)D )a b
+--R                    + 
+--R                                         3                       2
+--R                          (584C - 1402A)D  + (- 126B C + 300A B)D
+--R                        + 
+--R                                3         2         2      2         2       3
+--R                          (- 56C  + 330A C  + (- 36B  - 36A )C + 6A B  - 102A )D
+--R                        + 
+--R                                3          2      3      2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                               4          3
+--R                          1336D  + 2950B D
+--R                        + 
+--R                                  2                 2       2  2
+--R                          (- 2244C  + 2586A C + 258B  + 222A )D
+--R                        + 
+--R                                 2                 3       2         4        3
+--R                          (138B C  + 312A B C - 14B  - 402A B)D - 20C  + 22A C
+--R                        + 
+--R                                2       2  2            2       3       4
+--R                          (- 66B  - 102A )C  + (- 114A B  - 158A )C - 2B
+--R                        + 
+--R                               2 2      4
+--R                          - 48A B  - 14A
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                         3                         2
+--R                          (284C - 5284A)D  + (- 5196B C + 1860A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              1652C  + 276A C  + (- 12B  + 492A )C - 444A B
+--R                            + 
+--R                                     3
+--R                              - 1012A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 532B C  + 492A B C  + (- 148B  - 1164A B)C + 140A B
+--R                        + 
+--R                              3
+--R                          308A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          544D  + 4864B D
+--R                        + 
+--R                                  2                  2        2  2
+--R                          (- 5520C  + 7968A C + 3264B  + 2832A )D
+--R                        + 
+--R                                 2                   3        2          4
+--R                          (480B C  + 3840A B C + 160B  - 4128A B)D - 464C
+--R                        + 
+--R                                  3          2        2  2
+--R                          - 128A C  + (- 912B  - 1344A )C
+--R                        + 
+--R                                   2        3         4       2 2      4
+--R                          (- 384A B  - 1664A )C + 160B  + 528A B  + 16A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 1536C - 2688A)D  + (- 6528B C - 4224A B)D
+--R                        + 
+--R                                   3          2           2       2            2
+--R                              3968C  - 2496A C  + (- 2496B  - 768A )C + 2112A B
+--R                            + 
+--R                                  3
+--R                              704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2        3       2            3
+--R                          - 256B C  - 768A B C  + (704B  + 384A B)C - 448A B
+--R                        + 
+--R                              3
+--R                          128A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4         3         2        2        2  2
+--R                          - 384D  - 768B D  + (3072C  + 2688B  + 1536A )D
+--R                        + 
+--R                                  2                    3       2          4
+--R                          (1920B C  + 3840A B C + 1024B  - 384A B)D - 128C
+--R                        + 
+--R                                  3        2       2  2          2       3
+--R                          - 128A C  + (384B  - 768A )C  + (768A B  - 896A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          256B  + 384A B  - 128A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                 3                       2
+--R                          1536A D  + (1536B C - 6144A B)D
+--R                        + 
+--R                                  3           2       2          3            3
+--R                          (- 1280C  + (- 3072B  - 768A )C + 2048A )D + 1024B C
+--R                        + 
+--R                                    2        2             3       3
+--R                          - 768A B C  + 3072A B C - 1024A B  - 256A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                            4        3  9                    3          2    8
+--R                      (- 16D  - 16B D )b  + ((- 288C + 816A)D  + 48B C D )a b
+--R                    + 
+--R                                4          3        2                2      2  2
+--R                          - 252D  - 1236B D  + (888C  - 2076A C - 84B  - 84A )D
+--R                        + 
+--R                                  2                3       2        4        3
+--R                          (- 60B C  - 144A B C + 4B  + 108A B)D + 4C  - 20A C
+--R                        + 
+--R                              2      2  2         2      3
+--R                          (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                            3                       2
+--R                          (- 1704C + 5232A)D  + (3024B C + 1176A B)D
+--R                        + 
+--R                                    3          2          2       2           2
+--R                              - 792C  + 1728A C  + (- 168B  - 312A )C + 192A B
+--R                            + 
+--R                                    3
+--R                              - 272A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3           2       3       2          3      3
+--R                        128B C  - 312A B C  + (64B  + 528A B)C - 8A B  - 56A B
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1572D  - 5844B D
+--R                        + 
+--R                                2                  2        2  2
+--R                          (5112C  - 8748A C - 3348B  - 3492A )D
+--R                        + 
+--R                                    2                  3        2          4
+--R                          (- 1836B C  - 5904A B C + 84B  + 3996A B)D + 252C
+--R                        + 
+--R                                  3        2       2  2           2        3
+--R                          - 708A C  + (540B  + 396A )C  + (- 36A B  + 1236A )C
+--R                        + 
+--R                               4       2 2       4
+--R                          - 72B  - 576A B  - 120A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                          3                        2
+--R                          (4344C + 1416A)D  + (10872B C + 4680A B)D
+--R                        + 
+--R                                     3          2         2        2           2
+--R                              - 3480C  + 1944A C  + (5256B  + 1656A )C - 504A B
+--R                            + 
+--R                                 3
+--R                              72A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2          3       2            3
+--R                          840B C  + 1656A B C  + (- 168B  - 360A B)C + 792A B
+--R                        + 
+--R                                3
+--R                          - 408A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          544D  + 1024B D
+--R                        + 
+--R                                  2                  2        2  2
+--R                          (- 4896C  + 1152A C - 5472B  - 2592A )D
+--R                        + 
+--R                                    2                    3       2          4
+--R                          (- 3168B C  - 6336A B C - 2304B  + 864A B)D + 384C
+--R                        + 
+--R                                3          2        2  2
+--R                          864A C  + (- 576B  + 2304A )C
+--R                        + 
+--R                                    2        3         4       2 2       4
+--R                          (- 1152A B  + 2208A )C - 576B  - 576A B  + 384A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                          3                         2
+--R                          (1536C - 4224A)D  + (- 4224B C + 8064A B)D
+--R                        + 
+--R                                3          2         2        2          3
+--R                          (2496C  - 1728A C  + (5760B  + 1728A )C - 2496A )D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                        - 1344B C  + 1728A B C  - 5184A B C + 1536A B  + 192A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                 3           2                  2        2  2
+--R                          1536B D  + (- 4992C  + 3840A C + 3072B  + 4224A )D
+--R                        + 
+--R                                   2                    3        2          4
+--R                          (- 768B C  + 4608A B C - 1024B  - 6912A B)D - 640C
+--R                        + 
+--R                                3           2       2  2            2        3
+--R                          512A C  + (- 1920B  - 768A )C  + (- 768A B  - 1536A )C
+--R                        + 
+--R                               2 2       4
+--R                          1152A B  + 384A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                     2
+--R                          - 6144A B D
+--R                        + 
+--R                                3           2        2            2        3
+--R                          (3072C  + (- 3072B  - 3072A )C + 6144A B  + 2048A )D
+--R                        + 
+--R                                 3            2         3        2             3
+--R                          1024B C  - 3072A B C  + (2048B  + 3072A B)C - 1024A B
+--R                        + 
+--R                                 3
+--R                          - 1024A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                              3 10          3         2           2    9
+--R                  (32C - 96A)D b   + (128B D  + (- 96C  + 288A C)D )a b
+--R                + 
+--R                                     3                       2
+--R                      (384C - 1080A)D  + (- 360B C - 240A B)D
+--R                    + 
+--R                          3         2       2      2          2      3         3
+--R                      (96C  - 312A C  + (48B  + 48A )C - 24A B  + 72A )D - 8B C
+--R                    + 
+--R                             2        3      2
+--R                      48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                          4          3           2                 2       2  2
+--R                      144D  + 1272B D  + (- 1008C  + 2568A C + 456B  + 504A )D
+--R                    + 
+--R                             2                 3       2         4         3
+--R                      (264B C  + 864A B C - 24B  - 552A B)D - 32C  + 120A C
+--R                    + 
+--R                          2      2  2         2       3       4      2 2      4
+--R                    (- 72B  - 24A )C  + (24A B  - 152A )C + 8B  + 96A B  + 24A
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     3                         2
+--R                      (240C - 1944A)D  + (- 3240B C - 2304A B)D
+--R                    + 
+--R                           3          2          2      2          2       3
+--R                      (816C  - 2088A C  + (- 576B  - 96A )C - 24A B  + 504A )D
+--R                    + 
+--R                            3          2        3       2            3      3
+--R                    - 120B C  - 96A B C  + (- 8B  - 216A B)C - 144A B  + 16A B
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                           4          3
+--R                      1008D  + 1608B D
+--R                    + 
+--R                             2                  2        2  2
+--R                      (- 720C  + 1368A C + 3384B  + 3240A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (2232B C  + 6048A B C + 216B  - 3096A B)D - 192C
+--R                    + 
+--R                            3          2       2  2          2        3
+--R                      648A C  + (- 216B  - 360A )C  + (360A B  - 1128A )C
+--R                    + 
+--R                          4       2 2      4
+--R                      120B  + 576A B  + 72A
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 5648C + 4272A)D  + (- 2160B C - 2448A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 144C  + 3168A C  + (- 6768B  - 3024A )C + 432A B
+--R                        + 
+--R                                3
+--R                          - 576A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2        3        2             3
+--R                      - 384B C  - 3024A B C  + (144B  + 2592A B)C - 1008A B
+--R                    + 
+--R                          3
+--R                      240A B
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                             4          3
+--R                      - 1152D  - 3008B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (8736C  - 5760A C - 2304B  - 6048A )D
+--R                    + 
+--R                             2                    3        2          4
+--R                      (576B C  - 6912A B C + 2880B  + 9792A B)D + 480C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 2304A C  + (2592B  - 1152A )C  + (1152A B  + 768A )C
+--R                    + 
+--R                          4        2 2       4
+--R                      384B  - 1440A B  - 864A
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                      3                       2
+--R                      (4992C - 1152A)D  + (5760B C + 4992A B)D
+--R                    + 
+--R                              3         2         2        2            2
+--R                      (- 3840C  - 768A C  + (7296B  + 6144A )C - 6528A B )D
+--R                    + 
+--R                            3            2           3        2             3
+--R                      512B C  + 6144A B C  + (- 2176B  - 2304A B)C + 1152A B
+--R                    + 
+--R                          3
+--R                      768A B
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                              2                  2        2  2
+--R                      (- 6912C  + 1536A C - 1536B  + 2304A )D
+--R                    + 
+--R                                2        3        2          4          3
+--R                      (- 3072B C  - 3072B  - 6144A B)D - 256C  + 1536A C
+--R                    + 
+--R                              2        2  2             2       3         4
+--R                      (- 2304B  + 1536A )C  + (- 1536A B  + 512A )C - 512B
+--R                    + 
+--R                          2 2       4
+--R                      768A B  + 768A
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                            3        2           2              2        3
+--R                      (3072C  - 3072A C + 6144A B )D - 3072A B C  + 2048B C
+--R                    + 
+--R                             3
+--R                      - 1024A B
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                     5             4          3     3 2  2  7
+--R                  (4D a b + (- 8C D  - 16A B D  - 8A D )a )c
+--R                + 
+--R                         5 3          4          3     3 2    2
+--R                      - D b  + (- 6C D  + 12A B D  + 2A D )a b
+--R                    + 
+--R                             5        4       2             2      2  3
+--R                          20D  - 12B D  + (24C  + 16A C + 8B  + 28A )D
+--R                        + 
+--R                                          2   2
+--R                          (- 24A B C + 12A B)D
+--R                     *
+--R                         2
+--R                        a b
+--R                    + 
+--R                                        4                   3
+--R                          (- 32C + 24A)D  + (48B C - 64A B)D
+--R                        + 
+--R                                3        2      3  2           2      3
+--R                          (- 16C  + 72A B  - 32A )D  + (48A B C  + 16A B)D
+--R                        + 
+--R                            3 2     5
+--R                          8A C  - 8A
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                           4         3  4
+--R                      (2C D  - 2A B D )b
+--R                    + 
+--R                               5        4        2             2      2  3
+--R                          - 43D  + 11B D  + (- 2C  - 12A C - 6B  - 19A )D
+--R                        + 
+--R                                      2   2
+--R                          (6A B C - 3A B)D
+--R                     *
+--R                           3
+--R                        a b
+--R                    + 
+--R                                      4                      3
+--R                          (48C - 10A)D  + (- 52B C + 208A B)D
+--R                        + 
+--R                                3        2       2      2          2      3  2
+--R                          (- 12C  + 24A C  + (12B  + 24A )C - 30A B  + 92A )D
+--R                        + 
+--R                                    2     3        3 2     5
+--R                          (- 12A B C  - 4A B)D - 2A C  + 2A
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                              5         4       2             2      2  3
+--R                          - 4D  - 108B D  + (72C  - 64A C + 4B  + 56A )D
+--R                        + 
+--R                                           3       2   2
+--R                          (- 336A B C - 36B  - 144A B)D
+--R                        + 
+--R                                 4        3         2      2  2
+--R                              20C  - 48A C  + (- 24B  - 60A )C
+--R                            + 
+--R                                      2      3        2 2      4
+--R                              (- 48A B  - 40A )C - 24A B  - 16A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3      2   2      3         4
+--R                          - 8A B C  - 12A B C  - 16A B C + 20A B
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                               4                    3
+--R                          96A D  + (192B C - 96A B)D
+--R                        + 
+--R                                3        2      2          2      3  2
+--R                          (- 64C  + 24A C  - 96B C + 288A B  + 40A )D
+--R                        + 
+--R                                  3           2      2           3      3
+--R                          (- 16B C  + 192A B C  - 48A B C - 96A B  + 64A B)D
+--R                        + 
+--R                              5      2 3           2      3  2      4       3 2
+--R                          - 8C  - 16A C  + (- 72A B  + 32A )C  + 24A C - 24A B
+--R                        + 
+--R                               5
+--R                          - 32A
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                         5       4       2           2     2  3  5
+--R                      (9D  - 2B D  + (- C  + 2A C + B  + 3A )D )b
+--R                    + 
+--R                                    4                    3
+--R                          (59C + A)D  + (10B C - 114A B)D
+--R                        + 
+--R                             3       2        2     2         2      3  2
+--R                          (4C  - 6A C  + (- 3B  - 6A )C + 3A B  - 20A )D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                               5         4          2               2       2  3
+--R                          - 65D  + 189B D  + (- 186C  - 144A C - 81B  - 312A )D
+--R                        + 
+--R                                2                 3      2   2
+--R                          (12B C  + 312A B C + 13B  - 54A B)D
+--R                        + 
+--R                                  4        3      2      2  2         2      3
+--R                              - 5C  + 12A C  + (6B  + 15A )C  + (12A B  + 10A )C
+--R                            + 
+--R                                2 2     4
+--R                              6A B  + 4A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3     2   2     3        4
+--R                          2A B C  + 3A B C  + 4A B C - 5A B
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (164C - 144A)D  + (- 504B C + 448A B)D
+--R                        + 
+--R                                   3         2        2       2           2
+--R                                72C  + 282A C  + (228B  + 348A )C - 552A B
+--R                              + 
+--R                                    3
+--R                                186A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3           2       3       2           3
+--R                              4B C  - 336A B C  + (24B  + 180A B)C + 72A B
+--R                            + 
+--R                                    3
+--R                              - 104A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5       4      2      2  3         2      3  2
+--R                          2C  + 8A C  + (4B  + 24A )C  + (54A B  - 64A )C
+--R                        + 
+--R                              2 2      4       3 2      5
+--R                          (24A B  - 10A )C - 2A B  + 72A
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                                5        4          2                2      2  3
+--R                          - 104D  - 72B D  + (- 108C  - 232A C + 136B  - 28A )D
+--R                        + 
+--R                                 2                3       2   2
+--R                          (252B C  - 120A B C - 8B  - 372A B)D
+--R                        + 
+--R                                  4         3      2 2          2      3
+--R                              116C  - 128A C  + 12B C  + (456A B  - 16A )C
+--R                            + 
+--R                                 4       2 2      4
+--R                              48B  + 300A B  - 68A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          28B C  + 144A B C  + (36B  + 192A B)C
+--R                        + 
+--R                                 3      3         2 3      4
+--R                          (120A B  - 32A B)C + 36A B  + 84A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4           3
+--R                          128C D  - 128A B D
+--R                        + 
+--R                              3        2          2      2          2       3  2
+--R                          (48C  + 96A C  + (- 384B  - 48A )C + 96A B  + 288A )D
+--R                        + 
+--R                                     3          2       3       2            3
+--R                              - 64B C  - 96A B C  + (64B  - 192A B)C - 384A B
+--R                            + 
+--R                                   3
+--R                              - 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4       2      2  3
+--R                          - 32C  + 48A C  + (48B  - 64A )C
+--R                        + 
+--R                                   2      3  2        2 2      4          4
+--R                          (- 288A B  - 64A )C  + (144A B  + 96A )C + 32A B
+--R                        + 
+--R                               3 2      5
+--R                          - 96A B  + 16A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                              4          3  6
+--R                      (- 16C D  + 16A B D )b
+--R                    + 
+--R                              5         4      2               2       2  3
+--R                          127D  - 107B D  + (5C  + 106A C + 53B  + 173A )D
+--R                        + 
+--R                                 2              3      2   2
+--R                          (- 3B C  - 54A B C - B  + 21A B)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                         4                     3
+--R                          (- 229C + 37A)D  + (400B C - 690A B)D
+--R                        + 
+--R                                  3         2          2       2           2
+--R                              116C  - 300A C  + (- 177B  - 315A )C + 189A B
+--R                            + 
+--R                                    3
+--R                              - 347A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  2        3      2           3      3
+--R                          (66A B C  + (- 6B  - 42A B)C - 12A B  + 20A B)D
+--R                        + 
+--R                                4       2     2  3          2      3  2
+--R                          - 2A C  + (- B  - 5A )C  + (- 9A B  + 13A )C
+--R                        + 
+--R                               2 2    4       3 2      5
+--R                          (- 6A B  + A )C + 2A B  - 15A
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              5         4       2               2      2  3
+--R                          212D  + 476B D  + (79C  + 650A C - 44B  + 55A )D
+--R                        + 
+--R                                   2                   3        2   2
+--R                          (- 231B C  + 1470A B C + 204B  + 1257A B)D
+--R                        + 
+--R                                    4         3        2       2  2
+--R                              - 195C  + 360A C  + (129B  + 318A )C
+--R                            + 
+--R                                      2       3        4      2 2       4
+--R                              (- 42A B  + 216A )C - 32B  - 63A B  + 133A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4          3         3      2   2
+--R                          - 15B C  - 48A B C  + (- 25B  - 66A B)C
+--R                        + 
+--R                                  3       3         2 3       4
+--R                          (- 78A B  + 112A B)C - 17A B  - 175A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                      4                       3
+--R                          (4C - 260A)D  + (- 800B C - 320A B)D
+--R                        + 
+--R                                    3         2        2       2            2
+--R                              - 140C  - 564A C  + (408B  - 564A )C - 1320A B
+--R                            + 
+--R                                    3
+--R                              - 780A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2          3       2
+--R                              - 104B C  - 1368A B C  + (- 384B  - 984A B)C
+--R                            + 
+--R                                    3       3
+--R                              384A B  - 488A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5         4          2      2  3
+--R                          56C  - 128A C  + (- 172B  - 64A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (108A B  - 160A )C  + (- 60B  - 564A B  - 248A )C
+--R                        + 
+--R                                 4       3 2      5
+--R                          - 84A B  + 116A B  + 32A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                               5         4          2                2      2  3
+--R                          - 48D  + 528B D  + (- 624C  + 352A C + 320B  + 16A )D
+--R                        + 
+--R                                 2                   3       2   2
+--R                          (432B C  + 2208A B C + 128B  + 432A B)D
+--R                        + 
+--R                                 4        3          2       2  2
+--R                              32C  - 64A C  + (- 144B  + 672A )C
+--R                            + 
+--R                                      2       3        4       2 2
+--R                              (1056A B  + 512A )C + 48B  + 624A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3         3       2   2
+--R                          - 64B C  + 128A B C  + (- 48B  + 288A B)C
+--R                        + 
+--R                                  3       3         5       2 3      4
+--R                          (- 32A B  - 192A B)C - 16B  - 176A B  - 32A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (128C - 384A)D  + (- 768B C + 256A B)D
+--R                        + 
+--R                               3       2          2       3  2
+--R                          (448C  - 192A C - 768A B  + 128A )D
+--R                        + 
+--R                                      2       3        3            4       2 3
+--R                          (- 1152A B C  + 256B C - 384A B)D + 192A C  + 192B C
+--R                        + 
+--R                                3 2       2 2          4       5
+--R                          - 384A C  + 576A B C + 128A B  + 192A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            5        4      2             2      2  3  7
+--R                      (- 24D  + 16B D  + (8C  - 16A C - 8B  - 24A )D )b
+--R                    + 
+--R                                        4                      3
+--R                          (- 114C - 2A)D  + (- 68B C + 284A B)D
+--R                        + 
+--R                                3        2       2      2          2      3  2
+--R                          (- 30C  + 54A C  + (30B  + 54A )C - 18A B  + 66A )D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                                5         4        2                2       2  3
+--R                          - 135D  - 552B D  + (318C  + 228A C + 186B  + 720A )D
+--R                        + 
+--R                                  2                 3      2   2
+--R                          (- 12B C  - 900A B C - 64B  - 90A B)D
+--R                        + 
+--R                                 4        3         2      2  2
+--R                              39C  - 76A C  + (- 30B  - 72A )C
+--R                            + 
+--R                                      2      3       4      4
+--R                              (- 12A B  - 48A )C + 5B  - 27A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4         3      3     2   2         3      3
+--R                          2B C  + 4A B C  + (4B  + 6A B)C  + (12A B  - 24A B)C
+--R                        + 
+--R                            2 3      4
+--R                          2A B  + 36A B
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         4                      3
+--R                          (- 515C + 93A)D  + (1044B C - 184A B)D
+--R                        + 
+--R                                  3         2          2        2            2
+--R                              - 4C  - 924A C  + (- 828B  - 1182A )C + 1104A B
+--R                            + 
+--R                                  3
+--R                              - 6A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2       3       2            3
+--R                              112B C  + 972A B C  + (64B  - 252A B)C - 196A B
+--R                            + 
+--R                                  3
+--R                              296A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4       2      2  3
+--R                          - 7C  + 13A C  + (62B  - 28A )C
+--R                        + 
+--R                                  2       3  2       4       2 2      4
+--R                          (- 42A B  + 184A )C  + (35B  + 144A B  + 91A )C
+--R                        + 
+--R                               4      3 2       5
+--R                          39A B  + 56A B  - 141A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5          4         2                2       2  3
+--R                          52D  - 1100B D  + (1418C  + 540A C - 648B  + 826A )D
+--R                        + 
+--R                                   2                   3       2   2
+--R                          (- 714B C  - 2316A B C - 168B  + 726A B)D
+--R                        + 
+--R                                    4         3        2      2  2
+--R                              - 222C  + 736A C  + (630B  - 12A )C
+--R                            + 
+--R                                        2      3         4        2 2       4
+--R                              (- 1404A B  + 48A )C - 108B  - 1098A B  + 314A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3        3       2   2
+--R                          34B C  - 256A B C  + (138B  - 300A B)C
+--R                        + 
+--R                                3       3         5       2 3      4
+--R                          (12A B  + 656A B)C + 36B  + 186A B  - 38A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                          4                       3
+--R                          (- 120C + 312A)D  + (1920B C - 1152A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 328C  - 936A C  + (528B  - 1368A )C + 1296A B
+--R                            + 
+--R                                    3
+--R                              - 984A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 3            2       2            3       3
+--R                          (944B C  + 3120A B C  + 144A B C + 896A B  + 912A B)D
+--R                        + 
+--R                              5         4       2       2  3
+--R                          112C  - 240A C  + (24B  + 224A )C
+--R                        + 
+--R                                  2       3  2        4       2 2      4
+--R                          (1272A B  + 960A )C  + (200B  - 120A B  + 48A )C
+--R                        + 
+--R                                4       3 2       5
+--R                          - 8A B  + 744A B  - 336A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                             5         4          2                2       2  3
+--R                          96D  + 480B D  + (- 384C  + 768A C - 768B  - 192A )D
+--R                        + 
+--R                                    2                   3       2   2
+--R                          (- 1152B C  + 1152A B C - 256B  + 960A B)D
+--R                        + 
+--R                                    4         3          2       2  2
+--R                              - 544C  + 128A C  + (- 768B  + 384A )C
+--R                            + 
+--R                                        2       3         4        2 2       4
+--R                              (- 2304A B  + 512A )C - 288B  - 1536A B  + 288A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4            3          3        2   2
+--R                          - 352B C  - 1024A B C  + (- 384B  - 1152A B)C
+--R                        + 
+--R                                    3       3         5       2 3       4
+--R                          (- 1024A B  - 384A B)C - 32B  - 640A B  - 416A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                  4                        3
+--R                          - 384A D  + (- 768B C + 1536A B)D
+--R                        + 
+--R                               3         2        2           2       3  2
+--R                          (256C  - 384A C  + 1536B C - 1152A B  - 640A )D
+--R                        + 
+--R                                 3           2       2             3       3
+--R                          (256B C  - 768A B C  + 768A B C + 1536A B  - 256A B)D
+--R                        + 
+--R                              5       2 3           2       3  2       4
+--R                          128C  + 256A C  + (1152A B  - 128A )C  - 384A C
+--R                        + 
+--R                              3 2       5
+--R                          384A B  + 128A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                            4          3  8
+--R                      (32C D  - 32A B D )b
+--R                    + 
+--R                               5         4       2                2       2  3
+--R                          - 76D  + 252B D  + (12C  - 232A C - 116B  - 388A )D
+--R                        + 
+--R                                2                3      2   2
+--R                          (12B C  + 120A B C + 4B  - 36A B)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                       4                       3
+--R                          (807C + 31A)D  + (- 740B C + 356A B)D
+--R                        + 
+--R                                    3         2        2       2           2
+--R                              - 274C  + 810A C  + (510B  + 870A )C - 282A B
+--R                            + 
+--R                                  3
+--R                              426A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2      3       2           3
+--R                              - 20B C  - 132A B C  + (4B  + 108A B)C + 28A B
+--R                            + 
+--R                                   3
+--R                              - 36A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5       4        2      2  3        2      3  2
+--R                          - C  + 3A C  + (- 6B  + 10A )C  + (6A B  - 30A )C
+--R                        + 
+--R                               4     2 2     4         4      3 2      5
+--R                          (- 5B  - 6A B  - 9A )C - 5A B  - 18A B  + 27A
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                             5         4           2               2        2  3
+--R                          48D  + 740B D  + (- 1472C  - 1808A C - 4B  - 1944A )D
+--R                        + 
+--R                                 2       3        2   2
+--R                          (816B C  - 228B  - 2760A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              376C  - 912A C  + (- 540B  - 600A )C
+--R                            + 
+--R                                     2       3        4       2 2       4
+--R                              (312A B  - 416A )C + 68B  + 348A B  - 336A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4          3         3      2   2
+--R                          - 12B C  + 80A B C  + (- 44B  + 96A B)C
+--R                        + 
+--R                                3       3         5      2 3       4
+--R                          (40A B  - 480A B)C - 16B  - 84A B  + 284A B
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (256C + 584A)D  + (- 688B C + 2904A B)D
+--R                        + 
+--R                                  3          2         2        2           2
+--R                              496C  + 3888A C  + (1116B  + 5532A )C + 996A B
+--R                            + 
+--R                                   3
+--R                              2140A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2        3        2
+--R                              - 672B C  + 120A B C  + (712B  + 4200A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 256A B  + 336A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4        2       2  3
+--R                          - 156C  + 364A C  + (116B  + 268A )C
+--R                        + 
+--R                                   2       3  2          4       2 2       4
+--R                          (- 492A B  - 444A )C  + (- 100B  + 792A B  + 160A )C
+--R                        + 
+--R                               4       3 2       5
+--R                          12A B  - 904A B  + 352A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                               5          4
+--R                          - 80D  - 1040B D
+--R                        + 
+--R                                 2                 2       2  3
+--R                          (- 748C  - 2760A C + 816B  - 380A )D
+--R                        + 
+--R                                    2                   3        2   2
+--R                          (- 1044B C  - 7032A B C - 272B  - 4260A B)D
+--R                        + 
+--R                                  4          3           2        2  2
+--R                              396C  - 2272A C  + (- 1716B  - 4152A )C
+--R                            + 
+--R                                        2        3        4       2 2        4
+--R                              (- 2040A B  - 3360A )C + 16B  - 180A B  - 1108A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3        2   2
+--R                          188B C  - 128A B C  + (- 364B  - 1080A B)C
+--R                        + 
+--R                                   3        3         5       2 3       4
+--R                          (- 168A B  - 1408A B)C - 48B  + 244A B  + 124A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                          4                      3
+--R                          (- 528C + 816A)D  + (3264B C - 768A B)D
+--R                        + 
+--R                                  3          2           2        2            2
+--R                              816C  + 1680A C  + (- 1056B  + 2064A )C + 4224A B
+--R                            + 
+--R                                   3
+--R                              1584A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3        2
+--R                              544B C  + 5280A B C  + (1280B  + 4320A B)C
+--R                            + 
+--R                                      3        3
+--R                              - 768A B  + 1888A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4        2       2  3
+--R                          - 160C  + 320A C  + (496B  + 384A )C
+--R                        + 
+--R                                 2       3  2        4        2 2       4
+--R                          (144A B  + 800A )C  + (240B  + 1680A B  + 800A )C
+--R                        + 
+--R                                4       3 2      5
+--R                          208A B  - 272A B  - 96A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                  4         2                 2       2  3
+--R                          - 384B D  + (1344C  - 384A C - 1344B  - 960A )D
+--R                        + 
+--R                                    2                  3       2   2
+--R                          (- 1728B C  - 3456A B C + 64B  + 576A B)D
+--R                        + 
+--R                                    4          3        2        2  2
+--R                              - 448C  + 1024A C  + (960B  - 1728A )C
+--R                            + 
+--R                                        2        3         4        2 2       4
+--R                              (- 3456A B  - 1408A )C - 192B  - 2112A B  + 256A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3        3       2   2
+--R                          256B C  - 384A B C  + (192B  - 960A B)C
+--R                        + 
+--R                                 3        3         5       2 3       4
+--R                          (128A B  + 1024A B)C + 64B  + 704A B  - 192A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                   3
+--R                          1536A B D
+--R                        + 
+--R                                    3         2         2       2            2
+--R                              - 768C  - 384A C  + (1536B  + 768A )C - 1536A B
+--R                            + 
+--R                                    3
+--R                              - 640A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2           3       2
+--R                              256B C  + 1536A B C  + (- 1024B  + 768A B)C
+--R                            + 
+--R                                     3       3
+--R                              1536A B  + 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4          2       2  3
+--R                          128C  - 768A C  + (- 768B  + 256A )C
+--R                        + 
+--R                                  2        3  2           2 2       4
+--R                          (1152A B  + 1024A )C  + (- 2304A B  - 384A )C
+--R                        + 
+--R                                  4       3 2       5
+--R                          - 512A B  + 384A B  - 256A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                      5        4         2              2      2  3  9
+--R                  (16D  - 32B D  + (- 16C  + 32A C + 16B  + 48A )D )b
+--R                + 
+--R                                    4                    3
+--R                      (- 104C - 8A)D  + (112B C - 80A B)D
+--R                    + 
+--R                          3         2         2       2          2      3  2
+--R                      (56C  - 120A C  + (- 72B  - 120A )C + 24A B  - 72A )D
+--R                 *
+--R                       8
+--R                    a b
+--R                + 
+--R                         5         4       2               2       2  3
+--R                      94D  - 214B D  + (76C  + 440A C + 76B  + 484A )D
+--R                    + 
+--R                               2                 3       2   2
+--R                      (- 132B C  + 168A B C + 52B  + 468A B)D
+--R                    + 
+--R                               4         3       2       2  2
+--R                          - 66C  + 152A C  + (84B  + 108A )C
+--R                        + 
+--R                                  2      3        4      2 2      4
+--R                          (- 24A B  + 72A )C - 10B  - 36A B  + 54A
+--R                     *
+--R                        D
+--R                    + 
+--R                          4         3      3      2   2          3      3
+--R                      2B C  - 8A B C  + (4B  - 12A B)C  + (- 8A B  + 72A B)C
+--R                    + 
+--R                        5      2 3      4
+--R                      2B  + 12A B  - 54A B
+--R                 *
+--R                     2 7
+--R                    a b
+--R                + 
+--R                                      4                     3
+--R                      (- 662C - 182A)D  + (568B C - 824A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                            260C  - 1236A C  + (- 516B  - 1500A )C - 276A B
+--R                          + 
+--R                                  3
+--R                            - 772A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               3           2          3       2           3
+--R                          88B C  - 264A B C  + (- 136B  - 744A B)C + 40A B
+--R                        + 
+--R                                3
+--R                          - 136A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4         2      2  3         2      3  2
+--R                      26C  - 62A C  + (- 28B  - 52A )C  + (60A B  + 28A )C
+--R                    + 
+--R                          4       2 2      4         4       3 2      5
+--R                      (10B  - 156A B  - 38A )C - 6A B  + 140A B  - 30A
+--R                 *
+--R                     3 6
+--R                    a b
+--R                + 
+--R                            5         4         2                 2       2  3
+--R                      - 236D  + 416B D  + (1408C  + 1664A C - 248B  + 904A )D
+--R                    + 
+--R                               2                   3        2   2
+--R                      (- 456B C  + 2400A B C + 400B  + 3648A B)D
+--R                    + 
+--R                                4          3        2        2  2
+--R                          - 412C  + 1232A C  + (768B  + 1488A )C
+--R                        + 
+--R                                 2        3        4       2 2       4
+--R                          (672A B  + 1088A )C - 28B  + 120A B  + 476A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4          3       3       2   2
+--R                      - 16B C  + 80A B C  + (88B  + 264A B)C
+--R                    + 
+--R                            3       3         5      2 3       4
+--R                      (32A B  + 608A B)C + 16B  + 16A B  - 328A B
+--R                 *
+--R                     4 5
+--R                    a b
+--R                + 
+--R                                     4                         3
+--R                      (1204C - 908A)D  + (- 2768B C - 1568A B)D
+--R                    + 
+--R                                 3          2         2        2            2
+--R                          - 1456C  - 2352A C  + (- 48B  - 4296A )C - 3648A B
+--R                        + 
+--R                                 3
+--R                          - 1480A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2           3        2           3
+--R                          256B C  - 3120A B C  + (- 1184B  - 6288A B)C - 80A B
+--R                        + 
+--R                                 3
+--R                          - 1376A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          5         4          2       2  3
+--R                      164C  - 428A C  + (- 280B  - 544A )C
+--R                    + 
+--R                               2       3  2         4        2 2       4
+--R                      (- 120A B  - 112A )C  + (- 20B  - 1344A B  - 356A )C
+--R                    + 
+--R                             4       3 2       5
+--R                      - 68A B  + 800A B  - 196A
+--R                 *
+--R                     5 4
+--R                    a b
+--R                + 
+--R                          5         4           2                  2       2  3
+--R                      288D  + 640B D  + (- 1576C  + 1488A C + 1392B  + 760A )D
+--R                    + 
+--R                              2                  3       2   2
+--R                      (4872B C  + 8304A B C + 16B  - 600A B)D
+--R                    + 
+--R                              4         3         2        2  2
+--R                          968C  + 320A C  + (1128B  + 4800A )C
+--R                        + 
+--R                                  2        3         4        2 2       4
+--R                          (7152A B  + 3872A )C + 464B  + 3432A B  + 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4            3        3        2   2
+--R                      - 136B C  + 1376A B C  + (568B  + 3072A B)C
+--R                    + 
+--R                              3       3         5       2 3       4
+--R                      (1040A B  + 512A B)C + 16B  - 392A B  + 872A B
+--R                 *
+--R                     6 3
+--R                    a b
+--R                + 
+--R                                       4                        3
+--R                      (- 1248C + 288A)D  + (- 1152B C - 768A B)D
+--R                    + 
+--R                                3          2           2       2           2
+--R                            288C  - 1152A C  + (- 4224B  + 288A )C + 576A B
+--R                          + 
+--R                                3
+--R                            704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                   3            2          3        2
+--R                          - 3584B C  - 7872A B C  + (- 896B  - 2688A B)C
+--R                        + 
+--R                                   3        3
+--R                          - 3200A B  - 2240A B
+--R                     *
+--R                        D
+--R                    + 
+--R                            5         4          2        2  3
+--R                      - 352C  + 448A C  + (- 544B  - 1024A )C
+--R                    + 
+--R                                2        3  2          4        2 2       4
+--R                      (- 4800A B  - 2560A )C  + (- 800B  - 1056A B  - 416A )C
+--R                    + 
+--R                              4        3 2       5
+--R                      - 224A B  - 2560A B  + 320A
+--R                 *
+--R                     7 2
+--R                    a b
+--R                + 
+--R                            2                2       2  3
+--R                      (1728C  - 384A C + 384B  - 576A )D
+--R                    + 
+--R                             2                    3        2   2
+--R                      (576B C  - 1152A B C + 1152B  + 1344A B)D
+--R                    + 
+--R                              4          3         2        2  2
+--R                          320C  + 1536A C  + (2880B  - 1536A )C
+--R                        + 
+--R                                  2        3         4        2 2      4
+--R                          (1920A B  - 1792A )C + 384B  + 1344A B  - 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4            3        3        2   2
+--R                      960B C  + 1792A B C  + (960B  + 1536A B)C
+--R                    + 
+--R                              3        3          5        2 3       4
+--R                      (2176A B  + 2048A B)C + 128B  + 1984A B  + 320A B
+--R                 *
+--R                     8
+--R                    a b
+--R                + 
+--R                             3       2           2  2
+--R                      (- 768C  + 768A C - 1536A B )D
+--R                    + 
+--R                                2        3        3            4       2 3
+--R                      (1536A B C  - 1024B C + 512A B)D - 768A C  - 768B C
+--R                    + 
+--R                           3 2        2 2          4       5
+--R                      1024A C  - 2304A B C - 512A B  - 256A
+--R                 *
+--R                     9
+--R                    a
+--R             *
+--R                %%BN0
+--R            + 
+--R                       5          4   7
+--R                  (2A D b - 4A C D a)c
+--R                + 
+--R                            5         4  2
+--R                      (- B D  - 4A C D )b
+--R                    + 
+--R                                    5                  4         2     3  3
+--R                      ((- 2C + 10A)D  + (2B C - 14A B)D  + (12A C  + 4A )D )a b
+--R                    + 
+--R                        2             2  4            3          3     3   2  2
+--R                    ((4C  - 16A C + 4A )D  + 32A B C D  + (- 8A C  - 8A C)D )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 5                 4        2     3  3  3
+--R                      ((C - 19A)D  + (2B C + 6A B)D  + (2A C  - 2A )D )b
+--R                    + 
+--R                            6       5      2             2      2  4
+--R                          3D  - 2B D  + (2C  + 28A C + 7B  + 18A )D
+--R                        + 
+--R                                 2              2   3          3     3   2
+--R                          (- 6B C  - 4A B C - 6A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                           2
+--R                        a b
+--R                    + 
+--R                                       5                   4
+--R                          (- 16C + 8A)D  + (16B C - 80A B)D
+--R                        + 
+--R                                3        2         2      2          2      3  3
+--R                          (- 12C  + 28A C  + (- 16B  - 68A )C + 32A B  + 20A )D
+--R                        + 
+--R                               3          2      2         3   2
+--R                          (4B C  - 36A B C  + 12A B C - 12A B)D
+--R                        + 
+--R                                4      3 2     5
+--R                          (10A C  - 12A C  + 2A )D
+--R                     *
+--R                         2
+--R                        a b
+--R                    + 
+--R                              2              2  4
+--R                          (16C  - 16A C + 16A )D
+--R                        + 
+--R                                  2                 2   3
+--R                          (- 32B C  + 128A B C - 32A B)D
+--R                        + 
+--R                             4        3      2 2           2      3       4  2
+--R                          (8C  - 32A C  + 48A C  + (- 96A B  - 32A )C + 8A )D
+--R                        + 
+--R                                  3      3            5     3 3     5
+--R                          (32A B C  + 32A B C)D - 4A C  + 8A C  - 4A C
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                             6       5        2             2     2  4
+--R                          - D  + 8B D  + (- 2C  + 32A C - 3B  - 6A )D
+--R                        + 
+--R                                2              2   3
+--R                          (- B C  - 6A B C + 3A B)D
+--R                     *
+--R                         4
+--R                        b
+--R                    + 
+--R                                      5                      4
+--R                          (14C - 46A)D  + (- 30B C + 130A B)D
+--R                        + 
+--R                             3        2      2      2          2      3  3
+--R                          (4C  - 96A C  + (2B  + 12A )C - 18A B  - 48A )D
+--R                        + 
+--R                               3          2      2     2
+--R                          (4B C  + 24A B C  - 12A B C)D
+--R                     *
+--R                           3
+--R                        a b
+--R                    + 
+--R                             6        5        2              2      2  4
+--R                          10D  - 16B D  + (- 6C  + 76A C + 18B  + 58A )D
+--R                        + 
+--R                                2                 3      2   3
+--R                          (24B C  - 240A B C - 16B  - 72A B)D
+--R                        + 
+--R                                4        3       2      2  2         2       3
+--R                              4C  + 64A C  + (18B  + 24A )C  + (60A B  + 128A )C
+--R                            + 
+--R                                 2 2     4
+--R                              18A B  + 4A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 4          3      2   2     3        4
+--R                          (- 5B C  - 28A B C  + 18A B C  + 4A B C - 5A B)D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                                       5                    4
+--R                          (- 24C - 8A)D  + (120B C - 72A B)D
+--R                        + 
+--R                                     3        2         2       2           2
+--R                                - 40C  + 40A C  + (- 48B  - 248A )C + 240A B
+--R                              + 
+--R                                   3
+--R                                56A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                   3          2       3       2           3
+--R                              40B C  - 72A B C  + (48B  + 312A B)C - 16A B
+--R                            + 
+--R                                   3
+--R                              - 88A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2      2  3      3 2
+--R                              - 10C  + 18A C  + (- 16B  - 36A )C  - 92A C
+--R                            + 
+--R                                    2 2      4        5
+--R                              (- 48A B  - 18A )C + 10A
+--R                         *
+--R                            D
+--R                        + 
+--R                            5          4      2   3      3   2      4        5
+--R                        2B C  + 10A B C  - 12A B C  - 12A B C  + 10A B C + 2A B
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                              2      2  4            2                  2   3
+--R                          (16C  + 16A )D  + (- 128B C  + 128A B C - 128A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              32C  - 64A C  + (96B  + 192A )C
+--R                            + 
+--R                                       2      3        2 2      4
+--R                              (- 384A B  - 64A )C + 96A B  + 32A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4           3       2   2
+--R                              - 32B C  + 128A B C  - 192A B C
+--R                            + 
+--R                                     3       3         4
+--R                              (128A B  + 128A B)C - 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            6        5     2 4           2      3  3     4 2
+--R                          4C  - 16A C  - 4A C  + (- 32A B  + 32A )C  - 4A C
+--R                        + 
+--R                                3 2      5       6
+--R                          (- 32A B  - 16A )C + 4A
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       5                     4
+--R                          (- 5C + 59A)D  + (- 10B C - 42A B)D
+--R                        + 
+--R                            3        2      2     2         2      3  3
+--R                          (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                     *
+--R                         5
+--R                        b
+--R                    + 
+--R                               6        5         2               2       2  4
+--R                          - 22D  + 14B D  + (- 14C  - 112A C - 50B  - 162A )D
+--R                        + 
+--R                                2                3       2   3
+--R                          (46B C  + 20A B C + 10B  + 102A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 52A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 68A )C
+--R                         *
+--R                             2
+--R                            D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                                      5                       4
+--R                          (72C + 40A)D  + (- 160B C + 288A B)D
+--R                        + 
+--R                              3        2        2       2           2      3  3
+--R                          (66C  - 46A C  + (144B  + 598A )C - 304A B  - 58A )D
+--R                        + 
+--R                                  3           2         3       2         3   2
+--R                          (- 80B C  + 264A B C  + (- 32B  - 336A B)C + 88A B)D
+--R                        + 
+--R                                5        4       2      2  3        2      3  2
+--R                              5C  - 67A C  + (14B  + 10A )C  + (6A B  + 98A )C
+--R                            + 
+--R                                   2 2    4       3 2      5
+--R                              (- 6A B  + A )C + 2A B  - 15A
+--R                         *
+--R                            D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                 5         2              2  4
+--R                          - 80B D  + (- 64C  - 128A C + 8B )D
+--R                        + 
+--R                                 2                 3       2   3
+--R                          (208B C  - 480A B C - 64B  - 176A B)D
+--R                        + 
+--R                                   4         3          2       2  2
+--R                              - 41C  + 116A C  + (- 144B  - 582A )C
+--R                            + 
+--R                                     2      3       4      2 2      4
+--R                              (672A B  - 12A )C + 8B  + 48A B  - 41A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3       2   2
+--R                              50B C  - 328A B C  + 204A B C
+--R                            + 
+--R                                      3       3         4
+--R                              (- 64A B  - 200A B)C - 14A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              6        5        2     2  4        2      3  3
+--R                          - 2C  + 28A C  + (- 5B  + 2A )C  + (4A B  - 56A )C
+--R                        + 
+--R                              2 2     4  2      3 2      5       4 2     6
+--R                          (18A B  + 2A )C  + (4A B  + 28A )C - 5A B  - 2A
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                                           4
+--R                          (192B C + 64A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 16C  + 208A C  + (- 320B  - 176A )C + 256A B
+--R                            + 
+--R                                  3
+--R                              112A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                   3           2       3        2            3
+--R                              80B C  - 144A B C  + (64B  + 1008A B)C - 320A B
+--R                            + 
+--R                                    3
+--R                              - 304A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5       4         2       2  3
+--R                              - 24C  - 8A C  + (- 16B  + 144A )C
+--R                            + 
+--R                                      2       3  2         4       2 2     4
+--R                              (- 48A B  + 112A )C  + (- 64B  - 432A B  + 8A )C
+--R                            + 
+--R                                     4       3 2      5
+--R                              - 32A B  + 112A B  + 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5          4       3      2   3
+--R                          - 8B C  + 88A B C  + (16B  + 48A B)C
+--R                        + 
+--R                              3      3   2       2 3      4         3 3     5
+--R                        (48A B  + 48A B)C  + (48A B  + 88A B)C + 16A B  - 8A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                   2       2   3
+--R                          (- 128B C  - 128A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              32C  - 128A C  + (384B  + 192A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 384A B  - 128A )C + 384A B  + 32A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3       2   2
+--R                              - 128B C  + 256A B C  + (- 128B  - 768A B)C
+--R                            + 
+--R                                     3       3          2 3       4
+--R                              (512A B  + 256A B)C - 128A B  - 128A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6       2      2  4         2 3
+--R                          16C  + (32B  - 16A )C  - 128A B C
+--R                        + 
+--R                               2 2      4  2           4       3 2        4 2
+--R                          (192A B  - 16A )C  + (- 64A B  - 128A B )C + 32A B
+--R                        + 
+--R                             6
+--R                          16A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            6        5       2              2      2  4
+--R                          6D  - 22B D  + (10C  - 76A C + 18B  + 42A )D
+--R                        + 
+--R                               2               3      2   3
+--R                          (2B C  + 36A B C - 2B  - 30A B)D
+--R                     *
+--R                         6
+--R                        b
+--R                    + 
+--R                                       5                     4
+--R                          (- 18C + 6A)D  + (148B C - 260A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 22C  + 262A C  + (- 34B  - 114A )C + 102A B
+--R                            + 
+--R                                  3
+--R                              114A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                 3           2      3       2     2
+--R                          (- 8B C  - 144A B C  + (8B  + 120A B)C)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                               6         5        2              2       2  4
+--R                          - 15D  + 136B D  + (- 8C  + 48A C - 22B  - 216A )D
+--R                        + 
+--R                                   2                  3       2   3
+--R                          (- 162B C  + 436A B C + 112B  + 486A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 11C  - 268A C  + (- 24B  - 18A )C
+--R                            + 
+--R                                       2       3       4       2 2      4
+--R                              (- 288A B  - 300A )C - 3B  - 120A B  - 27A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3        3       2   2
+--R                              12B C  + 184A B C  + (- 6B  - 144A B)C
+--R                            + 
+--R                                    3      3        2 3      4
+--R                              (12A B  - 24A B)C + 2A B  + 36A B
+--R                         *
+--R                            D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                                      5                       4
+--R                          (56C + 72A)D  + (- 464B C - 208A B)D
+--R                        + 
+--R                              3         2        2       2           2      3  3
+--R                          (84C  - 300A C  + (448B  + 908A )C - 704A B  + 12A )D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 208B C  + 336A B C  + (- 256B  - 1824A B)C
+--R                            + 
+--R                                    3       3
+--R                              256A B  + 448A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5        4       2       2  3
+--R                              48C  + 72A C  + (92B  + 160A )C
+--R                            + 
+--R                                     2       3  2       4       2 2       4
+--R                              (108A B  + 272A )C  + (40B  + 516A B  + 112A )C
+--R                            + 
+--R                                   4      3 2      5
+--R                              24A B  - 12A B  - 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5          4      2   3           3      3   2
+--R                          - 6B C  - 78A B C  + 52A B C  + (- 16A B  + 52A B)C
+--R                        + 
+--R                                2 3      4        5
+--R                          (- 16A B  - 78A B)C - 6A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                2                2      2  4
+--R                          (- 72C  - 240A C + 240B  - 72A )D
+--R                        + 
+--R                                 2                 3      2   3
+--R                          (480B C  + 576A B C + 96B  + 96A B)D
+--R                        + 
+--R                                   4         3          2        2  2
+--R                              - 98C  + 456A C  + (- 768B  - 1068A )C
+--R                            + 
+--R                                      2       3         4      4
+--R                              (1152A B  - 312A )C + 112B  + 30A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3        3        2   2
+--R                              348B C  - 560A B C  + (224B  + 1512A B)C
+--R                            + 
+--R                                       3       3         5      2 3      4
+--R                              (- 704A B  - 304A B)C + 16B  + 96A B  + 92A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               6         2      2  4         2       3  3
+--R                          - 24C  + (- 42B  - 40A )C  + (40A B  - 128A )C
+--R                        + 
+--R                                4       2 2      4  2           4      3 2
+--R                          (- 24B  - 348A B  - 40A )C  + (- 16A B  + 40A B )C
+--R                        + 
+--R                               2 4      4 2      6
+--R                          - 24A B  - 42A B  - 24A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                   3         2          2      2           2
+--R                                32C  + 288A C  + (- 576B  + 96A )C - 192A B
+--R                              + 
+--R                                   3
+--R                                96A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                     3           2        3       2            3
+--R                              - 32B C  - 864A B C  + (320B  + 672A B)C - 448A B
+--R                            + 
+--R                                    3
+--R                              - 544A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              32C  - 256A C  + (160B  + 320A )C
+--R                            + 
+--R                                    2       3  2         4        2 2      4
+--R                              (96A B  + 512A )C  + (- 32B  - 1056A B  - 96A )C
+--R                            + 
+--R                                    4       3 2
+--R                              160A B  + 544A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5          4         3       2   3
+--R                          - 96B C  + 32A B C  + (- 32B  - 192A B)C
+--R                        + 
+--R                                 3       3   2       5       2 3      4
+--R                          (160A B  - 192A B)C  + (32B  + 160A B  + 32A B)C
+--R                        + 
+--R                               5      3 3      5
+--R                          32A B  - 32A B  - 96A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                   3       2 2       3        2 2  2
+--R                          (- 128A C  + 384B C  - 128A C + 384A B )D
+--R                        + 
+--R                                      4           3          3       2   2
+--R                              - 128B C  + 512A B C  + (- 512B  - 768A B)C
+--R                            + 
+--R                                     3       3          2 3       4
+--R                              (512A B  + 512A B)C - 512A B  - 128A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5       2 4            2       3  3
+--R                          64A C  + 128B C  + (- 256A B  - 128A )C
+--R                        + 
+--R                              4       2 2  2            4       3 2      5
+--R                          (64B  + 768A B )C  + (- 256A B  - 256A B  + 64A )C
+--R                        + 
+--R                             2 4       4 2
+--R                          64A B  + 128A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                     5                  4
+--R                          (4C - 60A)D  + (8B C + 72A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  3
+--R                          (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                     *
+--R                         7
+--R                        b
+--R                    + 
+--R                             6        5                2       2  4
+--R                          32D  - 48B D  + (208A C + 64B  + 336A )D
+--R                        + 
+--R                                   2                3       2   3
+--R                          (- 112B C  - 64A B C - 48B  - 336A B)D
+--R                        + 
+--R                            4        3       2      2  2         2       3    2
+--R                        (16C  - 80A C  + (48B  + 48A )C  + (48A B  + 144A )C)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                                          5                    4
+--R                          (- 145C - 177A)D  + (180B C + 84A B)D
+--R                        + 
+--R                                   3         2          2        2           2
+--R                              - 54C  - 178A C  + (- 458B  - 1442A )C + 470A B
+--R                            + 
+--R                                    3
+--R                              - 294A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2           3
+--R                              332B C  - 348A B C  + (140B  + 1188A B)C - 20A B
+--R                            + 
+--R                                    3
+--R                              - 180A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4         2      2  3
+--R                              - 21C  + 103A C  + (- 66B  - 50A )C
+--R                            + 
+--R                                      2       3  2        4     2 2     4
+--R                              (- 54A B  - 210A )C  + (- 5B  - 6A B  - 9A )C
+--R                            + 
+--R                                    4      3 2      5
+--R                              - 5A B  - 18A B  + 27A
+--R                         *
+--R                            D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                               5        2                2       2  4
+--R                          60B D  + (213C  + 794A C - 280B  + 261A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 164B C  - 392A B C - 48B  + 348A B)D
+--R                        + 
+--R                                  4        3        2        2  2
+--R                              118C  - 56A C  + (870B  + 2100A )C
+--R                            + 
+--R                                       2        3         4       2 2     4
+--R                              (- 900A B  + 1256A )C - 104B  - 426A B  + 6A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 352B C  + 480A B C  + (- 124B  - 1056A B)C
+--R                            + 
+--R                                     3       3         5      2 3
+--R                              (104A B  + 160A B)C - 12B  - 92A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            6        5       2     2  4         2       3  3
+--R                          9C  - 42A C  + (30B  + 7A )C  + (24A B  + 116A )C
+--R                        + 
+--R                             4      2 2     4  2         4      3 2      5
+--R                          (5B  - 12A B  + 7A )C  + (10A B  + 24A B  - 42A )C
+--R                        + 
+--R                            2 4      4 2     6
+--R                          5A B  + 30A B  + 9A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                              4
+--R                          (- 224B C - 288A B)D
+--R                        + 
+--R                                   3          2        2       2           2
+--R                              - 24C  - 1432A C  + (992B  - 712A )C + 352A B
+--R                            + 
+--R                                    3
+--R                              - 328A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 144B C  + 816A B C  + (- 320B  - 1776A B)C
+--R                            + 
+--R                                    3       3
+--R                              832A B  + 336A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4          2        2  3
+--R                              - 92C  + 100A C  + (- 488B  - 1208A )C
+--R                            + 
+--R                                       2        3  2
+--R                              (- 168A B  - 1560A )C
+--R                            + 
+--R                                   4        2 2       4          4       3 2
+--R                              (176B  + 1608A B  - 172A )C - 16A B  - 760A B
+--R                            + 
+--R                                   5
+--R                              - 12A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5           4       3       2   3
+--R                          120B C  - 104A B C  + (16B  + 112A B)C
+--R                        + 
+--R                                  3       3   2         2 3       4         3 3
+--R                          (- 16A B  + 112A B)C  + (- 16A B  - 104A B)C + 16A B
+--R                        + 
+--R                              5
+--R                          120A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                 2                  3       2   3
+--R                          (288B C  + 960A B C - 320B  + 288A B)D
+--R                        + 
+--R                                    4          3           2       2  2
+--R                              - 236C  + 1264A C  + (- 1152B  + 696A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 768A B  + 496A )C - 208B  - 384A B  + 276A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3        3        2   2
+--R                              280B C  - 608A B C  + (768B  + 2064A B)C
+--R                            + 
+--R                                        3      3         5       2 3      4
+--R                              (- 1280A B  - 96A B)C - 96B  + 256A B  + 24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5      2       2  4          2       3  3
+--R                          24C  - 16A C  + (4B  + 232A )C  + (560A B  + 544A )C
+--R                        + 
+--R                                4       2 2       4  2
+--R                          (- 96B  - 936A B  + 232A )C
+--R                        + 
+--R                                 4       3 2      5        6      2 4     4 2
+--R                          (192A B  + 560A B  - 16A )C - 16B  - 96A B  + 4A B
+--R                        + 
+--R                             6
+--R                          24A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                      3            2        3       2
+--R                              - 128B C  - 1152A B C  + (768B  - 384A B)C
+--R                            + 
+--R                                    3       3
+--R                              256A B  - 384A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  5         4        2       2  3         2 2
+--R                              224C  - 512A C  + (320B  - 320A )C  + 960A B C
+--R                            + 
+--R                                     2 2       4           4       3 2
+--R                              (- 576A B  - 416A )C + 384A B  + 832A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5          4          3       2   3
+--R                          - 96B C  + 32A B C  + (- 320B  - 448A B)C
+--R                        + 
+--R                                3       3   2       2 3      4          3 3
+--R                          (64A B  - 448A B)C  + (64A B  + 32A B)C - 320A B
+--R                        + 
+--R                               5
+--R                          - 96A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                   3       3 2       3          2 3        6
+--R                          (512A B C  - 512B C  + 512A B C - 512A B )D - 64C
+--R                        + 
+--R                               5        2      2  4            2       3  3
+--R                          64A C  + (128B  + 64A )C  + (- 512A B  - 128A )C
+--R                        + 
+--R                               4       2 2      4  2
+--R                          (256B  + 768A B  + 64A )C
+--R                        + 
+--R                                 4       3 2      5         2 4       4 2      6
+--R                        (- 256A B  - 512A B  + 64A )C + 256A B  + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                          6        5        2              2      2  4
+--R                      - 8D  + 24B D  + (- 8C  + 48A C - 24B  - 72A )D
+--R                    + 
+--R                           2               3      2   3
+--R                      (8B C  - 48A B C + 8B  + 72A B)D
+--R                 *
+--R                     8
+--R                    b
+--R                + 
+--R                                   5                      4
+--R                      (24C + 120A)D  + (- 144B C - 48A B)D
+--R                    + 
+--R                          3         2        2       2          2      3  3
+--R                      (40C  - 232A C  + (152B  + 312A )C - 72A B  + 72A )D
+--R                    + 
+--R                              3           2         3       2     2
+--R                      (- 32B C  + 192A B C  + (- 32B  - 288A B)C)D
+--R                 *
+--R                       7
+--R                    a b
+--R                + 
+--R                           6        5       2               2       2  4
+--R                      - 10D  - 78B D  + (28C  - 648A C + 84B  - 228A )D
+--R                    + 
+--R                             2                 3      2   3
+--R                      (332B C  + 312A B C - 20B  - 84A B)D
+--R                    + 
+--R                               4         3          2       2  2
+--R                          - 74C  + 408A C  + (- 324B  - 444A )C
+--R                        + 
+--R                                 2       3        4       2 2      4
+--R                          (120A B  - 360A )C + 22B  + 252A B  + 54A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          42B C  - 248A B C  + (44B  + 348A B)C
+--R                        + 
+--R                                 3      3        5      2 3      4
+--R                          (- 8A B  + 72A B)C + 2B  + 12A B  - 54A B
+--R                     *
+--R                        D
+--R                 *
+--R                     2 6
+--R                    a b
+--R                + 
+--R                                  5                     4
+--R                      (84C - 12A)D  + (414B C + 318A B)D
+--R                    + 
+--R                                3          2          2       2           2
+--R                          - 208C  + 1424A C  + (- 376B  + 912A )C - 216A B
+--R                        + 
+--R                              3
+--R                          304A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3           2        3       2            3
+--R                          - 356B C  - 780A B C  + (196B  + 468A B)C - 348A B
+--R                        + 
+--R                                3
+--R                          - 132A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5         4        2       2  3
+--R                          60C  - 308A C  + (272B  + 216A )C
+--R                        + 
+--R                                 2       3  2         4       2 2      4
+--R                          (144A B  + 536A )C  + (- 60B  - 912A B  - 84A )C
+--R                        + 
+--R                              4       3 2      5
+--R                          4A B  + 240A B  - 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4         3       2   3
+--R                      - 18B C  + 102A B C  + (- 20B  - 116A B)C
+--R                    + 
+--R                           3       3   2        5     2 3       4          5
+--R                      (4A B  - 116A B)C  + (- 2B  + 4A B  + 102A B)C - 2A B
+--R                    + 
+--R                           3 3      5
+--R                      - 20A B  - 18A B
+--R                 *
+--R                     3 5
+--R                    a b
+--R                + 
+--R                             2              2      2  4
+--R                      (- 290C  + 60A C - 60B  + 30A )D
+--R                    + 
+--R                               2                   3       2   3
+--R                      (- 880B C  - 1344A B C + 192B  - 528A B)D
+--R                    + 
+--R                              4          3        2        2  2
+--R                          340C  - 1584A C  + (612B  - 1416A )C
+--R                        + 
+--R                                 2       3        4      2 2       4
+--R                          (840A B  - 816A )C + 88B  + 36A B  - 300A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3          3       2   2         3
+--R                          168B C  + 832A B C  + (- 400B  - 624A B)C  + 832A B C
+--R                        + 
+--R                             5       2 3       4
+--R                          32B  + 144A B  + 264A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6        5         2      2  4
+--R                      - 18C  + 84A C  + (- 72B  - 14A )C
+--R                    + 
+--R                               2       3  3       4       2 2      4  2
+--R                      (- 224A B  - 232A )C  + (46B  + 720A B  - 14A )C
+--R                    + 
+--R                            4       3 2      5       6      2 4      4 2      6
+--R                    (- 36A B  - 224A B  + 84A )C + 4B  + 46A B  - 72A B  - 18A
+--R                 *
+--R                     4 4
+--R                    a b
+--R                + 
+--R                           3         2        2       2           2      3  3
+--R                      (528C  - 112A C  + (224B  - 144A )C + 288A B  - 16A )D
+--R                    + 
+--R                                3            2          3        2            3
+--R                          928B C  + 2208A B C  + (- 704B  + 1440A B)C - 192A B
+--R                        + 
+--R                              3
+--R                          672A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5         4          2        2  3
+--R                          - 240C  + 880A C  + (- 400B  + 1056A )C
+--R                        + 
+--R                                    2       3  2         4       2 2       4
+--R                          (- 1296A B  + 608A )C  + (- 96B  + 528A B  + 720A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 416A B  - 624A B  + 48A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4        3       2   3
+--R                      - 24B C  - 312A B C  + (224B  + 208A B)C
+--R                    + 
+--R                               3       3   2         5       2 3       4
+--R                      (- 416A B  + 208A B)C  + (- 32B  - 416A B  - 312A B)C
+--R                    + 
+--R                             5       3 3      5
+--R                      - 32A B  + 224A B  - 24A B
+--R                 *
+--R                     5 3
+--R                    a b
+--R                + 
+--R                                4        3          2       2  2
+--R                          - 536C  + 96A C  + (- 288B  + 240A )C
+--R                        + 
+--R                                   2      3         4       2 2      4
+--R                          (- 960A B  + 96A )C + 160B  - 288A B  - 24A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3        3        2   2
+--R                          - 480B C  - 1664A B C  + (896B  - 1344A B)C
+--R                        + 
+--R                                 3        3          5       2 3       4
+--R                          (256A B  - 1152A B)C + 128B  + 384A B  - 480A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6         5       2       2  4          2       3  3
+--R                      64C  - 192A C  + (72B  - 320A )C  + (736A B  - 128A )C
+--R                    + 
+--R                            4       2 2       4  2
+--R                      (- 32B  - 720A B  - 320A )C
+--R                    + 
+--R                           4       3 2       5        6      2 4      4 2      6
+--R                    (576A B  + 736A B  - 192A )C + 32B  - 32A B  + 72A B  + 64A
+--R                 *
+--R                     6 2
+--R                    a b
+--R                + 
+--R                              5        4        2       2  3
+--R                          288C  - 32A C  + (128B  - 192A )C
+--R                        + 
+--R                                  2      3  2          4       2 2      4
+--R                          (1152A B  - 64A )C  + (- 384B  + 384A B  - 96A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 128A B  + 384A B  + 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4          3       2   3
+--R                      96B C  + 480A B C  + (- 384B  + 448A B)C
+--R                    + 
+--R                               3       3   2          5       2 3       4
+--R                      (- 128A B  + 448A B)C  + (- 128B  - 128A B  + 480A B)C
+--R                    + 
+--R                              5       3 3      5
+--R                      - 128A B  - 384A B  + 96A B
+--R                 *
+--R                     7
+--R                    a b
+--R                + 
+--R                           6      2 4         2 3        4      4  2       3 2
+--R                      - 64C  + 64A C  - 512A B C  + (256B  + 64A )C  - 512A B C
+--R                    + 
+--R                          2 4      6
+--R                      256A B  - 64A
+--R                 *
+--R                     8
+--R                    a
+--R             *
+--R                x
+--R            + 
+--R                3 3   7
+--R              4A D a c
+--R            + 
+--R                      5     3 3  2
+--R                  (A D  - 2A D )b
+--R                + 
+--R                         5               2  4     2   3     3   2
+--R                  (- 2B D  + (- 2A C - 4A )D  - 6A B D  + 6A C D )a b
+--R                + 
+--R                            4        2        2      3  3      3   2
+--R                      4B C D  + (- 4A C + 4A B  + 16A )D  - 20A B D
+--R                    + 
+--R                            3 2     5
+--R                      (- 12A C  + 4A )D
+--R                 *
+--R                     2
+--R                    a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                              2  4     2   3  3
+--R                  ((- 2A C + A )D  + 3A B D )b
+--R                + 
+--R                               5                 4        2      2       3  3
+--R                      (C + 6A)D  + (4B C - 3A B)D  + (6A C  + 14A C - 53A )D
+--R                    + 
+--R                           2        3   2
+--R                      (- 9A B C + 2A B)D
+--R                 *
+--R                       2
+--R                    a b
+--R                + 
+--R                        6        5        2             2  4
+--R                      2D  - 10B D  + (- 2C  - 2A C + 10B )D
+--R                    + 
+--R                              2               3  3
+--R                      (- 12B C  + 12A B C - 2B )D
+--R                    + 
+--R                             3      2 2        2      3        2 2      4  2
+--R                      (- 4A C  - 30A C  + (6A B  + 64A )C + 30A B  + 14A )D
+--R                    + 
+--R                          2   2      3         4        3 3     5
+--R                      (18A B C  + 12A B C - 10A B)D + 2A C  - 2A C
+--R                 *
+--R                     2
+--R                    a b
+--R                + 
+--R                            5                   4
+--R                      - 4C D  + (16B C - 12A B)D
+--R                    + 
+--R                             2         2      2          2     3  3
+--R                      (- 4A C  + (- 28B  - 16A )C + 16A B  - 4A )D
+--R                    + 
+--R                           3      2           3      3   2
+--R                      (8B C  + 24A B C - 20A B  - 80A B)D
+--R                    + 
+--R                          2 3           2      3  2     4       3 2      5
+--R                      (44A C  + (- 12A B  - 48A )C  + 4A C + 36A B  + 16A )D
+--R                    + 
+--R                         3   2     5
+--R                      20A B C  - 4A B
+--R                 *
+--R                     3
+--R                    a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                         5         4       2     2       2      3  3  4
+--R                  (- 9A D  + 2A B D  + (A C  - 4A C - A B  + 19A )D )b
+--R                + 
+--R                         6        5        2            2      2  4
+--R                      - D  + 17B D  + (- 2C  + 5A C - 5B  + 33A )D
+--R                    + 
+--R                             2              3      2   3
+--R                      (- 2B C  - 10A B C + B  + 60A B)D
+--R                    + 
+--R                             3      2 2        2      3       2 2     4  2
+--R                      (- 4A C  + 12A C  + (3A B  - 58A )C - 3A B  - 2A )D
+--R                 *
+--R                       3
+--R                    a b
+--R                + 
+--R                            5                     4
+--R                      - 5A D  + (- 27B C - 52A B)D
+--R                    + 
+--R                         3        2       2      2          2      3  3
+--R                      (6C  + 10A C  + (12B  + 88A )C - 49A B  - 92A )D
+--R                    + 
+--R                           3        3       2          3       3   2
+--R                      (8B C  + (- 3B  - 102A B)C - 8A B  + 148A B)D
+--R                    + 
+--R                              4      2 3          2      3  2
+--R                          5A C  - 20A C  + (- 6A B  + 93A )C
+--R                        + 
+--R                                2 2     4       3 2      5
+--R                          (- 18A B  - 2A )C - 2A B  - 32A
+--R                     *
+--R                        D
+--R                    + 
+--R                          2   3     3   2     4        5
+--R                      - 3A B C  - 8A B C  + 5A B C + 2A B
+--R                 *
+--R                     2 2
+--R                    a b
+--R                + 
+--R                         6        5      2              2      2  4
+--R                      10D  - 16B D  + (6C  + 28A C + 68B  + 50A )D
+--R                    + 
+--R                              2                3     2   3
+--R                      (- 18B C  + 76A B C - 16B  + 2A B)D
+--R                    + 
+--R                              4        3       2       2  2         2      3
+--R                          - 4C  + 22A C  + (18B  - 258A )C  + (36A B  + 94A )C
+--R                        + 
+--R                             4      2 2      4
+--R                          10B  + 78A B  + 26A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4         3      3      2   2
+--R                          - 10B C  - 4A B C  + (6B  + 24A B)C
+--R                        + 
+--R                                3       3         2 3      4
+--R                          (12A B  - 100A B)C - 54A B  - 94A B
+--R                     *
+--R                        D
+--R                    + 
+--R                            5     2 4        2      3  3         2 2      4  2
+--R                      - 2A C  - 6A C  + (2A B  - 12A )C  + (- 30A B  - 16A )C
+--R                    + 
+--R                            3 2     5        4 2     6
+--R                      (- 38A B  - 2A )C + 10A B  + 6A
+--R                 *
+--R                     3
+--R                    a b
+--R                + 
+--R                                   5                   4
+--R                      (- 16C + 8A)D  + (40B C - 48A B)D
+--R                    + 
+--R                           3        2          2     2          2      3  3
+--R                      (- 4C  - 16A C  + (- 112B  + 4A )C + 72A B  - 80A )D
+--R                    + 
+--R                            3          2       3      2           3     3   2
+--R                      (32B C  + 12A B C  + (72B  + 96A B)C - 80A B  + 4A B)D
+--R                    + 
+--R                                 4         2       2  3           2      3  2
+--R                          - 52A C  + (- 12B  + 176A )C  + (- 48A B  - 64A )C
+--R                        + 
+--R                                2 2      4          4       3 2      5
+--R                          (- 36A B  + 16A )C + 32A B  + 144A B  - 12A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5      2   3         3      3   2      4         3 3
+--R                      4B C  - 80A B C  + (20A B  + 80A B)C  - 20A B C - 20A B
+--R                    + 
+--R                           5
+--R                      - 16A B
+--R                 *
+--R                     4
+--R                    a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                              2  4      2   3  5
+--R                  ((16A C - 8A )D  - 24A B D )b
+--R                + 
+--R                                   5                     4
+--R                      (- 5C - 20A)D  + (- 26B C + 49A B)D
+--R                    + 
+--R                        3        2      2       2         2       3  3
+--R                      (C  - 34A C  + (3B  - 135A )C - 2A B  + 196A )D
+--R                    + 
+--R                             2      2         3      3   2
+--R                      (3A B C  + 78A B C + A B  - 13A B)D
+--R                 *
+--R                       4
+--R                    a b
+--R                + 
+--R                           6        5       2              2      2  4
+--R                      - 16D  + 47B D  + (12C  + 13A C - 99B  - 96A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (77B C  - 86A B C + 29B  - 102A B)D
+--R                    + 
+--R                              4       3         2       2  2        2       3
+--R                          - 4C  - 4A C  + (- 15B  + 378A )C  + (3A B  - 335A )C
+--R                        + 
+--R                             4       2 2       4
+--R                          - B  - 201A B  - 105A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             2   2        3      3         2 3      4        2 4
+--R                      (- 105A B C  + (6A B  - 48A B)C + 13A B  + 89A B)D + 3A C
+--R                    + 
+--R                          2     3  3       2 2     4  2      3 2      5
+--R                      (A B  - 9A )C  + (12A B  + 3A )C  + (6A B  + 13A )C
+--R                    + 
+--R                          4 2     6
+--R                      - 5A B  - 2A
+--R                 *
+--R                     2 3
+--R                    a b
+--R                + 
+--R                                  5                      4
+--R                      (20C - 22A)D  + (- 114B C + 30A B)D
+--R                    + 
+--R                           3         2        2       2          2       3  3
+--R                      (- 2C  - 129A C  + (242B  + 254A )C + 38A B  + 221A )D
+--R                    + 
+--R                                 3          2         3      2            3
+--R                          - 59B C  - 42A B C  + (- 86B  - 69A B)C + 146A B
+--R                        + 
+--R                              3
+--R                          266A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                            5        4       2       2  3         2       3  2
+--R                          5C  + 50A C  + (14B  - 388A )C  + (81A B  + 218A )C
+--R                        + 
+--R                               4       2 2      4         4       3 2     5
+--R                          (- 6B  + 198A B  + 79A )C + 8A B  - 101A B  + 4A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4       3      2   3        3      3   2
+--R                      7A B C  + (- B  + 82A B)C  + (2A B  - 68A B)C
+--R                    + 
+--R                          2 3      4         3 3      5
+--R                      (57A B  + 62A B)C + 14A B  + 13A B
+--R                 *
+--R                     3 2
+--R                    a b
+--R                + 
+--R                        6        5       2              2      2  4
+--R                      8D  - 48B D  + (14C  - 20A C + 80B  + 38A )D
+--R                    + 
+--R                            2                 3       2   3
+--R                      (32B C  - 64A B C - 160B  - 272A B)D
+--R                    + 
+--R                               4         3         2       2  2
+--R                          - 12C  + 344A C  + (- 84B  - 384A )C
+--R                        + 
+--R                                   2      3       4      2 2      4
+--R                          (- 264A B  - 72A )C + 8B  + 12A B  - 68A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4           3       2   2
+--R                          - 16B C  + 112A B C  + 336A B C
+--R                        + 
+--R                                  3       3         5       2 3      4
+--R                          (- 64A B  - 208A B)C - 16B  - 208A B  - 64A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6       5         2      2  4        2      3  3
+--R                      - 2C  - 4A C  + (- 12B  + 66A )C  + (8A B  + 40A )C
+--R                    + 
+--R                            4      2 2      4  2           4     3 2      5
+--R                      (- 10B  + 48A B  - 14A )C  + (- 36A B  + 8A B  + 28A )C
+--R                    + 
+--R                         2 4       4 2      6
+--R                      30A B  + 108A B  + 14A
+--R                 *
+--R                     4
+--R                    a b
+--R                + 
+--R                                    5                   4
+--R                      (- 16C + 32A)D  + (96B C - 80A B)D
+--R                    + 
+--R                            3          2      2           2      3  3
+--R                      (- 16C  + (- 160B  + 80A )C + 224A B  - 64A )D
+--R                    + 
+--R                              2       3          3       3   2
+--R                      (48A B C  + 288B C - 160A B  + 336A B)D
+--R                    + 
+--R                             5         4         2       2  3      3 2
+--R                          16C  - 208A C  + (- 48B  + 160A )C  - 64A C
+--R                        + 
+--R                                4       2 2      4           4       5
+--R                          (- 80B  - 144A B  + 80A )C + 128A B  - 112A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5          4       2   3         3       3   2
+--R                      16B C  + 80A B C  - 320A B C  + (80A B  + 160A B)C
+--R                    + 
+--R                           4           5      3 3      5
+--R                      - 80A B C - 16A B  - 80A B  + 16A B
+--R                 *
+--R                     5
+--R                    a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                        5          4          2      2        2      3  3  6
+--R                  (24A D  - 16A B D  + (- 8A C  + 32A C + 8A B  - 56A )D )b
+--R                + 
+--R                        6        5       2              2      2  4
+--R                      6D  - 46B D  + (10C  - 26A C + 34B  - 52A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (10B C  + 56A B C - 10B  - 114A B)D
+--R                    + 
+--R                          3       2 2           2       3        2 2      4  2
+--R                    (30A C  - 102A C  + (- 30A B  + 170A )C + 18A B  + 14A )D
+--R                 *
+--R                       5
+--R                    a b
+--R                + 
+--R                                  5                     4
+--R                      (10C + 65A)D  + (122B C + 258A B)D
+--R                    + 
+--R                            3         2         2       2          2      3  3
+--R                      (- 34C  + 108A C  + (- 90B  - 306A )C + 92A B  - 22A )D
+--R                    + 
+--R                                   3         2       3       2           3
+--R                            - 38B C  - 6A B C  + (38B  + 336A B)C + 38A B
+--R                          + 
+--R                                  3
+--R                            - 290A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4       2 3         2       3  2
+--R                          - 39A C  + 132A C  + (30A B  - 228A )C
+--R                        + 
+--R                              2 2      4         4      3 2      5
+--R                          (48A B  - 16A )C - 5A B  - 32A B  + 63A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4     2   3          3      3   2
+--R                      - 2A B C  - 2A B C  + (- 4A B  + 28A B)C
+--R                    + 
+--R                            2 3      4        5
+--R                      (- 14A B  - 42A B)C - 6A B
+--R                 *
+--R                     2 4
+--R                    a b
+--R                + 
+--R                           6        5         2               2       2  4
+--R                      - 29D  + 67B D  + (- 40C  + 77A C - 276B  - 243A )D
+--R                    + 
+--R                              2                  3      2   3
+--R                      (- 62B C  - 296A B C + 144B  + 28A B)D
+--R                    + 
+--R                             4         3         2        2  2
+--R                          35C  - 372A C  + (- 30B  + 1110A )C
+--R                        + 
+--R                                  2     3        4       2 2      4
+--R                          (- 12A B  - 6A )C - 55B  - 156A B  + 13A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4          3         3       2   2
+--R                          51B C  - 76A B C  + (- 36B  - 252A B)C
+--R                        + 
+--R                                   3       3        5       2 3       4
+--R                          (- 144A B  + 420A B)C + 5B  + 230A B  + 225A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          5      2      2  4           2      3  3
+--R                      9A C  + (2B  - 15A )C  + (- 50A B  + 28A )C
+--R                    + 
+--R                         4      2 2      4  2          4      3 2      5
+--R                      (4B  - 12A B  + 40A )C  + (- 9A B  + 60A B  - 45A )C
+--R                    + 
+--R                           2 4       4 2      6
+--R                      - 31A B  - 108A B  - 33A
+--R                 *
+--R                     3 3
+--R                    a b
+--R                + 
+--R                                  5                       4
+--R                      (82C + 22A)D  + (- 234B C + 342A B)D
+--R                    + 
+--R                          3         2        2      2           2       3  3
+--R                      (52C  - 486A C  + (624B  + 36A )C + 144A B  + 366A )D
+--R                    + 
+--R                                 3           2          3      2            3
+--R                          - 18B C  - 108A B C  + (- 424B  + 18A B)C + 272A B
+--R                        + 
+--R                                3
+--R                          - 692A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         4        2       2  3
+--R                          - 12C  + 346A C  + (164B  - 796A )C
+--R                        + 
+--R                               2       3  2        4      2 2       4
+--R                          (6A B  - 112A )C  + (142B  + 36A B  - 136A )C
+--R                        + 
+--R                                  4       3 2       5
+--R                          - 118A B  - 190A B  + 166A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5          4       3       2   3
+--R                      - 18B C  - 72A B C  + (42B  + 352A B)C
+--R                    + 
+--R                               3       3   2       5      2 3      4           5
+--R                      (- 100A B  - 508A B)C  + (18B  - 90A B  - 62A B)C + 10A B
+--R                    + 
+--R                           3 3       5
+--R                      - 28A B  - 108A B
+--R                 *
+--R                     4 2
+--R                    a b
+--R                + 
+--R                          6        5         2               2      2  4
+--R                      - 8D  - 64B D  + (- 36C  - 152A C + 56B  - 36A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (272B C  - 96A B C - 224B  - 336A B)D
+--R                    + 
+--R                               4         3          2       2  2
+--R                          - 96C  + 544A C  + (- 216B  + 192A )C
+--R                        + 
+--R                                   2      3         4       2 2       4
+--R                          (- 432A B  - 64A )C + 136B  + 456A B  - 224A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3        3       2   2
+--R                          16B C  - 256A B C  + (208B  + 576A B)C
+--R                        + 
+--R                                 3      3         2 3       4
+--R                          (224A B  + 64A B)C - 48A B  + 432A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6        5         2       2  4            2      3  3
+--R                      - 4C  - 72A C  + (- 48B  + 100A )C  + (- 224A B  + 48A )C
+--R                    + 
+--R                           4       2 2      4  2           4      3 2      5
+--R                      (- 4B  + 192A B  - 60A )C  + (- 24A B  + 96A B  + 24A )C
+--R                    + 
+--R                        6       2 4       4 2      6
+--R                      8B  + 156A B  + 112A B  - 36A
+--R                 *
+--R                     5
+--R                    a b
+--R                + 
+--R                           5                    4
+--R                      32A D  + (96B C - 128A B)D
+--R                    + 
+--R                            2          2      2           2      3  3
+--R                      (64A C  + (- 192B  + 64A )C + 256A B  + 64A )D
+--R                    + 
+--R                               3        3       2            3       3   2
+--R                      (- 128B C  + (320B  - 384A B)C - 320A B  + 320A B)D
+--R                    + 
+--R                             5         4      2 3          2       3  2
+--R                          64C  - 160A C  - 64A C  + (192A B  - 128A )C
+--R                        + 
+--R                                 4       4           4       3 2      5
+--R                          (- 320B  + 256A )C + 160A B  - 576A B  - 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4       2   3       3   2
+--R                      - 32B C  + 320A B C  - 320A B C  + 320A B C
+--R                    + 
+--R                          5       4           5       5
+--R                      (32B  - 160A B)C - 64A B  + 128A B
+--R                 *
+--R                     6
+--R                    a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                                 2  4      2   3  7
+--R                  ((- 32A C + 16A )D  + 48A B D )b
+--R                + 
+--R                                 5                    4
+--R                      (4C - 16A)D  + (40B C - 148A B)D
+--R                    + 
+--R                           3        2         2       2         2       3  3
+--R                      (- 4C  + 40A C  + (- 12B  + 316A )C + 8A B  - 192A )D
+--R                    + 
+--R                                2       2          3      3   2
+--R                      (- 12A B C  - 168A B C - 4A B  + 20A B)D
+--R                 *
+--R                       6
+--R                    a b
+--R                + 
+--R                         6        5         2                2       2  4
+--R                      24D  - 52B D  + (- 40C  - 215A C + 212B  + 405A )D
+--R                    + 
+--R                               2                3       2   3
+--R                      (- 140B C  + 76A B C - 92B  + 548A B)D
+--R                    + 
+--R                             4        3       2        2  2
+--R                          16C  + 82A C  + (60B  - 1026A )C
+--R                        + 
+--R                                   2       3       4       2 2       4
+--R                          (- 102A B  + 322A )C + 4B  + 330A B  + 198A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 3       2   2          3      3         2 3
+--R                          20A B C  + 192A B C  + (- 4A B  + 60A B)C - 32A B
+--R                        + 
+--R                                4
+--R                          - 176A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5     2 4        2      3  3         2 2     4  2
+--R                      A C  - 7A C  + (6A B  + 14A )C  + (- 18A B  - 2A )C
+--R                    + 
+--R                           4     3 2      5       2 4      4 2     6
+--R                      (5A B  + 6A B  - 15A )C + 5A B  + 30A B  + 9A
+--R                 *
+--R                     2 5
+--R                    a b
+--R                + 
+--R                                     5                     4
+--R                      (- 81C - 173A)D  + (239B C - 569A B)D
+--R                    + 
+--R                          3         2          2       2           2       3  3
+--R                      (42C  + 902A C  + (- 582B  - 474A )C - 778A B  - 590A )D
+--R                    + 
+--R                                3           2        3       2            3
+--R                          182B C  + 378A B C  + (350B  - 894A B)C - 310A B
+--R                        + 
+--R                              3
+--R                          118A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         4         2       2  3
+--R                          - 21C  - 141A C  + (- 86B  + 966A )C
+--R                        + 
+--R                                2     3  2       4       2 2       4          4
+--R                          (66A B  + 6A )C  + (- B  - 546A B  - 273A )C - 17A B
+--R                        + 
+--R                               3 2       5
+--R                          - 34A B  - 217A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5          4        3       2   3
+--R                      - B C  + 19A B C  + (- 6B  - 202A B)C
+--R                    + 
+--R                            3       3   2        5      2 3      4          5
+--R                      (66A B  + 158A B)C  + (- 5B  - 74A B  - 21A B)C + 7A B
+--R                    + 
+--R                         3 3       5
+--R                      54A B  + 111A B
+--R                 *
+--R                     3 4
+--R                    a b
+--R                + 
+--R                        6         5        2               2       2  4
+--R                      2D  + 188B D  + (- 2C  + 548A C + 30B  + 194A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 380B C  + 536A B C + 508B  + 928A B)D
+--R                    + 
+--R                             4          3        2       2  2
+--R                          78C  - 1240A C  + (432B  - 372A )C
+--R                        + 
+--R                                  2       3        4       2 2       4
+--R                          (1620A B  + 356A )C - 70B  + 240A B  + 562A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4           3          3       2   2
+--R                          - 112B C  - 160A B C  + (- 312B  - 684A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (232A B  + 608A B)C + 24B  + 468A B  - 420A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6        5       2       2  4          2       3  3
+--R                      10C  + 48A C  + (26B  - 282A )C  + (180A B  - 124A )C
+--R                    + 
+--R                            4      2 2       4  2          4       3 2      5
+--R                      (- 34B  - 84A B  + 178A )C  + (168A B  + 240A B  + 60A )C
+--R                    + 
+--R                           6      2 4      4 2      6
+--R                      - 10B  - 94A B  - 34A B  + 78A
+--R                 *
+--R                     4 3
+--R                    a b
+--R                + 
+--R                                  5                       4
+--R                      (56C - 48A)D  + (- 576B C - 112A B)D
+--R                    + 
+--R                           3         2       2       2           2       3  3
+--R                      (200C  - 268A C  + (72B  - 600A )C - 840A B  - 180A )D
+--R                    + 
+--R                                3           2           3      2            3
+--R                          156B C  + 744A B C  + (- 1048B  - 12A B)C - 440A B
+--R                        + 
+--R                                 3
+--R                          - 1160A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5         4          2       2  3
+--R                          - 124C  + 672A C  + (- 184B  + 544A )C
+--R                        + 
+--R                                   2       3  2        4       2 2       4
+--R                          (- 276A B  + 520A )C  + (240B  - 984A B  - 484A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 456A B  + 676A B  + 24A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       3       2   3
+--R                      40B C  - 132A B C  + (20B  + 808A B)C
+--R                    + 
+--R                            3       3   2         5       2 3       4
+--R                      (56A B  - 352A B)C  + (- 72B  - 244A B  + 368A B)C
+--R                    + 
+--R                           5       3 3      5
+--R                      24A B  - 120A B  - 92A B
+--R                 *
+--R                     5 2
+--R                    a b
+--R                + 
+--R                           5          2               2      2  4
+--R                      32B D  + (- 120C  - 16A C + 160B  + 72A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (448B C  + 576A B C + 32B  + 192A B)D
+--R                    + 
+--R                                4         3          2       2  2
+--R                          - 208C  - 288A C  + (- 240B  + 480A )C
+--R                        + 
+--R                                 2       3         4       2 2       4
+--R                          (192A B  + 288A )C + 288B  + 816A B  - 208A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4            3        3       2   2
+--R                          256B C  - 1216A B C  + (384B  - 480A B)C
+--R                        + 
+--R                                 3       3         2 3       4
+--R                          (768A B  - 128A B)C - 64A B  + 608A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6         5        2       2  4            2       3  3
+--R                      40C  - 112A C  + (112B  - 104A )C  + (- 288A B  - 192A )C
+--R                    + 
+--R                            4       2 2       4  2         4       3 2      5
+--R                      (- 56B  + 192A B  - 104A )C  + (16A B  - 288A B  + 48A )C
+--R                    + 
+--R                          2 4       4 2      6
+--R                      104A B  - 368A B  - 88A
+--R                 *
+--R                     6
+--R                    a b
+--R                + 
+--R                                4
+--R                      - 128A B D
+--R                    + 
+--R                          3        2          2      2           2      3  3
+--R                      (64C  + 64A C  + (- 192B  - 64A )C + 128A B  + 64A )D
+--R                    + 
+--R                                  3           2        3       2            3
+--R                          - 128B C  - 192A B C  + (128B  - 384A B)C - 320A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5         4        2      2  3
+--R                          64C  + 192A C  + (192B  - 64A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (192A B  - 256A )C  + (- 320B  + 576A B  + 256A )C
+--R                        + 
+--R                                4       3 2      5
+--R                          128A B  - 576A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                              5           4            3       3   2
+--R                      - 192B C  + 320A B C  + (- 320A B  + 320A B)C
+--R                    + 
+--R                           5       4           5       3 3       5
+--R                      (128B  - 320A B)C - 64A B  + 320A B  + 128A B
+--R                 *
+--R                     7
+--R                    a
+--R             *
+--R                c
+--R            + 
+--R                      5          4         2      2         2      3  3  8
+--R              (- 16A D  + 32A B D  + (16A C  - 64A C - 16A B  + 48A )D )b
+--R            + 
+--R                      6        5        2               2      2  4
+--R                  - 8D  + 40B D  + (- 8C  + 152A C - 56B  - 64A )D
+--R                + 
+--R                         2                3       2   3
+--R                  (- 8B C  - 64A B C + 24B  - 120A B)D
+--R                + 
+--R                          3       2 2         2       3        2 2      4  2
+--R                  (- 56A C  + 216A C  + (72A B  - 136A )C - 24A B  - 24A )D
+--R             *
+--R                   7
+--R                a b
+--R            + 
+--R                             5                      4
+--R                  (8C + 74A)D  + (- 216B C + 62A B)D
+--R                + 
+--R                      3         2        2      2           2       3  3
+--R                  (56C  - 452A C  + (216B  - 80A )C + 172A B  + 260A )D
+--R                + 
+--R                        3          2          3       2           3      3   2
+--R                  (24B C  + 12A B C  + (- 104B  + 264A B)C - 28A B  + 60A B)D
+--R                + 
+--R                           4       2 3           2       3  2
+--R                      66A C  - 248A C  + (- 84A B  + 132A )C
+--R                    + 
+--R                            2 2      4          4       3 2     5
+--R                      (- 24A B  + 56A )C + 10A B  + 100A B  - 6A
+--R                 *
+--R                    D
+--R                + 
+--R                          4      2   3          3      3   2       2 3      4
+--R                  - 2A B C  + 16A B C  + (- 4A B  - 44A B)C  + (16A B  + 48A B)C
+--R                + 
+--R                        5      3 3      5
+--R                  - 2A B  - 20A B  - 18A B
+--R             *
+--R                 2 6
+--R                a b
+--R            + 
+--R                     6         5        2               2       2  4
+--R                  14D  - 104B D  + (124C  - 242A C + 38B  - 286A )D
+--R                + 
+--R                         2                  3       2   3
+--R                  (416B C  + 392A B C - 144B  - 672A B)D
+--R                + 
+--R                            4         3          2       2  2
+--R                      - 130C  + 628A C  + (- 288B  + 504A )C
+--R                    + 
+--R                               2       3        4       2 2       4
+--R                      (- 348A B  - 188A )C + 74B  - 372A B  - 446A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                             4         3        3      2   2
+--R                      - 24B C  + 8A B C  + (128B  + 48A B)C
+--R                    + 
+--R                             3       3        5       2 3       4
+--R                      (200A B  - 552A B)C - 8B  - 208A B  + 328A B
+--R                 *
+--R                    D
+--R                + 
+--R                         5      2      2  4        2      3  3
+--R                  - 26A C  + (2B  + 94A )C  + (4A B  - 28A )C
+--R                + 
+--R                     4       2 2      4  2           4       3 2      5       6
+--R                  (4B  + 120A B  - 76A )C  + (- 34A B  - 156A B  + 54A )C + 2B
+--R                + 
+--R                     2 4      4 2      6
+--R                  34A B  - 18A B  - 18A
+--R             *
+--R                 3 5
+--R                a b
+--R            + 
+--R                                5                     4
+--R                  (- 58C + 74A)D  + (414B C + 422A B)D
+--R                + 
+--R                         3        2          2        2           2       3  3
+--R                  (- 380C  + 28A C  + (- 348B  + 1020A )C + 684A B  + 204A )D
+--R                + 
+--R                              3            2        3       2            3
+--R                      - 348B C  - 1404A B C  + (276B  + 660A B)C + 500A B
+--R                    + 
+--R                          3
+--R                      812A B
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                          5         4        2       2  3           2       3  2
+--R                      126C  - 438A C  + (180B  - 500A )C  + (- 84A B  - 340A )C
+--R                    + 
+--R                             4        2 2       4           4       3 2       5
+--R                      (- 234B  + 1308A B  + 614A )C + 138A B  - 356A B  + 250A
+--R                 *
+--R                    D
+--R                + 
+--R                      5          4         3       2   3
+--R                  6B C  + 22A B C  + (- 44B  - 188A B)C
+--R                + 
+--R                           3       3   2       5       2 3       4           5
+--R                  (- 204A B  + 412A B)C  + (14B  + 196A B  - 218A B)C - 26A B
+--R                + 
+--R                     3 3      5
+--R                  76A B  - 66A B
+--R             *
+--R                 4 4
+--R                a b
+--R            + 
+--R                       6        5       2                2      2  4
+--R                  - 24D  - 44B D  + (28C  - 212A C - 220B  + 32A )D
+--R                + 
+--R                           2                   3       2   3
+--R                  (- 376B C  - 1600A B C - 112B  - 192A B)D
+--R                + 
+--R                          4         3        2        2  2
+--R                      464C  + 448A C  + (864B  - 1008A )C
+--R                    + 
+--R                               2       3         4       2 2       4
+--R                      (- 960A B  - 632A )C - 280B  - 840A B  + 232A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                           4            3       3       2   2
+--R                      84B C  + 1520A B C  + (32B  + 336A B)C
+--R                    + 
+--R                                3       3         5       2 3        4
+--R                      (- 1216A B  - 336A B)C + 28B  - 136A B  - 1028A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6         5         2       2  4          2       3  3
+--R                  - 44C  + 124A C  + (- 52B  + 160A )C  + (184A B  + 208A )C
+--R                + 
+--R                       4       2 2       4  2           4      3 2       5
+--R                  (172B  - 600A B  - 100A )C  + (- 76A B  - 96A B  - 300A )C
+--R                + 
+--R                     6       2 4       4 2      6
+--R                  12B  - 128A B  + 228A B  + 16A
+--R             *
+--R                 5 3
+--R                a b
+--R            + 
+--R                               5                   4
+--R                  (104C - 24A)D  + (72B C + 24A B)D
+--R                + 
+--R                      3         2        2       2           2       3  3
+--R                  (80C  + 408A C  + (672B  - 272A )C + 112A B  - 152A )D
+--R                + 
+--R                              3            2        3       2            3
+--R                      - 216B C  + 1584A B C  + (240B  + 696A B)C + 608A B
+--R                    + 
+--R                          3
+--R                      272A B
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                            5         4          2       2  3
+--R                      - 288C  - 360A C  + (- 912B  + 208A )C
+--R                    + 
+--R                             2       3  2        4       2 2       4           4
+--R                      (168A B  + 464A )C  + (504B  - 240A B  - 400A )C + 264A B
+--R                    + 
+--R                           3 2       5
+--R                      1336A B  - 200A
+--R                 *
+--R                    D
+--R                + 
+--R                       5           4          3       2   3
+--R                  24B C  - 560A B C  + (- 136B  - 368A B)C
+--R                + 
+--R                         3       3   2         5       2 3       4            5
+--R                  (528A B  - 368A B)C  + (- 88B  + 328A B  + 760A B)C + 136A B
+--R                + 
+--R                       3 3       5
+--R                  - 16A B  + 192A B
+--R             *
+--R                 6 2
+--R                a b
+--R            + 
+--R                         2              2      2  4
+--R                  (- 144C  + 32A C - 32B  + 48A )D
+--R                + 
+--R                          2                  3      2   3
+--R                  (- 32B C  + 192A B C - 128B  - 96A B)D
+--R                + 
+--R                           4         3          2       2  2
+--R                      - 64C  - 480A C  + (- 576B  + 288A )C
+--R                    + 
+--R                               2       3        4       2 2      4
+--R                      (- 384A B  + 416A )C - 64B  - 384A B  - 32A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                            4           3          3       2   2
+--R                      480B C  - 448A B C  + (- 160B  - 384A B)C
+--R                    + 
+--R                              3       3          5       2 3       4
+--R                      (- 64A B  - 192A B)C - 128B  - 736A B  + 160A B
+--R                 *
+--R                    D
+--R                + 
+--R                     6        5        2      2  4         2 3
+--R                  80C  + 64A C  + (320B  + 16A )C  + 352A B C
+--R                + 
+--R                         4       2 2       4  2            4       3 2       5
+--R                  (- 176B  + 480A B  + 176A )C  + (- 160A B  - 288A B  + 192A )C
+--R                + 
+--R                       6       2 4       4 2      6
+--R                  - 32B  - 176A B  - 480A B  - 16A
+--R             *
+--R                 7
+--R                a b
+--R            + 
+--R                      3      2          2  3              2       3       3   2
+--R                  (64C  - 64A C + 128A B )D  + (- 192A B C  + 128B C - 64A B)D
+--R                + 
+--R                         4       2 3       3 2       2 2          4      5
+--R                  (192A C  + 192B C  - 256A C  + 576A B C + 128A B  + 64A )D
+--R                + 
+--R                          5         3 2        5       4          3 3
+--R                  - 192B C  - 320A B C  + (128B  - 320A B)C + 320A B
+--R             *
+--R                 8
+--R                a
+--R  /
+--R     2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 656
+
+--S 657 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                       +-----------------+
+--R                   +-+ |          2     2
+--R                2a\|2 \|- 4a c + b  + 8a
+--R             *
+--R                 +-----------------------------------------+
+--R                 |    +-----------------+
+--R                 |    |          2     2            2     2
+--R                \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R             *
+--R                 +---------------------------------------+
+--R                 |  +-----------------+
+--R                 |  |          2     2            2     2
+--R                \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R             *
+--R                ROOT
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN1
+--R                     + 
+--R                                   3 3      2 2      4  2       3 2      5
+--R                               - 8a c  + (2a b  - 16a )c  + (40a b  + 32a )c
+--R                             + 
+--R                                   2 4      4 2      6
+--R                               - 8a b  - 56a b  + 64a
+--R                          *
+--R                             %%BN0
+--R                         + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN1
+--R                     + 
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN0
+--R                     + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN0
+--R                     + 
+--R                           2 2                          2     2  2  2
+--R                       (- D b  + 4C D a b + (- 8B D - 4C  - 4A )a )c
+--R                     + 
+--R                               2   2                               2
+--R                           - 4D a b  + ((20C + 4A)D + 4B C + 4A B)a b
+--R                         + 
+--R                              2             2             2     2  3
+--R                           (8D  - 16B D - 8C  + 16A C + 8B  - 8A )a
+--R                      *
+--R                         c
+--R                     + 
+--R                         2 4            3
+--R                       4D b  - 16C D a b
+--R                     + 
+--R                            2              2            2      2  2 2
+--R                       (- 8D  + 24B D + 12C  - 8A C - 4B  + 12A )a b
+--R                     + 
+--R                                                       3
+--R                       ((- 8C - 24A)D - 24B C - 24A B)a b
+--R                     + 
+--R                           2              2  4
+--R                       (16D  + 32A C + 16B )a
+--R                  /
+--R                         3 3       2 2     4  2         3 2      5       2 4
+--R                       4a c  + (- a b  + 8a )c  + (- 20a b  - 16a )c + 4a b
+--R                     + 
+--R                          4 2      6
+--R                       28a b  - 32a
+--R         + 
+--R           -
+--R                       +-----------------+
+--R                   +-+ |          2     2
+--R                2a\|2 \|- 4a c + b  + 8a
+--R             *
+--R                 +-----------------------------------------+
+--R                 |    +-----------------+
+--R                 |    |          2     2            2     2
+--R                \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R             *
+--R                 +---------------------------------------+
+--R                 |  +-----------------+
+--R                 |  |          2     2            2     2
+--R                \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a  %%BN1
+--R         + 
+--R                       +-----------------+               +-----------------+
+--R                   +-+ |          2     2            +-+ |          2     2
+--R             (- 2a\|2 \|- 4a c + b  + 8a  %%BN0 + 2D\|2 \|- 4a c + b  + 8a  )
+--R          *
+--R              +-----------------------------------------+
+--R              |    +-----------------+
+--R              |    |          2     2            2     2
+--R             \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R          *
+--R              +---------------------------------------+
+--R              |  +-----------------+
+--R              |  |          2     2            2     2
+--R             \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R         log
+--R                               2 4 8
+--R                          32A D a c
+--R                        + 
+--R                                     2 3 2         3        2  4
+--R                              - 16A D a b  + (- 16D  - 16B D )a b
+--R                            + 
+--R                                     2                   2      3  5
+--R                              (128A D  - 128A B D - 32A C  + 32A )a
+--R                         *
+--R                             7
+--R                            c
+--R                        + 
+--R                                  2 2 4      3       2  3 3
+--R                              2A D a b  + (8D  + 8B D )a b
+--R                            + 
+--R                                            2                  2      3  4 2
+--R                              ((32C - 448A)D  + 64A B D + 16A C  - 16A )a b
+--R                            + 
+--R                                       3        2
+--R                                  - 32D  + 32B D
+--R                                + 
+--R                                        2               2       2          2
+--R                                  (- 48C  + 224A C + 64B  + 144A )D + 16B C
+--R                                + 
+--R                                               2
+--R                                  96A B C - 48A B
+--R                             *
+--R                                 5
+--R                                a b
+--R                            + 
+--R                                          2                 3         2      2
+--R                                  - 128A D  - 512A B D + 64C  - 128A C  - 64A C
+--R                                + 
+--R                                        2       3
+--R                                  128A B  + 128A
+--R                             *
+--R                                 6
+--R                                a
+--R                         *
+--R                             6
+--R                            c
+--R                        + 
+--R                                  3      2  2 5
+--R                              (- D  - B D )a b
+--R                            + 
+--R                                              2                2     3  3 4
+--R                              ((- 16C + 192A)D  - 8A B D - 2A C  + 2A )a b
+--R                            + 
+--R                                      3         2
+--R                                  160D  + 128B D
+--R                                + 
+--R                                      2               2      2         2
+--R                                  (24C  - 112A C - 32B  - 72A )D - 8B C
+--R                                + 
+--R                                                 2
+--R                                  - 48A B C + 24A B
+--R                             *
+--R                                 4 3
+--R                                a b
+--R                            + 
+--R                                               2                             3
+--R                                  (80C - 560A)D  + (- 96B C + 1312A B)D - 48C
+--R                                + 
+--R                                        2         2      2           2       3
+--R                                  304A C  + (- 48B  - 16A )C - 112A B  - 368A
+--R                             *
+--R                                 5 2
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  128D  + 256B D
+--R                                + 
+--R                                         2               2       2           2
+--R                                  (- 384C  + 512A C + 64B  + 384A )D - 128B C
+--R                                + 
+--R                                       3       2
+--R                                  - 64B  - 384A B
+--R                             *
+--R                                 6
+--R                                a b
+--R                            + 
+--R                                           2                  3         2
+--R                                  - 1024A D  + 512A B D + 256C  + 128A C
+--R                                + 
+--R                                        2          2       3
+--R                                  - 256A C + 512A B  - 128A
+--R                             *
+--R                                 7
+--R                                a
+--R                         *
+--R                             5
+--R                            c
+--R                        + 
+--R                                         2 2 6
+--R                              (2C - 22A)D a b
+--R                            + 
+--R                                       3        2        2             2     2
+--R                                  - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D
+--R                                + 
+--R                                     2              2
+--R                                  B C  + 6A B C - 3A B
+--R                             *
+--R                                 3 5
+--R                                a b
+--R                            + 
+--R                                                   2                          3
+--R                                  (- 328C + 1896A)D  + (48B C - 528A B)D + 12C
+--R                                + 
+--R                                          2       2      2          2       3
+--R                                  - 120A C  + (24B  + 20A )C + 32A B  + 152A
+--R                             *
+--R                                 4 4
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 224D  - 800B D
+--R                                + 
+--R                                       2                 2        2          2
+--R                                  (720C  - 2080A C - 512B  - 1392A )D + 16B C
+--R                                + 
+--R                                                  3       2
+--R                                  - 672A B C + 64B  + 720A B
+--R                             *
+--R                                 5 3
+--R                                a b
+--R                            + 
+--R                                                 2                             3
+--R                                  (160C + 2976A)D  + (576B C + 1088A B)D - 608C
+--R                                + 
+--R                                        2        2       2            2      3
+--R                                  416A C  + (288B  + 992A )C - 1120A B  - 32A
+--R                             *
+--R                                 6 2
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  256D  - 256B D
+--R                                + 
+--R                                         2                 2       2           2
+--R                                  (- 192C  - 1664A C - 640B  - 960A )D - 448B C
+--R                                + 
+--R                                                    3       2
+--R                                  - 1152A B C - 128B  - 192A B
+--R                             *
+--R                                 7
+--R                                a b
+--R                            + 
+--R                                          2                   3          2
+--R                                  - 512A D  + 4096A B D - 256C  + 1024A C
+--R                                + 
+--R                                      2          2        3
+--R                                  256A C - 512A B  - 1024A
+--R                             *
+--R                                 8
+--R                                a
+--R                         *
+--R                             4
+--R                            c
+--R                        + 
+--R                                 3       2  2 7
+--R                              (8D  + 8B D )a b
+--R                            + 
+--R                                                2                        3
+--R                                  (141C - 755A)D  + (- 6B C + 58A B)D - C
+--R                                + 
+--R                                       2        2     2         2      3
+--R                                  13A C  + (- 3B  - 3A )C - 3A B  - 17A
+--R                             *
+--R                                 3 6
+--R                                a b
+--R                            + 
+--R                                        3        2
+--R                                  - 284D  - 36B D
+--R                                + 
+--R                                         2                2       2          2
+--R                                  (- 276C  + 888A C + 228B  + 588A )D + 12B C
+--R                                + 
+--R                                                3       2
+--R                                  312A B C - 20B  - 276A B
+--R                             *
+--R                                 4 5
+--R                                a b
+--R                            + 
+--R                                                  2
+--R                                  (- 32C - 2016A)D  + (192B C - 3072A B)D
+--R                                + 
+--R                                      3         2       2       2           2
+--R                                  320C  - 720A C  + (96B  - 192A )C + 672A B
+--R                                + 
+--R                                      3
+--R                                  848A
+--R                             *
+--R                                 5 4
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 896D  - 384B D
+--R                                + 
+--R                                        2                 2       2            2
+--R                                  (1344C  + 1408A C + 896B  + 576A )D + 1088B C
+--R                                + 
+--R                                                  3        2
+--R                                  1920A B C + 384B  + 1344A B
+--R                             *
+--R                                 6 3
+--R                                a b
+--R                            + 
+--R                                                   2
+--R                                  (- 640C + 4224A)D  + (768B C - 8448A B)D
+--R                                + 
+--R                                        3          2        2       2
+--R                                  - 128C  - 1920A C  + (384B  + 640A )C
+--R                                + 
+--R                                          2        3
+--R                                  - 128A B  + 2432A
+--R                             *
+--R                                 7 2
+--R                                a b
+--R                            + 
+--R                                        3          2
+--R                                  - 256D  - 1280B D
+--R                                + 
+--R                                        2                 2        2
+--R                                  (3072C  - 4096A C - 512B  - 3072A )D
+--R                                + 
+--R                                         2       3        2
+--R                                  1024B C  + 512B  + 3072A B
+--R                             *
+--R                                 8
+--R                                a b
+--R                            + 
+--R                                         2                    3         2
+--R                                  2048A D  + 2048A B D - 2048C  + 512A C
+--R                                + 
+--R                                       2           2       3
+--R                                  2048A C - 4096A B  - 512A
+--R                             *
+--R                                 9
+--R                                a
+--R                         *
+--R                             3
+--R                            c
+--R                        + 
+--R                                            2 2 8
+--R                              (- 16C + 80A)D a b
+--R                            + 
+--R                                      3         2
+--R                                  146D  + 118B D
+--R                                + 
+--R                                      2               2      2         2
+--R                                  (30C  - 100A C - 26B  - 66A )D - 2B C
+--R                                + 
+--R                                                3      2
+--R                                  - 36A B C + 2B  + 30A B
+--R                             *
+--R                                 3 7
+--R                                a b
+--R                            + 
+--R                                                 2
+--R                                  (726C - 2090A)D  + (- 180B C + 1100A B)D
+--R                                + 
+--R                                       3         2         2      2           2
+--R                                  - 62C  + 230A C  + (- 90B  - 58A )C - 154A B
+--R                                + 
+--R                                        3
+--R                                  - 350A
+--R                             *
+--R                                 4 6
+--R                                a b
+--R                            + 
+--R                                       3          2
+--R                                  1752D  + 2760B D
+--R                                + 
+--R                                          2                 2        2
+--R                                  (- 2160C  + 3840A C + 696B  + 2736A )D
+--R                                + 
+--R                                          2                  3        2
+--R                                  - 528B C  + 576A B C - 312B  - 2160A B
+--R                             *
+--R                                 5 5
+--R                                a b
+--R                            + 
+--R                                           2                                3
+--R                                  - 8160A D  + (- 4608B C + 5376A B)D + 864C
+--R                                + 
+--R                                        2           2        2           2
+--R                                  192A C  + (- 2304B  - 3936A )C + 960A B
+--R                                + 
+--R                                         3
+--R                                  - 3264A
+--R                             *
+--R                                 6 4
+--R                                a b
+--R                            + 
+--R                                       3          2
+--R                                  1152D  + 4224B D
+--R                                + 
+--R                                          2                   2        2
+--R                                  (- 5760C  + 11520A C + 2304B  + 8064A )D
+--R                                + 
+--R                                           2                   3        2
+--R                                  - 1152B C  + 2304A B C - 768B  - 5760A B
+--R                             *
+--R                                 7 3
+--R                                a b
+--R                            + 
+--R                                                    2
+--R                                  (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D
+--R                                + 
+--R                                       3          2           2        2
+--R                                  3840C  - 3072A C  + (- 2304B  - 6912A )C
+--R                                + 
+--R                                         2
+--R                                  6912A B
+--R                             *
+--R                                 8 2
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 512D  + 512B D
+--R                                + 
+--R                                        2                  2       2
+--R                                  (3840C  + 2560A C + 2048B  + 768A )D
+--R                                + 
+--R                                         2                    3        2
+--R                                  2816B C  + 4608A B C + 1024B  + 3840A B
+--R                             *
+--R                                 9
+--R                                a b
+--R                            + 
+--R                                         2                    3          2
+--R                                  2048A D  - 8192A B D - 1024C  - 2048A C
+--R                                + 
+--R                                       2           2        3
+--R                                  1024A C - 2048A B  + 2048A
+--R                             *
+--R                                 10
+--R                                a
+--R                         *
+--R                             2
+--R                            c
+--R                        + 
+--R                                    3        2  2 9
+--R                              (- 16D  - 16B D )a b
+--R                            + 
+--R                                                  2                         3
+--R                                  (- 308C + 972A)D  + (24B C - 104A B)D + 4C
+--R                                + 
+--R                                         2       2      2          2      3
+--R                                  - 20A C  + (12B  + 12A )C + 12A B  + 36A
+--R                             *
+--R                                 3 8
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 456D  - 920B D
+--R                                + 
+--R                                       2                 2        2           2
+--R                                  (744C  - 1712A C - 376B  - 1176A )D + 104B C
+--R                                + 
+--R                                                  3       2
+--R                                  - 432A B C + 88B  + 744A B
+--R                             *
+--R                                 4 7
+--R                                a b
+--R                            + 
+--R                                                    2
+--R                                  (- 1668C + 8316A)D  + (1656B C - 136A B)D
+--R                                + 
+--R                                        3         2        2        2
+--R                                  - 364C  + 380A C  + (828B  + 1468A )C
+--R                                + 
+--R                                          2       3
+--R                                  - 452A B  + 724A
+--R                             *
+--R                                 5 6
+--R                                a b
+--R                            + 
+--R                                         3          2
+--R                                  - 2496D  - 6432B D
+--R                                + 
+--R                                        2                   2        2
+--R                                  (5328C  - 14304A C - 3408B  - 9648A )D
+--R                                + 
+--R                                        2                   3        2
+--R                                  336B C  - 4320A B C + 528B  + 5328A B
+--R                             *
+--R                                 6 5
+--R                                a b
+--R                            + 
+--R                                                  2
+--R                                  (6528C + 3456A)D  + (11520B C + 7296A B)D
+--R                                + 
+--R                                         3          2         2         2
+--R                                  - 3072C  + 4704A C  + (5760B  + 10752A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 4224A B  + 2976A
+--R                             *
+--R                                 7 4
+--R                                a b
+--R                            + 
+--R                                       3         2
+--R                                  1024D  - 512B D
+--R                                + 
+--R                                          2                  2        2
+--R                                  (- 5760C  - 3840A C - 3072B  - 1152A )D
+--R                                + 
+--R                                           2                    3        2
+--R                                  - 4224B C  - 6912A B C - 1536B  - 5760A B
+--R                             *
+--R                                 8 3
+--R                                a b
+--R                            + 
+--R                                                  2
+--R                                  (1280C - 6912A)D  + (- 1536B C + 12800A B)D
+--R                                + 
+--R                                       3          2          2        2
+--R                                  1280C  + 2816A C  + (- 768B  - 2304A )C
+--R                                + 
+--R                                         2        3
+--R                                  2304A B  - 3840A
+--R                             *
+--R                                 9 2
+--R                                a b
+--R                            + 
+--R                                         2
+--R                                  2048B D
+--R                                + 
+--R                                          2                  2        2
+--R                                  (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                                + 
+--R                                           2        3        2
+--R                                  - 2048B C  - 1024B  - 6144A B
+--R                             *
+--R                                 10
+--R                                a  b
+--R                            + 
+--R                                                     3          2        2
+--R                                  - 8192A B D + 4096C  - 2048A C  - 4096A C
+--R                                + 
+--R                                         2        3
+--R                                  8192A B  + 2048A
+--R                             *
+--R                                 11
+--R                                a
+--R                         *
+--R                            c
+--R                        + 
+--R                                      2 2 10
+--R                          (32C - 96A)D a b
+--R                        + 
+--R                                 3        2         2               2       2
+--R                              24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D
+--R                            + 
+--R                                    2               3      2
+--R                              - 8B C  + 48A B C - 8B  - 72A B
+--R                         *
+--R                             3 9
+--R                            a b
+--R                        + 
+--R                                             2                             3
+--R                              (376C - 1416A)D  + (- 144B C - 144A B)D + 40C
+--R                            + 
+--R                                     2         2       2          2      3
+--R                              - 72A C  + (- 72B  - 136A )C + 56A B  - 24A
+--R                         *
+--R                             4 8
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              360D  + 1080B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 936C  + 2608A C + 632B  + 1752A )D - 40B C
+--R                            + 
+--R                                            3       2
+--R                              816A B C - 88B  - 936A B
+--R                         *
+--R                             5 7
+--R                            a b
+--R                        + 
+--R                                              2                                3
+--R                              (- 24C - 4248A)D  + (- 2160B C - 2160A B)D + 536C
+--R                            + 
+--R                                     2           2        2           2       3
+--R                            - 1080A C  + (- 1080B  - 1976A )C + 712A B  - 360A
+--R                         *
+--R                             6 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1152D  + 3456B D
+--R                            + 
+--R                                      2                  2        2           2
+--R                              (- 1296C  + 7968A C + 2400B  + 5040A )D + 816B C
+--R                            + 
+--R                                             3        2
+--R                              3744A B C + 96B  - 1296A B
+--R                         *
+--R                             7 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D
+--R                            + 
+--R                                  3          2           2        2           2
+--R                              960C  - 3456A C  + (- 3456B  - 5568A )C + 768A B
+--R                            + 
+--R                                     3
+--R                              - 1152A
+--R                         *
+--R                             8 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1536D  - 4608B D
+--R                            + 
+--R                                     2                   2        2            2
+--R                              (11520C  - 12800A C - 1024B  - 9984A )D + 4352B C
+--R                            + 
+--R                                               3         2
+--R                              1536A B C + 2048B  + 11520A B
+--R                         *
+--R                             9 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (6656C - 1536A)D  + (9216B C + 9216A B)D - 5632C
+--R                            + 
+--R                                   2         2         2            2        3
+--R                            4608A C  + (4608B  + 11776A )C - 9728A B  + 1536A
+--R                         *
+--R                             10 2
+--R                            a  b
+--R                        + 
+--R                                      2                  2        2            2
+--R                              (- 9216C  + 2048A C - 2048B  + 3072A )D - 5120B C
+--R                            + 
+--R                                                 3        2
+--R                              - 6144A B C - 2048B  - 9216A B
+--R                         *
+--R                             11
+--R                            a  b
+--R                        + 
+--R                                3        2           2  12
+--R                          (4096C  - 4096A C + 8192A B )a
+--R                     *
+--R                        %%BN0
+--R                    + 
+--R                             3 3 8
+--R                      - 16A D a c
+--R                    + 
+--R                              3 2 2        3          2  3
+--R                          4A D a b  + (8B D  + 24A C D )a b
+--R                        + 
+--R                                       3          2           2      3    4
+--R                          ((16C - 64A)D  + 80A B D  + (- 16A C  - 16A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                 3         2  2 3
+--R                          (- 2B D  - 6A C D )a b
+--R                        + 
+--R                                             3                     2
+--R                              (- 12C + 188A)D  + (- 12B C - 52A B)D
+--R                            + 
+--R                                     2      3
+--R                              (- 4A C  + 12A )D
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 24D  + 16B D
+--R                            + 
+--R                                    2              2       2  2
+--R                              (- 24C  + 16A C - 40B  - 120A )D
+--R                            + 
+--R                                   2                2          3     3
+--R                              (8B C  - 48A B C + 24A B)D + 8A C  - 8A C
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                          3                      2
+--R                              (64C + 32A)D  + (- 96B C + 320A B)D
+--R                            + 
+--R                                  3        2       2          2      3
+--R                              (16C  - 64A C  + 112A C - 128A B  - 64A )D
+--R                            + 
+--R                                     2      3
+--R                              48A B C  + 16A B
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                      3                 2        2     3    2 4
+--R                          ((2C - 41A)D  + (3B C + 8A B)D  + (2A C  - 2A )D)a b
+--R                        + 
+--R                                 4        3       2               2      2  2
+--R                              14D  - 80B D  + (18C  - 224A C + 26B  + 66A )D
+--R                            + 
+--R                                   2                2          3     3
+--R                              (2B C  + 36A B C - 18A B)D - 2A C  + 2A C
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                              3                     2
+--R                              (- 144C + 232A)D  + (120B C - 808A B)D
+--R                            + 
+--R                                      3         2       2      2           2
+--R                                  - 4C  + 212A C  + (24B  - 20A )C + 112A B
+--R                                + 
+--R                                      3
+--R                                  196A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3          2      2        3
+--R                              - 4B C  - 36A B C  + 12A B C - 4A B
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 64D  + 96B D
+--R                            + 
+--R                                    2              2       2  2
+--R                              (- 24C  - 80A C - 64B  - 408A )D
+--R                            + 
+--R                                    2                3       2        4        3
+--R                              (80B C  - 96A B C + 64B  + 336A B)D - 8C  - 32A C
+--R                            + 
+--R                                    2      2  2           2      3        2 2
+--R                              (- 24B  - 48A )C  + (- 48A B  - 32A )C - 24A B
+--R                            + 
+--R                                  4
+--R                              - 8A
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    3                       2
+--R                              384A D  + (- 384B C - 128A B)D
+--R                            + 
+--R                                  3         2        2       2           2
+--R                              (64C  - 128A C  + (192B  + 448A )C - 512A B )D
+--R                            + 
+--R                                     3           2       2           3      3
+--R                              - 64B C  + 192A B C  - 192A B C + 64A B  + 64A B
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                  4        3        2             2     2  2
+--R                              - 2D  + 18B D  + (- 3C  + 52A C - 4B  - 9A )D
+--R                            + 
+--R                                    2              2
+--R                              (- B C  - 6A B C + 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                           3                    2
+--R                              (86C - 686A)D  + (54B C + 420A B)D
+--R                            + 
+--R                                      3       2         2      2          2
+--R                                  - 4C  + 9A C  + (- 18B  - 14A )C - 32A B
+--R                                + 
+--R                                        3
+--R                                  - 115A
+--R                             *
+--R                                D
+--R                            + 
+--R                                 3         2     2
+--R                              B C  + 6A B C  - 3A B C
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                  4        3
+--R                              224D  - 92B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (162C  + 280A C + 320B  + 1206A )D
+--R                            + 
+--R                                       2                 3       2        4
+--R                              (- 172B C  + 336A B C - 60B  - 492A B)D + 6C
+--R                            + 
+--R                                     3       2      2  2         2      3
+--R                              - 48A C  + (18B  + 24A )C  + (24A B  + 80A )C
+--R                            + 
+--R                                2 2     4
+--R                              6A B  + 2A
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                               3                     2
+--R                              (- 232C - 1128A)D  + (936B C - 584A B)D
+--R                            + 
+--R                                        3         2          2        2
+--R                                  - 208C  + 400A C  + (- 312B  - 1376A )C
+--R                                + 
+--R                                         2      3
+--R                                  1192A B  - 64A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2       3       2           3
+--R                              96B C  - 384A B C  + (24B  + 240A B)C - 24A B
+--R                            + 
+--R                                    3
+--R                              - 144A B
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                 4         3        2               2       2  2
+--R                              64D  + 256B D  + (144C  + 608A C - 32B  + 336A )D
+--R                            + 
+--R                                    2      3       2         4        3
+--R                              (64B C  + 64B  + 768A B)D + 48C  - 96A C
+--R                            + 
+--R                                  2      2  2           2       3        4
+--R                              (48B  + 96A )C  + (- 96A B  + 224A )C - 32B
+--R                            + 
+--R                                    2 2      4
+--R                              - 144A B  - 16A
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                              3            2
+--R                              (- 256C + 256A)D  - 1792A B D
+--R                            + 
+--R                                     3         2        2      2           2
+--R                                  64C  - 256A C  + (768B  - 64A )C + 128A B
+--R                                + 
+--R                                      3
+--R                                  256A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3       2
+--R                              - 256B C  + 192A B C  + (- 128B  - 768A B)C
+--R                            + 
+--R                                    3      3
+--R                              256A B  + 64A B
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                             3                     2
+--R                              (- 13C + 139A)D  + (- 18B C - 58A B)D
+--R                            + 
+--R                                3        2      2     2         2      3
+--R                              (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 109D  + 265B D
+--R                            + 
+--R                                     2                2       2  2
+--R                              (- 114C  + 591A C - 183B  - 543A )D
+--R                            + 
+--R                                    2                 3       2       4        3
+--R                              (27B C  - 228A B C + 19B  + 225A B)D - C  + 13A C
+--R                            + 
+--R                                   2     2  2          2      3
+--R                              (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                            3                        2
+--R                              (258C + 874A)D  + (- 978B C + 1542A B)D
+--R                            + 
+--R                                     3         2       2       2           2
+--R                                  94C  - 990A C  + (54B  + 426A )C - 714A B
+--R                                + 
+--R                                        3
+--R                                  - 346A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3           2         3       2          3
+--R                              - 10B C  + 234A B C  + (- 14B  - 174A B)C + 2A B
+--R                            + 
+--R                                 3
+--R                              30A B
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                      3          2               2       2  2
+--R                              - 768B D  + (- 192C  - 736A C - 80B  + 384A )D
+--R                            + 
+--R                                       2                 3        2            3
+--R                              (- 272B C  + 96A B C - 384B  - 1968A B)D + 368A C
+--R                            + 
+--R                                  2       2  2          2       3        4
+--R                              (48B  + 192A )C  + (288A B  - 112A )C + 16B
+--R                            + 
+--R                                  2 2      4
+--R                              240A B  + 64A
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (384C - 1536A)D  + (576B C + 4032A B)D
+--R                            + 
+--R                                        3         2           2        2
+--R                                  - 416C  + 672A C  + (- 2112B  - 1312A )C
+--R                                + 
+--R                                        2       3
+--R                                  512A B  - 992A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3        2            3
+--R                              480B C  - 672A B C  + (128B  + 1632A B)C - 512A B
+--R                            + 
+--R                                    3
+--R                              - 160A B
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              256D  - 384B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 192C  + 1024A C - 256B  + 2112A )D
+--R                            + 
+--R                                       2                  3        2          4
+--R                              (- 640B C  - 768A B C - 256B  - 1152A B)D + 192C
+--R                            + 
+--R                                   2       2  2          2       3         2 2
+--R                              (576B  + 384A )C  + (384A B  + 512A )C - 192A B
+--R                            + 
+--R                                   4
+--R                              - 64A
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                              3                       2
+--R                              (- 256C - 512A)D  + (1536B C - 1280A B)D
+--R                            + 
+--R                                     2        2           2       3         3
+--R                              (256A C  - 2048A C + 2560A B  + 256A )D - 512B C
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                 4        3       2               2      2  2
+--R                              14D  - 54B D  + (18C  - 140A C + 26B  + 66A )D
+--R                            + 
+--R                                   2               3      2
+--R                              (2B C  + 36A B C - 2B  - 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                              3                    2
+--R                              (- 142C + 688A)D  + (54B C - 800A B)D
+--R                            + 
+--R                                      3         2       2      2           2
+--R                                    6C  + 100A C  + (54B  + 22A )C + 160A B
+--R                                  + 
+--R                                        3
+--R                                    248A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3          2      3      2
+--R                              - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 416D  + 190B D
+--R                            + 
+--R                                    2                 2        2  2
+--R                              (- 84C  - 1254A C - 438B  - 2514A )D
+--R                            + 
+--R                                     2                  3        2         4
+--R                              (666B C  - 264A B C + 298B  + 1758A B)D - 20C
+--R                            + 
+--R                                   3         2       2  2            2       3
+--R                              22A C  + (- 66B  - 102A )C  + (- 114A B  - 158A )C
+--R                            + 
+--R                                  4      2 2      4
+--R                              - 2B  - 48A B  - 14A
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (284C + 2876A)D  + (- 588B C - 3516A B)D
+--R                            + 
+--R                                      3        2         2        2            2
+--R                                  788C  + 84A C  + (2292B  + 4428A )C - 1404A B
+--R                                + 
+--R                                       3
+--R                                  2252A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3        2
+--R                              - 532B C  + 492A B C  + (- 148B  - 1164A B)C
+--R                            + 
+--R                                    3       3
+--R                              140A B  + 308A B
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 608D  + 640B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (240C  - 3552A C + 960B  - 5232A )D
+--R                            + 
+--R                                      2                   3        2          4
+--R                              (1632B C  + 1536A B C + 928B  + 1632A B)D - 464C
+--R                            + 
+--R                                      3          2        2  2
+--R                              - 128A C  + (- 912B  - 1344A )C
+--R                            + 
+--R                                       2        3         4       2 2      4
+--R                              (- 384A B  - 1664A )C + 160B  + 528A B  + 16A
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                              3                         2
+--R                              (1280C + 1664A)D  + (- 1920B C + 3456A B)D
+--R                            + 
+--R                                      3         2          2        2
+--R                                  128C  + 576A C  + (- 192B  + 6144A )C
+--R                                + 
+--R                                           2       3
+--R                                  - 4800A B  + 704A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2        3       2
+--R                              - 256B C  - 768A B C  + (704B  + 384A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 448A B  + 128A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              128D  - 1280B D
+--R                            + 
+--R                                     2                 2       2  2
+--R                              (- 768C  - 2560A C + 640B  + 768A )D
+--R                            + 
+--R                                       2                   2          4
+--R                              (- 896B C  - 768A B C - 4224A B)D - 128C
+--R                            + 
+--R                                      3        2       2  2          2       3
+--R                              - 128A C  + (384B  - 768A )C  + (768A B  - 896A )C
+--R                            + 
+--R                                  4       2 2       4
+--R                              256B  + 384A B  - 128A
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                      3                       2
+--R                              - 512A D  + (1536B C + 2048A B)D
+--R                            + 
+--R                                        3          2           2        2
+--R                                  - 256C  + 2048A C  + (- 3072B  - 1792A )C
+--R                                + 
+--R                                         2
+--R                                  2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2        2             3       3
+--R                            1024B C  - 768A B C  + 3072A B C - 1024A B  - 256A B
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                           3                    2
+--R                              (20C - 156A)D  + (24B C + 104A B)D
+--R                            + 
+--R                                 3        2         2      2          2      3
+--R                            (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              204D  - 316B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (144C  - 364A C + 292B  + 1092A )D
+--R                            + 
+--R                                       2                 3       2        4
+--R                              (- 164B C  + 288A B C - 84B  - 636A B)D + 4C
+--R                            + 
+--R                                     3       2      2  2         2      3
+--R                              - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                              3                       2
+--R                              (- 36C - 3084A)D  + (1368B C + 1312A B)D
+--R                            + 
+--R                                        3          2          2        2
+--R                                  - 428C  + 1348A C  + (- 996B  - 1780A )C
+--R                                + 
+--R                                        2       3
+--R                                  644A B  - 996A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2       3       2          3
+--R                              128B C  - 312A B C  + (64B  + 528A B)C - 8A B
+--R                            + 
+--R                                   3
+--R                              - 56A B
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              924D  + 588B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 216C  + 5556A C + 60B  + 6156A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 2172B C  - 1584A B C - 444B  - 1332A B)D
+--R                            + 
+--R                                  4         3        2       2  2
+--R                              252C  - 708A C  + (540B  + 396A )C
+--R                            + 
+--R                                      2        3        4       2 2       4
+--R                              (- 36A B  + 1236A )C - 72B  - 576A B  - 120A
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                                3                        2
+--R                              (- 2184C - 2040A)D  + (- 648B C - 2616A B)D
+--R                            + 
+--R                                        3          2          2        2
+--R                                  - 408C  - 2760A C  + (- 504B  - 9096A )C
+--R                                + 
+--R                                         2        3
+--R                                  3720A B  - 2904A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3            2          3       2
+--R                              840B C  + 1656A B C  + (- 168B  - 360A B)C
+--R                            + 
+--R                                    3       3
+--R                              792A B  - 408A B
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 480D  + 1536B D
+--R                            + 
+--R                                   2                  2        2  2
+--R                              (864C  + 4992A C - 2400B  - 1440A )D
+--R                            + 
+--R                                      2                  3        2          4
+--R                              (1056B C  + 576A B C - 768B  + 6624A B)D + 384C
+--R                            + 
+--R                                    3          2        2  2
+--R                              864A C  + (- 576B  + 2304A )C
+--R                            + 
+--R                                        2        3         4       2 2       4
+--R                              (- 1152A B  + 2208A )C - 576B  - 576A B  + 384A
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                             3                         2
+--R                              (256C + 2688A)D  + (- 2688B C - 4736A B)D
+--R                            + 
+--R                                       3          2         2        2
+--R                                  1216C  - 4544A C  + (6528B  + 4032A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 2304A B  + 1344A
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3            2        2             3
+--R                              - 1344B C  + 1728A B C  - 5184A B C + 1536A B
+--R                            + 
+--R                                  3
+--R                              192A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                      3         2                  2        2  2
+--R                              - 512B D  + (1152C  - 4352A C + 2048B  - 1920A )D
+--R                            + 
+--R                                      2                   2          4         3
+--R                              (1280B C  + 4608A B C - 768A B)D - 640C  + 512A C
+--R                            + 
+--R                                      2       2  2            2        3
+--R                              (- 1920B  - 768A )C  + (- 768A B  - 1536A )C
+--R                            + 
+--R                                   2 2       4
+--R                              1152A B  + 384A
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2
+--R                              2048A B D
+--R                            + 
+--R                                         3          2           2        2
+--R                                  - 1024C  + 2048A C  + (- 3072B  + 1024A )C
+--R                                + 
+--R                                           2
+--R                                  - 2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3            2         3        2
+--R                              1024B C  - 3072A B C  + (2048B  + 3072A B)C
+--R                            + 
+--R                                       3        3
+--R                              - 1024A B  - 1024A B
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                               4        3         2               2       2  2
+--R                          - 24D  + 56B D  + (- 24C  + 112A C - 40B  - 120A )D
+--R                        + 
+--R                               2               3      2
+--R                          (8B C  - 48A B C + 8B  + 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                      3                      2
+--R                          (8C + 336A)D  + (- 216B C - 96A B)D
+--R                        + 
+--R                              3         2        2       2          2      3
+--R                          (56C  - 240A C  + (120B  + 184A )C - 80A B  + 96A )D
+--R                        + 
+--R                                3          2        3      2
+--R                          - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 216D  + 192B D
+--R                        + 
+--R                                2               2        2  2
+--R                          (- 72C  - 40A C - 176B  - 1248A )D
+--R                        + 
+--R                                 2                3       2         4         3
+--R                          (304B C  + 48A B C + 64B  + 384A B)D - 32C  + 120A C
+--R                        + 
+--R                                2      2  2         2       3       4      2 2
+--R                          (- 72B  - 24A )C  + (24A B  - 152A )C + 8B  + 96A B
+--R                        + 
+--R                             4
+--R                          24A
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                         3                        2
+--R                          (264C + 2304A)D  + (- 1080B C - 144A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              280C  - 1008A C  + (504B  + 1880A )C - 736A B
+--R                            + 
+--R                                  3
+--R                              864A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3          2        3       2            3
+--R                          - 120B C  - 96A B C  + (- 8B  - 216A B)C - 144A B
+--R                        + 
+--R                             3
+--R                          16A B
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 144D  - 1848B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (576C  - 6600A C + 984B  - 1800A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (1416B C  + 2304A B C + 120B  - 1800A B)D - 192C
+--R                        + 
+--R                                3          2       2  2          2        3
+--R                          648A C  + (- 216B  - 360A )C  + (360A B  - 1128A )C
+--R                        + 
+--R                              4       2 2      4
+--R                          120B  + 576A B  + 72A
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (1392C - 3024A)D  + (4752B C + 4464A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1104C  + 6624A C  + (- 3312B  + 2544A )C
+--R                            + 
+--R                                      2       3
+--R                              - 336A B  + 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3        2             3
+--R                          - 384B C  - 3024A B C  + (144B  + 2592A B)C - 1008A B
+--R                        + 
+--R                              3
+--R                          240A B
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          384D  + 1600B D
+--R                        + 
+--R                                  2                  2        2  2
+--R                          (- 2784C  + 7040A C - 1280B  + 3936A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 3776B C  - 8448A B C + 832B  - 1728A B)D + 480C
+--R                        + 
+--R                                   3         2        2  2           2       3
+--R                          - 2304A C  + (2592B  - 1152A )C  + (1152A B  + 768A )C
+--R                        + 
+--R                              4        2 2       4
+--R                          384B  - 1440A B  - 864A
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                           3                         2
+--R                          (- 1664C + 384A)D  + (- 3456B C - 4224A B)D
+--R                        + 
+--R                                   3          2         2        2            2
+--R                              1792C  - 5376A C  + (2688B  - 5632A )C + 3200A B
+--R                            + 
+--R                                     3
+--R                              - 1536A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2           3        2
+--R                          512B C  + 6144A B C  + (- 2176B  - 2304A B)C
+--R                        + 
+--R                                 3       3
+--R                          1152A B  + 768A B
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                2                2       2  2
+--R                          (2304C  - 512A C + 512B  - 768A )D
+--R                        + 
+--R                                  2                    3        2          4
+--R                          (2048B C  + 6144A B C - 1024B  + 3072A B)D - 256C
+--R                        + 
+--R                                 3           2        2  2
+--R                          1536A C  + (- 2304B  + 1536A )C
+--R                        + 
+--R                                    2       3         4       2 2       4
+--R                          (- 1536A B  + 512A )C - 512B  + 768A B  + 768A
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                                  3        2           2              2
+--R                          (- 1024C  + 1024A C - 2048A B )D - 3072A B C
+--R                        + 
+--R                               3         3
+--R                          2048B C - 1024A B
+--R                     *
+--R                         11
+--R                        a
+--R                 *
+--R                    %%BN1
+--R                + 
+--R                             3 3 8
+--R                      - 16A D a c
+--R                    + 
+--R                              3 2 2        3          2  3
+--R                          4A D a b  + (8B D  + 24A C D )a b
+--R                        + 
+--R                                       3          2           2      3    4
+--R                          ((16C - 64A)D  + 80A B D  + (- 16A C  - 16A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                 3         2  2 3
+--R                          (- 2B D  - 6A C D )a b
+--R                        + 
+--R                                             3                     2
+--R                              (- 12C + 188A)D  + (- 12B C - 52A B)D
+--R                            + 
+--R                                     2      3
+--R                              (- 4A C  + 12A )D
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 24D  + 16B D
+--R                            + 
+--R                                    2              2       2  2
+--R                              (- 24C  + 16A C - 40B  - 120A )D
+--R                            + 
+--R                                   2                2          3     3
+--R                              (8B C  - 48A B C + 24A B)D + 8A C  - 8A C
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                          3                      2
+--R                              (64C + 32A)D  + (- 96B C + 320A B)D
+--R                            + 
+--R                                  3        2       2          2      3
+--R                              (16C  - 64A C  + 112A C - 128A B  - 64A )D
+--R                            + 
+--R                                     2      3
+--R                              48A B C  + 16A B
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                      3                 2        2     3    2 4
+--R                          ((2C - 41A)D  + (3B C + 8A B)D  + (2A C  - 2A )D)a b
+--R                        + 
+--R                                 4        3       2               2      2  2
+--R                              14D  - 80B D  + (18C  - 224A C + 26B  + 66A )D
+--R                            + 
+--R                                   2                2          3     3
+--R                              (2B C  + 36A B C - 18A B)D - 2A C  + 2A C
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                              3                     2
+--R                              (- 144C + 232A)D  + (120B C - 808A B)D
+--R                            + 
+--R                                      3         2       2      2           2
+--R                                  - 4C  + 212A C  + (24B  - 20A )C + 112A B
+--R                                + 
+--R                                      3
+--R                                  196A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3          2      2        3
+--R                              - 4B C  - 36A B C  + 12A B C - 4A B
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 64D  + 96B D
+--R                            + 
+--R                                    2              2       2  2
+--R                              (- 24C  - 80A C - 64B  - 408A )D
+--R                            + 
+--R                                    2                3       2        4        3
+--R                              (80B C  - 96A B C + 64B  + 336A B)D - 8C  - 32A C
+--R                            + 
+--R                                    2      2  2           2      3        2 2
+--R                              (- 24B  - 48A )C  + (- 48A B  - 32A )C - 24A B
+--R                            + 
+--R                                  4
+--R                              - 8A
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    3                       2
+--R                              384A D  + (- 384B C - 128A B)D
+--R                            + 
+--R                                  3         2        2       2           2
+--R                              (64C  - 128A C  + (192B  + 448A )C - 512A B )D
+--R                            + 
+--R                                     3           2       2           3      3
+--R                              - 64B C  + 192A B C  - 192A B C + 64A B  + 64A B
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                  4        3        2             2     2  2
+--R                              - 2D  + 18B D  + (- 3C  + 52A C - 4B  - 9A )D
+--R                            + 
+--R                                    2              2
+--R                              (- B C  - 6A B C + 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                           3                    2
+--R                              (86C - 686A)D  + (54B C + 420A B)D
+--R                            + 
+--R                                      3       2         2      2          2
+--R                                  - 4C  + 9A C  + (- 18B  - 14A )C - 32A B
+--R                                + 
+--R                                        3
+--R                                  - 115A
+--R                             *
+--R                                D
+--R                            + 
+--R                                 3         2     2
+--R                              B C  + 6A B C  - 3A B C
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                  4        3
+--R                              224D  - 92B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (162C  + 280A C + 320B  + 1206A )D
+--R                            + 
+--R                                       2                 3       2        4
+--R                              (- 172B C  + 336A B C - 60B  - 492A B)D + 6C
+--R                            + 
+--R                                     3       2      2  2         2      3
+--R                              - 48A C  + (18B  + 24A )C  + (24A B  + 80A )C
+--R                            + 
+--R                                2 2     4
+--R                              6A B  + 2A
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                               3                     2
+--R                              (- 232C - 1128A)D  + (936B C - 584A B)D
+--R                            + 
+--R                                        3         2          2        2
+--R                                  - 208C  + 400A C  + (- 312B  - 1376A )C
+--R                                + 
+--R                                         2      3
+--R                                  1192A B  - 64A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2       3       2           3
+--R                              96B C  - 384A B C  + (24B  + 240A B)C - 24A B
+--R                            + 
+--R                                    3
+--R                              - 144A B
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                 4         3        2               2       2  2
+--R                              64D  + 256B D  + (144C  + 608A C - 32B  + 336A )D
+--R                            + 
+--R                                    2      3       2         4        3
+--R                              (64B C  + 64B  + 768A B)D + 48C  - 96A C
+--R                            + 
+--R                                  2      2  2           2       3        4
+--R                              (48B  + 96A )C  + (- 96A B  + 224A )C - 32B
+--R                            + 
+--R                                    2 2      4
+--R                              - 144A B  - 16A
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                              3            2
+--R                              (- 256C + 256A)D  - 1792A B D
+--R                            + 
+--R                                     3         2        2      2           2
+--R                                  64C  - 256A C  + (768B  - 64A )C + 128A B
+--R                                + 
+--R                                      3
+--R                                  256A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3       2
+--R                              - 256B C  + 192A B C  + (- 128B  - 768A B)C
+--R                            + 
+--R                                    3      3
+--R                              256A B  + 64A B
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                             3                     2
+--R                              (- 13C + 139A)D  + (- 18B C - 58A B)D
+--R                            + 
+--R                                3        2      2     2         2      3
+--R                              (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 109D  + 265B D
+--R                            + 
+--R                                     2                2       2  2
+--R                              (- 114C  + 591A C - 183B  - 543A )D
+--R                            + 
+--R                                    2                 3       2       4        3
+--R                              (27B C  - 228A B C + 19B  + 225A B)D - C  + 13A C
+--R                            + 
+--R                                   2     2  2          2      3
+--R                              (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                            3                        2
+--R                              (258C + 874A)D  + (- 978B C + 1542A B)D
+--R                            + 
+--R                                     3         2       2       2           2
+--R                                  94C  - 990A C  + (54B  + 426A )C - 714A B
+--R                                + 
+--R                                        3
+--R                                  - 346A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3           2         3       2          3
+--R                              - 10B C  + 234A B C  + (- 14B  - 174A B)C + 2A B
+--R                            + 
+--R                                 3
+--R                              30A B
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                      3          2               2       2  2
+--R                              - 768B D  + (- 192C  - 736A C - 80B  + 384A )D
+--R                            + 
+--R                                       2                 3        2            3
+--R                              (- 272B C  + 96A B C - 384B  - 1968A B)D + 368A C
+--R                            + 
+--R                                  2       2  2          2       3        4
+--R                              (48B  + 192A )C  + (288A B  - 112A )C + 16B
+--R                            + 
+--R                                  2 2      4
+--R                              240A B  + 64A
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (384C - 1536A)D  + (576B C + 4032A B)D
+--R                            + 
+--R                                        3         2           2        2
+--R                                  - 416C  + 672A C  + (- 2112B  - 1312A )C
+--R                                + 
+--R                                        2       3
+--R                                  512A B  - 992A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3        2            3
+--R                              480B C  - 672A B C  + (128B  + 1632A B)C - 512A B
+--R                            + 
+--R                                    3
+--R                              - 160A B
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              256D  - 384B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 192C  + 1024A C - 256B  + 2112A )D
+--R                            + 
+--R                                       2                  3        2          4
+--R                              (- 640B C  - 768A B C - 256B  - 1152A B)D + 192C
+--R                            + 
+--R                                   2       2  2          2       3         2 2
+--R                              (576B  + 384A )C  + (384A B  + 512A )C - 192A B
+--R                            + 
+--R                                   4
+--R                              - 64A
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                              3                       2
+--R                              (- 256C - 512A)D  + (1536B C - 1280A B)D
+--R                            + 
+--R                                     2        2           2       3         3
+--R                              (256A C  - 2048A C + 2560A B  + 256A )D - 512B C
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                 4        3       2               2      2  2
+--R                              14D  - 54B D  + (18C  - 140A C + 26B  + 66A )D
+--R                            + 
+--R                                   2               3      2
+--R                              (2B C  + 36A B C - 2B  - 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                              3                    2
+--R                              (- 142C + 688A)D  + (54B C - 800A B)D
+--R                            + 
+--R                                      3         2       2      2           2
+--R                                    6C  + 100A C  + (54B  + 22A )C + 160A B
+--R                                  + 
+--R                                        3
+--R                                    248A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3          2      3      2
+--R                              - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 416D  + 190B D
+--R                            + 
+--R                                    2                 2        2  2
+--R                              (- 84C  - 1254A C - 438B  - 2514A )D
+--R                            + 
+--R                                     2                  3        2         4
+--R                              (666B C  - 264A B C + 298B  + 1758A B)D - 20C
+--R                            + 
+--R                                   3         2       2  2            2       3
+--R                              22A C  + (- 66B  - 102A )C  + (- 114A B  - 158A )C
+--R                            + 
+--R                                  4      2 2      4
+--R                              - 2B  - 48A B  - 14A
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (284C + 2876A)D  + (- 588B C - 3516A B)D
+--R                            + 
+--R                                      3        2         2        2            2
+--R                                  788C  + 84A C  + (2292B  + 4428A )C - 1404A B
+--R                                + 
+--R                                       3
+--R                                  2252A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3        2
+--R                              - 532B C  + 492A B C  + (- 148B  - 1164A B)C
+--R                            + 
+--R                                    3       3
+--R                              140A B  + 308A B
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 608D  + 640B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (240C  - 3552A C + 960B  - 5232A )D
+--R                            + 
+--R                                      2                   3        2          4
+--R                              (1632B C  + 1536A B C + 928B  + 1632A B)D - 464C
+--R                            + 
+--R                                      3          2        2  2
+--R                              - 128A C  + (- 912B  - 1344A )C
+--R                            + 
+--R                                       2        3         4       2 2      4
+--R                              (- 384A B  - 1664A )C + 160B  + 528A B  + 16A
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                              3                         2
+--R                              (1280C + 1664A)D  + (- 1920B C + 3456A B)D
+--R                            + 
+--R                                      3         2          2        2
+--R                                  128C  + 576A C  + (- 192B  + 6144A )C
+--R                                + 
+--R                                           2       3
+--R                                  - 4800A B  + 704A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2        3       2
+--R                              - 256B C  - 768A B C  + (704B  + 384A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 448A B  + 128A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              128D  - 1280B D
+--R                            + 
+--R                                     2                 2       2  2
+--R                              (- 768C  - 2560A C + 640B  + 768A )D
+--R                            + 
+--R                                       2                   2          4
+--R                              (- 896B C  - 768A B C - 4224A B)D - 128C
+--R                            + 
+--R                                      3        2       2  2          2       3
+--R                              - 128A C  + (384B  - 768A )C  + (768A B  - 896A )C
+--R                            + 
+--R                                  4       2 2       4
+--R                              256B  + 384A B  - 128A
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                      3                       2
+--R                              - 512A D  + (1536B C + 2048A B)D
+--R                            + 
+--R                                        3          2           2        2
+--R                                  - 256C  + 2048A C  + (- 3072B  - 1792A )C
+--R                                + 
+--R                                         2
+--R                                  2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2        2             3       3
+--R                            1024B C  - 768A B C  + 3072A B C - 1024A B  - 256A B
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                           3                    2
+--R                              (20C - 156A)D  + (24B C + 104A B)D
+--R                            + 
+--R                                 3        2         2      2          2      3
+--R                            (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              204D  - 316B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (144C  - 364A C + 292B  + 1092A )D
+--R                            + 
+--R                                       2                 3       2        4
+--R                              (- 164B C  + 288A B C - 84B  - 636A B)D + 4C
+--R                            + 
+--R                                     3       2      2  2         2      3
+--R                              - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                              3                       2
+--R                              (- 36C - 3084A)D  + (1368B C + 1312A B)D
+--R                            + 
+--R                                        3          2          2        2
+--R                                  - 428C  + 1348A C  + (- 996B  - 1780A )C
+--R                                + 
+--R                                        2       3
+--R                                  644A B  - 996A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2       3       2          3
+--R                              128B C  - 312A B C  + (64B  + 528A B)C - 8A B
+--R                            + 
+--R                                   3
+--R                              - 56A B
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              924D  + 588B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 216C  + 5556A C + 60B  + 6156A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 2172B C  - 1584A B C - 444B  - 1332A B)D
+--R                            + 
+--R                                  4         3        2       2  2
+--R                              252C  - 708A C  + (540B  + 396A )C
+--R                            + 
+--R                                      2        3        4       2 2       4
+--R                              (- 36A B  + 1236A )C - 72B  - 576A B  - 120A
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                                3                        2
+--R                              (- 2184C - 2040A)D  + (- 648B C - 2616A B)D
+--R                            + 
+--R                                        3          2          2        2
+--R                                  - 408C  - 2760A C  + (- 504B  - 9096A )C
+--R                                + 
+--R                                         2        3
+--R                                  3720A B  - 2904A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3            2          3       2
+--R                              840B C  + 1656A B C  + (- 168B  - 360A B)C
+--R                            + 
+--R                                    3       3
+--R                              792A B  - 408A B
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 480D  + 1536B D
+--R                            + 
+--R                                   2                  2        2  2
+--R                              (864C  + 4992A C - 2400B  - 1440A )D
+--R                            + 
+--R                                      2                  3        2          4
+--R                              (1056B C  + 576A B C - 768B  + 6624A B)D + 384C
+--R                            + 
+--R                                    3          2        2  2
+--R                              864A C  + (- 576B  + 2304A )C
+--R                            + 
+--R                                        2        3         4       2 2       4
+--R                              (- 1152A B  + 2208A )C - 576B  - 576A B  + 384A
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                             3                         2
+--R                              (256C + 2688A)D  + (- 2688B C - 4736A B)D
+--R                            + 
+--R                                       3          2         2        2
+--R                                  1216C  - 4544A C  + (6528B  + 4032A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 2304A B  + 1344A
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3            2        2             3
+--R                              - 1344B C  + 1728A B C  - 5184A B C + 1536A B
+--R                            + 
+--R                                  3
+--R                              192A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                      3         2                  2        2  2
+--R                              - 512B D  + (1152C  - 4352A C + 2048B  - 1920A )D
+--R                            + 
+--R                                      2                   2          4         3
+--R                              (1280B C  + 4608A B C - 768A B)D - 640C  + 512A C
+--R                            + 
+--R                                      2       2  2            2        3
+--R                              (- 1920B  - 768A )C  + (- 768A B  - 1536A )C
+--R                            + 
+--R                                   2 2       4
+--R                              1152A B  + 384A
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2
+--R                              2048A B D
+--R                            + 
+--R                                         3          2           2        2
+--R                                  - 1024C  + 2048A C  + (- 3072B  + 1024A )C
+--R                                + 
+--R                                           2
+--R                                  - 2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3            2         3        2
+--R                              1024B C  - 3072A B C  + (2048B  + 3072A B)C
+--R                            + 
+--R                                       3        3
+--R                              - 1024A B  - 1024A B
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                               4        3         2               2       2  2
+--R                          - 24D  + 56B D  + (- 24C  + 112A C - 40B  - 120A )D
+--R                        + 
+--R                               2               3      2
+--R                          (8B C  - 48A B C + 8B  + 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                      3                      2
+--R                          (8C + 336A)D  + (- 216B C - 96A B)D
+--R                        + 
+--R                              3         2        2       2          2      3
+--R                          (56C  - 240A C  + (120B  + 184A )C - 80A B  + 96A )D
+--R                        + 
+--R                                3          2        3      2
+--R                          - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 216D  + 192B D
+--R                        + 
+--R                                2               2        2  2
+--R                          (- 72C  - 40A C - 176B  - 1248A )D
+--R                        + 
+--R                                 2                3       2         4         3
+--R                          (304B C  + 48A B C + 64B  + 384A B)D - 32C  + 120A C
+--R                        + 
+--R                                2      2  2         2       3       4      2 2
+--R                          (- 72B  - 24A )C  + (24A B  - 152A )C + 8B  + 96A B
+--R                        + 
+--R                             4
+--R                          24A
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                         3                        2
+--R                          (264C + 2304A)D  + (- 1080B C - 144A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              280C  - 1008A C  + (504B  + 1880A )C - 736A B
+--R                            + 
+--R                                  3
+--R                              864A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3          2        3       2            3
+--R                          - 120B C  - 96A B C  + (- 8B  - 216A B)C - 144A B
+--R                        + 
+--R                             3
+--R                          16A B
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 144D  - 1848B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (576C  - 6600A C + 984B  - 1800A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (1416B C  + 2304A B C + 120B  - 1800A B)D - 192C
+--R                        + 
+--R                                3          2       2  2          2        3
+--R                          648A C  + (- 216B  - 360A )C  + (360A B  - 1128A )C
+--R                        + 
+--R                              4       2 2      4
+--R                          120B  + 576A B  + 72A
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (1392C - 3024A)D  + (4752B C + 4464A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1104C  + 6624A C  + (- 3312B  + 2544A )C
+--R                            + 
+--R                                      2       3
+--R                              - 336A B  + 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3        2             3
+--R                          - 384B C  - 3024A B C  + (144B  + 2592A B)C - 1008A B
+--R                        + 
+--R                              3
+--R                          240A B
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          384D  + 1600B D
+--R                        + 
+--R                                  2                  2        2  2
+--R                          (- 2784C  + 7040A C - 1280B  + 3936A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 3776B C  - 8448A B C + 832B  - 1728A B)D + 480C
+--R                        + 
+--R                                   3         2        2  2           2       3
+--R                          - 2304A C  + (2592B  - 1152A )C  + (1152A B  + 768A )C
+--R                        + 
+--R                              4        2 2       4
+--R                          384B  - 1440A B  - 864A
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                           3                         2
+--R                          (- 1664C + 384A)D  + (- 3456B C - 4224A B)D
+--R                        + 
+--R                                   3          2         2        2            2
+--R                              1792C  - 5376A C  + (2688B  - 5632A )C + 3200A B
+--R                            + 
+--R                                     3
+--R                              - 1536A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2           3        2
+--R                          512B C  + 6144A B C  + (- 2176B  - 2304A B)C
+--R                        + 
+--R                                 3       3
+--R                          1152A B  + 768A B
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                2                2       2  2
+--R                          (2304C  - 512A C + 512B  - 768A )D
+--R                        + 
+--R                                  2                    3        2          4
+--R                          (2048B C  + 6144A B C - 1024B  + 3072A B)D - 256C
+--R                        + 
+--R                                 3           2        2  2
+--R                          1536A C  + (- 2304B  + 1536A )C
+--R                        + 
+--R                                    2       3         4       2 2       4
+--R                          (- 1536A B  + 512A )C - 512B  + 768A B  + 768A
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                                  3        2           2              2
+--R                          (- 1024C  + 1024A C - 2048A B )D - 3072A B C
+--R                        + 
+--R                               3         3
+--R                          2048B C - 1024A B
+--R                     *
+--R                         11
+--R                        a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                      4 2 8
+--R                  8A D a c
+--R                + 
+--R                            4   2          4          3  2
+--R                      - 2A D a b  + (- 4B D  - 16A C D )a b
+--R                    + 
+--R                                    4          3         2     3  2  3
+--R                      ((- 8C + 32A)D  - 48A B D  + (16A C  + 8A )D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                          4         3    3
+--R                      (B D  + 4A C D )a b
+--R                    + 
+--R                                  4                  3        2      3  2  2 2
+--R                      ((6C - 88A)D  + (8B C + 36A B)D  + (4A C  - 10A )D )a b
+--R                    + 
+--R                             5       4       2              2      2  3
+--R                          12D  - 4B D  + (16C  - 32A C + 24B  + 68A )D
+--R                        + 
+--R                                 2                2   2           3      3
+--R                          (- 8B C  + 24A B C - 12A B)D  + (- 16A C  + 16A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                       4                    3
+--R                          (- 32C - 8A)D  + (48B C - 192A B)D
+--R                        + 
+--R                                3        2      2          2      3  2
+--R                          (- 16C  + 64A C  - 64A C + 104A B  + 32A )D
+--R                        + 
+--R                                    2      3          4     3 2
+--R                          (- 48A B C  - 16A B)D + 8A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                     4                   3          2     3  2
+--R                        ((- C + 19A)D  + (- 2B C - 6A B)D  + (- 2A C  + 2A )D )a
+--R                     *
+--R                         4
+--R                        b
+--R                    + 
+--R                              5        4         2               2      2  3
+--R                          - 7D  + 35B D  + (- 12C  + 144A C - 18B  - 41A )D
+--R                        + 
+--R                                 2                2   2        3     3
+--R                          (- 2B C  - 30A B C + 15A B)D  + (4A C  - 4A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                       4                      3
+--R                          (56C - 114A)D  + (- 68B C + 496A B)D
+--R                        + 
+--R                             3         2         2     2          2       3  2
+--R                          (4C  - 152A C  + (- 12B  + 8A )C - 94A B  - 116A )D
+--R                        + 
+--R                               3          2      2        3          4     3 2
+--R                          (8B C  + 60A B C  - 24A B C + 4A B)D - 2A C  + 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                             5        4       2              2       2  3
+--R                          28D  - 44B D  + (56C  + 32A C + 20B  + 232A )D
+--R                        + 
+--R                                  2                3       2   2
+--R                          (- 32B C  + 48A B C - 52B  - 240A B)D
+--R                        + 
+--R                                 4        3       2      2  2         2      3
+--R                              16C  - 32A C  + (24B  + 60A )C  + (48A B  + 72A )C
+--R                            + 
+--R                                 2 2     4
+--R                              24A B  - 4A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      2   2
+--R                          - 4B C  - 24A B C  + 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                  4                    3
+--R                          - 160A D  + (192B C + 32A B)D
+--R                        + 
+--R                                     3        2         2       2           2
+--R                                - 64C  + 56A C  + (- 96B  - 256A )C + 416A B
+--R                              + 
+--R                                  3
+--R                                8A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                3           2       2           3      3
+--R                          (48B C  - 192A B C  + 144A B C - 96A B  - 64A B)D
+--R                        + 
+--R                              5        4      2 3         2      3  2      4
+--R                          - 8C  + 32A C  - 16A C  + (24A B  - 32A )C  + 24A C
+--R                        + 
+--R                            3 2
+--R                          8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           5       4      2             2     2  3
+--R                          D  - 8B D  + (2C  - 32A C + 3B  + 6A )D
+--R                        + 
+--R                              2              2   2
+--R                          (B C  + 6A B C - 3A B)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                         4                      3
+--R                          (- 33C + 297A)D  + (- 30B C - 286A B)D
+--R                        + 
+--R                             3        2       2      2          2      3  2
+--R                          (4C  - 24A C  + (15B  + 14A )C + 29A B  + 98A )D
+--R                        + 
+--R                                 3          2     2
+--R                          (- 2B C  - 12A B C  + 6A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               5        4          2               2       2  3
+--R                          - 97D  + 29B D  + (- 114C  - 40A C - 173B  - 672A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (112B C  - 192A B C + 49B  + 342A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 12C  + 120A C  + (- 30B  - 39A )C
+--R                            + 
+--R                                      2       3       2 2    4
+--R                              (- 36A B  - 162A )C - 6A B  + A
+--R                         *
+--R                            D
+--R                        + 
+--R                             4         3     2   2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                       4                       3
+--R                          (68C + 432A)D  + (- 488B C + 400A B)D
+--R                        + 
+--R                                    3         2        2       2            2
+--R                                112C  - 262A C  + (180B  + 740A )C - 1000A B
+--R                              + 
+--R                                   3
+--R                                74A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2           3
+--R                              - 92B C  + 480A B C  + (- 24B  - 300A B)C + 56A B
+--R                            + 
+--R                                  3
+--R                              168A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3        2      3  2
+--R                          6C  - 64A C  + (12B  + 16A )C  + (6A B  + 80A )C
+--R                        + 
+--R                              4      3 2
+--R                          - 6A C - 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                               5         4         2               2       2  3
+--R                          - 40D  - 136B D  + (- 28C  - 136A C - 24B  - 140A )D
+--R                        + 
+--R                                  2                3       2   2
+--R                          (- 52B C  - 24A B C - 40B  - 612A B)D
+--R                        + 
+--R                                 4        3         2      2  2
+--R                              44C  + 32A C  + (- 36B  + 48A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (168A B  - 176A )C + 48B  + 252A B  - 44A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3         3      2   2
+--R                          20B C  - 80A B C  + (- 12B  + 48A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                        4           3
+--R                          (128C - 128A)D  + 896A B D
+--R                        + 
+--R                                     3        2          2      2          2
+--R                                - 16C  - 32A C  + (- 384B  + 16A )C - 32A B
+--R                              + 
+--R                                     3
+--R                                - 96A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3          2       3       2            3
+--R                              192B C  - 96A B C  + (64B  + 576A B)C - 384A B
+--R                            + 
+--R                                   3
+--R                              - 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4         2      2  3        2 2
+--R                          - 32C  + 16A C  + (- 16B  - 64A )C  + 96A B C
+--R                        + 
+--R                                2 2      4          4      3 2      5
+--R                          (- 48A B  + 96A )C + 32A B  + 32A B  - 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                     4                   3
+--R                          (5C - 59A)D  + (10B C + 42A B)D
+--R                        + 
+--R                              3        2        2     2         2      3  2
+--R                          (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                             5         4       2                2       2  3
+--R                          47D  - 107B D  + (67C  - 352A C + 117B  + 325A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (- 15B C  + 198A B C - 17B  - 195A B)D
+--R                        + 
+--R                             4        3      2     2  2        2      3
+--R                          (2C  - 26A C  + (6B  + 6A )C  + (6A B  + 34A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         4                     3
+--R                          (- 29C - 315A)D  + (540B C - 958A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 30C  + 546A C  + (- 57B  - 213A )C + 621A B
+--R                            + 
+--R                                  3
+--R                              171A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     2       3       2          3      3       5
+--R                          (- 414A B C  + (22B  + 318A B)C - 8A B  - 36A B)D - C
+--R                        + 
+--R                               4        2     2  3          2      3  2
+--R                          13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5         4         2               2       2  3
+--R                          36D  + 428B D  + (- 45C  + 98A C + 196B  - 261A )D
+--R                        + 
+--R                                 2                3        2   2
+--R                          (149B C  + 6A B C + 316B  + 1605A B)D
+--R                        + 
+--R                                   4        3         2       2  2
+--R                              - 95C  - 56A C  + (- 51B  - 330A )C
+--R                            + 
+--R                                       2     3        4       2 2      4
+--R                              (- 354A B  - 8A )C - 32B  - 339A B  + 41A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4           3        3       2   2
+--R                          5B C  + 176A B C  + (- 5B  - 138A B)C
+--R                        + 
+--R                                3      3        2 3     4
+--R                          (10A B  + 16A B)C + 3A B  + 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                          4                        3
+--R                          (- 108C + 620A)D  + (- 160B C - 1984A B)D
+--R                        + 
+--R                                    3        2         2       2           2
+--R                                164C  - 36A C  + (1080B  + 796A )C - 584A B
+--R                              + 
+--R                                    3
+--R                                612A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 520B C  + 456A B C  + (- 128B  - 1464A B)C
+--R                            + 
+--R                                    3       3
+--R                              768A B  + 120A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4      2       2  3            2      3  2
+--R                          56C  - 80A C  + (4B  + 128A )C  + (- 132A B  + 64A )C
+--R                        + 
+--R                              4       2 2       4         4      3 2      5
+--R                          (20B  + 156A B  - 184A )C - 4A B  - 28A B  + 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 112D  + 208B D
+--R                        + 
+--R                                 2                2        2  3
+--R                          (- 176C  - 288A C + 192B  - 1072A )D
+--R                        + 
+--R                                 2                  3       2   2
+--R                          (112B C  + 288A B C + 256B  + 624A B)D
+--R                        + 
+--R                                   4        3          2       2  2
+--R                              - 64C  + 64A C  + (- 336B  - 288A )C
+--R                            + 
+--R                                      2       3        4       2 2      4
+--R                              (- 96A B  - 640A )C + 48B  + 432A B  + 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4       3      2   2            3      3
+--R                          96B C  + (16B  + 96A B)C  + (- 160A B  - 64A B)C
+--R                        + 
+--R                               5       2 3
+--R                          - 16B  - 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (128C + 128A)D  + (- 768B C + 768A B)D
+--R                        + 
+--R                               3         2        2           2       3  2
+--R                          (192C  - 256A C  + 1088A C - 1792A B  - 128A )D
+--R                        + 
+--R                                   2       3        3           4      2 3
+--R                          (384A B C  + 256B C + 128A B)D - 64A C  - 64B C
+--R                        + 
+--R                              3 2       2 2          4      5
+--R                          128A C  - 192A B C + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                              5        4         2              2      2  3
+--R                          - 6D  + 22B D  + (- 10C  + 76A C - 18B  - 42A )D
+--R                        + 
+--R                                 2               3      2   2
+--R                          (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                       4                      3
+--R                          (24C - 276A)D  + (- 52B C + 536A B)D
+--R                        + 
+--R                                     3       2         2      2           2
+--R                                - 16C  - 4A C  + (- 48B  - 40A )C - 148A B
+--R                              + 
+--R                                      3
+--R                                - 212A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                               3          2        3      2
+--R                          (4B C  + 72A B C  + (- 4B  - 60A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              5         4       2                2        2  3
+--R                          129D  - 160B D  + (56C  + 572A C + 130B  + 1334A )D
+--R                        + 
+--R                                   2                 3        2   2
+--R                          (- 426B C  + 96A B C - 248B  - 1344A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              55C  - 192A C  + (120B  + 180A )C
+--R                            + 
+--R                                     2       3       4      2 2     4
+--R                              (180A B  + 356A )C + 5B  + 66A B  - 7A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      3      2   2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                           4                     3
+--R                          (- 203C - 1051A)D  + (60B C + 1760A B)D
+--R                        + 
+--R                                    3         2           2        2
+--R                              - 216C  - 144A C  + (- 1356B  - 2418A )C
+--R                            + 
+--R                                     2        3
+--R                              1296A B  - 1594A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2        3        2            3
+--R                              624B C  - 612A B C  + (168B  + 1428A B)C - 300A B
+--R                            + 
+--R                                    3
+--R                              - 408A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5         4         2      2  3
+--R                          - 29C  + 119A C  + (- 54B  - 80A )C
+--R                        + 
+--R                                  2       3  2        4      2 2      4        4
+--R                          (- 30A B  - 188A )C  + (- 5B  - 36A B  + 37A )C - A B
+--R                        + 
+--R                            3 2     5
+--R                          4A B  - 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                              5         4        2                 2        2  3
+--R                          196D  - 508B D  + (226C  + 1068A C - 712B  + 2514A )D
+--R                        + 
+--R                                   2                  3       2   2
+--R                          (- 258B C  - 540A B C - 808B  - 930A B)D
+--R                        + 
+--R                                 4        3        2       2  2
+--R                              98C  - 64A C  + (894B  + 852A )C
+--R                            + 
+--R                                      2        3         4        2 2       4
+--R                              (- 12A B  + 1872A )C - 268B  - 1218A B  + 154A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4          3       3       2   2
+--R                          - 190B C  + 96A B C  + (34B  - 204A B)C
+--R                        + 
+--R                                 3       3        5      2 3      4
+--R                          (220A B  + 304A B)C + 4B  + 82A B  + 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                          4                       3
+--R                          (- 344C - 488A)D  + (1152B C - 1920A B)D
+--R                        + 
+--R                                    3         2         2        2            2
+--R                              - 104C  + 120A C  + (- 48B  - 3000A )C + 3408A B
+--R                            + 
+--R                                    3
+--R                              - 504A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2          3      2            3
+--R                              112B C  - 528A B C  + (- 384B  - 48A B)C + 512A B
+--R                            + 
+--R                                    3
+--R                              - 560A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2      2  3
+--R                          16C  + 80A C  + (- 8B  + 32A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 168A B  - 320A )C  + (40B  + 552A B  - 176A )C
+--R                        + 
+--R                                  4     3 2       5
+--R                          - 168A B  + 8A B  + 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                               5         4                  2       2  3
+--R                          - 32D  + 608B D  + (1024A C - 256B  - 576A )D
+--R                        + 
+--R                                 2                   2   2
+--R                          (512B C  + 384A B C + 2880A B)D
+--R                        + 
+--R                                    4         3            2       3         4
+--R                              - 224C  + 128A C  + (- 768A B  + 512A )C - 288B
+--R                            + 
+--R                                    2 2       4
+--R                              - 768A B  + 352A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3 2       3         5
+--R                          - 32B C  + 256A B C  + 128B C  + 384A B C - 32B
+--R                        + 
+--R                                2 3       4
+--R                          - 128A B  + 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                4                       3
+--R                          128A D  + (- 768B C - 512A B)D
+--R                        + 
+--R                                  3         2         2        2            2
+--R                              256C  - 896A C  + (1536B  + 1024A )C - 1664A B
+--R                            + 
+--R                                    3
+--R                              - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2        2             3
+--R                              - 768B C  + 768A B C  - 2304A B C + 1536A B
+--R                            + 
+--R                                  3
+--R                              256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4       2 3            2       3  2
+--R                          128C  - 128A C  + 256A C  + (- 384A B  + 128A )C
+--R                        + 
+--R                                4        3 2
+--R                          - 384A C - 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                       4                    3
+--R                          (- 4C + 60A)D  + (- 8B C - 72A B)D
+--R                        + 
+--R                             3        2       2      2          2      3  2
+--R                          (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                     *
+--R                           8
+--R                        a b
+--R                    + 
+--R                               5         4         2                2       2  3
+--R                          - 68D  + 148B D  + (- 52C  + 176A C - 156B  - 620A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (116B C  - 264A B C + 76B  + 564A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 8C  + 40A C  + (- 24B  - 24A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 24A B  - 72A )C
+--R                         *
+--R                            D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (24C + 1088A)D  + (- 504B C - 672A B)D
+--R                        + 
+--R                                  3         2        2        2           2
+--R                              132C  - 628A C  + (744B  + 1048A )C - 608A B
+--R                            + 
+--R                                  3
+--R                              912A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2          3       2
+--R                              - 176B C  + 600A B C  + (- 104B  - 936A B)C
+--R                            + 
+--R                                   3      3
+--R                              32A B  + 80A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3         2      3  2
+--R                          4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                                5        4        2                2        2  3
+--R                          - 288D  - 44B D  + (112C  - 1816A C + 60B  - 2928A )D
+--R                        + 
+--R                                 2                  3       2   2
+--R                          (792B C  + 672A B C + 348B  + 528A B)D
+--R                        + 
+--R                                   4         3          2       2  2
+--R                              - 64C  + 408A C  + (- 732B  - 240A )C
+--R                            + 
+--R                                     2        3         4        2 2      4
+--R                              (144A B  - 1576A )C + 148B  + 1044A B  - 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          68B C  - 272A B C  + (28B  + 384A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (656C + 664A)D  + (128B C + 1416A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 136C  + 792A C  + (636B  + 4356A )C - 2652A B
+--R                            + 
+--R                                   3
+--R                              1892A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3          2        3       2            3
+--R                              - 480B C  - 72A B C  + (152B  - 120A B)C - 848A B
+--R                            + 
+--R                                   3
+--R                              1008A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3
+--R                          - 8C  - 64A C  + (188B  - 28A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (252A B  + 412A )C  + (- 100B  - 768A B  + 308A )C
+--R                        + 
+--R                               4      3 2      5
+--R                          12A B  - 64A B  - 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          176D  - 592B D
+--R                        + 
+--R                                 2                  2        2  3
+--R                          (- 156C  - 1896A C + 1328B  + 1172A )D
+--R                        + 
+--R                                    2                  3        2   2
+--R                          (- 1188B C  - 216A B C + 560B  - 4596A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              252C  - 416A C  + (- 420B  - 792A )C
+--R                            + 
+--R                                      2        3         4        2 2       4
+--R                              (1128A B  - 1632A )C + 656B  + 1500A B  - 740A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3      2   2
+--R                          108B C  - 256A B C  + (- 252B  - 24A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (120A B  - 768A B)C + 80B  + 356A B  - 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                          4                      3
+--R                          (- 208C - 912A)D  + (960B C + 1280A B)D
+--R                        + 
+--R                                    3          2           2        2
+--R                              - 400C  + 1616A C  + (- 3360B  - 2352A )C
+--R                            + 
+--R                                     2       3
+--R                              2304A B  - 912A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3            2        3        2
+--R                              1568B C  - 1632A B C  + (256B  + 5088A B)C
+--R                            + 
+--R                                       3       3
+--R                              - 2304A B  - 160A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2       2  3
+--R                          - 160C  + 160A C  + (48B  - 384A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (336A B  - 160A )C  + (- 80B  - 432A B  + 544A )C
+--R                        + 
+--R                                  4      3 2
+--R                          - 112A B  + 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                4          2                  2       2  3
+--R                          128B D  + (- 192C  + 1664A C - 1088B  + 576A )D
+--R                        + 
+--R                                2                   3        2   2
+--R                          (64B C  - 1920A B C - 192B  + 1344A B)D
+--R                        + 
+--R                                    3        2       2  2
+--R                              256A C  + (960B  + 192A )C
+--R                            + 
+--R                                       2        3         4        2 2      4
+--R                              (- 384A B  + 1408A )C - 192B  - 2112A B  - 64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3         3       2   2
+--R                          - 320B C  + 384A B C  + (- 64B  - 576A B)C
+--R                        + 
+--R                                 3       3         5       2 3
+--R                          (640A B  + 256A B)C + 64B  + 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                    3
+--R                          - 512A B D
+--R                        + 
+--R                                  3         2         2       2           2
+--R                              256C  - 896A C  + (1536B  - 256A )C + 512A B
+--R                            + 
+--R                                    3
+--R                              - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2           3        2
+--R                              - 768B C  + 1536A B C  + (- 1024B  - 2304A B)C
+--R                            + 
+--R                                     3       3
+--R                              1536A B  + 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4        2       2  3         2 2
+--R                          128C  - 256A C  + (256B  + 256A )C  - 384A B C
+--R                        + 
+--R                               2 2       4           4       3 2       5
+--R                          (768A B  - 384A )C - 512A B  - 128A B  + 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                        5        4      2              2      2  3
+--R                      8D  - 24B D  + (8C  - 48A C + 24B  + 72A )D
+--R                    + 
+--R                             2               3      2   2
+--R                      (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                 *
+--R                       9
+--R                    a b
+--R                + 
+--R                              4                   3
+--R                      - 112A D  + (80B C + 32A B)D
+--R                    + 
+--R                            3        2         2       2          2      3  2
+--R                      (- 16C  + 96A C  + (- 96B  - 112A )C + 80A B  - 96A )D
+--R                    + 
+--R                            3          2       3       2
+--R                      (16B C  - 96A B C  + (16B  + 144A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                         5         4      2               2       2  3
+--R                      68D  - 104B D  + (8C  - 64A C + 112B  + 656A )D
+--R                    + 
+--R                               2                 3       2   2
+--R                      (- 112B C  + 144A B C - 56B  - 312A B)D
+--R                    + 
+--R                            4        3      2 2           2       3        4
+--R                          4C  - 32A C  + 96B C  + (- 48A B  + 176A )C - 20B
+--R                        + 
+--R                                2 2      4
+--R                          - 168A B  + 12A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4          3        3      2   2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     4                    3
+--R                      (- 52C - 772A)D  + (416B C + 32A B)D
+--R                    + 
+--R                                 3         2          2        2           2
+--R                            - 48C  + 480A C  + (- 528B  - 1016A )C + 592A B
+--R                          + 
+--R                                  3
+--R                            - 776A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                            3           2       3       2            3      3
+--R                      (80B C  - 432A B C  + (48B  + 672A B)C + 176A B  - 96A B)D
+--R                    + 
+--R                        5        4         2      2  3           2      3  2
+--R                      4C  - 12A C  + (- 24B  + 16A )C  + (- 24A B  - 32A )C
+--R                    + 
+--R                          4       2 2      4         4      3 2      5
+--R                      (20B  + 144A B  - 52A )C + 4A B  + 16A B  + 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                         5         4          2                 2       2  3
+--R                      20D  + 640B D  + (- 328C  + 2272A C - 568B  + 464A )D
+--R                    + 
+--R                               2                  3        2   2
+--R                      (- 240B C  - 1392A B C - 16B  + 2040A B)D
+--R                    + 
+--R                            4         3        2      2  2
+--R                          4C  - 224A C  + (600B  + 96A )C
+--R                        + 
+--R                                   2        3         4        2 2       4
+--R                          (- 384A B  + 1264A )C - 188B  - 1056A B  + 172A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3         3       2   2
+--R                      - 32B C  + 304A B C  + (- 16B  - 408A B)C
+--R                    + 
+--R                              3      3         5      2 3      4
+--R                      (- 80A B  + 64A B)C - 16B  - 88A B  + 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      4                         3
+--R                      (- 364C + 980A)D  + (- 1648B C - 1600A B)D
+--R                    + 
+--R                           3          2         2       2           2      3  2
+--R                      (544C  - 2112A C  + (1776B  - 696A )C - 480A B  + 40A )D
+--R                    + 
+--R                                  3            2          3        2
+--R                          - 352B C  + 2256A B C  + (- 448B  - 3504A B)C
+--R                        + 
+--R                                 3       3
+--R                          1232A B  - 736A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4          2       2  3
+--R                      28C  - 52A C  + (- 200B  + 112A )C
+--R                    + 
+--R                               2       3  2        4       2 2       4
+--R                      (- 168A B  - 224A )C  + (140B  + 912A B  - 364A )C
+--R                    + 
+--R                           4       3 2      5
+--R                      92A B  + 112A B  + 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                           5         4        2                 2        2  3
+--R                      - 96D  - 512B D  + (888C  - 2288A C + 560B  - 1384A )D
+--R                    + 
+--R                              2                   3       2   2
+--R                      (1064B C  + 3888A B C - 560B  - 696A B)D
+--R                    + 
+--R                                4         3           2       2  2
+--R                          - 200C  + 256A C  + (- 1272B  + 672A )C
+--R                        + 
+--R                                2        3         4        2 2       4
+--R                          (48A B  - 1184A )C - 176B  + 2184A B  + 520A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3        2   2
+--R                      232B C  - 608A B C  + (344B  + 1248A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 560A B  + 448A B)C - 112B  - 616A B  + 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                   4                       3
+--R                      (416C - 96A)D  + (1152B C + 1536A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 736C  + 1536A C  + (- 1152B  + 2080A )C - 704A B
+--R                        + 
+--R                              3
+--R                          832A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2         3        2             3
+--R                          256B C  - 3264A B C  + (1408B  + 2688A B)C - 1408A B
+--R                        + 
+--R                              3
+--R                          320A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4         2       2  3
+--R                      - 32C  + 320A C  + (- 32B  - 128A )C
+--R                    + 
+--R                             2       3  2          4        2 2       4
+--R                      (192A B  + 256A )C  + (- 160B  - 1824A B  + 416A )C
+--R                    + 
+--R                            4       3 2       5
+--R                      416A B  - 128A B  - 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                             2                2       2  3
+--R                      (- 576C  + 128A C - 128B  + 192A )D
+--R                    + 
+--R                               2                   3       2   2
+--R                      (- 704B C  - 2688A B C + 640B  - 960A B)D
+--R                    + 
+--R                              4        2       2  2          2       3         4
+--R                          192C  + (576B  - 768A )C  + (384A B  - 256A )C + 384B
+--R                        + 
+--R                                2 2       4
+--R                          - 960A B  - 704A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3       2   2
+--R                      - 192B C  + 256A B C  + (- 320B  - 768A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (640A B  - 512A B)C + 128B  + 704A B  - 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                           3       2          2  2
+--R                      (256C  - 256A C + 512A B )D
+--R                    + 
+--R                                2        3        3            4       2 3
+--R                      (1536A B C  - 1024B C + 512A B)D - 256A C  + 256B C
+--R                    + 
+--R                          2 2          4       5
+--R                      768A B C - 512A B  + 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                ROOT
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN1
+--R                     + 
+--R                                   3 3      2 2      4  2       3 2      5
+--R                               - 8a c  + (2a b  - 16a )c  + (40a b  + 32a )c
+--R                             + 
+--R                                   2 4      4 2      6
+--R                               - 8a b  - 56a b  + 64a
+--R                          *
+--R                             %%BN0
+--R                         + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN1
+--R                     + 
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN0
+--R                     + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN0
+--R                     + 
+--R                           2 2                          2     2  2  2
+--R                       (- D b  + 4C D a b + (- 8B D - 4C  - 4A )a )c
+--R                     + 
+--R                               2   2                               2
+--R                           - 4D a b  + ((20C + 4A)D + 4B C + 4A B)a b
+--R                         + 
+--R                              2             2             2     2  3
+--R                           (8D  - 16B D - 8C  + 16A C + 8B  - 8A )a
+--R                      *
+--R                         c
+--R                     + 
+--R                         2 4            3
+--R                       4D b  - 16C D a b
+--R                     + 
+--R                            2              2            2      2  2 2
+--R                       (- 8D  + 24B D + 12C  - 8A C - 4B  + 12A )a b
+--R                     + 
+--R                                                       3
+--R                       ((- 8C - 24A)D - 24B C - 24A B)a b
+--R                     + 
+--R                           2              2  4
+--R                       (16D  + 32A C + 16B )a
+--R                  /
+--R                         3 3       2 2     4  2         3 2      5       2 4
+--R                       4a c  + (- a b  + 8a )c  + (- 20a b  - 16a )c + 4a b
+--R                     + 
+--R                          4 2      6
+--R                       28a b  - 32a
+--R            + 
+--R                             2 4 8
+--R                      - 32A D a c
+--R                    + 
+--R                               2 3 2       3        2  4
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   2                   2      3  5
+--R                          (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                2 2 4        3       2  3 3
+--R                          - 2A D a b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          2                  2      3  4 2
+--R                          ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                        + 
+--R                                 3        2       2               2       2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                     2                2
+--R                              - 16B C  - 96A B C + 48A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    2                 3         2      2
+--R                              128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                            + 
+--R                                      2       3
+--R                              - 128A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3      2  2 5
+--R                          (D  + B D )a b
+--R                        + 
+--R                                        2                2     3  3 4
+--R                          ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                        + 
+--R                                    3         2
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 24C  + 112A C + 32B  + 72A )D + 8B C  + 48A B C
+--R                            + 
+--R                                   2
+--R                              - 24A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                           3
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2           2      3
+--R                              (384C  - 512A C - 64B  - 384A )D + 128B C  + 64B
+--R                            + 
+--R                                  2
+--R                              384A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                     2                  3         2       2
+--R                              1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                            + 
+--R                                      2       3
+--R                              - 512A B  + 128A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       2 2 6
+--R                          (- 2C + 22A)D a b
+--R                        + 
+--R                                 3        2      2             2     2        2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D - B C
+--R                            + 
+--R                                           2
+--R                              - 6A B C + 3A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                             2                            3
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                            + 
+--R                                    2         2      2          2       3
+--R                              120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                            + 
+--R                                            3       2
+--R                              672A B C - 64B  - 720A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                               3
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D + 608C
+--R                            + 
+--R                                      2          2       2            2      3
+--R                              - 416A C  + (- 288B  - 992A )C + 1120A B  + 32A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2           2
+--R                              (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                            + 
+--R                                              3       2
+--R                              1152A B C + 128B  + 192A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                    2                   3          2       2
+--R                              512A D  - 4096A B D + 256C  - 1024A C  - 256A C
+--R                            + 
+--R                                    2        3
+--R                              512A B  + 1024A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               3       2  2 7
+--R                          (- 8D  - 8B D )a b
+--R                        + 
+--R                                              2                      3        2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D + C  - 13A C
+--R                            + 
+--R                                 2     2         2      3
+--R                              (3B  + 3A )C + 3A B  + 17A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  3        2        2                2       2
+--R                              284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              - 12B C  - 312A B C + 20B  + 276A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                            2                               3
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D - 320C
+--R                            + 
+--R                                    2         2       2           2       3
+--R                              720A C  + (- 96B  + 192A )C - 672A B  - 848A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2            2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D - 1088B C
+--R                            + 
+--R                                                3        2
+--R                              - 1920A B C - 384B  - 1344A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                             2                               3
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D + 128C
+--R                            + 
+--R                                     2          2       2           2        3
+--R                              1920A C  + (- 384B  - 640A )C + 128A B  - 2432A
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2            2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D - 1024B C
+--R                            + 
+--R                                    3        2
+--R                              - 512B  - 3072A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2                    3         2
+--R                              - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                            + 
+--R                                     2           2       3
+--R                              - 2048A C + 4096A B  + 512A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      2 2 8
+--R                          (16C - 80A)D a b
+--R                        + 
+--R                                    3         2
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 30C  + 100A C + 26B  + 66A )D + 2B C  + 36A B C
+--R                            + 
+--R                                  3      2
+--R                              - 2B  - 30A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                               2                            3
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D + 62C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 230A C  + (90B  + 58A )C + 154A B  + 350A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2           2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                            + 
+--R                                               3        2
+--R                              - 576A B C + 312B  + 2160A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                     2                              3         2
+--R                              8160A D  + (4608B C - 5376A B)D - 864C  - 192A C
+--R                            + 
+--R                                    2        2           2        3
+--R                              (2304B  + 3936A )C - 960A B  + 3264A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2            2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D + 1152B C
+--R                            + 
+--R                                                3        2
+--R                              - 2304A B C + 768B  + 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D - 3840C
+--R                            + 
+--R                                     2         2        2            2
+--R                              3072A C  + (2304B  + 6912A )C - 6912A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2            2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D - 2816B C
+--R                            + 
+--R                                                 3        2
+--R                              - 4608A B C - 1024B  - 3840A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2                    3          2
+--R                              - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                            + 
+--R                                     2           2        3
+--R                              - 1024A C + 2048A B  - 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3        2  2 9
+--R                          (16D  + 16B D )a b
+--R                        + 
+--R                                            2                           3
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                            + 
+--R                                   2         2      2          2      3
+--R                              20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                         *
+--R                             3 8
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2           2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D - 104B C
+--R                            + 
+--R                                            3       2
+--R                              432A B C - 88B  - 744A B
+--R                         *
+--R                             4 7
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D + 364C
+--R                            + 
+--R                                      2          2        2           2       3
+--R                              - 380A C  + (- 828B  - 1468A )C + 452A B  - 724A
+--R                         *
+--R                             5 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2           2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D - 336B C
+--R                            + 
+--R                                              3        2
+--R                              4320A B C - 528B  - 5328A B
+--R                         *
+--R                             6 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                             7 4
+--R                            a b
+--R                        + 
+--R                                     3         2
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2            2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D + 4224B C
+--R                            + 
+--R                                               3        2
+--R                              6912A B C + 1536B  + 5760A B
+--R                         *
+--R                             8 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                             9 2
+--R                            a b
+--R                        + 
+--R                                       2         2                  2        2
+--R                              - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                     2        3        2
+--R                              2048B C  + 1024B  + 6144A B
+--R                         *
+--R                             10
+--R                            a  b
+--R                        + 
+--R                                               3          2        2           2
+--R                              8192A B D - 4096C  + 2048A C  + 4096A C - 8192A B
+--R                            + 
+--R                                     3
+--R                              - 2048A
+--R                         *
+--R                             11
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    2 2 10
+--R                      (- 32C + 96A)D a b
+--R                    + 
+--R                               3        2       2               2       2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                              2               3      2
+--R                          8B C  - 48A B C + 8B  + 72A B
+--R                     *
+--R                         3 9
+--R                        a b
+--R                    + 
+--R                                           2                           3
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                        + 
+--R                               2       2       2          2      3
+--R                          72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                     *
+--R                         4 8
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                        + 
+--R                                          3       2
+--R                          - 816A B C + 88B  + 936A B
+--R                     *
+--R                         5 7
+--R                        a b
+--R                    + 
+--R                                        2                              3
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                        + 
+--R                                 2         2        2           2       3
+--R                          1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                     *
+--R                         6 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2           2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                        + 
+--R                                           3        2
+--R                          - 3744A B C - 96B  + 1296A B
+--R                     *
+--R                         7 5
+--R                        a b
+--R                    + 
+--R                                          2                              3
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                        + 
+--R                                 2         2        2           2        3
+--R                          3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                     *
+--R                         8 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2            2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D - 4352B C
+--R                        + 
+--R                                             3         2
+--R                          - 1536A B C - 2048B  - 11520A B
+--R                     *
+--R                         9 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D + 5632C
+--R                        + 
+--R                                 2           2         2            2        3
+--R                        - 4608A C  + (- 4608B  - 11776A )C + 9728A B  - 1536A
+--R                     *
+--R                         10 2
+--R                        a  b
+--R                    + 
+--R                                2                  2        2            2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                        + 
+--R                                           3        2
+--R                          6144A B C + 2048B  + 9216A B
+--R                     *
+--R                         11
+--R                        a  b
+--R                    + 
+--R                              3        2           2  12
+--R                      (- 4096C  + 4096A C - 8192A B )a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                       3 3 8
+--R                  16A D a c
+--R                + 
+--R                            3 2 2          3          2  3
+--R                      - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                    + 
+--R                                     3          2         2      3    4
+--R                      ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           3         2  2 3
+--R                      (2B D  + 6A C D )a b
+--R                    + 
+--R                                    3                   2        2      3    3 2
+--R                      ((12C - 188A)D  + (12B C + 52A B)D  + (4A C  - 12A )D)a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 64C - 32A)D  + (96B C - 320A B)D
+--R                        + 
+--R                                3        2       2          2      3
+--R                          (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                        + 
+--R                                   2      3
+--R                          - 48A B C  - 16A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                      3                   2          2     3
+--R                        ((- 2C + 41A)D  + (- 3B C - 8A B)D  + (- 2A C  + 2A )D)
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 80B D  + (- 18C  + 224A C - 26B  - 66A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                        3                       2
+--R                          (144C - 232A)D  + (- 120B C + 808A B)D
+--R                        + 
+--R                             3         2         2      2           2       3
+--R                          (4C  - 212A C  + (- 24B  + 20A )C - 112A B  - 196A )D
+--R                        + 
+--R                              3          2      2        3
+--R                          4B C  + 36A B C  - 12A B C + 4A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                        + 
+--R                                  2                3       2        4        3
+--R                          (- 80B C  + 96A B C - 64B  - 336A B)D + 8C  + 32A C
+--R                        + 
+--R                              2      2  2         2      3        2 2     4
+--R                          (24B  + 48A )C  + (48A B  + 32A )C + 24A B  + 8A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                  3                     2
+--R                          - 384A D  + (384B C + 128A B)D
+--R                        + 
+--R                                3         2          2       2           2
+--R                          (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                        + 
+--R                               3           2       2           3      3
+--R                          64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4        3      2             2     2  2
+--R                          2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                        + 
+--R                              2              2
+--R                          (B C  + 6A B C - 3A B)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                        + 
+--R                             3       2       2      2          2       3
+--R                          (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                        + 
+--R                               3         2     2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                4        3
+--R                          - 224D  + 92B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 162C  - 280A C - 320B  - 1206A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (172B C  - 336A B C + 60B  + 492A B)D - 6C  + 48A C
+--R                        + 
+--R                                2      2  2           2      3       2 2     4
+--R                          (- 18B  - 24A )C  + (- 24A B  - 80A )C - 6A B  - 2A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                            + 
+--R                                 3
+--R                              64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2         3       2           3
+--R                          - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                        + 
+--R                              3
+--R                          144A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               4         3          2               2       2  2
+--R                          - 64D  - 256B D  + (- 144C  - 608A C + 32B  - 336A )D
+--R                        + 
+--R                                  2      3       2         4        3
+--R                          (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                        + 
+--R                                2      2  2         2       3        4       2 2
+--R                          (- 48B  - 96A )C  + (96A B  - 224A )C + 32B  + 144A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                        3            2
+--R                          (256C - 256A)D  + 1792A B D
+--R                        + 
+--R                                   3         2          2      2           2
+--R                              - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                            + 
+--R                                    3
+--R                              - 256A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3       2            3
+--R                          256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       3                   2
+--R                          (13C - 139A)D  + (18B C + 58A B)D
+--R                        + 
+--R                              3        2        2     2         2      3
+--R                          (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              4         3        2                2       2  2
+--R                          109D  - 265B D  + (114C  - 591A C + 183B  + 543A )D
+--R                        + 
+--R                                  2                 3       2       4        3
+--R                          (- 27B C  + 228A B C - 19B  - 225A B)D + C  - 13A C
+--R                        + 
+--R                             2     2  2        2      3
+--R                          (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                            + 
+--R                                  3
+--R                              346A
+--R                         *
+--R                            D
+--R                        + 
+--R                               3           2       3       2          3      3
+--R                          10B C  - 234A B C  + (14B  + 174A B)C - 2A B  - 30A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                3        2               2       2  2
+--R                          768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                        + 
+--R                                 2                 3        2            3
+--R                          (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                        + 
+--R                                2       2  2            2       3        4
+--R                          (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                        + 
+--R                                2 2      4
+--R                          - 240A B  - 64A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                           3                        2
+--R                          (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                        + 
+--R                                  3         2         2        2           2
+--R                              416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                            + 
+--R                                  3
+--R                              992A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 480B C  + 672A B C  + (- 128B  - 1632A B)C + 512A B
+--R                        + 
+--R                              3
+--R                          160A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 256D  + 384B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (192C  - 1024A C + 256B  - 2112A )D
+--R                        + 
+--R                                 2                  3        2          4
+--R                          (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                        + 
+--R                                 2       2  2            2       3         2 2
+--R                          (- 576B  - 384A )C  + (- 384A B  - 512A )C + 192A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                        + 
+--R                                   2        2           2       3         3
+--R                          (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 54B D  + (- 18C  + 140A C - 26B  - 66A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                        3                      2
+--R                          (142C - 688A)D  + (- 54B C + 800A B)D
+--R                        + 
+--R                                    3         2         2      2           2
+--R                                - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                              + 
+--R                                      3
+--R                                - 248A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2        3      2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              4         3       2                 2        2  2
+--R                          416D  - 190B D  + (84C  + 1254A C + 438B  + 2514A )D
+--R                        + 
+--R                                   2                  3        2         4
+--R                          (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                        + 
+--R                                 3       2       2  2          2       3       4
+--R                          - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C + 2B
+--R                        + 
+--R                             2 2      4
+--R                          48A B  + 14A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                        + 
+--R                                    3        2           2        2            2
+--R                              - 788C  - 84A C  + (- 2292B  - 4428A )C + 1404A B
+--R                            + 
+--R                                     3
+--R                              - 2252A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                        + 
+--R                                3
+--R                          - 308A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          608D  - 640B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 240C  + 3552A C - 960B  + 5232A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1632B C  - 1536A B C - 928B  - 1632A B)D + 464C
+--R                        + 
+--R                                3        2        2  2          2        3
+--R                          128A C  + (912B  + 1344A )C  + (384A B  + 1664A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 160B  - 528A B  - 16A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            3                       2
+--R                          (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 128C  - 576A C  + (192B  - 6144A )C + 4800A B
+--R                            + 
+--R                                    3
+--R                              - 704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2          3       2            3
+--R                          256B C  + 768A B C  + (- 704B  - 384A B)C + 448A B
+--R                        + 
+--R                                3
+--R                          - 128A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 128D  + 1280B D
+--R                        + 
+--R                               2                 2       2  2
+--R                          (768C  + 2560A C - 640B  - 768A )D
+--R                        + 
+--R                                 2                   2          4         3
+--R                          (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                        + 
+--R                                 2       2  2            2       3         4
+--R                          (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                        + 
+--R                                2 2       4
+--R                          - 384A B  + 128A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                3                         2
+--R                          512A D  + (- 1536B C - 2048A B)D
+--R                        + 
+--R                               3          2         2        2            2
+--R                          (256C  - 2048A C  + (3072B  + 1792A )C - 2048A B )D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                        - 1024B C  + 768A B C  - 3072A B C + 1024A B  + 256A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                         3                      2
+--R                          (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                        + 
+--R                             3        2       2      2          2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 204D  + 316B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 144C  + 364A C - 292B  - 1092A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (164B C  - 288A B C + 84B  + 636A B)D - 4C  + 20A C
+--R                        + 
+--R                                2      2  2           2      3
+--R                          (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                            + 
+--R                                  3
+--R                              996A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2         3       2          3
+--R                          - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                        + 
+--R                             3
+--R                          56A B
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 924D  - 588B D
+--R                        + 
+--R                               2                2        2  2
+--R                          (216C  - 5556A C - 60B  - 6156A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                        + 
+--R                                3          2       2  2         2        3
+--R                          708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                        + 
+--R                             4       2 2       4
+--R                          72B  + 576A B  + 120A
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                        + 
+--R                                  3          2        2        2            2
+--R                              408C  + 2760A C  + (504B  + 9096A )C - 3720A B
+--R                            + 
+--R                                   3
+--R                              2904A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3       2            3
+--R                          - 840B C  - 1656A B C  + (168B  + 360A B)C - 792A B
+--R                        + 
+--R                              3
+--R                          408A B
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          480D  - 1536B D
+--R                        + 
+--R                                 2                  2        2  2
+--R                          (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                        + 
+--R                                    2                  3        2          4
+--R                          (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                        + 
+--R                                  3        2        2  2           2        3
+--R                          - 864A C  + (576B  - 2304A )C  + (1152A B  - 2208A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          576B  + 576A B  - 384A
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                           3                       2
+--R                          (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                            + 
+--R                                     2        3
+--R                              2304A B  - 1344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                          1344B C  - 1728A B C  + 5184A B C - 1536A B  - 192A B
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                3           2                  2        2  2
+--R                          512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                        + 
+--R                                    2                   2          4         3
+--R                          (- 1280B C  - 4608A B C + 768A B)D + 640C  - 512A C
+--R                        + 
+--R                                2       2  2          2        3          2 2
+--R                          (1920B  + 768A )C  + (768A B  + 1536A )C - 1152A B
+--R                        + 
+--R                                4
+--R                          - 384A
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                     2
+--R                          - 2048A B D
+--R                        + 
+--R                                3          2         2        2            2
+--R                          (1024C  - 2048A C  + (3072B  - 1024A )C + 2048A B )D
+--R                        + 
+--R                                   3            2           3        2
+--R                          - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                        + 
+--R                                 3        3
+--R                          1024A B  + 1024A B
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                         4        3       2               2       2  2
+--R                      24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                    + 
+--R                             2               3      2
+--R                      (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                    3                    2
+--R                      (- 8C - 336A)D  + (216B C + 96A B)D
+--R                    + 
+--R                            3         2          2       2          2      3
+--R                      (- 56C  + 240A C  + (- 120B  - 184A )C + 80A B  - 96A )D
+--R                    + 
+--R                          3          2      3      2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                          4         3       2               2        2  2
+--R                      216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                    + 
+--R                               2                3       2         4         3
+--R                      (- 304B C  - 48A B C - 64B  - 384A B)D + 32C  - 120A C
+--R                    + 
+--R                        2      2  2           2       3       4      2 2      4
+--R                    (72B  + 24A )C  + (- 24A B  + 152A )C - 8B  - 96A B  - 24A
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                       3                      2
+--R                      (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                        + 
+--R                                3
+--R                          - 864A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3          2      3       2            3      3
+--R                      120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                          4          3          2                 2        2  2
+--R                      144D  + 1848B D  + (- 576C  + 6600A C - 984B  + 1800A )D
+--R                    + 
+--R                                2                   3        2          4
+--R                      (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                    + 
+--R                              3        2       2  2            2        3
+--R                      - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                    + 
+--R                            4       2 2      4
+--R                      - 120B  - 576A B  - 72A
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                    + 
+--R                                 3          2         2        2           2
+--R                            1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                          + 
+--R                                  3
+--R                            - 576A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3            2          3        2             3
+--R                      384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                    + 
+--R                            3
+--R                      - 240A B
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                            4          3
+--R                      - 384D  - 1600B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (2784C  - 7040A C + 1280B  - 3936A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                    + 
+--R                             3           2        2  2             2       3
+--R                      2304A C  + (- 2592B  + 1152A )C  + (- 1152A B  - 768A )C
+--R                    + 
+--R                            4        2 2       4
+--R                      - 384B  + 1440A B  + 864A
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                     3                       2
+--R                      (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                    + 
+--R                                 3          2           2        2            2
+--R                          - 1792C  + 5376A C  + (- 2688B  + 5632A )C - 3200A B
+--R                        + 
+--R                               3
+--R                          1536A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2         3        2             3
+--R                      - 512B C  - 6144A B C  + (2176B  + 2304A B)C - 1152A B
+--R                    + 
+--R                            3
+--R                      - 768A B
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                              2                2       2  2
+--R                      (- 2304C  + 512A C - 512B  + 768A )D
+--R                    + 
+--R                                2                    3        2          4
+--R                      (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                    + 
+--R                          4       2 2       4
+--R                      512B  - 768A B  - 768A
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                            3        2           2              2        3
+--R                      (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                    + 
+--R                           3
+--R                      1024A B
+--R                 *
+--R                     11
+--R                    a
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                             2 4 8
+--R                      - 32A D a c
+--R                    + 
+--R                               2 3 2       3        2  4
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   2                   2      3  5
+--R                          (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                2 2 4        3       2  3 3
+--R                          - 2A D a b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          2                  2      3  4 2
+--R                          ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                        + 
+--R                                 3        2       2               2       2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                     2                2
+--R                              - 16B C  - 96A B C + 48A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    2                 3         2      2
+--R                              128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                            + 
+--R                                      2       3
+--R                              - 128A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3      2  2 5
+--R                          (D  + B D )a b
+--R                        + 
+--R                                        2                2     3  3 4
+--R                          ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                        + 
+--R                                    3         2
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 24C  + 112A C + 32B  + 72A )D + 8B C  + 48A B C
+--R                            + 
+--R                                   2
+--R                              - 24A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                           3
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2           2      3
+--R                              (384C  - 512A C - 64B  - 384A )D + 128B C  + 64B
+--R                            + 
+--R                                  2
+--R                              384A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                     2                  3         2       2
+--R                              1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                            + 
+--R                                      2       3
+--R                              - 512A B  + 128A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       2 2 6
+--R                          (- 2C + 22A)D a b
+--R                        + 
+--R                                 3        2      2             2     2        2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D - B C
+--R                            + 
+--R                                           2
+--R                              - 6A B C + 3A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                             2                            3
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                            + 
+--R                                    2         2      2          2       3
+--R                              120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                            + 
+--R                                            3       2
+--R                              672A B C - 64B  - 720A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                               3
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D + 608C
+--R                            + 
+--R                                      2          2       2            2      3
+--R                              - 416A C  + (- 288B  - 992A )C + 1120A B  + 32A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2           2
+--R                              (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                            + 
+--R                                              3       2
+--R                              1152A B C + 128B  + 192A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                    2                   3          2       2
+--R                              512A D  - 4096A B D + 256C  - 1024A C  - 256A C
+--R                            + 
+--R                                    2        3
+--R                              512A B  + 1024A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               3       2  2 7
+--R                          (- 8D  - 8B D )a b
+--R                        + 
+--R                                              2                      3        2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D + C  - 13A C
+--R                            + 
+--R                                 2     2         2      3
+--R                              (3B  + 3A )C + 3A B  + 17A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  3        2        2                2       2
+--R                              284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              - 12B C  - 312A B C + 20B  + 276A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                            2                               3
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D - 320C
+--R                            + 
+--R                                    2         2       2           2       3
+--R                              720A C  + (- 96B  + 192A )C - 672A B  - 848A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2            2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D - 1088B C
+--R                            + 
+--R                                                3        2
+--R                              - 1920A B C - 384B  - 1344A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                             2                               3
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D + 128C
+--R                            + 
+--R                                     2          2       2           2        3
+--R                              1920A C  + (- 384B  - 640A )C + 128A B  - 2432A
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2            2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D - 1024B C
+--R                            + 
+--R                                    3        2
+--R                              - 512B  - 3072A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2                    3         2
+--R                              - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                            + 
+--R                                     2           2       3
+--R                              - 2048A C + 4096A B  + 512A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      2 2 8
+--R                          (16C - 80A)D a b
+--R                        + 
+--R                                    3         2
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 30C  + 100A C + 26B  + 66A )D + 2B C  + 36A B C
+--R                            + 
+--R                                  3      2
+--R                              - 2B  - 30A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                               2                            3
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D + 62C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 230A C  + (90B  + 58A )C + 154A B  + 350A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2           2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                            + 
+--R                                               3        2
+--R                              - 576A B C + 312B  + 2160A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                     2                              3         2
+--R                              8160A D  + (4608B C - 5376A B)D - 864C  - 192A C
+--R                            + 
+--R                                    2        2           2        3
+--R                              (2304B  + 3936A )C - 960A B  + 3264A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2            2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D + 1152B C
+--R                            + 
+--R                                                3        2
+--R                              - 2304A B C + 768B  + 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D - 3840C
+--R                            + 
+--R                                     2         2        2            2
+--R                              3072A C  + (2304B  + 6912A )C - 6912A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2            2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D - 2816B C
+--R                            + 
+--R                                                 3        2
+--R                              - 4608A B C - 1024B  - 3840A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2                    3          2
+--R                              - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                            + 
+--R                                     2           2        3
+--R                              - 1024A C + 2048A B  - 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3        2  2 9
+--R                          (16D  + 16B D )a b
+--R                        + 
+--R                                            2                           3
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                            + 
+--R                                   2         2      2          2      3
+--R                              20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                         *
+--R                             3 8
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2           2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D - 104B C
+--R                            + 
+--R                                            3       2
+--R                              432A B C - 88B  - 744A B
+--R                         *
+--R                             4 7
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D + 364C
+--R                            + 
+--R                                      2          2        2           2       3
+--R                              - 380A C  + (- 828B  - 1468A )C + 452A B  - 724A
+--R                         *
+--R                             5 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2           2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D - 336B C
+--R                            + 
+--R                                              3        2
+--R                              4320A B C - 528B  - 5328A B
+--R                         *
+--R                             6 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                             7 4
+--R                            a b
+--R                        + 
+--R                                     3         2
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2            2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D + 4224B C
+--R                            + 
+--R                                               3        2
+--R                              6912A B C + 1536B  + 5760A B
+--R                         *
+--R                             8 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                             9 2
+--R                            a b
+--R                        + 
+--R                                       2         2                  2        2
+--R                              - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                     2        3        2
+--R                              2048B C  + 1024B  + 6144A B
+--R                         *
+--R                             10
+--R                            a  b
+--R                        + 
+--R                                               3          2        2           2
+--R                              8192A B D - 4096C  + 2048A C  + 4096A C - 8192A B
+--R                            + 
+--R                                     3
+--R                              - 2048A
+--R                         *
+--R                             11
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    2 2 10
+--R                      (- 32C + 96A)D a b
+--R                    + 
+--R                               3        2       2               2       2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                              2               3      2
+--R                          8B C  - 48A B C + 8B  + 72A B
+--R                     *
+--R                         3 9
+--R                        a b
+--R                    + 
+--R                                           2                           3
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                        + 
+--R                               2       2       2          2      3
+--R                          72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                     *
+--R                         4 8
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                        + 
+--R                                          3       2
+--R                          - 816A B C + 88B  + 936A B
+--R                     *
+--R                         5 7
+--R                        a b
+--R                    + 
+--R                                        2                              3
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                        + 
+--R                                 2         2        2           2       3
+--R                          1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                     *
+--R                         6 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2           2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                        + 
+--R                                           3        2
+--R                          - 3744A B C - 96B  + 1296A B
+--R                     *
+--R                         7 5
+--R                        a b
+--R                    + 
+--R                                          2                              3
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                        + 
+--R                                 2         2        2           2        3
+--R                          3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                     *
+--R                         8 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2            2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D - 4352B C
+--R                        + 
+--R                                             3         2
+--R                          - 1536A B C - 2048B  - 11520A B
+--R                     *
+--R                         9 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D + 5632C
+--R                        + 
+--R                                 2           2         2            2        3
+--R                        - 4608A C  + (- 4608B  - 11776A )C + 9728A B  - 1536A
+--R                     *
+--R                         10 2
+--R                        a  b
+--R                    + 
+--R                                2                  2        2            2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                        + 
+--R                                           3        2
+--R                          6144A B C + 2048B  + 9216A B
+--R                     *
+--R                         11
+--R                        a  b
+--R                    + 
+--R                              3        2           2  12
+--R                      (- 4096C  + 4096A C - 8192A B )a
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                           3 3 8
+--R                      32A D a c
+--R                    + 
+--R                                 3 2 2         4        3  3
+--R                          - 16A D a b  + (- 16D  - 16B D )a b
+--R                        + 
+--R                                 3           2           2      3    4
+--R                          (128A D  - 128A B D  + (- 32A C  + 32A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              3   4      4       3  2 3
+--R                          2A D a b  + (8D  + 8B D )a b
+--R                        + 
+--R                                        3          2         2      3    3 2
+--R                          ((32C - 448A)D  + 64A B D  + (16A C  - 16A )D)a b
+--R                        + 
+--R                                   4        3
+--R                              - 32D  + 32B D
+--R                            + 
+--R                                    2               2       2  2
+--R                              (- 48C  + 224A C + 64B  + 144A )D
+--R                            + 
+--R                                    2                2
+--R                              (16B C  + 96A B C - 48A B)D
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                      3           2
+--R                              - 128A D  - 512A B D
+--R                            + 
+--R                                  3         2      2          2       3
+--R                              (64C  - 128A C  - 64A C + 128A B  + 128A )D
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              4      3    5
+--R                          (- D  - B D )a b
+--R                        + 
+--R                                          3         2          2     3    2 4
+--R                          ((- 16C + 192A)D  - 8A B D  + (- 2A C  + 2A )D)a b
+--R                        + 
+--R                                  4         3       2               2      2  2
+--R                              160D  + 128B D  + (24C  - 112A C - 32B  - 72A )D
+--R                            + 
+--R                                     2                2
+--R                              (- 8B C  - 48A B C + 24A B)D
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                           3                       2
+--R                              (80C - 560A)D  + (- 96B C + 1312A B)D
+--R                            + 
+--R                                       3         2         2      2           2
+--R                                  - 48C  + 304A C  + (- 48B  - 16A )C - 112A B
+--R                                + 
+--R                                        3
+--R                                  - 368A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              128D  + 256B D
+--R                            + 
+--R                                     2               2       2  2
+--R                              (- 384C  + 512A C + 64B  + 384A )D
+--R                            + 
+--R                                       2      3       2
+--R                              (- 128B C  - 64B  - 384A B)D
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                       3           2
+--R                              - 1024A D  + 512A B D
+--R                            + 
+--R                                   3         2       2          2       3
+--R                              (256C  + 128A C  - 256A C + 512A B  - 128A )D
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                     3   6
+--R                          (2C - 22A)D a b
+--R                        + 
+--R                                   4        3        2             2     2  2
+--R                              - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D
+--R                            + 
+--R                                  2              2
+--R                              (B C  + 6A B C - 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                               3                    2
+--R                              (- 328C + 1896A)D  + (48B C - 528A B)D
+--R                            + 
+--R                                3         2       2      2          2       3
+--R                            (12C  - 120A C  + (24B  + 20A )C + 32A B  + 152A )D
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 224D  - 800B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (720C  - 2080A C - 512B  - 1392A )D
+--R                            + 
+--R                                    2                 3       2
+--R                              (16B C  - 672A B C + 64B  + 720A B)D
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (160C + 2976A)D  + (576B C + 1088A B)D
+--R                            + 
+--R                                        3         2        2       2
+--R                                  - 608C  + 416A C  + (288B  + 992A )C
+--R                                + 
+--R                                           2      3
+--R                                  - 1120A B  - 32A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              256D  - 256B D
+--R                            + 
+--R                                     2                 2       2  2
+--R                              (- 192C  - 1664A C - 640B  - 960A )D
+--R                            + 
+--R                                       2                   3       2
+--R                              (- 448B C  - 1152A B C - 128B  - 192A B)D
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                      3            2
+--R                              - 512A D  + 4096A B D
+--R                            + 
+--R                                     3          2       2          2        3
+--R                              (- 256C  + 1024A C  + 256A C - 512A B  - 1024A )D
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             4       3    7
+--R                          (8D  + 8B D )a b
+--R                        + 
+--R                                            3                    2
+--R                              (141C - 755A)D  + (- 6B C + 58A B)D
+--R                            + 
+--R                                  3        2        2     2         2      3
+--R                              (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    4        3
+--R                              - 284D  - 36B D
+--R                            + 
+--R                                     2                2       2  2
+--R                              (- 276C  + 888A C + 228B  + 588A )D
+--R                            + 
+--R                                    2                 3       2
+--R                              (12B C  + 312A B C - 20B  - 276A B)D
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (- 32C - 2016A)D  + (192B C - 3072A B)D
+--R                            + 
+--R                                      3         2       2       2           2
+--R                                  320C  - 720A C  + (96B  - 192A )C + 672A B
+--R                                + 
+--R                                      3
+--R                                  848A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 896D  - 384B D
+--R                            + 
+--R                                    2                 2       2  2
+--R                              (1344C  + 1408A C + 896B  + 576A )D
+--R                            + 
+--R                                      2                   3        2
+--R                              (1088B C  + 1920A B C + 384B  + 1344A B)D
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 640C + 4224A)D  + (768B C - 8448A B)D
+--R                            + 
+--R                                        3          2        2       2
+--R                                  - 128C  - 1920A C  + (384B  + 640A )C
+--R                                + 
+--R                                          2        3
+--R                                  - 128A B  + 2432A
+--R                             *
+--R                                D
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 256D  - 1280B D
+--R                            + 
+--R                                    2                 2        2  2
+--R                              (3072C  - 4096A C - 512B  - 3072A )D
+--R                            + 
+--R                                      2       3        2
+--R                              (1024B C  + 512B  + 3072A B)D
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                     3            2
+--R                              2048A D  + 2048A B D
+--R                            + 
+--R                                    3         2        2           2       3
+--R                            (- 2048C  + 512A C  + 2048A C - 4096A B  - 512A )D
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                        3   8
+--R                          (- 16C + 80A)D a b
+--R                        + 
+--R                                  4         3       2               2      2  2
+--R                              146D  + 118B D  + (30C  - 100A C - 26B  - 66A )D
+--R                            + 
+--R                                     2               3      2
+--R                              (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (726C - 2090A)D  + (- 180B C + 1100A B)D
+--R                            + 
+--R                                       3         2         2      2           2
+--R                                  - 62C  + 230A C  + (- 90B  - 58A )C - 154A B
+--R                                + 
+--R                                        3
+--R                                  - 350A
+--R                             *
+--R                                D
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              1752D  + 2760B D
+--R                            + 
+--R                                      2                 2        2  2
+--R                              (- 2160C  + 3840A C + 696B  + 2736A )D
+--R                            + 
+--R                                       2                  3        2
+--R                              (- 528B C  + 576A B C - 312B  - 2160A B)D
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                       3                         2
+--R                              - 8160A D  + (- 4608B C + 5376A B)D
+--R                            + 
+--R                                      3         2           2        2
+--R                                  864C  + 192A C  + (- 2304B  - 3936A )C
+--R                                + 
+--R                                        2        3
+--R                                  960A B  - 3264A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              1152D  + 4224B D
+--R                            + 
+--R                                      2                   2        2  2
+--R                              (- 5760C  + 11520A C + 2304B  + 8064A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 1152B C  + 2304A B C - 768B  - 5760A B)D
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                3                         2
+--R                              (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D
+--R                            + 
+--R                                       3          2           2        2
+--R                                  3840C  - 3072A C  + (- 2304B  - 6912A )C
+--R                                + 
+--R                                         2
+--R                                  6912A B
+--R                             *
+--R                                D
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 512D  + 512B D
+--R                            + 
+--R                                    2                  2       2  2
+--R                              (3840C  + 2560A C + 2048B  + 768A )D
+--R                            + 
+--R                                      2                    3        2
+--R                              (2816B C  + 4608A B C + 1024B  + 3840A B)D
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                     3            2
+--R                              2048A D  - 8192A B D
+--R                            + 
+--R                                    3          2        2           2        3
+--R                            (- 1024C  - 2048A C  + 1024A C - 2048A B  + 2048A )D
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                4        3    9
+--R                          (- 16D  - 16B D )a b
+--R                        + 
+--R                                              3                    2
+--R                              (- 308C + 972A)D  + (24B C - 104A B)D
+--R                            + 
+--R                                 3        2       2      2          2      3
+--R                              (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 456D  - 920B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (744C  - 1712A C - 376B  - 1176A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              (104B C  - 432A B C + 88B  + 744A B)D
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                                3                      2
+--R                              (- 1668C + 8316A)D  + (1656B C - 136A B)D
+--R                            + 
+--R                                        3         2        2        2
+--R                                  - 364C  + 380A C  + (828B  + 1468A )C
+--R                                + 
+--R                                          2       3
+--R                                  - 452A B  + 724A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     4          3
+--R                              - 2496D  - 6432B D
+--R                            + 
+--R                                    2                   2        2  2
+--R                              (5328C  - 14304A C - 3408B  - 9648A )D
+--R                            + 
+--R                                     2                   3        2
+--R                              (336B C  - 4320A B C + 528B  + 5328A B)D
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              3                        2
+--R                              (6528C + 3456A)D  + (11520B C + 7296A B)D
+--R                            + 
+--R                                         3          2         2         2
+--R                                  - 3072C  + 4704A C  + (5760B  + 10752A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 4224A B  + 2976A
+--R                             *
+--R                                D
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                   4         3
+--R                              1024D  - 512B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 5760C  - 3840A C - 3072B  - 1152A )D
+--R                            + 
+--R                                        2                    3        2
+--R                              (- 4224B C  - 6912A B C - 1536B  - 5760A B)D
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              3                          2
+--R                              (1280C - 6912A)D  + (- 1536B C + 12800A B)D
+--R                            + 
+--R                                       3          2          2        2
+--R                                  1280C  + 2816A C  + (- 768B  - 2304A )C
+--R                                + 
+--R                                         2        3
+--R                                  2304A B  - 3840A
+--R                             *
+--R                                D
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                     3
+--R                              2048B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                            + 
+--R                                        2        3        2
+--R                              (- 2048B C  - 1024B  - 6144A B)D
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                         2
+--R                              - 8192A B D
+--R                            + 
+--R                                  3          2        2           2        3
+--R                            (4096C  - 2048A C  - 4096A C + 8192A B  + 2048A )D
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                  3   10
+--R                      (32C - 96A)D a b
+--R                    + 
+--R                             4        3         2               2       2  2
+--R                          24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (376C - 1416A)D  + (- 144B C - 144A B)D
+--R                        + 
+--R                              3        2         2       2          2      3
+--R                          (40C  - 72A C  + (- 72B  - 136A )C + 56A B  - 24A )D
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          360D  + 1080B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 936C  + 2608A C + 632B  + 1752A )D
+--R                        + 
+--R                                  2                 3       2
+--R                          (- 40B C  + 816A B C - 88B  - 936A B)D
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                          3                         2
+--R                          (- 24C - 4248A)D  + (- 2160B C - 2160A B)D
+--R                        + 
+--R                                  3          2           2        2           2
+--R                              536C  - 1080A C  + (- 1080B  - 1976A )C + 712A B
+--R                            + 
+--R                                    3
+--R                              - 360A
+--R                         *
+--R                            D
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                               4          3
+--R                          1152D  + 3456B D
+--R                        + 
+--R                                  2                  2        2  2
+--R                          (- 1296C  + 7968A C + 2400B  + 5040A )D
+--R                        + 
+--R                                 2                  3        2
+--R                          (816B C  + 3744A B C + 96B  - 1296A B)D
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D
+--R                        + 
+--R                                  3          2           2        2           2
+--R                              960C  - 3456A C  + (- 3456B  - 5568A )C + 768A B
+--R                            + 
+--R                                     3
+--R                              - 1152A
+--R                         *
+--R                            D
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1536D  - 4608B D
+--R                        + 
+--R                                 2                   2        2  2
+--R                          (11520C  - 12800A C - 1024B  - 9984A )D
+--R                        + 
+--R                                  2                    3         2
+--R                          (4352B C  + 1536A B C + 2048B  + 11520A B)D
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (6656C - 1536A)D  + (9216B C + 9216A B)D
+--R                        + 
+--R                                     3          2         2         2
+--R                              - 5632C  + 4608A C  + (4608B  + 11776A )C
+--R                            + 
+--R                                       2        3
+--R                              - 9728A B  + 1536A
+--R                         *
+--R                            D
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                  2        2  2
+--R                          (- 9216C  + 2048A C - 2048B  + 3072A )D
+--R                        + 
+--R                                    2                    3        2
+--R                          (- 5120B C  - 6144A B C - 2048B  - 9216A B)D
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                            3        2           2    11
+--R                      (4096C  - 4096A C + 8192A B )D a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                        4 2 8
+--R                  - 8A D a c
+--R                + 
+--R                          4   2        4         3  2
+--R                      2A D a b  + (4B D  + 8A C D )a b
+--R                    + 
+--R                                  4          3     3 2  3
+--R                      ((8C - 32A)D  + 32A B D  - 8A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            4         3    3
+--R                      (- B D  - 2A C D )a b
+--R                    + 
+--R                                     4                    3     3 2  2 2
+--R                      ((- 6C + 100A)D  + (- 4B C - 16A B)D  + 2A D )a b
+--R                    + 
+--R                               5        4        2              2      2  3
+--R                          - 12D  + 12B D  + (- 8C  - 16A C - 16B  - 52A )D
+--R                        + 
+--R                                          2   2          3     3
+--R                          (- 24A B C + 12A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      4                      3
+--R                          (32C + 24A)D  + (- 48B C + 128A B)D
+--R                        + 
+--R                              2         2      3  2       4     3 2
+--R                          (48A C - 24A B  - 32A )D  + 8A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 4                3    4
+--R                      ((C - 22A)D  + (B C + 2A B)D )a b
+--R                    + 
+--R                            5        4      2             2      2  3
+--R                          7D  - 45B D  + (6C  - 80A C + 8B  + 25A )D
+--R                        + 
+--R                                      2   2        3     3
+--R                          (6A B C - 3A B)D  + (2A C  - 2A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 88C + 118A)D  + (52B C - 312A B)D
+--R                        + 
+--R                                2       2      2          2      3  2
+--R                          (60A C  + (12B  - 12A )C + 18A B  + 80A )D
+--R                        + 
+--R                               3          2      2            4     3 2
+--R                          (4B C  + 24A B C  - 12A B C)D - 2A C  + 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5        4       2              2       2  3
+--R                          - 36D  + 52B D  + (32C  - 48A C - 44B  - 176A )D
+--R                        + 
+--R                                2                3      2   2
+--R                          (48B C  - 48A B C + 12B  + 96A B)D
+--R                        + 
+--R                             4        3      2 2      3       4         4
+--R                          (8C  - 64A C  + 12A C  + 40A C - 12A )D - 4B C
+--R                        + 
+--R                                   3      2   2
+--R                          - 24A B C  + 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4                      3
+--R                          224A D  + (- 192B C - 96A B)D
+--R                        + 
+--R                                  2       2       2          2     3  2
+--R                          (- 72A C  + (96B  + 192A )C - 96A B  + 8A )D
+--R                        + 
+--R                                  3      2           3       5        4      2 3
+--R                          (- 16B C  - 48A B C - 32A B )D - 8C  + 32A C  - 16A C
+--R                        + 
+--R                                2      3  2      4      3 2
+--R                          (24A B  - 32A )C  + 24A C + 8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          5        4       2            2     2  3    5
+--R                      (- D  + 10B D  + (- C  + 20A C - B  - 3A )D )a b
+--R                    + 
+--R                                       4                    3
+--R                          (53C - 389A)D  + (24B C + 134A B)D
+--R                        + 
+--R                                  2     2        2      3  2
+--R                          (- 15A C  - 3B C - 3A B  - 17A )D
+--R                        + 
+--R                                3         2     2
+--R                          (- B C  - 6A B C  + 3A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              5        4       2                2       2  3
+--R                          127D  - 63B D  + (48C  + 240A C + 147B  + 534A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (- 60B C  + 144A B C - 11B  - 150A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 6C  + 72A C  + (- 12B  - 15A )C
+--R                            + 
+--R                                      2      3       4
+--R                              (- 12A B  - 82A )C + 3A
+--R                         *
+--R                            D
+--R                        + 
+--R                             4         3     2   2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 164C - 696A)D  + (448B C - 184A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 96C  + 138A C  + (- 132B  - 636A )C + 192A B
+--R                            + 
+--R                                 3
+--R                              10A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                               3          2      2           3      3        5
+--R                          (4B C  + 96A B C  - 60A B C + 32A B  + 24A B)D + 6C
+--R                        + 
+--R                                 4       2      2  3        2      3  2     4
+--R                          - 64A C  + (12B  + 16A )C  + (6A B  + 80A )C  - 6A C
+--R                        + 
+--R                              3 2
+--R                          - 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             5         4        2               2       2  3
+--R                          24D  + 120B D  + (116C  + 472A C - 56B  + 196A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (12B C  - 24A B C + 24B  + 156A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              92C  - 64A C  + (12B  + 144A )C
+--R                            + 
+--R                                    2      3        4       2 2      4
+--R                              (72A B  + 48A )C + 16B  + 108A B  - 60A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3         3      2   2
+--R                          20B C  - 80A B C  + (- 12B  + 48A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          4           3
+--R                          (- 128C + 128A)D  - 896A B D
+--R                        + 
+--R                              3         2        2      2          2       3  2
+--R                          (48C  - 288A C  + (384B  - 48A )C + 96A B  + 160A )D
+--R                        + 
+--R                                     3          2         3       2            3
+--R                              - 64B C  + 96A B C  + (- 64B  - 192A B)C - 128A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4         2      2  3        2 2
+--R                          - 32C  + 16A C  + (- 16B  - 64A )C  + 96A B C
+--R                        + 
+--R                                2 2      4          4      3 2      5
+--R                          (- 48A B  + 96A )C + 32A B  + 32A B  - 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                    4                    3    6
+--R                      ((- 8C + 80A)D  + (- 8B C - 16A B)D )a b
+--R                    + 
+--R                               5         4         2               2       2  3
+--R                          - 62D  + 158B D  + (- 47C  + 239A C - 66B  - 218A )D
+--R                        + 
+--R                                2               3      2   2
+--R                          (12B C  - 30A B C + 2B  + 30A B)D
+--R                        + 
+--R                            4        3      2     2  2        2      3
+--R                          (C  - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (229C + 559A)D  + (- 438B C + 584A B)D
+--R                        + 
+--R                              3         2        2       2          2       3  2
+--R                          (64C  - 444A C  + (- 3B  + 213A )C - 93A B  - 175A )D
+--R                        + 
+--R                                     3           2      3       2          3
+--R                              - 10B C  - 180A B C  + (8B  + 144A B)C - 6A B
+--R                            + 
+--R                                  3
+--R                              - 6A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2     2  3          2      3  2
+--R                          - C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5         4          2                2       2  3
+--R                          36D  - 340B D  + (- 237C  - 638A C + 116B  + 123A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 123B C  + 102A B C - 68B  - 363A B)D
+--R                        + 
+--R                                   4         3        2       2  2
+--R                              - 95C  + 312A C  + (- 3B  - 138A )C
+--R                            + 
+--R                                      2       3        4      2 2       4
+--R                              (- 66A B  - 120A )C - 16B  - 99A B  + 105A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4           3        3       2   2
+--R                          5B C  + 176A B C  + (- 5B  - 138A B)C
+--R                        + 
+--R                                3      3        2 3     4
+--R                          (10A B  + 16A B)C + 3A B  + 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (276C - 916A)D  + (416B C + 2048A B)D
+--R                        + 
+--R                                    3         2           2       2          2
+--R                              - 252C  + 636A C  + (- 1032B  - 516A )C - 72A B
+--R                            + 
+--R                                    3
+--R                              - 380A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3           2       2            3      3
+--R                          (- 40B C  - 216A B C  + 168A B C + 256A B  - 40A B)D
+--R                        + 
+--R                             5        4      2       2  3            2      3  2
+--R                          56C  - 80A C  + (4B  + 128A )C  + (- 132A B  + 64A )C
+--R                        + 
+--R                              4       2 2       4         4      3 2      5
+--R                          (20B  + 156A B  - 184A )C - 4A B  - 28A B  + 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              5         4          2               2        2  3
+--R                          144D  - 176B D  + (- 368C  + 736A C - 64B  + 1040A )D
+--R                        + 
+--R                                   2                  2   2
+--R                          (- 528B C  - 480A B C - 528A B)D
+--R                        + 
+--R                                  4        3        2      2  2
+--R                              128C  + 64A C  + (240B  + 96A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (288A B  - 128A )C + 48B  + 240A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4       3      2   2            3      3
+--R                          96B C  + (16B  + 96A B)C  + (- 160A B  - 64A B)C
+--R                        + 
+--R                               5       2 3
+--R                          - 16B  - 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 128C - 384A)D  + (768B C - 512A B)D
+--R                        + 
+--R                               3       2          2       3  2
+--R                          (192C  - 960A C + 768A B  + 128A )D
+--R                        + 
+--R                                   2       3        3           4      2 3
+--R                          (384A B C  - 256B C + 128A B)D - 64A C  - 64B C
+--R                        + 
+--R                              3 2       2 2          4      5
+--R                          128A C  - 192A B C + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         5        4      2             2      2  3    7
+--R                      (8D  - 32B D  + (8C  - 64A C + 8B  + 24A )D )a b
+--R                    + 
+--R                                          4                   3
+--R                          (- 118C + 412A)D  + (2B C - 264A B)D
+--R                        + 
+--R                                3        2      2      2          2      3  2
+--R                          (- 10C  + 96A C  + (6B  - 18A )C + 12A B  + 36A )D
+--R                        + 
+--R                               3          2        3      2
+--R                          (2B C  + 36A B C  + (- 2B  - 30A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5        4
+--R                          - 287D  + 30B D
+--R                        + 
+--R                                2                2        2  3
+--R                          (- 28C  - 682A C - 308B  - 1180A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (240B C  - 168A B C + 50B  + 414A B)D
+--R                        + 
+--R                                 4         3       2      2  2
+--R                              35C  - 170A C  + (54B  + 78A )C
+--R                            + 
+--R                                    2       3       4      2 2      4
+--R                              (66A B  + 198A )C + 3B  + 18A B  - 21A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      3      2   2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (81C + 1825A)D  + (- 528B C - 1756A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                572C  - 60A C  + (936B  + 2010A )C - 108A B
+--R                              + 
+--R                                    3
+--R                                658A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2            3
+--R                              92B C  - 120A B C  + (20B  + 264A B)C - 160A B
+--R                            + 
+--R                                    3
+--R                              - 100A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5         4         2      2  3
+--R                          - 29C  + 119A C  + (- 54B  - 80A )C
+--R                        + 
+--R                                  2       3  2        4      2 2      4        4
+--R                          (- 30A B  - 188A )C  + (- 5B  - 36A B  + 37A )C - A B
+--R                        + 
+--R                            3 2     5
+--R                          4A B  - 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 412D  + 132B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (466C  - 2484A C + 248B  - 2718A )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (1374B C  + 996A B C + 120B  + 702A B)D
+--R                        + 
+--R                                    4         3         2       2  2
+--R                              - 366C  - 192A C  + (- 18B  - 492A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 396A B  + 208A )C - 108B  - 690A B  + 170A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4          3       3       2   2
+--R                          - 190B C  + 96A B C  + (34B  - 204A B)C
+--R                        + 
+--R                                 3       3        5      2 3      4
+--R                          (220A B  + 304A B)C + 4B  + 82A B  + 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         4                        3
+--R                          (936C + 1176A)D  + (- 768B C + 1536A B)D
+--R                        + 
+--R                                 3         2          2        2            2
+--R                              24C  + 696A C  + (- 240B  + 3144A )C - 1392A B
+--R                            + 
+--R                                  3
+--R                              200A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2        3       2
+--R                              - 144B C  - 1296A B C  + (320B  + 336A B)C
+--R                            + 
+--R                                   3       3
+--R                              64A B  - 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2      2  3
+--R                          16C  + 80A C  + (- 8B  + 32A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 168A B  - 320A )C  + (40B  + 552A B  - 176A )C
+--R                        + 
+--R                                  4     3 2       5
+--R                          - 168A B  + 8A B  + 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                             5         4          2                 2       2  3
+--R                          96D  - 672B D  + (- 768C  - 1536A C + 384B  + 192A )D
+--R                        + 
+--R                                   2                   2   2
+--R                          (- 384B C  - 384A B C - 1344A B)D
+--R                        + 
+--R                                    4        2       2  2       3       4
+--R                              - 352C  + (384B  - 768A )C  - 384A C - 32B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 224A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3 2       3         5
+--R                          - 32B C  + 256A B C  + 128B C  + 384A B C - 32B
+--R                        + 
+--R                                2 3       4
+--R                          - 128A B  + 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  4                      3
+--R                          - 384A D  + (768B C + 1536A B)D
+--R                        + 
+--R                                  2           2       2           2       3  2
+--R                          (1152A C  + (- 1536B  - 768A )C + 384A B  - 128A )D
+--R                        + 
+--R                                 3       2            3         5         4
+--R                          (256B C  + 768A B C + 512A B )D + 128C  - 128A C
+--R                        + 
+--R                              2 3            2       3  2       4        3 2
+--R                          256A C  + (- 384A B  + 128A )C  - 384A C - 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                   4                   3    8
+--R                      ((16C - 96A)D  + (16B C + 32A B)D )a b
+--R                    + 
+--R                              5         4       2                2       2  3
+--R                          136D  - 168B D  + (92C  - 188A C + 136B  + 472A )D
+--R                        + 
+--R                                  2               3      2   2
+--R                          (- 48B C  + 24A B C - 8B  - 72A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 20A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 36A )C
+--R                         *
+--R                            D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 12C - 1996A)D  + (864B C + 640A B)D
+--R                        + 
+--R                                    3         2          2       2          2
+--R                              - 296C  + 720A C  + (- 252B  - 732A )C + 36A B
+--R                            + 
+--R                                   3
+--R                              - 84A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2           3
+--R                              - 48B C  + 288A B C  + (- 40B  - 408A B)C + 24A B
+--R                            + 
+--R                                 3
+--R                              24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3         2      3  2
+--R                          4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          636D  + 544B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 104C  + 3740A C + 120B  + 3228A )D
+--R                        + 
+--R                                    2                 3       2   2
+--R                          (- 1380B C  - 912A B C - 96B  - 804A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              188C  - 300A C  + (- 192B  + 156A )C
+--R                            + 
+--R                                     2       3        4       2 2       4
+--R                              (108A B  - 340A )C + 76B  + 468A B  - 216A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          68B C  - 272A B C  + (28B  + 384A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            4                        3
+--R                          (- 1528C - 1376A)D  + (- 520B C - 1200A B)D
+--R                        + 
+--R                                    3          2        2        2            2
+--R                              - 544C  - 1968A C  + (132B  - 4740A )C + 1068A B
+--R                            + 
+--R                                     3
+--R                              - 1012A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2           3
+--R                              360B C  + 1584A B C  + (- 16B  - 480A B)C - 56A B
+--R                            + 
+--R                                  3
+--R                              600A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3
+--R                          - 8C  - 64A C  + (188B  - 28A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (252A B  + 412A )C  + (- 100B  - 768A B  + 308A )C
+--R                        + 
+--R                               4      3 2      5
+--R                          12A B  - 64A B  - 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 304D  + 944B D
+--R                        + 
+--R                               2                  2       2  3
+--R                          (708C  + 3096A C - 1072B  - 268A )D
+--R                        + 
+--R                                   2                  3        2   2
+--R                          (- 132B C  + 360A B C - 208B  + 2028A B)D
+--R                        + 
+--R                                  4         3          2        2  2
+--R                              636C  + 448A C  + (- 996B  + 1512A )C
+--R                            + 
+--R                                      2       3        4       2 2       4
+--R                              (- 24A B  + 576A )C + 80B  + 924A B  - 356A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3      2   2
+--R                          108B C  - 256A B C  + (- 252B  - 24A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (120A B  - 768A B)C + 80B  + 356A B  - 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                        4                         3
+--R                          (48C + 1776A)D  + (- 1728B C - 3456A B)D
+--R                        + 
+--R                               3          2         2        2         3  2
+--R                          (816C  - 2928A C  + (3168B  + 1680A )C + 432A )D
+--R                        + 
+--R                                    3          2        3      2            3
+--R                              224B C  + 96A B C  + (256B  - 96A B)C - 768A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2       2  3
+--R                          - 160C  + 160A C  + (48B  - 384A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (336A B  - 160A )C  + (- 80B  - 432A B  + 544A )C
+--R                        + 
+--R                                  4      3 2
+--R                          - 112A B  + 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  4        2                 2        2  3
+--R                          - 384B D  + (960C  - 2688A C + 960B  - 1344A )D
+--R                        + 
+--R                                  2                   3       2   2
+--R                          (1344B C  + 2688A B C - 192B  + 576A B)D
+--R                        + 
+--R                                    4         3          2       2  2
+--R                              - 640C  + 768A C  + (- 960B  - 576A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1152A B  - 128A )C - 192B  - 960A B  + 320A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3         3       2   2
+--R                          - 320B C  + 384A B C  + (- 64B  - 576A B)C
+--R                        + 
+--R                                 3       3         5       2 3
+--R                          (640A B  + 256A B)C + 64B  + 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   3
+--R                          1536A B D
+--R                        + 
+--R                                    3          2           2       2
+--R                              - 768C  + 1152A C  + (- 1536B  + 768A )C
+--R                            + 
+--R                                       2       3
+--R                              - 1536A B  - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2
+--R                              256B C  - 1536A B C  + (1024B  + 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4        2       2  3         2 2
+--R                          128C  - 256A C  + (256B  + 256A )C  - 384A B C
+--R                        + 
+--R                               2 2       4           4       3 2       5
+--R                          (768A B  - 384A )C - 512A B  - 128A B  + 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                        5        4         2              2      2  3    9
+--R                  (- 16D  + 32B D  + (- 16C  + 64A C - 16B  - 48A )D )a b
+--R                + 
+--R                                  4                      3
+--R                      (8C + 224A)D  + (- 136B C - 64A B)D
+--R                    + 
+--R                          3         2       2      2    2
+--R                      (40C  - 144A C  + (24B  + 72A )C)D
+--R                    + 
+--R                           3          2      3      2
+--R                      (8B C  - 48A B C  + (8B  + 72A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            5        4         2               2       2  3
+--R                      - 148D  + 88B D  + (- 64C  - 104A C - 64B  - 592A )D
+--R                    + 
+--R                             2                3      2   2
+--R                      (192B C  + 192A B C + 8B  + 72A B)D
+--R                    + 
+--R                               4        3       2      2  2           2      3
+--R                          - 28C  + 88A C  + (24B  - 24A )C  + (- 24A B  + 24A )C
+--R                        + 
+--R                               4      2 2      4
+--R                          - 12B  - 72A B  + 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4          3        3      2   2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (212C + 1532A)D  + (- 664B C - 112A B)D
+--R                    + 
+--R                           3         2         2       2           2      3  2
+--R                      (232C  - 528A C  + (- 24B  + 864A )C - 144A B  + 88A )D
+--R                    + 
+--R                                   3           2       3       2           3
+--R                            - 40B C  - 528A B C  + (40B  + 456A B)C + 32A B
+--R                          + 
+--R                                 3
+--R                            - 80A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        5        4         2      2  3           2      3  2
+--R                      4C  - 12A C  + (- 24B  + 16A )C  + (- 24A B  - 32A )C
+--R                    + 
+--R                          4       2 2      4         4      3 2      5
+--R                      (20B  + 144A B  - 52A )C + 4A B  + 16A B  + 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                            5          4        2                 2        2  3
+--R                      - 124D  - 1208B D  + (248C  - 4328A C + 416B  - 1336A )D
+--R                    + 
+--R                              2                  3       2   2
+--R                      (1176B C  + 912A B C + 104B  + 240A B)D
+--R                    + 
+--R                                4         3        2       2  2
+--R                          - 188C  + 424A C  + (384B  - 264A )C
+--R                        + 
+--R                                  2       3        4       2 2       4
+--R                          (- 24A B  + 136A )C - 68B  - 480A B  + 244A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3         3       2   2
+--R                      - 32B C  + 304A B C  + (- 16B  - 408A B)C
+--R                    + 
+--R                              3      3         5      2 3      4
+--R                      (- 80A B  + 64A B)C - 16B  - 88A B  + 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      4                       3
+--R                      (1028C - 2044A)D  + (3104B C + 2864A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 560C  + 4512A C  + (- 1536B  + 1848A )C - 816A B
+--R                        + 
+--R                              3
+--R                          616A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3           2          3       2            3
+--R                          - 736B C  - 768A B C  + (- 304B  - 912A B)C + 224A B
+--R                        + 
+--R                                3
+--R                          - 496A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4          2       2  3
+--R                      28C  - 52A C  + (- 200B  + 112A )C
+--R                    + 
+--R                               2       3  2        4       2 2       4
+--R                      (- 168A B  - 224A )C  + (140B  + 912A B  - 364A )C
+--R                    + 
+--R                           4       3 2      5
+--R                      92A B  + 112A B  + 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                          5          4           2                 2        2  3
+--R                      288D  + 1088B D  + (- 1896C  + 4752A C - 720B  + 2552A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 2712B C  - 4560A B C + 272B  - 2424A B)D
+--R                    + 
+--R                              4          3         2       2  2
+--R                          280C  - 2048A C  + (1320B  - 480A )C
+--R                        + 
+--R                                  2       3         4       2 2       4
+--R                          (1200A B  - 416A )C + 208B  + 744A B  - 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3        2   2
+--R                      232B C  - 608A B C  + (344B  + 1248A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 560A B  + 448A B)C - 112B  - 616A B  + 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                       4                         3
+--R                      (- 1248C + 288A)D  + (- 2304B C - 2688A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          1056C  - 3840A C  + (1536B  - 3552A )C + 2496A B
+--R                        + 
+--R                                3
+--R                          - 704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2          3       2            3
+--R                          768B C  + 2880A B C  + (- 768B  + 384A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          1088A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4         2       2  3
+--R                      - 32C  + 320A C  + (- 32B  - 128A )C
+--R                    + 
+--R                             2       3  2          4        2 2       4
+--R                      (192A B  + 256A )C  + (- 160B  - 1824A B  + 416A )C
+--R                    + 
+--R                            4       3 2       5
+--R                      416A B  - 128A B  - 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                2       2  3
+--R                      (1728C  - 384A C + 384B  - 576A )D
+--R                    + 
+--R                              2                   3        2   2
+--R                      (1344B C  + 3456A B C - 384B  + 2112A B)D
+--R                    + 
+--R                               4          3           2       2  2
+--R                          - 64C  + 1536A C  + (- 1728B  + 768A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1152A B  + 256A )C - 128B  - 192A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3       2   2
+--R                      - 192B C  + 256A B C  + (- 320B  - 768A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (640A B  - 512A B)C + 128B  + 704A B  - 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                             3       2           2  2
+--R                      (- 768C  + 768A C - 1536A B )D
+--R                    + 
+--R                                  2        3        3            4       2 3
+--R                      (- 1536A B C  + 1024B C - 512A B)D - 256A C  + 256B C
+--R                    + 
+--R                          2 2          4       5
+--R                      768A B C - 512A B  + 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                %%BN1
+--R            + 
+--R                       3 3 8
+--R                  16A D a c
+--R                + 
+--R                            3 2 2          3          2  3
+--R                      - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                    + 
+--R                                     3          2         2      3    4
+--R                      ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           3         2  2 3
+--R                      (2B D  + 6A C D )a b
+--R                    + 
+--R                                    3                   2        2      3    3 2
+--R                      ((12C - 188A)D  + (12B C + 52A B)D  + (4A C  - 12A )D)a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 64C - 32A)D  + (96B C - 320A B)D
+--R                        + 
+--R                                3        2       2          2      3
+--R                          (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                        + 
+--R                                   2      3
+--R                          - 48A B C  - 16A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                      3                   2          2     3
+--R                        ((- 2C + 41A)D  + (- 3B C - 8A B)D  + (- 2A C  + 2A )D)
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 80B D  + (- 18C  + 224A C - 26B  - 66A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                        3                       2
+--R                          (144C - 232A)D  + (- 120B C + 808A B)D
+--R                        + 
+--R                             3         2         2      2           2       3
+--R                          (4C  - 212A C  + (- 24B  + 20A )C - 112A B  - 196A )D
+--R                        + 
+--R                              3          2      2        3
+--R                          4B C  + 36A B C  - 12A B C + 4A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                        + 
+--R                                  2                3       2        4        3
+--R                          (- 80B C  + 96A B C - 64B  - 336A B)D + 8C  + 32A C
+--R                        + 
+--R                              2      2  2         2      3        2 2     4
+--R                          (24B  + 48A )C  + (48A B  + 32A )C + 24A B  + 8A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                  3                     2
+--R                          - 384A D  + (384B C + 128A B)D
+--R                        + 
+--R                                3         2          2       2           2
+--R                          (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                        + 
+--R                               3           2       2           3      3
+--R                          64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4        3      2             2     2  2
+--R                          2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                        + 
+--R                              2              2
+--R                          (B C  + 6A B C - 3A B)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                        + 
+--R                             3       2       2      2          2       3
+--R                          (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                        + 
+--R                               3         2     2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                4        3
+--R                          - 224D  + 92B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 162C  - 280A C - 320B  - 1206A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (172B C  - 336A B C + 60B  + 492A B)D - 6C  + 48A C
+--R                        + 
+--R                                2      2  2           2      3       2 2     4
+--R                          (- 18B  - 24A )C  + (- 24A B  - 80A )C - 6A B  - 2A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                            + 
+--R                                 3
+--R                              64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2         3       2           3
+--R                          - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                        + 
+--R                              3
+--R                          144A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               4         3          2               2       2  2
+--R                          - 64D  - 256B D  + (- 144C  - 608A C + 32B  - 336A )D
+--R                        + 
+--R                                  2      3       2         4        3
+--R                          (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                        + 
+--R                                2      2  2         2       3        4       2 2
+--R                          (- 48B  - 96A )C  + (96A B  - 224A )C + 32B  + 144A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                        3            2
+--R                          (256C - 256A)D  + 1792A B D
+--R                        + 
+--R                                   3         2          2      2           2
+--R                              - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                            + 
+--R                                    3
+--R                              - 256A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3       2            3
+--R                          256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       3                   2
+--R                          (13C - 139A)D  + (18B C + 58A B)D
+--R                        + 
+--R                              3        2        2     2         2      3
+--R                          (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              4         3        2                2       2  2
+--R                          109D  - 265B D  + (114C  - 591A C + 183B  + 543A )D
+--R                        + 
+--R                                  2                 3       2       4        3
+--R                          (- 27B C  + 228A B C - 19B  - 225A B)D + C  - 13A C
+--R                        + 
+--R                             2     2  2        2      3
+--R                          (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                            + 
+--R                                  3
+--R                              346A
+--R                         *
+--R                            D
+--R                        + 
+--R                               3           2       3       2          3      3
+--R                          10B C  - 234A B C  + (14B  + 174A B)C - 2A B  - 30A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                3        2               2       2  2
+--R                          768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                        + 
+--R                                 2                 3        2            3
+--R                          (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                        + 
+--R                                2       2  2            2       3        4
+--R                          (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                        + 
+--R                                2 2      4
+--R                          - 240A B  - 64A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                           3                        2
+--R                          (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                        + 
+--R                                  3         2         2        2           2
+--R                              416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                            + 
+--R                                  3
+--R                              992A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 480B C  + 672A B C  + (- 128B  - 1632A B)C + 512A B
+--R                        + 
+--R                              3
+--R                          160A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 256D  + 384B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (192C  - 1024A C + 256B  - 2112A )D
+--R                        + 
+--R                                 2                  3        2          4
+--R                          (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                        + 
+--R                                 2       2  2            2       3         2 2
+--R                          (- 576B  - 384A )C  + (- 384A B  - 512A )C + 192A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                        + 
+--R                                   2        2           2       3         3
+--R                          (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 54B D  + (- 18C  + 140A C - 26B  - 66A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                        3                      2
+--R                          (142C - 688A)D  + (- 54B C + 800A B)D
+--R                        + 
+--R                                    3         2         2      2           2
+--R                                - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                              + 
+--R                                      3
+--R                                - 248A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2        3      2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              4         3       2                 2        2  2
+--R                          416D  - 190B D  + (84C  + 1254A C + 438B  + 2514A )D
+--R                        + 
+--R                                   2                  3        2         4
+--R                          (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                        + 
+--R                                 3       2       2  2          2       3       4
+--R                          - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C + 2B
+--R                        + 
+--R                             2 2      4
+--R                          48A B  + 14A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                        + 
+--R                                    3        2           2        2            2
+--R                              - 788C  - 84A C  + (- 2292B  - 4428A )C + 1404A B
+--R                            + 
+--R                                     3
+--R                              - 2252A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                        + 
+--R                                3
+--R                          - 308A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          608D  - 640B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 240C  + 3552A C - 960B  + 5232A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1632B C  - 1536A B C - 928B  - 1632A B)D + 464C
+--R                        + 
+--R                                3        2        2  2          2        3
+--R                          128A C  + (912B  + 1344A )C  + (384A B  + 1664A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 160B  - 528A B  - 16A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            3                       2
+--R                          (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 128C  - 576A C  + (192B  - 6144A )C + 4800A B
+--R                            + 
+--R                                    3
+--R                              - 704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2          3       2            3
+--R                          256B C  + 768A B C  + (- 704B  - 384A B)C + 448A B
+--R                        + 
+--R                                3
+--R                          - 128A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 128D  + 1280B D
+--R                        + 
+--R                               2                 2       2  2
+--R                          (768C  + 2560A C - 640B  - 768A )D
+--R                        + 
+--R                                 2                   2          4         3
+--R                          (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                        + 
+--R                                 2       2  2            2       3         4
+--R                          (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                        + 
+--R                                2 2       4
+--R                          - 384A B  + 128A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                3                         2
+--R                          512A D  + (- 1536B C - 2048A B)D
+--R                        + 
+--R                               3          2         2        2            2
+--R                          (256C  - 2048A C  + (3072B  + 1792A )C - 2048A B )D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                        - 1024B C  + 768A B C  - 3072A B C + 1024A B  + 256A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                         3                      2
+--R                          (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                        + 
+--R                             3        2       2      2          2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 204D  + 316B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 144C  + 364A C - 292B  - 1092A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (164B C  - 288A B C + 84B  + 636A B)D - 4C  + 20A C
+--R                        + 
+--R                                2      2  2           2      3
+--R                          (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                            + 
+--R                                  3
+--R                              996A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2         3       2          3
+--R                          - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                        + 
+--R                             3
+--R                          56A B
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 924D  - 588B D
+--R                        + 
+--R                               2                2        2  2
+--R                          (216C  - 5556A C - 60B  - 6156A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                        + 
+--R                                3          2       2  2         2        3
+--R                          708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                        + 
+--R                             4       2 2       4
+--R                          72B  + 576A B  + 120A
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                        + 
+--R                                  3          2        2        2            2
+--R                              408C  + 2760A C  + (504B  + 9096A )C - 3720A B
+--R                            + 
+--R                                   3
+--R                              2904A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3       2            3
+--R                          - 840B C  - 1656A B C  + (168B  + 360A B)C - 792A B
+--R                        + 
+--R                              3
+--R                          408A B
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          480D  - 1536B D
+--R                        + 
+--R                                 2                  2        2  2
+--R                          (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                        + 
+--R                                    2                  3        2          4
+--R                          (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                        + 
+--R                                  3        2        2  2           2        3
+--R                          - 864A C  + (576B  - 2304A )C  + (1152A B  - 2208A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          576B  + 576A B  - 384A
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                           3                       2
+--R                          (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                            + 
+--R                                     2        3
+--R                              2304A B  - 1344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                          1344B C  - 1728A B C  + 5184A B C - 1536A B  - 192A B
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                3           2                  2        2  2
+--R                          512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                        + 
+--R                                    2                   2          4         3
+--R                          (- 1280B C  - 4608A B C + 768A B)D + 640C  - 512A C
+--R                        + 
+--R                                2       2  2          2        3          2 2
+--R                          (1920B  + 768A )C  + (768A B  + 1536A )C - 1152A B
+--R                        + 
+--R                                4
+--R                          - 384A
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                     2
+--R                          - 2048A B D
+--R                        + 
+--R                                3          2         2        2            2
+--R                          (1024C  - 2048A C  + (3072B  - 1024A )C + 2048A B )D
+--R                        + 
+--R                                   3            2           3        2
+--R                          - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                        + 
+--R                                 3        3
+--R                          1024A B  + 1024A B
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                         4        3       2               2       2  2
+--R                      24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                    + 
+--R                             2               3      2
+--R                      (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                    3                    2
+--R                      (- 8C - 336A)D  + (216B C + 96A B)D
+--R                    + 
+--R                            3         2          2       2          2      3
+--R                      (- 56C  + 240A C  + (- 120B  - 184A )C + 80A B  - 96A )D
+--R                    + 
+--R                          3          2      3      2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                          4         3       2               2        2  2
+--R                      216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                    + 
+--R                               2                3       2         4         3
+--R                      (- 304B C  - 48A B C - 64B  - 384A B)D + 32C  - 120A C
+--R                    + 
+--R                        2      2  2           2       3       4      2 2      4
+--R                    (72B  + 24A )C  + (- 24A B  + 152A )C - 8B  - 96A B  - 24A
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                       3                      2
+--R                      (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                        + 
+--R                                3
+--R                          - 864A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3          2      3       2            3      3
+--R                      120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                          4          3          2                 2        2  2
+--R                      144D  + 1848B D  + (- 576C  + 6600A C - 984B  + 1800A )D
+--R                    + 
+--R                                2                   3        2          4
+--R                      (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                    + 
+--R                              3        2       2  2            2        3
+--R                      - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                    + 
+--R                            4       2 2      4
+--R                      - 120B  - 576A B  - 72A
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                    + 
+--R                                 3          2         2        2           2
+--R                            1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                          + 
+--R                                  3
+--R                            - 576A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3            2          3        2             3
+--R                      384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                    + 
+--R                            3
+--R                      - 240A B
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                            4          3
+--R                      - 384D  - 1600B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (2784C  - 7040A C + 1280B  - 3936A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                    + 
+--R                             3           2        2  2             2       3
+--R                      2304A C  + (- 2592B  + 1152A )C  + (- 1152A B  - 768A )C
+--R                    + 
+--R                            4        2 2       4
+--R                      - 384B  + 1440A B  + 864A
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                     3                       2
+--R                      (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                    + 
+--R                                 3          2           2        2            2
+--R                          - 1792C  + 5376A C  + (- 2688B  + 5632A )C - 3200A B
+--R                        + 
+--R                               3
+--R                          1536A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2         3        2             3
+--R                      - 512B C  - 6144A B C  + (2176B  + 2304A B)C - 1152A B
+--R                    + 
+--R                            3
+--R                      - 768A B
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                              2                2       2  2
+--R                      (- 2304C  + 512A C - 512B  + 768A )D
+--R                    + 
+--R                                2                    3        2          4
+--R                      (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                    + 
+--R                          4       2 2       4
+--R                      512B  - 768A B  - 768A
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                            3        2           2              2        3
+--R                      (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                    + 
+--R                           3
+--R                      1024A B
+--R                 *
+--R                     11
+--R                    a
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                        4 2 8
+--R                  - 8A D a c
+--R                + 
+--R                          4   2        4         3  2
+--R                      2A D a b  + (4B D  + 8A C D )a b
+--R                    + 
+--R                                  4          3     3 2  3
+--R                      ((8C - 32A)D  + 32A B D  - 8A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            4         3    3
+--R                      (- B D  - 2A C D )a b
+--R                    + 
+--R                                     4                    3     3 2  2 2
+--R                      ((- 6C + 100A)D  + (- 4B C - 16A B)D  + 2A D )a b
+--R                    + 
+--R                               5        4        2              2      2  3
+--R                          - 12D  + 12B D  + (- 8C  - 16A C - 16B  - 52A )D
+--R                        + 
+--R                                          2   2          3     3
+--R                          (- 24A B C + 12A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      4                      3
+--R                          (32C + 24A)D  + (- 48B C + 128A B)D
+--R                        + 
+--R                              2         2      3  2       4     3 2
+--R                          (48A C - 24A B  - 32A )D  + 8A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 4                3    4
+--R                      ((C - 22A)D  + (B C + 2A B)D )a b
+--R                    + 
+--R                            5        4      2             2      2  3
+--R                          7D  - 45B D  + (6C  - 80A C + 8B  + 25A )D
+--R                        + 
+--R                                      2   2        3     3
+--R                          (6A B C - 3A B)D  + (2A C  - 2A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 88C + 118A)D  + (52B C - 312A B)D
+--R                        + 
+--R                                2       2      2          2      3  2
+--R                          (60A C  + (12B  - 12A )C + 18A B  + 80A )D
+--R                        + 
+--R                               3          2      2            4     3 2
+--R                          (4B C  + 24A B C  - 12A B C)D - 2A C  + 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5        4       2              2       2  3
+--R                          - 36D  + 52B D  + (32C  - 48A C - 44B  - 176A )D
+--R                        + 
+--R                                2                3      2   2
+--R                          (48B C  - 48A B C + 12B  + 96A B)D
+--R                        + 
+--R                             4        3      2 2      3       4         4
+--R                          (8C  - 64A C  + 12A C  + 40A C - 12A )D - 4B C
+--R                        + 
+--R                                   3      2   2
+--R                          - 24A B C  + 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4                      3
+--R                          224A D  + (- 192B C - 96A B)D
+--R                        + 
+--R                                  2       2       2          2     3  2
+--R                          (- 72A C  + (96B  + 192A )C - 96A B  + 8A )D
+--R                        + 
+--R                                  3      2           3       5        4      2 3
+--R                          (- 16B C  - 48A B C - 32A B )D - 8C  + 32A C  - 16A C
+--R                        + 
+--R                                2      3  2      4      3 2
+--R                          (24A B  - 32A )C  + 24A C + 8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          5        4       2            2     2  3    5
+--R                      (- D  + 10B D  + (- C  + 20A C - B  - 3A )D )a b
+--R                    + 
+--R                                       4                    3
+--R                          (53C - 389A)D  + (24B C + 134A B)D
+--R                        + 
+--R                                  2     2        2      3  2
+--R                          (- 15A C  - 3B C - 3A B  - 17A )D
+--R                        + 
+--R                                3         2     2
+--R                          (- B C  - 6A B C  + 3A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              5        4       2                2       2  3
+--R                          127D  - 63B D  + (48C  + 240A C + 147B  + 534A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (- 60B C  + 144A B C - 11B  - 150A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 6C  + 72A C  + (- 12B  - 15A )C
+--R                            + 
+--R                                      2      3       4
+--R                              (- 12A B  - 82A )C + 3A
+--R                         *
+--R                            D
+--R                        + 
+--R                             4         3     2   2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 164C - 696A)D  + (448B C - 184A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 96C  + 138A C  + (- 132B  - 636A )C + 192A B
+--R                            + 
+--R                                 3
+--R                              10A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                               3          2      2           3      3        5
+--R                          (4B C  + 96A B C  - 60A B C + 32A B  + 24A B)D + 6C
+--R                        + 
+--R                                 4       2      2  3        2      3  2     4
+--R                          - 64A C  + (12B  + 16A )C  + (6A B  + 80A )C  - 6A C
+--R                        + 
+--R                              3 2
+--R                          - 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             5         4        2               2       2  3
+--R                          24D  + 120B D  + (116C  + 472A C - 56B  + 196A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (12B C  - 24A B C + 24B  + 156A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              92C  - 64A C  + (12B  + 144A )C
+--R                            + 
+--R                                    2      3        4       2 2      4
+--R                              (72A B  + 48A )C + 16B  + 108A B  - 60A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3         3      2   2
+--R                          20B C  - 80A B C  + (- 12B  + 48A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          4           3
+--R                          (- 128C + 128A)D  - 896A B D
+--R                        + 
+--R                              3         2        2      2          2       3  2
+--R                          (48C  - 288A C  + (384B  - 48A )C + 96A B  + 160A )D
+--R                        + 
+--R                                     3          2         3       2            3
+--R                              - 64B C  + 96A B C  + (- 64B  - 192A B)C - 128A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4         2      2  3        2 2
+--R                          - 32C  + 16A C  + (- 16B  - 64A )C  + 96A B C
+--R                        + 
+--R                                2 2      4          4      3 2      5
+--R                          (- 48A B  + 96A )C + 32A B  + 32A B  - 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                    4                    3    6
+--R                      ((- 8C + 80A)D  + (- 8B C - 16A B)D )a b
+--R                    + 
+--R                               5         4         2               2       2  3
+--R                          - 62D  + 158B D  + (- 47C  + 239A C - 66B  - 218A )D
+--R                        + 
+--R                                2               3      2   2
+--R                          (12B C  - 30A B C + 2B  + 30A B)D
+--R                        + 
+--R                            4        3      2     2  2        2      3
+--R                          (C  - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (229C + 559A)D  + (- 438B C + 584A B)D
+--R                        + 
+--R                              3         2        2       2          2       3  2
+--R                          (64C  - 444A C  + (- 3B  + 213A )C - 93A B  - 175A )D
+--R                        + 
+--R                                     3           2      3       2          3
+--R                              - 10B C  - 180A B C  + (8B  + 144A B)C - 6A B
+--R                            + 
+--R                                  3
+--R                              - 6A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2     2  3          2      3  2
+--R                          - C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5         4          2                2       2  3
+--R                          36D  - 340B D  + (- 237C  - 638A C + 116B  + 123A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 123B C  + 102A B C - 68B  - 363A B)D
+--R                        + 
+--R                                   4         3        2       2  2
+--R                              - 95C  + 312A C  + (- 3B  - 138A )C
+--R                            + 
+--R                                      2       3        4      2 2       4
+--R                              (- 66A B  - 120A )C - 16B  - 99A B  + 105A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4           3        3       2   2
+--R                          5B C  + 176A B C  + (- 5B  - 138A B)C
+--R                        + 
+--R                                3      3        2 3     4
+--R                          (10A B  + 16A B)C + 3A B  + 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (276C - 916A)D  + (416B C + 2048A B)D
+--R                        + 
+--R                                    3         2           2       2          2
+--R                              - 252C  + 636A C  + (- 1032B  - 516A )C - 72A B
+--R                            + 
+--R                                    3
+--R                              - 380A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3           2       2            3      3
+--R                          (- 40B C  - 216A B C  + 168A B C + 256A B  - 40A B)D
+--R                        + 
+--R                             5        4      2       2  3            2      3  2
+--R                          56C  - 80A C  + (4B  + 128A )C  + (- 132A B  + 64A )C
+--R                        + 
+--R                              4       2 2       4         4      3 2      5
+--R                          (20B  + 156A B  - 184A )C - 4A B  - 28A B  + 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              5         4          2               2        2  3
+--R                          144D  - 176B D  + (- 368C  + 736A C - 64B  + 1040A )D
+--R                        + 
+--R                                   2                  2   2
+--R                          (- 528B C  - 480A B C - 528A B)D
+--R                        + 
+--R                                  4        3        2      2  2
+--R                              128C  + 64A C  + (240B  + 96A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (288A B  - 128A )C + 48B  + 240A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4       3      2   2            3      3
+--R                          96B C  + (16B  + 96A B)C  + (- 160A B  - 64A B)C
+--R                        + 
+--R                               5       2 3
+--R                          - 16B  - 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 128C - 384A)D  + (768B C - 512A B)D
+--R                        + 
+--R                               3       2          2       3  2
+--R                          (192C  - 960A C + 768A B  + 128A )D
+--R                        + 
+--R                                   2       3        3           4      2 3
+--R                          (384A B C  - 256B C + 128A B)D - 64A C  - 64B C
+--R                        + 
+--R                              3 2       2 2          4      5
+--R                          128A C  - 192A B C + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         5        4      2             2      2  3    7
+--R                      (8D  - 32B D  + (8C  - 64A C + 8B  + 24A )D )a b
+--R                    + 
+--R                                          4                   3
+--R                          (- 118C + 412A)D  + (2B C - 264A B)D
+--R                        + 
+--R                                3        2      2      2          2      3  2
+--R                          (- 10C  + 96A C  + (6B  - 18A )C + 12A B  + 36A )D
+--R                        + 
+--R                               3          2        3      2
+--R                          (2B C  + 36A B C  + (- 2B  - 30A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5        4
+--R                          - 287D  + 30B D
+--R                        + 
+--R                                2                2        2  3
+--R                          (- 28C  - 682A C - 308B  - 1180A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (240B C  - 168A B C + 50B  + 414A B)D
+--R                        + 
+--R                                 4         3       2      2  2
+--R                              35C  - 170A C  + (54B  + 78A )C
+--R                            + 
+--R                                    2       3       4      2 2      4
+--R                              (66A B  + 198A )C + 3B  + 18A B  - 21A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      3      2   2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (81C + 1825A)D  + (- 528B C - 1756A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                572C  - 60A C  + (936B  + 2010A )C - 108A B
+--R                              + 
+--R                                    3
+--R                                658A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2            3
+--R                              92B C  - 120A B C  + (20B  + 264A B)C - 160A B
+--R                            + 
+--R                                    3
+--R                              - 100A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5         4         2      2  3
+--R                          - 29C  + 119A C  + (- 54B  - 80A )C
+--R                        + 
+--R                                  2       3  2        4      2 2      4        4
+--R                          (- 30A B  - 188A )C  + (- 5B  - 36A B  + 37A )C - A B
+--R                        + 
+--R                            3 2     5
+--R                          4A B  - 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 412D  + 132B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (466C  - 2484A C + 248B  - 2718A )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (1374B C  + 996A B C + 120B  + 702A B)D
+--R                        + 
+--R                                    4         3         2       2  2
+--R                              - 366C  - 192A C  + (- 18B  - 492A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 396A B  + 208A )C - 108B  - 690A B  + 170A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4          3       3       2   2
+--R                          - 190B C  + 96A B C  + (34B  - 204A B)C
+--R                        + 
+--R                                 3       3        5      2 3      4
+--R                          (220A B  + 304A B)C + 4B  + 82A B  + 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         4                        3
+--R                          (936C + 1176A)D  + (- 768B C + 1536A B)D
+--R                        + 
+--R                                 3         2          2        2            2
+--R                              24C  + 696A C  + (- 240B  + 3144A )C - 1392A B
+--R                            + 
+--R                                  3
+--R                              200A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2        3       2
+--R                              - 144B C  - 1296A B C  + (320B  + 336A B)C
+--R                            + 
+--R                                   3       3
+--R                              64A B  - 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2      2  3
+--R                          16C  + 80A C  + (- 8B  + 32A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 168A B  - 320A )C  + (40B  + 552A B  - 176A )C
+--R                        + 
+--R                                  4     3 2       5
+--R                          - 168A B  + 8A B  + 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                             5         4          2                 2       2  3
+--R                          96D  - 672B D  + (- 768C  - 1536A C + 384B  + 192A )D
+--R                        + 
+--R                                   2                   2   2
+--R                          (- 384B C  - 384A B C - 1344A B)D
+--R                        + 
+--R                                    4        2       2  2       3       4
+--R                              - 352C  + (384B  - 768A )C  - 384A C - 32B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 224A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3 2       3         5
+--R                          - 32B C  + 256A B C  + 128B C  + 384A B C - 32B
+--R                        + 
+--R                                2 3       4
+--R                          - 128A B  + 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  4                      3
+--R                          - 384A D  + (768B C + 1536A B)D
+--R                        + 
+--R                                  2           2       2           2       3  2
+--R                          (1152A C  + (- 1536B  - 768A )C + 384A B  - 128A )D
+--R                        + 
+--R                                 3       2            3         5         4
+--R                          (256B C  + 768A B C + 512A B )D + 128C  - 128A C
+--R                        + 
+--R                              2 3            2       3  2       4        3 2
+--R                          256A C  + (- 384A B  + 128A )C  - 384A C - 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                   4                   3    8
+--R                      ((16C - 96A)D  + (16B C + 32A B)D )a b
+--R                    + 
+--R                              5         4       2                2       2  3
+--R                          136D  - 168B D  + (92C  - 188A C + 136B  + 472A )D
+--R                        + 
+--R                                  2               3      2   2
+--R                          (- 48B C  + 24A B C - 8B  - 72A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 20A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 36A )C
+--R                         *
+--R                            D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 12C - 1996A)D  + (864B C + 640A B)D
+--R                        + 
+--R                                    3         2          2       2          2
+--R                              - 296C  + 720A C  + (- 252B  - 732A )C + 36A B
+--R                            + 
+--R                                   3
+--R                              - 84A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2           3
+--R                              - 48B C  + 288A B C  + (- 40B  - 408A B)C + 24A B
+--R                            + 
+--R                                 3
+--R                              24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3         2      3  2
+--R                          4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          636D  + 544B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 104C  + 3740A C + 120B  + 3228A )D
+--R                        + 
+--R                                    2                 3       2   2
+--R                          (- 1380B C  - 912A B C - 96B  - 804A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              188C  - 300A C  + (- 192B  + 156A )C
+--R                            + 
+--R                                     2       3        4       2 2       4
+--R                              (108A B  - 340A )C + 76B  + 468A B  - 216A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          68B C  - 272A B C  + (28B  + 384A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            4                        3
+--R                          (- 1528C - 1376A)D  + (- 520B C - 1200A B)D
+--R                        + 
+--R                                    3          2        2        2            2
+--R                              - 544C  - 1968A C  + (132B  - 4740A )C + 1068A B
+--R                            + 
+--R                                     3
+--R                              - 1012A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2           3
+--R                              360B C  + 1584A B C  + (- 16B  - 480A B)C - 56A B
+--R                            + 
+--R                                  3
+--R                              600A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3
+--R                          - 8C  - 64A C  + (188B  - 28A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (252A B  + 412A )C  + (- 100B  - 768A B  + 308A )C
+--R                        + 
+--R                               4      3 2      5
+--R                          12A B  - 64A B  - 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 304D  + 944B D
+--R                        + 
+--R                               2                  2       2  3
+--R                          (708C  + 3096A C - 1072B  - 268A )D
+--R                        + 
+--R                                   2                  3        2   2
+--R                          (- 132B C  + 360A B C - 208B  + 2028A B)D
+--R                        + 
+--R                                  4         3          2        2  2
+--R                              636C  + 448A C  + (- 996B  + 1512A )C
+--R                            + 
+--R                                      2       3        4       2 2       4
+--R                              (- 24A B  + 576A )C + 80B  + 924A B  - 356A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3      2   2
+--R                          108B C  - 256A B C  + (- 252B  - 24A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (120A B  - 768A B)C + 80B  + 356A B  - 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                        4                         3
+--R                          (48C + 1776A)D  + (- 1728B C - 3456A B)D
+--R                        + 
+--R                               3          2         2        2         3  2
+--R                          (816C  - 2928A C  + (3168B  + 1680A )C + 432A )D
+--R                        + 
+--R                                    3          2        3      2            3
+--R                              224B C  + 96A B C  + (256B  - 96A B)C - 768A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2       2  3
+--R                          - 160C  + 160A C  + (48B  - 384A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (336A B  - 160A )C  + (- 80B  - 432A B  + 544A )C
+--R                        + 
+--R                                  4      3 2
+--R                          - 112A B  + 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  4        2                 2        2  3
+--R                          - 384B D  + (960C  - 2688A C + 960B  - 1344A )D
+--R                        + 
+--R                                  2                   3       2   2
+--R                          (1344B C  + 2688A B C - 192B  + 576A B)D
+--R                        + 
+--R                                    4         3          2       2  2
+--R                              - 640C  + 768A C  + (- 960B  - 576A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1152A B  - 128A )C - 192B  - 960A B  + 320A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3         3       2   2
+--R                          - 320B C  + 384A B C  + (- 64B  - 576A B)C
+--R                        + 
+--R                                 3       3         5       2 3
+--R                          (640A B  + 256A B)C + 64B  + 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   3
+--R                          1536A B D
+--R                        + 
+--R                                    3          2           2       2
+--R                              - 768C  + 1152A C  + (- 1536B  + 768A )C
+--R                            + 
+--R                                       2       3
+--R                              - 1536A B  - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2
+--R                              256B C  - 1536A B C  + (1024B  + 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4        2       2  3         2 2
+--R                          128C  - 256A C  + (256B  + 256A )C  - 384A B C
+--R                        + 
+--R                               2 2       4           4       3 2       5
+--R                          (768A B  - 384A )C - 512A B  - 128A B  + 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                        5        4         2              2      2  3    9
+--R                  (- 16D  + 32B D  + (- 16C  + 64A C - 16B  - 48A )D )a b
+--R                + 
+--R                                  4                      3
+--R                      (8C + 224A)D  + (- 136B C - 64A B)D
+--R                    + 
+--R                          3         2       2      2    2
+--R                      (40C  - 144A C  + (24B  + 72A )C)D
+--R                    + 
+--R                           3          2      3      2
+--R                      (8B C  - 48A B C  + (8B  + 72A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            5        4         2               2       2  3
+--R                      - 148D  + 88B D  + (- 64C  - 104A C - 64B  - 592A )D
+--R                    + 
+--R                             2                3      2   2
+--R                      (192B C  + 192A B C + 8B  + 72A B)D
+--R                    + 
+--R                               4        3       2      2  2           2      3
+--R                          - 28C  + 88A C  + (24B  - 24A )C  + (- 24A B  + 24A )C
+--R                        + 
+--R                               4      2 2      4
+--R                          - 12B  - 72A B  + 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4          3        3      2   2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (212C + 1532A)D  + (- 664B C - 112A B)D
+--R                    + 
+--R                           3         2         2       2           2      3  2
+--R                      (232C  - 528A C  + (- 24B  + 864A )C - 144A B  + 88A )D
+--R                    + 
+--R                                   3           2       3       2           3
+--R                            - 40B C  - 528A B C  + (40B  + 456A B)C + 32A B
+--R                          + 
+--R                                 3
+--R                            - 80A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        5        4         2      2  3           2      3  2
+--R                      4C  - 12A C  + (- 24B  + 16A )C  + (- 24A B  - 32A )C
+--R                    + 
+--R                          4       2 2      4         4      3 2      5
+--R                      (20B  + 144A B  - 52A )C + 4A B  + 16A B  + 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                            5          4        2                 2        2  3
+--R                      - 124D  - 1208B D  + (248C  - 4328A C + 416B  - 1336A )D
+--R                    + 
+--R                              2                  3       2   2
+--R                      (1176B C  + 912A B C + 104B  + 240A B)D
+--R                    + 
+--R                                4         3        2       2  2
+--R                          - 188C  + 424A C  + (384B  - 264A )C
+--R                        + 
+--R                                  2       3        4       2 2       4
+--R                          (- 24A B  + 136A )C - 68B  - 480A B  + 244A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3         3       2   2
+--R                      - 32B C  + 304A B C  + (- 16B  - 408A B)C
+--R                    + 
+--R                              3      3         5      2 3      4
+--R                      (- 80A B  + 64A B)C - 16B  - 88A B  + 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      4                       3
+--R                      (1028C - 2044A)D  + (3104B C + 2864A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 560C  + 4512A C  + (- 1536B  + 1848A )C - 816A B
+--R                        + 
+--R                              3
+--R                          616A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3           2          3       2            3
+--R                          - 736B C  - 768A B C  + (- 304B  - 912A B)C + 224A B
+--R                        + 
+--R                                3
+--R                          - 496A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4          2       2  3
+--R                      28C  - 52A C  + (- 200B  + 112A )C
+--R                    + 
+--R                               2       3  2        4       2 2       4
+--R                      (- 168A B  - 224A )C  + (140B  + 912A B  - 364A )C
+--R                    + 
+--R                           4       3 2      5
+--R                      92A B  + 112A B  + 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                          5          4           2                 2        2  3
+--R                      288D  + 1088B D  + (- 1896C  + 4752A C - 720B  + 2552A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 2712B C  - 4560A B C + 272B  - 2424A B)D
+--R                    + 
+--R                              4          3         2       2  2
+--R                          280C  - 2048A C  + (1320B  - 480A )C
+--R                        + 
+--R                                  2       3         4       2 2       4
+--R                          (1200A B  - 416A )C + 208B  + 744A B  - 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3        2   2
+--R                      232B C  - 608A B C  + (344B  + 1248A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 560A B  + 448A B)C - 112B  - 616A B  + 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                       4                         3
+--R                      (- 1248C + 288A)D  + (- 2304B C - 2688A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          1056C  - 3840A C  + (1536B  - 3552A )C + 2496A B
+--R                        + 
+--R                                3
+--R                          - 704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2          3       2            3
+--R                          768B C  + 2880A B C  + (- 768B  + 384A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          1088A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4         2       2  3
+--R                      - 32C  + 320A C  + (- 32B  - 128A )C
+--R                    + 
+--R                             2       3  2          4        2 2       4
+--R                      (192A B  + 256A )C  + (- 160B  - 1824A B  + 416A )C
+--R                    + 
+--R                            4       3 2       5
+--R                      416A B  - 128A B  - 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                2       2  3
+--R                      (1728C  - 384A C + 384B  - 576A )D
+--R                    + 
+--R                              2                   3        2   2
+--R                      (1344B C  + 3456A B C - 384B  + 2112A B)D
+--R                    + 
+--R                               4          3           2       2  2
+--R                          - 64C  + 1536A C  + (- 1728B  + 768A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1152A B  + 256A )C - 128B  - 192A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3       2   2
+--R                      - 192B C  + 256A B C  + (- 320B  - 768A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (640A B  - 512A B)C + 128B  + 704A B  - 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                             3       2           2  2
+--R                      (- 768C  + 768A C - 1536A B )D
+--R                    + 
+--R                                  2        3        3            4       2 3
+--R                      (- 1536A B C  + 1024B C - 512A B)D - 256A C  + 256B C
+--R                    + 
+--R                          2 2          4       5
+--R                      768A B C - 512A B  + 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                %%BN0
+--R            + 
+--R                       5            4 2  7
+--R                  (4A D a b - 8A C D a )c
+--R                + 
+--R                             5         4    2
+--R                      (- 2B D  - 8A C D )a b
+--R                    + 
+--R                                    5                  4         2     3  3  2
+--R                      ((- 4C + 20A)D  + (4B C - 28A B)D  + (24A C  + 8A )D )a b
+--R                    + 
+--R                             2             2  4            3
+--R                          (8C  - 32A C + 8A )D  + 64A B C D
+--R                        + 
+--R                                  3      3   2
+--R                          (- 16A C  - 16A C)D
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                  5                  4        2     3  3    3
+--R                      ((2C - 38A)D  + (4B C + 12A B)D  + (4A C  - 4A )D )a b
+--R                    + 
+--R                            6       5      2              2      2  4
+--R                          6D  - 4B D  + (4C  + 56A C + 14B  + 36A )D
+--R                        + 
+--R                                  2               2   3           3      3   2
+--R                          (- 12B C  - 8A B C - 12A B)D  + (- 16A C  + 16A C)D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                                        5                    4
+--R                          (- 32C + 16A)D  + (32B C - 160A B)D
+--R                        + 
+--R                                     3        2         2       2          2
+--R                                - 24C  + 56A C  + (- 32B  - 136A )C + 64A B
+--R                              + 
+--R                                   3
+--R                                40A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                               3          2      2         3   2
+--R                          (8B C  - 72A B C  + 24A B C - 24A B)D
+--R                        + 
+--R                                4      3 2     5
+--R                          (20A C  - 24A C  + 4A )D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                              2              2  4
+--R                          (32C  - 32A C + 32A )D
+--R                        + 
+--R                                  2                 2   3
+--R                          (- 64B C  + 256A B C - 64A B)D
+--R                        + 
+--R                                   4        3      2 2            2      3
+--R                                16C  - 64A C  + 96A C  + (- 192A B  - 64A )C
+--R                              + 
+--R                                   4
+--R                                16A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3      3            5      3 3     5
+--R                          (64A B C  + 64A B C)D - 8A C  + 16A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              6        5        2             2      2  4
+--R                          - 2D  + 16B D  + (- 4C  + 64A C - 6B  - 12A )D
+--R                        + 
+--R                                 2               2   3
+--R                          (- 2B C  - 12A B C + 6A B)D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                                      5                      4
+--R                          (28C - 92A)D  + (- 60B C + 260A B)D
+--R                        + 
+--R                             3         2      2      2          2      3  3
+--R                          (8C  - 192A C  + (4B  + 24A )C - 36A B  - 96A )D
+--R                        + 
+--R                               3          2      2     2
+--R                          (8B C  + 48A B C  - 24A B C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                             6        5         2               2       2  4
+--R                          20D  - 32B D  + (- 12C  + 152A C + 36B  + 116A )D
+--R                        + 
+--R                                2                 3       2   3
+--R                          (48B C  - 480A B C - 32B  - 144A B)D
+--R                        + 
+--R                                4         3       2      2  2
+--R                              8C  + 128A C  + (36B  + 48A )C
+--R                            + 
+--R                                     2       3        2 2     4
+--R                              (120A B  + 256A )C + 36A B  + 8A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  4          3      2   2     3         4
+--R                          (- 10B C  - 56A B C  + 36A B C  + 8A B C - 10A B)D
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                                        5                     4
+--R                          (- 48C - 16A)D  + (240B C - 144A B)D
+--R                        + 
+--R                                   3        2         2       2           2
+--R                              - 80C  + 80A C  + (- 96B  - 496A )C + 480A B
+--R                            + 
+--R                                  3
+--R                              112A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                   3           2       3       2           3
+--R                              80B C  - 144A B C  + (96B  + 624A B)C - 32A B
+--R                            + 
+--R                                    3
+--R                              - 176A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2      2  3       3 2
+--R                              - 20C  + 36A C  + (- 32B  - 72A )C  - 184A C
+--R                            + 
+--R                                    2 2      4        5
+--R                              (- 96A B  - 36A )C + 20A
+--R                         *
+--R                            D
+--R                        + 
+--R                            5          4      2   3      3   2      4        5
+--R                        4B C  + 20A B C  - 24A B C  - 24A B C  + 20A B C + 4A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                              2      2  4            2                  2   3
+--R                          (32C  + 32A )D  + (- 256B C  + 256A B C - 256A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              64C  - 128A C  + (192B  + 384A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 768A B  - 128A )C + 192A B  + 64A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4           3       2   2
+--R                              - 64B C  + 256A B C  - 384A B C
+--R                            + 
+--R                                     3       3         4
+--R                              (256A B  + 256A B)C - 64A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            6        5     2 4           2      3  3     4 2
+--R                          8C  - 32A C  - 8A C  + (- 64A B  + 64A )C  - 8A C
+--R                        + 
+--R                                3 2      5       6
+--R                          (- 64A B  - 32A )C + 8A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                         5                     4
+--R                          (- 10C + 118A)D  + (- 20B C - 84A B)D
+--R                        + 
+--R                             3        2      2     2         2      3  3
+--R                          (2C  - 26A C  + (6B  + 6A )C + 6A B  + 34A )D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                               6        5         2                2       2  4
+--R                          - 44D  + 28B D  + (- 28C  - 224A C - 100B  - 324A )D
+--R                        + 
+--R                                2                3       2   3
+--R                          (92B C  + 40A B C + 20B  + 204A B)D
+--R                        + 
+--R                                  4         3         2      2  2
+--R                              - 8C  + 104A C  + (- 24B  - 24A )C
+--R                            + 
+--R                                      2       3
+--R                              (- 24A B  - 136A )C
+--R                         *
+--R                             2
+--R                            D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                                       5                       4
+--R                          (144C + 80A)D  + (- 320B C + 576A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                132C  - 92A C  + (288B  + 1196A )C - 608A B
+--R                              + 
+--R                                      3
+--R                                - 116A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                        3           2         3       2
+--R                                - 160B C  + 528A B C  + (- 64B  - 672A B)C
+--R                              + 
+--R                                    3
+--R                                176A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4       2      2  3
+--R                              10C  - 134A C  + (28B  + 20A )C
+--R                            + 
+--R                                    2       3  2         2 2     4       3 2
+--R                              (12A B  + 196A )C  + (- 12A B  + 2A )C + 4A B
+--R                            + 
+--R                                   5
+--R                              - 30A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                  5          2               2  4
+--R                          - 160B D  + (- 128C  - 256A C + 16B )D
+--R                        + 
+--R                                 2                  3       2   3
+--R                          (416B C  - 960A B C - 128B  - 352A B)D
+--R                        + 
+--R                                   4         3          2        2  2
+--R                              - 82C  + 232A C  + (- 288B  - 1164A )C
+--R                            + 
+--R                                      2      3        4      2 2      4
+--R                              (1344A B  - 24A )C + 16B  + 96A B  - 82A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3       2   2
+--R                              100B C  - 656A B C  + 408A B C
+--R                            + 
+--R                                       3       3         4
+--R                              (- 128A B  - 400A B)C - 28A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              6        5         2     2  4        2       3  3
+--R                          - 4C  + 56A C  + (- 10B  + 4A )C  + (8A B  - 112A )C
+--R                        + 
+--R                              2 2     4  2      3 2      5        4 2     6
+--R                          (36A B  + 4A )C  + (8A B  + 56A )C - 10A B  - 4A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                            4
+--R                          (384B C + 128A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 32C  + 416A C  + (- 640B  - 352A )C + 512A B
+--R                            + 
+--R                                  3
+--R                              224A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2            3
+--R                              160B C  - 288A B C  + (128B  + 2016A B)C - 640A B
+--R                            + 
+--R                                    3
+--R                              - 608A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2       2  3
+--R                              - 48C  - 16A C  + (- 32B  + 288A )C
+--R                            + 
+--R                                      2       3  2          4       2 2      4
+--R                              (- 96A B  + 224A )C  + (- 128B  - 864A B  + 16A )C
+--R                            + 
+--R                                     4       3 2      5
+--R                              - 64A B  + 224A B  + 48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4       3      2   3
+--R                          - 16B C  + 176A B C  + (32B  + 96A B)C
+--R                        + 
+--R                              3      3   2       2 3       4         3 3      5
+--R                        (96A B  + 96A B)C  + (96A B  + 176A B)C + 32A B  - 16A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                   2       2   3
+--R                          (- 256B C  - 256A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              64C  - 256A C  + (768B  + 384A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 768A B  - 256A )C + 768A B  + 64A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 256B C  + 512A B C  + (- 256B  - 1536A B)C
+--R                            + 
+--R                                      3       3          2 3       4
+--R                              (1024A B  + 512A B)C - 256A B  - 256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6       2      2  4         2 3
+--R                          32C  + (64B  - 32A )C  - 256A B C
+--R                        + 
+--R                               2 2      4  2            4       3 2        4 2
+--R                          (384A B  - 32A )C  + (- 128A B  - 256A B )C + 64A B
+--R                        + 
+--R                             6
+--R                          32A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                             6        5       2               2      2  4
+--R                          12D  - 44B D  + (20C  - 152A C + 36B  + 84A )D
+--R                        + 
+--R                               2               3      2   3
+--R                          (4B C  + 72A B C - 4B  - 60A B)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                                        5                     4
+--R                          (- 36C + 12A)D  + (296B C - 520A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 44C  + 524A C  + (- 68B  - 228A )C + 204A B
+--R                            + 
+--R                                  3
+--R                              228A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                  3           2       3       2     2
+--R                          (- 16B C  - 288A B C  + (16B  + 240A B)C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                               6         5         2              2       2  4
+--R                          - 30D  + 272B D  + (- 16C  + 96A C - 44B  - 432A )D
+--R                        + 
+--R                                   2                  3       2   3
+--R                          (- 324B C  + 872A B C + 224B  + 972A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 22C  - 536A C  + (- 48B  - 36A )C
+--R                            + 
+--R                                       2       3       4       2 2      4
+--R                              (- 576A B  - 600A )C - 6B  - 240A B  - 54A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3         3       2   2
+--R                              24B C  + 368A B C  + (- 12B  - 288A B)C
+--R                            + 
+--R                                    3      3        2 3      4
+--R                              (24A B  - 48A B)C + 4A B  + 72A B
+--R                         *
+--R                            D
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                        5                       4
+--R                          (112C + 144A)D  + (- 928B C - 416A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              168C  - 600A C  + (896B  + 1816A )C - 1408A B
+--R                            + 
+--R                                 3
+--R                              24A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 416B C  + 672A B C  + (- 512B  - 3648A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  + 896A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              96C  + 144A C  + (184B  + 320A )C
+--R                            + 
+--R                                     2       3  2       4        2 2       4
+--R                              (216A B  + 544A )C  + (80B  + 1032A B  + 224A )C
+--R                            + 
+--R                                   4      3 2      5
+--R                              48A B  - 24A B  - 48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4       2   3
+--R                          - 12B C  - 156A B C  + 104A B C
+--R                        + 
+--R                                  3       3   2         2 3       4         5
+--R                          (- 32A B  + 104A B)C  + (- 32A B  - 156A B)C - 12A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                 2                2       2  4
+--R                          (- 144C  - 480A C + 480B  - 144A )D
+--R                        + 
+--R                                 2                   3       2   3
+--R                          (960B C  + 1152A B C + 192B  + 192A B)D
+--R                        + 
+--R                                    4         3           2        2  2
+--R                              - 196C  + 912A C  + (- 1536B  - 2136A )C
+--R                            + 
+--R                                      2       3         4      4
+--R                              (2304A B  - 624A )C + 224B  + 60A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4            3        3        2   2
+--R                              696B C  - 1120A B C  + (448B  + 3024A B)C
+--R                            + 
+--R                                        3       3         5       2 3       4
+--R                              (- 1408A B  - 608A B)C + 32B  + 192A B  + 184A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               6         2      2  4         2       3  3
+--R                          - 48C  + (- 84B  - 80A )C  + (80A B  - 256A )C
+--R                        + 
+--R                                4       2 2      4  2           4      3 2
+--R                          (- 48B  - 696A B  - 80A )C  + (- 32A B  + 80A B )C
+--R                        + 
+--R                               2 4      4 2      6
+--R                          - 48A B  - 84A B  - 48A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                 3         2           2       2           2
+--R                              64C  + 576A C  + (- 1152B  + 192A )C - 384A B
+--R                            + 
+--R                                  3
+--R                              192A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                     3            2        3        2
+--R                              - 64B C  - 1728A B C  + (640B  + 1344A B)C
+--R                            + 
+--R                                      3        3
+--R                              - 896A B  - 1088A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              64C  - 512A C  + (320B  + 640A )C
+--R                            + 
+--R                                     2        3  2
+--R                              (192A B  + 1024A )C
+--R                            + 
+--R                                    4        2 2       4           4        3 2
+--R                              (- 64B  - 2112A B  - 192A )C + 320A B  + 1088A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                  5          4         3       2   3
+--R                          - 192B C  + 64A B C  + (- 64B  - 384A B)C
+--R                        + 
+--R                                 3       3   2       5       2 3      4
+--R                          (320A B  - 384A B)C  + (64B  + 320A B  + 64A B)C
+--R                        + 
+--R                               5      3 3       5
+--R                          64A B  - 64A B  - 192A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                   3       2 2       3        2 2  2
+--R                          (- 256A C  + 768B C  - 256A C + 768A B )D
+--R                        + 
+--R                                      4            3           3        2   2
+--R                              - 256B C  + 1024A B C  + (- 1024B  - 1536A B)C
+--R                            + 
+--R                                      3        3           2 3       4
+--R                              (1024A B  + 1024A B)C - 1024A B  - 256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5       2 4            2       3  3
+--R                          128A C  + 256B C  + (- 512A B  - 256A )C
+--R                        + 
+--R                               4        2 2  2            4       3 2       5
+--R                          (128B  + 1536A B )C  + (- 512A B  - 512A B  + 128A )C
+--R                        + 
+--R                              2 4       4 2
+--R                          128A B  + 256A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                      5                    4
+--R                          (8C - 120A)D  + (16B C + 144A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  3
+--R                          (- 8C  + 40A C  + (- 24B  - 24A )C - 24A B  - 72A )D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                             6        5                 2       2  4
+--R                          64D  - 96B D  + (416A C + 128B  + 672A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 224B C  - 128A B C - 96B  - 672A B)D
+--R                        + 
+--R                            4         3       2      2  2         2       3    2
+--R                        (32C  - 160A C  + (96B  + 96A )C  + (96A B  + 288A )C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                          5                     4
+--R                          (- 290C - 354A)D  + (360B C + 168A B)D
+--R                        + 
+--R                                    3         2          2        2           2
+--R                              - 108C  - 356A C  + (- 916B  - 2884A )C + 940A B
+--R                            + 
+--R                                    3
+--R                              - 588A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2           3
+--R                              664B C  - 696A B C  + (280B  + 2376A B)C - 40A B
+--R                            + 
+--R                                    3
+--R                              - 360A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4          2       2  3
+--R                              - 42C  + 206A C  + (- 132B  - 100A )C
+--R                            + 
+--R                                       2       3  2         4      2 2      4
+--R                              (- 108A B  - 420A )C  + (- 10B  - 12A B  - 18A )C
+--R                            + 
+--R                                     4      3 2      5
+--R                              - 10A B  - 36A B  + 54A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                5        2                 2       2  4
+--R                          120B D  + (426C  + 1588A C - 560B  + 522A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 328B C  - 784A B C - 96B  + 696A B)D
+--R                        + 
+--R                                  4         3         2        2  2
+--R                              236C  - 112A C  + (1740B  + 4200A )C
+--R                            + 
+--R                                        2        3         4       2 2      4
+--R                              (- 1800A B  + 2512A )C - 208B  - 852A B  + 12A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 704B C  + 960A B C  + (- 248B  - 2112A B)C
+--R                            + 
+--R                                     3       3         5       2 3
+--R                              (208A B  + 320A B)C - 24B  - 184A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5       2      2  4         2       3  3
+--R                          18C  - 84A C  + (60B  + 14A )C  + (48A B  + 232A )C
+--R                        + 
+--R                              4      2 2      4  2         4      3 2      5
+--R                          (10B  - 24A B  + 14A )C  + (20A B  + 48A B  - 84A )C
+--R                        + 
+--R                             2 4      4 2      6
+--R                          10A B  + 60A B  + 18A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                              4
+--R                          (- 448B C - 576A B)D
+--R                        + 
+--R                                   3          2         2        2           2
+--R                              - 48C  - 2864A C  + (1984B  - 1424A )C + 704A B
+--R                            + 
+--R                                    3
+--R                              - 656A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3            2          3        2
+--R                              - 288B C  + 1632A B C  + (- 640B  - 3552A B)C
+--R                            + 
+--R                                     3       3
+--R                              1664A B  + 672A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    5         4          2        2  3
+--R                              - 184C  + 200A C  + (- 976B  - 2416A )C
+--R                            + 
+--R                                       2        3  2
+--R                              (- 336A B  - 3120A )C
+--R                            + 
+--R                                   4        2 2       4          4        3 2
+--R                              (352B  + 3216A B  - 344A )C - 32A B  - 1520A B
+--R                            + 
+--R                                   5
+--R                              - 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5           4       3       2   3
+--R                          240B C  - 208A B C  + (32B  + 224A B)C
+--R                        + 
+--R                                  3       3   2         2 3       4         3 3
+--R                          (- 32A B  + 224A B)C  + (- 32A B  - 208A B)C + 32A B
+--R                        + 
+--R                              5
+--R                          240A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                 2                   3       2   3
+--R                          (576B C  + 1920A B C - 640B  + 576A B)D
+--R                        + 
+--R                                    4          3           2        2  2
+--R                              - 472C  + 2528A C  + (- 2304B  + 1392A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1536A B  + 992A )C - 416B  - 768A B  + 552A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4            3         3        2   2
+--R                              560B C  - 1216A B C  + (1536B  + 4128A B)C
+--R                            + 
+--R                                        3       3          5       2 3      4
+--R                              (- 2560A B  - 192A B)C - 192B  + 512A B  + 48A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5      2       2  4
+--R                          48C  - 32A C  + (8B  + 464A )C
+--R                        + 
+--R                                  2        3  3          4        2 2       4  2
+--R                          (1120A B  + 1088A )C  + (- 192B  - 1872A B  + 464A )C
+--R                        + 
+--R                                 4        3 2      5        6       2 4     4 2
+--R                          (384A B  + 1120A B  - 32A )C - 32B  - 192A B  + 8A B
+--R                        + 
+--R                             6
+--R                          48A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                      3            2         3       2
+--R                              - 256B C  - 2304A B C  + (1536B  - 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 768A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  5          4        2       2  3          2 2
+--R                              448C  - 1024A C  + (640B  - 640A )C  + 1920A B C
+--R                            + 
+--R                                      2 2       4           4        3 2
+--R                              (- 1152A B  - 832A )C + 768A B  + 1664A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                  5          4          3       2   3
+--R                          - 192B C  + 64A B C  + (- 640B  - 896A B)C
+--R                        + 
+--R                                 3       3   2        2 3      4          3 3
+--R                          (128A B  - 896A B)C  + (128A B  + 64A B)C - 640A B
+--R                        + 
+--R                                5
+--R                          - 192A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                    3        3 2        3           2 3
+--R                          (1024A B C  - 1024B C  + 1024A B C - 1024A B )D
+--R                        + 
+--R                                6         5        2       2  4
+--R                          - 128C  + 128A C  + (256B  + 128A )C
+--R                        + 
+--R                                    2       3  3        4        2 2       4  2
+--R                          (- 1024A B  - 256A )C  + (512B  + 1536A B  + 128A )C
+--R                        + 
+--R                                   4        3 2       5         2 4       4 2
+--R                          (- 512A B  - 1024A B  + 128A )C + 512A B  + 256A B
+--R                        + 
+--R                                6
+--R                          - 128A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                           6        5         2              2       2  4
+--R                      - 16D  + 48B D  + (- 16C  + 96A C - 48B  - 144A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (16B C  - 96A B C + 16B  + 144A B)D
+--R                 *
+--R                       8
+--R                    a b
+--R                + 
+--R                                   5                      4
+--R                      (48C + 240A)D  + (- 288B C - 96A B)D
+--R                    + 
+--R                          3         2        2       2           2       3  3
+--R                      (80C  - 464A C  + (304B  + 624A )C - 144A B  + 144A )D
+--R                    + 
+--R                              3           2         3       2     2
+--R                      (- 64B C  + 384A B C  + (- 64B  - 576A B)C)D
+--R                 *
+--R                     2 7
+--R                    a b
+--R                + 
+--R                           6         5       2                 2       2  4
+--R                      - 20D  - 156B D  + (56C  - 1296A C + 168B  - 456A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (664B C  + 624A B C - 40B  - 168A B)D
+--R                    + 
+--R                                4         3          2       2  2
+--R                          - 148C  + 816A C  + (- 648B  - 888A )C
+--R                        + 
+--R                                 2       3        4       2 2       4
+--R                          (240A B  - 720A )C + 44B  + 504A B  + 108A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          84B C  - 496A B C  + (88B  + 696A B)C
+--R                        + 
+--R                                  3       3        5      2 3       4
+--R                          (- 16A B  + 144A B)C + 4B  + 24A B  - 108A B
+--R                     *
+--R                        D
+--R                 *
+--R                     3 6
+--R                    a b
+--R                + 
+--R                                   5                     4
+--R                      (168C - 24A)D  + (828B C + 636A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 416C  + 2848A C  + (- 752B  + 1824A )C - 432A B
+--R                        + 
+--R                              3
+--R                          608A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3            2        3       2            3
+--R                          - 712B C  - 1560A B C  + (392B  + 936A B)C - 696A B
+--R                        + 
+--R                                3
+--R                          - 264A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2       2  3
+--R                          120C  - 616A C  + (544B  + 432A )C
+--R                        + 
+--R                                 2        3  2          4        2 2       4
+--R                          (288A B  + 1072A )C  + (- 120B  - 1824A B  - 168A )C
+--R                        + 
+--R                              4       3 2      5
+--R                          8A B  + 480A B  - 72A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4         3       2   3
+--R                      - 36B C  + 204A B C  + (- 40B  - 232A B)C
+--R                    + 
+--R                           3       3   2        5     2 3       4          5
+--R                      (8A B  - 232A B)C  + (- 4B  + 8A B  + 204A B)C - 4A B
+--R                    + 
+--R                           3 3      5
+--R                      - 40A B  - 36A B
+--R                 *
+--R                     4 5
+--R                    a b
+--R                + 
+--R                             2                2      2  4
+--R                      (- 580C  + 120A C - 120B  + 60A )D
+--R                    + 
+--R                                2                   3        2   3
+--R                      (- 1760B C  - 2688A B C + 384B  - 1056A B)D
+--R                    + 
+--R                              4          3         2        2  2
+--R                          680C  - 3168A C  + (1224B  - 2832A )C
+--R                        + 
+--R                                  2        3         4      2 2       4
+--R                          (1680A B  - 1632A )C + 176B  + 72A B  - 600A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4            3          3        2   2
+--R                          336B C  + 1664A B C  + (- 800B  - 1248A B)C
+--R                        + 
+--R                                 3       5       2 3       4
+--R                          1664A B C + 64B  + 288A B  + 528A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5          2      2  4
+--R                      - 36C  + 168A C  + (- 144B  - 28A )C
+--R                    + 
+--R                               2       3  3       4        2 2      4  2
+--R                      (- 448A B  - 464A )C  + (92B  + 1440A B  - 28A )C
+--R                    + 
+--R                              4       3 2       5       6      2 4       4 2
+--R                      (- 72A B  - 448A B  + 168A )C + 8B  + 92A B  - 144A B
+--R                    + 
+--R                           6
+--R                      - 36A
+--R                 *
+--R                     5 4
+--R                    a b
+--R                + 
+--R                            3         2        2       2           2      3  3
+--R                      (1056C  - 224A C  + (448B  - 288A )C + 576A B  - 32A )D
+--R                    + 
+--R                                 3            2           3        2
+--R                          1856B C  + 4416A B C  + (- 1408B  + 2880A B)C
+--R                        + 
+--R                                  3        3
+--R                          - 384A B  + 1344A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5          4          2        2  3
+--R                          - 480C  + 1760A C  + (- 800B  + 2112A )C
+--R                        + 
+--R                                    2        3  2
+--R                          (- 2592A B  + 1216A )C
+--R                        + 
+--R                                 4        2 2        4           4        3 2
+--R                          (- 192B  + 1056A B  + 1440A )C - 832A B  - 1248A B
+--R                        + 
+--R                             5
+--R                          96A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4        3       2   3
+--R                      - 48B C  - 624A B C  + (448B  + 416A B)C
+--R                    + 
+--R                               3       3   2         5       2 3       4
+--R                      (- 832A B  + 416A B)C  + (- 64B  - 832A B  - 624A B)C
+--R                    + 
+--R                             5       3 3      5
+--R                      - 64A B  + 448A B  - 48A B
+--R                 *
+--R                     6 3
+--R                    a b
+--R                + 
+--R                                 4         3          2       2  2
+--R                          - 1072C  + 192A C  + (- 576B  + 480A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1920A B  + 192A )C + 320B  - 576A B  - 48A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3         3        2   2
+--R                          - 960B C  - 3328A B C  + (1792B  - 2688A B)C
+--R                        + 
+--R                                 3        3          5       2 3       4
+--R                          (512A B  - 2304A B)C + 256B  + 768A B  - 960A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6         5        2       2  4           2       3  3
+--R                      128C  - 384A C  + (144B  - 640A )C  + (1472A B  - 256A )C
+--R                    + 
+--R                            4        2 2       4  2
+--R                      (- 64B  - 1440A B  - 640A )C
+--R                    + 
+--R                              4        3 2       5        6      2 4       4 2
+--R                      (1152A B  + 1472A B  - 384A )C + 64B  - 64A B  + 144A B
+--R                    + 
+--R                          6
+--R                      128A
+--R                 *
+--R                     7 2
+--R                    a b
+--R                + 
+--R                              5        4        2       2  3
+--R                          576C  - 64A C  + (256B  - 384A )C
+--R                        + 
+--R                                  2       3  2          4       2 2       4
+--R                          (2304A B  - 128A )C  + (- 768B  + 768A B  - 192A )C
+--R                        + 
+--R                                  4       3 2       5
+--R                          - 256A B  + 768A B  + 192A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4          3       2   3
+--R                      192B C  + 960A B C  + (- 768B  + 896A B)C
+--R                    + 
+--R                               3       3   2          5       2 3       4
+--R                      (- 256A B  + 896A B)C  + (- 256B  - 256A B  + 960A B)C
+--R                    + 
+--R                              5       3 3       5
+--R                      - 256A B  - 768A B  + 192A B
+--R                 *
+--R                     8
+--R                    a b
+--R                + 
+--R                            6       2 4          2 3        4       4  2
+--R                      - 128C  + 128A C  - 1024A B C  + (512B  + 128A )C
+--R                    + 
+--R                             3 2        2 4       6
+--R                      - 1024A B C + 512A B  - 128A
+--R                 *
+--R                     9
+--R                    a
+--R             *
+--R                x
+--R            + 
+--R                   5 2         4            4 2  7
+--R              (2A D b  - 4A C D a b + 8A B D a )c
+--R            + 
+--R                        5         4  3
+--R                  (- B D  - 4A C D )b
+--R                + 
+--R                               5                  4         2     3  3    2
+--R                  ((- 2C + 8A)D  + (2B C - 16A B)D  + (12A C  + 6A )D )a b
+--R                + 
+--R                      2             2  4            3          3      3   2  2
+--R                  ((4C  - 20A C - 4B )D  + 24A B C D  + (- 8A C  - 20A C)D )a b
+--R                + 
+--R                            5                    4        2         2  3
+--R                      - 8A D  + (- 8B C + 32A B)D  + (- 8A C - 48A B )D
+--R                    + 
+--R                        3   2      3 2
+--R                      8A B D  + 16A C D
+--R                 *
+--R                     3
+--R                    a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                             5                 4        2     3  3  4
+--R                  ((C - 19A)D  + (2B C + 6A B)D  + (2A C  - 2A )D )b
+--R                + 
+--R                        6      5      2             2      2  4
+--R                      3D  - B D  + (2C  + 34A C + 8B  + 19A )D
+--R                    + 
+--R                             2              2   3          3     3   2
+--R                      (- 6B C  - 2A B C - 9A B)D  + (- 8A C  + 8A C)D
+--R                 *
+--R                       3
+--R                    a b
+--R                + 
+--R                                    5                    4
+--R                      (- 14C + 10A)D  + (24B C - 150A B)D
+--R                    + 
+--R                            3        2         2      2          2      3  3
+--R                      (- 12C  + 24A C  + (- 12B  - 68A )C + 54A B  + 34A )D
+--R                    + 
+--R                         3          2      2        3   2         4      3 2
+--R                    (4B C  - 36A B C  + 30A B C - 8A B)D  + (10A C  - 10A C )D
+--R                 *
+--R                     2 2
+--R                    a b
+--R                + 
+--R                           5       2             2      2  4
+--R                      16B D  + (20C  - 12A C - 8B  + 16A )D
+--R                    + 
+--R                              2                 3      2   3
+--R                      (- 24B C  + 184A B C + 24B  + 64A B)D
+--R                    + 
+--R                            4        3      2 2           2       3        2 2
+--R                          8C  - 24A C  + 96A C  + (- 60A B  - 104A )C - 12A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              3      2   2      3            5     3 3
+--R                      (40A B C  - 24A B C  + 24A B C)D - 4A C  + 4A C
+--R                 *
+--R                     3
+--R                    a b
+--R                + 
+--R                                 5                     4
+--R                      (8C - 32A)D  + (- 32B C + 56A B)D
+--R                    + 
+--R                            2       2      2           2  3
+--R                      (16A C  + (56B  - 32A )C - 192A B )D
+--R                    + 
+--R                             3      3   2
+--R                      (104A B  + 32A B)D
+--R                    + 
+--R                          2 3      3 2      4       3 2           4      3   2
+--R                    (- 56A C  + 64A C  - 40A C - 16A B )D - 8A B C  - 24A B C
+--R                 *
+--R                     4
+--R                    a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                         6       5        2             2     2  4
+--R                      - D  + 8B D  + (- 2C  + 32A C - 3B  - 6A )D
+--R                    + 
+--R                            2              2   3
+--R                      (- B C  - 6A B C + 3A B)D
+--R                 *
+--R                     5
+--R                    b
+--R                + 
+--R                                  5                      4
+--R                      (13C - 31A)D  + (- 34B C + 142A B)D
+--R                    + 
+--R                         3         2     2      2          2      3  3
+--R                      (4C  - 100A C  + (B  + 14A )C - 19A B  - 66A )D
+--R                    + 
+--R                           3          2      2     2
+--R                      (4B C  + 24A B C  - 12A B C)D
+--R                 *
+--R                       4
+--R                    a b
+--R                + 
+--R                        6        5         2               2      2  4
+--R                      7D  - 27B D  + (- 14C  + 110A C + 47B  + 82A )D
+--R                    + 
+--R                            2                 3       2   3
+--R                      (20B C  - 196A B C - 27B  - 126A B)D
+--R                    + 
+--R                            4        3       2     2  2         2       3
+--R                          4C  + 72A C  + (18B  + 3A )C  + (42A B  + 230A )C
+--R                        + 
+--R                             2 2    4
+--R                          12A B  - A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             4          3      2   2
+--R                      (- 5B C  - 30A B C  + 15A B C )D
+--R                 *
+--R                     2 3
+--R                    a b
+--R                + 
+--R                                    5                     4
+--R                      (- 36C + 74A)D  + (174B C - 216A B)D
+--R                    + 
+--R                            3        2          2       2           2      3  3
+--R                      (- 36C  - 30A C  + (- 132B  - 332A )C + 586A B  + 30A )D
+--R                    + 
+--R                                 3           2       3       2           3
+--R                            36B C  - 192A B C  + (30B  + 288A B)C - 80A B
+--R                          + 
+--R                                  3
+--R                            - 160A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         2      2  3           2       3  2
+--R                          - 10C  + (- 20B  - 24A )C  + (- 18A B  - 214A )C
+--R                        + 
+--R                                2 2     4       3 2     5
+--R                          (- 36A B  - 2A )C - 2A B  + 2A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4     2   3
+--R                      2B C  + 12A B C  - 6A B C
+--R                 *
+--R                     3 2
+--R                    a b
+--R                + 
+--R                           6        5       2              2      2  4
+--R                      - 12D  + 40B D  + (16C  - 48A C - 96B  - 24A )D
+--R                    + 
+--R                               2                 3      2   3
+--R                      (- 200B C  + 128A B C + 40B  + 96A B)D
+--R                    + 
+--R                             4         3       2       2  2
+--R                          24C  - 108A C  + (48B  + 492A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 528A B  - 172A )C - 52B  - 264A B  + 100A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4           3       2   2         3       3
+--R                          - 40B C  + 216A B C  - 240A B C  + (80A B  + 264A B)C
+--R                        + 
+--R                             2 3     4
+--R                          24A B  + 8A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6       5      2      2  4          2      3  3
+--R                      4C  - 4A C  + (4B  + 16A )C  + (- 4A B  + 40A )C
+--R                    + 
+--R                          2 2      4  2       3 2     5
+--R                      (36A B  + 12A )C  + (12A B  - 4A )C
+--R                 *
+--R                     4
+--R                    a b
+--R                + 
+--R                                  5                     4
+--R                      (32C - 16A)D  + (- 80B C + 96A B)D
+--R                    + 
+--R                           3        2        2     2           2  3
+--R                      (- 8C  + 64A C  + (224B  + 8A )C - 176A B )D
+--R                    + 
+--R                                2       3          3     3   2
+--R                      (- 24A B C  - 144B C + 416A B  - 8A B)D
+--R                    + 
+--R                               4      2       2  3       3 2       2 2       4
+--R                          72A C  + (8B  - 224A )C  + 160A C  + (24A B  - 160A )C
+--R                        + 
+--R                                 4      3 2      5
+--R                          - 96A B  - 64A B  + 24A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4       2   3          3      3   2
+--R                      8B C  - 32A B C  + 128A B C  + (- 8A B  - 96A B)C
+--R                    + 
+--R                         4        3 3
+--R                      56A B C + 8A B
+--R                 *
+--R                     5
+--R                    a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                                   5                     4
+--R                      (- 5C + 59A)D  + (- 10B C - 42A B)D
+--R                    + 
+--R                        3        2      2     2         2      3  3
+--R                      (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                 *
+--R                     6
+--R                    b
+--R                + 
+--R                           6       5         2               2       2  4
+--R                      - 21D  + 9B D  + (- 11C  - 154A C - 55B  - 167A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (49B C  + 10A B C + 11B  + 129A B)D
+--R                    + 
+--R                         4        3         2      2  2           2      3    2
+--R                    (- 4C  + 52A C  + (- 12B  - 12A )C  + (- 12A B  - 68A )C)D
+--R                 *
+--R                       5
+--R                    a b
+--R                + 
+--R                                  5                       4
+--R                      (75C - 13A)D  + (- 196B C + 452A B)D
+--R                    + 
+--R                          3        2        2       2           2      3  3
+--R                      (68C  - 10A C  + (143B  + 671A )C - 425A B  - 99A )D
+--R                    + 
+--R                                 3           2         3       2           3
+--R                          - 84B C  + 288A B C  + (- 26B  - 438A B)C + 14A B
+--R                        + 
+--R                             3
+--R                          70A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                         5        4       2      2  3         2      3  2
+--R                      (5C  - 65A C  + (15B  + 15A )C  + (15A B  + 85A )C )D
+--R                 *
+--R                     2 4
+--R                    a b
+--R                + 
+--R                         6         5         2               2      2  4
+--R                      12D  - 194B D  + (- 99C  - 164A C + 90B  + 29A )D
+--R                    + 
+--R                             2                  3       2   3
+--R                      (241B C  - 698A B C - 206B  - 737A B)D
+--R                    + 
+--R                               4         3         2       2  2
+--R                          - 45C  + 188A C  + (- 63B  - 966A )C
+--R                        + 
+--R                                 2       3        4       2 2       4
+--R                          (660A B  + 338A )C + 42B  + 357A B  - 127A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          65B C  - 336A B C  + (13B  + 432A B)C
+--R                        + 
+--R                                  3       3        2 3    4
+--R                          (- 22A B  - 192A B)C + 3A B  - A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6        5        2     2  4          2      3  3
+--R                      - 2C  + 26A C  + (- 6B  - 6A )C  + (- 6A B  - 34A )C
+--R                 *
+--R                     3 3
+--R                    a b
+--R                + 
+--R                                     5                    4
+--R                      (- 76C + 128A)D  + (500B C + 52A B)D
+--R                    + 
+--R                          3         2          2       2           2      3  3
+--R                      (72C  + 422A C  + (- 652B  - 256A )C + 812A B  + 98A )D
+--R                    + 
+--R                                3          2        3        2            3
+--R                          222B C  + 36A B C  + (348B  + 1410A B)C - 884A B
+--R                        + 
+--R                                3
+--R                          - 132A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2       2  3
+--R                          - 6C  - 120A C  + (- 8B  + 592A )C
+--R                        + 
+--R                                  2       3  2         4       2 2       4
+--R                          (- 30A B  - 172A )C  + (- 40B  - 384A B  + 278A )C
+--R                        + 
+--R                               4       3 2     5
+--R                          36A B  + 102A B  + 4A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5          4      3       2   3
+--R                      - 20B C  + 78A B C  + (2B  - 124A B)C
+--R                    + 
+--R                           3       3   2         2 3      4        3 3     5
+--R                      (4A B  + 144A B)C  + (- 18A B  - 16A B)C - 4A B  + 2A B
+--R                 *
+--R                     4 2
+--R                    a b
+--R                + 
+--R                           6        5       2               2       2  4
+--R                      - 32D  + 80B D  + (68C  - 88A C - 224B  - 172A )D
+--R                    + 
+--R                               2                  3      2   3
+--R                      (- 240B C  - 288A B C + 192B  - 16A B)D
+--R                    + 
+--R                             4         3        2       2  2
+--R                          40C  - 624A C  + (600B  + 576A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 336A B  - 368A )C - 64B  - 360A B  + 120A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4           3         3        2   2
+--R                          - 224B C  + 288A B C  + (- 80B  - 1344A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (672A B  + 480A B)C + 48B  + 336A B  - 160A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6       5      2       2  4            2      3  3
+--R                      4C  + 8A C  + (8B  - 100A )C  + (- 144A B  - 80A )C
+--R                    + 
+--R                         4      4  2           4       3 2      5        2 4
+--R                      (4B  - 36A )C  + (- 24A B  - 144A B  - 56A )C - 12A B
+--R                    + 
+--R                           4 2     6
+--R                      - 40A B  + 4A
+--R                 *
+--R                     5
+--R                    a b
+--R                + 
+--R                                  5                      4
+--R                      (32C + 64A)D  + (- 192B C + 32A B)D
+--R                    + 
+--R                            3        2       2          2  3
+--R                      (- 32C  + (320B  + 160A )C + 64A B )D
+--R                    + 
+--R                                2       3          3       3   2
+--R                      (- 96A B C  - 576B C + 320A B  - 160A B)D
+--R                    + 
+--R                               5         4       2       2  3       3 2
+--R                          - 32C  + 288A C  + (32B  - 320A )C  + 384A C
+--R                        + 
+--R                               4      2 2       4           4      5
+--R                          (160B  + 96A B  - 160A )C - 384A B  + 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       2   3           3       3   2
+--R                      32B C  - 160A B C  + 512A B C  + (- 32A B  - 320A B)C
+--R                    + 
+--R                          4           5      3 3      5
+--R                      224A B C + 32A B  + 32A B  - 32A B
+--R                 *
+--R                     6
+--R                    a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                        6        5       2              2      2  4
+--R                      6D  - 22B D  + (10C  - 76A C + 18B  + 42A )D
+--R                    + 
+--R                           2               3      2   3
+--R                      (2B C  + 36A B C - 2B  - 30A B)D
+--R                 *
+--R                     7
+--R                    b
+--R                + 
+--R                                    5                     4
+--R                      (- 16C - 24A)D  + (168B C - 272A B)D
+--R                    + 
+--R                            3         2         2       2           2       3  3
+--R                      (- 24C  + 288A C  + (- 32B  - 136A )C + 104A B  + 160A )D
+--R                    + 
+--R                             3           2      3       2     2
+--R                      (- 8B C  - 144A B C  + (8B  + 120A B)C)D
+--R                 *
+--R                       6
+--R                    a b
+--R                + 
+--R                          6         5       2              2       2  4
+--R                      - 5D  + 208B D  + (28C  + 52A C - 90B  - 258A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 166B C  + 352A B C + 168B  + 696A B)D
+--R                    + 
+--R                              4         3         2       2  2
+--R                          - 7C  - 344A C  + (- 36B  + 108A )C
+--R                        + 
+--R                                   2       3       4       2 2     4
+--R                          (- 228A B  - 572A )C - 9B  - 126A B  + 7A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                            4           3         3       2   2
+--R                      (10B C  + 180A B C  + (- 10B  - 150A B)C )D
+--R                 *
+--R                     2 5
+--R                    a b
+--R                + 
+--R                                    5                       4
+--R                      (155C - 103A)D  + (- 600B C - 212A B)D
+--R                    + 
+--R                          3         2        2        2            2       3  3
+--R                      (36C  - 308A C  + (816B  + 1470A )C - 1208A B  + 210A )D
+--R                    + 
+--R                                  3           2          3        2            3
+--R                          - 296B C  + 624A B C  + (- 332B  - 1848A B)C + 432A B
+--R                        + 
+--R                              3
+--R                          516A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5         4       2      2  3         2       3  2
+--R                          37C  + 171A C  + (62B  + 16A )C  + (54A B  + 548A )C
+--R                        + 
+--R                              4       2 2      4         4     3 2      5
+--R                          (17B  + 300A B  + 11A )C - 5A B  + 8A B  - 15A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5          4      3      2   3
+--R                      - 4B C  - 72A B C  + (4B  + 60A B)C
+--R                 *
+--R                     3 4
+--R                    a b
+--R                + 
+--R                         6         5          2                2       2  4
+--R                      94D  - 130B D  + (- 210C  - 318A C + 752B  + 284A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (494B C  + 940A B C - 88B  - 118A B)D
+--R                    + 
+--R                                4         3           2        2  2
+--R                          - 204C  + 880A C  + (- 1170B  - 2592A )C
+--R                        + 
+--R                                  2       3         4        2 2       4
+--R                          (1284A B  - 380A )C + 306B  + 1434A B  - 352A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3        3        2   2
+--R                          380B C  - 936A B C  + (102B  + 1596A B)C
+--R                        + 
+--R                                   3        3         5       2 3      4
+--R                          (- 700A B  - 1272A B)C - 22B  - 302A B  - 24A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6        5         2      2  4         2       3  3
+--R                      - 16C  - 38A C  + (- 12B  - 38A )C  + (76A B  - 112A )C
+--R                    + 
+--R                           4       2 2      4  2         4      3 2      5
+--R                      (- 8B  - 192A B  - 56A )C  + (10A B  - 16A B  + 38A )C
+--R                    + 
+--R                        2 4     4 2     6
+--R                      6A B  + 8A B  - 2A
+--R                 *
+--R                     4 3
+--R                    a b
+--R                + 
+--R                                      5                    4
+--R                      (- 220C - 244A)D  + (324B C - 60A B)D
+--R                    + 
+--R                                3         2           2       2            2
+--R                          - 112C  + 948A C  + (- 1776B  - 288A )C - 1008A B
+--R                        + 
+--R                              3
+--R                          188A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3           2         3       2             3
+--R                          - 108B C  - 936A B C  + (1104B  + 876A B)C - 1312A B
+--R                        + 
+--R                              3
+--R                          104A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2        2  3
+--R                          160C  - 668A C  + (176B  + 1512A )C
+--R                        + 
+--R                                2      3  2          4        2 2       4
+--R                          (60A B  + 80A )C  + (- 372B  - 1248A B  + 344A )C
+--R                        + 
+--R                                4      3 2      5
+--R                          484A B  + 84A B  - 84A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4       3       2   3
+--R                      - 84B C  + 360A B C  + (12B  - 592A B)C
+--R                    + 
+--R                             3       3   2       5       2 3       4          5
+--R                      (280A B  + 712A B)C  + (12B  + 276A B  - 124A B)C - 4A B
+--R                    + 
+--R                         3 3      5
+--R                      40A B  + 48A B
+--R                 *
+--R                     5 2
+--R                    a b
+--R                + 
+--R                           6         5        2                2      2  4
+--R                      - 16D  + 160B D  + (168C  + 368A C - 176B  - 24A )D
+--R                    + 
+--R                              2                  3      2   3
+--R                      (- 32B C  - 192A B C + 448B  + 96A B)D
+--R                    + 
+--R                              4         3         2       2  2
+--R                          288C  - 832A C  + (1008B  + 384A )C
+--R                        + 
+--R                                  2       3         4       2 2      4
+--R                          (1248A B  - 512A )C - 112B  + 432A B  - 32A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3          3        2   2
+--R                          - 192B C  + 1024A B C  + (- 928B  - 1536A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (320A B  + 768A B)C + 32B  + 352A B  - 448A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5       2       2  4           2      3  3
+--R                      - 24C  + 144A C  + (96B  - 168A )C  + (- 64A B  - 96A )C
+--R                    + 
+--R                          4       2 2       4  2            4       3 2      5
+--R                      (40B  + 384A B  + 152A )C  + (- 272A B  - 192A B  - 48A )C
+--R                    + 
+--R                           6       2 4      4 2      6
+--R                      - 16B  - 152A B  + 32A B  + 40A
+--R                 *
+--R                     6
+--R                    a b
+--R                + 
+--R                           5                       4
+--R                      64A D  + (- 192B C - 256A B)D
+--R                    + 
+--R                               2        2       2           2  3
+--R                      (- 256A C  + (384B  + 128A )C + 128A B )D
+--R                    + 
+--R                             3          3       3   2
+--R                      (- 640B C - 384A B  - 128A B)D
+--R                    + 
+--R                                5         4       2 3       3 2       4
+--R                          - 128C  + 320A C  - 384A C  + 384A C  + 640B C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 320A B  + 256A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       2   3       3   2
+--R                      64B C  - 512A B C  + 640A B C  - 896A B C
+--R                    + 
+--R                            5       4            5       5
+--R                      (- 64B  + 320A B)C + 128A B  - 128A B
+--R                 *
+--R                     7
+--R                    a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                                 5                  4
+--R                      (4C - 60A)D  + (8B C + 72A B)D
+--R                    + 
+--R                           3        2         2      2          2      3  3
+--R                      (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                 *
+--R                     8
+--R                    b
+--R                + 
+--R                         6        5         2               2       2  4
+--R                      28D  - 44B D  + (- 12C  + 280A C + 68B  + 340A )D
+--R                    + 
+--R                               2                3       2   3
+--R                      (- 124B C  - 56A B C - 52B  - 396A B)D
+--R                    + 
+--R                          4        3       2      2  2         2       3    2
+--R                      (16C  - 80A C  + (48B  + 48A )C  + (48A B  + 144A )C)D
+--R                 *
+--R                       7
+--R                    a b
+--R                + 
+--R                                     5                   4
+--R                      (- 208C - 16A)D  + (168B C + 8A B)D
+--R                    + 
+--R                                 3         2          2        2           2
+--R                            - 60C  - 252A C  + (- 512B  - 1728A )C + 608A B
+--R                          + 
+--R                                  3
+--R                            - 352A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                3           2        3        2           3
+--R                          368B C  - 384A B C  + (136B  + 1368A B)C - 56A B
+--R                        + 
+--R                                3
+--R                          - 152A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         4         2      2  3
+--R                          - 20C  + 100A C  + (- 60B  - 60A )C
+--R                        + 
+--R                                  2       3  2
+--R                          (- 60A B  - 180A )C
+--R                     *
+--R                        D
+--R                 *
+--R                     2 6
+--R                    a b
+--R                + 
+--R                            6         5        2                 2      2  4
+--R                      - 102D  + 166B D  + (276C  + 1024A C - 552B  + 12A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 204B C  - 280A B C + 136B  + 724A B)D
+--R                    + 
+--R                              4         3        2        2  2
+--R                          210C  - 280A C  + (888B  + 3060A )C
+--R                        + 
+--R                                   2        3         4        2 2       4
+--R                          (- 984A B  + 1120A )C - 194B  - 1296A B  + 258A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4           3         3        2   2
+--R                          - 370B C  + 504A B C  + (- 72B  - 1404A B)C
+--R                        + 
+--R                                 3       3        5     2 3      4
+--R                          (128A B  + 424A B)C + 2B  + 8A B  + 14A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6        5       2      2  4         2      3  3
+--R                      8C  - 40A C  + (24B  + 24A )C  + (24A B  + 72A )C
+--R                 *
+--R                     3 5
+--R                    a b
+--R                + 
+--R                                    5                       4
+--R                      (158C + 262A)D  + (- 842B C - 602A B)D
+--R                    + 
+--R                                3          2         2       2            2
+--R                            156C  - 2876A C  + (1688B  - 808A )C + 1080A B
+--R                          + 
+--R                                  3
+--R                            - 736A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                3           2          3        2             3
+--R                          - 4B C  + 540A B C  + (- 988B  - 2484A B)C + 1332A B
+--R                        + 
+--R                                3
+--R                          - 644A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5         4          2        2  3
+--R                          - 194C  + 414A C  + (- 360B  - 2216A )C
+--R                        + 
+--R                                 2        3  2        4        2 2       4
+--R                          (120A B  - 1200A )C  + (338B  + 2124A B  - 422A )C
+--R                        + 
+--R                                 4     3 2     5
+--R                          - 54A B  - 4A B  + 2A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4         3       2   3
+--R                      118B C  - 138A B C  + (- 12B  + 444A B)C
+--R                    + 
+--R                              3       3   2        5      2 3      4          5
+--R                      (- 76A B  - 292A B)C  + (- 2B  + 12A B  + 14A B)C - 2A B
+--R                    + 
+--R                          3 3      5
+--R                      - 4A B  - 18A B
+--R                 *
+--R                     4 4
+--R                    a b
+--R                + 
+--R                         6         5        2                2       2  4
+--R                      60D  - 264B D  + (240C  - 576A C + 356B  + 152A )D
+--R                    + 
+--R                              2                    3       2   3
+--R                      (1244B C  + 2472A B C - 1032B  + 596A B)D
+--R                    + 
+--R                                4          3           2        2  2
+--R                          - 520C  + 3168A C  + (- 1692B  + 1200A )C
+--R                        + 
+--R                                    2        3         4       2 2       4
+--R                          (- 2352A B  + 2152A )C - 148B  - 732A B  + 544A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3         3        2   2
+--R                          316B C  - 832A B C  + (1292B  + 3936A B)C
+--R                        + 
+--R                                    3       3          5        2 3       4
+--R                          (- 1224A B  + 384A B)C - 160B  - 1100A B  + 932A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6         5         2       2  4          2       3  3
+--R                      52C  - 104A C  + (- 60B  + 532A )C  + (104A B  + 520A )C
+--R                    + 
+--R                             4       2 2     4  2         4       3 2       5
+--R                      (- 108B  - 696A B  + 4A )C  + (16A B  + 176A B  + 128A )C
+--R                    + 
+--R                        6      2 4      4 2      6
+--R                      4B  + 12A B  + 12A B  - 44A
+--R                 *
+--R                     5 3
+--R                    a b
+--R                + 
+--R                                     5                     4
+--R                      (- 32C - 336A)D  + (576B C + 736A B)D
+--R                    + 
+--R                                  3         2          2       2           2
+--R                            - 672C  + 520A C  + (- 816B  - 768A )C - 432A B
+--R                          + 
+--R                                 3
+--R                            - 72A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3            2         3        2
+--R                          - 664B C  - 3024A B C  + (2416B  - 1800A B)C
+--R                        + 
+--R                                 3       3
+--R                          1712A B  - 496A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5          4        2       2  3
+--R                          360C  - 1680A C  + (608B  - 352A )C
+--R                        + 
+--R                                 2        3  2          4       2 2       4
+--R                          (984A B  - 1680A )C  + (- 528B  - 192A B  - 904A )C
+--R                        + 
+--R                                 4       3 2      5
+--R                          1088A B  - 120A B  - 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                              5           4          3        2   3
+--R                      - 192B C  + 344A B C  + (- 296B  - 1904A B)C
+--R                    + 
+--R                              3       3   2        5       2 3       4
+--R                      (- 16A B  + 288A B)C  + (144B  + 360A B  - 848A B)C
+--R                    + 
+--R                             5      3 3     5
+--R                      - 48A B  + 16A B  + 8A B
+--R                 *
+--R                     6 2
+--R                    a b
+--R                + 
+--R                           5          2                2       2  4
+--R                      64B D  + (- 144C  + 544A C - 256B  + 240A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 448B C  - 768A B C + 128B  - 192A B)D
+--R                    + 
+--R                              4         3        2       2  2
+--R                          480C  - 192A C  + (288B  + 768A )C
+--R                        + 
+--R                                 2      3         4       2 2      4
+--R                          (768A B  + 64A )C - 384B  + 480A B  + 32A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                   3           3       2   2
+--R                          1792A B C  + (- 1472B  + 384A B)C
+--R                        + 
+--R                                    3        3         5       2 3       4
+--R                          (- 1664A B  + 1280A B)C - 64B  - 576A B  - 256A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5       2      2  4         2       3  3
+--R                      - 80C  + 288A C  + (96B  + 80A )C  + (64A B  + 256A )C
+--R                    + 
+--R                           4       2 2       4  2            4      3 2      5
+--R                      (432B  + 768A B  + 464A )C  + (- 160A B  + 64A B  - 32A )C
+--R                    + 
+--R                            2 4       4 2      6
+--R                      - 144A B  + 288A B  + 48A
+--R                 *
+--R                     7
+--R                    a b
+--R                + 
+--R                                4
+--R                      - 256A B D
+--R                    + 
+--R                           3         2        2       2           2  3
+--R                      (128C  - 256A C  + (384B  - 128A )C + 256A B )D
+--R                    + 
+--R                               2       3          3       3   2
+--R                      (384A B C  - 256B C - 384A B  + 128A B)D
+--R                    + 
+--R                                5         4          2       2  3
+--R                          - 128C  + 128A C  + (- 128B  - 384A )C
+--R                        + 
+--R                               4       2 2           4       3 2       5
+--R                          (640B  - 384A B )C + 256A B  + 256A B  - 128A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4       2   3          3       3   2
+--R                      128B C  - 512A B C  + 512A B C  + (128A B  - 896A B)C
+--R                    + 
+--R                             5       4            5       3 3       5
+--R                      (- 256B  + 384A B)C + 128A B  - 128A B  - 128A B
+--R                 *
+--R                     8
+--R                    a
+--R             *
+--R                c
+--R            + 
+--R                      6        5        2              2      2  4
+--R                  - 8D  + 24B D  + (- 8C  + 48A C - 24B  - 72A )D
+--R                + 
+--R                       2               3      2   3
+--R                  (8B C  - 48A B C + 8B  + 72A B)D
+--R             *
+--R                 9
+--R                b
+--R            + 
+--R                               5                      4
+--R                  (32C + 128A)D  + (- 160B C - 64A B)D
+--R                + 
+--R                      3         2        2       2          2      3  3
+--R                  (48C  - 272A C  + (160B  + 368A )C - 64A B  + 48A )D
+--R                + 
+--R                          3           2         3       2     2
+--R                  (- 32B C  + 192A B C  + (- 32B  - 288A B)C)D
+--R             *
+--R                   8
+--R                a b
+--R            + 
+--R                     6         5       2                2       2  4
+--R                  12D  - 152B D  + (40C  - 896A C + 176B  - 160A )D
+--R                + 
+--R                         2                 3      2   3
+--R                  (400B C  + 432A B C - 72B  - 72A B)D
+--R                + 
+--R                            4         3          2       2  2
+--R                      - 100C  + 544A C  + (- 336B  - 672A )C
+--R                    + 
+--R                            2       3        4       2 2      4
+--R                      (48A B  - 176A )C + 36B  + 312A B  - 12A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                        4           3       3       2   2
+--R                  (40B C  - 240A B C  + (40B  + 360A B)C )D
+--R             *
+--R                 2 7
+--R                a b
+--R            + 
+--R                               5                     4
+--R                  (96C - 280A)D  + (752B C + 608A B)D
+--R                + 
+--R                         3          2          2       2           2       3  3
+--R                  (- 296C  + 2152A C  + (- 728B  + 816A )C - 504A B  + 432A )D
+--R                + 
+--R                           3            2        3       2            3  2
+--R                  (- 464B C  - 1008A B C  + (384B  + 240A B)C - 304A B )D
+--R                + 
+--R                         5         4        2       2  3          2       3  2
+--R                      88C  - 464A C  + (272B  + 520A )C  + (192A B  + 248A )C
+--R                    + 
+--R                            4       2 2      4        3 2      5
+--R                      (- 88B  - 744A B  - 32A )C - 40A B  + 24A
+--R                 *
+--R                    D
+--R                + 
+--R                         5          4         3       2   3
+--R                  - 16B C  + 96A B C  + (- 16B  - 144A B)C
+--R             *
+--R                 3 6
+--R                a b
+--R            + 
+--R                    6         5          2                2      2  4
+--R                  8D  + 220B D  + (- 524C  + 800A C - 320B  + 68A )D
+--R                + 
+--R                            2                   3        2   3
+--R                  (- 1368B C  - 2496A B C + 408B  - 1008A B)D
+--R                + 
+--R                          4          3         2        2  2
+--R                      464C  - 2480A C  + (1176B  - 1224A )C
+--R                    + 
+--R                              2        3        4       2 2       4
+--R                      (1728A B  - 1392A )C + 24B  + 576A B  - 296A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                            4            3          3       2   2
+--R                      220B C  + 1152A B C  + (- 600B  - 624A B)C
+--R                    + 
+--R                             3       3         5       2 3       4
+--R                      (448A B  + 304A B)C + 44B  + 512A B  - 188A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6         5         2       2  4            2       3  3
+--R                  - 28C  + 144A C  + (- 72B  - 140A )C  + (- 176A B  - 144A )C
+--R                + 
+--R                      4       2 2      4  2       3 2      5       2 4     4 2
+--R                  (52B  + 432A B  + 92A )C  + (32A B  - 64A )C - 4A B  + 8A B
+--R                + 
+--R                     6
+--R                  12A
+--R             *
+--R                 4 5
+--R                a b
+--R            + 
+--R                                  5                       4
+--R                  (- 120C + 416A)D  + (- 484B C - 532A B)D
+--R                + 
+--R                       3         2         2       2           2       3  3
+--R                  (968C  - 824A C  + (1144B  + 400A )C + 856A B  + 128A )D
+--R                + 
+--R                             3            2           3        2             3
+--R                      1144B C  + 3768A B C  + (- 1336B  + 2760A B)C - 1096A B
+--R                    + 
+--R                           3
+--R                      1112A B
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                            5          4          2       2  3
+--R                      - 320C  + 1464A C  + (- 912B  + 712A )C
+--R                    + 
+--R                                2        3  2        4       2 2       4
+--R                      (- 1968A B  + 1304A )C  + (176B  - 984A B  + 760A )C
+--R                    + 
+--R                              4       3 2      5
+--R                      - 584A B  - 232A B  - 80A
+--R                 *
+--R                    D
+--R                + 
+--R                         5           4        3       2   3
+--R                  - 20B C  - 516A B C  + (280B  + 488A B)C
+--R                + 
+--R                          3       3   2         5       2 3       4           5
+--R                  (- 88A B  - 360A B)C  + (- 52B  - 552A B  + 204A B)C + 12A B
+--R                + 
+--R                       3 3      5
+--R                  - 72A B  + 12A B
+--R             *
+--R                 5 4
+--R                a b
+--R            + 
+--R                       6         5        2                 2       2  4
+--R                  - 48D  - 200B D  + (240C  - 1096A C + 232B  - 472A )D
+--R                + 
+--R                         2                  3       2   3
+--R                  (136B C  + 720A B C - 112B  + 312A B)D
+--R                + 
+--R                            4         3           2        2  2
+--R                      - 904C  + 352A C  + (- 1416B  - 1152A )C
+--R                    + 
+--R                                2       3         4        2 2       4
+--R                      (- 2160A B  - 528A )C + 480B  - 1080A B  - 296A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                              4            3         3        2   2
+--R                      - 416B C  - 2688A B C  + (1512B  - 2208A B)C
+--R                    + 
+--R                              3        3          5       2 3       4
+--R                      (2224A B  - 2336A B)C + 152B  + 824A B  - 224A B
+--R                 *
+--R                    D
+--R                + 
+--R                     6         5        2       2  4          2       3  3
+--R                  88C  - 360A C  + (264B  - 176A )C  + (880A B  - 320A )C
+--R                + 
+--R                         4       2 2       4  2          4       3 2       5
+--R                  (- 248B  + 144A B  - 472A )C  + (504A B  + 416A B  + 104A )C
+--R                + 
+--R                    6       2 4       4 2      6
+--R                  8B  + 320A B  - 136A B  - 16A
+--R             *
+--R                 6 3
+--R                a b
+--R            + 
+--R                               5                     4
+--R                  (208C - 48A)D  + (432B C + 528A B)D
+--R                + 
+--R                         3          2          2       2           2       3  3
+--R                  (- 128C  + 1104A C  + (- 576B  + 704A )C - 544A B  + 112A )D
+--R                + 
+--R                         3          2        3       2            3       3   2
+--R                  (432B C  - 96A B C  + (160B  + 528A B)C + 320A B  - 160A B)D
+--R                + 
+--R                          5        4        2       2  3           2       3  2
+--R                      448C  - 48A C  + (768B  + 928A )C  + (1776A B  + 608A )C
+--R                    + 
+--R                            4        2 2       4           4       3 2       5
+--R                    (- 1168B  + 2112A B  + 352A )C - 752A B  + 272A B  + 400A
+--R                 *
+--R                    D
+--R                + 
+--R                       5           4          3       2   3
+--R                  16B C  + 960A B C  + (- 624B  + 224A B)C
+--R                + 
+--R                            3        3   2         5       2 3      4
+--R                  (- 1120A B  + 1440A B)C  + (- 16B  - 528A B  - 48A B)C
+--R                + 
+--R                          5       3 3      5
+--R                  - 336A B  - 160A B  + 96A B
+--R             *
+--R                 7 2
+--R                a b
+--R            + 
+--R                         2              2      2  4
+--R                  (- 288C  + 64A C - 64B  + 96A )D
+--R                + 
+--R                           2                  3       2   3
+--R                  (- 256B C  - 768A B C + 128B  - 384A B)D
+--R                + 
+--R                              3        2       2  2          2      3
+--R                      - 576A C  + (576B  - 192A )C  + (384A B  - 64A )C
+--R                    + 
+--R                          2 2      4
+--R                      192A B  + 64A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                              4           3        3       2   2
+--R                      - 384B C  - 384A B C  + (128B  - 768A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 512A B  - 128A B)C + 128B  - 256A B  - 128A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6          2       2  4            2       3  3
+--R                  - 96C  + (- 192B  - 224A )C  + (- 704A B  - 256A )C
+--R                + 
+--R                       4       2 2       4  2          4       3 2       5
+--R                  (736B  - 576A B  - 160A )C  + (576A B  - 448A B  - 256A )C
+--R                + 
+--R                     6       2 4       4 2      6
+--R                  64B  + 224A B  + 128A B  - 32A
+--R             *
+--R                 8
+--R                a b
+--R            + 
+--R                       3       2          2  3            2       3        3   2
+--R                  (128C  - 128A C + 256A B )D  + (384A B C  - 256B C + 128A B)D
+--R                + 
+--R                         4       2 3       2 2          4       5           5
+--R                  (128A C  - 128B C  - 384A B C + 256A B  - 128A )D + 128B C
+--R                + 
+--R                      2   3         3 2          5       4          3 3
+--R                  512A B C  + 128A B C  + (- 256B  + 384A B)C - 128A B
+--R             *
+--R                 9
+--R                a
+--R     + 
+--R                    +-----------------+
+--R                +-+ |          2     2
+--R             2a\|2 \|- 4a c + b  + 8a
+--R          *
+--R              +-----------------------------------------+
+--R              |    +-----------------+
+--R              |    |          2     2            2     2
+--R             \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R          *
+--R              +---------------------------------------+
+--R              |  +-----------------+
+--R              |  |          2     2            2     2
+--R             \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R          *
+--R             ROOT
+--R                             3 3      2 2      4  2       3 2      5        2 4
+--R                        - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c - 12a b
+--R                      + 
+--R                             4 2      6
+--R                        - 84a b  + 96a
+--R                   *
+--R                           2
+--R                      %%BN1
+--R                  + 
+--R                                3 3      2 2      4  2       3 2      5
+--R                            - 8a c  + (2a b  - 16a )c  + (40a b  + 32a )c
+--R                          + 
+--R                                2 4      4 2      6
+--R                            - 8a b  - 56a b  + 64a
+--R                       *
+--R                          %%BN0
+--R                      + 
+--R                            2 3            2        3  2
+--R                        8D a c  + (- 2D a b  + 16D a )c
+--R                      + 
+--R                                2 2        4           4        3 2        5
+--R                        (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                   *
+--R                      %%BN1
+--R                  + 
+--R                             3 3      2 2      4  2       3 2      5        2 4
+--R                        - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c - 12a b
+--R                      + 
+--R                             4 2      6
+--R                        - 84a b  + 96a
+--R                   *
+--R                           2
+--R                      %%BN0
+--R                  + 
+--R                            2 3            2        3  2
+--R                        8D a c  + (- 2D a b  + 16D a )c
+--R                      + 
+--R                                2 2        4           4        3 2        5
+--R                        (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                   *
+--R                      %%BN0
+--R                  + 
+--R                        2 2                          2     2  2  2
+--R                    (- D b  + 4C D a b + (- 8B D - 4C  - 4A )a )c
+--R                  + 
+--R                            2   2                               2
+--R                        - 4D a b  + ((20C + 4A)D + 4B C + 4A B)a b
+--R                      + 
+--R                           2             2             2     2  3
+--R                        (8D  - 16B D - 8C  + 16A C + 8B  - 8A )a
+--R                   *
+--R                      c
+--R                  + 
+--R                      2 4            3
+--R                    4D b  - 16C D a b
+--R                  + 
+--R                         2              2            2      2  2 2
+--R                    (- 8D  + 24B D + 12C  - 8A C - 4B  + 12A )a b
+--R                  + 
+--R                                                  3        2              2  4
+--R                  ((- 8C - 24A)D - 24B C - 24A B)a b + (16D  + 32A C + 16B )a
+--R               /
+--R                      3 3       2 2     4  2         3 2      5       2 4
+--R                    4a c  + (- a b  + 8a )c  + (- 20a b  - 16a )c + 4a b
+--R                  + 
+--R                       4 2      6
+--R                    28a b  - 32a
+--R         + 
+--R           -
+--R                       +-----------------+
+--R                   +-+ |          2     2
+--R                2a\|2 \|- 4a c + b  + 8a
+--R             *
+--R                 +-----------------------------------------+
+--R                 |    +-----------------+
+--R                 |    |          2     2            2     2
+--R                \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R             *
+--R                 +---------------------------------------+
+--R                 |  +-----------------+
+--R                 |  |          2     2            2     2
+--R                \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a  %%BN1
+--R         + 
+--R                       +-----------------+               +-----------------+
+--R                   +-+ |          2     2            +-+ |          2     2
+--R             (- 2a\|2 \|- 4a c + b  + 8a  %%BN0 + 2D\|2 \|- 4a c + b  + 8a  )
+--R          *
+--R              +-----------------------------------------+
+--R              |    +-----------------+
+--R              |    |          2     2            2     2
+--R             \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R          *
+--R              +---------------------------------------+
+--R              |  +-----------------+
+--R              |  |          2     2            2     2
+--R             \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R         log
+--R                                 2 4 8
+--R                          - 32A D a c
+--R                        + 
+--R                                   2 3 2       3        2  4
+--R                              16A D a b  + (16D  + 16B D )a b
+--R                            + 
+--R                                       2                   2      3  5
+--R                              (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                         *
+--R                             7
+--R                            c
+--R                        + 
+--R                                    2 2 4        3       2  3 3
+--R                              - 2A D a b  + (- 8D  - 8B D )a b
+--R                            + 
+--R                                              2                  2      3  4 2
+--R                              ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                            + 
+--R                                     3        2
+--R                                  32D  - 32B D
+--R                                + 
+--R                                      2               2       2          2
+--R                                  (48C  - 224A C - 64B  - 144A )D - 16B C
+--R                                + 
+--R                                                 2
+--R                                  - 96A B C + 48A B
+--R                             *
+--R                                 5
+--R                                a b
+--R                            + 
+--R                                        2                 3         2      2
+--R                                  128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                                + 
+--R                                          2       3
+--R                                  - 128A B  - 128A
+--R                             *
+--R                                 6
+--R                                a
+--R                         *
+--R                             6
+--R                            c
+--R                        + 
+--R                                3      2  2 5
+--R                              (D  + B D )a b
+--R                            + 
+--R                                            2                2     3  3 4
+--R                              ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                            + 
+--R                                        3         2
+--R                                  - 160D  - 128B D
+--R                                + 
+--R                                        2               2      2         2
+--R                                  (- 24C  + 112A C + 32B  + 72A )D + 8B C
+--R                                + 
+--R                                               2
+--R                                  48A B C - 24A B
+--R                             *
+--R                                 4 3
+--R                                a b
+--R                            + 
+--R                                                 2                           3
+--R                                  (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                                + 
+--R                                          2       2      2           2       3
+--R                                  - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                             *
+--R                                 5 2
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 128D  - 256B D
+--R                                + 
+--R                                       2               2       2           2
+--R                                  (384C  - 512A C - 64B  - 384A )D + 128B C
+--R                                + 
+--R                                     3       2
+--R                                  64B  + 384A B
+--R                             *
+--R                                 6
+--R                                a b
+--R                            + 
+--R                                         2                  3         2       2
+--R                                  1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                                + 
+--R                                          2       3
+--R                                  - 512A B  + 128A
+--R                             *
+--R                                 7
+--R                                a
+--R                         *
+--R                             5
+--R                            c
+--R                        + 
+--R                                           2 2 6
+--R                              (- 2C + 22A)D a b
+--R                            + 
+--R                                     3        2      2             2     2
+--R                                  70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D
+--R                                + 
+--R                                       2              2
+--R                                  - B C  - 6A B C + 3A B
+--R                             *
+--R                                 3 5
+--R                                a b
+--R                            + 
+--R                                                 2                            3
+--R                                  (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                                + 
+--R                                        2         2      2          2       3
+--R                                  120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                             *
+--R                                 4 4
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  224D  + 800B D
+--R                                + 
+--R                                         2                 2        2          2
+--R                                  (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                                + 
+--R                                                3       2
+--R                                  672A B C - 64B  - 720A B
+--R                             *
+--R                                 5 3
+--R                                a b
+--R                            + 
+--R                                                   2
+--R                                  (- 160C - 2976A)D  + (- 576B C - 1088A B)D
+--R                                + 
+--R                                      3         2          2       2
+--R                                  608C  - 416A C  + (- 288B  - 992A )C
+--R                                + 
+--R                                         2      3
+--R                                  1120A B  + 32A
+--R                             *
+--R                                 6 2
+--R                                a b
+--R                            + 
+--R                                        3         2
+--R                                  - 256D  + 256B D
+--R                                + 
+--R                                       2                 2       2           2
+--R                                  (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                                + 
+--R                                                  3       2
+--R                                  1152A B C + 128B  + 192A B
+--R                             *
+--R                                 7
+--R                                a b
+--R                            + 
+--R                                        2                   3          2
+--R                                  512A D  - 4096A B D + 256C  - 1024A C
+--R                                + 
+--R                                        2          2        3
+--R                                  - 256A C + 512A B  + 1024A
+--R                             *
+--R                                 8
+--R                                a
+--R                         *
+--R                             4
+--R                            c
+--R                        + 
+--R                                   3       2  2 7
+--R                              (- 8D  - 8B D )a b
+--R                            + 
+--R                                                  2                      3
+--R                                  (- 141C + 755A)D  + (6B C - 58A B)D + C
+--R                                + 
+--R                                         2      2     2         2      3
+--R                                  - 13A C  + (3B  + 3A )C + 3A B  + 17A
+--R                             *
+--R                                 3 6
+--R                                a b
+--R                            + 
+--R                                      3        2
+--R                                  284D  + 36B D
+--R                                + 
+--R                                       2                2       2          2
+--R                                  (276C  - 888A C - 228B  - 588A )D - 12B C
+--R                                + 
+--R                                                  3       2
+--R                                  - 312A B C + 20B  + 276A B
+--R                             *
+--R                                 4 5
+--R                                a b
+--R                            + 
+--R                                                2
+--R                                  (32C + 2016A)D  + (- 192B C + 3072A B)D
+--R                                + 
+--R                                        3         2         2       2
+--R                                  - 320C  + 720A C  + (- 96B  + 192A )C
+--R                                + 
+--R                                          2       3
+--R                                  - 672A B  - 848A
+--R                             *
+--R                                 5 4
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  896D  + 384B D
+--R                                + 
+--R                                          2                 2       2
+--R                                  (- 1344C  - 1408A C - 896B  - 576A )D
+--R                                + 
+--R                                           2                   3        2
+--R                                  - 1088B C  - 1920A B C - 384B  - 1344A B
+--R                             *
+--R                                 6 3
+--R                                a b
+--R                            + 
+--R                                                 2
+--R                                  (640C - 4224A)D  + (- 768B C + 8448A B)D
+--R                                + 
+--R                                      3          2          2       2
+--R                                  128C  + 1920A C  + (- 384B  - 640A )C
+--R                                + 
+--R                                        2        3
+--R                                  128A B  - 2432A
+--R                             *
+--R                                 7 2
+--R                                a b
+--R                            + 
+--R                                      3          2
+--R                                  256D  + 1280B D
+--R                                + 
+--R                                          2                 2        2
+--R                                  (- 3072C  + 4096A C + 512B  + 3072A )D
+--R                                + 
+--R                                           2       3        2
+--R                                  - 1024B C  - 512B  - 3072A B
+--R                             *
+--R                                 8
+--R                                a b
+--R                            + 
+--R                                           2                    3         2
+--R                                  - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                                + 
+--R                                         2           2       3
+--R                                  - 2048A C + 4096A B  + 512A
+--R                             *
+--R                                 9
+--R                                a
+--R                         *
+--R                             3
+--R                            c
+--R                        + 
+--R                                          2 2 8
+--R                              (16C - 80A)D a b
+--R                            + 
+--R                                        3         2
+--R                                  - 146D  - 118B D
+--R                                + 
+--R                                        2               2      2         2
+--R                                  (- 30C  + 100A C + 26B  + 66A )D + 2B C
+--R                                + 
+--R                                              3      2
+--R                                  36A B C - 2B  - 30A B
+--R                             *
+--R                                 3 7
+--R                                a b
+--R                            + 
+--R                                                   2
+--R                                  (- 726C + 2090A)D  + (180B C - 1100A B)D
+--R                                + 
+--R                                     3         2       2      2           2
+--R                                  62C  - 230A C  + (90B  + 58A )C + 154A B
+--R                                + 
+--R                                      3
+--R                                  350A
+--R                             *
+--R                                 4 6
+--R                                a b
+--R                            + 
+--R                                         3          2
+--R                                  - 1752D  - 2760B D
+--R                                + 
+--R                                        2                 2        2           2
+--R                                  (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                                + 
+--R                                                   3        2
+--R                                  - 576A B C + 312B  + 2160A B
+--R                             *
+--R                                 5 5
+--R                                a b
+--R                            + 
+--R                                         2                              3
+--R                                  8160A D  + (4608B C - 5376A B)D - 864C
+--R                                + 
+--R                                          2         2        2           2
+--R                                  - 192A C  + (2304B  + 3936A )C - 960A B
+--R                                + 
+--R                                       3
+--R                                  3264A
+--R                             *
+--R                                 6 4
+--R                                a b
+--R                            + 
+--R                                         3          2
+--R                                  - 1152D  - 4224B D
+--R                                + 
+--R                                        2                   2        2
+--R                                  (5760C  - 11520A C - 2304B  - 8064A )D
+--R                                + 
+--R                                         2                   3        2
+--R                                  1152B C  - 2304A B C + 768B  + 5760A B
+--R                             *
+--R                                 7 3
+--R                                a b
+--R                            + 
+--R                                                  2
+--R                                  (2816C + 4352A)D  + (4608B C + 7680A B)D
+--R                                + 
+--R                                         3          2         2        2
+--R                                  - 3840C  + 3072A C  + (2304B  + 6912A )C
+--R                                + 
+--R                                           2
+--R                                  - 6912A B
+--R                             *
+--R                                 8 2
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  512D  - 512B D
+--R                                + 
+--R                                          2                  2       2
+--R                                  (- 3840C  - 2560A C - 2048B  - 768A )D
+--R                                + 
+--R                                           2                    3        2
+--R                                  - 2816B C  - 4608A B C - 1024B  - 3840A B
+--R                             *
+--R                                 9
+--R                                a b
+--R                            + 
+--R                                           2                    3          2
+--R                                  - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                                + 
+--R                                         2           2        3
+--R                                  - 1024A C + 2048A B  - 2048A
+--R                             *
+--R                                 10
+--R                                a
+--R                         *
+--R                             2
+--R                            c
+--R                        + 
+--R                                  3        2  2 9
+--R                              (16D  + 16B D )a b
+--R                            + 
+--R                                                2                           3
+--R                                  (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                                + 
+--R                                       2         2      2          2      3
+--R                                  20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                             *
+--R                                 3 8
+--R                                a b
+--R                            + 
+--R                                      3         2
+--R                                  456D  + 920B D
+--R                                + 
+--R                                         2                 2        2
+--R                                  (- 744C  + 1712A C + 376B  + 1176A )D
+--R                                + 
+--R                                          2                 3       2
+--R                                  - 104B C  + 432A B C - 88B  - 744A B
+--R                             *
+--R                                 4 7
+--R                                a b
+--R                            + 
+--R                                                  2
+--R                                  (1668C - 8316A)D  + (- 1656B C + 136A B)D
+--R                                + 
+--R                                      3         2          2        2
+--R                                  364C  - 380A C  + (- 828B  - 1468A )C
+--R                                + 
+--R                                        2       3
+--R                                  452A B  - 724A
+--R                             *
+--R                                 5 6
+--R                                a b
+--R                            + 
+--R                                       3          2
+--R                                  2496D  + 6432B D
+--R                                + 
+--R                                          2                   2        2
+--R                                  (- 5328C  + 14304A C + 3408B  + 9648A )D
+--R                                + 
+--R                                          2                   3        2
+--R                                  - 336B C  + 4320A B C - 528B  - 5328A B
+--R                             *
+--R                                 6 5
+--R                                a b
+--R                            + 
+--R                                                    2
+--R                                  (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                                + 
+--R                                       3          2           2         2
+--R                                  3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                                + 
+--R                                         2        3
+--R                                  4224A B  - 2976A
+--R                             *
+--R                                 7 4
+--R                                a b
+--R                            + 
+--R                                         3         2
+--R                                  - 1024D  + 512B D
+--R                                + 
+--R                                        2                  2        2
+--R                                  (5760C  + 3840A C + 3072B  + 1152A )D
+--R                                + 
+--R                                         2                    3        2
+--R                                  4224B C  + 6912A B C + 1536B  + 5760A B
+--R                             *
+--R                                 8 3
+--R                                a b
+--R                            + 
+--R                                                    2
+--R                                  (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                                + 
+--R                                         3          2        2        2
+--R                                  - 1280C  - 2816A C  + (768B  + 2304A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 2304A B  + 3840A
+--R                             *
+--R                                 9 2
+--R                                a b
+--R                            + 
+--R                                           2
+--R                                  - 2048B D
+--R                                + 
+--R                                        2                  2        2
+--R                                  (6144C  - 8192A C - 1024B  - 6144A )D
+--R                                + 
+--R                                         2        3        2
+--R                                  2048B C  + 1024B  + 6144A B
+--R                             *
+--R                                 10
+--R                                a  b
+--R                            + 
+--R                                                   3          2        2
+--R                                  8192A B D - 4096C  + 2048A C  + 4096A C
+--R                                + 
+--R                                           2        3
+--R                                  - 8192A B  - 2048A
+--R                             *
+--R                                 11
+--R                                a
+--R                         *
+--R                            c
+--R                        + 
+--R                                        2 2 10
+--R                          (- 32C + 96A)D a b
+--R                        + 
+--R                                   3        2       2               2       2
+--R                              - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                            + 
+--R                                  2               3      2
+--R                              8B C  - 48A B C + 8B  + 72A B
+--R                         *
+--R                             3 9
+--R                            a b
+--R                        + 
+--R                                               2                           3
+--R                              (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                            + 
+--R                                   2       2       2          2      3
+--R                              72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                         *
+--R                             4 8
+--R                            a b
+--R                        + 
+--R                                    3          2
+--R                              - 360D  - 1080B D
+--R                            + 
+--R                                   2                 2        2          2
+--R                              (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                            + 
+--R                                              3       2
+--R                              - 816A B C + 88B  + 936A B
+--R                         *
+--R                             5 7
+--R                            a b
+--R                        + 
+--R                                            2                              3
+--R                              (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                            + 
+--R                                     2         2        2           2       3
+--R                              1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                         *
+--R                             6 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 3456B D
+--R                            + 
+--R                                    2                  2        2           2
+--R                              (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                            + 
+--R                                               3        2
+--R                              - 3744A B C - 96B  + 1296A B
+--R                         *
+--R                             7 5
+--R                            a b
+--R                        + 
+--R                                              2                              3
+--R                              (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                            + 
+--R                                     2         2        2           2        3
+--R                              3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                         *
+--R                             8 4
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1536D  + 4608B D
+--R                            + 
+--R                                       2                   2        2
+--R                              (- 11520C  + 12800A C + 1024B  + 9984A )D
+--R                            + 
+--R                                       2                    3         2
+--R                              - 4352B C  - 1536A B C - 2048B  - 11520A B
+--R                         *
+--R                             9 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              5632C  - 4608A C  + (- 4608B  - 11776A )C
+--R                            + 
+--R                                     2        3
+--R                              9728A B  - 1536A
+--R                         *
+--R                             10 2
+--R                            a  b
+--R                        + 
+--R                                    2                  2        2            2
+--R                              (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                            + 
+--R                                               3        2
+--R                              6144A B C + 2048B  + 9216A B
+--R                         *
+--R                             11
+--R                            a  b
+--R                        + 
+--R                                  3        2           2  12
+--R                          (- 4096C  + 4096A C - 8192A B )a
+--R                     *
+--R                        %%BN0
+--R                    + 
+--R                           3 3 8
+--R                      16A D a c
+--R                    + 
+--R                                3 2 2          3          2  3
+--R                          - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                        + 
+--R                                         3          2         2      3    4
+--R                          ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                               3         2  2 3
+--R                          (2B D  + 6A C D )a b
+--R                        + 
+--R                                             3                   2
+--R                                (12C - 188A)D  + (12B C + 52A B)D
+--R                              + 
+--R                                     2      3
+--R                                (4A C  - 12A )D
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                 4        3       2              2       2  2
+--R                              24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                            + 
+--R                                     2                2          3     3
+--R                              (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                            3                    2
+--R                              (- 64C - 32A)D  + (96B C - 320A B)D
+--R                            + 
+--R                                    3        2       2          2      3
+--R                              (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                            + 
+--R                                       2      3
+--R                              - 48A B C  - 16A B
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                           3                   2
+--R                              (- 2C + 41A)D  + (- 3B C - 8A B)D
+--R                            + 
+--R                                     2     3
+--R                              (- 2A C  + 2A )D
+--R                         *
+--R                             2 4
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 14D  + 80B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 18C  + 224A C - 26B  - 66A )D
+--R                            + 
+--R                                     2                2          3     3
+--R                              (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                            3                       2
+--R                              (144C - 232A)D  + (- 120B C + 808A B)D
+--R                            + 
+--R                                    3         2         2      2           2
+--R                                  4C  - 212A C  + (- 24B  + 20A )C - 112A B
+--R                                + 
+--R                                        3
+--R                                  - 196A
+--R                             *
+--R                                D
+--R                            + 
+--R                                  3          2      2        3
+--R                              4B C  + 36A B C  - 12A B C + 4A B
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                 4        3       2              2       2  2
+--R                              64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                            + 
+--R                                      2                3       2        4
+--R                              (- 80B C  + 96A B C - 64B  - 336A B)D + 8C
+--R                            + 
+--R                                   3       2      2  2         2      3
+--R                              32A C  + (24B  + 48A )C  + (48A B  + 32A )C
+--R                            + 
+--R                                 2 2     4
+--R                              24A B  + 8A
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                      3                     2
+--R                              - 384A D  + (384B C + 128A B)D
+--R                            + 
+--R                                    3         2          2       2           2
+--R                              (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                            + 
+--R                                   3           2       2           3      3
+--R                              64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                4        3      2             2     2  2
+--R                              2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                            + 
+--R                                  2              2
+--R                              (B C  + 6A B C - 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                            + 
+--R                                 3       2       2      2          2       3
+--R                              (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                            + 
+--R                                   3         2     2
+--R                              - B C  - 6A B C  + 3A B C
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    4        3
+--R                              - 224D  + 92B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 162C  - 280A C - 320B  - 1206A )D
+--R                            + 
+--R                                     2                 3       2        4
+--R                              (172B C  - 336A B C + 60B  + 492A B)D - 6C
+--R                            + 
+--R                                   3         2      2  2           2      3
+--R                              48A C  + (- 18B  - 24A )C  + (- 24A B  - 80A )C
+--R                            + 
+--R                                  2 2     4
+--R                              - 6A B  - 2A
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             3                       2
+--R                              (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                            + 
+--R                                      3         2        2        2            2
+--R                                  208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                                + 
+--R                                     3
+--R                                  64A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3           2         3       2           3
+--R                              - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                            + 
+--R                                  3
+--R                              144A B
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                   4         3
+--R                              - 64D  - 256B D
+--R                            + 
+--R                                     2               2       2  2
+--R                              (- 144C  - 608A C + 32B  - 336A )D
+--R                            + 
+--R                                      2      3       2         4        3
+--R                              (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                            + 
+--R                                    2      2  2         2       3        4
+--R                              (- 48B  - 96A )C  + (96A B  - 224A )C + 32B
+--R                            + 
+--R                                  2 2      4
+--R                              144A B  + 16A
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                            3            2
+--R                              (256C - 256A)D  + 1792A B D
+--R                            + 
+--R                                       3         2          2      2           2
+--R                                  - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                                + 
+--R                                        3
+--R                                  - 256A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3       2            3
+--R                              256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                            + 
+--R                                   3
+--R                              - 64A B
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                           3                   2
+--R                              (13C - 139A)D  + (18B C + 58A B)D
+--R                            + 
+--R                                  3        2        2     2         2      3
+--R                              (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              109D  - 265B D
+--R                            + 
+--R                                   2                2       2  2
+--R                              (114C  - 591A C + 183B  + 543A )D
+--R                            + 
+--R                                      2                 3       2       4
+--R                              (- 27B C  + 228A B C - 19B  - 225A B)D + C
+--R                            + 
+--R                                     3      2     2  2        2      3
+--R                              - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                            + 
+--R                                       3         2         2       2           2
+--R                                  - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                                + 
+--R                                      3
+--R                                  346A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2       3       2          3
+--R                              10B C  - 234A B C  + (14B  + 174A B)C - 2A B
+--R                            + 
+--R                                   3
+--R                              - 30A B
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    3        2               2       2  2
+--R                              768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                            + 
+--R                                     2                 3        2            3
+--R                              (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                            + 
+--R                                    2       2  2            2       3        4
+--R                              (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                            + 
+--R                                    2 2      4
+--R                              - 240A B  - 64A
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               3                        2
+--R                              (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                            + 
+--R                                      3         2         2        2           2
+--R                                  416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                                + 
+--R                                      3
+--R                                  992A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3        2
+--R                              - 480B C  + 672A B C  + (- 128B  - 1632A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  + 160A B
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 256D  + 384B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (192C  - 1024A C + 256B  - 2112A )D
+--R                            + 
+--R                                     2                  3        2          4
+--R                              (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                            + 
+--R                                     2       2  2            2       3
+--R                              (- 576B  - 384A )C  + (- 384A B  - 512A )C
+--R                            + 
+--R                                  2 2      4
+--R                              192A B  + 64A
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                            3                         2
+--R                              (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                            + 
+--R                                     2        2           2       3         3
+--R                            (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                   4        3
+--R                              - 14D  + 54B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 18C  + 140A C - 26B  - 66A )D
+--R                            + 
+--R                                     2               3      2
+--R                              (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                            3                      2
+--R                              (142C - 688A)D  + (- 54B C + 800A B)D
+--R                            + 
+--R                                      3         2         2      2           2
+--R                                  - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                                + 
+--R                                        3
+--R                                  - 248A
+--R                             *
+--R                                D
+--R                            + 
+--R                                  3          2        3      2
+--R                              2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              416D  - 190B D
+--R                            + 
+--R                                  2                 2        2  2
+--R                              (84C  + 1254A C + 438B  + 2514A )D
+--R                            + 
+--R                                       2                  3        2         4
+--R                              (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                            + 
+--R                                     3       2       2  2          2       3
+--R                              - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C
+--R                            + 
+--R                                4      2 2      4
+--R                              2B  + 48A B  + 14A
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                            + 
+--R                                        3        2           2        2
+--R                                  - 788C  - 84A C  + (- 2292B  - 4428A )C
+--R                                + 
+--R                                         2        3
+--R                                  1404A B  - 2252A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3        2            3
+--R                              532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                            + 
+--R                                    3
+--R                              - 308A B
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              608D  - 640B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 240C  + 3552A C - 960B  + 5232A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 1632B C  - 1536A B C - 928B  - 1632A B)D
+--R                            + 
+--R                                  4         3        2        2  2
+--R                              464C  + 128A C  + (912B  + 1344A )C
+--R                            + 
+--R                                     2        3         4       2 2      4
+--R                              (384A B  + 1664A )C - 160B  - 528A B  - 16A
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                3                       2
+--R                              (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                            + 
+--R                                        3         2        2        2
+--R                                  - 128C  - 576A C  + (192B  - 6144A )C
+--R                                + 
+--R                                         2       3
+--R                                  4800A B  - 704A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2          3       2
+--R                              256B C  + 768A B C  + (- 704B  - 384A B)C
+--R                            + 
+--R                                    3       3
+--R                              448A B  - 128A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 128D  + 1280B D
+--R                            + 
+--R                                   2                 2       2  2
+--R                              (768C  + 2560A C - 640B  - 768A )D
+--R                            + 
+--R                                     2                   2          4         3
+--R                              (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                            + 
+--R                                     2       2  2            2       3         4
+--R                              (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 128A
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                    3                         2
+--R                              512A D  + (- 1536B C - 2048A B)D
+--R                            + 
+--R                                        3          2         2        2
+--R                                    256C  - 2048A C  + (3072B  + 1792A )C
+--R                                  + 
+--R                                             2
+--R                                    - 2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3           2        2             3
+--R                              - 1024B C  + 768A B C  - 3072A B C + 1024A B
+--R                            + 
+--R                                  3
+--R                              256A B
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                             3                      2
+--R                              (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                            + 
+--R                                 3        2       2      2          2      3
+--R                              (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 204D  + 316B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 144C  + 364A C - 292B  - 1092A )D
+--R                            + 
+--R                                     2                 3       2        4
+--R                              (164B C  - 288A B C + 84B  + 636A B)D - 4C
+--R                            + 
+--R                                   3         2      2  2           2      3
+--R                              20A C  + (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                            3                         2
+--R                              (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                            + 
+--R                                      3          2        2        2           2
+--R                                  428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                                + 
+--R                                      3
+--R                                  996A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2         3       2          3
+--R                              - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                            + 
+--R                                 3
+--R                              56A B
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 924D  - 588B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (216C  - 5556A C - 60B  - 6156A )D
+--R                            + 
+--R                                      2                   3        2          4
+--R                              (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                            + 
+--R                                    3          2       2  2         2        3
+--R                              708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                            + 
+--R                                 4       2 2       4
+--R                              72B  + 576A B  + 120A
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                            + 
+--R                                      3          2        2        2
+--R                                  408C  + 2760A C  + (504B  + 9096A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 3720A B  + 2904A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3            2        3       2
+--R                              - 840B C  - 1656A B C  + (168B  + 360A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 792A B  + 408A B
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              480D  - 1536B D
+--R                            + 
+--R                                     2                  2        2  2
+--R                              (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                            + 
+--R                                        2                  3        2          4
+--R                              (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                            + 
+--R                                      3        2        2  2
+--R                              - 864A C  + (576B  - 2304A )C
+--R                            + 
+--R                                      2        3         4       2 2       4
+--R                              (1152A B  - 2208A )C + 576B  + 576A B  - 384A
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                               3                       2
+--R                              (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                            + 
+--R                                         3          2           2        2
+--R                                  - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                                + 
+--R                                         2        3
+--R                                  2304A B  - 1344A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3            2        2             3
+--R                              1344B C  - 1728A B C  + 5184A B C - 1536A B
+--R                            + 
+--R                                    3
+--R                              - 192A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                    3           2                  2        2  2
+--R                              512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                            + 
+--R                                        2                   2          4
+--R                              (- 1280B C  - 4608A B C + 768A B)D + 640C
+--R                            + 
+--R                                      3         2       2  2
+--R                              - 512A C  + (1920B  + 768A )C
+--R                            + 
+--R                                     2        3          2 2       4
+--R                              (768A B  + 1536A )C - 1152A B  - 384A
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                         2
+--R                              - 2048A B D
+--R                            + 
+--R                                       3          2         2        2
+--R                                  1024C  - 2048A C  + (3072B  - 1024A )C
+--R                                + 
+--R                                         2
+--R                                  2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3            2           3        2
+--R                              - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                            + 
+--R                                     3        3
+--R                              1024A B  + 1024A B
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                             4        3       2               2       2  2
+--R                          24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 8C - 336A)D  + (216B C + 96A B)D
+--R                        + 
+--R                                   3         2          2       2          2
+--R                              - 56C  + 240A C  + (- 120B  - 184A )C + 80A B
+--R                            + 
+--R                                   3
+--R                              - 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2      3      2
+--R                          8B C  - 48A B C  + (8B  + 72A B)C
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              4         3       2               2        2  2
+--R                          216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                        + 
+--R                                   2                3       2         4
+--R                          (- 304B C  - 48A B C - 64B  - 384A B)D + 32C
+--R                        + 
+--R                                  3       2      2  2           2       3
+--R                          - 120A C  + (72B  + 24A )C  + (- 24A B  + 152A )C
+--R                        + 
+--R                              4      2 2      4
+--R                          - 8B  - 96A B  - 24A
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                        + 
+--R                                    3          2          2        2           2
+--R                              - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                            + 
+--R                                    3
+--R                              - 864A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2      3       2            3      3
+--R                        120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          144D  + 1848B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 576C  + 6600A C - 984B  + 1800A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                        + 
+--R                                  3        2       2  2            2        3
+--R                          - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 120B  - 576A B  - 72A
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                        + 
+--R                                   3          2         2        2           2
+--R                              1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                            + 
+--R                                    3
+--R                              - 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2          3        2             3
+--R                          384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                        + 
+--R                                3
+--R                          - 240A B
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 384D  - 1600B D
+--R                        + 
+--R                                2                  2        2  2
+--R                          (2784C  - 7040A C + 1280B  - 3936A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                        + 
+--R                                 3           2        2  2
+--R                          2304A C  + (- 2592B  + 1152A )C
+--R                        + 
+--R                                    2       3         4        2 2       4
+--R                          (- 1152A B  - 768A )C - 384B  + 1440A B  + 864A
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1792C  + 5376A C  + (- 2688B  + 5632A )C
+--R                            + 
+--R                                       2        3
+--R                              - 3200A B  + 1536A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2         3        2
+--R                          - 512B C  - 6144A B C  + (2176B  + 2304A B)C
+--R                        + 
+--R                                   3       3
+--R                          - 1152A B  - 768A B
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                2       2  2
+--R                          (- 2304C  + 512A C - 512B  + 768A )D
+--R                        + 
+--R                                    2                    3        2          4
+--R                          (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                        + 
+--R                                   3         2        2  2           2       3
+--R                          - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          512B  - 768A B  - 768A
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                                3        2           2              2        3
+--R                          (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                        + 
+--R                               3
+--R                          1024A B
+--R                     *
+--R                         11
+--R                        a
+--R                 *
+--R                    %%BN1
+--R                + 
+--R                           3 3 8
+--R                      16A D a c
+--R                    + 
+--R                                3 2 2          3          2  3
+--R                          - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                        + 
+--R                                         3          2         2      3    4
+--R                          ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                               3         2  2 3
+--R                          (2B D  + 6A C D )a b
+--R                        + 
+--R                                             3                   2
+--R                                (12C - 188A)D  + (12B C + 52A B)D
+--R                              + 
+--R                                     2      3
+--R                                (4A C  - 12A )D
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                 4        3       2              2       2  2
+--R                              24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                            + 
+--R                                     2                2          3     3
+--R                              (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                            3                    2
+--R                              (- 64C - 32A)D  + (96B C - 320A B)D
+--R                            + 
+--R                                    3        2       2          2      3
+--R                              (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                            + 
+--R                                       2      3
+--R                              - 48A B C  - 16A B
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                           3                   2
+--R                              (- 2C + 41A)D  + (- 3B C - 8A B)D
+--R                            + 
+--R                                     2     3
+--R                              (- 2A C  + 2A )D
+--R                         *
+--R                             2 4
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 14D  + 80B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 18C  + 224A C - 26B  - 66A )D
+--R                            + 
+--R                                     2                2          3     3
+--R                              (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                            3                       2
+--R                              (144C - 232A)D  + (- 120B C + 808A B)D
+--R                            + 
+--R                                    3         2         2      2           2
+--R                                  4C  - 212A C  + (- 24B  + 20A )C - 112A B
+--R                                + 
+--R                                        3
+--R                                  - 196A
+--R                             *
+--R                                D
+--R                            + 
+--R                                  3          2      2        3
+--R                              4B C  + 36A B C  - 12A B C + 4A B
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                 4        3       2              2       2  2
+--R                              64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                            + 
+--R                                      2                3       2        4
+--R                              (- 80B C  + 96A B C - 64B  - 336A B)D + 8C
+--R                            + 
+--R                                   3       2      2  2         2      3
+--R                              32A C  + (24B  + 48A )C  + (48A B  + 32A )C
+--R                            + 
+--R                                 2 2     4
+--R                              24A B  + 8A
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                      3                     2
+--R                              - 384A D  + (384B C + 128A B)D
+--R                            + 
+--R                                    3         2          2       2           2
+--R                              (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                            + 
+--R                                   3           2       2           3      3
+--R                              64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                4        3      2             2     2  2
+--R                              2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                            + 
+--R                                  2              2
+--R                              (B C  + 6A B C - 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                            + 
+--R                                 3       2       2      2          2       3
+--R                              (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                            + 
+--R                                   3         2     2
+--R                              - B C  - 6A B C  + 3A B C
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    4        3
+--R                              - 224D  + 92B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 162C  - 280A C - 320B  - 1206A )D
+--R                            + 
+--R                                     2                 3       2        4
+--R                              (172B C  - 336A B C + 60B  + 492A B)D - 6C
+--R                            + 
+--R                                   3         2      2  2           2      3
+--R                              48A C  + (- 18B  - 24A )C  + (- 24A B  - 80A )C
+--R                            + 
+--R                                  2 2     4
+--R                              - 6A B  - 2A
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             3                       2
+--R                              (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                            + 
+--R                                      3         2        2        2            2
+--R                                  208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                                + 
+--R                                     3
+--R                                  64A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3           2         3       2           3
+--R                              - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                            + 
+--R                                  3
+--R                              144A B
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                   4         3
+--R                              - 64D  - 256B D
+--R                            + 
+--R                                     2               2       2  2
+--R                              (- 144C  - 608A C + 32B  - 336A )D
+--R                            + 
+--R                                      2      3       2         4        3
+--R                              (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                            + 
+--R                                    2      2  2         2       3        4
+--R                              (- 48B  - 96A )C  + (96A B  - 224A )C + 32B
+--R                            + 
+--R                                  2 2      4
+--R                              144A B  + 16A
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                            3            2
+--R                              (256C - 256A)D  + 1792A B D
+--R                            + 
+--R                                       3         2          2      2           2
+--R                                  - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                                + 
+--R                                        3
+--R                                  - 256A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3       2            3
+--R                              256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                            + 
+--R                                   3
+--R                              - 64A B
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                           3                   2
+--R                              (13C - 139A)D  + (18B C + 58A B)D
+--R                            + 
+--R                                  3        2        2     2         2      3
+--R                              (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              109D  - 265B D
+--R                            + 
+--R                                   2                2       2  2
+--R                              (114C  - 591A C + 183B  + 543A )D
+--R                            + 
+--R                                      2                 3       2       4
+--R                              (- 27B C  + 228A B C - 19B  - 225A B)D + C
+--R                            + 
+--R                                     3      2     2  2        2      3
+--R                              - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                            + 
+--R                                       3         2         2       2           2
+--R                                  - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                                + 
+--R                                      3
+--R                                  346A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2       3       2          3
+--R                              10B C  - 234A B C  + (14B  + 174A B)C - 2A B
+--R                            + 
+--R                                   3
+--R                              - 30A B
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    3        2               2       2  2
+--R                              768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                            + 
+--R                                     2                 3        2            3
+--R                              (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                            + 
+--R                                    2       2  2            2       3        4
+--R                              (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                            + 
+--R                                    2 2      4
+--R                              - 240A B  - 64A
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               3                        2
+--R                              (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                            + 
+--R                                      3         2         2        2           2
+--R                                  416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                                + 
+--R                                      3
+--R                                  992A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3        2
+--R                              - 480B C  + 672A B C  + (- 128B  - 1632A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  + 160A B
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 256D  + 384B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (192C  - 1024A C + 256B  - 2112A )D
+--R                            + 
+--R                                     2                  3        2          4
+--R                              (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                            + 
+--R                                     2       2  2            2       3
+--R                              (- 576B  - 384A )C  + (- 384A B  - 512A )C
+--R                            + 
+--R                                  2 2      4
+--R                              192A B  + 64A
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                            3                         2
+--R                              (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                            + 
+--R                                     2        2           2       3         3
+--R                            (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                   4        3
+--R                              - 14D  + 54B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 18C  + 140A C - 26B  - 66A )D
+--R                            + 
+--R                                     2               3      2
+--R                              (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                            3                      2
+--R                              (142C - 688A)D  + (- 54B C + 800A B)D
+--R                            + 
+--R                                      3         2         2      2           2
+--R                                  - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                                + 
+--R                                        3
+--R                                  - 248A
+--R                             *
+--R                                D
+--R                            + 
+--R                                  3          2        3      2
+--R                              2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              416D  - 190B D
+--R                            + 
+--R                                  2                 2        2  2
+--R                              (84C  + 1254A C + 438B  + 2514A )D
+--R                            + 
+--R                                       2                  3        2         4
+--R                              (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                            + 
+--R                                     3       2       2  2          2       3
+--R                              - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C
+--R                            + 
+--R                                4      2 2      4
+--R                              2B  + 48A B  + 14A
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                            + 
+--R                                        3        2           2        2
+--R                                  - 788C  - 84A C  + (- 2292B  - 4428A )C
+--R                                + 
+--R                                         2        3
+--R                                  1404A B  - 2252A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3        2            3
+--R                              532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                            + 
+--R                                    3
+--R                              - 308A B
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              608D  - 640B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 240C  + 3552A C - 960B  + 5232A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 1632B C  - 1536A B C - 928B  - 1632A B)D
+--R                            + 
+--R                                  4         3        2        2  2
+--R                              464C  + 128A C  + (912B  + 1344A )C
+--R                            + 
+--R                                     2        3         4       2 2      4
+--R                              (384A B  + 1664A )C - 160B  - 528A B  - 16A
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                3                       2
+--R                              (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                            + 
+--R                                        3         2        2        2
+--R                                  - 128C  - 576A C  + (192B  - 6144A )C
+--R                                + 
+--R                                         2       3
+--R                                  4800A B  - 704A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2          3       2
+--R                              256B C  + 768A B C  + (- 704B  - 384A B)C
+--R                            + 
+--R                                    3       3
+--R                              448A B  - 128A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 128D  + 1280B D
+--R                            + 
+--R                                   2                 2       2  2
+--R                              (768C  + 2560A C - 640B  - 768A )D
+--R                            + 
+--R                                     2                   2          4         3
+--R                              (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                            + 
+--R                                     2       2  2            2       3         4
+--R                              (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 128A
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                    3                         2
+--R                              512A D  + (- 1536B C - 2048A B)D
+--R                            + 
+--R                                        3          2         2        2
+--R                                    256C  - 2048A C  + (3072B  + 1792A )C
+--R                                  + 
+--R                                             2
+--R                                    - 2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3           2        2             3
+--R                              - 1024B C  + 768A B C  - 3072A B C + 1024A B
+--R                            + 
+--R                                  3
+--R                              256A B
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                             3                      2
+--R                              (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                            + 
+--R                                 3        2       2      2          2      3
+--R                              (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 204D  + 316B D
+--R                            + 
+--R                                     2                2        2  2
+--R                              (- 144C  + 364A C - 292B  - 1092A )D
+--R                            + 
+--R                                     2                 3       2        4
+--R                              (164B C  - 288A B C + 84B  + 636A B)D - 4C
+--R                            + 
+--R                                   3         2      2  2           2      3
+--R                              20A C  + (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                            3                         2
+--R                              (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                            + 
+--R                                      3          2        2        2           2
+--R                                  428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                                + 
+--R                                      3
+--R                                  996A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2         3       2          3
+--R                              - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                            + 
+--R                                 3
+--R                              56A B
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 924D  - 588B D
+--R                            + 
+--R                                   2                2        2  2
+--R                              (216C  - 5556A C - 60B  - 6156A )D
+--R                            + 
+--R                                      2                   3        2          4
+--R                              (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                            + 
+--R                                    3          2       2  2         2        3
+--R                              708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                            + 
+--R                                 4       2 2       4
+--R                              72B  + 576A B  + 120A
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                            + 
+--R                                      3          2        2        2
+--R                                  408C  + 2760A C  + (504B  + 9096A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 3720A B  + 2904A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3            2        3       2
+--R                              - 840B C  - 1656A B C  + (168B  + 360A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 792A B  + 408A B
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              480D  - 1536B D
+--R                            + 
+--R                                     2                  2        2  2
+--R                              (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                            + 
+--R                                        2                  3        2          4
+--R                              (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                            + 
+--R                                      3        2        2  2
+--R                              - 864A C  + (576B  - 2304A )C
+--R                            + 
+--R                                      2        3         4       2 2       4
+--R                              (1152A B  - 2208A )C + 576B  + 576A B  - 384A
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                               3                       2
+--R                              (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                            + 
+--R                                         3          2           2        2
+--R                                  - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                                + 
+--R                                         2        3
+--R                                  2304A B  - 1344A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3            2        2             3
+--R                              1344B C  - 1728A B C  + 5184A B C - 1536A B
+--R                            + 
+--R                                    3
+--R                              - 192A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                    3           2                  2        2  2
+--R                              512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                            + 
+--R                                        2                   2          4
+--R                              (- 1280B C  - 4608A B C + 768A B)D + 640C
+--R                            + 
+--R                                      3         2       2  2
+--R                              - 512A C  + (1920B  + 768A )C
+--R                            + 
+--R                                     2        3          2 2       4
+--R                              (768A B  + 1536A )C - 1152A B  - 384A
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                         2
+--R                              - 2048A B D
+--R                            + 
+--R                                       3          2         2        2
+--R                                  1024C  - 2048A C  + (3072B  - 1024A )C
+--R                                + 
+--R                                         2
+--R                                  2048A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                       3            2           3        2
+--R                              - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                            + 
+--R                                     3        3
+--R                              1024A B  + 1024A B
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                             4        3       2               2       2  2
+--R                          24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 8C - 336A)D  + (216B C + 96A B)D
+--R                        + 
+--R                                   3         2          2       2          2
+--R                              - 56C  + 240A C  + (- 120B  - 184A )C + 80A B
+--R                            + 
+--R                                   3
+--R                              - 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2      3      2
+--R                          8B C  - 48A B C  + (8B  + 72A B)C
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              4         3       2               2        2  2
+--R                          216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                        + 
+--R                                   2                3       2         4
+--R                          (- 304B C  - 48A B C - 64B  - 384A B)D + 32C
+--R                        + 
+--R                                  3       2      2  2           2       3
+--R                          - 120A C  + (72B  + 24A )C  + (- 24A B  + 152A )C
+--R                        + 
+--R                              4      2 2      4
+--R                          - 8B  - 96A B  - 24A
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                        + 
+--R                                    3          2          2        2           2
+--R                              - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                            + 
+--R                                    3
+--R                              - 864A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2      3       2            3      3
+--R                        120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          144D  + 1848B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 576C  + 6600A C - 984B  + 1800A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                        + 
+--R                                  3        2       2  2            2        3
+--R                          - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 120B  - 576A B  - 72A
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                        + 
+--R                                   3          2         2        2           2
+--R                              1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                            + 
+--R                                    3
+--R                              - 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2          3        2             3
+--R                          384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                        + 
+--R                                3
+--R                          - 240A B
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 384D  - 1600B D
+--R                        + 
+--R                                2                  2        2  2
+--R                          (2784C  - 7040A C + 1280B  - 3936A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                        + 
+--R                                 3           2        2  2
+--R                          2304A C  + (- 2592B  + 1152A )C
+--R                        + 
+--R                                    2       3         4        2 2       4
+--R                          (- 1152A B  - 768A )C - 384B  + 1440A B  + 864A
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1792C  + 5376A C  + (- 2688B  + 5632A )C
+--R                            + 
+--R                                       2        3
+--R                              - 3200A B  + 1536A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2         3        2
+--R                          - 512B C  - 6144A B C  + (2176B  + 2304A B)C
+--R                        + 
+--R                                   3       3
+--R                          - 1152A B  - 768A B
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                2       2  2
+--R                          (- 2304C  + 512A C - 512B  + 768A )D
+--R                        + 
+--R                                    2                    3        2          4
+--R                          (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                        + 
+--R                                   3         2        2  2           2       3
+--R                          - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          512B  - 768A B  - 768A
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                                3        2           2              2        3
+--R                          (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                        + 
+--R                               3
+--R                          1024A B
+--R                     *
+--R                         11
+--R                        a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                        4 2 8
+--R                  - 8A D a c
+--R                + 
+--R                          4   2        4          3  2
+--R                      2A D a b  + (4B D  + 16A C D )a b
+--R                    + 
+--R                                  4          3           2     3  2  3
+--R                      ((8C - 32A)D  + 48A B D  + (- 16A C  - 8A )D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            4         3    3
+--R                      (- B D  - 4A C D )a b
+--R                    + 
+--R                                         4                    3
+--R                            (- 6C + 88A)D  + (- 8B C - 36A B)D
+--R                          + 
+--R                                   2      3  2
+--R                            (- 4A C  + 10A )D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                               5       4         2              2      2  3
+--R                          - 12D  + 4B D  + (- 16C  + 32A C - 24B  - 68A )D
+--R                        + 
+--R                               2                2   2         3      3
+--R                          (8B C  - 24A B C + 12A B)D  + (16A C  - 16A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                     4                      3
+--R                          (32C + 8A)D  + (- 48B C + 192A B)D
+--R                        + 
+--R                              3        2      2          2      3  2
+--R                          (16C  - 64A C  + 64A C - 104A B  - 32A )D
+--R                        + 
+--R                                  2      3          4     3 2
+--R                          (48A B C  + 16A B)D - 8A C  + 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 4                 3        2     3  2    4
+--R                      ((C - 19A)D  + (2B C + 6A B)D  + (2A C  - 2A )D )a b
+--R                    + 
+--R                            5        4       2               2      2  3
+--R                          7D  - 35B D  + (12C  - 144A C + 18B  + 41A )D
+--R                        + 
+--R                               2                2   2          3     3
+--R                          (2B C  + 30A B C - 15A B)D  + (- 4A C  + 4A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 56C + 114A)D  + (68B C - 496A B)D
+--R                        + 
+--R                               3         2       2     2          2       3  2
+--R                          (- 4C  + 152A C  + (12B  - 8A )C + 94A B  + 116A )D
+--R                        + 
+--R                               3          2      2        3          4     3 2
+--R                        (- 8B C  - 60A B C  + 24A B C - 4A B)D + 2A C  - 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5        4         2              2       2  3
+--R                          - 28D  + 44B D  + (- 56C  - 32A C - 20B  - 232A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (32B C  - 48A B C + 52B  + 240A B)D
+--R                        + 
+--R                                   4        3         2      2  2
+--R                              - 16C  + 32A C  + (- 24B  - 60A )C
+--R                            + 
+--R                                      2      3        2 2     4
+--R                              (- 48A B  - 72A )C - 24A B  + 4A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4          3      2   2
+--R                          4B C  + 24A B C  - 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4                      3
+--R                          160A D  + (- 192B C - 32A B)D
+--R                        + 
+--R                              3        2       2       2           2     3  2
+--R                          (64C  - 56A C  + (96B  + 256A )C - 416A B  - 8A )D
+--R                        + 
+--R                                  3           2       2           3      3
+--R                          (- 48B C  + 192A B C  - 144A B C + 96A B  + 64A B)D
+--R                        + 
+--R                            5        4      2 3           2      3  2      4
+--R                          8C  - 32A C  + 16A C  + (- 24A B  + 32A )C  - 24A C
+--R                        + 
+--R                              3 2
+--R                          - 8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                             5       4        2             2     2  3
+--R                          - D  + 8B D  + (- 2C  + 32A C - 3B  - 6A )D
+--R                        + 
+--R                                2              2   2
+--R                          (- B C  - 6A B C + 3A B)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                       4                    3
+--R                          (33C - 297A)D  + (30B C + 286A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  2
+--R                          (- 4C  + 24A C  + (- 15B  - 14A )C - 29A B  - 98A )D
+--R                        + 
+--R                               3          2     2
+--R                          (2B C  + 12A B C  - 6A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                             5        4        2               2       2  3
+--R                          97D  - 29B D  + (114C  + 40A C + 173B  + 672A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 112B C  + 192A B C - 49B  - 342A B)D
+--R                        + 
+--R                                 4         3       2      2  2
+--R                              12C  - 120A C  + (30B  + 39A )C
+--R                            + 
+--R                                    2       3       2 2    4
+--R                              (36A B  + 162A )C + 6A B  - A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4         3     2   2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                         4                     3
+--R                          (- 68C - 432A)D  + (488B C - 400A B)D
+--R                        + 
+--R                                    3         2          2       2            2
+--R                              - 112C  + 262A C  + (- 180B  - 740A )C + 1000A B
+--R                            + 
+--R                                   3
+--R                              - 74A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2           3
+--R                              92B C  - 480A B C  + (24B  + 300A B)C - 56A B
+--R                            + 
+--R                                    3
+--R                              - 168A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4         2      2  3
+--R                          - 6C  + 64A C  + (- 12B  - 16A )C
+--R                        + 
+--R                                 2      3  2     4      3 2
+--R                          (- 6A B  - 80A )C  + 6A C + 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             5         4       2               2       2  3
+--R                          40D  + 136B D  + (28C  + 136A C + 24B  + 140A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (52B C  + 24A B C + 40B  + 612A B)D
+--R                        + 
+--R                                   4        3       2      2  2
+--R                              - 44C  - 32A C  + (36B  - 48A )C
+--R                            + 
+--R                                       2       3        4       2 2      4
+--R                              (- 168A B  + 176A )C - 48B  - 252A B  + 44A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4          3       3      2   2
+--R                          - 20B C  + 80A B C  + (12B  - 48A B)C
+--R                        + 
+--R                                3      3         2 3      4
+--R                          (40A B  + 64A B)C + 12A B  + 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          4           3
+--R                          (- 128C + 128A)D  - 896A B D
+--R                        + 
+--R                              3        2        2      2          2      3  2
+--R                          (16C  + 32A C  + (384B  - 16A )C + 32A B  + 96A )D
+--R                        + 
+--R                                      3          2         3       2
+--R                              - 192B C  + 96A B C  + (- 64B  - 576A B)C
+--R                            + 
+--R                                    3      3
+--R                              384A B  + 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4       2      2  3        2 2
+--R                          32C  - 16A C  + (16B  + 64A )C  - 96A B C
+--R                        + 
+--R                              2 2      4          4      3 2      5
+--R                          (48A B  - 96A )C - 32A B  - 32A B  + 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       4                     3
+--R                          (- 5C + 59A)D  + (- 10B C - 42A B)D
+--R                        + 
+--R                            3        2      2     2         2      3  2
+--R                          (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                               5         4         2                2       2  3
+--R                          - 47D  + 107B D  + (- 67C  + 352A C - 117B  - 325A )D
+--R                        + 
+--R                                2                 3       2   2
+--R                          (15B C  - 198A B C + 17B  + 195A B)D
+--R                        + 
+--R                             4        3        2     2  2          2      3
+--R                        (- 2C  + 26A C  + (- 6B  - 6A )C  + (- 6A B  - 34A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                       4                       3
+--R                          (29C + 315A)D  + (- 540B C + 958A B)D
+--R                        + 
+--R                              3         2       2       2           2       3  2
+--R                          (30C  - 546A C  + (57B  + 213A )C - 621A B  - 171A )D
+--R                        + 
+--R                                   2         3       2          3      3       5
+--R                          (414A B C  + (- 22B  - 318A B)C + 8A B  + 36A B)D + C
+--R                        + 
+--R                                 4      2     2  3        2      3  2
+--R                          - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                               5         4       2               2       2  3
+--R                          - 36D  - 428B D  + (45C  - 98A C - 196B  + 261A )D
+--R                        + 
+--R                                   2                3        2   2
+--R                          (- 149B C  - 6A B C - 316B  - 1605A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              95C  + 56A C  + (51B  + 330A )C
+--R                            + 
+--R                                     2     3        4       2 2      4
+--R                              (354A B  + 8A )C + 32B  + 339A B  - 41A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3      3       2   2
+--R                          - 5B C  - 176A B C  + (5B  + 138A B)C
+--R                        + 
+--R                                  3      3        2 3     4
+--R                          (- 10A B  - 16A B)C - 3A B  - 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (108C - 620A)D  + (160B C + 1984A B)D
+--R                        + 
+--R                                    3        2           2       2           2
+--R                              - 164C  + 36A C  + (- 1080B  - 796A )C + 584A B
+--R                            + 
+--R                                    3
+--R                              - 612A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2        3        2            3
+--R                              520B C  - 456A B C  + (128B  + 1464A B)C - 768A B
+--R                            + 
+--R                                    3
+--R                              - 120A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4        2       2  3
+--R                          - 56C  + 80A C  + (- 4B  - 128A )C
+--R                        + 
+--R                                 2      3  2         4       2 2       4
+--R                          (132A B  - 64A )C  + (- 20B  - 156A B  + 184A )C
+--R                        + 
+--R                              4      3 2      5
+--R                          4A B  + 28A B  - 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              5         4        2                2        2  3
+--R                          112D  - 208B D  + (176C  + 288A C - 192B  + 1072A )D
+--R                        + 
+--R                                   2                  3       2   2
+--R                          (- 112B C  - 288A B C - 256B  - 624A B)D
+--R                        + 
+--R                                 4        3        2       2  2
+--R                              64C  - 64A C  + (336B  + 288A )C
+--R                            + 
+--R                                    2       3        4       2 2      4
+--R                              (96A B  + 640A )C - 48B  - 432A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4         3      2   2          3      3
+--R                          - 96B C  + (- 16B  - 96A B)C  + (160A B  + 64A B)C
+--R                        + 
+--R                             5       2 3
+--R                          16B  + 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 128C - 128A)D  + (768B C - 768A B)D
+--R                        + 
+--R                                 3         2        2           2       3  2
+--R                          (- 192C  + 256A C  - 1088A C + 1792A B  + 128A )D
+--R                        + 
+--R                                     2       3        3           4      2 3
+--R                          (- 384A B C  - 256B C - 128A B)D + 64A C  + 64B C
+--R                        + 
+--R                                3 2       2 2          4      5
+--R                          - 128A C  + 192A B C - 128A B  + 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            5        4       2              2      2  3
+--R                          6D  - 22B D  + (10C  - 76A C + 18B  + 42A )D
+--R                        + 
+--R                               2               3      2   2
+--R                          (2B C  + 36A B C - 2B  - 30A B)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 24C + 276A)D  + (52B C - 536A B)D
+--R                        + 
+--R                              3       2       2      2           2       3  2
+--R                          (16C  + 4A C  + (48B  + 40A )C + 148A B  + 212A )D
+--R                        + 
+--R                                 3          2      3      2
+--R                          (- 4B C  - 72A B C  + (4B  + 60A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 129D  + 160B D
+--R                        + 
+--R                                2                2        2  3
+--R                          (- 56C  - 572A C - 130B  - 1334A )D
+--R                        + 
+--R                                 2                 3        2   2
+--R                          (426B C  - 96A B C + 248B  + 1344A B)D
+--R                        + 
+--R                                   4         3          2       2  2
+--R                              - 55C  + 192A C  + (- 120B  - 180A )C
+--R                            + 
+--R                                       2       3       4      2 2     4
+--R                              (- 180A B  - 356A )C - 5B  - 66A B  + 7A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4          3        3      2   2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                         4                       3
+--R                          (203C + 1051A)D  + (- 60B C - 1760A B)D
+--R                        + 
+--R                                  3         2         2        2            2
+--R                              216C  + 144A C  + (1356B  + 2418A )C - 1296A B
+--R                            + 
+--R                                   3
+--R                              1594A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 624B C  + 612A B C  + (- 168B  - 1428A B)C
+--R                            + 
+--R                                    3       3
+--R                              300A B  + 408A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5         4       2      2  3         2       3  2
+--R                          29C  - 119A C  + (54B  + 80A )C  + (30A B  + 188A )C
+--R                        + 
+--R                             4      2 2      4        4     3 2     5
+--R                          (5B  + 36A B  - 37A )C + A B  - 4A B  + 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 196D  + 508B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 226C  - 1068A C + 712B  - 2514A )D
+--R                        + 
+--R                                 2                  3       2   2
+--R                          (258B C  + 540A B C + 808B  + 930A B)D
+--R                        + 
+--R                                   4        3          2       2  2
+--R                              - 98C  + 64A C  + (- 894B  - 852A )C
+--R                            + 
+--R                                    2        3         4        2 2       4
+--R                              (12A B  - 1872A )C + 268B  + 1218A B  - 154A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3         3       2   2
+--R                          190B C  - 96A B C  + (- 34B  + 204A B)C
+--R                        + 
+--R                                   3       3        5      2 3      4
+--R                          (- 220A B  - 304A B)C - 4B  - 82A B  - 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                        4                         3
+--R                          (344C + 488A)D  + (- 1152B C + 1920A B)D
+--R                        + 
+--R                                  3         2       2        2            2
+--R                              104C  - 120A C  + (48B  + 3000A )C - 3408A B
+--R                            + 
+--R                                  3
+--R                              504A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2        3      2            3
+--R                              - 112B C  + 528A B C  + (384B  + 48A B)C - 512A B
+--R                            + 
+--R                                  3
+--R                              560A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4      2      2  3          2       3  2
+--R                          - 16C  - 80A C  + (8B  - 32A )C  + (168A B  + 320A )C
+--R                        + 
+--R                                4       2 2       4           4     3 2       5
+--R                          (- 40B  - 552A B  + 176A )C + 168A B  - 8A B  - 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                             5         4                    2       2  3
+--R                          32D  - 608B D  + (- 1024A C + 256B  + 576A )D
+--R                        + 
+--R                                   2                   2   2
+--R                          (- 512B C  - 384A B C - 2880A B)D
+--R                        + 
+--R                                  4         3          2       3         4
+--R                              224C  - 128A C  + (768A B  - 512A )C + 288B
+--R                            + 
+--R                                  2 2       4
+--R                              768A B  - 352A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3 2       3         5
+--R                          32B C  - 256A B C  - 128B C  - 384A B C + 32B
+--R                        + 
+--R                              2 3       4
+--R                          128A B  - 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  4                     3
+--R                          - 128A D  + (768B C + 512A B)D
+--R                        + 
+--R                                    3         2           2        2
+--R                              - 256C  + 896A C  + (- 1536B  - 1024A )C
+--R                            + 
+--R                                     2       3
+--R                              1664A B  + 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                          (768B C  - 768A B C  + 2304A B C - 1536A B  - 256A B)D
+--R                        + 
+--R                                5         4       2 3          2       3  2
+--R                          - 128C  + 128A C  - 256A C  + (384A B  - 128A )C
+--R                        + 
+--R                              4        3 2
+--R                          384A C + 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                     4                  3
+--R                          (4C - 60A)D  + (8B C + 72A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  2
+--R                          (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                     *
+--R                           8
+--R                        a b
+--R                    + 
+--R                             5         4       2                2       2  3
+--R                          68D  - 148B D  + (52C  - 176A C + 156B  + 620A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 116B C  + 264A B C - 76B  - 564A B)D
+--R                        + 
+--R                             4        3       2      2  2         2      3
+--R                          (8C  - 40A C  + (24B  + 24A )C  + (24A B  + 72A )C)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 24C - 1088A)D  + (504B C + 672A B)D
+--R                        + 
+--R                                    3         2          2        2           2
+--R                              - 132C  + 628A C  + (- 744B  - 1048A )C + 608A B
+--R                            + 
+--R                                    3
+--R                              - 912A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2        3       2           3
+--R                              176B C  - 600A B C  + (104B  + 936A B)C - 32A B
+--R                            + 
+--R                                   3
+--R                              - 80A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4         2      2  3           2      3  2
+--R                        - 4C  + 20A C  + (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              5        4          2                2        2  3
+--R                          288D  + 44B D  + (- 112C  + 1816A C - 60B  + 2928A )D
+--R                        + 
+--R                                   2                  3       2   2
+--R                          (- 792B C  - 672A B C - 348B  - 528A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              64C  - 408A C  + (732B  + 240A )C
+--R                            + 
+--R                                       2        3         4        2 2      4
+--R                              (- 144A B  + 1576A )C - 148B  - 1044A B  + 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3         3       2   2
+--R                          - 68B C  + 272A B C  + (- 28B  - 384A B)C
+--R                        + 
+--R                                3      3         2 3      4
+--R                          (40A B  + 64A B)C + 12A B  + 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                          4                        3
+--R                          (- 656C - 664A)D  + (- 128B C - 1416A B)D
+--R                        + 
+--R                                  3         2          2        2            2
+--R                              136C  - 792A C  + (- 636B  - 4356A )C + 2652A B
+--R                            + 
+--R                                     3
+--R                              - 1892A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3          2          3       2            3
+--R                              480B C  + 72A B C  + (- 152B  + 120A B)C + 848A B
+--R                            + 
+--R                                     3
+--R                              - 1008A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4          2      2  3
+--R                          8C  + 64A C  + (- 188B  + 28A )C
+--R                        + 
+--R                                   2       3  2        4       2 2       4
+--R                          (- 252A B  - 412A )C  + (100B  + 768A B  - 308A )C
+--R                        + 
+--R                                 4      3 2      5
+--R                          - 12A B  + 64A B  + 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 176D  + 592B D
+--R                        + 
+--R                               2                  2        2  3
+--R                          (156C  + 1896A C - 1328B  - 1172A )D
+--R                        + 
+--R                                  2                  3        2   2
+--R                          (1188B C  + 216A B C - 560B  + 4596A B)D
+--R                        + 
+--R                                    4         3        2       2  2
+--R                              - 252C  + 416A C  + (420B  + 792A )C
+--R                            + 
+--R                                        2        3         4        2 2       4
+--R                              (- 1128A B  + 1632A )C - 656B  - 1500A B  + 740A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3        3      2   2
+--R                          - 108B C  + 256A B C  + (252B  + 24A B)C
+--R                        + 
+--R                                   3       3         5       2 3       4
+--R                          (- 120A B  + 768A B)C - 80B  - 356A B  + 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (208C + 912A)D  + (- 960B C - 1280A B)D
+--R                        + 
+--R                                  3          2         2        2            2
+--R                              400C  - 1616A C  + (3360B  + 2352A )C - 2304A B
+--R                            + 
+--R                                  3
+--R                              912A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                       3            2          3        2
+--R                              - 1568B C  + 1632A B C  + (- 256B  - 5088A B)C
+--R                            + 
+--R                                     3       3
+--R                              2304A B  + 160A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4         2       2  3
+--R                          160C  - 160A C  + (- 48B  + 384A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 336A B  + 160A )C  + (80B  + 432A B  - 544A )C
+--R                        + 
+--R                                4      3 2
+--R                          112A B  - 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  4        2                  2       2  3
+--R                          - 128B D  + (192C  - 1664A C + 1088B  - 576A )D
+--R                        + 
+--R                                  2                   3        2   2
+--R                          (- 64B C  + 1920A B C + 192B  - 1344A B)D
+--R                        + 
+--R                                      3          2       2  2
+--R                              - 256A C  + (- 960B  - 192A )C
+--R                            + 
+--R                                     2        3         4        2 2      4
+--R                              (384A B  - 1408A )C + 192B  + 2112A B  + 64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3       3       2   2
+--R                          320B C  - 384A B C  + (64B  + 576A B)C
+--R                        + 
+--R                                   3       3         5       2 3
+--R                          (- 640A B  - 256A B)C - 64B  - 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                  3
+--R                          512A B D
+--R                        + 
+--R                                    3         2           2       2           2
+--R                              - 256C  + 896A C  + (- 1536B  + 256A )C - 512A B
+--R                            + 
+--R                                  3
+--R                              128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3        2
+--R                              768B C  - 1536A B C  + (1024B  + 2304A B)C
+--R                            + 
+--R                                       3       3
+--R                              - 1536A B  - 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4          2       2  3         2 2
+--R                          - 128C  + 256A C  + (- 256B  - 256A )C  + 384A B C
+--R                        + 
+--R                                 2 2       4           4       3 2       5
+--R                          (- 768A B  + 384A )C + 512A B  + 128A B  - 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                          5        4        2              2      2  3
+--R                      - 8D  + 24B D  + (- 8C  + 48A C - 24B  - 72A )D
+--R                    + 
+--R                           2               3      2   2
+--R                      (8B C  - 48A B C + 8B  + 72A B)D
+--R                 *
+--R                       9
+--R                    a b
+--R                + 
+--R                            4                     3
+--R                      112A D  + (- 80B C - 32A B)D
+--R                    + 
+--R                          3        2       2       2          2      3  2
+--R                      (16C  - 96A C  + (96B  + 112A )C - 80A B  + 96A )D
+--R                    + 
+--R                              3          2         3       2
+--R                      (- 16B C  + 96A B C  + (- 16B  - 144A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                           5         4        2               2       2  3
+--R                      - 68D  + 104B D  + (- 8C  + 64A C - 112B  - 656A )D
+--R                    + 
+--R                             2                 3       2   2
+--R                      (112B C  - 144A B C + 56B  + 312A B)D
+--R                    + 
+--R                              4        3      2 2         2       3        4
+--R                          - 4C  + 32A C  - 96B C  + (48A B  - 176A )C + 20B
+--R                        + 
+--R                              2 2      4
+--R                          168A B  - 12A
+--R                     *
+--R                        D
+--R                    + 
+--R                          4          3      3      2   2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                   4                      3
+--R                      (52C + 772A)D  + (- 416B C - 32A B)D
+--R                    + 
+--R                          3         2        2        2           2       3  2
+--R                      (48C  - 480A C  + (528B  + 1016A )C - 592A B  + 776A )D
+--R                    + 
+--R                                 3           2         3       2            3
+--R                          - 80B C  + 432A B C  + (- 48B  - 672A B)C - 176A B
+--R                        + 
+--R                             3
+--R                          96A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          5        4       2      2  3         2      3  2
+--R                      - 4C  + 12A C  + (24B  - 16A )C  + (24A B  + 32A )C
+--R                    + 
+--R                            4       2 2      4         4      3 2      5
+--R                      (- 20B  - 144A B  + 52A )C - 4A B  - 16A B  - 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                           5         4        2                 2       2  3
+--R                      - 20D  - 640B D  + (328C  - 2272A C + 568B  - 464A )D
+--R                    + 
+--R                             2                  3        2   2
+--R                      (240B C  + 1392A B C + 16B  - 2040A B)D
+--R                    + 
+--R                              4         3          2      2  2
+--R                          - 4C  + 224A C  + (- 600B  - 96A )C
+--R                        + 
+--R                                 2        3         4        2 2       4
+--R                          (384A B  - 1264A )C + 188B  + 1056A B  - 172A
+--R                     *
+--R                        D
+--R                    + 
+--R                           4           3       3       2   2         3      3
+--R                      32B C  - 304A B C  + (16B  + 408A B)C  + (80A B  - 64A B)C
+--R                    + 
+--R                         5      2 3      4
+--R                      16B  + 88A B  - 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                    4                       3
+--R                      (364C - 980A)D  + (1648B C + 1600A B)D
+--R                    + 
+--R                                3          2           2       2           2
+--R                          - 544C  + 2112A C  + (- 1776B  + 696A )C + 480A B
+--R                        + 
+--R                               3
+--R                          - 40A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2        3        2             3
+--R                          352B C  - 2256A B C  + (448B  + 3504A B)C - 1232A B
+--R                        + 
+--R                              3
+--R                          736A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5        4        2       2  3          2       3  2
+--R                      - 28C  + 52A C  + (200B  - 112A )C  + (168A B  + 224A )C
+--R                    + 
+--R                             4       2 2       4          4       3 2      5
+--R                      (- 140B  - 912A B  + 364A )C - 92A B  - 112A B  - 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                         5         4          2                 2        2  3
+--R                      96D  + 512B D  + (- 888C  + 2288A C - 560B  + 1384A )D
+--R                    + 
+--R                                2                   3       2   2
+--R                      (- 1064B C  - 3888A B C + 560B  + 696A B)D
+--R                    + 
+--R                              4         3         2       2  2
+--R                          200C  - 256A C  + (1272B  - 672A )C
+--R                        + 
+--R                                  2        3         4        2 2       4
+--R                          (- 48A B  + 1184A )C + 176B  - 2184A B  - 520A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3        2   2
+--R                      - 232B C  + 608A B C  + (- 344B  - 1248A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (560A B  - 448A B)C + 112B  + 616A B  - 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                     4                         3
+--R                      (- 416C + 96A)D  + (- 1152B C - 1536A B)D
+--R                    + 
+--R                                3          2         2        2           2
+--R                            736C  - 1536A C  + (1152B  - 2080A )C + 704A B
+--R                          + 
+--R                                  3
+--R                            - 832A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3            2           3        2
+--R                          - 256B C  + 3264A B C  + (- 1408B  - 2688A B)C
+--R                        + 
+--R                                 3       3
+--R                          1408A B  - 320A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5         4       2       2  3            2       3  2
+--R                      32C  - 320A C  + (32B  + 128A )C  + (- 192A B  - 256A )C
+--R                    + 
+--R                           4        2 2       4           4       3 2       5
+--R                      (160B  + 1824A B  - 416A )C - 416A B  + 128A B  + 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                           2                2       2  3
+--R                      (576C  - 128A C + 128B  - 192A )D
+--R                    + 
+--R                             2                   3       2   2
+--R                      (704B C  + 2688A B C - 640B  + 960A B)D
+--R                    + 
+--R                                4          2       2  2            2       3
+--R                          - 192C  + (- 576B  + 768A )C  + (- 384A B  + 256A )C
+--R                        + 
+--R                                4       2 2       4
+--R                          - 384B  + 960A B  + 704A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3       2   2
+--R                      192B C  - 256A B C  + (320B  + 768A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 640A B  + 512A B)C - 128B  - 704A B  + 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                             3       2          2  2
+--R                      (- 256C  + 256A C - 512A B )D
+--R                    + 
+--R                                  2        3        3            4       2 3
+--R                      (- 1536A B C  + 1024B C - 512A B)D + 256A C  - 256B C
+--R                    + 
+--R                            2 2          4       5
+--R                      - 768A B C + 512A B  - 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                ROOT
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN1
+--R                     + 
+--R                                   3 3      2 2      4  2       3 2      5
+--R                               - 8a c  + (2a b  - 16a )c  + (40a b  + 32a )c
+--R                             + 
+--R                                   2 4      4 2      6
+--R                               - 8a b  - 56a b  + 64a
+--R                          *
+--R                             %%BN0
+--R                         + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN1
+--R                     + 
+--R                                3 3      2 2      4  2       3 2      5
+--R                           - 12a c  + (3a b  - 24a )c  + (60a b  + 48a )c
+--R                         + 
+--R                                2 4      4 2      6
+--R                           - 12a b  - 84a b  + 96a
+--R                      *
+--R                              2
+--R                         %%BN0
+--R                     + 
+--R                               2 3            2        3  2
+--R                           8D a c  + (- 2D a b  + 16D a )c
+--R                         + 
+--R                                   2 2        4           4        3 2        5
+--R                           (- 40D a b  - 32D a )c + 8D a b  + 56D a b  - 64D a
+--R                      *
+--R                         %%BN0
+--R                     + 
+--R                           2 2                          2     2  2  2
+--R                       (- D b  + 4C D a b + (- 8B D - 4C  - 4A )a )c
+--R                     + 
+--R                               2   2                               2
+--R                           - 4D a b  + ((20C + 4A)D + 4B C + 4A B)a b
+--R                         + 
+--R                              2             2             2     2  3
+--R                           (8D  - 16B D - 8C  + 16A C + 8B  - 8A )a
+--R                      *
+--R                         c
+--R                     + 
+--R                         2 4            3
+--R                       4D b  - 16C D a b
+--R                     + 
+--R                            2              2            2      2  2 2
+--R                       (- 8D  + 24B D + 12C  - 8A C - 4B  + 12A )a b
+--R                     + 
+--R                                                       3
+--R                       ((- 8C - 24A)D - 24B C - 24A B)a b
+--R                     + 
+--R                           2              2  4
+--R                       (16D  + 32A C + 16B )a
+--R                  /
+--R                         3 3       2 2     4  2         3 2      5       2 4
+--R                       4a c  + (- a b  + 8a )c  + (- 20a b  - 16a )c + 4a b
+--R                     + 
+--R                          4 2      6
+--R                       28a b  - 32a
+--R            + 
+--R                             2 4 8
+--R                      - 32A D a c
+--R                    + 
+--R                               2 3 2       3        2  4
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   2                   2      3  5
+--R                          (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                2 2 4        3       2  3 3
+--R                          - 2A D a b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          2                  2      3  4 2
+--R                          ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                        + 
+--R                                 3        2       2               2       2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                     2                2
+--R                              - 16B C  - 96A B C + 48A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    2                 3         2      2
+--R                              128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                            + 
+--R                                      2       3
+--R                              - 128A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3      2  2 5
+--R                          (D  + B D )a b
+--R                        + 
+--R                                        2                2     3  3 4
+--R                          ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                        + 
+--R                                    3         2
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 24C  + 112A C + 32B  + 72A )D + 8B C  + 48A B C
+--R                            + 
+--R                                   2
+--R                              - 24A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                           3
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2           2      3
+--R                              (384C  - 512A C - 64B  - 384A )D + 128B C  + 64B
+--R                            + 
+--R                                  2
+--R                              384A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                     2                  3         2       2
+--R                              1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                            + 
+--R                                      2       3
+--R                              - 512A B  + 128A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       2 2 6
+--R                          (- 2C + 22A)D a b
+--R                        + 
+--R                                 3        2      2             2     2        2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D - B C
+--R                            + 
+--R                                           2
+--R                              - 6A B C + 3A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                             2                            3
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                            + 
+--R                                    2         2      2          2       3
+--R                              120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                            + 
+--R                                            3       2
+--R                              672A B C - 64B  - 720A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                               3
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D + 608C
+--R                            + 
+--R                                      2          2       2            2      3
+--R                              - 416A C  + (- 288B  - 992A )C + 1120A B  + 32A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2           2
+--R                              (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                            + 
+--R                                              3       2
+--R                              1152A B C + 128B  + 192A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                    2                   3          2       2
+--R                              512A D  - 4096A B D + 256C  - 1024A C  - 256A C
+--R                            + 
+--R                                    2        3
+--R                              512A B  + 1024A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               3       2  2 7
+--R                          (- 8D  - 8B D )a b
+--R                        + 
+--R                                              2                      3        2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D + C  - 13A C
+--R                            + 
+--R                                 2     2         2      3
+--R                              (3B  + 3A )C + 3A B  + 17A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  3        2        2                2       2
+--R                              284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              - 12B C  - 312A B C + 20B  + 276A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                            2                               3
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D - 320C
+--R                            + 
+--R                                    2         2       2           2       3
+--R                              720A C  + (- 96B  + 192A )C - 672A B  - 848A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2            2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D - 1088B C
+--R                            + 
+--R                                                3        2
+--R                              - 1920A B C - 384B  - 1344A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                             2                               3
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D + 128C
+--R                            + 
+--R                                     2          2       2           2        3
+--R                              1920A C  + (- 384B  - 640A )C + 128A B  - 2432A
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2            2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D - 1024B C
+--R                            + 
+--R                                    3        2
+--R                              - 512B  - 3072A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2                    3         2
+--R                              - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                            + 
+--R                                     2           2       3
+--R                              - 2048A C + 4096A B  + 512A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      2 2 8
+--R                          (16C - 80A)D a b
+--R                        + 
+--R                                    3         2
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 30C  + 100A C + 26B  + 66A )D + 2B C  + 36A B C
+--R                            + 
+--R                                  3      2
+--R                              - 2B  - 30A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                               2                            3
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D + 62C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 230A C  + (90B  + 58A )C + 154A B  + 350A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2           2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                            + 
+--R                                               3        2
+--R                              - 576A B C + 312B  + 2160A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                     2                              3         2
+--R                              8160A D  + (4608B C - 5376A B)D - 864C  - 192A C
+--R                            + 
+--R                                    2        2           2        3
+--R                              (2304B  + 3936A )C - 960A B  + 3264A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2            2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D + 1152B C
+--R                            + 
+--R                                                3        2
+--R                              - 2304A B C + 768B  + 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D - 3840C
+--R                            + 
+--R                                     2         2        2            2
+--R                              3072A C  + (2304B  + 6912A )C - 6912A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2            2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D - 2816B C
+--R                            + 
+--R                                                 3        2
+--R                              - 4608A B C - 1024B  - 3840A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2                    3          2
+--R                              - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                            + 
+--R                                     2           2        3
+--R                              - 1024A C + 2048A B  - 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3        2  2 9
+--R                          (16D  + 16B D )a b
+--R                        + 
+--R                                            2                           3
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                            + 
+--R                                   2         2      2          2      3
+--R                              20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                         *
+--R                             3 8
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2           2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D - 104B C
+--R                            + 
+--R                                            3       2
+--R                              432A B C - 88B  - 744A B
+--R                         *
+--R                             4 7
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D + 364C
+--R                            + 
+--R                                      2          2        2           2       3
+--R                              - 380A C  + (- 828B  - 1468A )C + 452A B  - 724A
+--R                         *
+--R                             5 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2           2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D - 336B C
+--R                            + 
+--R                                              3        2
+--R                              4320A B C - 528B  - 5328A B
+--R                         *
+--R                             6 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                             7 4
+--R                            a b
+--R                        + 
+--R                                     3         2
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2            2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D + 4224B C
+--R                            + 
+--R                                               3        2
+--R                              6912A B C + 1536B  + 5760A B
+--R                         *
+--R                             8 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                             9 2
+--R                            a b
+--R                        + 
+--R                                       2         2                  2        2
+--R                              - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                     2        3        2
+--R                              2048B C  + 1024B  + 6144A B
+--R                         *
+--R                             10
+--R                            a  b
+--R                        + 
+--R                                               3          2        2           2
+--R                              8192A B D - 4096C  + 2048A C  + 4096A C - 8192A B
+--R                            + 
+--R                                     3
+--R                              - 2048A
+--R                         *
+--R                             11
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    2 2 10
+--R                      (- 32C + 96A)D a b
+--R                    + 
+--R                               3        2       2               2       2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                              2               3      2
+--R                          8B C  - 48A B C + 8B  + 72A B
+--R                     *
+--R                         3 9
+--R                        a b
+--R                    + 
+--R                                           2                           3
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                        + 
+--R                               2       2       2          2      3
+--R                          72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                     *
+--R                         4 8
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                        + 
+--R                                          3       2
+--R                          - 816A B C + 88B  + 936A B
+--R                     *
+--R                         5 7
+--R                        a b
+--R                    + 
+--R                                        2                              3
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                        + 
+--R                                 2         2        2           2       3
+--R                          1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                     *
+--R                         6 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2           2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                        + 
+--R                                           3        2
+--R                          - 3744A B C - 96B  + 1296A B
+--R                     *
+--R                         7 5
+--R                        a b
+--R                    + 
+--R                                          2                              3
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                        + 
+--R                                 2         2        2           2        3
+--R                          3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                     *
+--R                         8 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2            2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D - 4352B C
+--R                        + 
+--R                                             3         2
+--R                          - 1536A B C - 2048B  - 11520A B
+--R                     *
+--R                         9 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D + 5632C
+--R                        + 
+--R                                 2           2         2            2        3
+--R                        - 4608A C  + (- 4608B  - 11776A )C + 9728A B  - 1536A
+--R                     *
+--R                         10 2
+--R                        a  b
+--R                    + 
+--R                                2                  2        2            2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                        + 
+--R                                           3        2
+--R                          6144A B C + 2048B  + 9216A B
+--R                     *
+--R                         11
+--R                        a  b
+--R                    + 
+--R                              3        2           2  12
+--R                      (- 4096C  + 4096A C - 8192A B )a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                       3 3 8
+--R                  16A D a c
+--R                + 
+--R                            3 2 2          3          2  3
+--R                      - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                    + 
+--R                                     3          2         2      3    4
+--R                      ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           3         2  2 3
+--R                      (2B D  + 6A C D )a b
+--R                    + 
+--R                                    3                   2        2      3    3 2
+--R                      ((12C - 188A)D  + (12B C + 52A B)D  + (4A C  - 12A )D)a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 64C - 32A)D  + (96B C - 320A B)D
+--R                        + 
+--R                                3        2       2          2      3
+--R                          (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                        + 
+--R                                   2      3
+--R                          - 48A B C  - 16A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                      3                   2          2     3
+--R                        ((- 2C + 41A)D  + (- 3B C - 8A B)D  + (- 2A C  + 2A )D)
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 80B D  + (- 18C  + 224A C - 26B  - 66A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                        3                       2
+--R                          (144C - 232A)D  + (- 120B C + 808A B)D
+--R                        + 
+--R                             3         2         2      2           2       3
+--R                          (4C  - 212A C  + (- 24B  + 20A )C - 112A B  - 196A )D
+--R                        + 
+--R                              3          2      2        3
+--R                          4B C  + 36A B C  - 12A B C + 4A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                        + 
+--R                                  2                3       2        4        3
+--R                          (- 80B C  + 96A B C - 64B  - 336A B)D + 8C  + 32A C
+--R                        + 
+--R                              2      2  2         2      3        2 2     4
+--R                          (24B  + 48A )C  + (48A B  + 32A )C + 24A B  + 8A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                  3                     2
+--R                          - 384A D  + (384B C + 128A B)D
+--R                        + 
+--R                                3         2          2       2           2
+--R                          (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                        + 
+--R                               3           2       2           3      3
+--R                          64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4        3      2             2     2  2
+--R                          2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                        + 
+--R                              2              2
+--R                          (B C  + 6A B C - 3A B)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                        + 
+--R                             3       2       2      2          2       3
+--R                          (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                        + 
+--R                               3         2     2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                4        3
+--R                          - 224D  + 92B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 162C  - 280A C - 320B  - 1206A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (172B C  - 336A B C + 60B  + 492A B)D - 6C  + 48A C
+--R                        + 
+--R                                2      2  2           2      3       2 2     4
+--R                          (- 18B  - 24A )C  + (- 24A B  - 80A )C - 6A B  - 2A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                            + 
+--R                                 3
+--R                              64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2         3       2           3
+--R                          - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                        + 
+--R                              3
+--R                          144A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               4         3          2               2       2  2
+--R                          - 64D  - 256B D  + (- 144C  - 608A C + 32B  - 336A )D
+--R                        + 
+--R                                  2      3       2         4        3
+--R                          (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                        + 
+--R                                2      2  2         2       3        4       2 2
+--R                          (- 48B  - 96A )C  + (96A B  - 224A )C + 32B  + 144A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                        3            2
+--R                          (256C - 256A)D  + 1792A B D
+--R                        + 
+--R                                   3         2          2      2           2
+--R                              - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                            + 
+--R                                    3
+--R                              - 256A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3       2            3
+--R                          256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       3                   2
+--R                          (13C - 139A)D  + (18B C + 58A B)D
+--R                        + 
+--R                              3        2        2     2         2      3
+--R                          (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              4         3        2                2       2  2
+--R                          109D  - 265B D  + (114C  - 591A C + 183B  + 543A )D
+--R                        + 
+--R                                  2                 3       2       4        3
+--R                          (- 27B C  + 228A B C - 19B  - 225A B)D + C  - 13A C
+--R                        + 
+--R                             2     2  2        2      3
+--R                          (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                            + 
+--R                                  3
+--R                              346A
+--R                         *
+--R                            D
+--R                        + 
+--R                               3           2       3       2          3      3
+--R                          10B C  - 234A B C  + (14B  + 174A B)C - 2A B  - 30A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                3        2               2       2  2
+--R                          768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                        + 
+--R                                 2                 3        2            3
+--R                          (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                        + 
+--R                                2       2  2            2       3        4
+--R                          (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                        + 
+--R                                2 2      4
+--R                          - 240A B  - 64A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                           3                        2
+--R                          (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                        + 
+--R                                  3         2         2        2           2
+--R                              416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                            + 
+--R                                  3
+--R                              992A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 480B C  + 672A B C  + (- 128B  - 1632A B)C + 512A B
+--R                        + 
+--R                              3
+--R                          160A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 256D  + 384B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (192C  - 1024A C + 256B  - 2112A )D
+--R                        + 
+--R                                 2                  3        2          4
+--R                          (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                        + 
+--R                                 2       2  2            2       3         2 2
+--R                          (- 576B  - 384A )C  + (- 384A B  - 512A )C + 192A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                        + 
+--R                                   2        2           2       3         3
+--R                          (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 54B D  + (- 18C  + 140A C - 26B  - 66A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                        3                      2
+--R                          (142C - 688A)D  + (- 54B C + 800A B)D
+--R                        + 
+--R                                    3         2         2      2           2
+--R                                - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                              + 
+--R                                      3
+--R                                - 248A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2        3      2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              4         3       2                 2        2  2
+--R                          416D  - 190B D  + (84C  + 1254A C + 438B  + 2514A )D
+--R                        + 
+--R                                   2                  3        2         4
+--R                          (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                        + 
+--R                                 3       2       2  2          2       3       4
+--R                          - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C + 2B
+--R                        + 
+--R                             2 2      4
+--R                          48A B  + 14A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                        + 
+--R                                    3        2           2        2            2
+--R                              - 788C  - 84A C  + (- 2292B  - 4428A )C + 1404A B
+--R                            + 
+--R                                     3
+--R                              - 2252A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                        + 
+--R                                3
+--R                          - 308A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          608D  - 640B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 240C  + 3552A C - 960B  + 5232A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1632B C  - 1536A B C - 928B  - 1632A B)D + 464C
+--R                        + 
+--R                                3        2        2  2          2        3
+--R                          128A C  + (912B  + 1344A )C  + (384A B  + 1664A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 160B  - 528A B  - 16A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            3                       2
+--R                          (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 128C  - 576A C  + (192B  - 6144A )C + 4800A B
+--R                            + 
+--R                                    3
+--R                              - 704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2          3       2            3
+--R                          256B C  + 768A B C  + (- 704B  - 384A B)C + 448A B
+--R                        + 
+--R                                3
+--R                          - 128A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 128D  + 1280B D
+--R                        + 
+--R                               2                 2       2  2
+--R                          (768C  + 2560A C - 640B  - 768A )D
+--R                        + 
+--R                                 2                   2          4         3
+--R                          (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                        + 
+--R                                 2       2  2            2       3         4
+--R                          (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                        + 
+--R                                2 2       4
+--R                          - 384A B  + 128A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                3                         2
+--R                          512A D  + (- 1536B C - 2048A B)D
+--R                        + 
+--R                               3          2         2        2            2
+--R                          (256C  - 2048A C  + (3072B  + 1792A )C - 2048A B )D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                        - 1024B C  + 768A B C  - 3072A B C + 1024A B  + 256A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                         3                      2
+--R                          (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                        + 
+--R                             3        2       2      2          2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 204D  + 316B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 144C  + 364A C - 292B  - 1092A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (164B C  - 288A B C + 84B  + 636A B)D - 4C  + 20A C
+--R                        + 
+--R                                2      2  2           2      3
+--R                          (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                            + 
+--R                                  3
+--R                              996A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2         3       2          3
+--R                          - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                        + 
+--R                             3
+--R                          56A B
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 924D  - 588B D
+--R                        + 
+--R                               2                2        2  2
+--R                          (216C  - 5556A C - 60B  - 6156A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                        + 
+--R                                3          2       2  2         2        3
+--R                          708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                        + 
+--R                             4       2 2       4
+--R                          72B  + 576A B  + 120A
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                        + 
+--R                                  3          2        2        2            2
+--R                              408C  + 2760A C  + (504B  + 9096A )C - 3720A B
+--R                            + 
+--R                                   3
+--R                              2904A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3       2            3
+--R                          - 840B C  - 1656A B C  + (168B  + 360A B)C - 792A B
+--R                        + 
+--R                              3
+--R                          408A B
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          480D  - 1536B D
+--R                        + 
+--R                                 2                  2        2  2
+--R                          (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                        + 
+--R                                    2                  3        2          4
+--R                          (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                        + 
+--R                                  3        2        2  2           2        3
+--R                          - 864A C  + (576B  - 2304A )C  + (1152A B  - 2208A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          576B  + 576A B  - 384A
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                           3                       2
+--R                          (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                            + 
+--R                                     2        3
+--R                              2304A B  - 1344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                          1344B C  - 1728A B C  + 5184A B C - 1536A B  - 192A B
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                3           2                  2        2  2
+--R                          512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                        + 
+--R                                    2                   2          4         3
+--R                          (- 1280B C  - 4608A B C + 768A B)D + 640C  - 512A C
+--R                        + 
+--R                                2       2  2          2        3          2 2
+--R                          (1920B  + 768A )C  + (768A B  + 1536A )C - 1152A B
+--R                        + 
+--R                                4
+--R                          - 384A
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                     2
+--R                          - 2048A B D
+--R                        + 
+--R                                3          2         2        2            2
+--R                          (1024C  - 2048A C  + (3072B  - 1024A )C + 2048A B )D
+--R                        + 
+--R                                   3            2           3        2
+--R                          - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                        + 
+--R                                 3        3
+--R                          1024A B  + 1024A B
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                         4        3       2               2       2  2
+--R                      24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                    + 
+--R                             2               3      2
+--R                      (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                    3                    2
+--R                      (- 8C - 336A)D  + (216B C + 96A B)D
+--R                    + 
+--R                            3         2          2       2          2      3
+--R                      (- 56C  + 240A C  + (- 120B  - 184A )C + 80A B  - 96A )D
+--R                    + 
+--R                          3          2      3      2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                          4         3       2               2        2  2
+--R                      216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                    + 
+--R                               2                3       2         4         3
+--R                      (- 304B C  - 48A B C - 64B  - 384A B)D + 32C  - 120A C
+--R                    + 
+--R                        2      2  2           2       3       4      2 2      4
+--R                    (72B  + 24A )C  + (- 24A B  + 152A )C - 8B  - 96A B  - 24A
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                       3                      2
+--R                      (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                        + 
+--R                                3
+--R                          - 864A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3          2      3       2            3      3
+--R                      120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                          4          3          2                 2        2  2
+--R                      144D  + 1848B D  + (- 576C  + 6600A C - 984B  + 1800A )D
+--R                    + 
+--R                                2                   3        2          4
+--R                      (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                    + 
+--R                              3        2       2  2            2        3
+--R                      - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                    + 
+--R                            4       2 2      4
+--R                      - 120B  - 576A B  - 72A
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                    + 
+--R                                 3          2         2        2           2
+--R                            1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                          + 
+--R                                  3
+--R                            - 576A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3            2          3        2             3
+--R                      384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                    + 
+--R                            3
+--R                      - 240A B
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                            4          3
+--R                      - 384D  - 1600B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (2784C  - 7040A C + 1280B  - 3936A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                    + 
+--R                             3           2        2  2             2       3
+--R                      2304A C  + (- 2592B  + 1152A )C  + (- 1152A B  - 768A )C
+--R                    + 
+--R                            4        2 2       4
+--R                      - 384B  + 1440A B  + 864A
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                     3                       2
+--R                      (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                    + 
+--R                                 3          2           2        2            2
+--R                          - 1792C  + 5376A C  + (- 2688B  + 5632A )C - 3200A B
+--R                        + 
+--R                               3
+--R                          1536A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2         3        2             3
+--R                      - 512B C  - 6144A B C  + (2176B  + 2304A B)C - 1152A B
+--R                    + 
+--R                            3
+--R                      - 768A B
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                              2                2       2  2
+--R                      (- 2304C  + 512A C - 512B  + 768A )D
+--R                    + 
+--R                                2                    3        2          4
+--R                      (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                    + 
+--R                          4       2 2       4
+--R                      512B  - 768A B  - 768A
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                            3        2           2              2        3
+--R                      (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                    + 
+--R                           3
+--R                      1024A B
+--R                 *
+--R                     11
+--R                    a
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                             2 4 8
+--R                      - 32A D a c
+--R                    + 
+--R                               2 3 2       3        2  4
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   2                   2      3  5
+--R                          (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                2 2 4        3       2  3 3
+--R                          - 2A D a b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          2                  2      3  4 2
+--R                          ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                        + 
+--R                                 3        2       2               2       2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                     2                2
+--R                              - 16B C  - 96A B C + 48A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    2                 3         2      2
+--R                              128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                            + 
+--R                                      2       3
+--R                              - 128A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3      2  2 5
+--R                          (D  + B D )a b
+--R                        + 
+--R                                        2                2     3  3 4
+--R                          ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                        + 
+--R                                    3         2
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 24C  + 112A C + 32B  + 72A )D + 8B C  + 48A B C
+--R                            + 
+--R                                   2
+--R                              - 24A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                           3
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2           2      3
+--R                              (384C  - 512A C - 64B  - 384A )D + 128B C  + 64B
+--R                            + 
+--R                                  2
+--R                              384A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                     2                  3         2       2
+--R                              1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                            + 
+--R                                      2       3
+--R                              - 512A B  + 128A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       2 2 6
+--R                          (- 2C + 22A)D a b
+--R                        + 
+--R                                 3        2      2             2     2        2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D - B C
+--R                            + 
+--R                                           2
+--R                              - 6A B C + 3A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                             2                            3
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                            + 
+--R                                    2         2      2          2       3
+--R                              120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                            + 
+--R                                            3       2
+--R                              672A B C - 64B  - 720A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                               3
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D + 608C
+--R                            + 
+--R                                      2          2       2            2      3
+--R                              - 416A C  + (- 288B  - 992A )C + 1120A B  + 32A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2           2
+--R                              (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                            + 
+--R                                              3       2
+--R                              1152A B C + 128B  + 192A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                    2                   3          2       2
+--R                              512A D  - 4096A B D + 256C  - 1024A C  - 256A C
+--R                            + 
+--R                                    2        3
+--R                              512A B  + 1024A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               3       2  2 7
+--R                          (- 8D  - 8B D )a b
+--R                        + 
+--R                                              2                      3        2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D + C  - 13A C
+--R                            + 
+--R                                 2     2         2      3
+--R                              (3B  + 3A )C + 3A B  + 17A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                  3        2        2                2       2
+--R                              284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              - 12B C  - 312A B C + 20B  + 276A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                            2                               3
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D - 320C
+--R                            + 
+--R                                    2         2       2           2       3
+--R                              720A C  + (- 96B  + 192A )C - 672A B  - 848A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2            2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D - 1088B C
+--R                            + 
+--R                                                3        2
+--R                              - 1920A B C - 384B  - 1344A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                             2                               3
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D + 128C
+--R                            + 
+--R                                     2          2       2           2        3
+--R                              1920A C  + (- 384B  - 640A )C + 128A B  - 2432A
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2            2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D - 1024B C
+--R                            + 
+--R                                    3        2
+--R                              - 512B  - 3072A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2                    3         2
+--R                              - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                            + 
+--R                                     2           2       3
+--R                              - 2048A C + 4096A B  + 512A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      2 2 8
+--R                          (16C - 80A)D a b
+--R                        + 
+--R                                    3         2
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 30C  + 100A C + 26B  + 66A )D + 2B C  + 36A B C
+--R                            + 
+--R                                  3      2
+--R                              - 2B  - 30A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                               2                            3
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D + 62C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 230A C  + (90B  + 58A )C + 154A B  + 350A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2           2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                            + 
+--R                                               3        2
+--R                              - 576A B C + 312B  + 2160A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                     2                              3         2
+--R                              8160A D  + (4608B C - 5376A B)D - 864C  - 192A C
+--R                            + 
+--R                                    2        2           2        3
+--R                              (2304B  + 3936A )C - 960A B  + 3264A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2            2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D + 1152B C
+--R                            + 
+--R                                                3        2
+--R                              - 2304A B C + 768B  + 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D - 3840C
+--R                            + 
+--R                                     2         2        2            2
+--R                              3072A C  + (2304B  + 6912A )C - 6912A B
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2            2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D - 2816B C
+--R                            + 
+--R                                                 3        2
+--R                              - 4608A B C - 1024B  - 3840A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                       2                    3          2
+--R                              - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                            + 
+--R                                     2           2        3
+--R                              - 1024A C + 2048A B  - 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3        2  2 9
+--R                          (16D  + 16B D )a b
+--R                        + 
+--R                                            2                           3
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                            + 
+--R                                   2         2      2          2      3
+--R                              20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                         *
+--R                             3 8
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2           2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D - 104B C
+--R                            + 
+--R                                            3       2
+--R                              432A B C - 88B  - 744A B
+--R                         *
+--R                             4 7
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D + 364C
+--R                            + 
+--R                                      2          2        2           2       3
+--R                              - 380A C  + (- 828B  - 1468A )C + 452A B  - 724A
+--R                         *
+--R                             5 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2           2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D - 336B C
+--R                            + 
+--R                                              3        2
+--R                              4320A B C - 528B  - 5328A B
+--R                         *
+--R                             6 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                             7 4
+--R                            a b
+--R                        + 
+--R                                     3         2
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2            2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D + 4224B C
+--R                            + 
+--R                                               3        2
+--R                              6912A B C + 1536B  + 5760A B
+--R                         *
+--R                             8 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                             9 2
+--R                            a b
+--R                        + 
+--R                                       2         2                  2        2
+--R                              - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                     2        3        2
+--R                              2048B C  + 1024B  + 6144A B
+--R                         *
+--R                             10
+--R                            a  b
+--R                        + 
+--R                                               3          2        2           2
+--R                              8192A B D - 4096C  + 2048A C  + 4096A C - 8192A B
+--R                            + 
+--R                                     3
+--R                              - 2048A
+--R                         *
+--R                             11
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    2 2 10
+--R                      (- 32C + 96A)D a b
+--R                    + 
+--R                               3        2       2               2       2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                              2               3      2
+--R                          8B C  - 48A B C + 8B  + 72A B
+--R                     *
+--R                         3 9
+--R                        a b
+--R                    + 
+--R                                           2                           3
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                        + 
+--R                               2       2       2          2      3
+--R                          72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                     *
+--R                         4 8
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                        + 
+--R                                          3       2
+--R                          - 816A B C + 88B  + 936A B
+--R                     *
+--R                         5 7
+--R                        a b
+--R                    + 
+--R                                        2                              3
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                        + 
+--R                                 2         2        2           2       3
+--R                          1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                     *
+--R                         6 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2           2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                        + 
+--R                                           3        2
+--R                          - 3744A B C - 96B  + 1296A B
+--R                     *
+--R                         7 5
+--R                        a b
+--R                    + 
+--R                                          2                              3
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                        + 
+--R                                 2         2        2           2        3
+--R                          3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                     *
+--R                         8 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2            2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D - 4352B C
+--R                        + 
+--R                                             3         2
+--R                          - 1536A B C - 2048B  - 11520A B
+--R                     *
+--R                         9 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D + 5632C
+--R                        + 
+--R                                 2           2         2            2        3
+--R                        - 4608A C  + (- 4608B  - 11776A )C + 9728A B  - 1536A
+--R                     *
+--R                         10 2
+--R                        a  b
+--R                    + 
+--R                                2                  2        2            2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                        + 
+--R                                           3        2
+--R                          6144A B C + 2048B  + 9216A B
+--R                     *
+--R                         11
+--R                        a  b
+--R                    + 
+--R                              3        2           2  12
+--R                      (- 4096C  + 4096A C - 8192A B )a
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                           3 3 8
+--R                      32A D a c
+--R                    + 
+--R                                 3 2 2         4        3  3
+--R                          - 16A D a b  + (- 16D  - 16B D )a b
+--R                        + 
+--R                                 3           2           2      3    4
+--R                          (128A D  - 128A B D  + (- 32A C  + 32A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              3   4      4       3  2 3
+--R                          2A D a b  + (8D  + 8B D )a b
+--R                        + 
+--R                                        3          2         2      3    3 2
+--R                          ((32C - 448A)D  + 64A B D  + (16A C  - 16A )D)a b
+--R                        + 
+--R                                   4        3
+--R                              - 32D  + 32B D
+--R                            + 
+--R                                    2               2       2  2
+--R                              (- 48C  + 224A C + 64B  + 144A )D
+--R                            + 
+--R                                    2                2
+--R                              (16B C  + 96A B C - 48A B)D
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                      3           2
+--R                              - 128A D  - 512A B D
+--R                            + 
+--R                                  3         2      2          2       3
+--R                              (64C  - 128A C  - 64A C + 128A B  + 128A )D
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              4      3    5
+--R                          (- D  - B D )a b
+--R                        + 
+--R                                          3         2          2     3    2 4
+--R                          ((- 16C + 192A)D  - 8A B D  + (- 2A C  + 2A )D)a b
+--R                        + 
+--R                                  4         3       2               2      2  2
+--R                              160D  + 128B D  + (24C  - 112A C - 32B  - 72A )D
+--R                            + 
+--R                                     2                2
+--R                              (- 8B C  - 48A B C + 24A B)D
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                           3                       2
+--R                              (80C - 560A)D  + (- 96B C + 1312A B)D
+--R                            + 
+--R                                       3         2         2      2           2
+--R                                  - 48C  + 304A C  + (- 48B  - 16A )C - 112A B
+--R                                + 
+--R                                        3
+--R                                  - 368A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              128D  + 256B D
+--R                            + 
+--R                                     2               2       2  2
+--R                              (- 384C  + 512A C + 64B  + 384A )D
+--R                            + 
+--R                                       2      3       2
+--R                              (- 128B C  - 64B  - 384A B)D
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                       3           2
+--R                              - 1024A D  + 512A B D
+--R                            + 
+--R                                   3         2       2          2       3
+--R                              (256C  + 128A C  - 256A C + 512A B  - 128A )D
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                     3   6
+--R                          (2C - 22A)D a b
+--R                        + 
+--R                                   4        3        2             2     2  2
+--R                              - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D
+--R                            + 
+--R                                  2              2
+--R                              (B C  + 6A B C - 3A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                               3                    2
+--R                              (- 328C + 1896A)D  + (48B C - 528A B)D
+--R                            + 
+--R                                3         2       2      2          2       3
+--R                            (12C  - 120A C  + (24B  + 20A )C + 32A B  + 152A )D
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 224D  - 800B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (720C  - 2080A C - 512B  - 1392A )D
+--R                            + 
+--R                                    2                 3       2
+--R                              (16B C  - 672A B C + 64B  + 720A B)D
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (160C + 2976A)D  + (576B C + 1088A B)D
+--R                            + 
+--R                                        3         2        2       2
+--R                                  - 608C  + 416A C  + (288B  + 992A )C
+--R                                + 
+--R                                           2      3
+--R                                  - 1120A B  - 32A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              256D  - 256B D
+--R                            + 
+--R                                     2                 2       2  2
+--R                              (- 192C  - 1664A C - 640B  - 960A )D
+--R                            + 
+--R                                       2                   3       2
+--R                              (- 448B C  - 1152A B C - 128B  - 192A B)D
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                      3            2
+--R                              - 512A D  + 4096A B D
+--R                            + 
+--R                                     3          2       2          2        3
+--R                              (- 256C  + 1024A C  + 256A C - 512A B  - 1024A )D
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             4       3    7
+--R                          (8D  + 8B D )a b
+--R                        + 
+--R                                            3                    2
+--R                              (141C - 755A)D  + (- 6B C + 58A B)D
+--R                            + 
+--R                                  3        2        2     2         2      3
+--R                              (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    4        3
+--R                              - 284D  - 36B D
+--R                            + 
+--R                                     2                2       2  2
+--R                              (- 276C  + 888A C + 228B  + 588A )D
+--R                            + 
+--R                                    2                 3       2
+--R                              (12B C  + 312A B C - 20B  - 276A B)D
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (- 32C - 2016A)D  + (192B C - 3072A B)D
+--R                            + 
+--R                                      3         2       2       2           2
+--R                                  320C  - 720A C  + (96B  - 192A )C + 672A B
+--R                                + 
+--R                                      3
+--R                                  848A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 896D  - 384B D
+--R                            + 
+--R                                    2                 2       2  2
+--R                              (1344C  + 1408A C + 896B  + 576A )D
+--R                            + 
+--R                                      2                   3        2
+--R                              (1088B C  + 1920A B C + 384B  + 1344A B)D
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 640C + 4224A)D  + (768B C - 8448A B)D
+--R                            + 
+--R                                        3          2        2       2
+--R                                  - 128C  - 1920A C  + (384B  + 640A )C
+--R                                + 
+--R                                          2        3
+--R                                  - 128A B  + 2432A
+--R                             *
+--R                                D
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 256D  - 1280B D
+--R                            + 
+--R                                    2                 2        2  2
+--R                              (3072C  - 4096A C - 512B  - 3072A )D
+--R                            + 
+--R                                      2       3        2
+--R                              (1024B C  + 512B  + 3072A B)D
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                     3            2
+--R                              2048A D  + 2048A B D
+--R                            + 
+--R                                    3         2        2           2       3
+--R                            (- 2048C  + 512A C  + 2048A C - 4096A B  - 512A )D
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                        3   8
+--R                          (- 16C + 80A)D a b
+--R                        + 
+--R                                  4         3       2               2      2  2
+--R                              146D  + 118B D  + (30C  - 100A C - 26B  - 66A )D
+--R                            + 
+--R                                     2               3      2
+--R                              (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (726C - 2090A)D  + (- 180B C + 1100A B)D
+--R                            + 
+--R                                       3         2         2      2           2
+--R                                  - 62C  + 230A C  + (- 90B  - 58A )C - 154A B
+--R                                + 
+--R                                        3
+--R                                  - 350A
+--R                             *
+--R                                D
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              1752D  + 2760B D
+--R                            + 
+--R                                      2                 2        2  2
+--R                              (- 2160C  + 3840A C + 696B  + 2736A )D
+--R                            + 
+--R                                       2                  3        2
+--R                              (- 528B C  + 576A B C - 312B  - 2160A B)D
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                       3                         2
+--R                              - 8160A D  + (- 4608B C + 5376A B)D
+--R                            + 
+--R                                      3         2           2        2
+--R                                  864C  + 192A C  + (- 2304B  - 3936A )C
+--R                                + 
+--R                                        2        3
+--R                                  960A B  - 3264A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              1152D  + 4224B D
+--R                            + 
+--R                                      2                   2        2  2
+--R                              (- 5760C  + 11520A C + 2304B  + 8064A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 1152B C  + 2304A B C - 768B  - 5760A B)D
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                3                         2
+--R                              (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D
+--R                            + 
+--R                                       3          2           2        2
+--R                                  3840C  - 3072A C  + (- 2304B  - 6912A )C
+--R                                + 
+--R                                         2
+--R                                  6912A B
+--R                             *
+--R                                D
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 512D  + 512B D
+--R                            + 
+--R                                    2                  2       2  2
+--R                              (3840C  + 2560A C + 2048B  + 768A )D
+--R                            + 
+--R                                      2                    3        2
+--R                              (2816B C  + 4608A B C + 1024B  + 3840A B)D
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                     3            2
+--R                              2048A D  - 8192A B D
+--R                            + 
+--R                                    3          2        2           2        3
+--R                            (- 1024C  - 2048A C  + 1024A C - 2048A B  + 2048A )D
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                4        3    9
+--R                          (- 16D  - 16B D )a b
+--R                        + 
+--R                                              3                    2
+--R                              (- 308C + 972A)D  + (24B C - 104A B)D
+--R                            + 
+--R                                 3        2       2      2          2      3
+--R                              (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 456D  - 920B D
+--R                            + 
+--R                                   2                 2        2  2
+--R                              (744C  - 1712A C - 376B  - 1176A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              (104B C  - 432A B C + 88B  + 744A B)D
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                                3                      2
+--R                              (- 1668C + 8316A)D  + (1656B C - 136A B)D
+--R                            + 
+--R                                        3         2        2        2
+--R                                  - 364C  + 380A C  + (828B  + 1468A )C
+--R                                + 
+--R                                          2       3
+--R                                  - 452A B  + 724A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     4          3
+--R                              - 2496D  - 6432B D
+--R                            + 
+--R                                    2                   2        2  2
+--R                              (5328C  - 14304A C - 3408B  - 9648A )D
+--R                            + 
+--R                                     2                   3        2
+--R                              (336B C  - 4320A B C + 528B  + 5328A B)D
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              3                        2
+--R                              (6528C + 3456A)D  + (11520B C + 7296A B)D
+--R                            + 
+--R                                         3          2         2         2
+--R                                  - 3072C  + 4704A C  + (5760B  + 10752A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 4224A B  + 2976A
+--R                             *
+--R                                D
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                   4         3
+--R                              1024D  - 512B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 5760C  - 3840A C - 3072B  - 1152A )D
+--R                            + 
+--R                                        2                    3        2
+--R                              (- 4224B C  - 6912A B C - 1536B  - 5760A B)D
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              3                          2
+--R                              (1280C - 6912A)D  + (- 1536B C + 12800A B)D
+--R                            + 
+--R                                       3          2          2        2
+--R                                  1280C  + 2816A C  + (- 768B  - 2304A )C
+--R                                + 
+--R                                         2        3
+--R                                  2304A B  - 3840A
+--R                             *
+--R                                D
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                     3
+--R                              2048B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                            + 
+--R                                        2        3        2
+--R                              (- 2048B C  - 1024B  - 6144A B)D
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                         2
+--R                              - 8192A B D
+--R                            + 
+--R                                  3          2        2           2        3
+--R                            (4096C  - 2048A C  - 4096A C + 8192A B  + 2048A )D
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                  3   10
+--R                      (32C - 96A)D a b
+--R                    + 
+--R                             4        3         2               2       2  2
+--R                          24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (376C - 1416A)D  + (- 144B C - 144A B)D
+--R                        + 
+--R                              3        2         2       2          2      3
+--R                          (40C  - 72A C  + (- 72B  - 136A )C + 56A B  - 24A )D
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          360D  + 1080B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 936C  + 2608A C + 632B  + 1752A )D
+--R                        + 
+--R                                  2                 3       2
+--R                          (- 40B C  + 816A B C - 88B  - 936A B)D
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                          3                         2
+--R                          (- 24C - 4248A)D  + (- 2160B C - 2160A B)D
+--R                        + 
+--R                                  3          2           2        2           2
+--R                              536C  - 1080A C  + (- 1080B  - 1976A )C + 712A B
+--R                            + 
+--R                                    3
+--R                              - 360A
+--R                         *
+--R                            D
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                               4          3
+--R                          1152D  + 3456B D
+--R                        + 
+--R                                  2                  2        2  2
+--R                          (- 1296C  + 7968A C + 2400B  + 5040A )D
+--R                        + 
+--R                                 2                  3        2
+--R                          (816B C  + 3744A B C + 96B  - 1296A B)D
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D
+--R                        + 
+--R                                  3          2           2        2           2
+--R                              960C  - 3456A C  + (- 3456B  - 5568A )C + 768A B
+--R                            + 
+--R                                     3
+--R                              - 1152A
+--R                         *
+--R                            D
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1536D  - 4608B D
+--R                        + 
+--R                                 2                   2        2  2
+--R                          (11520C  - 12800A C - 1024B  - 9984A )D
+--R                        + 
+--R                                  2                    3         2
+--R                          (4352B C  + 1536A B C + 2048B  + 11520A B)D
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (6656C - 1536A)D  + (9216B C + 9216A B)D
+--R                        + 
+--R                                     3          2         2         2
+--R                              - 5632C  + 4608A C  + (4608B  + 11776A )C
+--R                            + 
+--R                                       2        3
+--R                              - 9728A B  + 1536A
+--R                         *
+--R                            D
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                  2        2  2
+--R                          (- 9216C  + 2048A C - 2048B  + 3072A )D
+--R                        + 
+--R                                    2                    3        2
+--R                          (- 5120B C  - 6144A B C - 2048B  - 9216A B)D
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                            3        2           2    11
+--R                      (4096C  - 4096A C + 8192A B )D a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                        4 2 8
+--R                  - 8A D a c
+--R                + 
+--R                          4   2        4         3  2
+--R                      2A D a b  + (4B D  + 8A C D )a b
+--R                    + 
+--R                                  4          3     3 2  3
+--R                      ((8C - 32A)D  + 32A B D  - 8A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            4         3    3
+--R                      (- B D  - 2A C D )a b
+--R                    + 
+--R                                     4                    3     3 2  2 2
+--R                      ((- 6C + 100A)D  + (- 4B C - 16A B)D  + 2A D )a b
+--R                    + 
+--R                               5        4        2              2      2  3
+--R                          - 12D  + 12B D  + (- 8C  - 16A C - 16B  - 52A )D
+--R                        + 
+--R                                          2   2          3     3
+--R                          (- 24A B C + 12A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      4                      3
+--R                          (32C + 24A)D  + (- 48B C + 128A B)D
+--R                        + 
+--R                              2         2      3  2       4     3 2
+--R                          (48A C - 24A B  - 32A )D  + 8A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 4                3    4
+--R                      ((C - 22A)D  + (B C + 2A B)D )a b
+--R                    + 
+--R                            5        4      2             2      2  3
+--R                          7D  - 45B D  + (6C  - 80A C + 8B  + 25A )D
+--R                        + 
+--R                                      2   2        3     3
+--R                          (6A B C - 3A B)D  + (2A C  - 2A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 88C + 118A)D  + (52B C - 312A B)D
+--R                        + 
+--R                                2       2      2          2      3  2
+--R                          (60A C  + (12B  - 12A )C + 18A B  + 80A )D
+--R                        + 
+--R                               3          2      2            4     3 2
+--R                          (4B C  + 24A B C  - 12A B C)D - 2A C  + 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5        4       2              2       2  3
+--R                          - 36D  + 52B D  + (32C  - 48A C - 44B  - 176A )D
+--R                        + 
+--R                                2                3      2   2
+--R                          (48B C  - 48A B C + 12B  + 96A B)D
+--R                        + 
+--R                             4        3      2 2      3       4         4
+--R                          (8C  - 64A C  + 12A C  + 40A C - 12A )D - 4B C
+--R                        + 
+--R                                   3      2   2
+--R                          - 24A B C  + 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4                      3
+--R                          224A D  + (- 192B C - 96A B)D
+--R                        + 
+--R                                  2       2       2          2     3  2
+--R                          (- 72A C  + (96B  + 192A )C - 96A B  + 8A )D
+--R                        + 
+--R                                  3      2           3       5        4      2 3
+--R                          (- 16B C  - 48A B C - 32A B )D - 8C  + 32A C  - 16A C
+--R                        + 
+--R                                2      3  2      4      3 2
+--R                          (24A B  - 32A )C  + 24A C + 8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          5        4       2            2     2  3    5
+--R                      (- D  + 10B D  + (- C  + 20A C - B  - 3A )D )a b
+--R                    + 
+--R                                       4                    3
+--R                          (53C - 389A)D  + (24B C + 134A B)D
+--R                        + 
+--R                                  2     2        2      3  2
+--R                          (- 15A C  - 3B C - 3A B  - 17A )D
+--R                        + 
+--R                                3         2     2
+--R                          (- B C  - 6A B C  + 3A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              5        4       2                2       2  3
+--R                          127D  - 63B D  + (48C  + 240A C + 147B  + 534A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (- 60B C  + 144A B C - 11B  - 150A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 6C  + 72A C  + (- 12B  - 15A )C
+--R                            + 
+--R                                      2      3       4
+--R                              (- 12A B  - 82A )C + 3A
+--R                         *
+--R                            D
+--R                        + 
+--R                             4         3     2   2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 164C - 696A)D  + (448B C - 184A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 96C  + 138A C  + (- 132B  - 636A )C + 192A B
+--R                            + 
+--R                                 3
+--R                              10A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                               3          2      2           3      3        5
+--R                          (4B C  + 96A B C  - 60A B C + 32A B  + 24A B)D + 6C
+--R                        + 
+--R                                 4       2      2  3        2      3  2     4
+--R                          - 64A C  + (12B  + 16A )C  + (6A B  + 80A )C  - 6A C
+--R                        + 
+--R                              3 2
+--R                          - 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             5         4        2               2       2  3
+--R                          24D  + 120B D  + (116C  + 472A C - 56B  + 196A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (12B C  - 24A B C + 24B  + 156A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              92C  - 64A C  + (12B  + 144A )C
+--R                            + 
+--R                                    2      3        4       2 2      4
+--R                              (72A B  + 48A )C + 16B  + 108A B  - 60A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3         3      2   2
+--R                          20B C  - 80A B C  + (- 12B  + 48A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          4           3
+--R                          (- 128C + 128A)D  - 896A B D
+--R                        + 
+--R                              3         2        2      2          2       3  2
+--R                          (48C  - 288A C  + (384B  - 48A )C + 96A B  + 160A )D
+--R                        + 
+--R                                     3          2         3       2            3
+--R                              - 64B C  + 96A B C  + (- 64B  - 192A B)C - 128A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4         2      2  3        2 2
+--R                          - 32C  + 16A C  + (- 16B  - 64A )C  + 96A B C
+--R                        + 
+--R                                2 2      4          4      3 2      5
+--R                          (- 48A B  + 96A )C + 32A B  + 32A B  - 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                    4                    3    6
+--R                      ((- 8C + 80A)D  + (- 8B C - 16A B)D )a b
+--R                    + 
+--R                               5         4         2               2       2  3
+--R                          - 62D  + 158B D  + (- 47C  + 239A C - 66B  - 218A )D
+--R                        + 
+--R                                2               3      2   2
+--R                          (12B C  - 30A B C + 2B  + 30A B)D
+--R                        + 
+--R                            4        3      2     2  2        2      3
+--R                          (C  - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (229C + 559A)D  + (- 438B C + 584A B)D
+--R                        + 
+--R                              3         2        2       2          2       3  2
+--R                          (64C  - 444A C  + (- 3B  + 213A )C - 93A B  - 175A )D
+--R                        + 
+--R                                     3           2      3       2          3
+--R                              - 10B C  - 180A B C  + (8B  + 144A B)C - 6A B
+--R                            + 
+--R                                  3
+--R                              - 6A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2     2  3          2      3  2
+--R                          - C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5         4          2                2       2  3
+--R                          36D  - 340B D  + (- 237C  - 638A C + 116B  + 123A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 123B C  + 102A B C - 68B  - 363A B)D
+--R                        + 
+--R                                   4         3        2       2  2
+--R                              - 95C  + 312A C  + (- 3B  - 138A )C
+--R                            + 
+--R                                      2       3        4      2 2       4
+--R                              (- 66A B  - 120A )C - 16B  - 99A B  + 105A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4           3        3       2   2
+--R                          5B C  + 176A B C  + (- 5B  - 138A B)C
+--R                        + 
+--R                                3      3        2 3     4
+--R                          (10A B  + 16A B)C + 3A B  + 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (276C - 916A)D  + (416B C + 2048A B)D
+--R                        + 
+--R                                    3         2           2       2          2
+--R                              - 252C  + 636A C  + (- 1032B  - 516A )C - 72A B
+--R                            + 
+--R                                    3
+--R                              - 380A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3           2       2            3      3
+--R                          (- 40B C  - 216A B C  + 168A B C + 256A B  - 40A B)D
+--R                        + 
+--R                             5        4      2       2  3            2      3  2
+--R                          56C  - 80A C  + (4B  + 128A )C  + (- 132A B  + 64A )C
+--R                        + 
+--R                              4       2 2       4         4      3 2      5
+--R                          (20B  + 156A B  - 184A )C - 4A B  - 28A B  + 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              5         4          2               2        2  3
+--R                          144D  - 176B D  + (- 368C  + 736A C - 64B  + 1040A )D
+--R                        + 
+--R                                   2                  2   2
+--R                          (- 528B C  - 480A B C - 528A B)D
+--R                        + 
+--R                                  4        3        2      2  2
+--R                              128C  + 64A C  + (240B  + 96A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (288A B  - 128A )C + 48B  + 240A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4       3      2   2            3      3
+--R                          96B C  + (16B  + 96A B)C  + (- 160A B  - 64A B)C
+--R                        + 
+--R                               5       2 3
+--R                          - 16B  - 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 128C - 384A)D  + (768B C - 512A B)D
+--R                        + 
+--R                               3       2          2       3  2
+--R                          (192C  - 960A C + 768A B  + 128A )D
+--R                        + 
+--R                                   2       3        3           4      2 3
+--R                          (384A B C  - 256B C + 128A B)D - 64A C  - 64B C
+--R                        + 
+--R                              3 2       2 2          4      5
+--R                          128A C  - 192A B C + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         5        4      2             2      2  3    7
+--R                      (8D  - 32B D  + (8C  - 64A C + 8B  + 24A )D )a b
+--R                    + 
+--R                                          4                   3
+--R                          (- 118C + 412A)D  + (2B C - 264A B)D
+--R                        + 
+--R                                3        2      2      2          2      3  2
+--R                          (- 10C  + 96A C  + (6B  - 18A )C + 12A B  + 36A )D
+--R                        + 
+--R                               3          2        3      2
+--R                          (2B C  + 36A B C  + (- 2B  - 30A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5        4
+--R                          - 287D  + 30B D
+--R                        + 
+--R                                2                2        2  3
+--R                          (- 28C  - 682A C - 308B  - 1180A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (240B C  - 168A B C + 50B  + 414A B)D
+--R                        + 
+--R                                 4         3       2      2  2
+--R                              35C  - 170A C  + (54B  + 78A )C
+--R                            + 
+--R                                    2       3       4      2 2      4
+--R                              (66A B  + 198A )C + 3B  + 18A B  - 21A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      3      2   2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (81C + 1825A)D  + (- 528B C - 1756A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                572C  - 60A C  + (936B  + 2010A )C - 108A B
+--R                              + 
+--R                                    3
+--R                                658A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2            3
+--R                              92B C  - 120A B C  + (20B  + 264A B)C - 160A B
+--R                            + 
+--R                                    3
+--R                              - 100A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5         4         2      2  3
+--R                          - 29C  + 119A C  + (- 54B  - 80A )C
+--R                        + 
+--R                                  2       3  2        4      2 2      4        4
+--R                          (- 30A B  - 188A )C  + (- 5B  - 36A B  + 37A )C - A B
+--R                        + 
+--R                            3 2     5
+--R                          4A B  - 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 412D  + 132B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (466C  - 2484A C + 248B  - 2718A )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (1374B C  + 996A B C + 120B  + 702A B)D
+--R                        + 
+--R                                    4         3         2       2  2
+--R                              - 366C  - 192A C  + (- 18B  - 492A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 396A B  + 208A )C - 108B  - 690A B  + 170A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4          3       3       2   2
+--R                          - 190B C  + 96A B C  + (34B  - 204A B)C
+--R                        + 
+--R                                 3       3        5      2 3      4
+--R                          (220A B  + 304A B)C + 4B  + 82A B  + 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         4                        3
+--R                          (936C + 1176A)D  + (- 768B C + 1536A B)D
+--R                        + 
+--R                                 3         2          2        2            2
+--R                              24C  + 696A C  + (- 240B  + 3144A )C - 1392A B
+--R                            + 
+--R                                  3
+--R                              200A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2        3       2
+--R                              - 144B C  - 1296A B C  + (320B  + 336A B)C
+--R                            + 
+--R                                   3       3
+--R                              64A B  - 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2      2  3
+--R                          16C  + 80A C  + (- 8B  + 32A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 168A B  - 320A )C  + (40B  + 552A B  - 176A )C
+--R                        + 
+--R                                  4     3 2       5
+--R                          - 168A B  + 8A B  + 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                             5         4          2                 2       2  3
+--R                          96D  - 672B D  + (- 768C  - 1536A C + 384B  + 192A )D
+--R                        + 
+--R                                   2                   2   2
+--R                          (- 384B C  - 384A B C - 1344A B)D
+--R                        + 
+--R                                    4        2       2  2       3       4
+--R                              - 352C  + (384B  - 768A )C  - 384A C - 32B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 224A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3 2       3         5
+--R                          - 32B C  + 256A B C  + 128B C  + 384A B C - 32B
+--R                        + 
+--R                                2 3       4
+--R                          - 128A B  + 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  4                      3
+--R                          - 384A D  + (768B C + 1536A B)D
+--R                        + 
+--R                                  2           2       2           2       3  2
+--R                          (1152A C  + (- 1536B  - 768A )C + 384A B  - 128A )D
+--R                        + 
+--R                                 3       2            3         5         4
+--R                          (256B C  + 768A B C + 512A B )D + 128C  - 128A C
+--R                        + 
+--R                              2 3            2       3  2       4        3 2
+--R                          256A C  + (- 384A B  + 128A )C  - 384A C - 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                   4                   3    8
+--R                      ((16C - 96A)D  + (16B C + 32A B)D )a b
+--R                    + 
+--R                              5         4       2                2       2  3
+--R                          136D  - 168B D  + (92C  - 188A C + 136B  + 472A )D
+--R                        + 
+--R                                  2               3      2   2
+--R                          (- 48B C  + 24A B C - 8B  - 72A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 20A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 36A )C
+--R                         *
+--R                            D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 12C - 1996A)D  + (864B C + 640A B)D
+--R                        + 
+--R                                    3         2          2       2          2
+--R                              - 296C  + 720A C  + (- 252B  - 732A )C + 36A B
+--R                            + 
+--R                                   3
+--R                              - 84A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2           3
+--R                              - 48B C  + 288A B C  + (- 40B  - 408A B)C + 24A B
+--R                            + 
+--R                                 3
+--R                              24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3         2      3  2
+--R                          4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          636D  + 544B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 104C  + 3740A C + 120B  + 3228A )D
+--R                        + 
+--R                                    2                 3       2   2
+--R                          (- 1380B C  - 912A B C - 96B  - 804A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              188C  - 300A C  + (- 192B  + 156A )C
+--R                            + 
+--R                                     2       3        4       2 2       4
+--R                              (108A B  - 340A )C + 76B  + 468A B  - 216A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          68B C  - 272A B C  + (28B  + 384A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            4                        3
+--R                          (- 1528C - 1376A)D  + (- 520B C - 1200A B)D
+--R                        + 
+--R                                    3          2        2        2            2
+--R                              - 544C  - 1968A C  + (132B  - 4740A )C + 1068A B
+--R                            + 
+--R                                     3
+--R                              - 1012A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2           3
+--R                              360B C  + 1584A B C  + (- 16B  - 480A B)C - 56A B
+--R                            + 
+--R                                  3
+--R                              600A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3
+--R                          - 8C  - 64A C  + (188B  - 28A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (252A B  + 412A )C  + (- 100B  - 768A B  + 308A )C
+--R                        + 
+--R                               4      3 2      5
+--R                          12A B  - 64A B  - 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 304D  + 944B D
+--R                        + 
+--R                               2                  2       2  3
+--R                          (708C  + 3096A C - 1072B  - 268A )D
+--R                        + 
+--R                                   2                  3        2   2
+--R                          (- 132B C  + 360A B C - 208B  + 2028A B)D
+--R                        + 
+--R                                  4         3          2        2  2
+--R                              636C  + 448A C  + (- 996B  + 1512A )C
+--R                            + 
+--R                                      2       3        4       2 2       4
+--R                              (- 24A B  + 576A )C + 80B  + 924A B  - 356A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3      2   2
+--R                          108B C  - 256A B C  + (- 252B  - 24A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (120A B  - 768A B)C + 80B  + 356A B  - 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                        4                         3
+--R                          (48C + 1776A)D  + (- 1728B C - 3456A B)D
+--R                        + 
+--R                               3          2         2        2         3  2
+--R                          (816C  - 2928A C  + (3168B  + 1680A )C + 432A )D
+--R                        + 
+--R                                    3          2        3      2            3
+--R                              224B C  + 96A B C  + (256B  - 96A B)C - 768A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2       2  3
+--R                          - 160C  + 160A C  + (48B  - 384A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (336A B  - 160A )C  + (- 80B  - 432A B  + 544A )C
+--R                        + 
+--R                                  4      3 2
+--R                          - 112A B  + 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  4        2                 2        2  3
+--R                          - 384B D  + (960C  - 2688A C + 960B  - 1344A )D
+--R                        + 
+--R                                  2                   3       2   2
+--R                          (1344B C  + 2688A B C - 192B  + 576A B)D
+--R                        + 
+--R                                    4         3          2       2  2
+--R                              - 640C  + 768A C  + (- 960B  - 576A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1152A B  - 128A )C - 192B  - 960A B  + 320A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3         3       2   2
+--R                          - 320B C  + 384A B C  + (- 64B  - 576A B)C
+--R                        + 
+--R                                 3       3         5       2 3
+--R                          (640A B  + 256A B)C + 64B  + 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   3
+--R                          1536A B D
+--R                        + 
+--R                                    3          2           2       2
+--R                              - 768C  + 1152A C  + (- 1536B  + 768A )C
+--R                            + 
+--R                                       2       3
+--R                              - 1536A B  - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2
+--R                              256B C  - 1536A B C  + (1024B  + 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4        2       2  3         2 2
+--R                          128C  - 256A C  + (256B  + 256A )C  - 384A B C
+--R                        + 
+--R                               2 2       4           4       3 2       5
+--R                          (768A B  - 384A )C - 512A B  - 128A B  + 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                        5        4         2              2      2  3    9
+--R                  (- 16D  + 32B D  + (- 16C  + 64A C - 16B  - 48A )D )a b
+--R                + 
+--R                                  4                      3
+--R                      (8C + 224A)D  + (- 136B C - 64A B)D
+--R                    + 
+--R                          3         2       2      2    2
+--R                      (40C  - 144A C  + (24B  + 72A )C)D
+--R                    + 
+--R                           3          2      3      2
+--R                      (8B C  - 48A B C  + (8B  + 72A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            5        4         2               2       2  3
+--R                      - 148D  + 88B D  + (- 64C  - 104A C - 64B  - 592A )D
+--R                    + 
+--R                             2                3      2   2
+--R                      (192B C  + 192A B C + 8B  + 72A B)D
+--R                    + 
+--R                               4        3       2      2  2           2      3
+--R                          - 28C  + 88A C  + (24B  - 24A )C  + (- 24A B  + 24A )C
+--R                        + 
+--R                               4      2 2      4
+--R                          - 12B  - 72A B  + 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4          3        3      2   2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (212C + 1532A)D  + (- 664B C - 112A B)D
+--R                    + 
+--R                           3         2         2       2           2      3  2
+--R                      (232C  - 528A C  + (- 24B  + 864A )C - 144A B  + 88A )D
+--R                    + 
+--R                                   3           2       3       2           3
+--R                            - 40B C  - 528A B C  + (40B  + 456A B)C + 32A B
+--R                          + 
+--R                                 3
+--R                            - 80A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        5        4         2      2  3           2      3  2
+--R                      4C  - 12A C  + (- 24B  + 16A )C  + (- 24A B  - 32A )C
+--R                    + 
+--R                          4       2 2      4         4      3 2      5
+--R                      (20B  + 144A B  - 52A )C + 4A B  + 16A B  + 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                            5          4        2                 2        2  3
+--R                      - 124D  - 1208B D  + (248C  - 4328A C + 416B  - 1336A )D
+--R                    + 
+--R                              2                  3       2   2
+--R                      (1176B C  + 912A B C + 104B  + 240A B)D
+--R                    + 
+--R                                4         3        2       2  2
+--R                          - 188C  + 424A C  + (384B  - 264A )C
+--R                        + 
+--R                                  2       3        4       2 2       4
+--R                          (- 24A B  + 136A )C - 68B  - 480A B  + 244A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3         3       2   2
+--R                      - 32B C  + 304A B C  + (- 16B  - 408A B)C
+--R                    + 
+--R                              3      3         5      2 3      4
+--R                      (- 80A B  + 64A B)C - 16B  - 88A B  + 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      4                       3
+--R                      (1028C - 2044A)D  + (3104B C + 2864A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 560C  + 4512A C  + (- 1536B  + 1848A )C - 816A B
+--R                        + 
+--R                              3
+--R                          616A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3           2          3       2            3
+--R                          - 736B C  - 768A B C  + (- 304B  - 912A B)C + 224A B
+--R                        + 
+--R                                3
+--R                          - 496A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4          2       2  3
+--R                      28C  - 52A C  + (- 200B  + 112A )C
+--R                    + 
+--R                               2       3  2        4       2 2       4
+--R                      (- 168A B  - 224A )C  + (140B  + 912A B  - 364A )C
+--R                    + 
+--R                           4       3 2      5
+--R                      92A B  + 112A B  + 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                          5          4           2                 2        2  3
+--R                      288D  + 1088B D  + (- 1896C  + 4752A C - 720B  + 2552A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 2712B C  - 4560A B C + 272B  - 2424A B)D
+--R                    + 
+--R                              4          3         2       2  2
+--R                          280C  - 2048A C  + (1320B  - 480A )C
+--R                        + 
+--R                                  2       3         4       2 2       4
+--R                          (1200A B  - 416A )C + 208B  + 744A B  - 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3        2   2
+--R                      232B C  - 608A B C  + (344B  + 1248A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 560A B  + 448A B)C - 112B  - 616A B  + 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                       4                         3
+--R                      (- 1248C + 288A)D  + (- 2304B C - 2688A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          1056C  - 3840A C  + (1536B  - 3552A )C + 2496A B
+--R                        + 
+--R                                3
+--R                          - 704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2          3       2            3
+--R                          768B C  + 2880A B C  + (- 768B  + 384A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          1088A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4         2       2  3
+--R                      - 32C  + 320A C  + (- 32B  - 128A )C
+--R                    + 
+--R                             2       3  2          4        2 2       4
+--R                      (192A B  + 256A )C  + (- 160B  - 1824A B  + 416A )C
+--R                    + 
+--R                            4       3 2       5
+--R                      416A B  - 128A B  - 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                2       2  3
+--R                      (1728C  - 384A C + 384B  - 576A )D
+--R                    + 
+--R                              2                   3        2   2
+--R                      (1344B C  + 3456A B C - 384B  + 2112A B)D
+--R                    + 
+--R                               4          3           2       2  2
+--R                          - 64C  + 1536A C  + (- 1728B  + 768A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1152A B  + 256A )C - 128B  - 192A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3       2   2
+--R                      - 192B C  + 256A B C  + (- 320B  - 768A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (640A B  - 512A B)C + 128B  + 704A B  - 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                             3       2           2  2
+--R                      (- 768C  + 768A C - 1536A B )D
+--R                    + 
+--R                                  2        3        3            4       2 3
+--R                      (- 1536A B C  + 1024B C - 512A B)D - 256A C  + 256B C
+--R                    + 
+--R                          2 2          4       5
+--R                      768A B C - 512A B  + 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                %%BN1
+--R            + 
+--R                       3 3 8
+--R                  16A D a c
+--R                + 
+--R                            3 2 2          3          2  3
+--R                      - 4A D a b  + (- 8B D  - 24A C D )a b
+--R                    + 
+--R                                     3          2         2      3    4
+--R                      ((- 16C + 64A)D  - 80A B D  + (16A C  + 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                           3         2  2 3
+--R                      (2B D  + 6A C D )a b
+--R                    + 
+--R                                    3                   2        2      3    3 2
+--R                      ((12C - 188A)D  + (12B C + 52A B)D  + (4A C  - 12A )D)a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          24D  - 16B D  + (24C  - 16A C + 40B  + 120A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 8B C  + 48A B C - 24A B)D - 8A C  + 8A C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        3                    2
+--R                          (- 64C - 32A)D  + (96B C - 320A B)D
+--R                        + 
+--R                                3        2       2          2      3
+--R                          (- 16C  + 64A C  - 112A C + 128A B  + 64A )D
+--R                        + 
+--R                                   2      3
+--R                          - 48A B C  - 16A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                      3                   2          2     3
+--R                        ((- 2C + 41A)D  + (- 3B C - 8A B)D  + (- 2A C  + 2A )D)
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 80B D  + (- 18C  + 224A C - 26B  - 66A )D
+--R                        + 
+--R                                 2                2          3     3
+--R                          (- 2B C  - 36A B C + 18A B)D + 2A C  - 2A C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                        3                       2
+--R                          (144C - 232A)D  + (- 120B C + 808A B)D
+--R                        + 
+--R                             3         2         2      2           2       3
+--R                          (4C  - 212A C  + (- 24B  + 20A )C - 112A B  - 196A )D
+--R                        + 
+--R                              3          2      2        3
+--R                          4B C  + 36A B C  - 12A B C + 4A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             4        3       2              2       2  2
+--R                          64D  - 96B D  + (24C  + 80A C + 64B  + 408A )D
+--R                        + 
+--R                                  2                3       2        4        3
+--R                          (- 80B C  + 96A B C - 64B  - 336A B)D + 8C  + 32A C
+--R                        + 
+--R                              2      2  2         2      3        2 2     4
+--R                          (24B  + 48A )C  + (48A B  + 32A )C + 24A B  + 8A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                  3                     2
+--R                          - 384A D  + (384B C + 128A B)D
+--R                        + 
+--R                                3         2          2       2           2
+--R                          (- 64C  + 128A C  + (- 192B  - 448A )C + 512A B )D
+--R                        + 
+--R                               3           2       2           3      3
+--R                          64B C  - 192A B C  + 192A B C - 64A B  - 64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                            4        3      2             2     2  2
+--R                          2D  - 18B D  + (3C  - 52A C + 4B  + 9A )D
+--R                        + 
+--R                              2              2
+--R                          (B C  + 6A B C - 3A B)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (- 86C + 686A)D  + (- 54B C - 420A B)D
+--R                        + 
+--R                             3       2       2      2          2       3
+--R                          (4C  - 9A C  + (18B  + 14A )C + 32A B  + 115A )D
+--R                        + 
+--R                               3         2     2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                4        3
+--R                          - 224D  + 92B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 162C  - 280A C - 320B  - 1206A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (172B C  - 336A B C + 60B  + 492A B)D - 6C  + 48A C
+--R                        + 
+--R                                2      2  2           2      3       2 2     4
+--R                          (- 18B  - 24A )C  + (- 24A B  - 80A )C - 6A B  - 2A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                       2
+--R                          (232C + 1128A)D  + (- 936B C + 584A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              208C  - 400A C  + (312B  + 1376A )C - 1192A B
+--R                            + 
+--R                                 3
+--R                              64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2         3       2           3
+--R                          - 96B C  + 384A B C  + (- 24B  - 240A B)C + 24A B
+--R                        + 
+--R                              3
+--R                          144A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               4         3          2               2       2  2
+--R                          - 64D  - 256B D  + (- 144C  - 608A C + 32B  - 336A )D
+--R                        + 
+--R                                  2      3       2         4        3
+--R                          (- 64B C  - 64B  - 768A B)D - 48C  + 96A C
+--R                        + 
+--R                                2      2  2         2       3        4       2 2
+--R                          (- 48B  - 96A )C  + (96A B  - 224A )C + 32B  + 144A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                        3            2
+--R                          (256C - 256A)D  + 1792A B D
+--R                        + 
+--R                                   3         2          2      2           2
+--R                              - 64C  + 256A C  + (- 768B  + 64A )C - 128A B
+--R                            + 
+--R                                    3
+--R                              - 256A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3       2            3
+--R                          256B C  - 192A B C  + (128B  + 768A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       3                   2
+--R                          (13C - 139A)D  + (18B C + 58A B)D
+--R                        + 
+--R                              3        2        2     2         2      3
+--R                          (- C  + 13A C  + (- 3B  - 3A )C - 3A B  - 17A )D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                              4         3        2                2       2  2
+--R                          109D  - 265B D  + (114C  - 591A C + 183B  + 543A )D
+--R                        + 
+--R                                  2                 3       2       4        3
+--R                          (- 27B C  + 228A B C - 19B  - 225A B)D + C  - 13A C
+--R                        + 
+--R                             2     2  2        2      3
+--R                          (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (- 258C - 874A)D  + (978B C - 1542A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 94C  + 990A C  + (- 54B  - 426A )C + 714A B
+--R                            + 
+--R                                  3
+--R                              346A
+--R                         *
+--R                            D
+--R                        + 
+--R                               3           2       3       2          3      3
+--R                          10B C  - 234A B C  + (14B  + 174A B)C - 2A B  - 30A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                3        2               2       2  2
+--R                          768B D  + (192C  + 736A C + 80B  - 384A )D
+--R                        + 
+--R                                 2                 3        2            3
+--R                          (272B C  - 96A B C + 384B  + 1968A B)D - 368A C
+--R                        + 
+--R                                2       2  2            2       3        4
+--R                          (- 48B  - 192A )C  + (- 288A B  + 112A )C - 16B
+--R                        + 
+--R                                2 2      4
+--R                          - 240A B  - 64A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                           3                        2
+--R                          (- 384C + 1536A)D  + (- 576B C - 4032A B)D
+--R                        + 
+--R                                  3         2         2        2           2
+--R                              416C  - 672A C  + (2112B  + 1312A )C - 512A B
+--R                            + 
+--R                                  3
+--R                              992A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 480B C  + 672A B C  + (- 128B  - 1632A B)C + 512A B
+--R                        + 
+--R                              3
+--R                          160A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 256D  + 384B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (192C  - 1024A C + 256B  - 2112A )D
+--R                        + 
+--R                                 2                  3        2          4
+--R                          (640B C  + 768A B C + 256B  + 1152A B)D - 192C
+--R                        + 
+--R                                 2       2  2            2       3         2 2
+--R                          (- 576B  - 384A )C  + (- 384A B  - 512A )C + 192A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (256C + 512A)D  + (- 1536B C + 1280A B)D
+--R                        + 
+--R                                   2        2           2       3         3
+--R                          (- 256A C  + 2048A C - 2560A B  - 256A )D + 512B C
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                               4        3         2               2      2  2
+--R                          - 14D  + 54B D  + (- 18C  + 140A C - 26B  - 66A )D
+--R                        + 
+--R                                 2               3      2
+--R                          (- 2B C  - 36A B C + 2B  + 30A B)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                        3                      2
+--R                          (142C - 688A)D  + (- 54B C + 800A B)D
+--R                        + 
+--R                                    3         2         2      2           2
+--R                                - 6C  - 100A C  + (- 54B  - 22A )C - 160A B
+--R                              + 
+--R                                      3
+--R                                - 248A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3          2        3      2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              4         3       2                 2        2  2
+--R                          416D  - 190B D  + (84C  + 1254A C + 438B  + 2514A )D
+--R                        + 
+--R                                   2                  3        2         4
+--R                          (- 666B C  + 264A B C - 298B  - 1758A B)D + 20C
+--R                        + 
+--R                                 3       2       2  2          2       3       4
+--R                          - 22A C  + (66B  + 102A )C  + (114A B  + 158A )C + 2B
+--R                        + 
+--R                             2 2      4
+--R                          48A B  + 14A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 284C - 2876A)D  + (588B C + 3516A B)D
+--R                        + 
+--R                                    3        2           2        2            2
+--R                              - 788C  - 84A C  + (- 2292B  - 4428A )C + 1404A B
+--R                            + 
+--R                                     3
+--R                              - 2252A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          532B C  - 492A B C  + (148B  + 1164A B)C - 140A B
+--R                        + 
+--R                                3
+--R                          - 308A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          608D  - 640B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 240C  + 3552A C - 960B  + 5232A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 1632B C  - 1536A B C - 928B  - 1632A B)D + 464C
+--R                        + 
+--R                                3        2        2  2          2        3
+--R                          128A C  + (912B  + 1344A )C  + (384A B  + 1664A )C
+--R                        + 
+--R                                4       2 2      4
+--R                          - 160B  - 528A B  - 16A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            3                       2
+--R                          (- 1280C - 1664A)D  + (1920B C - 3456A B)D
+--R                        + 
+--R                                    3         2        2        2            2
+--R                              - 128C  - 576A C  + (192B  - 6144A )C + 4800A B
+--R                            + 
+--R                                    3
+--R                              - 704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2          3       2            3
+--R                          256B C  + 768A B C  + (- 704B  - 384A B)C + 448A B
+--R                        + 
+--R                                3
+--R                          - 128A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 128D  + 1280B D
+--R                        + 
+--R                               2                 2       2  2
+--R                          (768C  + 2560A C - 640B  - 768A )D
+--R                        + 
+--R                                 2                   2          4         3
+--R                          (896B C  + 768A B C + 4224A B)D + 128C  + 128A C
+--R                        + 
+--R                                 2       2  2            2       3         4
+--R                          (- 384B  + 768A )C  + (- 768A B  + 896A )C - 256B
+--R                        + 
+--R                                2 2       4
+--R                          - 384A B  + 128A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                3                         2
+--R                          512A D  + (- 1536B C - 2048A B)D
+--R                        + 
+--R                               3          2         2        2            2
+--R                          (256C  - 2048A C  + (3072B  + 1792A )C - 2048A B )D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                        - 1024B C  + 768A B C  - 3072A B C + 1024A B  + 256A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                         3                      2
+--R                          (- 20C + 156A)D  + (- 24B C - 104A B)D
+--R                        + 
+--R                             3        2       2      2          2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C + 12A B  + 36A )D
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 204D  + 316B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 144C  + 364A C - 292B  - 1092A )D
+--R                        + 
+--R                                 2                 3       2        4        3
+--R                          (164B C  - 288A B C + 84B  + 636A B)D - 4C  + 20A C
+--R                        + 
+--R                                2      2  2           2      3
+--R                          (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                        3                         2
+--R                          (36C + 3084A)D  + (- 1368B C - 1312A B)D
+--R                        + 
+--R                                  3          2        2        2           2
+--R                              428C  - 1348A C  + (996B  + 1780A )C - 644A B
+--R                            + 
+--R                                  3
+--R                              996A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2         3       2          3
+--R                          - 128B C  + 312A B C  + (- 64B  - 528A B)C + 8A B
+--R                        + 
+--R                             3
+--R                          56A B
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 924D  - 588B D
+--R                        + 
+--R                               2                2        2  2
+--R                          (216C  - 5556A C - 60B  - 6156A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (2172B C  + 1584A B C + 444B  + 1332A B)D - 252C
+--R                        + 
+--R                                3          2       2  2         2        3
+--R                          708A C  + (- 540B  - 396A )C  + (36A B  - 1236A )C
+--R                        + 
+--R                             4       2 2       4
+--R                          72B  + 576A B  + 120A
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          3                      2
+--R                          (2184C + 2040A)D  + (648B C + 2616A B)D
+--R                        + 
+--R                                  3          2        2        2            2
+--R                              408C  + 2760A C  + (504B  + 9096A )C - 3720A B
+--R                            + 
+--R                                   3
+--R                              2904A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3       2            3
+--R                          - 840B C  - 1656A B C  + (168B  + 360A B)C - 792A B
+--R                        + 
+--R                              3
+--R                          408A B
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          480D  - 1536B D
+--R                        + 
+--R                                 2                  2        2  2
+--R                          (- 864C  - 4992A C + 2400B  + 1440A )D
+--R                        + 
+--R                                    2                  3        2          4
+--R                          (- 1056B C  - 576A B C + 768B  - 6624A B)D - 384C
+--R                        + 
+--R                                  3        2        2  2           2        3
+--R                          - 864A C  + (576B  - 2304A )C  + (1152A B  - 2208A )C
+--R                        + 
+--R                              4       2 2       4
+--R                          576B  + 576A B  - 384A
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                           3                       2
+--R                          (- 256C - 2688A)D  + (2688B C + 4736A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1216C  + 4544A C  + (- 6528B  - 4032A )C
+--R                            + 
+--R                                     2        3
+--R                              2304A B  - 1344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                          1344B C  - 1728A B C  + 5184A B C - 1536A B  - 192A B
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                3           2                  2        2  2
+--R                          512B D  + (- 1152C  + 4352A C - 2048B  + 1920A )D
+--R                        + 
+--R                                    2                   2          4         3
+--R                          (- 1280B C  - 4608A B C + 768A B)D + 640C  - 512A C
+--R                        + 
+--R                                2       2  2          2        3          2 2
+--R                          (1920B  + 768A )C  + (768A B  + 1536A )C - 1152A B
+--R                        + 
+--R                                4
+--R                          - 384A
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                     2
+--R                          - 2048A B D
+--R                        + 
+--R                                3          2         2        2            2
+--R                          (1024C  - 2048A C  + (3072B  - 1024A )C + 2048A B )D
+--R                        + 
+--R                                   3            2           3        2
+--R                          - 1024B C  + 3072A B C  + (- 2048B  - 3072A B)C
+--R                        + 
+--R                                 3        3
+--R                          1024A B  + 1024A B
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                         4        3       2               2       2  2
+--R                      24D  - 56B D  + (24C  - 112A C + 40B  + 120A )D
+--R                    + 
+--R                             2               3      2
+--R                      (- 8B C  + 48A B C - 8B  - 72A B)D
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                    3                    2
+--R                      (- 8C - 336A)D  + (216B C + 96A B)D
+--R                    + 
+--R                            3         2          2       2          2      3
+--R                      (- 56C  + 240A C  + (- 120B  - 184A )C + 80A B  - 96A )D
+--R                    + 
+--R                          3          2      3      2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                          4         3       2               2        2  2
+--R                      216D  - 192B D  + (72C  + 40A C + 176B  + 1248A )D
+--R                    + 
+--R                               2                3       2         4         3
+--R                      (- 304B C  - 48A B C - 64B  - 384A B)D + 32C  - 120A C
+--R                    + 
+--R                        2      2  2           2       3       4      2 2      4
+--R                    (72B  + 24A )C  + (- 24A B  + 152A )C - 8B  - 96A B  - 24A
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                       3                      2
+--R                      (- 264C - 2304A)D  + (1080B C + 144A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 280C  + 1008A C  + (- 504B  - 1880A )C + 736A B
+--R                        + 
+--R                                3
+--R                          - 864A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3          2      3       2            3      3
+--R                      120B C  + 96A B C  + (8B  + 216A B)C + 144A B  - 16A B
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                          4          3          2                 2        2  2
+--R                      144D  + 1848B D  + (- 576C  + 6600A C - 984B  + 1800A )D
+--R                    + 
+--R                                2                   3        2          4
+--R                      (- 1416B C  - 2304A B C - 120B  + 1800A B)D + 192C
+--R                    + 
+--R                              3        2       2  2            2        3
+--R                      - 648A C  + (216B  + 360A )C  + (- 360A B  + 1128A )C
+--R                    + 
+--R                            4       2 2      4
+--R                      - 120B  - 576A B  - 72A
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 1392C + 3024A)D  + (- 4752B C - 4464A B)D
+--R                    + 
+--R                                 3          2         2        2           2
+--R                            1104C  - 6624A C  + (3312B  - 2544A )C + 336A B
+--R                          + 
+--R                                  3
+--R                            - 576A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3            2          3        2             3
+--R                      384B C  + 3024A B C  + (- 144B  - 2592A B)C + 1008A B
+--R                    + 
+--R                            3
+--R                      - 240A B
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                            4          3
+--R                      - 384D  - 1600B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (2784C  - 7040A C + 1280B  - 3936A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (3776B C  + 8448A B C - 832B  + 1728A B)D - 480C
+--R                    + 
+--R                             3           2        2  2             2       3
+--R                      2304A C  + (- 2592B  + 1152A )C  + (- 1152A B  - 768A )C
+--R                    + 
+--R                            4        2 2       4
+--R                      - 384B  + 1440A B  + 864A
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                     3                       2
+--R                      (1664C - 384A)D  + (3456B C + 4224A B)D
+--R                    + 
+--R                                 3          2           2        2            2
+--R                          - 1792C  + 5376A C  + (- 2688B  + 5632A )C - 3200A B
+--R                        + 
+--R                               3
+--R                          1536A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2         3        2             3
+--R                      - 512B C  - 6144A B C  + (2176B  + 2304A B)C - 1152A B
+--R                    + 
+--R                            3
+--R                      - 768A B
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                              2                2       2  2
+--R                      (- 2304C  + 512A C - 512B  + 768A )D
+--R                    + 
+--R                                2                    3        2          4
+--R                      (- 2048B C  - 6144A B C + 1024B  - 3072A B)D + 256C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 1536A C  + (2304B  - 1536A )C  + (1536A B  - 512A )C
+--R                    + 
+--R                          4       2 2       4
+--R                      512B  - 768A B  - 768A
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                            3        2           2              2        3
+--R                      (1024C  - 1024A C + 2048A B )D + 3072A B C  - 2048B C
+--R                    + 
+--R                           3
+--R                      1024A B
+--R                 *
+--R                     11
+--R                    a
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                        4 2 8
+--R                  - 8A D a c
+--R                + 
+--R                          4   2        4         3  2
+--R                      2A D a b  + (4B D  + 8A C D )a b
+--R                    + 
+--R                                  4          3     3 2  3
+--R                      ((8C - 32A)D  + 32A B D  - 8A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            4         3    3
+--R                      (- B D  - 2A C D )a b
+--R                    + 
+--R                                     4                    3     3 2  2 2
+--R                      ((- 6C + 100A)D  + (- 4B C - 16A B)D  + 2A D )a b
+--R                    + 
+--R                               5        4        2              2      2  3
+--R                          - 12D  + 12B D  + (- 8C  - 16A C - 16B  - 52A )D
+--R                        + 
+--R                                          2   2          3     3
+--R                          (- 24A B C + 12A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      4                      3
+--R                          (32C + 24A)D  + (- 48B C + 128A B)D
+--R                        + 
+--R                              2         2      3  2       4     3 2
+--R                          (48A C - 24A B  - 32A )D  + 8A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 4                3    4
+--R                      ((C - 22A)D  + (B C + 2A B)D )a b
+--R                    + 
+--R                            5        4      2             2      2  3
+--R                          7D  - 45B D  + (6C  - 80A C + 8B  + 25A )D
+--R                        + 
+--R                                      2   2        3     3
+--R                          (6A B C - 3A B)D  + (2A C  - 2A C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         4                    3
+--R                          (- 88C + 118A)D  + (52B C - 312A B)D
+--R                        + 
+--R                                2       2      2          2      3  2
+--R                          (60A C  + (12B  - 12A )C + 18A B  + 80A )D
+--R                        + 
+--R                               3          2      2            4     3 2
+--R                          (4B C  + 24A B C  - 12A B C)D - 2A C  + 2A C
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5        4       2              2       2  3
+--R                          - 36D  + 52B D  + (32C  - 48A C - 44B  - 176A )D
+--R                        + 
+--R                                2                3      2   2
+--R                          (48B C  - 48A B C + 12B  + 96A B)D
+--R                        + 
+--R                             4        3      2 2      3       4         4
+--R                          (8C  - 64A C  + 12A C  + 40A C - 12A )D - 4B C
+--R                        + 
+--R                                   3      2   2
+--R                          - 24A B C  + 12A B C
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                4                      3
+--R                          224A D  + (- 192B C - 96A B)D
+--R                        + 
+--R                                  2       2       2          2     3  2
+--R                          (- 72A C  + (96B  + 192A )C - 96A B  + 8A )D
+--R                        + 
+--R                                  3      2           3       5        4      2 3
+--R                          (- 16B C  - 48A B C - 32A B )D - 8C  + 32A C  - 16A C
+--R                        + 
+--R                                2      3  2      4      3 2
+--R                          (24A B  - 32A )C  + 24A C + 8A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                          5        4       2            2     2  3    5
+--R                      (- D  + 10B D  + (- C  + 20A C - B  - 3A )D )a b
+--R                    + 
+--R                                       4                    3
+--R                          (53C - 389A)D  + (24B C + 134A B)D
+--R                        + 
+--R                                  2     2        2      3  2
+--R                          (- 15A C  - 3B C - 3A B  - 17A )D
+--R                        + 
+--R                                3         2     2
+--R                          (- B C  - 6A B C  + 3A B C)D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              5        4       2                2       2  3
+--R                          127D  - 63B D  + (48C  + 240A C + 147B  + 534A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (- 60B C  + 144A B C - 11B  - 150A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 6C  + 72A C  + (- 12B  - 15A )C
+--R                            + 
+--R                                      2      3       4
+--R                              (- 12A B  - 82A )C + 3A
+--R                         *
+--R                            D
+--R                        + 
+--R                             4         3     2   2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 164C - 696A)D  + (448B C - 184A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 96C  + 138A C  + (- 132B  - 636A )C + 192A B
+--R                            + 
+--R                                 3
+--R                              10A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                               3          2      2           3      3        5
+--R                          (4B C  + 96A B C  - 60A B C + 32A B  + 24A B)D + 6C
+--R                        + 
+--R                                 4       2      2  3        2      3  2     4
+--R                          - 64A C  + (12B  + 16A )C  + (6A B  + 80A )C  - 6A C
+--R                        + 
+--R                              3 2
+--R                          - 2A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             5         4        2               2       2  3
+--R                          24D  + 120B D  + (116C  + 472A C - 56B  + 196A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (12B C  - 24A B C + 24B  + 156A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              92C  - 64A C  + (12B  + 144A )C
+--R                            + 
+--R                                    2      3        4       2 2      4
+--R                              (72A B  + 48A )C + 16B  + 108A B  - 60A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3         3      2   2
+--R                          20B C  - 80A B C  + (- 12B  + 48A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          4           3
+--R                          (- 128C + 128A)D  - 896A B D
+--R                        + 
+--R                              3         2        2      2          2       3  2
+--R                          (48C  - 288A C  + (384B  - 48A )C + 96A B  + 160A )D
+--R                        + 
+--R                                     3          2         3       2            3
+--R                              - 64B C  + 96A B C  + (- 64B  - 192A B)C - 128A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4         2      2  3        2 2
+--R                          - 32C  + 16A C  + (- 16B  - 64A )C  + 96A B C
+--R                        + 
+--R                                2 2      4          4      3 2      5
+--R                          (- 48A B  + 96A )C + 32A B  + 32A B  - 16A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                    4                    3    6
+--R                      ((- 8C + 80A)D  + (- 8B C - 16A B)D )a b
+--R                    + 
+--R                               5         4         2               2       2  3
+--R                          - 62D  + 158B D  + (- 47C  + 239A C - 66B  - 218A )D
+--R                        + 
+--R                                2               3      2   2
+--R                          (12B C  - 30A B C + 2B  + 30A B)D
+--R                        + 
+--R                            4        3      2     2  2        2      3
+--R                          (C  - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (229C + 559A)D  + (- 438B C + 584A B)D
+--R                        + 
+--R                              3         2        2       2          2       3  2
+--R                          (64C  - 444A C  + (- 3B  + 213A )C - 93A B  - 175A )D
+--R                        + 
+--R                                     3           2      3       2          3
+--R                              - 10B C  - 180A B C  + (8B  + 144A B)C - 6A B
+--R                            + 
+--R                                  3
+--R                              - 6A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2     2  3          2      3  2
+--R                          - C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                             5         4          2                2       2  3
+--R                          36D  - 340B D  + (- 237C  - 638A C + 116B  + 123A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 123B C  + 102A B C - 68B  - 363A B)D
+--R                        + 
+--R                                   4         3        2       2  2
+--R                              - 95C  + 312A C  + (- 3B  - 138A )C
+--R                            + 
+--R                                      2       3        4      2 2       4
+--R                              (- 66A B  - 120A )C - 16B  - 99A B  + 105A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4           3        3       2   2
+--R                          5B C  + 176A B C  + (- 5B  - 138A B)C
+--R                        + 
+--R                                3      3        2 3     4
+--R                          (10A B  + 16A B)C + 3A B  + 5A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                        4                      3
+--R                          (276C - 916A)D  + (416B C + 2048A B)D
+--R                        + 
+--R                                    3         2           2       2          2
+--R                              - 252C  + 636A C  + (- 1032B  - 516A )C - 72A B
+--R                            + 
+--R                                    3
+--R                              - 380A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3           2       2            3      3
+--R                          (- 40B C  - 216A B C  + 168A B C + 256A B  - 40A B)D
+--R                        + 
+--R                             5        4      2       2  3            2      3  2
+--R                          56C  - 80A C  + (4B  + 128A )C  + (- 132A B  + 64A )C
+--R                        + 
+--R                              4       2 2       4         4      3 2      5
+--R                          (20B  + 156A B  - 184A )C - 4A B  - 28A B  + 16A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              5         4          2               2        2  3
+--R                          144D  - 176B D  + (- 368C  + 736A C - 64B  + 1040A )D
+--R                        + 
+--R                                   2                  2   2
+--R                          (- 528B C  - 480A B C - 528A B)D
+--R                        + 
+--R                                  4        3        2      2  2
+--R                              128C  + 64A C  + (240B  + 96A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (288A B  - 128A )C + 48B  + 240A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4       3      2   2            3      3
+--R                          96B C  + (16B  + 96A B)C  + (- 160A B  - 64A B)C
+--R                        + 
+--R                               5       2 3
+--R                          - 16B  - 112A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 128C - 384A)D  + (768B C - 512A B)D
+--R                        + 
+--R                               3       2          2       3  2
+--R                          (192C  - 960A C + 768A B  + 128A )D
+--R                        + 
+--R                                   2       3        3           4      2 3
+--R                          (384A B C  - 256B C + 128A B)D - 64A C  - 64B C
+--R                        + 
+--R                              3 2       2 2          4      5
+--R                          128A C  - 192A B C + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                         5        4      2             2      2  3    7
+--R                      (8D  - 32B D  + (8C  - 64A C + 8B  + 24A )D )a b
+--R                    + 
+--R                                          4                   3
+--R                          (- 118C + 412A)D  + (2B C - 264A B)D
+--R                        + 
+--R                                3        2      2      2          2      3  2
+--R                          (- 10C  + 96A C  + (6B  - 18A )C + 12A B  + 36A )D
+--R                        + 
+--R                               3          2        3      2
+--R                          (2B C  + 36A B C  + (- 2B  - 30A B)C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5        4
+--R                          - 287D  + 30B D
+--R                        + 
+--R                                2                2        2  3
+--R                          (- 28C  - 682A C - 308B  - 1180A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (240B C  - 168A B C + 50B  + 414A B)D
+--R                        + 
+--R                                 4         3       2      2  2
+--R                              35C  - 170A C  + (54B  + 78A )C
+--R                            + 
+--R                                    2       3       4      2 2      4
+--R                              (66A B  + 198A )C + 3B  + 18A B  - 21A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3      3      2   2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                        4                        3
+--R                          (81C + 1825A)D  + (- 528B C - 1756A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                572C  - 60A C  + (936B  + 2010A )C - 108A B
+--R                              + 
+--R                                    3
+--R                                658A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2            3
+--R                              92B C  - 120A B C  + (20B  + 264A B)C - 160A B
+--R                            + 
+--R                                    3
+--R                              - 100A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5         4         2      2  3
+--R                          - 29C  + 119A C  + (- 54B  - 80A )C
+--R                        + 
+--R                                  2       3  2        4      2 2      4        4
+--R                          (- 30A B  - 188A )C  + (- 5B  - 36A B  + 37A )C - A B
+--R                        + 
+--R                            3 2     5
+--R                          4A B  - 3A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 412D  + 132B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (466C  - 2484A C + 248B  - 2718A )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (1374B C  + 996A B C + 120B  + 702A B)D
+--R                        + 
+--R                                    4         3         2       2  2
+--R                              - 366C  - 192A C  + (- 18B  - 492A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 396A B  + 208A )C - 108B  - 690A B  + 170A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4          3       3       2   2
+--R                          - 190B C  + 96A B C  + (34B  - 204A B)C
+--R                        + 
+--R                                 3       3        5      2 3      4
+--R                          (220A B  + 304A B)C + 4B  + 82A B  + 90A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         4                        3
+--R                          (936C + 1176A)D  + (- 768B C + 1536A B)D
+--R                        + 
+--R                                 3         2          2        2            2
+--R                              24C  + 696A C  + (- 240B  + 3144A )C - 1392A B
+--R                            + 
+--R                                  3
+--R                              200A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2        3       2
+--R                              - 144B C  - 1296A B C  + (320B  + 336A B)C
+--R                            + 
+--R                                   3       3
+--R                              64A B  - 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4        2      2  3
+--R                          16C  + 80A C  + (- 8B  + 32A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 168A B  - 320A )C  + (40B  + 552A B  - 176A )C
+--R                        + 
+--R                                  4     3 2       5
+--R                          - 168A B  + 8A B  + 112A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                             5         4          2                 2       2  3
+--R                          96D  - 672B D  + (- 768C  - 1536A C + 384B  + 192A )D
+--R                        + 
+--R                                   2                   2   2
+--R                          (- 384B C  - 384A B C - 1344A B)D
+--R                        + 
+--R                                    4        2       2  2       3       4
+--R                              - 352C  + (384B  - 768A )C  - 384A C - 32B
+--R                            + 
+--R                                    2 2       4
+--R                              - 384A B  + 224A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3 2       3         5
+--R                          - 32B C  + 256A B C  + 128B C  + 384A B C - 32B
+--R                        + 
+--R                                2 3       4
+--R                          - 128A B  + 160A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  4                      3
+--R                          - 384A D  + (768B C + 1536A B)D
+--R                        + 
+--R                                  2           2       2           2       3  2
+--R                          (1152A C  + (- 1536B  - 768A )C + 384A B  - 128A )D
+--R                        + 
+--R                                 3       2            3         5         4
+--R                          (256B C  + 768A B C + 512A B )D + 128C  - 128A C
+--R                        + 
+--R                              2 3            2       3  2       4        3 2
+--R                          256A C  + (- 384A B  + 128A )C  - 384A C - 128A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                   4                   3    8
+--R                      ((16C - 96A)D  + (16B C + 32A B)D )a b
+--R                    + 
+--R                              5         4       2                2       2  3
+--R                          136D  - 168B D  + (92C  - 188A C + 136B  + 472A )D
+--R                        + 
+--R                                  2               3      2   2
+--R                          (- 48B C  + 24A B C - 8B  - 72A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 20A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 36A )C
+--R                         *
+--R                            D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 12C - 1996A)D  + (864B C + 640A B)D
+--R                        + 
+--R                                    3         2          2       2          2
+--R                              - 296C  + 720A C  + (- 252B  - 732A )C + 36A B
+--R                            + 
+--R                                   3
+--R                              - 84A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2           3
+--R                              - 48B C  + 288A B C  + (- 40B  - 408A B)C + 24A B
+--R                            + 
+--R                                 3
+--R                              24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4       2      2  3         2      3  2
+--R                          4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          636D  + 544B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 104C  + 3740A C + 120B  + 3228A )D
+--R                        + 
+--R                                    2                 3       2   2
+--R                          (- 1380B C  - 912A B C - 96B  - 804A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              188C  - 300A C  + (- 192B  + 156A )C
+--R                            + 
+--R                                     2       3        4       2 2       4
+--R                              (108A B  - 340A )C + 76B  + 468A B  - 216A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          68B C  - 272A B C  + (28B  + 384A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 40A B  - 64A B)C - 12A B  - 20A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            4                        3
+--R                          (- 1528C - 1376A)D  + (- 520B C - 1200A B)D
+--R                        + 
+--R                                    3          2        2        2            2
+--R                              - 544C  - 1968A C  + (132B  - 4740A )C + 1068A B
+--R                            + 
+--R                                     3
+--R                              - 1012A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2           3
+--R                              360B C  + 1584A B C  + (- 16B  - 480A B)C - 56A B
+--R                            + 
+--R                                  3
+--R                              600A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3
+--R                          - 8C  - 64A C  + (188B  - 28A )C
+--R                        + 
+--R                                 2       3  2          4       2 2       4
+--R                          (252A B  + 412A )C  + (- 100B  - 768A B  + 308A )C
+--R                        + 
+--R                               4      3 2      5
+--R                          12A B  - 64A B  - 76A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 304D  + 944B D
+--R                        + 
+--R                               2                  2       2  3
+--R                          (708C  + 3096A C - 1072B  - 268A )D
+--R                        + 
+--R                                   2                  3        2   2
+--R                          (- 132B C  + 360A B C - 208B  + 2028A B)D
+--R                        + 
+--R                                  4         3          2        2  2
+--R                              636C  + 448A C  + (- 996B  + 1512A )C
+--R                            + 
+--R                                      2       3        4       2 2       4
+--R                              (- 24A B  + 576A )C + 80B  + 924A B  - 356A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3      2   2
+--R                          108B C  - 256A B C  + (- 252B  - 24A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (120A B  - 768A B)C + 80B  + 356A B  - 340A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                        4                         3
+--R                          (48C + 1776A)D  + (- 1728B C - 3456A B)D
+--R                        + 
+--R                               3          2         2        2         3  2
+--R                          (816C  - 2928A C  + (3168B  + 1680A )C + 432A )D
+--R                        + 
+--R                                    3          2        3      2            3
+--R                              224B C  + 96A B C  + (256B  - 96A B)C - 768A B
+--R                            + 
+--R                                 3
+--R                              32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2       2  3
+--R                          - 160C  + 160A C  + (48B  - 384A )C
+--R                        + 
+--R                                 2       3  2         4       2 2       4
+--R                          (336A B  - 160A )C  + (- 80B  - 432A B  + 544A )C
+--R                        + 
+--R                                  4      3 2
+--R                          - 112A B  + 48A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  4        2                 2        2  3
+--R                          - 384B D  + (960C  - 2688A C + 960B  - 1344A )D
+--R                        + 
+--R                                  2                   3       2   2
+--R                          (1344B C  + 2688A B C - 192B  + 576A B)D
+--R                        + 
+--R                                    4         3          2       2  2
+--R                              - 640C  + 768A C  + (- 960B  - 576A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1152A B  - 128A )C - 192B  - 960A B  + 320A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3         3       2   2
+--R                          - 320B C  + 384A B C  + (- 64B  - 576A B)C
+--R                        + 
+--R                                 3       3         5       2 3
+--R                          (640A B  + 256A B)C + 64B  + 448A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   3
+--R                          1536A B D
+--R                        + 
+--R                                    3          2           2       2
+--R                              - 768C  + 1152A C  + (- 1536B  + 768A )C
+--R                            + 
+--R                                       2       3
+--R                              - 1536A B  - 128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2         3       2
+--R                              256B C  - 1536A B C  + (1024B  + 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4        2       2  3         2 2
+--R                          128C  - 256A C  + (256B  + 256A )C  - 384A B C
+--R                        + 
+--R                               2 2       4           4       3 2       5
+--R                          (768A B  - 384A )C - 512A B  - 128A B  + 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                        5        4         2              2      2  3    9
+--R                  (- 16D  + 32B D  + (- 16C  + 64A C - 16B  - 48A )D )a b
+--R                + 
+--R                                  4                      3
+--R                      (8C + 224A)D  + (- 136B C - 64A B)D
+--R                    + 
+--R                          3         2       2      2    2
+--R                      (40C  - 144A C  + (24B  + 72A )C)D
+--R                    + 
+--R                           3          2      3      2
+--R                      (8B C  - 48A B C  + (8B  + 72A B)C)D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            5        4         2               2       2  3
+--R                      - 148D  + 88B D  + (- 64C  - 104A C - 64B  - 592A )D
+--R                    + 
+--R                             2                3      2   2
+--R                      (192B C  + 192A B C + 8B  + 72A B)D
+--R                    + 
+--R                               4        3       2      2  2           2      3
+--R                          - 28C  + 88A C  + (24B  - 24A )C  + (- 24A B  + 24A )C
+--R                        + 
+--R                               4      2 2      4
+--R                          - 12B  - 72A B  + 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4          3        3      2   2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (212C + 1532A)D  + (- 664B C - 112A B)D
+--R                    + 
+--R                           3         2         2       2           2      3  2
+--R                      (232C  - 528A C  + (- 24B  + 864A )C - 144A B  + 88A )D
+--R                    + 
+--R                                   3           2       3       2           3
+--R                            - 40B C  - 528A B C  + (40B  + 456A B)C + 32A B
+--R                          + 
+--R                                 3
+--R                            - 80A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        5        4         2      2  3           2      3  2
+--R                      4C  - 12A C  + (- 24B  + 16A )C  + (- 24A B  - 32A )C
+--R                    + 
+--R                          4       2 2      4         4      3 2      5
+--R                      (20B  + 144A B  - 52A )C + 4A B  + 16A B  + 12A
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                            5          4        2                 2        2  3
+--R                      - 124D  - 1208B D  + (248C  - 4328A C + 416B  - 1336A )D
+--R                    + 
+--R                              2                  3       2   2
+--R                      (1176B C  + 912A B C + 104B  + 240A B)D
+--R                    + 
+--R                                4         3        2       2  2
+--R                          - 188C  + 424A C  + (384B  - 264A )C
+--R                        + 
+--R                                  2       3        4       2 2       4
+--R                          (- 24A B  + 136A )C - 68B  - 480A B  + 244A
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3         3       2   2
+--R                      - 32B C  + 304A B C  + (- 16B  - 408A B)C
+--R                    + 
+--R                              3      3         5      2 3      4
+--R                      (- 80A B  + 64A B)C - 16B  - 88A B  + 40A B
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      4                       3
+--R                      (1028C - 2044A)D  + (3104B C + 2864A B)D
+--R                    + 
+--R                                3          2           2        2           2
+--R                          - 560C  + 4512A C  + (- 1536B  + 1848A )C - 816A B
+--R                        + 
+--R                              3
+--R                          616A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3           2          3       2            3
+--R                          - 736B C  - 768A B C  + (- 304B  - 912A B)C + 224A B
+--R                        + 
+--R                                3
+--R                          - 496A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5        4          2       2  3
+--R                      28C  - 52A C  + (- 200B  + 112A )C
+--R                    + 
+--R                               2       3  2        4       2 2       4
+--R                      (- 168A B  - 224A )C  + (140B  + 912A B  - 364A )C
+--R                    + 
+--R                           4       3 2      5
+--R                      92A B  + 112A B  + 52A
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                          5          4           2                 2        2  3
+--R                      288D  + 1088B D  + (- 1896C  + 4752A C - 720B  + 2552A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 2712B C  - 4560A B C + 272B  - 2424A B)D
+--R                    + 
+--R                              4          3         2       2  2
+--R                          280C  - 2048A C  + (1320B  - 480A )C
+--R                        + 
+--R                                  2       3         4       2 2       4
+--R                          (1200A B  - 416A )C + 208B  + 744A B  - 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3        2   2
+--R                      232B C  - 608A B C  + (344B  + 1248A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 560A B  + 448A B)C - 112B  - 616A B  + 280A B
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                       4                         3
+--R                      (- 1248C + 288A)D  + (- 2304B C - 2688A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          1056C  - 3840A C  + (1536B  - 3552A )C + 2496A B
+--R                        + 
+--R                                3
+--R                          - 704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2          3       2            3
+--R                          768B C  + 2880A B C  + (- 768B  + 384A B)C - 256A B
+--R                        + 
+--R                               3
+--R                          1088A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4         2       2  3
+--R                      - 32C  + 320A C  + (- 32B  - 128A )C
+--R                    + 
+--R                             2       3  2          4        2 2       4
+--R                      (192A B  + 256A )C  + (- 160B  - 1824A B  + 416A )C
+--R                    + 
+--R                            4       3 2       5
+--R                      416A B  - 128A B  - 320A
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                2       2  3
+--R                      (1728C  - 384A C + 384B  - 576A )D
+--R                    + 
+--R                              2                   3        2   2
+--R                      (1344B C  + 3456A B C - 384B  + 2112A B)D
+--R                    + 
+--R                               4          3           2       2  2
+--R                          - 64C  + 1536A C  + (- 1728B  + 768A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1152A B  + 256A )C - 128B  - 192A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3       2   2
+--R                      - 192B C  + 256A B C  + (- 320B  - 768A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (640A B  - 512A B)C + 128B  + 704A B  - 320A B
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                             3       2           2  2
+--R                      (- 768C  + 768A C - 1536A B )D
+--R                    + 
+--R                                  2        3        3            4       2 3
+--R                      (- 1536A B C  + 1024B C - 512A B)D - 256A C  + 256B C
+--R                    + 
+--R                          2 2          4       5
+--R                      768A B C - 512A B  + 256A
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                %%BN0
+--R            + 
+--R                       5            4 2  7
+--R                  (4A D a b - 8A C D a )c
+--R                + 
+--R                             5         4    2
+--R                      (- 2B D  - 8A C D )a b
+--R                    + 
+--R                                    5                  4         2     3  3  2
+--R                      ((- 4C + 20A)D  + (4B C - 28A B)D  + (24A C  + 8A )D )a b
+--R                    + 
+--R                             2             2  4            3
+--R                          (8C  - 32A C + 8A )D  + 64A B C D
+--R                        + 
+--R                                  3      3   2
+--R                          (- 16A C  - 16A C)D
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                  5                  4        2     3  3    3
+--R                      ((2C - 38A)D  + (4B C + 12A B)D  + (4A C  - 4A )D )a b
+--R                    + 
+--R                            6       5      2              2      2  4
+--R                          6D  - 4B D  + (4C  + 56A C + 14B  + 36A )D
+--R                        + 
+--R                                  2               2   3           3      3   2
+--R                          (- 12B C  - 8A B C - 12A B)D  + (- 16A C  + 16A C)D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                                        5                    4
+--R                          (- 32C + 16A)D  + (32B C - 160A B)D
+--R                        + 
+--R                                     3        2         2       2          2
+--R                                - 24C  + 56A C  + (- 32B  - 136A )C + 64A B
+--R                              + 
+--R                                   3
+--R                                40A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                               3          2      2         3   2
+--R                          (8B C  - 72A B C  + 24A B C - 24A B)D
+--R                        + 
+--R                                4      3 2     5
+--R                          (20A C  - 24A C  + 4A )D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                              2              2  4
+--R                          (32C  - 32A C + 32A )D
+--R                        + 
+--R                                  2                 2   3
+--R                          (- 64B C  + 256A B C - 64A B)D
+--R                        + 
+--R                                   4        3      2 2            2      3
+--R                                16C  - 64A C  + 96A C  + (- 192A B  - 64A )C
+--R                              + 
+--R                                   4
+--R                                16A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  3      3            5      3 3     5
+--R                          (64A B C  + 64A B C)D - 8A C  + 16A C  - 8A C
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              6        5        2             2      2  4
+--R                          - 2D  + 16B D  + (- 4C  + 64A C - 6B  - 12A )D
+--R                        + 
+--R                                 2               2   3
+--R                          (- 2B C  - 12A B C + 6A B)D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                                      5                      4
+--R                          (28C - 92A)D  + (- 60B C + 260A B)D
+--R                        + 
+--R                             3         2      2      2          2      3  3
+--R                          (8C  - 192A C  + (4B  + 24A )C - 36A B  - 96A )D
+--R                        + 
+--R                               3          2      2     2
+--R                          (8B C  + 48A B C  - 24A B C)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                             6        5         2               2       2  4
+--R                          20D  - 32B D  + (- 12C  + 152A C + 36B  + 116A )D
+--R                        + 
+--R                                2                 3       2   3
+--R                          (48B C  - 480A B C - 32B  - 144A B)D
+--R                        + 
+--R                                4         3       2      2  2
+--R                              8C  + 128A C  + (36B  + 48A )C
+--R                            + 
+--R                                     2       3        2 2     4
+--R                              (120A B  + 256A )C + 36A B  + 8A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  4          3      2   2     3         4
+--R                          (- 10B C  - 56A B C  + 36A B C  + 8A B C - 10A B)D
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                                        5                     4
+--R                          (- 48C - 16A)D  + (240B C - 144A B)D
+--R                        + 
+--R                                   3        2         2       2           2
+--R                              - 80C  + 80A C  + (- 96B  - 496A )C + 480A B
+--R                            + 
+--R                                  3
+--R                              112A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                   3           2       3       2           3
+--R                              80B C  - 144A B C  + (96B  + 624A B)C - 32A B
+--R                            + 
+--R                                    3
+--R                              - 176A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2      2  3       3 2
+--R                              - 20C  + 36A C  + (- 32B  - 72A )C  - 184A C
+--R                            + 
+--R                                    2 2      4        5
+--R                              (- 96A B  - 36A )C + 20A
+--R                         *
+--R                            D
+--R                        + 
+--R                            5          4      2   3      3   2      4        5
+--R                        4B C  + 20A B C  - 24A B C  - 24A B C  + 20A B C + 4A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                              2      2  4            2                  2   3
+--R                          (32C  + 32A )D  + (- 256B C  + 256A B C - 256A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              64C  - 128A C  + (192B  + 384A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 768A B  - 128A )C + 192A B  + 64A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4           3       2   2
+--R                              - 64B C  + 256A B C  - 384A B C
+--R                            + 
+--R                                     3       3         4
+--R                              (256A B  + 256A B)C - 64A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            6        5     2 4           2      3  3     4 2
+--R                          8C  - 32A C  - 8A C  + (- 64A B  + 64A )C  - 8A C
+--R                        + 
+--R                                3 2      5       6
+--R                          (- 64A B  - 32A )C + 8A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                         5                     4
+--R                          (- 10C + 118A)D  + (- 20B C - 84A B)D
+--R                        + 
+--R                             3        2      2     2         2      3  3
+--R                          (2C  - 26A C  + (6B  + 6A )C + 6A B  + 34A )D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                               6        5         2                2       2  4
+--R                          - 44D  + 28B D  + (- 28C  - 224A C - 100B  - 324A )D
+--R                        + 
+--R                                2                3       2   3
+--R                          (92B C  + 40A B C + 20B  + 204A B)D
+--R                        + 
+--R                                  4         3         2      2  2
+--R                              - 8C  + 104A C  + (- 24B  - 24A )C
+--R                            + 
+--R                                      2       3
+--R                              (- 24A B  - 136A )C
+--R                         *
+--R                             2
+--R                            D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                                       5                       4
+--R                          (144C + 80A)D  + (- 320B C + 576A B)D
+--R                        + 
+--R                                    3        2        2        2           2
+--R                                132C  - 92A C  + (288B  + 1196A )C - 608A B
+--R                              + 
+--R                                      3
+--R                                - 116A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                        3           2         3       2
+--R                                - 160B C  + 528A B C  + (- 64B  - 672A B)C
+--R                              + 
+--R                                    3
+--R                                176A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4       2      2  3
+--R                              10C  - 134A C  + (28B  + 20A )C
+--R                            + 
+--R                                    2       3  2         2 2     4       3 2
+--R                              (12A B  + 196A )C  + (- 12A B  + 2A )C + 4A B
+--R                            + 
+--R                                   5
+--R                              - 30A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                  5          2               2  4
+--R                          - 160B D  + (- 128C  - 256A C + 16B )D
+--R                        + 
+--R                                 2                  3       2   3
+--R                          (416B C  - 960A B C - 128B  - 352A B)D
+--R                        + 
+--R                                   4         3          2        2  2
+--R                              - 82C  + 232A C  + (- 288B  - 1164A )C
+--R                            + 
+--R                                      2      3        4      2 2      4
+--R                              (1344A B  - 24A )C + 16B  + 96A B  - 82A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3       2   2
+--R                              100B C  - 656A B C  + 408A B C
+--R                            + 
+--R                                       3       3         4
+--R                              (- 128A B  - 400A B)C - 28A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              6        5         2     2  4        2       3  3
+--R                          - 4C  + 56A C  + (- 10B  + 4A )C  + (8A B  - 112A )C
+--R                        + 
+--R                              2 2     4  2      3 2      5        4 2     6
+--R                          (36A B  + 4A )C  + (8A B  + 56A )C - 10A B  - 4A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                            4
+--R                          (384B C + 128A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 32C  + 416A C  + (- 640B  - 352A )C + 512A B
+--R                            + 
+--R                                  3
+--R                              224A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2            3
+--R                              160B C  - 288A B C  + (128B  + 2016A B)C - 640A B
+--R                            + 
+--R                                    3
+--R                              - 608A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2       2  3
+--R                              - 48C  - 16A C  + (- 32B  + 288A )C
+--R                            + 
+--R                                      2       3  2          4       2 2      4
+--R                              (- 96A B  + 224A )C  + (- 128B  - 864A B  + 16A )C
+--R                            + 
+--R                                     4       3 2      5
+--R                              - 64A B  + 224A B  + 48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4       3      2   3
+--R                          - 16B C  + 176A B C  + (32B  + 96A B)C
+--R                        + 
+--R                              3      3   2       2 3       4         3 3      5
+--R                        (96A B  + 96A B)C  + (96A B  + 176A B)C + 32A B  - 16A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                   2       2   3
+--R                          (- 256B C  - 256A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              64C  - 256A C  + (768B  + 384A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 768A B  - 256A )C + 768A B  + 64A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 256B C  + 512A B C  + (- 256B  - 1536A B)C
+--R                            + 
+--R                                      3       3          2 3       4
+--R                              (1024A B  + 512A B)C - 256A B  - 256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6       2      2  4         2 3
+--R                          32C  + (64B  - 32A )C  - 256A B C
+--R                        + 
+--R                               2 2      4  2            4       3 2        4 2
+--R                          (384A B  - 32A )C  + (- 128A B  - 256A B )C + 64A B
+--R                        + 
+--R                             6
+--R                          32A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                             6        5       2               2      2  4
+--R                          12D  - 44B D  + (20C  - 152A C + 36B  + 84A )D
+--R                        + 
+--R                               2               3      2   3
+--R                          (4B C  + 72A B C - 4B  - 60A B)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                                        5                     4
+--R                          (- 36C + 12A)D  + (296B C - 520A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 44C  + 524A C  + (- 68B  - 228A )C + 204A B
+--R                            + 
+--R                                  3
+--R                              228A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                  3           2       3       2     2
+--R                          (- 16B C  - 288A B C  + (16B  + 240A B)C)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                               6         5         2              2       2  4
+--R                          - 30D  + 272B D  + (- 16C  + 96A C - 44B  - 432A )D
+--R                        + 
+--R                                   2                  3       2   3
+--R                          (- 324B C  + 872A B C + 224B  + 972A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 22C  - 536A C  + (- 48B  - 36A )C
+--R                            + 
+--R                                       2       3       4       2 2      4
+--R                              (- 576A B  - 600A )C - 6B  - 240A B  - 54A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3         3       2   2
+--R                              24B C  + 368A B C  + (- 12B  - 288A B)C
+--R                            + 
+--R                                    3      3        2 3      4
+--R                              (24A B  - 48A B)C + 4A B  + 72A B
+--R                         *
+--R                            D
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                        5                       4
+--R                          (112C + 144A)D  + (- 928B C - 416A B)D
+--R                        + 
+--R                                  3         2        2        2            2
+--R                              168C  - 600A C  + (896B  + 1816A )C - 1408A B
+--R                            + 
+--R                                 3
+--R                              24A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 416B C  + 672A B C  + (- 512B  - 3648A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  + 896A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              96C  + 144A C  + (184B  + 320A )C
+--R                            + 
+--R                                     2       3  2       4        2 2       4
+--R                              (216A B  + 544A )C  + (80B  + 1032A B  + 224A )C
+--R                            + 
+--R                                   4      3 2      5
+--R                              48A B  - 24A B  - 48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4       2   3
+--R                          - 12B C  - 156A B C  + 104A B C
+--R                        + 
+--R                                  3       3   2         2 3       4         5
+--R                          (- 32A B  + 104A B)C  + (- 32A B  - 156A B)C - 12A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                 2                2       2  4
+--R                          (- 144C  - 480A C + 480B  - 144A )D
+--R                        + 
+--R                                 2                   3       2   3
+--R                          (960B C  + 1152A B C + 192B  + 192A B)D
+--R                        + 
+--R                                    4         3           2        2  2
+--R                              - 196C  + 912A C  + (- 1536B  - 2136A )C
+--R                            + 
+--R                                      2       3         4      4
+--R                              (2304A B  - 624A )C + 224B  + 60A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4            3        3        2   2
+--R                              696B C  - 1120A B C  + (448B  + 3024A B)C
+--R                            + 
+--R                                        3       3         5       2 3       4
+--R                              (- 1408A B  - 608A B)C + 32B  + 192A B  + 184A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               6         2      2  4         2       3  3
+--R                          - 48C  + (- 84B  - 80A )C  + (80A B  - 256A )C
+--R                        + 
+--R                                4       2 2      4  2           4      3 2
+--R                          (- 48B  - 696A B  - 80A )C  + (- 32A B  + 80A B )C
+--R                        + 
+--R                               2 4      4 2      6
+--R                          - 48A B  - 84A B  - 48A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                 3         2           2       2           2
+--R                              64C  + 576A C  + (- 1152B  + 192A )C - 384A B
+--R                            + 
+--R                                  3
+--R                              192A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                     3            2        3        2
+--R                              - 64B C  - 1728A B C  + (640B  + 1344A B)C
+--R                            + 
+--R                                      3        3
+--R                              - 896A B  - 1088A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              64C  - 512A C  + (320B  + 640A )C
+--R                            + 
+--R                                     2        3  2
+--R                              (192A B  + 1024A )C
+--R                            + 
+--R                                    4        2 2       4           4        3 2
+--R                              (- 64B  - 2112A B  - 192A )C + 320A B  + 1088A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                  5          4         3       2   3
+--R                          - 192B C  + 64A B C  + (- 64B  - 384A B)C
+--R                        + 
+--R                                 3       3   2       5       2 3      4
+--R                          (320A B  - 384A B)C  + (64B  + 320A B  + 64A B)C
+--R                        + 
+--R                               5      3 3       5
+--R                          64A B  - 64A B  - 192A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                   3       2 2       3        2 2  2
+--R                          (- 256A C  + 768B C  - 256A C + 768A B )D
+--R                        + 
+--R                                      4            3           3        2   2
+--R                              - 256B C  + 1024A B C  + (- 1024B  - 1536A B)C
+--R                            + 
+--R                                      3        3           2 3       4
+--R                              (1024A B  + 1024A B)C - 1024A B  - 256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5       2 4            2       3  3
+--R                          128A C  + 256B C  + (- 512A B  - 256A )C
+--R                        + 
+--R                               4        2 2  2            4       3 2       5
+--R                          (128B  + 1536A B )C  + (- 512A B  - 512A B  + 128A )C
+--R                        + 
+--R                              2 4       4 2
+--R                          128A B  + 256A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                      5                    4
+--R                          (8C - 120A)D  + (16B C + 144A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  3
+--R                          (- 8C  + 40A C  + (- 24B  - 24A )C - 24A B  - 72A )D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                             6        5                 2       2  4
+--R                          64D  - 96B D  + (416A C + 128B  + 672A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 224B C  - 128A B C - 96B  - 672A B)D
+--R                        + 
+--R                            4         3       2      2  2         2       3    2
+--R                        (32C  - 160A C  + (96B  + 96A )C  + (96A B  + 288A )C)D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                          5                     4
+--R                          (- 290C - 354A)D  + (360B C + 168A B)D
+--R                        + 
+--R                                    3         2          2        2           2
+--R                              - 108C  - 356A C  + (- 916B  - 2884A )C + 940A B
+--R                            + 
+--R                                    3
+--R                              - 588A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2           3
+--R                              664B C  - 696A B C  + (280B  + 2376A B)C - 40A B
+--R                            + 
+--R                                    3
+--R                              - 360A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4          2       2  3
+--R                              - 42C  + 206A C  + (- 132B  - 100A )C
+--R                            + 
+--R                                       2       3  2         4      2 2      4
+--R                              (- 108A B  - 420A )C  + (- 10B  - 12A B  - 18A )C
+--R                            + 
+--R                                     4      3 2      5
+--R                              - 10A B  - 36A B  + 54A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                5        2                 2       2  4
+--R                          120B D  + (426C  + 1588A C - 560B  + 522A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 328B C  - 784A B C - 96B  + 696A B)D
+--R                        + 
+--R                                  4         3         2        2  2
+--R                              236C  - 112A C  + (1740B  + 4200A )C
+--R                            + 
+--R                                        2        3         4       2 2      4
+--R                              (- 1800A B  + 2512A )C - 208B  - 852A B  + 12A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 704B C  + 960A B C  + (- 248B  - 2112A B)C
+--R                            + 
+--R                                     3       3         5       2 3
+--R                              (208A B  + 320A B)C - 24B  - 184A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5       2      2  4         2       3  3
+--R                          18C  - 84A C  + (60B  + 14A )C  + (48A B  + 232A )C
+--R                        + 
+--R                              4      2 2      4  2         4      3 2      5
+--R                          (10B  - 24A B  + 14A )C  + (20A B  + 48A B  - 84A )C
+--R                        + 
+--R                             2 4      4 2      6
+--R                          10A B  + 60A B  + 18A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                              4
+--R                          (- 448B C - 576A B)D
+--R                        + 
+--R                                   3          2         2        2           2
+--R                              - 48C  - 2864A C  + (1984B  - 1424A )C + 704A B
+--R                            + 
+--R                                    3
+--R                              - 656A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3            2          3        2
+--R                              - 288B C  + 1632A B C  + (- 640B  - 3552A B)C
+--R                            + 
+--R                                     3       3
+--R                              1664A B  + 672A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    5         4          2        2  3
+--R                              - 184C  + 200A C  + (- 976B  - 2416A )C
+--R                            + 
+--R                                       2        3  2
+--R                              (- 336A B  - 3120A )C
+--R                            + 
+--R                                   4        2 2       4          4        3 2
+--R                              (352B  + 3216A B  - 344A )C - 32A B  - 1520A B
+--R                            + 
+--R                                   5
+--R                              - 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5           4       3       2   3
+--R                          240B C  - 208A B C  + (32B  + 224A B)C
+--R                        + 
+--R                                  3       3   2         2 3       4         3 3
+--R                          (- 32A B  + 224A B)C  + (- 32A B  - 208A B)C + 32A B
+--R                        + 
+--R                              5
+--R                          240A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                 2                   3       2   3
+--R                          (576B C  + 1920A B C - 640B  + 576A B)D
+--R                        + 
+--R                                    4          3           2        2  2
+--R                              - 472C  + 2528A C  + (- 2304B  + 1392A )C
+--R                            + 
+--R                                        2       3         4       2 2       4
+--R                              (- 1536A B  + 992A )C - 416B  - 768A B  + 552A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4            3         3        2   2
+--R                              560B C  - 1216A B C  + (1536B  + 4128A B)C
+--R                            + 
+--R                                        3       3          5       2 3      4
+--R                              (- 2560A B  - 192A B)C - 192B  + 512A B  + 48A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5      2       2  4
+--R                          48C  - 32A C  + (8B  + 464A )C
+--R                        + 
+--R                                  2        3  3          4        2 2       4  2
+--R                          (1120A B  + 1088A )C  + (- 192B  - 1872A B  + 464A )C
+--R                        + 
+--R                                 4        3 2      5        6       2 4     4 2
+--R                          (384A B  + 1120A B  - 32A )C - 32B  - 192A B  + 8A B
+--R                        + 
+--R                             6
+--R                          48A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                      3            2         3       2
+--R                              - 256B C  - 2304A B C  + (1536B  - 768A B)C
+--R                            + 
+--R                                    3       3
+--R                              512A B  - 768A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  5          4        2       2  3          2 2
+--R                              448C  - 1024A C  + (640B  - 640A )C  + 1920A B C
+--R                            + 
+--R                                      2 2       4           4        3 2
+--R                              (- 1152A B  - 832A )C + 768A B  + 1664A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                  5          4          3       2   3
+--R                          - 192B C  + 64A B C  + (- 640B  - 896A B)C
+--R                        + 
+--R                                 3       3   2        2 3      4          3 3
+--R                          (128A B  - 896A B)C  + (128A B  + 64A B)C - 640A B
+--R                        + 
+--R                                5
+--R                          - 192A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                    3        3 2        3           2 3
+--R                          (1024A B C  - 1024B C  + 1024A B C - 1024A B )D
+--R                        + 
+--R                                6         5        2       2  4
+--R                          - 128C  + 128A C  + (256B  + 128A )C
+--R                        + 
+--R                                    2       3  3        4        2 2       4  2
+--R                          (- 1024A B  - 256A )C  + (512B  + 1536A B  + 128A )C
+--R                        + 
+--R                                   4        3 2       5         2 4       4 2
+--R                          (- 512A B  - 1024A B  + 128A )C + 512A B  + 256A B
+--R                        + 
+--R                                6
+--R                          - 128A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                           6        5         2              2       2  4
+--R                      - 16D  + 48B D  + (- 16C  + 96A C - 48B  - 144A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (16B C  - 96A B C + 16B  + 144A B)D
+--R                 *
+--R                       8
+--R                    a b
+--R                + 
+--R                                   5                      4
+--R                      (48C + 240A)D  + (- 288B C - 96A B)D
+--R                    + 
+--R                          3         2        2       2           2       3  3
+--R                      (80C  - 464A C  + (304B  + 624A )C - 144A B  + 144A )D
+--R                    + 
+--R                              3           2         3       2     2
+--R                      (- 64B C  + 384A B C  + (- 64B  - 576A B)C)D
+--R                 *
+--R                     2 7
+--R                    a b
+--R                + 
+--R                           6         5       2                 2       2  4
+--R                      - 20D  - 156B D  + (56C  - 1296A C + 168B  - 456A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (664B C  + 624A B C - 40B  - 168A B)D
+--R                    + 
+--R                                4         3          2       2  2
+--R                          - 148C  + 816A C  + (- 648B  - 888A )C
+--R                        + 
+--R                                 2       3        4       2 2       4
+--R                          (240A B  - 720A )C + 44B  + 504A B  + 108A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          84B C  - 496A B C  + (88B  + 696A B)C
+--R                        + 
+--R                                  3       3        5      2 3       4
+--R                          (- 16A B  + 144A B)C + 4B  + 24A B  - 108A B
+--R                     *
+--R                        D
+--R                 *
+--R                     3 6
+--R                    a b
+--R                + 
+--R                                   5                     4
+--R                      (168C - 24A)D  + (828B C + 636A B)D
+--R                    + 
+--R                                3          2          2        2           2
+--R                          - 416C  + 2848A C  + (- 752B  + 1824A )C - 432A B
+--R                        + 
+--R                              3
+--R                          608A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3            2        3       2            3
+--R                          - 712B C  - 1560A B C  + (392B  + 936A B)C - 696A B
+--R                        + 
+--R                                3
+--R                          - 264A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2       2  3
+--R                          120C  - 616A C  + (544B  + 432A )C
+--R                        + 
+--R                                 2        3  2          4        2 2       4
+--R                          (288A B  + 1072A )C  + (- 120B  - 1824A B  - 168A )C
+--R                        + 
+--R                              4       3 2      5
+--R                          8A B  + 480A B  - 72A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4         3       2   3
+--R                      - 36B C  + 204A B C  + (- 40B  - 232A B)C
+--R                    + 
+--R                           3       3   2        5     2 3       4          5
+--R                      (8A B  - 232A B)C  + (- 4B  + 8A B  + 204A B)C - 4A B
+--R                    + 
+--R                           3 3      5
+--R                      - 40A B  - 36A B
+--R                 *
+--R                     4 5
+--R                    a b
+--R                + 
+--R                             2                2      2  4
+--R                      (- 580C  + 120A C - 120B  + 60A )D
+--R                    + 
+--R                                2                   3        2   3
+--R                      (- 1760B C  - 2688A B C + 384B  - 1056A B)D
+--R                    + 
+--R                              4          3         2        2  2
+--R                          680C  - 3168A C  + (1224B  - 2832A )C
+--R                        + 
+--R                                  2        3         4      2 2       4
+--R                          (1680A B  - 1632A )C + 176B  + 72A B  - 600A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4            3          3        2   2
+--R                          336B C  + 1664A B C  + (- 800B  - 1248A B)C
+--R                        + 
+--R                                 3       5       2 3       4
+--R                          1664A B C + 64B  + 288A B  + 528A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5          2      2  4
+--R                      - 36C  + 168A C  + (- 144B  - 28A )C
+--R                    + 
+--R                               2       3  3       4        2 2      4  2
+--R                      (- 448A B  - 464A )C  + (92B  + 1440A B  - 28A )C
+--R                    + 
+--R                              4       3 2       5       6      2 4       4 2
+--R                      (- 72A B  - 448A B  + 168A )C + 8B  + 92A B  - 144A B
+--R                    + 
+--R                           6
+--R                      - 36A
+--R                 *
+--R                     5 4
+--R                    a b
+--R                + 
+--R                            3         2        2       2           2      3  3
+--R                      (1056C  - 224A C  + (448B  - 288A )C + 576A B  - 32A )D
+--R                    + 
+--R                                 3            2           3        2
+--R                          1856B C  + 4416A B C  + (- 1408B  + 2880A B)C
+--R                        + 
+--R                                  3        3
+--R                          - 384A B  + 1344A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5          4          2        2  3
+--R                          - 480C  + 1760A C  + (- 800B  + 2112A )C
+--R                        + 
+--R                                    2        3  2
+--R                          (- 2592A B  + 1216A )C
+--R                        + 
+--R                                 4        2 2        4           4        3 2
+--R                          (- 192B  + 1056A B  + 1440A )C - 832A B  - 1248A B
+--R                        + 
+--R                             5
+--R                          96A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4        3       2   3
+--R                      - 48B C  - 624A B C  + (448B  + 416A B)C
+--R                    + 
+--R                               3       3   2         5       2 3       4
+--R                      (- 832A B  + 416A B)C  + (- 64B  - 832A B  - 624A B)C
+--R                    + 
+--R                             5       3 3      5
+--R                      - 64A B  + 448A B  - 48A B
+--R                 *
+--R                     6 3
+--R                    a b
+--R                + 
+--R                                 4         3          2       2  2
+--R                          - 1072C  + 192A C  + (- 576B  + 480A )C
+--R                        + 
+--R                                    2       3         4       2 2      4
+--R                          (- 1920A B  + 192A )C + 320B  - 576A B  - 48A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3         3        2   2
+--R                          - 960B C  - 3328A B C  + (1792B  - 2688A B)C
+--R                        + 
+--R                                 3        3          5       2 3       4
+--R                          (512A B  - 2304A B)C + 256B  + 768A B  - 960A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6         5        2       2  4           2       3  3
+--R                      128C  - 384A C  + (144B  - 640A )C  + (1472A B  - 256A )C
+--R                    + 
+--R                            4        2 2       4  2
+--R                      (- 64B  - 1440A B  - 640A )C
+--R                    + 
+--R                              4        3 2       5        6      2 4       4 2
+--R                      (1152A B  + 1472A B  - 384A )C + 64B  - 64A B  + 144A B
+--R                    + 
+--R                          6
+--R                      128A
+--R                 *
+--R                     7 2
+--R                    a b
+--R                + 
+--R                              5        4        2       2  3
+--R                          576C  - 64A C  + (256B  - 384A )C
+--R                        + 
+--R                                  2       3  2          4       2 2       4
+--R                          (2304A B  - 128A )C  + (- 768B  + 768A B  - 192A )C
+--R                        + 
+--R                                  4       3 2       5
+--R                          - 256A B  + 768A B  + 192A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4          3       2   3
+--R                      192B C  + 960A B C  + (- 768B  + 896A B)C
+--R                    + 
+--R                               3       3   2          5       2 3       4
+--R                      (- 256A B  + 896A B)C  + (- 256B  - 256A B  + 960A B)C
+--R                    + 
+--R                              5       3 3       5
+--R                      - 256A B  - 768A B  + 192A B
+--R                 *
+--R                     8
+--R                    a b
+--R                + 
+--R                            6       2 4          2 3        4       4  2
+--R                      - 128C  + 128A C  - 1024A B C  + (512B  + 128A )C
+--R                    + 
+--R                             3 2        2 4       6
+--R                      - 1024A B C + 512A B  - 128A
+--R                 *
+--R                     9
+--R                    a
+--R             *
+--R                x
+--R            + 
+--R                   5 2         4            4 2  7
+--R              (2A D b  - 4A C D a b + 8A B D a )c
+--R            + 
+--R                        5         4  3
+--R                  (- B D  - 4A C D )b
+--R                + 
+--R                               5                  4         2     3  3    2
+--R                  ((- 2C + 8A)D  + (2B C - 16A B)D  + (12A C  + 6A )D )a b
+--R                + 
+--R                      2             2  4            3          3      3   2  2
+--R                  ((4C  - 20A C - 4B )D  + 24A B C D  + (- 8A C  - 20A C)D )a b
+--R                + 
+--R                            5                    4        2         2  3
+--R                      - 8A D  + (- 8B C + 32A B)D  + (- 8A C - 48A B )D
+--R                    + 
+--R                        3   2      3 2
+--R                      8A B D  + 16A C D
+--R                 *
+--R                     3
+--R                    a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                             5                 4        2     3  3  4
+--R                  ((C - 19A)D  + (2B C + 6A B)D  + (2A C  - 2A )D )b
+--R                + 
+--R                        6      5      2             2      2  4
+--R                      3D  - B D  + (2C  + 34A C + 8B  + 19A )D
+--R                    + 
+--R                             2              2   3          3     3   2
+--R                      (- 6B C  - 2A B C - 9A B)D  + (- 8A C  + 8A C)D
+--R                 *
+--R                       3
+--R                    a b
+--R                + 
+--R                                    5                    4
+--R                      (- 14C + 10A)D  + (24B C - 150A B)D
+--R                    + 
+--R                            3        2         2      2          2      3  3
+--R                      (- 12C  + 24A C  + (- 12B  - 68A )C + 54A B  + 34A )D
+--R                    + 
+--R                         3          2      2        3   2         4      3 2
+--R                    (4B C  - 36A B C  + 30A B C - 8A B)D  + (10A C  - 10A C )D
+--R                 *
+--R                     2 2
+--R                    a b
+--R                + 
+--R                           5       2             2      2  4
+--R                      16B D  + (20C  - 12A C - 8B  + 16A )D
+--R                    + 
+--R                              2                 3      2   3
+--R                      (- 24B C  + 184A B C + 24B  + 64A B)D
+--R                    + 
+--R                            4        3      2 2           2       3        2 2
+--R                          8C  - 24A C  + 96A C  + (- 60A B  - 104A )C - 12A B
+--R                        + 
+--R                             4
+--R                          16A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              3      2   2      3            5     3 3
+--R                      (40A B C  - 24A B C  + 24A B C)D - 4A C  + 4A C
+--R                 *
+--R                     3
+--R                    a b
+--R                + 
+--R                                 5                     4
+--R                      (8C - 32A)D  + (- 32B C + 56A B)D
+--R                    + 
+--R                            2       2      2           2  3
+--R                      (16A C  + (56B  - 32A )C - 192A B )D
+--R                    + 
+--R                             3      3   2
+--R                      (104A B  + 32A B)D
+--R                    + 
+--R                          2 3      3 2      4       3 2           4      3   2
+--R                    (- 56A C  + 64A C  - 40A C - 16A B )D - 8A B C  - 24A B C
+--R                 *
+--R                     4
+--R                    a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                         6       5        2             2     2  4
+--R                      - D  + 8B D  + (- 2C  + 32A C - 3B  - 6A )D
+--R                    + 
+--R                            2              2   3
+--R                      (- B C  - 6A B C + 3A B)D
+--R                 *
+--R                     5
+--R                    b
+--R                + 
+--R                                  5                      4
+--R                      (13C - 31A)D  + (- 34B C + 142A B)D
+--R                    + 
+--R                         3         2     2      2          2      3  3
+--R                      (4C  - 100A C  + (B  + 14A )C - 19A B  - 66A )D
+--R                    + 
+--R                           3          2      2     2
+--R                      (4B C  + 24A B C  - 12A B C)D
+--R                 *
+--R                       4
+--R                    a b
+--R                + 
+--R                        6        5         2               2      2  4
+--R                      7D  - 27B D  + (- 14C  + 110A C + 47B  + 82A )D
+--R                    + 
+--R                            2                 3       2   3
+--R                      (20B C  - 196A B C - 27B  - 126A B)D
+--R                    + 
+--R                            4        3       2     2  2         2       3
+--R                          4C  + 72A C  + (18B  + 3A )C  + (42A B  + 230A )C
+--R                        + 
+--R                             2 2    4
+--R                          12A B  - A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             4          3      2   2
+--R                      (- 5B C  - 30A B C  + 15A B C )D
+--R                 *
+--R                     2 3
+--R                    a b
+--R                + 
+--R                                    5                     4
+--R                      (- 36C + 74A)D  + (174B C - 216A B)D
+--R                    + 
+--R                            3        2          2       2           2      3  3
+--R                      (- 36C  - 30A C  + (- 132B  - 332A )C + 586A B  + 30A )D
+--R                    + 
+--R                                 3           2       3       2           3
+--R                            36B C  - 192A B C  + (30B  + 288A B)C - 80A B
+--R                          + 
+--R                                  3
+--R                            - 160A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         2      2  3           2       3  2
+--R                          - 10C  + (- 20B  - 24A )C  + (- 18A B  - 214A )C
+--R                        + 
+--R                                2 2     4       3 2     5
+--R                          (- 36A B  - 2A )C - 2A B  + 2A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4     2   3
+--R                      2B C  + 12A B C  - 6A B C
+--R                 *
+--R                     3 2
+--R                    a b
+--R                + 
+--R                           6        5       2              2      2  4
+--R                      - 12D  + 40B D  + (16C  - 48A C - 96B  - 24A )D
+--R                    + 
+--R                               2                 3      2   3
+--R                      (- 200B C  + 128A B C + 40B  + 96A B)D
+--R                    + 
+--R                             4         3       2       2  2
+--R                          24C  - 108A C  + (48B  + 492A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 528A B  - 172A )C - 52B  - 264A B  + 100A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4           3       2   2         3       3
+--R                          - 40B C  + 216A B C  - 240A B C  + (80A B  + 264A B)C
+--R                        + 
+--R                             2 3     4
+--R                          24A B  + 8A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6       5      2      2  4          2      3  3
+--R                      4C  - 4A C  + (4B  + 16A )C  + (- 4A B  + 40A )C
+--R                    + 
+--R                          2 2      4  2       3 2     5
+--R                      (36A B  + 12A )C  + (12A B  - 4A )C
+--R                 *
+--R                     4
+--R                    a b
+--R                + 
+--R                                  5                     4
+--R                      (32C - 16A)D  + (- 80B C + 96A B)D
+--R                    + 
+--R                           3        2        2     2           2  3
+--R                      (- 8C  + 64A C  + (224B  + 8A )C - 176A B )D
+--R                    + 
+--R                                2       3          3     3   2
+--R                      (- 24A B C  - 144B C + 416A B  - 8A B)D
+--R                    + 
+--R                               4      2       2  3       3 2       2 2       4
+--R                          72A C  + (8B  - 224A )C  + 160A C  + (24A B  - 160A )C
+--R                        + 
+--R                                 4      3 2      5
+--R                          - 96A B  - 64A B  + 24A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4       2   3          3      3   2
+--R                      8B C  - 32A B C  + 128A B C  + (- 8A B  - 96A B)C
+--R                    + 
+--R                         4        3 3
+--R                      56A B C + 8A B
+--R                 *
+--R                     5
+--R                    a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                                   5                     4
+--R                      (- 5C + 59A)D  + (- 10B C - 42A B)D
+--R                    + 
+--R                        3        2      2     2         2      3  3
+--R                      (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                 *
+--R                     6
+--R                    b
+--R                + 
+--R                           6       5         2               2       2  4
+--R                      - 21D  + 9B D  + (- 11C  - 154A C - 55B  - 167A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (49B C  + 10A B C + 11B  + 129A B)D
+--R                    + 
+--R                         4        3         2      2  2           2      3    2
+--R                    (- 4C  + 52A C  + (- 12B  - 12A )C  + (- 12A B  - 68A )C)D
+--R                 *
+--R                       5
+--R                    a b
+--R                + 
+--R                                  5                       4
+--R                      (75C - 13A)D  + (- 196B C + 452A B)D
+--R                    + 
+--R                          3        2        2       2           2      3  3
+--R                      (68C  - 10A C  + (143B  + 671A )C - 425A B  - 99A )D
+--R                    + 
+--R                                 3           2         3       2           3
+--R                          - 84B C  + 288A B C  + (- 26B  - 438A B)C + 14A B
+--R                        + 
+--R                             3
+--R                          70A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                         5        4       2      2  3         2      3  2
+--R                      (5C  - 65A C  + (15B  + 15A )C  + (15A B  + 85A )C )D
+--R                 *
+--R                     2 4
+--R                    a b
+--R                + 
+--R                         6         5         2               2      2  4
+--R                      12D  - 194B D  + (- 99C  - 164A C + 90B  + 29A )D
+--R                    + 
+--R                             2                  3       2   3
+--R                      (241B C  - 698A B C - 206B  - 737A B)D
+--R                    + 
+--R                               4         3         2       2  2
+--R                          - 45C  + 188A C  + (- 63B  - 966A )C
+--R                        + 
+--R                                 2       3        4       2 2       4
+--R                          (660A B  + 338A )C + 42B  + 357A B  - 127A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          65B C  - 336A B C  + (13B  + 432A B)C
+--R                        + 
+--R                                  3       3        2 3    4
+--R                          (- 22A B  - 192A B)C + 3A B  - A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6        5        2     2  4          2      3  3
+--R                      - 2C  + 26A C  + (- 6B  - 6A )C  + (- 6A B  - 34A )C
+--R                 *
+--R                     3 3
+--R                    a b
+--R                + 
+--R                                     5                    4
+--R                      (- 76C + 128A)D  + (500B C + 52A B)D
+--R                    + 
+--R                          3         2          2       2           2      3  3
+--R                      (72C  + 422A C  + (- 652B  - 256A )C + 812A B  + 98A )D
+--R                    + 
+--R                                3          2        3        2            3
+--R                          222B C  + 36A B C  + (348B  + 1410A B)C - 884A B
+--R                        + 
+--R                                3
+--R                          - 132A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2       2  3
+--R                          - 6C  - 120A C  + (- 8B  + 592A )C
+--R                        + 
+--R                                  2       3  2         4       2 2       4
+--R                          (- 30A B  - 172A )C  + (- 40B  - 384A B  + 278A )C
+--R                        + 
+--R                               4       3 2     5
+--R                          36A B  + 102A B  + 4A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5          4      3       2   3
+--R                      - 20B C  + 78A B C  + (2B  - 124A B)C
+--R                    + 
+--R                           3       3   2         2 3      4        3 3     5
+--R                      (4A B  + 144A B)C  + (- 18A B  - 16A B)C - 4A B  + 2A B
+--R                 *
+--R                     4 2
+--R                    a b
+--R                + 
+--R                           6        5       2               2       2  4
+--R                      - 32D  + 80B D  + (68C  - 88A C - 224B  - 172A )D
+--R                    + 
+--R                               2                  3      2   3
+--R                      (- 240B C  - 288A B C + 192B  - 16A B)D
+--R                    + 
+--R                             4         3        2       2  2
+--R                          40C  - 624A C  + (600B  + 576A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 336A B  - 368A )C - 64B  - 360A B  + 120A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4           3         3        2   2
+--R                          - 224B C  + 288A B C  + (- 80B  - 1344A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (672A B  + 480A B)C + 48B  + 336A B  - 160A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6       5      2       2  4            2      3  3
+--R                      4C  + 8A C  + (8B  - 100A )C  + (- 144A B  - 80A )C
+--R                    + 
+--R                         4      4  2           4       3 2      5        2 4
+--R                      (4B  - 36A )C  + (- 24A B  - 144A B  - 56A )C - 12A B
+--R                    + 
+--R                           4 2     6
+--R                      - 40A B  + 4A
+--R                 *
+--R                     5
+--R                    a b
+--R                + 
+--R                                  5                      4
+--R                      (32C + 64A)D  + (- 192B C + 32A B)D
+--R                    + 
+--R                            3        2       2          2  3
+--R                      (- 32C  + (320B  + 160A )C + 64A B )D
+--R                    + 
+--R                                2       3          3       3   2
+--R                      (- 96A B C  - 576B C + 320A B  - 160A B)D
+--R                    + 
+--R                               5         4       2       2  3       3 2
+--R                          - 32C  + 288A C  + (32B  - 320A )C  + 384A C
+--R                        + 
+--R                               4      2 2       4           4      5
+--R                          (160B  + 96A B  - 160A )C - 384A B  + 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       2   3           3       3   2
+--R                      32B C  - 160A B C  + 512A B C  + (- 32A B  - 320A B)C
+--R                    + 
+--R                          4           5      3 3      5
+--R                      224A B C + 32A B  + 32A B  - 32A B
+--R                 *
+--R                     6
+--R                    a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                        6        5       2              2      2  4
+--R                      6D  - 22B D  + (10C  - 76A C + 18B  + 42A )D
+--R                    + 
+--R                           2               3      2   3
+--R                      (2B C  + 36A B C - 2B  - 30A B)D
+--R                 *
+--R                     7
+--R                    b
+--R                + 
+--R                                    5                     4
+--R                      (- 16C - 24A)D  + (168B C - 272A B)D
+--R                    + 
+--R                            3         2         2       2           2       3  3
+--R                      (- 24C  + 288A C  + (- 32B  - 136A )C + 104A B  + 160A )D
+--R                    + 
+--R                             3           2      3       2     2
+--R                      (- 8B C  - 144A B C  + (8B  + 120A B)C)D
+--R                 *
+--R                       6
+--R                    a b
+--R                + 
+--R                          6         5       2              2       2  4
+--R                      - 5D  + 208B D  + (28C  + 52A C - 90B  - 258A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 166B C  + 352A B C + 168B  + 696A B)D
+--R                    + 
+--R                              4         3         2       2  2
+--R                          - 7C  - 344A C  + (- 36B  + 108A )C
+--R                        + 
+--R                                   2       3       4       2 2     4
+--R                          (- 228A B  - 572A )C - 9B  - 126A B  + 7A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                            4           3         3       2   2
+--R                      (10B C  + 180A B C  + (- 10B  - 150A B)C )D
+--R                 *
+--R                     2 5
+--R                    a b
+--R                + 
+--R                                    5                       4
+--R                      (155C - 103A)D  + (- 600B C - 212A B)D
+--R                    + 
+--R                          3         2        2        2            2       3  3
+--R                      (36C  - 308A C  + (816B  + 1470A )C - 1208A B  + 210A )D
+--R                    + 
+--R                                  3           2          3        2            3
+--R                          - 296B C  + 624A B C  + (- 332B  - 1848A B)C + 432A B
+--R                        + 
+--R                              3
+--R                          516A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5         4       2      2  3         2       3  2
+--R                          37C  + 171A C  + (62B  + 16A )C  + (54A B  + 548A )C
+--R                        + 
+--R                              4       2 2      4         4     3 2      5
+--R                          (17B  + 300A B  + 11A )C - 5A B  + 8A B  - 15A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5          4      3      2   3
+--R                      - 4B C  - 72A B C  + (4B  + 60A B)C
+--R                 *
+--R                     3 4
+--R                    a b
+--R                + 
+--R                         6         5          2                2       2  4
+--R                      94D  - 130B D  + (- 210C  - 318A C + 752B  + 284A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (494B C  + 940A B C - 88B  - 118A B)D
+--R                    + 
+--R                                4         3           2        2  2
+--R                          - 204C  + 880A C  + (- 1170B  - 2592A )C
+--R                        + 
+--R                                  2       3         4        2 2       4
+--R                          (1284A B  - 380A )C + 306B  + 1434A B  - 352A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3        3        2   2
+--R                          380B C  - 936A B C  + (102B  + 1596A B)C
+--R                        + 
+--R                                   3        3         5       2 3      4
+--R                          (- 700A B  - 1272A B)C - 22B  - 302A B  - 24A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6        5         2      2  4         2       3  3
+--R                      - 16C  - 38A C  + (- 12B  - 38A )C  + (76A B  - 112A )C
+--R                    + 
+--R                           4       2 2      4  2         4      3 2      5
+--R                      (- 8B  - 192A B  - 56A )C  + (10A B  - 16A B  + 38A )C
+--R                    + 
+--R                        2 4     4 2     6
+--R                      6A B  + 8A B  - 2A
+--R                 *
+--R                     4 3
+--R                    a b
+--R                + 
+--R                                      5                    4
+--R                      (- 220C - 244A)D  + (324B C - 60A B)D
+--R                    + 
+--R                                3         2           2       2            2
+--R                          - 112C  + 948A C  + (- 1776B  - 288A )C - 1008A B
+--R                        + 
+--R                              3
+--R                          188A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3           2         3       2             3
+--R                          - 108B C  - 936A B C  + (1104B  + 876A B)C - 1312A B
+--R                        + 
+--R                              3
+--R                          104A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2        2  3
+--R                          160C  - 668A C  + (176B  + 1512A )C
+--R                        + 
+--R                                2      3  2          4        2 2       4
+--R                          (60A B  + 80A )C  + (- 372B  - 1248A B  + 344A )C
+--R                        + 
+--R                                4      3 2      5
+--R                          484A B  + 84A B  - 84A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4       3       2   3
+--R                      - 84B C  + 360A B C  + (12B  - 592A B)C
+--R                    + 
+--R                             3       3   2       5       2 3       4          5
+--R                      (280A B  + 712A B)C  + (12B  + 276A B  - 124A B)C - 4A B
+--R                    + 
+--R                         3 3      5
+--R                      40A B  + 48A B
+--R                 *
+--R                     5 2
+--R                    a b
+--R                + 
+--R                           6         5        2                2      2  4
+--R                      - 16D  + 160B D  + (168C  + 368A C - 176B  - 24A )D
+--R                    + 
+--R                              2                  3      2   3
+--R                      (- 32B C  - 192A B C + 448B  + 96A B)D
+--R                    + 
+--R                              4         3         2       2  2
+--R                          288C  - 832A C  + (1008B  + 384A )C
+--R                        + 
+--R                                  2       3         4       2 2      4
+--R                          (1248A B  - 512A )C - 112B  + 432A B  - 32A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3          3        2   2
+--R                          - 192B C  + 1024A B C  + (- 928B  - 1536A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (320A B  + 768A B)C + 32B  + 352A B  - 448A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5       2       2  4           2      3  3
+--R                      - 24C  + 144A C  + (96B  - 168A )C  + (- 64A B  - 96A )C
+--R                    + 
+--R                          4       2 2       4  2            4       3 2      5
+--R                      (40B  + 384A B  + 152A )C  + (- 272A B  - 192A B  - 48A )C
+--R                    + 
+--R                           6       2 4      4 2      6
+--R                      - 16B  - 152A B  + 32A B  + 40A
+--R                 *
+--R                     6
+--R                    a b
+--R                + 
+--R                           5                       4
+--R                      64A D  + (- 192B C - 256A B)D
+--R                    + 
+--R                               2        2       2           2  3
+--R                      (- 256A C  + (384B  + 128A )C + 128A B )D
+--R                    + 
+--R                             3          3       3   2
+--R                      (- 640B C - 384A B  - 128A B)D
+--R                    + 
+--R                                5         4       2 3       3 2       4
+--R                          - 128C  + 320A C  - 384A C  + 384A C  + 640B C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 320A B  + 256A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       2   3       3   2
+--R                      64B C  - 512A B C  + 640A B C  - 896A B C
+--R                    + 
+--R                            5       4            5       5
+--R                      (- 64B  + 320A B)C + 128A B  - 128A B
+--R                 *
+--R                     7
+--R                    a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                                 5                  4
+--R                      (4C - 60A)D  + (8B C + 72A B)D
+--R                    + 
+--R                           3        2         2      2          2      3  3
+--R                      (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                 *
+--R                     8
+--R                    b
+--R                + 
+--R                         6        5         2               2       2  4
+--R                      28D  - 44B D  + (- 12C  + 280A C + 68B  + 340A )D
+--R                    + 
+--R                               2                3       2   3
+--R                      (- 124B C  - 56A B C - 52B  - 396A B)D
+--R                    + 
+--R                          4        3       2      2  2         2       3    2
+--R                      (16C  - 80A C  + (48B  + 48A )C  + (48A B  + 144A )C)D
+--R                 *
+--R                       7
+--R                    a b
+--R                + 
+--R                                     5                   4
+--R                      (- 208C - 16A)D  + (168B C + 8A B)D
+--R                    + 
+--R                                 3         2          2        2           2
+--R                            - 60C  - 252A C  + (- 512B  - 1728A )C + 608A B
+--R                          + 
+--R                                  3
+--R                            - 352A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                3           2        3        2           3
+--R                          368B C  - 384A B C  + (136B  + 1368A B)C - 56A B
+--R                        + 
+--R                                3
+--R                          - 152A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         4         2      2  3
+--R                          - 20C  + 100A C  + (- 60B  - 60A )C
+--R                        + 
+--R                                  2       3  2
+--R                          (- 60A B  - 180A )C
+--R                     *
+--R                        D
+--R                 *
+--R                     2 6
+--R                    a b
+--R                + 
+--R                            6         5        2                 2      2  4
+--R                      - 102D  + 166B D  + (276C  + 1024A C - 552B  + 12A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 204B C  - 280A B C + 136B  + 724A B)D
+--R                    + 
+--R                              4         3        2        2  2
+--R                          210C  - 280A C  + (888B  + 3060A )C
+--R                        + 
+--R                                   2        3         4        2 2       4
+--R                          (- 984A B  + 1120A )C - 194B  - 1296A B  + 258A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4           3         3        2   2
+--R                          - 370B C  + 504A B C  + (- 72B  - 1404A B)C
+--R                        + 
+--R                                 3       3        5     2 3      4
+--R                          (128A B  + 424A B)C + 2B  + 8A B  + 14A B
+--R                     *
+--R                        D
+--R                    + 
+--R                        6        5       2      2  4         2      3  3
+--R                      8C  - 40A C  + (24B  + 24A )C  + (24A B  + 72A )C
+--R                 *
+--R                     3 5
+--R                    a b
+--R                + 
+--R                                    5                       4
+--R                      (158C + 262A)D  + (- 842B C - 602A B)D
+--R                    + 
+--R                                3          2         2       2            2
+--R                            156C  - 2876A C  + (1688B  - 808A )C + 1080A B
+--R                          + 
+--R                                  3
+--R                            - 736A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                3           2          3        2             3
+--R                          - 4B C  + 540A B C  + (- 988B  - 2484A B)C + 1332A B
+--R                        + 
+--R                                3
+--R                          - 644A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5         4          2        2  3
+--R                          - 194C  + 414A C  + (- 360B  - 2216A )C
+--R                        + 
+--R                                 2        3  2        4        2 2       4
+--R                          (120A B  - 1200A )C  + (338B  + 2124A B  - 422A )C
+--R                        + 
+--R                                 4     3 2     5
+--R                          - 54A B  - 4A B  + 2A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4         3       2   3
+--R                      118B C  - 138A B C  + (- 12B  + 444A B)C
+--R                    + 
+--R                              3       3   2        5      2 3      4          5
+--R                      (- 76A B  - 292A B)C  + (- 2B  + 12A B  + 14A B)C - 2A B
+--R                    + 
+--R                          3 3      5
+--R                      - 4A B  - 18A B
+--R                 *
+--R                     4 4
+--R                    a b
+--R                + 
+--R                         6         5        2                2       2  4
+--R                      60D  - 264B D  + (240C  - 576A C + 356B  + 152A )D
+--R                    + 
+--R                              2                    3       2   3
+--R                      (1244B C  + 2472A B C - 1032B  + 596A B)D
+--R                    + 
+--R                                4          3           2        2  2
+--R                          - 520C  + 3168A C  + (- 1692B  + 1200A )C
+--R                        + 
+--R                                    2        3         4       2 2       4
+--R                          (- 2352A B  + 2152A )C - 148B  - 732A B  + 544A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3         3        2   2
+--R                          316B C  - 832A B C  + (1292B  + 3936A B)C
+--R                        + 
+--R                                    3       3          5        2 3       4
+--R                          (- 1224A B  + 384A B)C - 160B  - 1100A B  + 932A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6         5         2       2  4          2       3  3
+--R                      52C  - 104A C  + (- 60B  + 532A )C  + (104A B  + 520A )C
+--R                    + 
+--R                             4       2 2     4  2         4       3 2       5
+--R                      (- 108B  - 696A B  + 4A )C  + (16A B  + 176A B  + 128A )C
+--R                    + 
+--R                        6      2 4      4 2      6
+--R                      4B  + 12A B  + 12A B  - 44A
+--R                 *
+--R                     5 3
+--R                    a b
+--R                + 
+--R                                     5                     4
+--R                      (- 32C - 336A)D  + (576B C + 736A B)D
+--R                    + 
+--R                                  3         2          2       2           2
+--R                            - 672C  + 520A C  + (- 816B  - 768A )C - 432A B
+--R                          + 
+--R                                 3
+--R                            - 72A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3            2         3        2
+--R                          - 664B C  - 3024A B C  + (2416B  - 1800A B)C
+--R                        + 
+--R                                 3       3
+--R                          1712A B  - 496A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5          4        2       2  3
+--R                          360C  - 1680A C  + (608B  - 352A )C
+--R                        + 
+--R                                 2        3  2          4       2 2       4
+--R                          (984A B  - 1680A )C  + (- 528B  - 192A B  - 904A )C
+--R                        + 
+--R                                 4       3 2      5
+--R                          1088A B  - 120A B  - 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                              5           4          3        2   3
+--R                      - 192B C  + 344A B C  + (- 296B  - 1904A B)C
+--R                    + 
+--R                              3       3   2        5       2 3       4
+--R                      (- 16A B  + 288A B)C  + (144B  + 360A B  - 848A B)C
+--R                    + 
+--R                             5      3 3     5
+--R                      - 48A B  + 16A B  + 8A B
+--R                 *
+--R                     6 2
+--R                    a b
+--R                + 
+--R                           5          2                2       2  4
+--R                      64B D  + (- 144C  + 544A C - 256B  + 240A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 448B C  - 768A B C + 128B  - 192A B)D
+--R                    + 
+--R                              4         3        2       2  2
+--R                          480C  - 192A C  + (288B  + 768A )C
+--R                        + 
+--R                                 2      3         4       2 2      4
+--R                          (768A B  + 64A )C - 384B  + 480A B  + 32A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                   3           3       2   2
+--R                          1792A B C  + (- 1472B  + 384A B)C
+--R                        + 
+--R                                    3        3         5       2 3       4
+--R                          (- 1664A B  + 1280A B)C - 64B  - 576A B  - 256A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5       2      2  4         2       3  3
+--R                      - 80C  + 288A C  + (96B  + 80A )C  + (64A B  + 256A )C
+--R                    + 
+--R                           4       2 2       4  2            4      3 2      5
+--R                      (432B  + 768A B  + 464A )C  + (- 160A B  + 64A B  - 32A )C
+--R                    + 
+--R                            2 4       4 2      6
+--R                      - 144A B  + 288A B  + 48A
+--R                 *
+--R                     7
+--R                    a b
+--R                + 
+--R                                4
+--R                      - 256A B D
+--R                    + 
+--R                           3         2        2       2           2  3
+--R                      (128C  - 256A C  + (384B  - 128A )C + 256A B )D
+--R                    + 
+--R                               2       3          3       3   2
+--R                      (384A B C  - 256B C - 384A B  + 128A B)D
+--R                    + 
+--R                                5         4          2       2  3
+--R                          - 128C  + 128A C  + (- 128B  - 384A )C
+--R                        + 
+--R                               4       2 2           4       3 2       5
+--R                          (640B  - 384A B )C + 256A B  + 256A B  - 128A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5           4       2   3          3       3   2
+--R                      128B C  - 512A B C  + 512A B C  + (128A B  - 896A B)C
+--R                    + 
+--R                             5       4            5       3 3       5
+--R                      (- 256B  + 384A B)C + 128A B  - 128A B  - 128A B
+--R                 *
+--R                     8
+--R                    a
+--R             *
+--R                c
+--R            + 
+--R                      6        5        2              2      2  4
+--R                  - 8D  + 24B D  + (- 8C  + 48A C - 24B  - 72A )D
+--R                + 
+--R                       2               3      2   3
+--R                  (8B C  - 48A B C + 8B  + 72A B)D
+--R             *
+--R                 9
+--R                b
+--R            + 
+--R                               5                      4
+--R                  (32C + 128A)D  + (- 160B C - 64A B)D
+--R                + 
+--R                      3         2        2       2          2      3  3
+--R                  (48C  - 272A C  + (160B  + 368A )C - 64A B  + 48A )D
+--R                + 
+--R                          3           2         3       2     2
+--R                  (- 32B C  + 192A B C  + (- 32B  - 288A B)C)D
+--R             *
+--R                   8
+--R                a b
+--R            + 
+--R                     6         5       2                2       2  4
+--R                  12D  - 152B D  + (40C  - 896A C + 176B  - 160A )D
+--R                + 
+--R                         2                 3      2   3
+--R                  (400B C  + 432A B C - 72B  - 72A B)D
+--R                + 
+--R                            4         3          2       2  2
+--R                      - 100C  + 544A C  + (- 336B  - 672A )C
+--R                    + 
+--R                            2       3        4       2 2      4
+--R                      (48A B  - 176A )C + 36B  + 312A B  - 12A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                        4           3       3       2   2
+--R                  (40B C  - 240A B C  + (40B  + 360A B)C )D
+--R             *
+--R                 2 7
+--R                a b
+--R            + 
+--R                               5                     4
+--R                  (96C - 280A)D  + (752B C + 608A B)D
+--R                + 
+--R                         3          2          2       2           2       3  3
+--R                  (- 296C  + 2152A C  + (- 728B  + 816A )C - 504A B  + 432A )D
+--R                + 
+--R                           3            2        3       2            3  2
+--R                  (- 464B C  - 1008A B C  + (384B  + 240A B)C - 304A B )D
+--R                + 
+--R                         5         4        2       2  3          2       3  2
+--R                      88C  - 464A C  + (272B  + 520A )C  + (192A B  + 248A )C
+--R                    + 
+--R                            4       2 2      4        3 2      5
+--R                      (- 88B  - 744A B  - 32A )C - 40A B  + 24A
+--R                 *
+--R                    D
+--R                + 
+--R                         5          4         3       2   3
+--R                  - 16B C  + 96A B C  + (- 16B  - 144A B)C
+--R             *
+--R                 3 6
+--R                a b
+--R            + 
+--R                    6         5          2                2      2  4
+--R                  8D  + 220B D  + (- 524C  + 800A C - 320B  + 68A )D
+--R                + 
+--R                            2                   3        2   3
+--R                  (- 1368B C  - 2496A B C + 408B  - 1008A B)D
+--R                + 
+--R                          4          3         2        2  2
+--R                      464C  - 2480A C  + (1176B  - 1224A )C
+--R                    + 
+--R                              2        3        4       2 2       4
+--R                      (1728A B  - 1392A )C + 24B  + 576A B  - 296A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                            4            3          3       2   2
+--R                      220B C  + 1152A B C  + (- 600B  - 624A B)C
+--R                    + 
+--R                             3       3         5       2 3       4
+--R                      (448A B  + 304A B)C + 44B  + 512A B  - 188A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6         5         2       2  4            2       3  3
+--R                  - 28C  + 144A C  + (- 72B  - 140A )C  + (- 176A B  - 144A )C
+--R                + 
+--R                      4       2 2      4  2       3 2      5       2 4     4 2
+--R                  (52B  + 432A B  + 92A )C  + (32A B  - 64A )C - 4A B  + 8A B
+--R                + 
+--R                     6
+--R                  12A
+--R             *
+--R                 4 5
+--R                a b
+--R            + 
+--R                                  5                       4
+--R                  (- 120C + 416A)D  + (- 484B C - 532A B)D
+--R                + 
+--R                       3         2         2       2           2       3  3
+--R                  (968C  - 824A C  + (1144B  + 400A )C + 856A B  + 128A )D
+--R                + 
+--R                             3            2           3        2             3
+--R                      1144B C  + 3768A B C  + (- 1336B  + 2760A B)C - 1096A B
+--R                    + 
+--R                           3
+--R                      1112A B
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                            5          4          2       2  3
+--R                      - 320C  + 1464A C  + (- 912B  + 712A )C
+--R                    + 
+--R                                2        3  2        4       2 2       4
+--R                      (- 1968A B  + 1304A )C  + (176B  - 984A B  + 760A )C
+--R                    + 
+--R                              4       3 2      5
+--R                      - 584A B  - 232A B  - 80A
+--R                 *
+--R                    D
+--R                + 
+--R                         5           4        3       2   3
+--R                  - 20B C  - 516A B C  + (280B  + 488A B)C
+--R                + 
+--R                          3       3   2         5       2 3       4           5
+--R                  (- 88A B  - 360A B)C  + (- 52B  - 552A B  + 204A B)C + 12A B
+--R                + 
+--R                       3 3      5
+--R                  - 72A B  + 12A B
+--R             *
+--R                 5 4
+--R                a b
+--R            + 
+--R                       6         5        2                 2       2  4
+--R                  - 48D  - 200B D  + (240C  - 1096A C + 232B  - 472A )D
+--R                + 
+--R                         2                  3       2   3
+--R                  (136B C  + 720A B C - 112B  + 312A B)D
+--R                + 
+--R                            4         3           2        2  2
+--R                      - 904C  + 352A C  + (- 1416B  - 1152A )C
+--R                    + 
+--R                                2       3         4        2 2       4
+--R                      (- 2160A B  - 528A )C + 480B  - 1080A B  - 296A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                              4            3         3        2   2
+--R                      - 416B C  - 2688A B C  + (1512B  - 2208A B)C
+--R                    + 
+--R                              3        3          5       2 3       4
+--R                      (2224A B  - 2336A B)C + 152B  + 824A B  - 224A B
+--R                 *
+--R                    D
+--R                + 
+--R                     6         5        2       2  4          2       3  3
+--R                  88C  - 360A C  + (264B  - 176A )C  + (880A B  - 320A )C
+--R                + 
+--R                         4       2 2       4  2          4       3 2       5
+--R                  (- 248B  + 144A B  - 472A )C  + (504A B  + 416A B  + 104A )C
+--R                + 
+--R                    6       2 4       4 2      6
+--R                  8B  + 320A B  - 136A B  - 16A
+--R             *
+--R                 6 3
+--R                a b
+--R            + 
+--R                               5                     4
+--R                  (208C - 48A)D  + (432B C + 528A B)D
+--R                + 
+--R                         3          2          2       2           2       3  3
+--R                  (- 128C  + 1104A C  + (- 576B  + 704A )C - 544A B  + 112A )D
+--R                + 
+--R                         3          2        3       2            3       3   2
+--R                  (432B C  - 96A B C  + (160B  + 528A B)C + 320A B  - 160A B)D
+--R                + 
+--R                          5        4        2       2  3           2       3  2
+--R                      448C  - 48A C  + (768B  + 928A )C  + (1776A B  + 608A )C
+--R                    + 
+--R                            4        2 2       4           4       3 2       5
+--R                    (- 1168B  + 2112A B  + 352A )C - 752A B  + 272A B  + 400A
+--R                 *
+--R                    D
+--R                + 
+--R                       5           4          3       2   3
+--R                  16B C  + 960A B C  + (- 624B  + 224A B)C
+--R                + 
+--R                            3        3   2         5       2 3      4
+--R                  (- 1120A B  + 1440A B)C  + (- 16B  - 528A B  - 48A B)C
+--R                + 
+--R                          5       3 3      5
+--R                  - 336A B  - 160A B  + 96A B
+--R             *
+--R                 7 2
+--R                a b
+--R            + 
+--R                         2              2      2  4
+--R                  (- 288C  + 64A C - 64B  + 96A )D
+--R                + 
+--R                           2                  3       2   3
+--R                  (- 256B C  - 768A B C + 128B  - 384A B)D
+--R                + 
+--R                              3        2       2  2          2      3
+--R                      - 576A C  + (576B  - 192A )C  + (384A B  - 64A )C
+--R                    + 
+--R                          2 2      4
+--R                      192A B  + 64A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                              4           3        3       2   2
+--R                      - 384B C  - 384A B C  + (128B  - 768A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 512A B  - 128A B)C + 128B  - 256A B  - 128A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6          2       2  4            2       3  3
+--R                  - 96C  + (- 192B  - 224A )C  + (- 704A B  - 256A )C
+--R                + 
+--R                       4       2 2       4  2          4       3 2       5
+--R                  (736B  - 576A B  - 160A )C  + (576A B  - 448A B  - 256A )C
+--R                + 
+--R                     6       2 4       4 2      6
+--R                  64B  + 224A B  + 128A B  - 32A
+--R             *
+--R                 8
+--R                a b
+--R            + 
+--R                       3       2          2  3            2       3        3   2
+--R                  (128C  - 128A C + 256A B )D  + (384A B C  - 256B C + 128A B)D
+--R                + 
+--R                         4       2 3       2 2          4       5           5
+--R                  (128A C  - 128B C  - 384A B C + 256A B  - 128A )D + 128B C
+--R                + 
+--R                      2   3         3 2          5       4          3 3
+--R                  512A B C  + 128A B C  + (- 256B  + 384A B)C - 128A B
+--R             *
+--R                 9
+--R                a
+--R     + 
+--R                                    +-----------------------------------------+
+--R                +-----------------+ |    +-----------------+
+--R            +-+ |          2     2  |    |          2     2            2     2
+--R         4a\|2 \|- 4a c + b  + 8a  \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R          +---------------------------------------+
+--R          |  +-----------------+
+--R          |  |          2     2            2     2
+--R         \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a  %%BN1
+--R      *
+--R         log
+--R                           2 3 8
+--R                      32A D a c
+--R                    + 
+--R                                 2 2 2         3        2  3
+--R                          - 16A D a b  + (- 16D  - 16B D )a b
+--R                        + 
+--R                                 2                   2      3  4
+--R                          (128A D  - 128A B D - 32A C  + 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              2   4      3       2  2 3
+--R                          2A D a b  + (8D  + 8B D )a b
+--R                        + 
+--R                                        2                  2      3  3 2
+--R                          ((32C - 448A)D  + 64A B D + 16A C  - 16A )a b
+--R                        + 
+--R                                   3        2
+--R                              - 32D  + 32B D
+--R                            + 
+--R                                    2               2       2          2
+--R                              (- 48C  + 224A C + 64B  + 144A )D + 16B C
+--R                            + 
+--R                                           2
+--R                              96A B C - 48A B
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                      2                 3         2      2
+--R                              - 128A D  - 512A B D + 64C  - 128A C  - 64A C
+--R                            + 
+--R                                    2       3
+--R                              128A B  + 128A
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              3      2    5
+--R                          (- D  - B D )a b
+--R                        + 
+--R                                          2                2     3  2 4
+--R                          ((- 16C + 192A)D  - 8A B D - 2A C  + 2A )a b
+--R                        + 
+--R                                  3         2       2               2      2
+--R                              160D  + 128B D  + (24C  - 112A C - 32B  - 72A )D
+--R                            + 
+--R                                    2                2
+--R                              - 8B C  - 48A B C + 24A B
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                           2                             3
+--R                              (80C - 560A)D  + (- 96B C + 1312A B)D - 48C
+--R                            + 
+--R                                    2         2      2           2       3
+--R                              304A C  + (- 48B  - 16A )C - 112A B  - 368A
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              128D  + 256B D
+--R                            + 
+--R                                     2               2       2           2
+--R                              (- 384C  + 512A C + 64B  + 384A )D - 128B C
+--R                            + 
+--R                                   3       2
+--R                              - 64B  - 384A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                       2                  3         2       2
+--R                              - 1024A D  + 512A B D + 256C  + 128A C  - 256A C
+--R                            + 
+--R                                    2       3
+--R                              512A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                     2   6
+--R                          (2C - 22A)D a b
+--R                        + 
+--R                                   3        2        2             2     2
+--R                              - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D
+--R                            + 
+--R                                 2              2
+--R                              B C  + 6A B C - 3A B
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                               2                          3
+--R                              (- 328C + 1896A)D  + (48B C - 528A B)D + 12C
+--R                            + 
+--R                                      2       2      2          2       3
+--R                              - 120A C  + (24B  + 20A )C + 32A B  + 152A
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 224D  - 800B D
+--R                            + 
+--R                                   2                 2        2          2
+--R                              (720C  - 2080A C - 512B  - 1392A )D + 16B C
+--R                            + 
+--R                                              3       2
+--R                              - 672A B C + 64B  + 720A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                             3
+--R                              (160C + 2976A)D  + (576B C + 1088A B)D - 608C
+--R                            + 
+--R                                    2        2       2            2      3
+--R                              416A C  + (288B  + 992A )C - 1120A B  - 32A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              256D  - 256B D
+--R                            + 
+--R                                     2                 2       2           2
+--R                              (- 192C  - 1664A C - 640B  - 960A )D - 448B C
+--R                            + 
+--R                                                3       2
+--R                              - 1152A B C - 128B  - 192A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                      2                   3          2       2
+--R                              - 512A D  + 4096A B D - 256C  + 1024A C  + 256A C
+--R                            + 
+--R                                      2        3
+--R                              - 512A B  - 1024A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             3       2    7
+--R                          (8D  + 8B D )a b
+--R                        + 
+--R                                            2                        3        2
+--R                              (141C - 755A)D  + (- 6B C + 58A B)D - C  + 13A C
+--R                            + 
+--R                                   2     2         2      3
+--R                              (- 3B  - 3A )C - 3A B  - 17A
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    3        2
+--R                              - 284D  - 36B D
+--R                            + 
+--R                                     2                2       2          2
+--R                              (- 276C  + 888A C + 228B  + 588A )D + 12B C
+--R                            + 
+--R                                            3       2
+--R                              312A B C - 20B  - 276A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              2                             3
+--R                              (- 32C - 2016A)D  + (192B C - 3072A B)D + 320C
+--R                            + 
+--R                                      2       2       2           2       3
+--R                              - 720A C  + (96B  - 192A )C + 672A B  + 848A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 896D  - 384B D
+--R                            + 
+--R                                    2                 2       2            2
+--R                              (1344C  + 1408A C + 896B  + 576A )D + 1088B C
+--R                            + 
+--R                                              3        2
+--R                              1920A B C + 384B  + 1344A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                             3
+--R                              (- 640C + 4224A)D  + (768B C - 8448A B)D - 128C
+--R                            + 
+--R                                       2        2       2           2        3
+--R                              - 1920A C  + (384B  + 640A )C - 128A B  + 2432A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3          2
+--R                              - 256D  - 1280B D
+--R                            + 
+--R                                    2                 2        2            2
+--R                              (3072C  - 4096A C - 512B  - 3072A )D + 1024B C
+--R                            + 
+--R                                  3        2
+--R                              512B  + 3072A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                     2                    3         2        2
+--R                              2048A D  + 2048A B D - 2048C  + 512A C  + 2048A C
+--R                            + 
+--R                                       2       3
+--R                              - 4096A B  - 512A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                        2   8
+--R                          (- 16C + 80A)D a b
+--R                        + 
+--R                                  3         2       2               2      2
+--R                              146D  + 118B D  + (30C  - 100A C - 26B  - 66A )D
+--R                            + 
+--R                                    2               3      2
+--R                              - 2B C  - 36A B C + 2B  + 30A B
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                             2                              3
+--R                              (726C - 2090A)D  + (- 180B C + 1100A B)D - 62C
+--R                            + 
+--R                                    2         2      2           2       3
+--R                              230A C  + (- 90B  - 58A )C - 154A B  - 350A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1752D  + 2760B D
+--R                            + 
+--R                                      2                 2        2           2
+--R                              (- 2160C  + 3840A C + 696B  + 2736A )D - 528B C
+--R                            + 
+--R                                             3        2
+--R                              576A B C - 312B  - 2160A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                       2                                3
+--R                              - 8160A D  + (- 4608B C + 5376A B)D + 864C
+--R                            + 
+--R                                    2           2        2           2        3
+--R                              192A C  + (- 2304B  - 3936A )C + 960A B  - 3264A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1152D  + 4224B D
+--R                            + 
+--R                                      2                   2        2
+--R                              (- 5760C  + 11520A C + 2304B  + 8064A )D
+--R                            + 
+--R                                       2                   3        2
+--R                              - 1152B C  + 2304A B C - 768B  - 5760A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D
+--R                            + 
+--R                                 3          2           2        2            2
+--R                            3840C  - 3072A C  + (- 2304B  - 6912A )C + 6912A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 512D  + 512B D
+--R                            + 
+--R                                    2                  2       2            2
+--R                              (3840C  + 2560A C + 2048B  + 768A )D + 2816B C
+--R                            + 
+--R                                               3        2
+--R                              4608A B C + 1024B  + 3840A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                     2                    3          2        2
+--R                              2048A D  - 8192A B D - 1024C  - 2048A C  + 1024A C
+--R                            + 
+--R                                       2        3
+--R                              - 2048A B  + 2048A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                3        2    9
+--R                          (- 16D  - 16B D )a b
+--R                        + 
+--R                                              2                         3
+--R                              (- 308C + 972A)D  + (24B C - 104A B)D + 4C
+--R                            + 
+--R                                     2       2      2          2      3
+--R                              - 20A C  + (12B  + 12A )C + 12A B  + 36A
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 456D  - 920B D
+--R                            + 
+--R                                   2                 2        2           2
+--R                              (744C  - 1712A C - 376B  - 1176A )D + 104B C
+--R                            + 
+--R                                              3       2
+--R                              - 432A B C + 88B  + 744A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                                2                             3
+--R                              (- 1668C + 8316A)D  + (1656B C - 136A B)D - 364C
+--R                            + 
+--R                                    2        2        2           2       3
+--R                              380A C  + (828B  + 1468A )C - 452A B  + 724A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 2496D  - 6432B D
+--R                            + 
+--R                                    2                   2        2           2
+--R                              (5328C  - 14304A C - 3408B  - 9648A )D + 336B C
+--R                            + 
+--R                                                3        2
+--R                              - 4320A B C + 528B  + 5328A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              2                                3
+--R                              (6528C + 3456A)D  + (11520B C + 7296A B)D - 3072C
+--R                            + 
+--R                                   2         2         2            2        3
+--R                            4704A C  + (5760B  + 10752A )C - 4224A B  + 2976A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                   3         2
+--R                              1024D  - 512B D
+--R                            + 
+--R                                      2                  2        2            2
+--R                              (- 5760C  - 3840A C - 3072B  - 1152A )D - 4224B C
+--R                            + 
+--R                                                 3        2
+--R                              - 6912A B C - 1536B  - 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2
+--R                              (1280C - 6912A)D  + (- 1536B C + 12800A B)D
+--R                            + 
+--R                                   3          2          2        2            2
+--R                              1280C  + 2816A C  + (- 768B  - 2304A )C + 2304A B
+--R                            + 
+--R                                     3
+--R                              - 3840A
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                     2           2                  2        2
+--R                              2048B D  + (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                            + 
+--R                                       2        3        2
+--R                              - 2048B C  - 1024B  - 6144A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                                 3          2        2
+--R                              - 8192A B D + 4096C  - 2048A C  - 4096A C
+--R                            + 
+--R                                     2        3
+--R                              8192A B  + 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                  2   10
+--R                      (32C - 96A)D a b
+--R                    + 
+--R                             3        2         2               2       2
+--R                          24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D
+--R                        + 
+--R                                2               3      2
+--R                          - 8B C  + 48A B C - 8B  - 72A B
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                         2                             3
+--R                          (376C - 1416A)D  + (- 144B C - 144A B)D + 40C
+--R                        + 
+--R                                 2         2       2          2      3
+--R                          - 72A C  + (- 72B  - 136A )C + 56A B  - 24A
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              3          2
+--R                          360D  + 1080B D
+--R                        + 
+--R                                 2                 2        2          2
+--R                          (- 936C  + 2608A C + 632B  + 1752A )D - 40B C
+--R                        + 
+--R                                        3       2
+--R                          816A B C - 88B  - 936A B
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                          2                                3
+--R                          (- 24C - 4248A)D  + (- 2160B C - 2160A B)D + 536C
+--R                        + 
+--R                                   2           2        2           2       3
+--R                          - 1080A C  + (- 1080B  - 1976A )C + 712A B  - 360A
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1152D  + 3456B D
+--R                        + 
+--R                                  2                  2        2           2
+--R                          (- 1296C  + 7968A C + 2400B  + 5040A )D + 816B C
+--R                        + 
+--R                                         3        2
+--R                          3744A B C + 96B  - 1296A B
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            2                                3
+--R                          (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D + 960C
+--R                        + 
+--R                                   2           2        2           2        3
+--R                          - 3456A C  + (- 3456B  - 5568A )C + 768A B  - 1152A
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1536D  - 4608B D
+--R                        + 
+--R                                 2                   2        2            2
+--R                          (11520C  - 12800A C - 1024B  - 9984A )D + 4352B C
+--R                        + 
+--R                                           3         2
+--R                          1536A B C + 2048B  + 11520A B
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                          2                               3
+--R                          (6656C - 1536A)D  + (9216B C + 9216A B)D - 5632C
+--R                        + 
+--R                                 2         2         2            2        3
+--R                          4608A C  + (4608B  + 11776A )C - 9728A B  + 1536A
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                  2        2            2
+--R                          (- 9216C  + 2048A C - 2048B  + 3072A )D - 5120B C
+--R                        + 
+--R                                             3        2
+--R                          - 6144A B C - 2048B  - 9216A B
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                            3        2           2  11
+--R                      (4096C  - 4096A C + 8192A B )a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                         3 2 8
+--R                  - 16A D a c
+--R                + 
+--R                          3   2        3          2  2
+--R                      4A D a b  + (8B D  + 24A C D )a b
+--R                    + 
+--R                                   3          2           2      3    3
+--R                      ((16C - 64A)D  + 80A B D  + (- 16A C  - 16A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                             3         2    3
+--R                      (- 2B D  - 6A C D )a b
+--R                    + 
+--R                                         3                     2
+--R                          (- 12C + 188A)D  + (- 12B C - 52A B)D
+--R                        + 
+--R                                 2      3
+--R                          (- 4A C  + 12A )D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                               4        3         2              2       2  2
+--R                          - 24D  + 16B D  + (- 24C  + 16A C - 40B  - 120A )D
+--R                        + 
+--R                               2                2          3     3
+--R                          (8B C  - 48A B C + 24A B)D + 8A C  - 8A C
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                      3                      2
+--R                          (64C + 32A)D  + (- 96B C + 320A B)D
+--R                        + 
+--R                              3        2       2          2      3            2
+--R                          (16C  - 64A C  + 112A C - 128A B  - 64A )D + 48A B C
+--R                        + 
+--R                             3
+--R                          16A B
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                  3                 2        2     3      4
+--R                      ((2C - 41A)D  + (3B C + 8A B)D  + (2A C  - 2A )D)a b
+--R                    + 
+--R                             4        3       2               2      2  2
+--R                          14D  - 80B D  + (18C  - 224A C + 26B  + 66A )D
+--R                        + 
+--R                               2                2          3     3
+--R                          (2B C  + 36A B C - 18A B)D - 2A C  + 2A C
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                          3                     2
+--R                          (- 144C + 232A)D  + (120B C - 808A B)D
+--R                        + 
+--R                               3         2       2      2           2       3
+--R                          (- 4C  + 212A C  + (24B  - 20A )C + 112A B  + 196A )D
+--R                        + 
+--R                                3          2      2        3
+--R                          - 4B C  - 36A B C  + 12A B C - 4A B
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               4        3         2              2       2  2
+--R                          - 64D  + 96B D  + (- 24C  - 80A C - 64B  - 408A )D
+--R                        + 
+--R                                2                3       2        4        3
+--R                          (80B C  - 96A B C + 64B  + 336A B)D - 8C  - 32A C
+--R                        + 
+--R                                2      2  2           2      3        2 2     4
+--R                          (- 24B  - 48A )C  + (- 48A B  - 32A )C - 24A B  - 8A
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                3                       2
+--R                          384A D  + (- 384B C - 128A B)D
+--R                        + 
+--R                              3         2        2       2           2
+--R                          (64C  - 128A C  + (192B  + 448A )C - 512A B )D
+--R                        + 
+--R                                 3           2       2           3      3
+--R                          - 64B C  + 192A B C  - 192A B C + 64A B  + 64A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                              4        3        2             2     2  2
+--R                          - 2D  + 18B D  + (- 3C  + 52A C - 4B  - 9A )D
+--R                        + 
+--R                                2              2
+--R                          (- B C  - 6A B C + 3A B)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                       3                    2
+--R                          (86C - 686A)D  + (54B C + 420A B)D
+--R                        + 
+--R                               3       2         2      2          2       3
+--R                          (- 4C  + 9A C  + (- 18B  - 14A )C - 32A B  - 115A )D
+--R                        + 
+--R                             3         2     2
+--R                          B C  + 6A B C  - 3A B C
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              4        3        2                2        2  2
+--R                          224D  - 92B D  + (162C  + 280A C + 320B  + 1206A )D
+--R                        + 
+--R                                   2                 3       2        4        3
+--R                          (- 172B C  + 336A B C - 60B  - 492A B)D + 6C  - 48A C
+--R                        + 
+--R                              2      2  2         2      3       2 2     4
+--R                          (18B  + 24A )C  + (24A B  + 80A )C + 6A B  + 2A
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                           3                     2
+--R                          (- 232C - 1128A)D  + (936B C - 584A B)D
+--R                        + 
+--R                                    3         2          2        2            2
+--R                              - 208C  + 400A C  + (- 312B  - 1376A )C + 1192A B
+--R                            + 
+--R                                   3
+--R                              - 64A
+--R                         *
+--R                            D
+--R                        + 
+--R                             3           2       3       2           3       3
+--R                        96B C  - 384A B C  + (24B  + 240A B)C - 24A B  - 144A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                             4         3        2               2       2  2
+--R                          64D  + 256B D  + (144C  + 608A C - 32B  + 336A )D
+--R                        + 
+--R                                2      3       2         4        3
+--R                          (64B C  + 64B  + 768A B)D + 48C  - 96A C
+--R                        + 
+--R                              2      2  2           2       3        4       2 2
+--R                          (48B  + 96A )C  + (- 96A B  + 224A )C - 32B  - 144A B
+--R                        + 
+--R                               4
+--R                          - 16A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                          3            2
+--R                          (- 256C + 256A)D  - 1792A B D
+--R                        + 
+--R                              3         2        2      2           2       3
+--R                          (64C  - 256A C  + (768B  - 64A )C + 128A B  + 256A )D
+--R                        + 
+--R                                  3           2          3       2            3
+--R                          - 256B C  + 192A B C  + (- 128B  - 768A B)C + 256A B
+--R                        + 
+--R                             3
+--R                          64A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                         3                     2
+--R                          (- 13C + 139A)D  + (- 18B C - 58A B)D
+--R                        + 
+--R                            3        2      2     2         2      3
+--R                          (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 109D  + 265B D
+--R                        + 
+--R                                 2                2       2  2
+--R                          (- 114C  + 591A C - 183B  - 543A )D
+--R                        + 
+--R                                2                 3       2       4        3
+--R                          (27B C  - 228A B C + 19B  + 225A B)D - C  + 13A C
+--R                        + 
+--R                               2     2  2          2      3
+--R                          (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        3                        2
+--R                          (258C + 874A)D  + (- 978B C + 1542A B)D
+--R                        + 
+--R                              3         2       2       2           2       3
+--R                          (94C  - 990A C  + (54B  + 426A )C - 714A B  - 346A )D
+--R                        + 
+--R                                 3           2         3       2          3
+--R                          - 10B C  + 234A B C  + (- 14B  - 174A B)C + 2A B
+--R                        + 
+--R                             3
+--R                          30A B
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                  3          2               2       2  2
+--R                          - 768B D  + (- 192C  - 736A C - 80B  + 384A )D
+--R                        + 
+--R                                   2                 3        2            3
+--R                          (- 272B C  + 96A B C - 384B  - 1968A B)D + 368A C
+--R                        + 
+--R                              2       2  2          2       3        4       2 2
+--R                          (48B  + 192A )C  + (288A B  - 112A )C + 16B  + 240A B
+--R                        + 
+--R                             4
+--R                          64A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (384C - 1536A)D  + (576B C + 4032A B)D
+--R                        + 
+--R                                    3         2           2        2           2
+--R                              - 416C  + 672A C  + (- 2112B  - 1312A )C + 512A B
+--R                            + 
+--R                                    3
+--R                              - 992A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3           2        3        2            3
+--R                          480B C  - 672A B C  + (128B  + 1632A B)C - 512A B
+--R                        + 
+--R                                3
+--R                          - 160A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          256D  - 384B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 192C  + 1024A C - 256B  + 2112A )D
+--R                        + 
+--R                                   2                  3        2          4
+--R                          (- 640B C  - 768A B C - 256B  - 1152A B)D + 192C
+--R                        + 
+--R                             2       2  2          2       3         2 2      4
+--R                        (576B  + 384A )C  + (384A B  + 512A )C - 192A B  - 64A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (- 256C - 512A)D  + (1536B C - 1280A B)D
+--R                        + 
+--R                                 2        2           2       3         3
+--R                          (256A C  - 2048A C + 2560A B  + 256A )D - 512B C
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                             4        3       2               2      2  2
+--R                          14D  - 54B D  + (18C  - 140A C + 26B  + 66A )D
+--R                        + 
+--R                               2               3      2
+--R                          (2B C  + 36A B C - 2B  - 30A B)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                          3                    2
+--R                          (- 142C + 688A)D  + (54B C - 800A B)D
+--R                        + 
+--R                             3         2       2      2           2       3
+--R                          (6C  + 100A C  + (54B  + 22A )C + 160A B  + 248A )D
+--R                        + 
+--R                                3          2      3      2
+--R                          - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 416D  + 190B D
+--R                        + 
+--R                                2                 2        2  2
+--R                          (- 84C  - 1254A C - 438B  - 2514A )D
+--R                        + 
+--R                                 2                  3        2         4
+--R                          (666B C  - 264A B C + 298B  + 1758A B)D - 20C
+--R                        + 
+--R                               3         2       2  2            2       3
+--R                          22A C  + (- 66B  - 102A )C  + (- 114A B  - 158A )C
+--R                        + 
+--R                              4      2 2      4
+--R                          - 2B  - 48A B  - 14A
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                         3                        2
+--R                          (284C + 2876A)D  + (- 588B C - 3516A B)D
+--R                        + 
+--R                                  3        2         2        2            2
+--R                              788C  + 84A C  + (2292B  + 4428A )C - 1404A B
+--R                            + 
+--R                                   3
+--R                              2252A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2          3        2            3
+--R                          - 532B C  + 492A B C  + (- 148B  - 1164A B)C + 140A B
+--R                        + 
+--R                              3
+--R                          308A B
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 608D  + 640B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (240C  - 3552A C + 960B  - 5232A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (1632B C  + 1536A B C + 928B  + 1632A B)D - 464C
+--R                        + 
+--R                                  3          2        2  2
+--R                          - 128A C  + (- 912B  - 1344A )C
+--R                        + 
+--R                                   2        3         4       2 2      4
+--R                          (- 384A B  - 1664A )C + 160B  + 528A B  + 16A
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                          3                         2
+--R                          (1280C + 1664A)D  + (- 1920B C + 3456A B)D
+--R                        + 
+--R                                  3         2          2        2            2
+--R                              128C  + 576A C  + (- 192B  + 6144A )C - 4800A B
+--R                            + 
+--R                                  3
+--R                              704A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3           2        3       2            3
+--R                          - 256B C  - 768A B C  + (704B  + 384A B)C - 448A B
+--R                        + 
+--R                              3
+--R                          128A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          128D  - 1280B D
+--R                        + 
+--R                                 2                 2       2  2
+--R                          (- 768C  - 2560A C + 640B  + 768A )D
+--R                        + 
+--R                                   2                   2          4         3
+--R                          (- 896B C  - 768A B C - 4224A B)D - 128C  - 128A C
+--R                        + 
+--R                               2       2  2          2       3         4
+--R                          (384B  - 768A )C  + (768A B  - 896A )C + 256B
+--R                        + 
+--R                              2 2       4
+--R                          384A B  - 128A
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                  3                       2
+--R                          - 512A D  + (1536B C + 2048A B)D
+--R                        + 
+--R                                      3          2           2        2
+--R                                - 256C  + 2048A C  + (- 3072B  - 1792A )C
+--R                              + 
+--R                                       2
+--R                                2048A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3           2        2             3       3
+--R                          1024B C  - 768A B C  + 3072A B C - 1024A B  - 256A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                       3                    2
+--R                          (20C - 156A)D  + (24B C + 104A B)D
+--R                        + 
+--R                               3        2         2      2          2      3
+--R                          (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                     *
+--R                           8
+--R                        a b
+--R                    + 
+--R                              4         3        2                2        2  2
+--R                          204D  - 316B D  + (144C  - 364A C + 292B  + 1092A )D
+--R                        + 
+--R                                   2                 3       2        4        3
+--R                          (- 164B C  + 288A B C - 84B  - 636A B)D + 4C  - 20A C
+--R                        + 
+--R                              2      2  2         2      3
+--R                          (12B  + 12A )C  + (12A B  + 36A )C
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (- 36C - 3084A)D  + (1368B C + 1312A B)D
+--R                        + 
+--R                                    3          2          2        2           2
+--R                              - 428C  + 1348A C  + (- 996B  - 1780A )C + 644A B
+--R                            + 
+--R                                    3
+--R                              - 996A
+--R                         *
+--R                            D
+--R                        + 
+--R                              3           2       3       2          3      3
+--R                        128B C  - 312A B C  + (64B  + 528A B)C - 8A B  - 56A B
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          924D  + 588B D
+--R                        + 
+--R                                 2                2        2  2
+--R                          (- 216C  + 5556A C + 60B  + 6156A )D
+--R                        + 
+--R                                    2                   3        2          4
+--R                          (- 2172B C  - 1584A B C - 444B  - 1332A B)D + 252C
+--R                        + 
+--R                                  3        2       2  2           2        3
+--R                          - 708A C  + (540B  + 396A )C  + (- 36A B  + 1236A )C
+--R                        + 
+--R                               4       2 2       4
+--R                          - 72B  - 576A B  - 120A
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            3                        2
+--R                          (- 2184C - 2040A)D  + (- 648B C - 2616A B)D
+--R                        + 
+--R                                    3          2          2        2
+--R                              - 408C  - 2760A C  + (- 504B  - 9096A )C
+--R                            + 
+--R                                     2        3
+--R                              3720A B  - 2904A
+--R                         *
+--R                            D
+--R                        + 
+--R                                3            2          3       2            3
+--R                          840B C  + 1656A B C  + (- 168B  - 360A B)C + 792A B
+--R                        + 
+--R                                3
+--R                          - 408A B
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 480D  + 1536B D
+--R                        + 
+--R                               2                  2        2  2
+--R                          (864C  + 4992A C - 2400B  - 1440A )D
+--R                        + 
+--R                                  2                  3        2          4
+--R                          (1056B C  + 576A B C - 768B  + 6624A B)D + 384C
+--R                        + 
+--R                                3          2        2  2
+--R                          864A C  + (- 576B  + 2304A )C
+--R                        + 
+--R                                    2        3         4       2 2       4
+--R                          (- 1152A B  + 2208A )C - 576B  - 576A B  + 384A
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                         3                         2
+--R                          (256C + 2688A)D  + (- 2688B C - 4736A B)D
+--R                        + 
+--R                                   3          2         2        2            2
+--R                              1216C  - 4544A C  + (6528B  + 4032A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              1344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2        2             3       3
+--R                        - 1344B C  + 1728A B C  - 5184A B C + 1536A B  + 192A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                  3         2                  2        2  2
+--R                          - 512B D  + (1152C  - 4352A C + 2048B  - 1920A )D
+--R                        + 
+--R                                  2                   2          4         3
+--R                          (1280B C  + 4608A B C - 768A B)D - 640C  + 512A C
+--R                        + 
+--R                                  2       2  2            2        3
+--R                          (- 1920B  - 768A )C  + (- 768A B  - 1536A )C
+--R                        + 
+--R                               2 2       4
+--R                          1152A B  + 384A
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   2
+--R                          2048A B D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1024C  + 2048A C  + (- 3072B  + 1024A )C
+--R                            + 
+--R                                       2
+--R                              - 2048A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3            2         3        2             3
+--R                          1024B C  - 3072A B C  + (2048B  + 3072A B)C - 1024A B
+--R                        + 
+--R                                 3
+--R                          - 1024A B
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                           4        3         2               2       2  2
+--R                      - 24D  + 56B D  + (- 24C  + 112A C - 40B  - 120A )D
+--R                    + 
+--R                           2               3      2
+--R                      (8B C  - 48A B C + 8B  + 72A B)D
+--R                 *
+--R                       9
+--R                    a b
+--R                + 
+--R                                  3                      2
+--R                      (8C + 336A)D  + (- 216B C - 96A B)D
+--R                    + 
+--R                          3         2        2       2          2      3
+--R                      (56C  - 240A C  + (120B  + 184A )C - 80A B  + 96A )D
+--R                    + 
+--R                            3          2        3      2
+--R                      - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            4         3         2               2        2  2
+--R                      - 216D  + 192B D  + (- 72C  - 40A C - 176B  - 1248A )D
+--R                    + 
+--R                             2                3       2         4         3
+--R                      (304B C  + 48A B C + 64B  + 384A B)D - 32C  + 120A C
+--R                    + 
+--R                          2      2  2         2       3       4      2 2      4
+--R                    (- 72B  - 24A )C  + (24A B  - 152A )C + 8B  + 96A B  + 24A
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                     3                        2
+--R                      (264C + 2304A)D  + (- 1080B C - 144A B)D
+--R                    + 
+--R                           3          2        2        2           2       3
+--R                      (280C  - 1008A C  + (504B  + 1880A )C - 736A B  + 864A )D
+--R                    + 
+--R                            3          2        3       2            3      3
+--R                    - 120B C  - 96A B C  + (- 8B  - 216A B)C - 144A B  + 16A B
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                            4          3        2                 2        2  2
+--R                      - 144D  - 1848B D  + (576C  - 6600A C + 984B  - 1800A )D
+--R                    + 
+--R                              2                   3        2          4
+--R                      (1416B C  + 2304A B C + 120B  - 1800A B)D - 192C
+--R                    + 
+--R                            3          2       2  2          2        3
+--R                      648A C  + (- 216B  - 360A )C  + (360A B  - 1128A )C
+--R                    + 
+--R                          4       2 2      4
+--R                      120B  + 576A B  + 72A
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      3                       2
+--R                      (1392C - 3024A)D  + (4752B C + 4464A B)D
+--R                    + 
+--R                                 3          2           2        2           2
+--R                          - 1104C  + 6624A C  + (- 3312B  + 2544A )C - 336A B
+--R                        + 
+--R                              3
+--R                          576A
+--R                     *
+--R                        D
+--R                    + 
+--R                              3            2        3        2             3
+--R                      - 384B C  - 3024A B C  + (144B  + 2592A B)C - 1008A B
+--R                    + 
+--R                          3
+--R                      240A B
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                          4          3
+--R                      384D  + 1600B D
+--R                    + 
+--R                              2                  2        2  2
+--R                      (- 2784C  + 7040A C - 1280B  + 3936A )D
+--R                    + 
+--R                                2                   3        2          4
+--R                      (- 3776B C  - 8448A B C + 832B  - 1728A B)D + 480C
+--R                    + 
+--R                               3         2        2  2           2       3
+--R                      - 2304A C  + (2592B  - 1152A )C  + (1152A B  + 768A )C
+--R                    + 
+--R                          4        2 2       4
+--R                      384B  - 1440A B  - 864A
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                       3                         2
+--R                      (- 1664C + 384A)D  + (- 3456B C - 4224A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          1792C  - 5376A C  + (2688B  - 5632A )C + 3200A B
+--R                        + 
+--R                                 3
+--R                          - 1536A
+--R                     *
+--R                        D
+--R                    + 
+--R                            3            2           3        2             3
+--R                      512B C  + 6144A B C  + (- 2176B  - 2304A B)C + 1152A B
+--R                    + 
+--R                          3
+--R                      768A B
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                2       2  2
+--R                      (2304C  - 512A C + 512B  - 768A )D
+--R                    + 
+--R                              2                    3        2          4
+--R                      (2048B C  + 6144A B C - 1024B  + 3072A B)D - 256C
+--R                    + 
+--R                             3           2        2  2             2       3
+--R                      1536A C  + (- 2304B  + 1536A )C  + (- 1536A B  + 512A )C
+--R                    + 
+--R                            4       2 2       4
+--R                      - 512B  + 768A B  + 768A
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                              3        2           2              2        3
+--R                      (- 1024C  + 1024A C - 2048A B )D - 3072A B C  + 2048B C
+--R                    + 
+--R                             3
+--R                      - 1024A B
+--R                 *
+--R                     10
+--R                    a
+--R             *
+--R                     2
+--R                %%BN1
+--R            + 
+--R                           2 3 8
+--R                      32A D a c
+--R                    + 
+--R                                 2 2 2         3        2  3
+--R                          - 16A D a b  + (- 16D  - 16B D )a b
+--R                        + 
+--R                                 2                   2      3  4
+--R                          (128A D  - 128A B D - 32A C  + 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              2   4      3       2  2 3
+--R                          2A D a b  + (8D  + 8B D )a b
+--R                        + 
+--R                                        2                  2      3  3 2
+--R                          ((32C - 448A)D  + 64A B D + 16A C  - 16A )a b
+--R                        + 
+--R                                   3        2
+--R                              - 32D  + 32B D
+--R                            + 
+--R                                    2               2       2          2
+--R                              (- 48C  + 224A C + 64B  + 144A )D + 16B C
+--R                            + 
+--R                                           2
+--R                              96A B C - 48A B
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                      2                 3         2      2
+--R                              - 128A D  - 512A B D + 64C  - 128A C  - 64A C
+--R                            + 
+--R                                    2       3
+--R                              128A B  + 128A
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              3      2    5
+--R                          (- D  - B D )a b
+--R                        + 
+--R                                          2                2     3  2 4
+--R                          ((- 16C + 192A)D  - 8A B D - 2A C  + 2A )a b
+--R                        + 
+--R                                  3         2       2               2      2
+--R                              160D  + 128B D  + (24C  - 112A C - 32B  - 72A )D
+--R                            + 
+--R                                    2                2
+--R                              - 8B C  - 48A B C + 24A B
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                           2                             3
+--R                              (80C - 560A)D  + (- 96B C + 1312A B)D - 48C
+--R                            + 
+--R                                    2         2      2           2       3
+--R                              304A C  + (- 48B  - 16A )C - 112A B  - 368A
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              128D  + 256B D
+--R                            + 
+--R                                     2               2       2           2
+--R                              (- 384C  + 512A C + 64B  + 384A )D - 128B C
+--R                            + 
+--R                                   3       2
+--R                              - 64B  - 384A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                       2                  3         2       2
+--R                              - 1024A D  + 512A B D + 256C  + 128A C  - 256A C
+--R                            + 
+--R                                    2       3
+--R                              512A B  - 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                     2   6
+--R                          (2C - 22A)D a b
+--R                        + 
+--R                                   3        2        2             2     2
+--R                              - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D
+--R                            + 
+--R                                 2              2
+--R                              B C  + 6A B C - 3A B
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                               2                          3
+--R                              (- 328C + 1896A)D  + (48B C - 528A B)D + 12C
+--R                            + 
+--R                                      2       2      2          2       3
+--R                              - 120A C  + (24B  + 20A )C + 32A B  + 152A
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 224D  - 800B D
+--R                            + 
+--R                                   2                 2        2          2
+--R                              (720C  - 2080A C - 512B  - 1392A )D + 16B C
+--R                            + 
+--R                                              3       2
+--R                              - 672A B C + 64B  + 720A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             2                             3
+--R                              (160C + 2976A)D  + (576B C + 1088A B)D - 608C
+--R                            + 
+--R                                    2        2       2            2      3
+--R                              416A C  + (288B  + 992A )C - 1120A B  - 32A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              256D  - 256B D
+--R                            + 
+--R                                     2                 2       2           2
+--R                              (- 192C  - 1664A C - 640B  - 960A )D - 448B C
+--R                            + 
+--R                                                3       2
+--R                              - 1152A B C - 128B  - 192A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                      2                   3          2       2
+--R                              - 512A D  + 4096A B D - 256C  + 1024A C  + 256A C
+--R                            + 
+--R                                      2        3
+--R                              - 512A B  - 1024A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             3       2    7
+--R                          (8D  + 8B D )a b
+--R                        + 
+--R                                            2                        3        2
+--R                              (141C - 755A)D  + (- 6B C + 58A B)D - C  + 13A C
+--R                            + 
+--R                                   2     2         2      3
+--R                              (- 3B  - 3A )C - 3A B  - 17A
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                    3        2
+--R                              - 284D  - 36B D
+--R                            + 
+--R                                     2                2       2          2
+--R                              (- 276C  + 888A C + 228B  + 588A )D + 12B C
+--R                            + 
+--R                                            3       2
+--R                              312A B C - 20B  - 276A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                              2                             3
+--R                              (- 32C - 2016A)D  + (192B C - 3072A B)D + 320C
+--R                            + 
+--R                                      2       2       2           2       3
+--R                              - 720A C  + (96B  - 192A )C + 672A B  + 848A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 896D  - 384B D
+--R                            + 
+--R                                    2                 2       2            2
+--R                              (1344C  + 1408A C + 896B  + 576A )D + 1088B C
+--R                            + 
+--R                                              3        2
+--R                              1920A B C + 384B  + 1344A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                               2                             3
+--R                              (- 640C + 4224A)D  + (768B C - 8448A B)D - 128C
+--R                            + 
+--R                                       2        2       2           2        3
+--R                              - 1920A C  + (384B  + 640A )C - 128A B  + 2432A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    3          2
+--R                              - 256D  - 1280B D
+--R                            + 
+--R                                    2                 2        2            2
+--R                              (3072C  - 4096A C - 512B  - 3072A )D + 1024B C
+--R                            + 
+--R                                  3        2
+--R                              512B  + 3072A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                     2                    3         2        2
+--R                              2048A D  + 2048A B D - 2048C  + 512A C  + 2048A C
+--R                            + 
+--R                                       2       3
+--R                              - 4096A B  - 512A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                        2   8
+--R                          (- 16C + 80A)D a b
+--R                        + 
+--R                                  3         2       2               2      2
+--R                              146D  + 118B D  + (30C  - 100A C - 26B  - 66A )D
+--R                            + 
+--R                                    2               3      2
+--R                              - 2B C  - 36A B C + 2B  + 30A B
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                             2                              3
+--R                              (726C - 2090A)D  + (- 180B C + 1100A B)D - 62C
+--R                            + 
+--R                                    2         2      2           2       3
+--R                              230A C  + (- 90B  - 58A )C - 154A B  - 350A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1752D  + 2760B D
+--R                            + 
+--R                                      2                 2        2           2
+--R                              (- 2160C  + 3840A C + 696B  + 2736A )D - 528B C
+--R                            + 
+--R                                             3        2
+--R                              576A B C - 312B  - 2160A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                       2                                3
+--R                              - 8160A D  + (- 4608B C + 5376A B)D + 864C
+--R                            + 
+--R                                    2           2        2           2        3
+--R                              192A C  + (- 2304B  - 3936A )C + 960A B  - 3264A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              1152D  + 4224B D
+--R                            + 
+--R                                      2                   2        2
+--R                              (- 5760C  + 11520A C + 2304B  + 8064A )D
+--R                            + 
+--R                                       2                   3        2
+--R                              - 1152B C  + 2304A B C - 768B  - 5760A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D
+--R                            + 
+--R                                 3          2           2        2            2
+--R                            3840C  - 3072A C  + (- 2304B  - 6912A )C + 6912A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 512D  + 512B D
+--R                            + 
+--R                                    2                  2       2            2
+--R                              (3840C  + 2560A C + 2048B  + 768A )D + 2816B C
+--R                            + 
+--R                                               3        2
+--R                              4608A B C + 1024B  + 3840A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                     2                    3          2        2
+--R                              2048A D  - 8192A B D - 1024C  - 2048A C  + 1024A C
+--R                            + 
+--R                                       2        3
+--R                              - 2048A B  + 2048A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                3        2    9
+--R                          (- 16D  - 16B D )a b
+--R                        + 
+--R                                              2                         3
+--R                              (- 308C + 972A)D  + (24B C - 104A B)D + 4C
+--R                            + 
+--R                                     2       2      2          2      3
+--R                              - 20A C  + (12B  + 12A )C + 12A B  + 36A
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 456D  - 920B D
+--R                            + 
+--R                                   2                 2        2           2
+--R                              (744C  - 1712A C - 376B  - 1176A )D + 104B C
+--R                            + 
+--R                                              3       2
+--R                              - 432A B C + 88B  + 744A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                                2                             3
+--R                              (- 1668C + 8316A)D  + (1656B C - 136A B)D - 364C
+--R                            + 
+--R                                    2        2        2           2       3
+--R                              380A C  + (828B  + 1468A )C - 452A B  + 724A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 2496D  - 6432B D
+--R                            + 
+--R                                    2                   2        2           2
+--R                              (5328C  - 14304A C - 3408B  - 9648A )D + 336B C
+--R                            + 
+--R                                                3        2
+--R                              - 4320A B C + 528B  + 5328A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                              2                                3
+--R                              (6528C + 3456A)D  + (11520B C + 7296A B)D - 3072C
+--R                            + 
+--R                                   2         2         2            2        3
+--R                            4704A C  + (5760B  + 10752A )C - 4224A B  + 2976A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                   3         2
+--R                              1024D  - 512B D
+--R                            + 
+--R                                      2                  2        2            2
+--R                              (- 5760C  - 3840A C - 3072B  - 1152A )D - 4224B C
+--R                            + 
+--R                                                 3        2
+--R                              - 6912A B C - 1536B  - 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                              2
+--R                              (1280C - 6912A)D  + (- 1536B C + 12800A B)D
+--R                            + 
+--R                                   3          2          2        2            2
+--R                              1280C  + 2816A C  + (- 768B  - 2304A )C + 2304A B
+--R                            + 
+--R                                     3
+--R                              - 3840A
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                     2           2                  2        2
+--R                              2048B D  + (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                            + 
+--R                                       2        3        2
+--R                              - 2048B C  - 1024B  - 6144A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                                 3          2        2
+--R                              - 8192A B D + 4096C  - 2048A C  - 4096A C
+--R                            + 
+--R                                     2        3
+--R                              8192A B  + 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                  2   10
+--R                      (32C - 96A)D a b
+--R                    + 
+--R                             3        2         2               2       2
+--R                          24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D
+--R                        + 
+--R                                2               3      2
+--R                          - 8B C  + 48A B C - 8B  - 72A B
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                         2                             3
+--R                          (376C - 1416A)D  + (- 144B C - 144A B)D + 40C
+--R                        + 
+--R                                 2         2       2          2      3
+--R                          - 72A C  + (- 72B  - 136A )C + 56A B  - 24A
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                              3          2
+--R                          360D  + 1080B D
+--R                        + 
+--R                                 2                 2        2          2
+--R                          (- 936C  + 2608A C + 632B  + 1752A )D - 40B C
+--R                        + 
+--R                                        3       2
+--R                          816A B C - 88B  - 936A B
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                          2                                3
+--R                          (- 24C - 4248A)D  + (- 2160B C - 2160A B)D + 536C
+--R                        + 
+--R                                   2           2        2           2       3
+--R                          - 1080A C  + (- 1080B  - 1976A )C + 712A B  - 360A
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1152D  + 3456B D
+--R                        + 
+--R                                  2                  2        2           2
+--R                          (- 1296C  + 7968A C + 2400B  + 5040A )D + 816B C
+--R                        + 
+--R                                         3        2
+--R                          3744A B C + 96B  - 1296A B
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                            2                                3
+--R                          (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D + 960C
+--R                        + 
+--R                                   2           2        2           2        3
+--R                          - 3456A C  + (- 3456B  - 5568A )C + 768A B  - 1152A
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1536D  - 4608B D
+--R                        + 
+--R                                 2                   2        2            2
+--R                          (11520C  - 12800A C - 1024B  - 9984A )D + 4352B C
+--R                        + 
+--R                                           3         2
+--R                          1536A B C + 2048B  + 11520A B
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                          2                               3
+--R                          (6656C - 1536A)D  + (9216B C + 9216A B)D - 5632C
+--R                        + 
+--R                                 2         2         2            2        3
+--R                          4608A C  + (4608B  + 11776A )C - 9728A B  + 1536A
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                  2                  2        2            2
+--R                          (- 9216C  + 2048A C - 2048B  + 3072A )D - 5120B C
+--R                        + 
+--R                                             3        2
+--R                          - 6144A B C - 2048B  - 9216A B
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                            3        2           2  11
+--R                      (4096C  - 4096A C + 8192A B )a
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                             3 2 8
+--R                      - 32A D a c
+--R                    + 
+--R                               3   2       4        3  2
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   3           2         2      3    3
+--R                          (- 128A D  + 128A B D  + (32A C  - 32A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                3 4        4       3    3
+--R                          - 2A D b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          3          2           2      3    2 2
+--R                          ((- 32C + 448A)D  - 64A B D  + (- 16A C  + 16A )D)a b
+--R                        + 
+--R                                 4        3       2               2       2  2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                      2                2
+--R                              (- 16B C  - 96A B C + 48A B)D
+--R                         *
+--R                             3
+--R                            a b
+--R                        + 
+--R                                    3           2
+--R                              128A D  + 512A B D
+--R                            + 
+--R                                    3         2      2          2       3
+--R                              (- 64C  + 128A C  + 64A C - 128A B  - 128A )D
+--R                         *
+--R                             4
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            4      3  5
+--R                          (D  + B D )b
+--R                        + 
+--R                                        3         2        2     3      4
+--R                          ((16C - 192A)D  + 8A B D  + (2A C  - 2A )D)a b
+--R                        + 
+--R                                    4         3
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 24C  + 112A C + 32B  + 72A )D
+--R                            + 
+--R                                   2                2
+--R                              (8B C  + 48A B C - 24A B)D
+--R                         *
+--R                             2 3
+--R                            a b
+--R                        + 
+--R                                             3                     2
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D
+--R                            + 
+--R                                3         2       2      2           2       3
+--R                            (48C  - 304A C  + (48B  + 16A )C + 112A B  + 368A )D
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2  2
+--R                              (384C  - 512A C - 64B  - 384A )D
+--R                            + 
+--R                                     2      3       2
+--R                              (128B C  + 64B  + 384A B)D
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                     3           2
+--R                              1024A D  - 512A B D
+--R                            + 
+--R                                     3         2       2          2       3
+--R                              (- 256C  - 128A C  + 256A C - 512A B  + 128A )D
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       3 6
+--R                          (- 2C + 22A)D b
+--R                        + 
+--R                                 4        3      2             2     2  2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D
+--R                            + 
+--R                                    2              2
+--R                              (- B C  - 6A B C + 3A B)D
+--R                         *
+--R                               5
+--R                            a b
+--R                        + 
+--R                                             3                      2
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D
+--R                            + 
+--R                                       3         2         2      2          2
+--R                                  - 12C  + 120A C  + (- 24B  - 20A )C - 32A B
+--R                                + 
+--R                                        3
+--R                                  - 152A
+--R                             *
+--R                                D
+--R                         *
+--R                             2 4
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D
+--R                            + 
+--R                                      2                 3       2
+--R                              (- 16B C  + 672A B C - 64B  - 720A B)D
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                               3                        2
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D
+--R                            + 
+--R                                      3         2          2       2
+--R                                  608C  - 416A C  + (- 288B  - 992A )C
+--R                                + 
+--R                                         2      3
+--R                                  1120A B  + 32A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                    4         3
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2  2
+--R                              (192C  + 1664A C + 640B  + 960A )D
+--R                            + 
+--R                                     2                   3       2
+--R                              (448B C  + 1152A B C + 128B  + 192A B)D
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                    3            2
+--R                              512A D  - 4096A B D
+--R                            + 
+--R                                   3          2       2          2        3
+--R                              (256C  - 1024A C  - 256A C + 512A B  + 1024A )D
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               4       3  7
+--R                          (- 8D  - 8B D )b
+--R                        + 
+--R                                              3                  2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D
+--R                            + 
+--R                                3        2      2     2         2      3
+--R                              (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                         *
+--R                               6
+--R                            a b
+--R                        + 
+--R                                  4        3
+--R                              284D  + 36B D
+--R                            + 
+--R                                   2                2       2  2
+--R                              (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                      2                 3       2
+--R                              (- 12B C  - 312A B C + 20B  + 276A B)D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                            3                        2
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D
+--R                            + 
+--R                                        3         2         2       2
+--R                                  - 320C  + 720A C  + (- 96B  + 192A )C
+--R                                + 
+--R                                          2       3
+--R                                  - 672A B  - 848A
+--R                             *
+--R                                D
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2  2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D
+--R                            + 
+--R                                        2                   3        2
+--R                              (- 1088B C  - 1920A B C - 384B  - 1344A B)D
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D
+--R                            + 
+--R                                      3          2          2       2
+--R                                  128C  + 1920A C  + (- 384B  - 640A )C
+--R                                + 
+--R                                        2        3
+--R                                  128A B  - 2432A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2  2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D
+--R                            + 
+--R                                        2       3        2
+--R                              (- 1024B C  - 512B  - 3072A B)D
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                       3            2
+--R                              - 2048A D  - 2048A B D
+--R                            + 
+--R                                    3         2        2           2       3
+--R                              (2048C  - 512A C  - 2048A C + 4096A B  + 512A )D
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      3 8
+--R                          (16C - 80A)D b
+--R                        + 
+--R                                    4         3
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 30C  + 100A C + 26B  + 66A )D
+--R                            + 
+--R                                   2               3      2
+--R                              (2B C  + 36A B C - 2B  - 30A B)D
+--R                         *
+--R                               7
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D
+--R                            + 
+--R                                3         2       2      2           2       3
+--R                            (62C  - 230A C  + (90B  + 58A )C + 154A B  + 350A )D
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                     4          3
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2  2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D
+--R                            + 
+--R                                     2                  3        2
+--R                              (528B C  - 576A B C + 312B  + 2160A B)D
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                     3                       2
+--R                              8160A D  + (4608B C - 5376A B)D
+--R                            + 
+--R                                        3         2         2        2
+--R                                  - 864C  - 192A C  + (2304B  + 3936A )C
+--R                                + 
+--R                                          2        3
+--R                                  - 960A B  + 3264A
+--R                             *
+--R                                D
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                     4          3
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2  2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D
+--R                            + 
+--R                                      2                   3        2
+--R                              (1152B C  - 2304A B C + 768B  + 5760A B)D
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                              3                       2
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D
+--R                            + 
+--R                                         3          2         2        2
+--R                                  - 3840C  + 3072A C  + (2304B  + 6912A )C
+--R                                + 
+--R                                           2
+--R                                  - 6912A B
+--R                             *
+--R                                D
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2  2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D
+--R                            + 
+--R                                        2                    3        2
+--R                              (- 2816B C  - 4608A B C - 1024B  - 3840A B)D
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                       3            2
+--R                              - 2048A D  + 8192A B D
+--R                            + 
+--R                                  3          2        2           2        3
+--R                            (1024C  + 2048A C  - 1024A C + 2048A B  - 2048A )D
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              4        3  9
+--R                          (16D  + 16B D )b
+--R                        + 
+--R                                            3                      2
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D
+--R                            + 
+--R                                 3        2         2      2          2      3
+--R                            (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                         *
+--R                               8
+--R                            a b
+--R                        + 
+--R                                  4         3
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2  2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D
+--R                            + 
+--R                                       2                 3       2
+--R                              (- 104B C  + 432A B C - 88B  - 744A B)D
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                              3                        2
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D
+--R                            + 
+--R                                      3         2          2        2
+--R                                  364C  - 380A C  + (- 828B  - 1468A )C
+--R                                + 
+--R                                        2       3
+--R                                  452A B  - 724A
+--R                             *
+--R                                D
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2  2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D
+--R                            + 
+--R                                       2                   3        2
+--R                              (- 336B C  + 4320A B C - 528B  - 5328A B)D
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                                3                          2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                       3          2           2         2
+--R                                  3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                                + 
+--R                                         2        3
+--R                                  4224A B  - 2976A
+--R                             *
+--R                                D
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                     4         3
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2  2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D
+--R                            + 
+--R                                      2                    3        2
+--R                              (4224B C  + 6912A B C + 1536B  + 5760A B)D
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                                3                        2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                         3          2        2        2
+--R                                  - 1280C  - 2816A C  + (768B  + 2304A )C
+--R                                + 
+--R                                           2        3
+--R                                  - 2304A B  + 3840A
+--R                             *
+--R                                D
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                       3
+--R                              - 2048B D
+--R                            + 
+--R                                    2                  2        2  2
+--R                              (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                      2        3        2
+--R                              (2048B C  + 1024B  + 6144A B)D
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2
+--R                              8192A B D
+--R                            + 
+--R                                    3          2        2           2        3
+--R                            (- 4096C  + 2048A C  + 4096A C - 8192A B  - 2048A )D
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    3 10
+--R                      (- 32C + 96A)D b
+--R                    + 
+--R                               4        3       2               2       2  2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                               2               3      2
+--R                          (8B C  - 48A B C + 8B  + 72A B)D
+--R                     *
+--R                           9
+--R                        a b
+--R                    + 
+--R                                           3                     2
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D
+--R                        + 
+--R                                3        2       2       2          2      3
+--R                          (- 40C  + 72A C  + (72B  + 136A )C - 56A B  + 24A )D
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                4          3
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2  2
+--R                          (936C  - 2608A C - 632B  - 1752A )D
+--R                        + 
+--R                                2                 3       2
+--R                          (40B C  - 816A B C + 88B  + 936A B)D
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                        3                       2
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D
+--R                        + 
+--R                                    3          2         2        2           2
+--R                              - 536C  + 1080A C  + (1080B  + 1976A )C - 712A B
+--R                            + 
+--R                                  3
+--R                              360A
+--R                         *
+--R                            D
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2  2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D
+--R                        + 
+--R                                   2                  3        2
+--R                          (- 816B C  - 3744A B C - 96B  + 1296A B)D
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D
+--R                        + 
+--R                                    3          2         2        2           2
+--R                              - 960C  + 3456A C  + (3456B  + 5568A )C - 768A B
+--R                            + 
+--R                                   3
+--R                              1152A
+--R                         *
+--R                            D
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                               4          3
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2  2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D
+--R                        + 
+--R                                    2                    3         2
+--R                          (- 4352B C  - 1536A B C - 2048B  - 11520A B)D
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D
+--R                        + 
+--R                                   3          2           2         2
+--R                              5632C  - 4608A C  + (- 4608B  - 11776A )C
+--R                            + 
+--R                                     2        3
+--R                              9728A B  - 1536A
+--R                         *
+--R                            D
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                2                  2        2  2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D
+--R                        + 
+--R                                  2                    3        2
+--R                          (5120B C  + 6144A B C + 2048B  + 9216A B)D
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                              3        2           2    10
+--R                      (- 4096C  + 4096A C - 8192A B )D a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                      4   8
+--R                  8A D a c
+--R                + 
+--R                            4 2          4         3
+--R                      - 2A D b  + (- 4B D  - 8A C D )a b
+--R                    + 
+--R                                    4          3     3 2  2
+--R                      ((- 8C + 32A)D  - 32A B D  + 8A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                          4         3  3
+--R                      (B D  + 2A C D )b
+--R                    + 
+--R                                   4                  3     3 2    2
+--R                      ((6C - 100A)D  + (4B C + 16A B)D  - 2A D )a b
+--R                    + 
+--R                             5        4      2              2      2  3
+--R                          12D  - 12B D  + (8C  + 16A C + 16B  + 52A )D
+--R                        + 
+--R                                        2   2        3     3
+--R                          (24A B C - 12A B)D  + (8A C  - 8A C)D
+--R                     *
+--R                         2
+--R                        a b
+--R                    + 
+--R                                        4                    3
+--R                          (- 32C - 24A)D  + (48B C - 128A B)D
+--R                        + 
+--R                                2         2      3  2       4     3 2
+--R                          (- 48A C + 24A B  + 32A )D  - 8A C  + 8A C
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                   4                  3  4
+--R                      ((- C + 22A)D  + (- B C - 2A B)D )b
+--R                    + 
+--R                              5        4        2             2      2  3
+--R                          - 7D  + 45B D  + (- 6C  + 80A C - 8B  - 25A )D
+--R                        + 
+--R                                        2   2          3     3
+--R                          (- 6A B C + 3A B)D  + (- 2A C  + 2A C)D
+--R                     *
+--R                           3
+--R                        a b
+--R                    + 
+--R                                       4                      3
+--R                          (88C - 118A)D  + (- 52B C + 312A B)D
+--R                        + 
+--R                                  2         2      2          2      3  2
+--R                          (- 60A C  + (- 12B  + 12A )C - 18A B  - 80A )D
+--R                        + 
+--R                                 3          2      2            4     3 2
+--R                          (- 4B C  - 24A B C  + 12A B C)D + 2A C  - 2A C
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                             5        4         2              2       2  3
+--R                          36D  - 52B D  + (- 32C  + 48A C + 44B  + 176A )D
+--R                        + 
+--R                                  2                3      2   2
+--R                          (- 48B C  + 48A B C - 12B  - 96A B)D
+--R                        + 
+--R                               4        3      2 2      3       4         4
+--R                          (- 8C  + 64A C  - 12A C  - 40A C + 12A )D + 4B C
+--R                        + 
+--R                                 3      2   2
+--R                          24A B C  - 12A B C
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                  4                    3
+--R                          - 224A D  + (192B C + 96A B)D
+--R                        + 
+--R                                2         2       2          2     3  2
+--R                          (72A C  + (- 96B  - 192A )C + 96A B  - 8A )D
+--R                        + 
+--R                                3      2           3       5        4      2 3
+--R                          (16B C  + 48A B C + 32A B )D + 8C  - 32A C  + 16A C
+--R                        + 
+--R                                  2      3  2      4      3 2
+--R                          (- 24A B  + 32A )C  - 24A C - 8A B
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                        5        4     2            2     2  3  5
+--R                      (D  - 10B D  + (C  - 20A C + B  + 3A )D )b
+--R                    + 
+--R                                         4                      3
+--R                          (- 53C + 389A)D  + (- 24B C - 134A B)D
+--R                        + 
+--R                                2     2        2      3  2
+--R                          (15A C  + 3B C + 3A B  + 17A )D
+--R                        + 
+--R                              3         2     2
+--R                          (B C  + 6A B C  - 3A B C)D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                                5        4         2                2       2  3
+--R                          - 127D  + 63B D  + (- 48C  - 240A C - 147B  - 534A )D
+--R                        + 
+--R                                2                 3       2   2
+--R                          (60B C  - 144A B C + 11B  + 150A B)D
+--R                        + 
+--R                                4        3       2      2  2         2      3
+--R                              6C  - 72A C  + (12B  + 15A )C  + (12A B  + 82A )C
+--R                            + 
+--R                                  4
+--R                              - 3A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4         3     2   2
+--R                          - B C  - 6A B C  + 3A B C
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (164C + 696A)D  + (- 448B C + 184A B)D
+--R                        + 
+--R                              3         2        2       2           2      3  2
+--R                          (96C  - 138A C  + (132B  + 636A )C - 192A B  - 10A )D
+--R                        + 
+--R                                 3          2      2           3      3        5
+--R                          (- 4B C  - 96A B C  + 60A B C - 32A B  - 24A B)D - 6C
+--R                        + 
+--R                               4         2      2  3          2      3  2     4
+--R                          64A C  + (- 12B  - 16A )C  + (- 6A B  - 80A )C  + 6A C
+--R                        + 
+--R                            3 2
+--R                          2A B
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                               5         4          2               2       2  3
+--R                          - 24D  - 120B D  + (- 116C  - 472A C + 56B  - 196A )D
+--R                        + 
+--R                                  2                3       2   2
+--R                          (- 12B C  + 24A B C - 24B  - 156A B)D
+--R                        + 
+--R                                   4        3         2       2  2
+--R                              - 92C  + 64A C  + (- 12B  - 144A )C
+--R                            + 
+--R                                      2      3        4       2 2      4
+--R                              (- 72A B  - 48A )C - 16B  - 108A B  + 60A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4          3       3      2   2
+--R                          - 20B C  + 80A B C  + (12B  - 48A B)C
+--R                        + 
+--R                                3      3         2 3      4
+--R                          (40A B  + 64A B)C + 12A B  + 20A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        4           3
+--R                          (128C - 128A)D  + 896A B D
+--R                        + 
+--R                                   3         2          2      2          2
+--R                              - 48C  + 288A C  + (- 384B  + 48A )C - 96A B
+--R                            + 
+--R                                    3
+--R                              - 160A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3          2       3       2            3
+--R                              64B C  - 96A B C  + (64B  + 192A B)C + 128A B
+--R                            + 
+--R                                   3
+--R                              - 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4       2      2  3        2 2
+--R                          32C  - 16A C  + (16B  + 64A )C  - 96A B C
+--R                        + 
+--R                              2 2      4          4      3 2      5
+--R                          (48A B  - 96A )C - 32A B  - 32A B  + 16A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                  4                  3  6
+--R                      ((8C - 80A)D  + (8B C + 16A B)D )b
+--R                    + 
+--R                             5         4       2               2       2  3
+--R                          62D  - 158B D  + (47C  - 239A C + 66B  + 218A )D
+--R                        + 
+--R                                  2               3      2   2
+--R                          (- 12B C  + 30A B C - 2B  - 30A B)D
+--R                        + 
+--R                            4        3        2     2  2          2      3
+--R                        (- C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 229C - 559A)D  + (438B C - 584A B)D
+--R                        + 
+--R                                3         2      2       2          2       3  2
+--R                          (- 64C  + 444A C  + (3B  - 213A )C + 93A B  + 175A )D
+--R                        + 
+--R                                   3           2        3       2          3
+--R                              10B C  + 180A B C  + (- 8B  - 144A B)C + 6A B
+--R                            + 
+--R                                3
+--R                              6A B
+--R                         *
+--R                            D
+--R                        + 
+--R                           5        4      2     2  3        2      3  2
+--R                          C  - 13A C  + (3B  + 3A )C  + (3A B  + 17A )C
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               5         4        2                2       2  3
+--R                          - 36D  + 340B D  + (237C  + 638A C - 116B  - 123A )D
+--R                        + 
+--R                                 2                 3       2   2
+--R                          (123B C  - 102A B C + 68B  + 363A B)D
+--R                        + 
+--R                                 4         3      2       2  2
+--R                              95C  - 312A C  + (3B  + 138A )C
+--R                            + 
+--R                                    2       3        4      2 2       4
+--R                              (66A B  + 120A )C + 16B  + 99A B  - 105A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3      3       2   2
+--R                          - 5B C  - 176A B C  + (5B  + 138A B)C
+--R                        + 
+--R                                  3      3        2 3     4
+--R                          (- 10A B  - 16A B)C - 3A B  - 5A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                          4                        3
+--R                          (- 276C + 916A)D  + (- 416B C - 2048A B)D
+--R                        + 
+--R                                    3         2         2       2          2
+--R                                252C  - 636A C  + (1032B  + 516A )C + 72A B
+--R                              + 
+--R                                    3
+--R                                380A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                3           2       2            3      3
+--R                          (40B C  + 216A B C  - 168A B C - 256A B  + 40A B)D
+--R                        + 
+--R                               5        4        2       2  3
+--R                          - 56C  + 80A C  + (- 4B  - 128A )C
+--R                        + 
+--R                                 2      3  2         4       2 2       4
+--R                          (132A B  - 64A )C  + (- 20B  - 156A B  + 184A )C
+--R                        + 
+--R                              4      3 2      5
+--R                          4A B  + 28A B  - 16A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                5         4        2               2        2  3
+--R                          - 144D  + 176B D  + (368C  - 736A C + 64B  - 1040A )D
+--R                        + 
+--R                                 2                  2   2
+--R                          (528B C  + 480A B C + 528A B)D
+--R                        + 
+--R                                    4        3          2      2  2
+--R                              - 128C  - 64A C  + (- 240B  - 96A )C
+--R                            + 
+--R                                       2       3        4       2 2      4
+--R                              (- 288A B  + 128A )C - 48B  - 240A B  + 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4         3      2   2          3      3
+--R                          - 96B C  + (- 16B  - 96A B)C  + (160A B  + 64A B)C
+--R                        + 
+--R                             5       2 3
+--R                          16B  + 112A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (128C + 384A)D  + (- 768B C + 512A B)D
+--R                        + 
+--R                                 3       2          2       3  2
+--R                          (- 192C  + 960A C - 768A B  - 128A )D
+--R                        + 
+--R                                     2       3        3           4      2 3
+--R                          (- 384A B C  + 256B C - 128A B)D + 64A C  + 64B C
+--R                        + 
+--R                                3 2       2 2          4      5
+--R                          - 128A C  + 192A B C - 128A B  + 64A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                           5        4        2             2      2  3  7
+--R                      (- 8D  + 32B D  + (- 8C  + 64A C - 8B  - 24A )D )b
+--R                    + 
+--R                                        4                     3
+--R                          (118C - 412A)D  + (- 2B C + 264A B)D
+--R                        + 
+--R                              3        2        2      2          2      3  2
+--R                          (10C  - 96A C  + (- 6B  + 18A )C - 12A B  - 36A )D
+--R                        + 
+--R                                 3          2      3      2
+--R                          (- 2B C  - 36A B C  + (2B  + 30A B)C)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                              5        4       2                2        2  3
+--R                          287D  - 30B D  + (28C  + 682A C + 308B  + 1180A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 240B C  + 168A B C - 50B  - 414A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 35C  + 170A C  + (- 54B  - 78A )C
+--R                            + 
+--R                                      2       3       4      2 2      4
+--R                              (- 66A B  - 198A )C - 3B  - 18A B  + 21A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4          3        3      2   2
+--R                          2B C  + 36A B C  + (- 2B  - 30A B)C
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                          4                      3
+--R                          (- 81C - 1825A)D  + (528B C + 1756A B)D
+--R                        + 
+--R                                    3        2          2        2           2
+--R                              - 572C  + 60A C  + (- 936B  - 2010A )C + 108A B
+--R                            + 
+--R                                    3
+--R                              - 658A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3           2         3       2
+--R                              - 92B C  + 120A B C  + (- 20B  - 264A B)C
+--R                            + 
+--R                                    3       3
+--R                              160A B  + 100A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5         4       2      2  3         2       3  2
+--R                          29C  - 119A C  + (54B  + 80A )C  + (30A B  + 188A )C
+--R                        + 
+--R                             4      2 2      4        4     3 2     5
+--R                          (5B  + 36A B  - 37A )C + A B  - 4A B  + 3A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          412D  - 132B D
+--R                        + 
+--R                                 2                 2        2  3
+--R                          (- 466C  + 2484A C - 248B  + 2718A )D
+--R                        + 
+--R                                    2                  3       2   2
+--R                          (- 1374B C  - 996A B C - 120B  - 702A B)D
+--R                        + 
+--R                                  4         3       2       2  2
+--R                              366C  + 192A C  + (18B  + 492A )C
+--R                            + 
+--R                                     2       3         4       2 2       4
+--R                              (396A B  - 208A )C + 108B  + 690A B  - 170A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4          3         3       2   2
+--R                          190B C  - 96A B C  + (- 34B  + 204A B)C
+--R                        + 
+--R                                   3       3        5      2 3      4
+--R                          (- 220A B  - 304A B)C - 4B  - 82A B  - 90A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                           4                      3
+--R                          (- 936C - 1176A)D  + (768B C - 1536A B)D
+--R                        + 
+--R                                   3         2        2        2            2
+--R                              - 24C  - 696A C  + (240B  - 3144A )C + 1392A B
+--R                            + 
+--R                                    3
+--R                              - 200A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2          3       2
+--R                              144B C  + 1296A B C  + (- 320B  - 336A B)C
+--R                            + 
+--R                                     3       3
+--R                              - 64A B  + 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5        4      2      2  3          2       3  2
+--R                          - 16C  - 80A C  + (8B  - 32A )C  + (168A B  + 320A )C
+--R                        + 
+--R                                4       2 2       4           4     3 2       5
+--R                          (- 40B  - 552A B  + 176A )C + 168A B  - 8A B  - 112A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               5         4        2                 2       2  3
+--R                          - 96D  + 672B D  + (768C  + 1536A C - 384B  - 192A )D
+--R                        + 
+--R                                 2                   2   2
+--R                          (384B C  + 384A B C + 1344A B)D
+--R                        + 
+--R                                  4          2       2  2       3       4
+--R                              352C  + (- 384B  + 768A )C  + 384A C + 32B
+--R                            + 
+--R                                  2 2       4
+--R                              384A B  - 224A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3 2       3         5
+--R                          32B C  - 256A B C  - 128B C  - 384A B C + 32B
+--R                        + 
+--R                              2 3       4
+--R                          128A B  - 160A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                4                        3
+--R                          384A D  + (- 768B C - 1536A B)D
+--R                        + 
+--R                                    2         2       2           2       3  2
+--R                          (- 1152A C  + (1536B  + 768A )C - 384A B  + 128A )D
+--R                        + 
+--R                                   3       2            3         5         4
+--R                          (- 256B C  - 768A B C - 512A B )D - 128C  + 128A C
+--R                        + 
+--R                                2 3          2       3  2       4        3 2
+--R                          - 256A C  + (384A B  - 128A )C  + 384A C + 128A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                     4                     3  8
+--R                      ((- 16C + 96A)D  + (- 16B C - 32A B)D )b
+--R                    + 
+--R                                5         4
+--R                          - 136D  + 168B D
+--R                        + 
+--R                                2                2       2  3
+--R                          (- 92C  + 188A C - 136B  - 472A )D
+--R                        + 
+--R                                2               3      2   2
+--R                          (48B C  - 24A B C + 8B  + 72A B)D
+--R                        + 
+--R                             4        3       2      2  2         2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                        4                       3
+--R                          (12C + 1996A)D  + (- 864B C - 640A B)D
+--R                        + 
+--R                               3         2        2       2          2      3  2
+--R                          (296C  - 720A C  + (252B  + 732A )C - 36A B  + 84A )D
+--R                        + 
+--R                                   3           2       3       2           3
+--R                              48B C  - 288A B C  + (40B  + 408A B)C - 24A B
+--R                            + 
+--R                                   3
+--R                              - 24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4         2      2  3           2      3  2
+--R                        - 4C  + 20A C  + (- 12B  - 12A )C  + (- 12A B  - 36A )C
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 636D  - 544B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (104C  - 3740A C - 120B  - 3228A )D
+--R                        + 
+--R                                  2                 3       2   2
+--R                          (1380B C  + 912A B C + 96B  + 804A B)D
+--R                        + 
+--R                                    4         3        2       2  2
+--R                              - 188C  + 300A C  + (192B  - 156A )C
+--R                            + 
+--R                                       2       3        4       2 2       4
+--R                              (- 108A B  + 340A )C - 76B  - 468A B  + 216A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3         3       2   2
+--R                          - 68B C  + 272A B C  + (- 28B  - 384A B)C
+--R                        + 
+--R                                3      3         2 3      4
+--R                          (40A B  + 64A B)C + 12A B  + 20A B
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          4                      3
+--R                          (1528C + 1376A)D  + (520B C + 1200A B)D
+--R                        + 
+--R                                  3          2          2        2            2
+--R                              544C  + 1968A C  + (- 132B  + 4740A )C - 1068A B
+--R                            + 
+--R                                   3
+--R                              1012A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2       3       2           3
+--R                              - 360B C  - 1584A B C  + (16B  + 480A B)C + 56A B
+--R                            + 
+--R                                    3
+--R                              - 600A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            5        4          2      2  3
+--R                          8C  + 64A C  + (- 188B  + 28A )C
+--R                        + 
+--R                                   2       3  2        4       2 2       4
+--R                          (- 252A B  - 412A )C  + (100B  + 768A B  - 308A )C
+--R                        + 
+--R                                 4      3 2      5
+--R                          - 12A B  + 64A B  + 76A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          304D  - 944B D
+--R                        + 
+--R                                 2                  2       2  3
+--R                          (- 708C  - 3096A C + 1072B  + 268A )D
+--R                        + 
+--R                                 2                  3        2   2
+--R                          (132B C  - 360A B C + 208B  - 2028A B)D
+--R                        + 
+--R                                    4         3        2        2  2
+--R                              - 636C  - 448A C  + (996B  - 1512A )C
+--R                            + 
+--R                                    2       3        4       2 2       4
+--R                              (24A B  - 576A )C - 80B  - 924A B  + 356A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3        3      2   2
+--R                          - 108B C  + 256A B C  + (252B  + 24A B)C
+--R                        + 
+--R                                   3       3         5       2 3       4
+--R                          (- 120A B  + 768A B)C - 80B  - 356A B  + 340A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                          4                       3
+--R                          (- 48C - 1776A)D  + (1728B C + 3456A B)D
+--R                        + 
+--R                                 3          2           2        2         3  2
+--R                          (- 816C  + 2928A C  + (- 3168B  - 1680A )C - 432A )D
+--R                        + 
+--R                                      3          2          3      2
+--R                              - 224B C  - 96A B C  + (- 256B  + 96A B)C
+--R                            + 
+--R                                    3      3
+--R                              768A B  - 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4         2       2  3
+--R                          160C  - 160A C  + (- 48B  + 384A )C
+--R                        + 
+--R                                   2       3  2       4       2 2       4
+--R                          (- 336A B  + 160A )C  + (80B  + 432A B  - 544A )C
+--R                        + 
+--R                                4      3 2
+--R                          112A B  - 48A B
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4          2                 2        2  3
+--R                          384B D  + (- 960C  + 2688A C - 960B  + 1344A )D
+--R                        + 
+--R                                    2                   3       2   2
+--R                          (- 1344B C  - 2688A B C + 192B  - 576A B)D
+--R                        + 
+--R                                  4         3        2       2  2
+--R                              640C  - 768A C  + (960B  + 576A )C
+--R                            + 
+--R                                      2       3         4       2 2       4
+--R                              (1152A B  + 128A )C + 192B  + 960A B  - 320A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3       3       2   2
+--R                          320B C  - 384A B C  + (64B  + 576A B)C
+--R                        + 
+--R                                   3       3         5       2 3
+--R                          (- 640A B  - 256A B)C - 64B  - 448A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                     3
+--R                          - 1536A B D
+--R                        + 
+--R                                  3          2         2       2            2
+--R                              768C  - 1152A C  + (1536B  - 768A )C + 1536A B
+--R                            + 
+--R                                  3
+--R                              128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2           3       2
+--R                              - 256B C  + 1536A B C  + (- 1024B  - 768A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 512A B  + 512A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4          2       2  3         2 2
+--R                          - 128C  + 256A C  + (- 256B  - 256A )C  + 384A B C
+--R                        + 
+--R                                 2 2       4           4       3 2       5
+--R                          (- 768A B  + 384A )C + 512A B  + 128A B  - 256A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                      5        4       2              2      2  3  9
+--R                  (16D  - 32B D  + (16C  - 64A C + 16B  + 48A )D )b
+--R                + 
+--R                                    4                    3
+--R                      (- 8C - 224A)D  + (136B C + 64A B)D
+--R                    + 
+--R                            3         2         2      2    2
+--R                      (- 40C  + 144A C  + (- 24B  - 72A )C)D
+--R                    + 
+--R                             3          2        3      2
+--R                      (- 8B C  + 48A B C  + (- 8B  - 72A B)C)D
+--R                 *
+--R                       8
+--R                    a b
+--R                + 
+--R                          5        4       2               2       2  3
+--R                      148D  - 88B D  + (64C  + 104A C + 64B  + 592A )D
+--R                    + 
+--R                               2                3      2   2
+--R                      (- 192B C  - 192A B C - 8B  - 72A B)D
+--R                    + 
+--R                             4        3         2      2  2         2      3
+--R                          28C  - 88A C  + (- 24B  + 24A )C  + (24A B  - 24A )C
+--R                        + 
+--R                             4      2 2      4
+--R                          12B  + 72A B  - 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                          4          3      3      2   2
+--R                      8B C  - 48A B C  + (8B  + 72A B)C
+--R                 *
+--R                     2 7
+--R                    a b
+--R                + 
+--R                                       4                     3
+--R                      (- 212C - 1532A)D  + (664B C + 112A B)D
+--R                    + 
+--R                             3         2       2       2           2      3  2
+--R                      (- 232C  + 528A C  + (24B  - 864A )C + 144A B  - 88A )D
+--R                    + 
+--R                                 3           2         3       2           3
+--R                            40B C  + 528A B C  + (- 40B  - 456A B)C - 32A B
+--R                          + 
+--R                               3
+--R                            80A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          5        4       2      2  3         2      3  2
+--R                      - 4C  + 12A C  + (24B  - 16A )C  + (24A B  + 32A )C
+--R                    + 
+--R                            4       2 2      4         4      3 2      5
+--R                      (- 20B  - 144A B  + 52A )C - 4A B  - 16A B  - 12A
+--R                 *
+--R                     3 6
+--R                    a b
+--R                + 
+--R                          5          4          2                 2        2  3
+--R                      124D  + 1208B D  + (- 248C  + 4328A C - 416B  + 1336A )D
+--R                    + 
+--R                                2                  3       2   2
+--R                      (- 1176B C  - 912A B C - 104B  - 240A B)D
+--R                    + 
+--R                              4         3          2       2  2
+--R                          188C  - 424A C  + (- 384B  + 264A )C
+--R                        + 
+--R                                2       3        4       2 2       4
+--R                          (24A B  - 136A )C + 68B  + 480A B  - 244A
+--R                     *
+--R                        D
+--R                    + 
+--R                           4           3       3       2   2         3      3
+--R                      32B C  - 304A B C  + (16B  + 408A B)C  + (80A B  - 64A B)C
+--R                    + 
+--R                         5      2 3      4
+--R                      16B  + 88A B  - 40A B
+--R                 *
+--R                     4 5
+--R                    a b
+--R                + 
+--R                                        4                         3
+--R                      (- 1028C + 2044A)D  + (- 3104B C - 2864A B)D
+--R                    + 
+--R                                3          2         2        2           2
+--R                            560C  - 4512A C  + (1536B  - 1848A )C + 816A B
+--R                          + 
+--R                                  3
+--R                            - 616A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3           2        3       2            3
+--R                          736B C  + 768A B C  + (304B  + 912A B)C - 224A B
+--R                        + 
+--R                              3
+--R                          496A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5        4        2       2  3          2       3  2
+--R                      - 28C  + 52A C  + (200B  - 112A )C  + (168A B  + 224A )C
+--R                    + 
+--R                             4       2 2       4          4       3 2      5
+--R                      (- 140B  - 912A B  + 364A )C - 92A B  - 112A B  - 52A
+--R                 *
+--R                     5 4
+--R                    a b
+--R                + 
+--R                            5          4         2                 2        2  3
+--R                      - 288D  - 1088B D  + (1896C  - 4752A C + 720B  - 2552A )D
+--R                    + 
+--R                              2                   3        2   2
+--R                      (2712B C  + 4560A B C - 272B  + 2424A B)D
+--R                    + 
+--R                                4          3           2       2  2
+--R                          - 280C  + 2048A C  + (- 1320B  + 480A )C
+--R                        + 
+--R                                    2       3         4       2 2       4
+--R                          (- 1200A B  + 416A )C - 208B  - 744A B  + 344A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4           3          3        2   2
+--R                      - 232B C  + 608A B C  + (- 344B  - 1248A B)C
+--R                    + 
+--R                             3       3          5       2 3       4
+--R                      (560A B  - 448A B)C + 112B  + 616A B  - 280A B
+--R                 *
+--R                     6 3
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (1248C - 288A)D  + (2304B C + 2688A B)D
+--R                    + 
+--R                                 3          2           2        2            2
+--R                          - 1056C  + 3840A C  + (- 1536B  + 3552A )C - 2496A B
+--R                        + 
+--R                              3
+--R                          704A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  3            2        3       2            3
+--R                          - 768B C  - 2880A B C  + (768B  - 384A B)C + 256A B
+--R                        + 
+--R                                 3
+--R                          - 1088A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         5         4       2       2  3            2       3  2
+--R                      32C  - 320A C  + (32B  + 128A )C  + (- 192A B  - 256A )C
+--R                    + 
+--R                           4        2 2       4           4       3 2       5
+--R                      (160B  + 1824A B  - 416A )C - 416A B  + 128A B  + 320A
+--R                 *
+--R                     7 2
+--R                    a b
+--R                + 
+--R                              2                2       2  3
+--R                      (- 1728C  + 384A C - 384B  + 576A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 1344B C  - 3456A B C + 384B  - 2112A B)D
+--R                    + 
+--R                             4          3         2       2  2
+--R                          64C  - 1536A C  + (1728B  - 768A )C
+--R                        + 
+--R                                  2       3         4       2 2      4
+--R                          (1152A B  - 256A )C + 128B  + 192A B  - 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                            4           3        3       2   2
+--R                      192B C  - 256A B C  + (320B  + 768A B)C
+--R                    + 
+--R                               3       3          5       2 3       4
+--R                      (- 640A B  + 512A B)C - 128B  - 704A B  + 320A B
+--R                 *
+--R                     8
+--R                    a b
+--R                + 
+--R                           3       2           2  2
+--R                      (768C  - 768A C + 1536A B )D
+--R                    + 
+--R                                2        3        3            4       2 3
+--R                      (1536A B C  - 1024B C + 512A B)D + 256A C  - 256B C
+--R                    + 
+--R                            2 2          4       5
+--R                      - 768A B C + 512A B  - 256A
+--R                 *
+--R                     9
+--R                    a
+--R             *
+--R                %%BN1
+--R            + 
+--R                       2 3 8
+--R                  32A D a c
+--R                + 
+--R                             2 2 2         3        2  3
+--R                      - 16A D a b  + (- 16D  - 16B D )a b
+--R                    + 
+--R                             2                   2      3  4
+--R                      (128A D  - 128A B D - 32A C  + 32A )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                          2   4      3       2  2 3
+--R                      2A D a b  + (8D  + 8B D )a b
+--R                    + 
+--R                                    2                  2      3  3 2
+--R                      ((32C - 448A)D  + 64A B D + 16A C  - 16A )a b
+--R                    + 
+--R                               3        2         2               2       2
+--R                          - 32D  + 32B D  + (- 48C  + 224A C + 64B  + 144A )D
+--R                        + 
+--R                               2                2
+--R                          16B C  + 96A B C - 48A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                  2                 3         2      2
+--R                          - 128A D  - 512A B D + 64C  - 128A C  - 64A C
+--R                        + 
+--R                                2       3
+--R                          128A B  + 128A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                          3      2    5
+--R                      (- D  - B D )a b
+--R                    + 
+--R                                      2                2     3  2 4
+--R                      ((- 16C + 192A)D  - 8A B D - 2A C  + 2A )a b
+--R                    + 
+--R                              3         2       2               2      2
+--R                          160D  + 128B D  + (24C  - 112A C - 32B  - 72A )D
+--R                        + 
+--R                                2                2
+--R                          - 8B C  - 48A B C + 24A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                       2                             3         2
+--R                          (80C - 560A)D  + (- 96B C + 1312A B)D - 48C  + 304A C
+--R                        + 
+--R                                2      2           2       3
+--R                          (- 48B  - 16A )C - 112A B  - 368A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                              3         2          2               2       2
+--R                          128D  + 256B D  + (- 384C  + 512A C + 64B  + 384A )D
+--R                        + 
+--R                                  2      3       2
+--R                          - 128B C  - 64B  - 384A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                   2                  3         2       2
+--R                          - 1024A D  + 512A B D + 256C  + 128A C  - 256A C
+--R                        + 
+--R                                2       3
+--R                          512A B  - 128A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                                 2   6
+--R                      (2C - 22A)D a b
+--R                    + 
+--R                               3        2        2             2     2        2
+--R                          - 70D  - 66B D  + (- 3C  + 14A C + 4B  + 9A )D + B C
+--R                        + 
+--R                                     2
+--R                          6A B C - 3A B
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                           2                          3
+--R                          (- 328C + 1896A)D  + (48B C - 528A B)D + 12C
+--R                        + 
+--R                                  2       2      2          2       3
+--R                          - 120A C  + (24B  + 20A )C + 32A B  + 152A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                3         2
+--R                          - 224D  - 800B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (720C  - 2080A C - 512B  - 1392A )D + 16B C
+--R                        + 
+--R                                          3       2
+--R                          - 672A B C + 64B  + 720A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         2                             3
+--R                          (160C + 2976A)D  + (576B C + 1088A B)D - 608C
+--R                        + 
+--R                                2        2       2            2      3
+--R                          416A C  + (288B  + 992A )C - 1120A B  - 32A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              3         2          2                 2       2
+--R                          256D  - 256B D  + (- 192C  - 1664A C - 640B  - 960A )D
+--R                        + 
+--R                                  2                   3       2
+--R                          - 448B C  - 1152A B C - 128B  - 192A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                  2                   3          2       2
+--R                          - 512A D  + 4096A B D - 256C  + 1024A C  + 256A C
+--R                        + 
+--R                                  2        3
+--R                          - 512A B  - 1024A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                         3       2    7
+--R                      (8D  + 8B D )a b
+--R                    + 
+--R                                        2                        3        2
+--R                          (141C - 755A)D  + (- 6B C + 58A B)D - C  + 13A C
+--R                        + 
+--R                               2     2         2      3
+--R                          (- 3B  - 3A )C - 3A B  - 17A
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                3        2          2                2       2
+--R                          - 284D  - 36B D  + (- 276C  + 888A C + 228B  + 588A )D
+--R                        + 
+--R                               2                 3       2
+--R                          12B C  + 312A B C - 20B  - 276A B
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                          2                             3
+--R                          (- 32C - 2016A)D  + (192B C - 3072A B)D + 320C
+--R                        + 
+--R                                  2       2       2           2       3
+--R                          - 720A C  + (96B  - 192A )C + 672A B  + 848A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                3         2
+--R                          - 896D  - 384B D
+--R                        + 
+--R                                2                 2       2            2
+--R                          (1344C  + 1408A C + 896B  + 576A )D + 1088B C
+--R                        + 
+--R                                          3        2
+--R                          1920A B C + 384B  + 1344A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                           2                             3
+--R                          (- 640C + 4224A)D  + (768B C - 8448A B)D - 128C
+--R                        + 
+--R                                   2        2       2           2        3
+--R                          - 1920A C  + (384B  + 640A )C - 128A B  + 2432A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 256D  - 1280B D
+--R                        + 
+--R                                2                 2        2            2
+--R                          (3072C  - 4096A C - 512B  - 3072A )D + 1024B C
+--R                        + 
+--R                              3        2
+--R                          512B  + 3072A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                 2                    3         2        2
+--R                          2048A D  + 2048A B D - 2048C  + 512A C  + 2048A C
+--R                        + 
+--R                                   2       3
+--R                          - 4096A B  - 512A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                                    2   8
+--R                      (- 16C + 80A)D a b
+--R                    + 
+--R                              3         2       2               2      2
+--R                          146D  + 118B D  + (30C  - 100A C - 26B  - 66A )D
+--R                        + 
+--R                                2               3      2
+--R                          - 2B C  - 36A B C + 2B  + 30A B
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                         2                              3
+--R                          (726C - 2090A)D  + (- 180B C + 1100A B)D - 62C
+--R                        + 
+--R                                2         2      2           2       3
+--R                          230A C  + (- 90B  - 58A )C - 154A B  - 350A
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1752D  + 2760B D
+--R                        + 
+--R                                  2                 2        2           2
+--R                          (- 2160C  + 3840A C + 696B  + 2736A )D - 528B C
+--R                        + 
+--R                                         3        2
+--R                          576A B C - 312B  - 2160A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                   2                                3         2
+--R                          - 8160A D  + (- 4608B C + 5376A B)D + 864C  + 192A C
+--R                        + 
+--R                                  2        2           2        3
+--R                          (- 2304B  - 3936A )C + 960A B  - 3264A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1152D  + 4224B D
+--R                        + 
+--R                                  2                   2        2            2
+--R                          (- 5760C  + 11520A C + 2304B  + 8064A )D - 1152B C
+--R                        + 
+--R                                          3        2
+--R                          2304A B C - 768B  - 5760A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 2816C - 4352A)D  + (- 4608B C - 7680A B)D + 3840C
+--R                        + 
+--R                                   2           2        2            2
+--R                          - 3072A C  + (- 2304B  - 6912A )C + 6912A B
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                3         2
+--R                          - 512D  + 512B D
+--R                        + 
+--R                                2                  2       2            2
+--R                          (3840C  + 2560A C + 2048B  + 768A )D + 2816B C
+--R                        + 
+--R                                           3        2
+--R                          4608A B C + 1024B  + 3840A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                 2                    3          2        2
+--R                          2048A D  - 8192A B D - 1024C  - 2048A C  + 1024A C
+--R                        + 
+--R                                   2        3
+--R                          - 2048A B  + 2048A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                            3        2    9
+--R                      (- 16D  - 16B D )a b
+--R                    + 
+--R                                          2                         3        2
+--R                          (- 308C + 972A)D  + (24B C - 104A B)D + 4C  - 20A C
+--R                        + 
+--R                              2      2          2      3
+--R                          (12B  + 12A )C + 12A B  + 36A
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                                3         2
+--R                          - 456D  - 920B D
+--R                        + 
+--R                               2                 2        2           2
+--R                          (744C  - 1712A C - 376B  - 1176A )D + 104B C
+--R                        + 
+--R                                          3       2
+--R                          - 432A B C + 88B  + 744A B
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                            2                             3
+--R                          (- 1668C + 8316A)D  + (1656B C - 136A B)D - 364C
+--R                        + 
+--R                                2        2        2           2       3
+--R                          380A C  + (828B  + 1468A )C - 452A B  + 724A
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 2496D  - 6432B D
+--R                        + 
+--R                                2                   2        2           2
+--R                          (5328C  - 14304A C - 3408B  - 9648A )D + 336B C
+--R                        + 
+--R                                            3        2
+--R                          - 4320A B C + 528B  + 5328A B
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                          2                                3
+--R                          (6528C + 3456A)D  + (11520B C + 7296A B)D - 3072C
+--R                        + 
+--R                                 2         2         2            2        3
+--R                          4704A C  + (5760B  + 10752A )C - 4224A B  + 2976A
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                               3         2
+--R                          1024D  - 512B D
+--R                        + 
+--R                                  2                  2        2            2
+--R                          (- 5760C  - 3840A C - 3072B  - 1152A )D - 4224B C
+--R                        + 
+--R                                             3        2
+--R                          - 6912A B C - 1536B  - 5760A B
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                          2                                  3
+--R                          (1280C - 6912A)D  + (- 1536B C + 12800A B)D + 1280C
+--R                        + 
+--R                                 2          2        2            2        3
+--R                          2816A C  + (- 768B  - 2304A )C + 2304A B  - 3840A
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                 2           2                  2        2
+--R                          2048B D  + (- 6144C  + 8192A C + 1024B  + 6144A )D
+--R                        + 
+--R                                   2        3        2
+--R                          - 2048B C  - 1024B  - 6144A B
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                             3          2        2           2
+--R                          - 8192A B D + 4096C  - 2048A C  - 4096A C + 8192A B
+--R                        + 
+--R                               3
+--R                          2048A
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                              2   10
+--R                  (32C - 96A)D a b
+--R                + 
+--R                         3        2         2               2       2         2
+--R                      24D  + 72B D  + (- 72C  + 176A C + 40B  + 120A )D - 8B C
+--R                    + 
+--R                                  3      2
+--R                      48A B C - 8B  - 72A B
+--R                 *
+--R                     2 9
+--R                    a b
+--R                + 
+--R                                     2                             3        2
+--R                      (376C - 1416A)D  + (- 144B C - 144A B)D + 40C  - 72A C
+--R                    + 
+--R                            2       2          2      3
+--R                      (- 72B  - 136A )C + 56A B  - 24A
+--R                 *
+--R                     3 8
+--R                    a b
+--R                + 
+--R                          3          2          2                 2        2
+--R                      360D  + 1080B D  + (- 936C  + 2608A C + 632B  + 1752A )D
+--R                    + 
+--R                             2                 3       2
+--R                      - 40B C  + 816A B C - 88B  - 936A B
+--R                 *
+--R                     4 7
+--R                    a b
+--R                + 
+--R                                      2                                3
+--R                      (- 24C - 4248A)D  + (- 2160B C - 2160A B)D + 536C
+--R                    + 
+--R                               2           2        2           2       3
+--R                      - 1080A C  + (- 1080B  - 1976A )C + 712A B  - 360A
+--R                 *
+--R                     5 6
+--R                    a b
+--R                + 
+--R                           3          2
+--R                      1152D  + 3456B D
+--R                    + 
+--R                              2                  2        2           2
+--R                      (- 1296C  + 7968A C + 2400B  + 5040A )D + 816B C
+--R                    + 
+--R                                     3        2
+--R                      3744A B C + 96B  - 1296A B
+--R                 *
+--R                     6 5
+--R                    a b
+--R                + 
+--R                                        2                                3
+--R                      (- 7040C + 7296A)D  + (- 6912B C - 6912A B)D + 960C
+--R                    + 
+--R                               2           2        2           2        3
+--R                      - 3456A C  + (- 3456B  - 5568A )C + 768A B  - 1152A
+--R                 *
+--R                     7 4
+--R                    a b
+--R                + 
+--R                             3          2
+--R                      - 1536D  - 4608B D
+--R                    + 
+--R                             2                   2        2            2
+--R                      (11520C  - 12800A C - 1024B  - 9984A )D + 4352B C
+--R                    + 
+--R                                       3         2
+--R                      1536A B C + 2048B  + 11520A B
+--R                 *
+--R                     8 3
+--R                    a b
+--R                + 
+--R                                      2                               3
+--R                      (6656C - 1536A)D  + (9216B C + 9216A B)D - 5632C
+--R                    + 
+--R                             2         2         2            2        3
+--R                      4608A C  + (4608B  + 11776A )C - 9728A B  + 1536A
+--R                 *
+--R                     9 2
+--R                    a b
+--R                + 
+--R                              2                  2        2            2
+--R                      (- 9216C  + 2048A C - 2048B  + 3072A )D - 5120B C
+--R                    + 
+--R                                         3        2
+--R                      - 6144A B C - 2048B  - 9216A B
+--R                 *
+--R                     10
+--R                    a  b
+--R                + 
+--R                        3        2           2  11
+--R                  (4096C  - 4096A C + 8192A B )a
+--R             *
+--R                     3
+--R                %%BN0
+--R            + 
+--R                         3 2 8
+--R                  - 32A D a c
+--R                + 
+--R                           3   2       4        3  2
+--R                      16A D a b  + (16D  + 16B D )a b
+--R                    + 
+--R                               3           2         2      3    3
+--R                      (- 128A D  + 128A B D  + (32A C  - 32A )D)a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                            3 4        4       3    3
+--R                      - 2A D b  + (- 8D  - 8B D )a b
+--R                    + 
+--R                                      3          2           2      3    2 2
+--R                      ((- 32C + 448A)D  - 64A B D  + (- 16A C  + 16A )D)a b
+--R                    + 
+--R                             4        3       2               2       2  2
+--R                          32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                        + 
+--R                                  2                2
+--R                          (- 16B C  - 96A B C + 48A B)D
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                3           2
+--R                          128A D  + 512A B D
+--R                        + 
+--R                                3         2      2          2       3
+--R                          (- 64C  + 128A C  + 64A C - 128A B  - 128A )D
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                        4      3  5
+--R                      (D  + B D )b
+--R                    + 
+--R                                    3         2        2     3      4
+--R                      ((16C - 192A)D  + 8A B D  + (2A C  - 2A )D)a b
+--R                    + 
+--R                                4         3         2               2      2  2
+--R                          - 160D  - 128B D  + (- 24C  + 112A C + 32B  + 72A )D
+--R                        + 
+--R                               2                2
+--R                          (8B C  + 48A B C - 24A B)D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                         3                     2
+--R                          (- 80C + 560A)D  + (96B C - 1312A B)D
+--R                        + 
+--R                              3         2       2      2           2       3
+--R                          (48C  - 304A C  + (48B  + 16A )C + 112A B  + 368A )D
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                                4         3        2               2       2  2
+--R                          - 128D  - 256B D  + (384C  - 512A C - 64B  - 384A )D
+--R                        + 
+--R                                 2      3       2
+--R                          (128B C  + 64B  + 384A B)D
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                 3           2
+--R                          1024A D  - 512A B D
+--R                        + 
+--R                                 3         2       2          2       3
+--R                          (- 256C  - 128A C  + 256A C - 512A B  + 128A )D
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                                   3 6
+--R                      (- 2C + 22A)D b
+--R                    + 
+--R                             4        3      2             2     2  2
+--R                          70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D
+--R                        + 
+--R                                2              2
+--R                          (- B C  - 6A B C + 3A B)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                         3                      2
+--R                          (328C - 1896A)D  + (- 48B C + 528A B)D
+--R                        + 
+--R                              3         2         2      2          2       3
+--R                        (- 12C  + 120A C  + (- 24B  - 20A )C - 32A B  - 152A )D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          224D  + 800B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 720C  + 2080A C + 512B  + 1392A )D
+--R                        + 
+--R                                  2                 3       2
+--R                          (- 16B C  + 672A B C - 64B  - 720A B)D
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                           3                        2
+--R                          (- 160C - 2976A)D  + (- 576B C - 1088A B)D
+--R                        + 
+--R                                  3         2          2       2            2
+--R                              608C  - 416A C  + (- 288B  - 992A )C + 1120A B
+--R                            + 
+--R                                 3
+--R                              32A
+--R                         *
+--R                            D
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                4         3
+--R                          - 256D  + 256B D
+--R                        + 
+--R                               2                 2       2  2
+--R                          (192C  + 1664A C + 640B  + 960A )D
+--R                        + 
+--R                                 2                   3       2
+--R                          (448B C  + 1152A B C + 128B  + 192A B)D
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                3            2
+--R                          512A D  - 4096A B D
+--R                        + 
+--R                               3          2       2          2        3
+--R                          (256C  - 1024A C  - 256A C + 512A B  + 1024A )D
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                           4       3  7
+--R                      (- 8D  - 8B D )b
+--R                    + 
+--R                                          3                  2
+--R                          (- 141C + 755A)D  + (6B C - 58A B)D
+--R                        + 
+--R                            3        2      2     2         2      3
+--R                          (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                              4        3        2                2       2  2
+--R                          284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                        + 
+--R                                  2                 3       2
+--R                          (- 12B C  - 312A B C + 20B  + 276A B)D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                        3                        2
+--R                          (32C + 2016A)D  + (- 192B C + 3072A B)D
+--R                        + 
+--R                                    3         2         2       2           2
+--R                              - 320C  + 720A C  + (- 96B  + 192A )C - 672A B
+--R                            + 
+--R                                    3
+--R                              - 848A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          896D  + 384B D
+--R                        + 
+--R                                  2                 2       2  2
+--R                          (- 1344C  - 1408A C - 896B  - 576A )D
+--R                        + 
+--R                                    2                   3        2
+--R                          (- 1088B C  - 1920A B C - 384B  - 1344A B)D
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                         3                        2
+--R                          (640C - 4224A)D  + (- 768B C + 8448A B)D
+--R                        + 
+--R                                  3          2          2       2           2
+--R                              128C  + 1920A C  + (- 384B  - 640A )C + 128A B
+--R                            + 
+--R                                     3
+--R                              - 2432A
+--R                         *
+--R                            D
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          256D  + 1280B D
+--R                        + 
+--R                                  2                 2        2  2
+--R                          (- 3072C  + 4096A C + 512B  + 3072A )D
+--R                        + 
+--R                                    2       3        2
+--R                          (- 1024B C  - 512B  - 3072A B)D
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                   3            2
+--R                          - 2048A D  - 2048A B D
+--R                        + 
+--R                                3         2        2           2       3
+--R                          (2048C  - 512A C  - 2048A C + 4096A B  + 512A )D
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                                  3 8
+--R                      (16C - 80A)D b
+--R                    + 
+--R                                4         3         2               2      2  2
+--R                          - 146D  - 118B D  + (- 30C  + 100A C + 26B  + 66A )D
+--R                        + 
+--R                               2               3      2
+--R                          (2B C  + 36A B C - 2B  - 30A B)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                           3                      2
+--R                          (- 726C + 2090A)D  + (180B C - 1100A B)D
+--R                        + 
+--R                              3         2       2      2           2       3
+--R                          (62C  - 230A C  + (90B  + 58A )C + 154A B  + 350A )D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1752D  - 2760B D
+--R                        + 
+--R                                2                 2        2  2
+--R                          (2160C  - 3840A C - 696B  - 2736A )D
+--R                        + 
+--R                                 2                  3        2
+--R                          (528B C  - 576A B C + 312B  + 2160A B)D
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                 3                       2
+--R                          8160A D  + (4608B C - 5376A B)D
+--R                        + 
+--R                                    3         2         2        2           2
+--R                              - 864C  - 192A C  + (2304B  + 3936A )C - 960A B
+--R                            + 
+--R                                   3
+--R                              3264A
+--R                         *
+--R                            D
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1152D  - 4224B D
+--R                        + 
+--R                                2                   2        2  2
+--R                          (5760C  - 11520A C - 2304B  - 8064A )D
+--R                        + 
+--R                                  2                   3        2
+--R                          (1152B C  - 2304A B C + 768B  + 5760A B)D
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (2816C + 4352A)D  + (4608B C + 7680A B)D
+--R                        + 
+--R                                3          2         2        2            2
+--R                        (- 3840C  + 3072A C  + (2304B  + 6912A )C - 6912A B )D
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          512D  - 512B D
+--R                        + 
+--R                                  2                  2       2  2
+--R                          (- 3840C  - 2560A C - 2048B  - 768A )D
+--R                        + 
+--R                                    2                    3        2
+--R                          (- 2816B C  - 4608A B C - 1024B  - 3840A B)D
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                   3            2
+--R                          - 2048A D  + 8192A B D
+--R                        + 
+--R                                3          2        2           2        3
+--R                          (1024C  + 2048A C  - 1024A C + 2048A B  - 2048A )D
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                          4        3  9
+--R                      (16D  + 16B D )b
+--R                    + 
+--R                                        3                      2
+--R                          (308C - 972A)D  + (- 24B C + 104A B)D
+--R                        + 
+--R                               3        2         2      2          2      3
+--R                          (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                     *
+--R                           8
+--R                        a b
+--R                    + 
+--R                              4         3
+--R                          456D  + 920B D
+--R                        + 
+--R                                 2                 2        2  2
+--R                          (- 744C  + 1712A C + 376B  + 1176A )D
+--R                        + 
+--R                                   2                 3       2
+--R                          (- 104B C  + 432A B C - 88B  - 744A B)D
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          3                        2
+--R                          (1668C - 8316A)D  + (- 1656B C + 136A B)D
+--R                        + 
+--R                                  3         2          2        2           2
+--R                              364C  - 380A C  + (- 828B  - 1468A )C + 452A B
+--R                            + 
+--R                                    3
+--R                              - 724A
+--R                         *
+--R                            D
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                               4          3
+--R                          2496D  + 6432B D
+--R                        + 
+--R                                  2                   2        2  2
+--R                          (- 5328C  + 14304A C + 3408B  + 9648A )D
+--R                        + 
+--R                                   2                   3        2
+--R                          (- 336B C  + 4320A B C - 528B  - 5328A B)D
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                            3                          2
+--R                          (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                        + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                            D
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                                 4         3
+--R                          - 1024D  + 512B D
+--R                        + 
+--R                                2                  2        2  2
+--R                          (5760C  + 3840A C + 3072B  + 1152A )D
+--R                        + 
+--R                                  2                    3        2
+--R                          (4224B C  + 6912A B C + 1536B  + 5760A B)D
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                            3                        2
+--R                          (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                        + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                            D
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                   3         2                  2        2  2
+--R                          - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                        + 
+--R                                  2        3        2
+--R                          (2048B C  + 1024B  + 6144A B)D
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                   2
+--R                          8192A B D
+--R                        + 
+--R                                  3          2        2           2        3
+--R                          (- 4096C  + 2048A C  + 4096A C - 8192A B  - 2048A )D
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                                3 10
+--R                  (- 32C + 96A)D b
+--R                + 
+--R                           4        3       2               2       2  2
+--R                      - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                    + 
+--R                           2               3      2
+--R                      (8B C  - 48A B C + 8B  + 72A B)D
+--R                 *
+--R                       9
+--R                    a b
+--R                + 
+--R                                       3                     2
+--R                      (- 376C + 1416A)D  + (144B C + 144A B)D
+--R                    + 
+--R                            3        2       2       2          2      3
+--R                      (- 40C  + 72A C  + (72B  + 136A )C - 56A B  + 24A )D
+--R                 *
+--R                     2 8
+--R                    a b
+--R                + 
+--R                            4          3        2                 2        2  2
+--R                      - 360D  - 1080B D  + (936C  - 2608A C - 632B  - 1752A )D
+--R                    + 
+--R                            2                 3       2
+--R                      (40B C  - 816A B C + 88B  + 936A B)D
+--R                 *
+--R                     3 7
+--R                    a b
+--R                + 
+--R                                    3                       2
+--R                      (24C + 4248A)D  + (2160B C + 2160A B)D
+--R                    + 
+--R                           3          2         2        2           2       3
+--R                    (- 536C  + 1080A C  + (1080B  + 1976A )C - 712A B  + 360A )D
+--R                 *
+--R                     4 6
+--R                    a b
+--R                + 
+--R                             4          3
+--R                      - 1152D  - 3456B D
+--R                    + 
+--R                            2                  2        2  2
+--R                      (1296C  - 7968A C - 2400B  - 5040A )D
+--R                    + 
+--R                               2                  3        2
+--R                      (- 816B C  - 3744A B C - 96B  + 1296A B)D
+--R                 *
+--R                     5 5
+--R                    a b
+--R                + 
+--R                                      3                       2
+--R                      (7040C - 7296A)D  + (6912B C + 6912A B)D
+--R                    + 
+--R                                3          2         2        2           2
+--R                          - 960C  + 3456A C  + (3456B  + 5568A )C - 768A B
+--R                        + 
+--R                               3
+--R                          1152A
+--R                     *
+--R                        D
+--R                 *
+--R                     6 4
+--R                    a b
+--R                + 
+--R                           4          3
+--R                      1536D  + 4608B D
+--R                    + 
+--R                               2                   2        2  2
+--R                      (- 11520C  + 12800A C + 1024B  + 9984A )D
+--R                    + 
+--R                                2                    3         2
+--R                      (- 4352B C  - 1536A B C - 2048B  - 11520A B)D
+--R                 *
+--R                     7 3
+--R                    a b
+--R                + 
+--R                                        3                         2
+--R                      (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D
+--R                    + 
+--R                               3          2           2         2            2
+--R                          5632C  - 4608A C  + (- 4608B  - 11776A )C + 9728A B
+--R                        + 
+--R                                 3
+--R                          - 1536A
+--R                     *
+--R                        D
+--R                 *
+--R                     8 2
+--R                    a b
+--R                + 
+--R                            2                  2        2  2
+--R                      (9216C  - 2048A C + 2048B  - 3072A )D
+--R                    + 
+--R                              2                    3        2
+--R                      (5120B C  + 6144A B C + 2048B  + 9216A B)D
+--R                 *
+--R                     9
+--R                    a b
+--R                + 
+--R                          3        2           2    10
+--R                  (- 4096C  + 4096A C - 8192A B )D a
+--R             *
+--R                     2
+--R                %%BN0
+--R            + 
+--R                      4   8
+--R                  8A D a c
+--R                + 
+--R                            4 2        5       4         3
+--R                      - 2A D b  + (- 4D  - 4B D  - 8A C D )a b
+--R                    + 
+--R                            4          3      3 2  2
+--R                      (32A D  - 16A B D  + 16A D )a
+--R                 *
+--R                     7
+--R                    c
+--R                + 
+--R                        5      4         3  3
+--R                      (D  + B D  + 2A C D )b
+--R                    + 
+--R                                    4                 3     3 2    2
+--R                      ((12C - 100A)D  + (4B C + 4A B)D  - 4A D )a b
+--R                    + 
+--R                              5         2     2      2  3                 2   2
+--R                          - 8D  + (- 16C  + 8B  + 24A )D  + (48A B C - 24A B)D
+--R                        + 
+--R                               3     3
+--R                          (8A C  - 8A C)D
+--R                     *
+--R                         2
+--R                        a b
+--R                    + 
+--R                                 4          3       3      2         2      3  2
+--R                          - 48A D  - 64A B D  + (16C  - 48A C - 48A B  + 64A )D
+--R                        + 
+--R                                    2      3          4     5
+--R                          (- 48A B C  - 16A B)D - 8A C  + 8A
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                    4        3  4
+--R                      ((- 3C + 22A)D  - B C D )b
+--R                    + 
+--R                             5        4        2             2     2  3
+--R                          36D  + 34B D  + (- 4C  + 92A C - 2B  - 6A )D
+--R                        + 
+--R                                         2   2          3     3
+--R                          (- 12A B C + 6A B)D  + (- 2A C  + 2A C)D
+--R                     *
+--R                           3
+--R                        a b
+--R                    + 
+--R                                       4           3
+--R                          (40C - 108A)D  + 104A B D
+--R                        + 
+--R                              3        2         2      2          2       3  2
+--R                          (12C  - 84A C  + (- 24B  - 12A )C + 12A B  - 172A )D
+--R                        + 
+--R                                 3          2      2        3          4     5
+--R                          (- 4B C  - 12A B C  + 12A B C + 4A B)D + 2A C  - 2A
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                             5        4          2               2       2  3
+--R                          40D  + 56B D  + (- 104C  + 112A C + 40B  + 120A )D
+--R                        + 
+--R                                  2                 3      2   2
+--R                          (- 48B C  + 384A B C + 24B  + 48A B)D
+--R                        + 
+--R                                   4         3       2      2  2        2
+--R                              - 28C  + 112A C  + (24B  + 48A )C  + 48A B C
+--R                            + 
+--R                                 2 2      4
+--R                              24A B  + 28A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4          3      3         4
+--R                          4B C  + 32A B C  + 16A B C - 20A B
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                  4           3
+--R                          - 320A D  + 192A B D
+--R                        + 
+--R                              3        2       2          2      3  2
+--R                          (64C  + 48A C  - 192A C - 192A B  - 48A )D
+--R                        + 
+--R                                3           2      2            3      3
+--R                          (32B C  - 192A B C  + 96A B C + 128A B  - 64A B)D
+--R                        + 
+--R                             5        4      2 3        2 2      4       3 2
+--R                          16C  - 32A C  + 32A C  + 48A B C  - 48A C + 16A B
+--R                        + 
+--R                             5
+--R                          32A
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                           5       4      2          3  5
+--R                      (- 8D  - 8B D  + (2C  - 22A C)D )b
+--R                    + 
+--R                                          4                     3
+--R                          (- 112C + 388A)D  + (- 34B C - 20A B)D
+--R                        + 
+--R                               3        2      2     2        3  2
+--R                          (- 4C  + 21A C  + (6B  + 6A )C + 37A )D
+--R                        + 
+--R                              3         2     2
+--R                          (B C  + 6A B C  - 3A B C)D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                               5         4        2              2       2  3
+--R                          - 62D  - 126B D  + (138C  - 96A C - 66B  - 222A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (48B C  - 456A B C - 2B  + 204A B)D
+--R                        + 
+--R                              4        3     2 2      3      2 2     4        4
+--R                          (11C  - 84A C  + 6B C  + 72A C - 6A B  - 7A )D - B C
+--R                        + 
+--R                                  3     3        4
+--R                          - 8A B C  - 4A B C + 5A B
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                4                    3
+--R                          840A D  + (56B C - 264A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                                24C  - 420A C  + (- 96B  + 288A )C + 360A B
+--R                              + 
+--R                                      3
+--R                                - 196A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3           2         3       2            3
+--R                              - 8B C  + 240A B C  + (- 24B  - 120A B)C - 104A B
+--R                            + 
+--R                                 3
+--R                              80A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4         2      2  3
+--R                          - 8C  + 56A C  + (- 16B  - 40A )C
+--R                        + 
+--R                                2      3  2         2 2      4       3 2      5
+--R                        (- 60A B  - 16A )C  + (- 24A B  + 16A )C + 4A B  - 72A
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                             5        4        2               2       2  3
+--R                          80D  - 48B D  + (- 8C  - 240A C - 80B  - 168A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 264B C  + 144A B C - 16B  + 216A B)D
+--R                        + 
+--R                                    4         3         2       2  2
+--R                              - 208C  + 192A C  + (- 24B  - 144A )C
+--R                            + 
+--R                                       2      3        4       2 2       4
+--R                              (- 528A B  - 32A )C - 64B  - 408A B  + 128A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4          3         3       2   2
+--R                          - 48B C  - 64A B C  + (- 24B  - 240A B)C
+--R                        + 
+--R                                  3      3         2 3      4
+--R                          (- 80A B  + 96A B)C - 24A B  - 64A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                  4            3
+--R                          - 128A D  + 1024A B D
+--R                        + 
+--R                                3         2      2          2       3  2
+--R                          (- 96C  + 192A C  + 96A C - 192A B  - 448A )D
+--R                        + 
+--R                                 3       2            3        5        4
+--R                          (128B C  + 384A B C + 512A B )D + 64C  - 64A C
+--R                        + 
+--R                                2       2  3          2      3  2
+--R                          (- 32B  + 128A )C  + (192A B  + 64A )C
+--R                        + 
+--R                                2 2       4          4      3 2
+--R                          (- 96A B  - 192A )C - 64A B  + 64A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                   4         3  6
+--R                      ((24C - 80A)D  + 8B C D )b
+--R                    + 
+--R                               5        4       2               2      2  3
+--R                          - 65D  - 51B D  + (42C  - 345A C + 13B  + 45A )D
+--R                        + 
+--R                                 2              3      2   2
+--R                          (- 9B C  + 84A B C - B  - 51A B)D
+--R                        + 
+--R                            4        3        2     2  2          2      3
+--R                        (- C  + 13A C  + (- 3B  - 3A )C  + (- 3A B  - 17A )C)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                  4                    3
+--R                          - 596A D  + (38B C + 106A B)D
+--R                        + 
+--R                                    3         2        2       2          2
+--R                              - 180C  + 744A C  + (180B  + 102A )C - 96A B
+--R                            + 
+--R                                  3
+--R                              522A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2        3       2           3
+--R                              10B C  + 114A B C  + (- 2B  - 102A B)C + 18A B
+--R                            + 
+--R                                   3
+--R                              - 14A B
+--R                         *
+--R                            D
+--R                        + 
+--R                           5        4      2     2  3         2     3  2
+--R                          C  - 11A C  + (4B  + 8A )C  + (12A B  + 4A )C
+--R                        + 
+--R                             2 2    4       3 2      5
+--R                          (6A B  - A )C - 2A B  + 15A
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                                5         4        2              2       2  3
+--R                          - 248D  - 136B D  + (158C  - 12A C - 72B  - 178A )D
+--R                        + 
+--R                                 2                   3       2   2
+--R                          (354B C  - 1572A B C - 136B  - 894A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              290C  - 672A C  + (- 126B  - 180A )C
+--R                            + 
+--R                                     2      3        4       2 2       4
+--R                              (108A B  - 96A )C + 48B  + 162A B  - 238A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4           3       3       2   2
+--R                          10B C  - 128A B C  + (30B  + 204A B)C
+--R                        + 
+--R                                3       3         2 3       4
+--R                          (68A B  - 128A B)C + 14A B  + 170A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                           4                      3
+--R                          (- 280C + 1176A)D  + (384B C - 1728A B)D
+--R                        + 
+--R                                  3        2        2        2            2
+--R                              392C  - 72A C  + (624B  + 1080A )C + 1392A B
+--R                            + 
+--R                                   3
+--R                              1160A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2        3       2            3
+--R                              144B C  + 1584A B C  + (384B  + 816A B)C - 640A B
+--R                            + 
+--R                                  3
+--R                              528A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4        2      2  3
+--R                          - 112C  + 208A C  + (168B  - 64A )C
+--R                        + 
+--R                                2      3  2       4       2 2       4          4
+--R                          (24A B  + 96A )C  + (40B  + 408A B  + 432A )C + 88A B
+--R                        + 
+--R                               3 2      5
+--R                          - 88A B  - 48A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                               5         4
+--R                          - 96D  - 352B D
+--R                        + 
+--R                               2                 2        2  3
+--R                          (992C  - 1088A C - 256B  - 1056A )D
+--R                        + 
+--R                                2                   3      2   2
+--R                          (96B C  - 1728A B C - 128B  + 96A B)D
+--R                        + 
+--R                                    4         2       2  2
+--R                              - 160C  + (- 96B  - 768A )C
+--R                            + 
+--R                                        2       3        4       2 2      4
+--R                              (- 1344A B  - 384A )C - 96B  - 864A B  + 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3       2   2
+--R                          - 32B C  - 128A B C  + (32B  - 384A B)C
+--R                        + 
+--R                                 3       3         5       2 3      4
+--R                          (192A B  + 256A B)C + 32B  + 288A B  + 32A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                4           3          3        2        3  2
+--R                          768A D  + 256A B D  + (- 640C  + 1152A C - 256A )D
+--R                        + 
+--R                                   2       3            4       2 3       3 2
+--R                          (768A B C  + 256A B)D - 128A C  - 128B C  + 256A C
+--R                        + 
+--R                                2 2          4       5
+--R                          - 384A B C - 256A B  - 128A
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                          5        4         2          3  7
+--R                      (16D  + 16B D  + (- 16C  + 80A C)D )b
+--R                    + 
+--R                                        4                   3
+--R                          (232C - 410A)D  + (66B C - 20A B)D
+--R                        + 
+--R                              3         2         2      2         2       3  2
+--R                          (40C  - 150A C  + (- 36B  - 36A )C + 6A B  - 102A )D
+--R                        + 
+--R                                 3          2      3      2
+--R                          (- 2B C  - 36A B C  + (2B  + 30A B)C)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                              5         4          2                2       2  3
+--R                          422D  + 522B D  + (- 290C  + 454A C + 122B  + 460A )D
+--R                        + 
+--R                                   2                  3       2   2
+--R                          (- 228B C  + 1068A B C + 14B  - 324A B)D
+--R                        + 
+--R                                   4         3         2     2  2
+--R                              - 74C  + 246A C  + (- 24B  - 6A )C
+--R                            + 
+--R                                      2       3       4      2 2      4
+--R                              (- 54A B  - 150A )C - 8B  - 18A B  + 48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 3        3      2   2           3      3
+--R                          32A B C  + (- 6B  - 36A B)C  + (- 12A B  + 24A B)C
+--R                        + 
+--R                              2 3      4
+--R                          - 2A B  - 36A B
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         4                        3
+--R                          (434C - 1918A)D  + (- 516B C + 1940A B)D
+--R                        + 
+--R                                    3         2          2       2           2
+--R                              - 568C  + 984A C  + (- 108B  - 828A )C - 996A B
+--R                            + 
+--R                                    3
+--R                              - 652A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3           2         3      2
+--R                              - 204B C  - 852A B C  + (- 84B  - 12A B)C
+--R                            + 
+--R                                    3       3
+--R                              356A B  - 196A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5         4        2       2  3         2     3  2
+--R                          36C  - 132A C  + (- 8B  + 108A )C  + (72A B  + 4A )C
+--R                        + 
+--R                                4       2 2       4          4      3 2       5
+--R                          (- 30B  - 108A B  - 128A )C - 38A B  - 60A B  + 144A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          360D  + 968B D
+--R                        + 
+--R                                  2                 2        2  3
+--R                          (- 1884C  + 1944A C + 400B  + 1892A )D
+--R                        + 
+--R                                   2                  3        2   2
+--R                          (- 660B C  + 1320A B C + 48B  - 1428A B)D
+--R                        + 
+--R                                  4         3          2       2  2
+--R                              588C  - 544A C  + (- 612B  + 504A )C
+--R                            + 
+--R                                      2       3         4        2 2       4
+--R                              (1800A B  - 256A )C + 216B  + 1788A B  - 484A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3          3       2   2
+--R                          156B C  + 160A B C  + (- 172B  + 504A B)C
+--R                        + 
+--R                                   3       3         5       2 3      4
+--R                          (- 232A B  - 960A B)C - 40B  - 268A B  - 52A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                           4                        3
+--R                          (- 816C - 1488A)D  + (- 1152B C - 384A B)D
+--R                        + 
+--R                                  3         2          2        2          2
+--R                              304C  + 240A C  + (- 288B  - 1776A )C + 96A B
+--R                            + 
+--R                                  3
+--R                              784A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2          3       2
+--R                              - 800B C  - 1824A B C  + (- 320B  - 480A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 960A B  - 480A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4         2       2  3
+--R                          - 128C  + 160A C  + (- 16B  - 256A )C
+--R                        + 
+--R                                    2       3  2          4       2 2       4
+--R                          (- 1104A B  - 640A )C  + (- 240B  - 432A B  + 128A )C
+--R                        + 
+--R                                4       3 2       5
+--R                          176A B  - 752A B  + 224A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                5         4         2                2  3
+--R                          - 192D  + 192B D  + (1152C  + 768A C + 384B )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (1536B C  - 768A B C + 256B  + 384A B)D
+--R                        + 
+--R                                  4         3        2       2  2
+--R                              896C  - 128A C  + (384B  + 384A )C
+--R                            + 
+--R                                      2       3         4        2 2       4
+--R                              (2304A B  - 128A )C + 320B  + 1920A B  - 512A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4           3        3        2   2          3
+--R                          384B C  + 768A B C  + (256B  + 1152A B)C  + 1024A B C
+--R                        + 
+--R                             5       2 3       4
+--R                          64B  + 768A B  + 256A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                4            3
+--R                          768A D  - 3072A B D
+--R                        + 
+--R                                 3         2       2          2       3  2
+--R                          (- 256C  - 768A C  + 768A C + 768A B  + 768A )D
+--R                        + 
+--R                                      3           2        2             3
+--R                              - 512B C  + 768A B C  - 1536A B C - 2048A B
+--R                            + 
+--R                                  3
+--R                              256A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4       2 3         2 2       4
+--R                          - 256C  + 128A C  - 512A C  - 768A B C  + 768A C
+--R                        + 
+--R                                3 2       5
+--R                          - 256A B  - 128A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                     4          3  8
+--R                      ((- 48C + 96A)D  - 16B C D )b
+--R                    + 
+--R                               5        4          2               2      2  3
+--R                          - 60D  - 84B D  + (- 104C  + 420A C - 20B  - 84A )D
+--R                        + 
+--R                                2                3       2   2
+--R                          (36B C  - 144A B C + 4B  + 108A B)D
+--R                        + 
+--R                             4        3       2      2  2         2      3
+--R                          (4C  - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                                           4                       3
+--R                          (- 795C + 1965A)D  + (- 124B C - 996A B)D
+--R                        + 
+--R                                  3          2          2       2           2
+--R                              570C  - 1530A C  + (- 258B  - 138A )C + 246A B
+--R                            + 
+--R                                    3
+--R                              - 342A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2       3       2           3
+--R                              68B C  - 156A B C  + (36B  + 300A B)C - 52A B
+--R                            + 
+--R                                 3
+--R                              12A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5        4        2      2  3           2     3  2
+--R                          - 3C  + 17A C  + (- 6B  - 22A )C  + (- 18A B  - 6A )C
+--R                        + 
+--R                             4     2 2     4         4      3 2      5
+--R                          (5B  + 6A B  + 9A )C + 5A B  + 18A B  - 27A
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                5          4
+--R                          - 684D  - 1284B D
+--R                        + 
+--R                                2                 2        2  3
+--R                          (1576C  - 1932A C - 116B  - 1284A )D
+--R                        + 
+--R                                 2                  3        2   2
+--R                          (564B C  + 912A B C + 324B  + 3564A B)D
+--R                        + 
+--R                                    4          3        2       2  2
+--R                              - 564C  + 1212A C  + (732B  + 444A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 420A B  + 756A )C - 144B  - 816A B  + 552A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4           3       3       2   2       3
+--R                          - 56B C  + 192A B C  + (16B  - 480A B)C  + 544A B C
+--R                        + 
+--R                             5      2 3       4
+--R                          16B  + 96A B  - 264A B
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                         4                       3
+--R                          (1272C + 792A)D  + (1208B C - 1704A B)D
+--R                        + 
+--R                                 3          2           2       2            2
+--R                              48C  - 1920A C  + (- 1248B  - 792A )C - 2064A B
+--R                            + 
+--R                                     3
+--R                              - 1128A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2          3        2
+--R                              312B C  - 1704A B C  + (- 696B  - 3720A B)C
+--R                            + 
+--R                                    3       3
+--R                              312A B  - 936A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4          2       2  3
+--R                          164C  - 300A C  + (- 304B  - 240A )C
+--R                        + 
+--R                                 2      3  2        4      2 2       4
+--R                          (240A B  + 32A )C  + (200B  - 24A B  - 468A )C
+--R                        + 
+--R                                 4       3 2       5
+--R                          - 24A B  + 968A B  - 276A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                              5        4       2                2       2  3
+--R                          384D  + 96B D  + (40C  - 336A C + 256B  + 648A )D
+--R                        + 
+--R                                  2                   3        2   2
+--R                          (1176B C  + 6672A B C + 480B  + 2232A B)D
+--R                        + 
+--R                                     4          3         2        2  2
+--R                              - 1032C  + 1824A C  + (2712B  + 2640A )C
+--R                            + 
+--R                                      2        3        4       2 2        4
+--R                              (2064A B  + 2784A )C - 96B  - 744A B  + 1464A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4           3        3        2   2
+--R                          - 296B C  + 384A B C  + (616B  + 1104A B)C
+--R                        + 
+--R                                3        3         5       2 3       4
+--R                          (48A B  + 2176A B)C - 32B  - 600A B  + 216A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                         4                         3
+--R                          (480C - 2592A)D  + (- 1536B C + 4224A B)D
+--R                        + 
+--R                                     3          2           2        2
+--R                              - 1632C  + 1248A C  + (- 2112B  - 3744A )C
+--R                            + 
+--R                                       2        3
+--R                              - 4224A B  - 2016A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      3            2           3        2
+--R                              - 768B C  - 5376A B C  + (- 1536B  - 4224A B)C
+--R                            + 
+--R                                     3        3
+--R                              1536A B  - 1920A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4       2 3            2       3  2
+--R                          320C  - 480A C  - 544B C  + (- 480A B  - 640A )C
+--R                        + 
+--R                               4        2 2        4          4       3 2      5
+--R                        (- 160B  - 1248A B  - 1344A )C - 96A B  + 224A B  + 96A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                4           2                 2        2  3
+--R                          768B D  + (- 2304C  + 3072A C + 384B  + 2304A )D
+--R                        + 
+--R                                 2                  3        2   2
+--R                          (384B C  + 768A B C + 128B  - 1152A B)D
+--R                        + 
+--R                                   4          3        2 2
+--R                              1088C  - 1792A C  + 2304A C
+--R                            + 
+--R                                      2        3         4        2 2       4
+--R                              (4608A B  + 1536A )C + 384B  + 3072A B  - 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                               4          3        2   2
+--R                          64B C  + (- 128B  + 1536A B)C
+--R                        + 
+--R                                   3        3          5        2 3       4
+--R                          (- 768A B  - 1280A B)C - 128B  - 1152A B  + 192A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                                     3
+--R                          - 3072A B D
+--R                        + 
+--R                                3         2        2           2       3  2
+--R                          (1536C  - 768A C  - 1536A C + 3072A B  + 768A )D
+--R                        + 
+--R                                   3        2             3         5          4
+--R                          (- 512B C  - 1536A B C - 2048A B )D - 256C  + 1024A C
+--R                        + 
+--R                               2       2  3            2        3  2
+--R                          (512B  - 512A )C  + (- 768A B  - 1024A )C
+--R                        + 
+--R                                2 2       4            4       3 2
+--R                          (1536A B  + 768A )C + 1024A B  - 256A B
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                      2          3 9
+--R                  (32C  - 96A C)D b
+--R                + 
+--R                                   4                    3
+--R                      (96C - 216A)D  + (24B C + 144A B)D
+--R                    + 
+--R                            3         2       2      2          2      3  2
+--R                      (- 96C  + 264A C  + (48B  + 48A )C - 24A B  + 72A )D
+--R                    + 
+--R                             3          2        3      2
+--R                      (- 8B C  + 48A B C  + (- 8B  - 72A B)C)D
+--R                 *
+--R                       8
+--R                    a b
+--R                + 
+--R                         5         4         2               2       2  3
+--R                      54D  + 126B D  + (- 12C  - 336A C - 12B  + 108A )D
+--R                    + 
+--R                              2                 3       2   2
+--R                      (- 60B C  - 360A B C - 60B  - 540A B)D
+--R                    + 
+--R                             4         3          2      2  2         2      3
+--R                          94C  - 240A C  + (- 108B  - 84A )C  + (48A B  - 96A )C
+--R                        + 
+--R                             4       2 2      4
+--R                          22B  + 108A B  - 90A
+--R                     *
+--R                        D
+--R                    + 
+--R                          4          3      3      2   2        3      3
+--R                      6B C  - 40A B C  + (4B  + 84A B)C  + (8A B  - 72A B)C
+--R                    + 
+--R                          5      2 3      4
+--R                      - 2B  - 12A B  + 54A B
+--R                 *
+--R                     2 7
+--R                    a b
+--R                + 
+--R                                     4                    3
+--R                      (450C - 1350A)D  + (96B C + 936A B)D
+--R                    + 
+--R                                  3          2        2       2           2
+--R                            - 492C  + 1764A C  + (540B  + 636A )C + 420A B
+--R                          + 
+--R                                3
+--R                            684A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 3           2       3       2           3
+--R                          - 48B C  + 792A B C  + (96B  + 288A B)C - 72A B
+--R                        + 
+--R                              3
+--R                          216A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           5        4       2      2  3           2     3  2
+--R                      - 30C  + 74A C  + (52B  + 36A )C  + (- 36A B  + 4A )C
+--R                    + 
+--R                            4      2 2      4         4       3 2      5
+--R                      (- 30B  + 12A B  + 90A )C + 2A B  - 156A B  + 18A
+--R                 *
+--R                     3 6
+--R                    a b
+--R                + 
+--R                          5         4           2                 2       2  3
+--R                      360D  + 792B D  + (- 1656C  + 2664A C - 168B  + 432A )D
+--R                    + 
+--R                               2                   3        2   2
+--R                      (- 720B C  - 3312A B C - 504B  - 3888A B)D
+--R                    + 
+--R                              4          3           2        2  2
+--R                          600C  - 1656A C  + (- 1152B  - 1224A )C
+--R                        + 
+--R                                   2        3        4       2 2       4
+--R                          (- 648A B  - 1224A )C + 96B  + 360A B  - 720A
+--R                     *
+--R                        D
+--R                    + 
+--R                           4           3         3       2   2
+--R                      48B C  - 384A B C  + (- 72B  + 144A B)C
+--R                    + 
+--R                            3       3         2 3       4
+--R                      (48A B  - 672A B)C + 72A B  + 288A B
+--R                 *
+--R                     4 5
+--R                    a b
+--R                + 
+--R                                        4                        3
+--R                      (- 2232C + 2952A)D  + (- 336B C - 1296A B)D
+--R                    + 
+--R                               3          2         2        2            2
+--R                          2016C  - 2160A C  + (1584B  + 2448A )C + 4464A B
+--R                        + 
+--R                              3
+--R                          864A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                3            2         3        2            3
+--R                          480B C  + 3888A B C  + (1488B  + 7200A B)C - 144A B
+--R                        + 
+--R                               3
+--R                          1872A B
+--R                     *
+--R                        D
+--R                    + 
+--R                            5         4        2       2  3
+--R                      - 192C  + 480A C  + (480B  + 432A )C
+--R                    + 
+--R                             2       3  2          4       2 2       4
+--R                      (288A B  + 336A )C  + (- 120B  + 432A B  + 720A )C
+--R                    + 
+--R                             4       3 2       5
+--R                      - 24A B  - 912A B  + 144A
+--R                 *
+--R                     5 4
+--R                    a b
+--R                + 
+--R                            5          4         2                 2        2  3
+--R                      - 576D  - 1728B D  + (3472C  - 6240A C - 672B  - 3312A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 2160B C  - 3744A B C - 288B  + 3024A B)D
+--R                    + 
+--R                                 4          3           2        2  2
+--R                          - 1248C  + 1728A C  + (- 2448B  - 4320A )C
+--R                        + 
+--R                                    2        3         4        2 2
+--R                          (- 8352A B  - 3456A )C - 672B  - 4176A B
+--R                     *
+--R                        D
+--R                    + 
+--R                             4           3          3        2   2
+--R                      - 96B C  - 768A B C  + (- 912B  - 4320A B)C
+--R                    + 
+--R                               3       3         5        2 3        4
+--R                      (- 480A B  - 960A B)C + 96B  + 1008A B  - 1152A B
+--R                 *
+--R                     6 3
+--R                    a b
+--R                + 
+--R                                     4                       3
+--R                      (2496C - 576A)D  + (3456B C + 3456A B)D
+--R                    + 
+--R                              3          2         2        2            2  2
+--R                      (- 1344C  + 4992A C  + (2688B  + 3264A )C - 3072A B )D
+--R                    + 
+--R                                 3            2         3        2             3
+--R                          2816B C  + 4992A B C  + (1664B  + 2304A B)C + 3456A B
+--R                        + 
+--R                               3
+--R                          1152A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          5         4        2        2  3
+--R                      384C  - 768A C  + (576B  + 1152A )C
+--R                    + 
+--R                              2        3  2        4        2 2           4
+--R                      (4608A B  + 2304A )C  + (960B  + 2880A B )C - 192A B
+--R                    + 
+--R                           3 2
+--R                      2688A B
+--R                 *
+--R                     7 2
+--R                    a b
+--R                + 
+--R                              2                2        2  3
+--R                      (- 3456C  + 768A C - 768B  + 1152A )D
+--R                    + 
+--R                                2                   3        2   2
+--R                      (- 1920B C  - 2304A B C - 768B  - 3456A B)D
+--R                    + 
+--R                                4          3           2       2  2
+--R                          - 256C  - 3072A C  + (- 1152B  + 768A )C
+--R                        + 
+--R                                   2        3         4        2 2
+--R                          (- 768A B  + 1536A )C - 256B  - 1152A B
+--R                     *
+--R                        D
+--R                    + 
+--R                              4            3          3       2   2
+--R                      - 768B C  - 2048A B C  + (- 640B  - 768A B)C
+--R                    + 
+--R                                3        3          5        2 3
+--R                      (- 2816A B  - 1536A B)C - 256B  - 2688A B
+--R                 *
+--R                     8
+--R                    a b
+--R                + 
+--R                            3        2           2  2          4       2 3
+--R                      (1536C  - 1536A C + 3072A B )D  + 1024A C  + 512B C
+--R                    + 
+--R                             3 2        2 2           4
+--R                      - 1024A C  + 1536A B C + 1024A B
+--R                 *
+--R                     9
+--R                    a
+--R             *
+--R                %%BN0
+--R            + 
+--R                       5          4   7
+--R                  (2A D b - 4A C D a)c
+--R                + 
+--R                            5         4  2
+--R                      (- B D  - 4A C D )b
+--R                    + 
+--R                                    5                  4         2     3  3
+--R                      ((- 2C + 10A)D  + (2B C - 14A B)D  + (12A C  + 4A )D )a b
+--R                    + 
+--R                        2             2  4            3          3     3   2  2
+--R                    ((4C  - 16A C + 4A )D  + 32A B C D  + (- 8A C  - 8A C)D )a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                 5                 4        2     3  3  3
+--R                      ((C - 19A)D  + (2B C + 6A B)D  + (2A C  - 2A )D )b
+--R                    + 
+--R                            6       5      2             2      2  4
+--R                          3D  - 2B D  + (2C  + 28A C + 7B  + 18A )D
+--R                        + 
+--R                                 2              2   3          3     3   2
+--R                          (- 6B C  - 4A B C - 6A B)D  + (- 8A C  + 8A C)D
+--R                     *
+--R                           2
+--R                        a b
+--R                    + 
+--R                                       5                   4
+--R                          (- 16C + 8A)D  + (16B C - 80A B)D
+--R                        + 
+--R                                3        2         2      2          2      3  3
+--R                          (- 12C  + 28A C  + (- 16B  - 68A )C + 32A B  + 20A )D
+--R                        + 
+--R                               3          2      2         3   2
+--R                          (4B C  - 36A B C  + 12A B C - 12A B)D
+--R                        + 
+--R                                4      3 2     5
+--R                          (10A C  - 12A C  + 2A )D
+--R                     *
+--R                         2
+--R                        a b
+--R                    + 
+--R                              2              2  4
+--R                          (16C  - 16A C + 16A )D
+--R                        + 
+--R                                  2                 2   3
+--R                          (- 32B C  + 128A B C - 32A B)D
+--R                        + 
+--R                             4        3      2 2           2      3       4  2
+--R                          (8C  - 32A C  + 48A C  + (- 96A B  - 32A )C + 8A )D
+--R                        + 
+--R                                  3      3            5     3 3     5
+--R                          (32A B C  + 32A B C)D - 4A C  + 8A C  - 4A C
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                             6       5        2             2     2  4
+--R                          - D  + 8B D  + (- 2C  + 32A C - 3B  - 6A )D
+--R                        + 
+--R                                2              2   3
+--R                          (- B C  - 6A B C + 3A B)D
+--R                     *
+--R                         4
+--R                        b
+--R                    + 
+--R                                      5                      4
+--R                          (14C - 46A)D  + (- 30B C + 130A B)D
+--R                        + 
+--R                             3        2      2      2          2      3  3
+--R                          (4C  - 96A C  + (2B  + 12A )C - 18A B  - 48A )D
+--R                        + 
+--R                               3          2      2     2
+--R                          (4B C  + 24A B C  - 12A B C)D
+--R                     *
+--R                           3
+--R                        a b
+--R                    + 
+--R                             6        5        2              2      2  4
+--R                          10D  - 16B D  + (- 6C  + 76A C + 18B  + 58A )D
+--R                        + 
+--R                                2                 3      2   3
+--R                          (24B C  - 240A B C - 16B  - 72A B)D
+--R                        + 
+--R                                4        3       2      2  2         2       3
+--R                              4C  + 64A C  + (18B  + 24A )C  + (60A B  + 128A )C
+--R                            + 
+--R                                 2 2     4
+--R                              18A B  + 4A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 4          3      2   2     3        4
+--R                          (- 5B C  - 28A B C  + 18A B C  + 4A B C - 5A B)D
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                                       5                    4
+--R                          (- 24C - 8A)D  + (120B C - 72A B)D
+--R                        + 
+--R                                     3        2         2       2           2
+--R                                - 40C  + 40A C  + (- 48B  - 248A )C + 240A B
+--R                              + 
+--R                                   3
+--R                                56A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                   3          2       3       2           3
+--R                              40B C  - 72A B C  + (48B  + 312A B)C - 16A B
+--R                            + 
+--R                                   3
+--R                              - 88A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5        4         2      2  3      3 2
+--R                              - 10C  + 18A C  + (- 16B  - 36A )C  - 92A C
+--R                            + 
+--R                                    2 2      4        5
+--R                              (- 48A B  - 18A )C + 10A
+--R                         *
+--R                            D
+--R                        + 
+--R                            5          4      2   3      3   2      4        5
+--R                        2B C  + 10A B C  - 12A B C  - 12A B C  + 10A B C + 2A B
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                              2      2  4            2                  2   3
+--R                          (16C  + 16A )D  + (- 128B C  + 128A B C - 128A B)D
+--R                        + 
+--R                                 4        3       2       2  2
+--R                              32C  - 64A C  + (96B  + 192A )C
+--R                            + 
+--R                                       2      3        2 2      4
+--R                              (- 384A B  - 64A )C + 96A B  + 32A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4           3       2   2
+--R                              - 32B C  + 128A B C  - 192A B C
+--R                            + 
+--R                                     3       3         4
+--R                              (128A B  + 128A B)C - 32A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            6        5     2 4           2      3  3     4 2
+--R                          4C  - 16A C  - 4A C  + (- 32A B  + 32A )C  - 4A C
+--R                        + 
+--R                                3 2      5       6
+--R                          (- 32A B  - 16A )C + 4A
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                       5                     4
+--R                          (- 5C + 59A)D  + (- 10B C - 42A B)D
+--R                        + 
+--R                            3        2      2     2         2      3  3
+--R                          (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                     *
+--R                         5
+--R                        b
+--R                    + 
+--R                               6        5         2               2       2  4
+--R                          - 22D  + 14B D  + (- 14C  - 112A C - 50B  - 162A )D
+--R                        + 
+--R                                2                3       2   3
+--R                          (46B C  + 20A B C + 10B  + 102A B)D
+--R                        + 
+--R                                  4        3         2      2  2
+--R                              - 4C  + 52A C  + (- 12B  - 12A )C
+--R                            + 
+--R                                      2      3
+--R                              (- 12A B  - 68A )C
+--R                         *
+--R                             2
+--R                            D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                                      5                       4
+--R                          (72C + 40A)D  + (- 160B C + 288A B)D
+--R                        + 
+--R                              3        2        2       2           2      3  3
+--R                          (66C  - 46A C  + (144B  + 598A )C - 304A B  - 58A )D
+--R                        + 
+--R                                  3           2         3       2         3   2
+--R                          (- 80B C  + 264A B C  + (- 32B  - 336A B)C + 88A B)D
+--R                        + 
+--R                                5        4       2      2  3        2      3  2
+--R                              5C  - 67A C  + (14B  + 10A )C  + (6A B  + 98A )C
+--R                            + 
+--R                                   2 2    4       3 2      5
+--R                              (- 6A B  + A )C + 2A B  - 15A
+--R                         *
+--R                            D
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                 5         2              2  4
+--R                          - 80B D  + (- 64C  - 128A C + 8B )D
+--R                        + 
+--R                                 2                 3       2   3
+--R                          (208B C  - 480A B C - 64B  - 176A B)D
+--R                        + 
+--R                                   4         3          2       2  2
+--R                              - 41C  + 116A C  + (- 144B  - 582A )C
+--R                            + 
+--R                                     2      3       4      2 2      4
+--R                              (672A B  - 12A )C + 8B  + 48A B  - 41A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3       2   2
+--R                              50B C  - 328A B C  + 204A B C
+--R                            + 
+--R                                      3       3         4
+--R                              (- 64A B  - 200A B)C - 14A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              6        5        2     2  4        2      3  3
+--R                          - 2C  + 28A C  + (- 5B  + 2A )C  + (4A B  - 56A )C
+--R                        + 
+--R                              2 2     4  2      3 2      5       4 2     6
+--R                          (18A B  + 2A )C  + (4A B  + 28A )C - 5A B  - 2A
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                                           4
+--R                          (192B C + 64A B)D
+--R                        + 
+--R                                   3         2          2       2           2
+--R                              - 16C  + 208A C  + (- 320B  - 176A )C + 256A B
+--R                            + 
+--R                                  3
+--R                              112A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                   3           2       3        2            3
+--R                              80B C  - 144A B C  + (64B  + 1008A B)C - 320A B
+--R                            + 
+--R                                    3
+--R                              - 304A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5       4         2       2  3
+--R                              - 24C  - 8A C  + (- 16B  + 144A )C
+--R                            + 
+--R                                      2       3  2         4       2 2     4
+--R                              (- 48A B  + 112A )C  + (- 64B  - 432A B  + 8A )C
+--R                            + 
+--R                                     4       3 2      5
+--R                              - 32A B  + 112A B  + 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5          4       3      2   3
+--R                          - 8B C  + 88A B C  + (16B  + 48A B)C
+--R                        + 
+--R                              3      3   2       2 3      4         3 3     5
+--R                        (48A B  + 48A B)C  + (48A B  + 88A B)C + 16A B  - 8A B
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                   2       2   3
+--R                          (- 128B C  - 128A B)D
+--R                        + 
+--R                                 4         3        2       2  2
+--R                              32C  - 128A C  + (384B  + 192A )C
+--R                            + 
+--R                                       2       3         2 2      4
+--R                              (- 384A B  - 128A )C + 384A B  + 32A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3       2   2
+--R                              - 128B C  + 256A B C  + (- 128B  - 768A B)C
+--R                            + 
+--R                                     3       3          2 3       4
+--R                              (512A B  + 256A B)C - 128A B  - 128A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6       2      2  4         2 3
+--R                          16C  + (32B  - 16A )C  - 128A B C
+--R                        + 
+--R                               2 2      4  2           4       3 2        4 2
+--R                          (192A B  - 16A )C  + (- 64A B  - 128A B )C + 32A B
+--R                        + 
+--R                             6
+--R                          16A
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            6        5       2              2      2  4
+--R                          6D  - 22B D  + (10C  - 76A C + 18B  + 42A )D
+--R                        + 
+--R                               2               3      2   3
+--R                          (2B C  + 36A B C - 2B  - 30A B)D
+--R                     *
+--R                         6
+--R                        b
+--R                    + 
+--R                                       5                     4
+--R                          (- 18C + 6A)D  + (148B C - 260A B)D
+--R                        + 
+--R                                   3         2         2       2           2
+--R                              - 22C  + 262A C  + (- 34B  - 114A )C + 102A B
+--R                            + 
+--R                                  3
+--R                              114A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                 3           2      3       2     2
+--R                          (- 8B C  - 144A B C  + (8B  + 120A B)C)D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                               6         5        2              2       2  4
+--R                          - 15D  + 136B D  + (- 8C  + 48A C - 22B  - 216A )D
+--R                        + 
+--R                                   2                  3       2   3
+--R                          (- 162B C  + 436A B C + 112B  + 486A B)D
+--R                        + 
+--R                                   4         3         2      2  2
+--R                              - 11C  - 268A C  + (- 24B  - 18A )C
+--R                            + 
+--R                                       2       3       4       2 2      4
+--R                              (- 288A B  - 300A )C - 3B  - 120A B  - 27A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3        3       2   2
+--R                              12B C  + 184A B C  + (- 6B  - 144A B)C
+--R                            + 
+--R                                    3      3        2 3      4
+--R                              (12A B  - 24A B)C + 2A B  + 36A B
+--R                         *
+--R                            D
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                                      5                       4
+--R                          (56C + 72A)D  + (- 464B C - 208A B)D
+--R                        + 
+--R                              3         2        2       2           2      3  3
+--R                          (84C  - 300A C  + (448B  + 908A )C - 704A B  + 12A )D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 208B C  + 336A B C  + (- 256B  - 1824A B)C
+--R                            + 
+--R                                    3       3
+--R                              256A B  + 448A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5        4       2       2  3
+--R                              48C  + 72A C  + (92B  + 160A )C
+--R                            + 
+--R                                     2       3  2       4       2 2       4
+--R                              (108A B  + 272A )C  + (40B  + 516A B  + 112A )C
+--R                            + 
+--R                                   4      3 2      5
+--R                              24A B  - 12A B  - 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5          4      2   3           3      3   2
+--R                          - 6B C  - 78A B C  + 52A B C  + (- 16A B  + 52A B)C
+--R                        + 
+--R                                2 3      4        5
+--R                          (- 16A B  - 78A B)C - 6A B
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                2                2      2  4
+--R                          (- 72C  - 240A C + 240B  - 72A )D
+--R                        + 
+--R                                 2                 3      2   3
+--R                          (480B C  + 576A B C + 96B  + 96A B)D
+--R                        + 
+--R                                   4         3          2        2  2
+--R                              - 98C  + 456A C  + (- 768B  - 1068A )C
+--R                            + 
+--R                                      2       3         4      4
+--R                              (1152A B  - 312A )C + 112B  + 30A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3        3        2   2
+--R                              348B C  - 560A B C  + (224B  + 1512A B)C
+--R                            + 
+--R                                       3       3         5      2 3      4
+--R                              (- 704A B  - 304A B)C + 16B  + 96A B  + 92A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               6         2      2  4         2       3  3
+--R                          - 24C  + (- 42B  - 40A )C  + (40A B  - 128A )C
+--R                        + 
+--R                                4       2 2      4  2           4      3 2
+--R                          (- 24B  - 348A B  - 40A )C  + (- 16A B  + 40A B )C
+--R                        + 
+--R                               2 4      4 2      6
+--R                          - 24A B  - 42A B  - 24A
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                                   3         2          2      2           2
+--R                                32C  + 288A C  + (- 576B  + 96A )C - 192A B
+--R                              + 
+--R                                   3
+--R                                96A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                     3           2        3       2            3
+--R                              - 32B C  - 864A B C  + (320B  + 672A B)C - 448A B
+--R                            + 
+--R                                    3
+--R                              - 544A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              32C  - 256A C  + (160B  + 320A )C
+--R                            + 
+--R                                    2       3  2         4        2 2      4
+--R                              (96A B  + 512A )C  + (- 32B  - 1056A B  - 96A )C
+--R                            + 
+--R                                    4       3 2
+--R                              160A B  + 544A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5          4         3       2   3
+--R                          - 96B C  + 32A B C  + (- 32B  - 192A B)C
+--R                        + 
+--R                                 3       3   2       5       2 3      4
+--R                          (160A B  - 192A B)C  + (32B  + 160A B  + 32A B)C
+--R                        + 
+--R                               5      3 3      5
+--R                          32A B  - 32A B  - 96A B
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                                   3       2 2       3        2 2  2
+--R                          (- 128A C  + 384B C  - 128A C + 384A B )D
+--R                        + 
+--R                                      4           3          3       2   2
+--R                              - 128B C  + 512A B C  + (- 512B  - 768A B)C
+--R                            + 
+--R                                     3       3          2 3       4
+--R                              (512A B  + 512A B)C - 512A B  - 128A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               5       2 4            2       3  3
+--R                          64A C  + 128B C  + (- 256A B  - 128A )C
+--R                        + 
+--R                              4       2 2  2            4       3 2      5
+--R                          (64B  + 768A B )C  + (- 256A B  - 256A B  + 64A )C
+--R                        + 
+--R                             2 4       4 2
+--R                          64A B  + 128A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                     5                  4
+--R                          (4C - 60A)D  + (8B C + 72A B)D
+--R                        + 
+--R                               3        2         2      2          2      3  3
+--R                          (- 4C  + 20A C  + (- 12B  - 12A )C - 12A B  - 36A )D
+--R                     *
+--R                         7
+--R                        b
+--R                    + 
+--R                             6        5                2       2  4
+--R                          32D  - 48B D  + (208A C + 64B  + 336A )D
+--R                        + 
+--R                                   2                3       2   3
+--R                          (- 112B C  - 64A B C - 48B  - 336A B)D
+--R                        + 
+--R                            4        3       2      2  2         2       3    2
+--R                        (16C  - 80A C  + (48B  + 48A )C  + (48A B  + 144A )C)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                                          5                    4
+--R                          (- 145C - 177A)D  + (180B C + 84A B)D
+--R                        + 
+--R                                   3         2          2        2           2
+--R                              - 54C  - 178A C  + (- 458B  - 1442A )C + 470A B
+--R                            + 
+--R                                    3
+--R                              - 294A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3        2           3
+--R                              332B C  - 348A B C  + (140B  + 1188A B)C - 20A B
+--R                            + 
+--R                                    3
+--R                              - 180A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4         2      2  3
+--R                              - 21C  + 103A C  + (- 66B  - 50A )C
+--R                            + 
+--R                                      2       3  2        4     2 2     4
+--R                              (- 54A B  - 210A )C  + (- 5B  - 6A B  - 9A )C
+--R                            + 
+--R                                    4      3 2      5
+--R                              - 5A B  - 18A B  + 27A
+--R                         *
+--R                            D
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                               5        2                2       2  4
+--R                          60B D  + (213C  + 794A C - 280B  + 261A )D
+--R                        + 
+--R                                   2                 3       2   3
+--R                          (- 164B C  - 392A B C - 48B  + 348A B)D
+--R                        + 
+--R                                  4        3        2        2  2
+--R                              118C  - 56A C  + (870B  + 2100A )C
+--R                            + 
+--R                                       2        3         4       2 2     4
+--R                              (- 900A B  + 1256A )C - 104B  - 426A B  + 6A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3        2   2
+--R                              - 352B C  + 480A B C  + (- 124B  - 1056A B)C
+--R                            + 
+--R                                     3       3         5      2 3
+--R                              (104A B  + 160A B)C - 12B  - 92A B
+--R                         *
+--R                            D
+--R                        + 
+--R                            6        5       2     2  4         2       3  3
+--R                          9C  - 42A C  + (30B  + 7A )C  + (24A B  + 116A )C
+--R                        + 
+--R                             4      2 2     4  2         4      3 2      5
+--R                          (5B  - 12A B  + 7A )C  + (10A B  + 24A B  - 42A )C
+--R                        + 
+--R                            2 4      4 2     6
+--R                          5A B  + 30A B  + 9A
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                                              4
+--R                          (- 224B C - 288A B)D
+--R                        + 
+--R                                   3          2        2       2           2
+--R                              - 24C  - 1432A C  + (992B  - 712A )C + 352A B
+--R                            + 
+--R                                    3
+--R                              - 328A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3           2          3        2
+--R                              - 144B C  + 816A B C  + (- 320B  - 1776A B)C
+--R                            + 
+--R                                    3       3
+--R                              832A B  + 336A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4          2        2  3
+--R                              - 92C  + 100A C  + (- 488B  - 1208A )C
+--R                            + 
+--R                                       2        3  2
+--R                              (- 168A B  - 1560A )C
+--R                            + 
+--R                                   4        2 2       4          4       3 2
+--R                              (176B  + 1608A B  - 172A )C - 16A B  - 760A B
+--R                            + 
+--R                                   5
+--R                              - 12A
+--R                         *
+--R                            D
+--R                        + 
+--R                                5           4       3       2   3
+--R                          120B C  - 104A B C  + (16B  + 112A B)C
+--R                        + 
+--R                                  3       3   2         2 3       4         3 3
+--R                          (- 16A B  + 112A B)C  + (- 16A B  - 104A B)C + 16A B
+--R                        + 
+--R                              5
+--R                          120A B
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                 2                  3       2   3
+--R                          (288B C  + 960A B C - 320B  + 288A B)D
+--R                        + 
+--R                                    4          3           2       2  2
+--R                              - 236C  + 1264A C  + (- 1152B  + 696A )C
+--R                            + 
+--R                                       2       3         4       2 2       4
+--R                              (- 768A B  + 496A )C - 208B  - 384A B  + 276A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3        3        2   2
+--R                              280B C  - 608A B C  + (768B  + 2064A B)C
+--R                            + 
+--R                                        3      3         5       2 3      4
+--R                              (- 1280A B  - 96A B)C - 96B  + 256A B  + 24A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5      2       2  4          2       3  3
+--R                          24C  - 16A C  + (4B  + 232A )C  + (560A B  + 544A )C
+--R                        + 
+--R                                4       2 2       4  2
+--R                          (- 96B  - 936A B  + 232A )C
+--R                        + 
+--R                                 4       3 2      5        6      2 4     4 2
+--R                          (192A B  + 560A B  - 16A )C - 16B  - 96A B  + 4A B
+--R                        + 
+--R                             6
+--R                          24A
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                                      3            2        3       2
+--R                              - 128B C  - 1152A B C  + (768B  - 384A B)C
+--R                            + 
+--R                                    3       3
+--R                              256A B  - 384A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                  5         4        2       2  3         2 2
+--R                              224C  - 512A C  + (320B  - 320A )C  + 960A B C
+--R                            + 
+--R                                     2 2       4           4       3 2
+--R                              (- 576A B  - 416A )C + 384A B  + 832A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5          4          3       2   3
+--R                          - 96B C  + 32A B C  + (- 320B  - 448A B)C
+--R                        + 
+--R                                3       3   2       2 3      4          3 3
+--R                          (64A B  - 448A B)C  + (64A B  + 32A B)C - 320A B
+--R                        + 
+--R                               5
+--R                          - 96A B
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                   3       3 2       3          2 3        6
+--R                          (512A B C  - 512B C  + 512A B C - 512A B )D - 64C
+--R                        + 
+--R                               5        2      2  4            2       3  3
+--R                          64A C  + (128B  + 64A )C  + (- 512A B  - 128A )C
+--R                        + 
+--R                               4       2 2      4  2
+--R                          (256B  + 768A B  + 64A )C
+--R                        + 
+--R                                 4       3 2      5         2 4       4 2      6
+--R                        (- 256A B  - 512A B  + 64A )C + 256A B  + 128A B  - 64A
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                          6        5        2              2      2  4
+--R                      - 8D  + 24B D  + (- 8C  + 48A C - 24B  - 72A )D
+--R                    + 
+--R                           2               3      2   3
+--R                      (8B C  - 48A B C + 8B  + 72A B)D
+--R                 *
+--R                     8
+--R                    b
+--R                + 
+--R                                   5                      4
+--R                      (24C + 120A)D  + (- 144B C - 48A B)D
+--R                    + 
+--R                          3         2        2       2          2      3  3
+--R                      (40C  - 232A C  + (152B  + 312A )C - 72A B  + 72A )D
+--R                    + 
+--R                              3           2         3       2     2
+--R                      (- 32B C  + 192A B C  + (- 32B  - 288A B)C)D
+--R                 *
+--R                       7
+--R                    a b
+--R                + 
+--R                           6        5       2               2       2  4
+--R                      - 10D  - 78B D  + (28C  - 648A C + 84B  - 228A )D
+--R                    + 
+--R                             2                 3      2   3
+--R                      (332B C  + 312A B C - 20B  - 84A B)D
+--R                    + 
+--R                               4         3          2       2  2
+--R                          - 74C  + 408A C  + (- 324B  - 444A )C
+--R                        + 
+--R                                 2       3        4       2 2      4
+--R                          (120A B  - 360A )C + 22B  + 252A B  + 54A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3       3       2   2
+--R                          42B C  - 248A B C  + (44B  + 348A B)C
+--R                        + 
+--R                                 3      3        5      2 3      4
+--R                          (- 8A B  + 72A B)C + 2B  + 12A B  - 54A B
+--R                     *
+--R                        D
+--R                 *
+--R                     2 6
+--R                    a b
+--R                + 
+--R                                  5                     4
+--R                      (84C - 12A)D  + (414B C + 318A B)D
+--R                    + 
+--R                                3          2          2       2           2
+--R                          - 208C  + 1424A C  + (- 376B  + 912A )C - 216A B
+--R                        + 
+--R                              3
+--R                          304A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3           2        3       2            3
+--R                          - 356B C  - 780A B C  + (196B  + 468A B)C - 348A B
+--R                        + 
+--R                                3
+--R                          - 132A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5         4        2       2  3
+--R                          60C  - 308A C  + (272B  + 216A )C
+--R                        + 
+--R                                 2       3  2         4       2 2      4
+--R                          (144A B  + 536A )C  + (- 60B  - 912A B  - 84A )C
+--R                        + 
+--R                              4       3 2      5
+--R                          4A B  + 240A B  - 36A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4         3       2   3
+--R                      - 18B C  + 102A B C  + (- 20B  - 116A B)C
+--R                    + 
+--R                           3       3   2        5     2 3       4          5
+--R                      (4A B  - 116A B)C  + (- 2B  + 4A B  + 102A B)C - 2A B
+--R                    + 
+--R                           3 3      5
+--R                      - 20A B  - 18A B
+--R                 *
+--R                     3 5
+--R                    a b
+--R                + 
+--R                             2              2      2  4
+--R                      (- 290C  + 60A C - 60B  + 30A )D
+--R                    + 
+--R                               2                   3       2   3
+--R                      (- 880B C  - 1344A B C + 192B  - 528A B)D
+--R                    + 
+--R                              4          3        2        2  2
+--R                          340C  - 1584A C  + (612B  - 1416A )C
+--R                        + 
+--R                                 2       3        4      2 2       4
+--R                          (840A B  - 816A )C + 88B  + 36A B  - 300A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3          3       2   2         3
+--R                          168B C  + 832A B C  + (- 400B  - 624A B)C  + 832A B C
+--R                        + 
+--R                             5       2 3       4
+--R                          32B  + 144A B  + 264A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6        5         2      2  4
+--R                      - 18C  + 84A C  + (- 72B  - 14A )C
+--R                    + 
+--R                               2       3  3       4       2 2      4  2
+--R                      (- 224A B  - 232A )C  + (46B  + 720A B  - 14A )C
+--R                    + 
+--R                            4       3 2      5       6      2 4      4 2      6
+--R                    (- 36A B  - 224A B  + 84A )C + 4B  + 46A B  - 72A B  - 18A
+--R                 *
+--R                     4 4
+--R                    a b
+--R                + 
+--R                           3         2        2       2           2      3  3
+--R                      (528C  - 112A C  + (224B  - 144A )C + 288A B  - 16A )D
+--R                    + 
+--R                                3            2          3        2            3
+--R                          928B C  + 2208A B C  + (- 704B  + 1440A B)C - 192A B
+--R                        + 
+--R                              3
+--R                          672A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5         4          2        2  3
+--R                          - 240C  + 880A C  + (- 400B  + 1056A )C
+--R                        + 
+--R                                    2       3  2         4       2 2       4
+--R                          (- 1296A B  + 608A )C  + (- 96B  + 528A B  + 720A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 416A B  - 624A B  + 48A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4        3       2   3
+--R                      - 24B C  - 312A B C  + (224B  + 208A B)C
+--R                    + 
+--R                               3       3   2         5       2 3       4
+--R                      (- 416A B  + 208A B)C  + (- 32B  - 416A B  - 312A B)C
+--R                    + 
+--R                             5       3 3      5
+--R                      - 32A B  + 224A B  - 24A B
+--R                 *
+--R                     5 3
+--R                    a b
+--R                + 
+--R                                4        3          2       2  2
+--R                          - 536C  + 96A C  + (- 288B  + 240A )C
+--R                        + 
+--R                                   2      3         4       2 2      4
+--R                          (- 960A B  + 96A )C + 160B  - 288A B  - 24A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4            3        3        2   2
+--R                          - 480B C  - 1664A B C  + (896B  - 1344A B)C
+--R                        + 
+--R                                 3        3          5       2 3       4
+--R                          (256A B  - 1152A B)C + 128B  + 384A B  - 480A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6         5       2       2  4          2       3  3
+--R                      64C  - 192A C  + (72B  - 320A )C  + (736A B  - 128A )C
+--R                    + 
+--R                            4       2 2       4  2
+--R                      (- 32B  - 720A B  - 320A )C
+--R                    + 
+--R                           4       3 2       5        6      2 4      4 2      6
+--R                    (576A B  + 736A B  - 192A )C + 32B  - 32A B  + 72A B  + 64A
+--R                 *
+--R                     6 2
+--R                    a b
+--R                + 
+--R                              5        4        2       2  3
+--R                          288C  - 32A C  + (128B  - 192A )C
+--R                        + 
+--R                                  2      3  2          4       2 2      4
+--R                          (1152A B  - 64A )C  + (- 384B  + 384A B  - 96A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 128A B  + 384A B  + 96A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4          3       2   3
+--R                      96B C  + 480A B C  + (- 384B  + 448A B)C
+--R                    + 
+--R                               3       3   2          5       2 3       4
+--R                      (- 128A B  + 448A B)C  + (- 128B  - 128A B  + 480A B)C
+--R                    + 
+--R                              5       3 3      5
+--R                      - 128A B  - 384A B  + 96A B
+--R                 *
+--R                     7
+--R                    a b
+--R                + 
+--R                           6      2 4         2 3        4      4  2       3 2
+--R                      - 64C  + 64A C  - 512A B C  + (256B  + 64A )C  - 512A B C
+--R                    + 
+--R                          2 4      6
+--R                      256A B  - 64A
+--R                 *
+--R                     8
+--R                    a
+--R             *
+--R                x
+--R            + 
+--R                       4     3 3    7
+--R              (- 8A B D  - 4A D )a c
+--R            + 
+--R                      5         4  2
+--R                  (A D  + 2A B D )b
+--R                + 
+--R                         5             2     2  4               2   3     3   2
+--R                    (2B D  + (6A C + 4B  + 8A )D  + (8A B C + 6A B)D  + 6A C D )
+--R                 *
+--R                    a b
+--R                + 
+--R                          5                  4       2         2      3  3
+--R                      8A D  + (4B C - 32A B)D  + (12A C + 44A B  - 16A )D
+--R                    + 
+--R                         3   2        3 2     5
+--R                      12A B D  + (- 4A C  - 4A )D
+--R                 *
+--R                     2
+--R                    a
+--R             *
+--R                 6
+--R                c
+--R            + 
+--R                        5              2     2  4           3  3
+--R                  (- B D  + (- 4A C - B  - 2A )D  - 2A B C D )b
+--R                + 
+--R                                  5                     4
+--R                      (- 3C - 8A)D  + (- 12B C + 73A B)D
+--R                    + 
+--R                             2        2      2          2      3  3
+--R                      (- 2A C  + (- 4B  - 14A )C - 22A B  + 39A )D
+--R                    + 
+--R                           2        3   2        3 2     5
+--R                      (- 9A B C - 6A B)D  + (- 2A C  + 2A )D
+--R                 *
+--R                       2
+--R                    a b
+--R                + 
+--R                          6       5        2            2  4
+--R                      - 2D  - 6B D  + (- 2C  - 2A C - 2B )D
+--R                    + 
+--R                           2                3      2   3
+--R                      (4B C  - 68A B C - 22B  - 96A B)D
+--R                    + 
+--R                             3      2 2           2     3        2 2      4  2
+--R                      (- 4A C  - 18A C  + (- 42A B  + 8A )C - 18A B  - 22A )D
+--R                    + 
+--R                               3     2   2     3         4        3 3     5
+--R                      (- 8A B C  + 6A B C  - 4A B C + 10A B)D + 2A C  - 2A C
+--R                 *
+--R                     2
+--R                    a b
+--R                + 
+--R                                   5                   4
+--R                      (- 4C + 32A)D  + (16B C - 44A B)D
+--R                    + 
+--R                              2         2      2           2     3  3
+--R                      (- 12A C  + (- 28B  + 48A )C + 176A B  + 4A )D
+--R                    + 
+--R                             3      2           3      3   2
+--R                      (- 8B C  - 24A B C - 84A B  + 48A B)D
+--R                    + 
+--R                          2 3         2      3  2      4       3 2      5
+--R                      (12A C  + (12A B  - 16A )C  + 36A C - 20A B  - 16A )D
+--R                    + 
+--R                            4     3   2     5
+--R                      8A B C  + 4A B C  + 4A B
+--R                 *
+--R                     3
+--R                    a
+--R             *
+--R                 5
+--R                c
+--R            + 
+--R                               5                  4
+--R                      (C - 6A)D  + (4B C - 14A B)D
+--R                    + 
+--R                           2     2     2         2    3  3
+--R                      (3A C  + (B  + 2A )C + 2A B  - A )D
+--R                 *
+--R                     4
+--R                    b
+--R                + 
+--R                        6       5       2              2      2  4
+--R                      4D  - 6B D  + (10C  - 39A C - 24B  - 57A )D
+--R                    + 
+--R                           2                3     2   3
+--R                      (6B C  - 34A B C + 10B  - 6A B)D
+--R                    + 
+--R                             3     2 2         2      3       2 2     4  2
+--R                      (- 4A C  + 9A C  + (15A B  - 44A )C + 9A B  + 7A )D
+--R                    + 
+--R                             3     2   2     3        4
+--R                      (2A B C  + 3A B C  + 4A B C - 5A B)D
+--R                 *
+--R                       3
+--R                    a b
+--R                + 
+--R                                  5                      4
+--R                      (12C - 77A)D  + (- 27B C + 196A B)D
+--R                    + 
+--R                            3        2       2     2           2       3  3
+--R                      (- 10C  + 60A C  + (72B  - 4A )C - 297A B  + 118A )D
+--R                    + 
+--R                                  3           2       3       2           3
+--R                            - 4B C  + 120A B C  + (21B  + 126A B)C + 72A B
+--R                          + 
+--R                                 3
+--R                            - 76A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4      2     2  3         2      3  2
+--R                          13A C  + (4B  + 8A )C  + (24A B  + 29A )C
+--R                        + 
+--R                             2 2      4       3 2      5
+--R                          (6A B  - 14A )C + 4A B  + 40A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4     2   3     3   2     4
+--R                      - 2A B C  - 3A B C  - 4A B C  + 5A B C
+--R                 *
+--R                     2 2
+--R                    a b
+--R                + 
+--R                        6        5        2              2      2  4
+--R                      2D  - 24B D  + (- 6C  + 20A C + 28B  - 10A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (90B C  - 76A B C - 24B  - 226A B)D
+--R                    + 
+--R                             4        3       2      2  2          2      3
+--R                          12C  + 22A C  + (30B  - 42A )C  + (108A B  + 14A )C
+--R                        + 
+--R                             4       2 2      4
+--R                          42B  + 282A B  - 94A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4          3        3      2   2
+--R                          18B C  - 84A B C  + (- 6B  + 24A B)C
+--R                        + 
+--R                                3      3         2 3      4
+--R                          (36A B  - 36A B)C + 30A B  + 54A B
+--R                     *
+--R                        D
+--R                    + 
+--R                             5        2      2  4           2     3  3     2 2 2
+--R                      - 10A C  + (- 4B  - 14A )C  + (- 30A B  + 4A )C  - 6A B C
+--R                    + 
+--R                           3 2      5        4 2     6
+--R                      (- 6A B  - 10A )C - 10A B  - 2A
+--R                 *
+--R                     3
+--R                    a b
+--R                + 
+--R                                   5                   4
+--R                      (- 16C + 8A)D  + (40B C - 48A B)D
+--R                    + 
+--R                          3        2          2      2           2      3  3
+--R                      (12C  - 48A C  + (- 112B  - 12A )C + 104A B  + 80A )D
+--R                    + 
+--R                              3          2       3      2            3     3   2
+--R                      (- 32B C  + 12A B C  + (72B  - 96A B)C - 336A B  + 4A B)D
+--R                    + 
+--R                                 4      2      2  3         2      3  2
+--R                          - 20A C  + (4B  + 48A )C  + (48A B  - 96A )C
+--R                        + 
+--R                              2 2       4          4      3 2      5
+--R                          (12A B  + 144A )C + 64A B  - 80A B  - 12A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5          4      2   3           3      3   2
+--R                      - 12B C  + 32A B C  - 48A B C  + (- 12A B  + 16A B)C
+--R                    + 
+--R                           4         3 3      5
+--R                      - 36A B C + 12A B  + 16A B
+--R                 *
+--R                     4
+--R                    a
+--R             *
+--R                 4
+--R                c
+--R            + 
+--R                         6       5        2             2      2  4
+--R                      - D  + 5B D  + (- 3C  + 26A C + 5B  + 13A )D
+--R                    + 
+--R                             2              3     2   3
+--R                      (- 3B C  + 10A B C - B  - 3A B)D
+--R                 *
+--R                     5
+--R                    b
+--R                + 
+--R                                 5                    4
+--R                      (2C + 73A)D  + (62B C - 213A B)D
+--R                    + 
+--R                           3       2        2      2           2       3  3
+--R                      (- 3C  - 2A C  + (- 2B  + 62A )C + 123A B  - 155A )D
+--R                    + 
+--R                           3          2        3      2           3      3   2
+--R                      (4B C  - 27A B C  + (- 6B  + 24A B)C - 15A B  + 31A B)D
+--R                    + 
+--R                                4       2     2  3          2      3  2
+--R                          - 2A C  + (- B  - 5A )C  + (- 9A B  + 13A )C
+--R                        + 
+--R                               2 2    4       3 2      5
+--R                          (- 6A B  + A )C + 2A B  - 15A
+--R                     *
+--R                        D
+--R                 *
+--R                       4
+--R                    a b
+--R                + 
+--R                        6        5       2              2      2  4
+--R                      4D  + 67B D  + (23C  + 23A C + 17B  + 67A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 110B C  + 304A B C + 113B  + 663A B)D
+--R                    + 
+--R                            4        3         2     2  2        2      3
+--R                          8C  - 68A C  + (- 66B  + 6A )C  + (9A B  - 15A )C
+--R                        + 
+--R                               4       2 2       4
+--R                          - 33B  - 108A B  + 191A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4         3         3       2   2
+--R                          - 15B C  + 8A B C  + (- 13B  - 123A B)C
+--R                        + 
+--R                                  3      3         2 3       4
+--R                          (- 48A B  + 40A B)C - 16A B  - 102A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          5     2     2  4        2      3  3      2 2    4  2
+--R                      2A C  + (B  + 5A )C  + (9A B  - 13A )C  + (6A B  - A )C
+--R                    + 
+--R                           3 2      5
+--R                      (- 2A B  + 15A )C
+--R                 *
+--R                     2 3
+--R                    a b
+--R                + 
+--R                                   5                      4
+--R                      (56C - 106A)D  + (- 194B C - 18A B)D
+--R                    + 
+--R                            3        2       2       2           2       3  3
+--R                      (- 86C  - 85A C  + (90B  - 174A )C - 594A B  - 207A )D
+--R                    + 
+--R                                 3           2          3       2            3
+--R                          - 83B C  - 138A B C  + (- 198B  - 333A B)C + 418A B
+--R                        + 
+--R                                3
+--R                          - 438A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5        4         2      2  3
+--R                          - 23C  + 62A C  + (- 22B  - 60A )C
+--R                        + 
+--R                                  2      3  2         4       2 2       4
+--R                          (- 99A B  + 66A )C  + (- 18B  - 246A B  - 349A )C
+--R                        + 
+--R                                 4       3 2      5
+--R                          - 76A B  + 111A B  + 16A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5         4       3      2   3         3      3   2
+--R                      12B C  + 3A B C  + (15B  + 90A B)C  + (42A B  - 28A B)C
+--R                    + 
+--R                         2 3      4        3 3      5
+--R                      (9A B  + 42A B)C + 6A B  - 23A B
+--R                 *
+--R                     3 2
+--R                    a b
+--R                + 
+--R                         6        5         2                2       2  4
+--R                      24D  - 32B D  + (- 82C  + 108A C + 144B  + 134A )D
+--R                    + 
+--R                            2                 3       2   3
+--R                      (80B C  + 352A B C - 32B  + 160A B)D
+--R                    + 
+--R                            4         3       2 2          2       3        4
+--R                          4C  + 152A C  - 132B C  + (216A B  + 312A )C + 56B
+--R                        + 
+--R                              2 2      4
+--R                          732A B  - 20A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3         3       2   2
+--R                          112B C  - 144A B C  + (- 48B  + 240A B)C
+--R                        + 
+--R                                  3      3         5       2 3      4
+--R                          (- 96A B  - 16A B)C - 32B  - 256A B  + 96A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6       5       2      2  4        2      3  3
+--R                      14C  - 4A C  + (36B  + 18A )C  + (8A B  + 40A )C
+--R                    + 
+--R                         4       2 2      4  2          4     3 2      5
+--R                      (6B  + 144A B  + 34A )C  + (- 4A B  + 8A B  + 28A )C
+--R                    + 
+--R                           2 4      4 2     6
+--R                      - 18A B  - 36A B  - 2A
+--R                 *
+--R                     4
+--R                    a b
+--R                + 
+--R                                    5                   4
+--R                      (- 16C - 96A)D  + (96B C + 48A B)D
+--R                    + 
+--R                          3          2       2           2      3  3
+--R                      (48C  + (- 160B  - 240A )C - 288A B  + 64A )D
+--R                    + 
+--R                              2       3          3       3   2
+--R                      (48A B C  + 288B C - 160A B  - 176A B)D
+--R                    + 
+--R                             5        4       2       2  3       3 2
+--R                          16C  - 80A C  + (16B  + 160A )C  - 320A C
+--R                        + 
+--R                                4      2 2      4           4      5
+--R                          (- 80B  + 48A B  + 80A )C + 256A B  + 16A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5          4       2   3           3       3   2
+--R                      - 48B C  + 80A B C  - 192A B C  + (- 48A B  + 160A B)C
+--R                    + 
+--R                            4           5      3 3      5
+--R                      - 144A B C - 16A B  + 48A B  + 16A B
+--R                 *
+--R                     5
+--R                    a
+--R             *
+--R                 3
+--R                c
+--R            + 
+--R                                  5                     4
+--R                      (- 2C + 6A)D  + (- 20B C + 28A B)D
+--R                    + 
+--R                         3        2        2      2          2      3  3
+--R                      (2C  - 18A C  + (- 2B  - 10A )C - 10A B  + 10A )D
+--R                 *
+--R                     6
+--R                    b
+--R                + 
+--R                           6        5         2              2      2  4
+--R                      - 16D  - 26B D  + (- 46C  + 22A C + 34B  + 94A )D
+--R                    + 
+--R                             2                3      2   3
+--R                      (- 6B C  + 28A B C - 46B  - 96A B)D
+--R                    + 
+--R                              4        3       2      2  2           2       3
+--R                          - 4C  + 46A C  + (12B  - 24A )C  + (- 30A B  + 102A )C
+--R                        + 
+--R                            4      2 2      4
+--R                          6B  - 12A B  - 48A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              4         3      3     2   2         3      3
+--R                          2B C  + 4A B C  + (4B  + 6A B)C  + (12A B  - 24A B)C
+--R                        + 
+--R                            2 3      4
+--R                          2A B  + 36A B
+--R                     *
+--R                        D
+--R                 *
+--R                       5
+--R                    a b
+--R                + 
+--R                                      5                    4
+--R                      (- 109C + 110A)D  + (14B C - 254A B)D
+--R                    + 
+--R                          3         2          2       2           2       3  3
+--R                      (82C  - 100A C  + (- 278B  - 256A )C + 412A B  - 176A )D
+--R                    + 
+--R                                3           2       3       2            3
+--R                          126B C  - 282A B C  + (38B  - 312A B)C - 214A B
+--R                        + 
+--R                              3
+--R                          222A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5        4       2      2  3         2      3  2
+--R                          11C  - 60A C  + (30B  + 12A )C  + (24A B  - 48A )C
+--R                        + 
+--R                              4       2 2       4          4      3 2      5
+--R                          (23B  + 168A B  + 117A )C + 34A B  + 12A B  - 72A
+--R                     *
+--R                        D
+--R                    + 
+--R                            5         4        3     2   3
+--R                      - 2B C  - 4A B C  + (- 4B  - 6A B)C
+--R                    + 
+--R                              3      3   2        2 3      4
+--R                      (- 12A B  + 24A B)C  + (- 2A B  - 36A B)C
+--R                 *
+--R                     2 4
+--R                    a b
+--R                + 
+--R                           6        5        2             2       2  4
+--R                      - 65D  + 63B D  + (178C  + A C - 236B  - 113A )D
+--R                    + 
+--R                            2                3       2   3
+--R                      (48B C  - 68A B C + 40B  + 186A B)D
+--R                    + 
+--R                             4        3        2       2  2
+--R                          71C  - 52A C  + (432B  + 414A )C
+--R                        + 
+--R                                   2      3         4        2 2       4
+--R                          (- 120A B  + 74A )C - 139B  - 1278A B  + 369A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4           3        3       2   2
+--R                          - 83B C  + 452A B C  + (158B  + 168A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (140A B  + 548A B)C + 33B  + 168A B  - 109A B
+--R                     *
+--R                        D
+--R                    + 
+--R                          6        5         2      2  4         2      3  3
+--R                      - 8C  + 29A C  + (- 32B  + 13A )C  + (14A B  - 44A )C
+--R                    + 
+--R                            4       2 2      4  2           4     3 2     5
+--R                      (- 20B  - 144A B  - 24A )C  + (- 17A B  - 4A B  + 7A )C
+--R                    + 
+--R                       2 4      4 2      6
+--R                      A B  + 58A B  + 11A
+--R                 *
+--R                     3 3
+--R                    a b
+--R                + 
+--R                                    5                      4
+--R                      (138C + 222A)D  + (- 90B C - 282A B)D
+--R                    + 
+--R                          3         2        2       2           2       3  3
+--R                      (92C  - 174A C  + (576B  + 348A )C + 672A B  - 458A )D
+--R                    + 
+--R                               3           2          3       2            3
+--R                          94B C  + 180A B C  + (- 360B  - 222A B)C + 592A B
+--R                        + 
+--R                             3
+--R                          44A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5        4          2       2  3
+--R                          - 116C  + 66A C  + (- 180B  - 396A )C
+--R                        + 
+--R                                2       3  2        4       2 2       4
+--R                          (30A B  + 544A )C  + (198B  + 156A B  - 304A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 206A B  + 650A B  - 82A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5           4         3      2   3
+--R                      6B C  - 256A B C  + (- 86B  + 48A B)C
+--R                    + 
+--R                              3       3   2      5      2 3       4           5
+--R                      (- 20A B  - 396A B)C  + (2B  - 26A B  + 218A B)C + 26A B
+--R                    + 
+--R                           3 3      5
+--R                      - 44A B  - 36A B
+--R                 *
+--R                     4 2
+--R                    a b
+--R                + 
+--R                         6        5          2                2      2  4
+--R                      24D  - 96B D  + (- 132C  - 216A C + 120B  + 60A )D
+--R                    + 
+--R                               2                  3       2   3
+--R                      (- 240B C  + 288A B C - 224B  + 240A B)D
+--R                    + 
+--R                                4         3          2       2  2
+--R                          - 192C  + 160A C  + (- 408B  - 576A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 816A B  + 448A )C - 24B  - 504A B  + 256A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3        3       2   2
+--R                          48B C  - 256A B C  + (208B  + 192A B)C
+--R                        + 
+--R                                  3       3         5       2 3       4
+--R                          (- 32A B  - 320A B)C - 32B  - 816A B  - 112A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6       5       2      2  4         2      3  3
+--R                      28C  - 8A C  + (80B  + 68A )C  + (32A B  - 80A )C
+--R                    + 
+--R                          4       2 2      4  2         4       3 2      5
+--R                      (28B  + 192A B  - 92A )C  + (40A B  - 160A B  + 88A )C
+--R                    + 
+--R                        6      2 4      4 2     6
+--R                      8B  + 60A B  - 16A B  - 4A
+--R                 *
+--R                     5
+--R                    a b
+--R                + 
+--R                             5                    4
+--R                      - 96A D  + (96B C + 384A B)D
+--R                    + 
+--R                             2          2       2           2      3  3
+--R                      (192A C  + (- 192B  - 192A )C - 384A B  - 64A )D
+--R                    + 
+--R                             3        3       2            3       3   2
+--R                      (128B C  + (320B  + 384A B)C + 704A B  - 192A B)D
+--R                    + 
+--R                             5         4       2 3            2       3  2
+--R                          64C  - 160A C  + 448A C  + (- 192A B  - 256A )C
+--R                        + 
+--R                                 4       4           4       3 2      5
+--R                          (- 320B  - 256A )C + 160A B  + 320A B  + 32A
+--R                     *
+--R                        D
+--R                    + 
+--R                             5           4       2   3       3   2
+--R                      - 32B C  + 192A B C  - 320A B C  + 576A B C
+--R                    + 
+--R                          5       4           5
+--R                      (32B  - 160A B)C - 64A B
+--R                 *
+--R                     6
+--R                    a
+--R             *
+--R                 2
+--R                c
+--R            + 
+--R                        6       5       2             2      2  4
+--R                      4D  - 4B D  + (12C  - 40A C - 4B  - 20A )D
+--R                    + 
+--R                            2              3      2   3
+--R                      (12B C  - 8A B C + 4B  + 12A B)D
+--R                 *
+--R                     7
+--R                    b
+--R                + 
+--R                                   5                      4
+--R                      (59C - 145A)D  + (- 28B C + 224A B)D
+--R                    + 
+--R                          3        2       2      2           2       3  3
+--R                      (10C  + 34A C  + (66B  - 30A )C - 146A B  + 250A )D
+--R                    + 
+--R                              3          2      3      2           3      3   2
+--R                      (- 36B C  + 48A B C  + (4B  - 12A B)C + 40A B  - 48A B)D
+--R                    + 
+--R                             5       4        2      2  3        2      3  2
+--R                          - C  + 3A C  + (- 6B  + 10A )C  + (6A B  - 30A )C
+--R                        + 
+--R                               4     2 2     4         4      3 2      5
+--R                          (- 5B  - 6A B  - 9A )C - 5A B  - 18A B  + 27A
+--R                     *
+--R                        D
+--R                 *
+--R                       6
+--R                    a b
+--R                + 
+--R                         6        5         2              2       2  4
+--R                      78D  - 54B D  + (- 23C  - 15A C + 60B  - 156A )D
+--R                    + 
+--R                             2                 3       2   3
+--R                      (180B C  - 188A B C - 92B  - 924A B)D
+--R                    + 
+--R                                4         3         2      2  2
+--R                          - 108C  + 142A C  + (- 78B  + 66A )C
+--R                        + 
+--R                                 2       3        4       2 2       4
+--R                          (186A B  - 186A )C + 86B  + 540A B  - 450A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4          3         3       2   2
+--R                          18B C  - 44A B C  + (- 52B  + 156A B)C
+--R                        + 
+--R                                  3       3         5      2 3       4
+--R                          (- 20A B  - 324A B)C - 14B  - 68A B  + 162A B
+--R                     *
+--R                        D
+--R                    + 
+--R                       6       5      2      2  4          2      3  3
+--R                      C  - 3A C  + (6B  - 10A )C  + (- 6A B  + 30A )C
+--R                    + 
+--R                         4     2 2     4  2        4      3 2      5
+--R                      (5B  + 6A B  + 9A )C  + (5A B  + 18A B  - 27A )C
+--R                 *
+--R                     2 5
+--R                    a b
+--R                + 
+--R                                    5                     4
+--R                      (- 77C - 89A)D  + (379B C + 883A B)D
+--R                    + 
+--R                                  3         2          2       2          2
+--R                            - 222C  + 542A C  + (- 114B  + 570A )C + 50A B
+--R                          + 
+--R                                3
+--R                            998A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3           2        3        2            3
+--R                          - 322B C  - 102A B C  + (318B  + 1602A B)C - 190A B
+--R                        + 
+--R                              3
+--R                          862A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4         2      2  3
+--R                          123C  - 173A C  + (- 42B  + 42A )C
+--R                        + 
+--R                                   2       3  2          4      2 2       4
+--R                          (- 354A B  - 366A )C  + (- 161B  + 30A B  + 523A )C
+--R                        + 
+--R                               4       3 2       5
+--R                          55A B  - 722A B  + 203A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4       3       2   3
+--R                      3B C  + 15A B C  + (34B  - 130A B)C
+--R                    + 
+--R                             3       3   2      5      2 3      4          5
+--R                      (- 6A B  + 246A B)C  + (7B  + 46A B  - 97A B)C - 5A B
+--R                    + 
+--R                           3 3      5
+--R                      - 34A B  + 27A B
+--R                 *
+--R                     3 4
+--R                    a b
+--R                + 
+--R                           6        5          2               2       2  4
+--R                      - 62D  + 76B D  + (- 238C  + 28A C - 386B  - 346A )D
+--R                    + 
+--R                               2                   3        2   3
+--R                      (- 576B C  - 2048A B C + 204B  - 1236A B)D
+--R                    + 
+--R                              4         3        2       2  2
+--R                          206C  - 664A C  + (108B  - 132A )C
+--R                        + 
+--R                                  2        3        4       2 2       4
+--R                          (- 36A B  - 2012A )C + 10B  + 108A B  - 830A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4           3          3        2   2
+--R                          76B C  + 384A B C  + (- 212B  - 1188A B)C
+--R                        + 
+--R                                   3        3         5       2 3       4
+--R                          (- 288A B  - 1088A B)C + 40B  + 888A B  - 488A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6        5       2      2  4          2       3  3
+--R                      - 38C  + 40A C  + (38B  - 18A )C  + (276A B  + 148A )C
+--R                    + 
+--R                          4       2 2      4  2        4       3 2       5
+--R                      (46B  - 156A B  + 50A )C  + (8A B  + 144A B  - 204A )C
+--R                    + 
+--R                           6      2 4      4 2      6
+--R                      - 10B  - 14A B  + 26A B  - 10A
+--R                 *
+--R                     4 3
+--R                    a b
+--R                + 
+--R                                     5           4
+--R                      (- 24C + 384A)D  - 624A B D
+--R                    + 
+--R                           3         2        2        2            2       3  3
+--R                      (472C  - 252A C  + (744B  + 1368A )C + 1272A B  + 252A )D
+--R                    + 
+--R                                3            2          3        2             3
+--R                          380B C  + 1128A B C  + (- 600B  + 1428A B)C - 1016A B
+--R                        + 
+--R                               3
+--R                          1272A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               5         4          2       2  3
+--R                          - 12C  + 496A C  + (- 104B  - 512A )C
+--R                        + 
+--R                                 2        3  2        4       2 2       4
+--R                          (252A B  + 1160A )C  + (288B  + 600A B  + 972A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 248A B  + 276A B  + 72A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4         3       2   3
+--R                      56B C  - 180A B C  + (- 44B  + 648A B)C
+--R                    + 
+--R                            3       3   2         5      2 3       4           5
+--R                      (24A B  - 384A B)C  + (- 72B  - 52A B  + 512A B)C + 24A B
+--R                    + 
+--R                            3 3      5
+--R                      - 216A B  - 12A B
+--R                 *
+--R                     5 2
+--R                    a b
+--R                + 
+--R                             5        2               2       2  4
+--R                      - 96B D  + (264C  - 528A C + 96B  - 312A )D
+--R                    + 
+--R                                      3  3
+--R                      (192A B C - 160B )D
+--R                    + 
+--R                                4         3         2        2  2
+--R                          - 272C  + 480A C  + (- 48B  - 1248A )C
+--R                        + 
+--R                                   2       3        4        2 2       4
+--R                          (- 960A B  - 352A )C + 96B  - 1296A B  + 176A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                  4          3        3      2   2
+--R                          - 256B C  - 64A B C  + (576B  + 96A B)C
+--R                        + 
+--R                                 3       3         5       2 3       4
+--R                          (896A B  - 640A B)C + 64B  + 128A B  - 352A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5         2      2  4
+--R                      - 24C  - 112A C  + (- 80B  + 88A )C
+--R                    + 
+--R                               2       3  3          4       2 2       4  2
+--R                      (- 288A B  - 192A )C  + (- 120B  - 192A B  - 296A )C
+--R                    + 
+--R                               4       3 2      5         2 4       4 2      6
+--R                      (- 112A B  - 288A B  + 48A )C + 296A B  + 208A B  - 24A
+--R                 *
+--R                     6
+--R                    a b
+--R                + 
+--R                              4
+--R                      384A B D
+--R                    + 
+--R                                  3         2          2       2           2
+--R                            - 192C  + 192A C  + (- 192B  + 192A )C - 384A B
+--R                          + 
+--R                                 3
+--R                            - 64A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                3           2        3       2            3
+--R                          128B C  - 192A B C  + (128B  + 384A B)C + 704A B
+--R                        + 
+--R                               3
+--R                          - 64A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                             5         4         2       2  3
+--R                          64C  - 320A C  + (- 64B  + 448A )C
+--R                        + 
+--R                                   2       3  2          4       2 2       4
+--R                          (- 192A B  + 256A )C  + (- 320B  - 192A B  - 256A )C
+--R                        + 
+--R                                  4       3 2      5
+--R                          - 384A B  + 320A B  + 64A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4       2   3          3       3   2
+--R                      64B C  + 192A B C  - 512A B C  + (192A B  + 576A B)C
+--R                    + 
+--R                           5      4           5       3 3
+--R                      (128B  - 64A B)C - 64A B  - 192A B
+--R                 *
+--R                     7
+--R                    a
+--R             *
+--R                c
+--R            + 
+--R                              5                   4
+--R                  (- 8C + 8A)D  + (16B C - 16A B)D
+--R                + 
+--R                       3        2        2     2         2      3  3
+--R                  (- 8C  + 24A C  + (- 8B  + 8A )C + 8A B  - 24A )D
+--R             *
+--R                 8
+--R                b
+--R            + 
+--R                       6        5        2              2     2  4
+--R                  - 14D  + 34B D  + (- 4C  + 96A C - 36B  - 4A )D
+--R                + 
+--R                          2                3       2   3
+--R                  (- 60B C  - 56A B C + 28B  + 108A B)D
+--R                + 
+--R                         4        3       2      2  2      3       4      2 2
+--R                      26C  - 80A C  + (12B  + 12A )C  - 48A C - 14B  - 36A B
+--R                    + 
+--R                         4
+--R                      90A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                          4         3      3      2   2          3      3
+--R                      2B C  - 8A B C  + (4B  - 12A B)C  + (- 8A B  + 72A B)C
+--R                    + 
+--R                        5      2 3      4
+--R                      2B  + 12A B  - 54A B
+--R                 *
+--R                    D
+--R             *
+--R                   7
+--R                a b
+--R            + 
+--R                                 5                       4
+--R                  (- 20C + 194A)D  + (- 122B C - 352A B)D
+--R                + 
+--R                      3         2        2       2           2       3  3
+--R                  (32C  - 276A C  + (136B  + 176A )C + 116A B  - 388A )D
+--R                + 
+--R                        3           2         3      2           3       3   2
+--R                  (84B C  + 216A B C  + (- 84B  - 36A B)C - 16A B  - 192A B)D
+--R                + 
+--R                           5        4      2 3         2       3  2
+--R                      - 28C  + 90A C  - 56A C  + (36A B  + 156A )C
+--R                    + 
+--R                          4       2 2       4         4       3 2      5
+--R                      (28B  - 144A B  - 108A )C - 6A B  + 180A B  - 54A
+--R                 *
+--R                    D
+--R                + 
+--R                        5         4        3      2   3        3      3   2
+--R                  - 2B C  + 8A B C  + (- 4B  + 12A B)C  + (8A B  - 72A B)C
+--R                + 
+--R                       5      2 3      4
+--R                  (- 2B  - 12A B  + 54A B)C
+--R             *
+--R                 2 6
+--R                a b
+--R            + 
+--R                       6         5        2                2       2  4
+--R                  - 22D  - 116B D  + (110C  - 498A C + 222B  + 248A )D
+--R                + 
+--R                        2                 3        2   3
+--R                  (72B C  + 760A B C - 72B  + 1152A B)D
+--R                + 
+--R                        4         3          2       2  2            2       3
+--R                      6C  + 268A C  + (- 276B  - 696A )C  + (- 540A B  + 764A )C
+--R                    + 
+--R                           4       2 2       4
+--R                      - 10B  - 168A B  + 442A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                             4           3       3      2   2
+--R                      - 28B C  - 328A B C  + (72B  - 48A B)C
+--R                    + 
+--R                             3       3        5       2 3       4
+--R                      (184A B  + 248A B)C - 4B  - 160A B  + 124A B
+--R                 *
+--R                    D
+--R                + 
+--R                     6        5        2      2  4           2      3  3
+--R                  10C  - 34A C  + (- 2B  + 32A )C  + (- 52A B  - 60A )C
+--R                + 
+--R                        4       2 2      4  2          4       3 2      5
+--R                  (- 10B  + 168A B  - 30A )C  + (- 2A B  - 100A B  + 94A )C
+--R                + 
+--R                    6      2 4      4 2      6
+--R                  2B  + 16A B  - 62A B  - 12A
+--R             *
+--R                 3 5
+--R                a b
+--R            + 
+--R                                5                    4
+--R                  (178C - 490A)D  + (70B C + 110A B)D
+--R                + 
+--R                        3         2          2        2            2       3  3
+--R                  (- 60C  + 684A C  + (- 572B  - 1564A )C - 1252A B  - 348A )D
+--R                + 
+--R                              3           2        3        2            3
+--R                        132B C  - 156A B C  + (356B  - 1980A B)C + 404A B
+--R                      + 
+--R                               3
+--R                        - 1252A B
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                           5         4        2       2  3          2       3  2
+--R                      - 46C  - 146A C  + (332B  + 844A )C  + (756A B  - 356A )C
+--R                    + 
+--R                            4       2 2       4          4      3 2       5
+--R                      (- 38B  + 204A B  - 654A )C + 30A B  - 36A B  - 122A
+--R                 *
+--R                    D
+--R                + 
+--R                         5           4         3      2   3
+--R                  - 10B C  + 182A B C  + (- 12B  - 92A B)C
+--R                + 
+--R                           3       3   2      5      2 3       4           5
+--R                  (- 124A B  + 156A B)C  + (6B  - 60A B  - 298A B)C - 18A B
+--R                + 
+--R                      3 3      5
+--R                  220A B  + 30A B
+--R             *
+--R                 4 4
+--R                a b
+--R            + 
+--R                     6         5          2                2       2  4
+--R                  72D  + 244B D  + (- 268C  + 1308A C - 12B  + 440A )D
+--R                + 
+--R                         2                  3       2   3
+--R                  (240B C  + 880A B C + 224B  - 120A B)D
+--R                + 
+--R                           4         3        2        2  2
+--R                      - 96C  - 704A C  + (264B  + 2400A )C
+--R                    + 
+--R                              2        3        4        2 2      4
+--R                      (2160A B  + 1256A )C - 40B  + 1632A B  + 40A
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                              4           3          3       2   2
+--R                      - 148B C  - 496A B C  + (- 648B  + 528A B)C
+--R                    + 
+--R                               3        3         5       2 3       4
+--R                      (- 752A B  + 1520A B)C - 52B  - 304A B  + 772A B
+--R                 *
+--R                    D
+--R                + 
+--R                     6        5          2       2  4            2      3  3
+--R                  20C  + 44A C  + (- 140B  - 304A )C  + (- 328A B  - 16A )C
+--R                + 
+--R                      4       2 2       4  2          4       3 2     5        6
+--R                  (44B  - 264A B  + 252A )C  + (148A B  + 416A B  + 4A )C + 12B
+--R                + 
+--R                        2 4      4 2      6
+--R                  - 224A B  - 20A B  + 64A
+--R             *
+--R                 5 3
+--R                a b
+--R            + 
+--R                                 5                       4
+--R                  (- 312C + 72A)D  + (- 504B C - 552A B)D
+--R                + 
+--R                      3          2         2       2           2      3  3
+--R                  (48C  - 1512A C  + (- 96B  - 432A )C + 432A B  + 40A )D
+--R                + 
+--R                              3            2          3        2            3
+--R                      - 216B C  - 1488A B C  + (- 400B  - 1224A B)C - 928A B
+--R                    + 
+--R                            3
+--R                      - 112A B
+--R                 *
+--R                     2
+--R                    D
+--R                + 
+--R                          5         4        2        2  3
+--R                      128C  + 376A C  + (272B  - 1328A )C
+--R                    + 
+--R                               2        3  2        4        2 2      4
+--R                      (- 792A B  - 1136A )C  + (280B  - 1488A B  - 48A )C
+--R                    + 
+--R                            4        3 2       5
+--R                      360A B  - 1224A B  - 104A
+--R                 *
+--R                    D
+--R                + 
+--R                       5          4        3       2   3          3       3   2
+--R                  56B C  + 80A B C  + (376B  + 592A B)C  + (464A B  - 624A B)C
+--R                + 
+--R                        5      2 3       4           5       3 3       5
+--R                  (- 24B  + 72A B  - 232A B)C + 72A B  - 208A B  - 192A B
+--R             *
+--R                 6 2
+--R                a b
+--R            + 
+--R                       2              2       2  4
+--R                  (432C  - 96A C + 96B  - 144A )D
+--R                + 
+--R                         2                  2   3
+--R                  (288B C  + 576A B C + 480A B)D
+--R                + 
+--R                      4          3      2 2       3       4       2 2      4  2
+--R                  (64C  + 1056A C  - 96A C  - 352A C + 64B  + 192A B  - 32A )D
+--R                + 
+--R                             4           3       3        2   2
+--R                      - 96B C  + 832A B C  + (32B  + 1152A B)C
+--R                    + 
+--R                             3       3          2 3      4
+--R                      (576A B  + 320A B)C + 992A B  - 32A B
+--R                 *
+--R                    D
+--R                + 
+--R                       6        5          2       2  4            2       3  3
+--R                  - 48C  - 64A C  + (- 128B  + 272A )C  + (- 160A B  + 256A )C
+--R                + 
+--R                         4      2 2      4  2            4       3 2      5
+--R                  (- 304B  + 96A B  + 48A )C  + (- 416A B  + 224A B  + 64A )C
+--R                + 
+--R                       6       2 4       4 2      6
+--R                  - 32B  + 208A B  + 352A B  - 16A
+--R             *
+--R                 7
+--R                a b
+--R            + 
+--R                         3       2          2  3
+--R                  (- 192C  + 192A C - 384A B )D
+--R                + 
+--R                             2       3       3   2
+--R                  (- 192A B C  + 128B C - 64A B)D
+--R                + 
+--R                           4      2 3       3 2       2 2          4      5
+--R                  (- 320A C  - 64B C  + 256A C  - 192A B C - 384A B  + 64A )D
+--R                + 
+--R                       5       2   3         3 2        5      4          3 3
+--R                  64B C  - 512A B C  + 192A B C  + (128B  - 64A B)C - 192A B
+--R             *
+--R                 8
+--R                a
+--R     + 
+--R                                 +-----------------+
+--R                                 |          2     2                 2
+--R           (4D b + (- 4C - 4A)a)\|- 4a c + b  + 8a   - 8D a c + 4D b
+--R         + 
+--R                                 2
+--R           (- 4C - 4A)a b + 16B a
+--R      *
+--R          +---------------------------------------+
+--R          |  +-----------------+
+--R          |  |          2     2            2     2
+--R         \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R                        +-----------------+
+--R                        |          2     2
+--R                       \|- 4a c + b  + 8a   + 4a x + b
+--R         atan(------------------------------------------------)
+--R                   +-----------------------------------------+
+--R                   |    +-----------------+
+--R               +-+ |    |          2     2            2     2
+--R              \|2 \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R     + 
+--R                                 +-----------------+
+--R                                 |          2     2                 2
+--R           (- 4D b + (4C + 4A)a)\|- 4a c + b  + 8a   - 8D a c + 4D b
+--R         + 
+--R                                 2
+--R           (- 4C - 4A)a b + 16B a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------------+
+--R          |    |          2     2            2     2
+--R         \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R                       +-----------------+
+--R                       |          2     2
+--R                      \|- 4a c + b  + 8a   - 4a x - b
+--R         atan(----------------------------------------------)
+--R                   +---------------------------------------+
+--R                   |  +-----------------+
+--R               +-+ |  |          2     2            2     2
+--R              \|2 \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R     + 
+--R                      +-----------------+
+--R                  +-+ |          2     2                         +-+
+--R             (- D\|2 \|- 4a c + b  + 8a   + (- D b + (2C - 2A)a)\|2 )
+--R          *
+--R                   +-----------------+
+--R                   |          2     2        2
+--R             log(x\|- 4a c + b  + 8a   + 2a x  + b x + 2a)
+--R         + 
+--R                      +-----------------+
+--R                  +-+ |          2     2                         +-+
+--R             (- D\|2 \|- 4a c + b  + 8a   + (D b + (- 2C + 2A)a)\|2 )
+--R          *
+--R                     +-----------------+
+--R                     |          2     2        2
+--R             log(- x\|- 4a c + b  + 8a   + 2a x  + b x + 2a)
+--R         + 
+--R                    +-----------------+
+--R                +-+ |          2     2
+--R             4a\|2 \|- 4a c + b  + 8a  %%BN0
+--R          *
+--R             log
+--R                             2 3 8
+--R                      - 32A D a c
+--R                    + 
+--R                               2 2 2       3        2  3
+--R                          16A D a b  + (16D  + 16B D )a b
+--R                        + 
+--R                                   2                   2      3  4
+--R                          (- 128A D  + 128A B D + 32A C  - 32A )a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                                2   4        3       2  2 3
+--R                          - 2A D a b  + (- 8D  - 8B D )a b
+--R                        + 
+--R                                          2                  2      3  3 2
+--R                          ((- 32C + 448A)D  - 64A B D - 16A C  + 16A )a b
+--R                        + 
+--R                                 3        2       2               2       2
+--R                              32D  - 32B D  + (48C  - 224A C - 64B  - 144A )D
+--R                            + 
+--R                                     2                2
+--R                              - 16B C  - 96A B C + 48A B
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                    2                 3         2      2
+--R                              128A D  + 512A B D - 64C  + 128A C  + 64A C
+--R                            + 
+--R                                      2       3
+--R                              - 128A B  - 128A
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                            3      2    5
+--R                          (D  + B D )a b
+--R                        + 
+--R                                        2                2     3  2 4
+--R                          ((16C - 192A)D  + 8A B D + 2A C  - 2A )a b
+--R                        + 
+--R                                    3         2
+--R                              - 160D  - 128B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 24C  + 112A C + 32B  + 72A )D + 8B C  + 48A B C
+--R                            + 
+--R                                   2
+--R                              - 24A B
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                             2                           3
+--R                              (- 80C + 560A)D  + (96B C - 1312A B)D + 48C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 304A C  + (48B  + 16A )C + 112A B  + 368A
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 128D  - 256B D
+--R                            + 
+--R                                   2               2       2           2      3
+--R                              (384C  - 512A C - 64B  - 384A )D + 128B C  + 64B
+--R                            + 
+--R                                  2
+--R                              384A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                     2                  3         2       2
+--R                              1024A D  - 512A B D - 256C  - 128A C  + 256A C
+--R                            + 
+--R                                      2       3
+--R                              - 512A B  + 128A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                       2   6
+--R                          (- 2C + 22A)D a b
+--R                        + 
+--R                                 3        2      2             2     2        2
+--R                              70D  + 66B D  + (3C  - 14A C - 4B  - 9A )D - B C
+--R                            + 
+--R                                           2
+--R                              - 6A B C + 3A B
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                             2                            3
+--R                              (328C - 1896A)D  + (- 48B C + 528A B)D - 12C
+--R                            + 
+--R                                    2         2      2          2       3
+--R                              120A C  + (- 24B  - 20A )C - 32A B  - 152A
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              224D  + 800B D
+--R                            + 
+--R                                     2                 2        2          2
+--R                              (- 720C  + 2080A C + 512B  + 1392A )D - 16B C
+--R                            + 
+--R                                            3       2
+--R                              672A B C - 64B  - 720A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                               2                               3
+--R                              (- 160C - 2976A)D  + (- 576B C - 1088A B)D + 608C
+--R                            + 
+--R                                      2          2       2            2      3
+--R                              - 416A C  + (- 288B  - 992A )C + 1120A B  + 32A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                    3         2
+--R                              - 256D  + 256B D
+--R                            + 
+--R                                   2                 2       2           2
+--R                              (192C  + 1664A C + 640B  + 960A )D + 448B C
+--R                            + 
+--R                                              3       2
+--R                              1152A B C + 128B  + 192A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                    2                   3          2       2
+--R                              512A D  - 4096A B D + 256C  - 1024A C  - 256A C
+--R                            + 
+--R                                    2        3
+--R                              512A B  + 1024A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                               3       2    7
+--R                          (- 8D  - 8B D )a b
+--R                        + 
+--R                                              2                      3        2
+--R                              (- 141C + 755A)D  + (6B C - 58A B)D + C  - 13A C
+--R                            + 
+--R                                 2     2         2      3
+--R                              (3B  + 3A )C + 3A B  + 17A
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                  3        2        2                2       2
+--R                              284D  + 36B D  + (276C  - 888A C - 228B  - 588A )D
+--R                            + 
+--R                                     2                 3       2
+--R                              - 12B C  - 312A B C + 20B  + 276A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                            2                               3
+--R                              (32C + 2016A)D  + (- 192B C + 3072A B)D - 320C
+--R                            + 
+--R                                    2         2       2           2       3
+--R                              720A C  + (- 96B  + 192A )C - 672A B  - 848A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              896D  + 384B D
+--R                            + 
+--R                                      2                 2       2            2
+--R                              (- 1344C  - 1408A C - 896B  - 576A )D - 1088B C
+--R                            + 
+--R                                                3        2
+--R                              - 1920A B C - 384B  - 1344A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                             2                               3
+--R                              (640C - 4224A)D  + (- 768B C + 8448A B)D + 128C
+--R                            + 
+--R                                     2          2       2           2        3
+--R                              1920A C  + (- 384B  - 640A )C + 128A B  - 2432A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                  3          2
+--R                              256D  + 1280B D
+--R                            + 
+--R                                      2                 2        2            2
+--R                              (- 3072C  + 4096A C + 512B  + 3072A )D - 1024B C
+--R                            + 
+--R                                    3        2
+--R                              - 512B  - 3072A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                       2                    3         2
+--R                              - 2048A D  - 2048A B D + 2048C  - 512A C
+--R                            + 
+--R                                     2           2       3
+--R                              - 2048A C + 4096A B  + 512A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                      2   8
+--R                          (16C - 80A)D a b
+--R                        + 
+--R                                    3         2
+--R                              - 146D  - 118B D
+--R                            + 
+--R                                    2               2      2         2
+--R                              (- 30C  + 100A C + 26B  + 66A )D + 2B C  + 36A B C
+--R                            + 
+--R                                  3      2
+--R                              - 2B  - 30A B
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                               2                            3
+--R                              (- 726C + 2090A)D  + (180B C - 1100A B)D + 62C
+--R                            + 
+--R                                      2       2      2           2       3
+--R                              - 230A C  + (90B  + 58A )C + 154A B  + 350A
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1752D  - 2760B D
+--R                            + 
+--R                                    2                 2        2           2
+--R                              (2160C  - 3840A C - 696B  - 2736A )D + 528B C
+--R                            + 
+--R                                               3        2
+--R                              - 576A B C + 312B  + 2160A B
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                     2                              3         2
+--R                              8160A D  + (4608B C - 5376A B)D - 864C  - 192A C
+--R                            + 
+--R                                    2        2           2        3
+--R                              (2304B  + 3936A )C - 960A B  + 3264A
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                     3          2
+--R                              - 1152D  - 4224B D
+--R                            + 
+--R                                    2                   2        2            2
+--R                              (5760C  - 11520A C - 2304B  - 8064A )D + 1152B C
+--R                            + 
+--R                                                3        2
+--R                              - 2304A B C + 768B  + 5760A B
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (2816C + 4352A)D  + (4608B C + 7680A B)D - 3840C
+--R                            + 
+--R                                     2         2        2            2
+--R                              3072A C  + (2304B  + 6912A )C - 6912A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              512D  - 512B D
+--R                            + 
+--R                                      2                  2       2            2
+--R                              (- 3840C  - 2560A C - 2048B  - 768A )D - 2816B C
+--R                            + 
+--R                                                 3        2
+--R                              - 4608A B C - 1024B  - 3840A B
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                       2                    3          2
+--R                              - 2048A D  + 8192A B D + 1024C  + 2048A C
+--R                            + 
+--R                                     2           2        3
+--R                              - 1024A C + 2048A B  - 2048A
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                              3        2    9
+--R                          (16D  + 16B D )a b
+--R                        + 
+--R                                            2                           3
+--R                              (308C - 972A)D  + (- 24B C + 104A B)D - 4C
+--R                            + 
+--R                                   2         2      2          2      3
+--R                              20A C  + (- 12B  - 12A )C - 12A B  - 36A
+--R                         *
+--R                             2 8
+--R                            a b
+--R                        + 
+--R                                  3         2
+--R                              456D  + 920B D
+--R                            + 
+--R                                     2                 2        2           2
+--R                              (- 744C  + 1712A C + 376B  + 1176A )D - 104B C
+--R                            + 
+--R                                            3       2
+--R                              432A B C - 88B  - 744A B
+--R                         *
+--R                             3 7
+--R                            a b
+--R                        + 
+--R                                              2                               3
+--R                              (1668C - 8316A)D  + (- 1656B C + 136A B)D + 364C
+--R                            + 
+--R                                      2          2        2           2       3
+--R                              - 380A C  + (- 828B  - 1468A )C + 452A B  - 724A
+--R                         *
+--R                             4 6
+--R                            a b
+--R                        + 
+--R                                   3          2
+--R                              2496D  + 6432B D
+--R                            + 
+--R                                      2                   2        2           2
+--R                              (- 5328C  + 14304A C + 3408B  + 9648A )D - 336B C
+--R                            + 
+--R                                              3        2
+--R                              4320A B C - 528B  - 5328A B
+--R                         *
+--R                             5 5
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 6528C - 3456A)D  + (- 11520B C - 7296A B)D
+--R                            + 
+--R                                   3          2           2         2
+--R                              3072C  - 4704A C  + (- 5760B  - 10752A )C
+--R                            + 
+--R                                     2        3
+--R                              4224A B  - 2976A
+--R                         *
+--R                             6 4
+--R                            a b
+--R                        + 
+--R                                     3         2
+--R                              - 1024D  + 512B D
+--R                            + 
+--R                                    2                  2        2            2
+--R                              (5760C  + 3840A C + 3072B  + 1152A )D + 4224B C
+--R                            + 
+--R                                               3        2
+--R                              6912A B C + 1536B  + 5760A B
+--R                         *
+--R                             7 3
+--R                            a b
+--R                        + 
+--R                                                2
+--R                              (- 1280C + 6912A)D  + (1536B C - 12800A B)D
+--R                            + 
+--R                                     3          2        2        2            2
+--R                              - 1280C  - 2816A C  + (768B  + 2304A )C - 2304A B
+--R                            + 
+--R                                   3
+--R                              3840A
+--R                         *
+--R                             8 2
+--R                            a b
+--R                        + 
+--R                                       2         2                  2        2
+--R                              - 2048B D  + (6144C  - 8192A C - 1024B  - 6144A )D
+--R                            + 
+--R                                     2        3        2
+--R                              2048B C  + 1024B  + 6144A B
+--R                         *
+--R                             9
+--R                            a b
+--R                        + 
+--R                                               3          2        2           2
+--R                              8192A B D - 4096C  + 2048A C  + 4096A C - 8192A B
+--R                            + 
+--R                                     3
+--R                              - 2048A
+--R                         *
+--R                             10
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                    2   10
+--R                      (- 32C + 96A)D a b
+--R                    + 
+--R                               3        2       2               2       2
+--R                          - 24D  - 72B D  + (72C  - 176A C - 40B  - 120A )D
+--R                        + 
+--R                              2               3      2
+--R                          8B C  - 48A B C + 8B  + 72A B
+--R                     *
+--R                         2 9
+--R                        a b
+--R                    + 
+--R                                           2                           3
+--R                          (- 376C + 1416A)D  + (144B C + 144A B)D - 40C
+--R                        + 
+--R                               2       2       2          2      3
+--R                          72A C  + (72B  + 136A )C - 56A B  + 24A
+--R                     *
+--R                         3 8
+--R                        a b
+--R                    + 
+--R                                3          2
+--R                          - 360D  - 1080B D
+--R                        + 
+--R                               2                 2        2          2
+--R                          (936C  - 2608A C - 632B  - 1752A )D + 40B C
+--R                        + 
+--R                                          3       2
+--R                          - 816A B C + 88B  + 936A B
+--R                     *
+--R                         4 7
+--R                        a b
+--R                    + 
+--R                                        2                              3
+--R                          (24C + 4248A)D  + (2160B C + 2160A B)D - 536C
+--R                        + 
+--R                                 2         2        2           2       3
+--R                          1080A C  + (1080B  + 1976A )C - 712A B  + 360A
+--R                     *
+--R                         5 6
+--R                        a b
+--R                    + 
+--R                                 3          2
+--R                          - 1152D  - 3456B D
+--R                        + 
+--R                                2                  2        2           2
+--R                          (1296C  - 7968A C - 2400B  - 5040A )D - 816B C
+--R                        + 
+--R                                           3        2
+--R                          - 3744A B C - 96B  + 1296A B
+--R                     *
+--R                         6 5
+--R                        a b
+--R                    + 
+--R                                          2                              3
+--R                          (7040C - 7296A)D  + (6912B C + 6912A B)D - 960C
+--R                        + 
+--R                                 2         2        2           2        3
+--R                          3456A C  + (3456B  + 5568A )C - 768A B  + 1152A
+--R                     *
+--R                         7 4
+--R                        a b
+--R                    + 
+--R                               3          2
+--R                          1536D  + 4608B D
+--R                        + 
+--R                                   2                   2        2            2
+--R                          (- 11520C  + 12800A C + 1024B  + 9984A )D - 4352B C
+--R                        + 
+--R                                             3         2
+--R                          - 1536A B C - 2048B  - 11520A B
+--R                     *
+--R                         8 3
+--R                        a b
+--R                    + 
+--R                                            2                                 3
+--R                          (- 6656C + 1536A)D  + (- 9216B C - 9216A B)D + 5632C
+--R                        + 
+--R                                 2           2         2            2        3
+--R                        - 4608A C  + (- 4608B  - 11776A )C + 9728A B  - 1536A
+--R                     *
+--R                         9 2
+--R                        a b
+--R                    + 
+--R                                2                  2        2            2
+--R                          (9216C  - 2048A C + 2048B  - 3072A )D + 5120B C
+--R                        + 
+--R                                           3        2
+--R                          6144A B C + 2048B  + 9216A B
+--R                     *
+--R                         10
+--R                        a  b
+--R                    + 
+--R                              3        2           2  11
+--R                      (- 4096C  + 4096A C - 8192A B )a
+--R                 *
+--R                         3
+--R                    %%BN0
+--R                + 
+--R                           3 2 8
+--R                      16A D a c
+--R                    + 
+--R                                 3   2         4       3          2  2
+--R                          - 12A D a b  + (- 16D  - 8B D  + 24A C D )a b
+--R                        + 
+--R                                       3          2           2      3    3
+--R                          ((16C + 64A)D  - 48A B D  + (- 48A C  + 16A )D)a
+--R                     *
+--R                         7
+--R                        c
+--R                    + 
+--R                              3 4      4       3         2    3
+--R                          2A D b  + (8D  + 6B D  - 6A C D )a b
+--R                        + 
+--R                                           3                     2
+--R                              (20C - 260A)D  + (- 12B C + 12A B)D
+--R                            + 
+--R                                    2     3
+--R                              (12A C  - 4A )D
+--R                         *
+--R                             2 2
+--R                            a b
+--R                        + 
+--R                                   4        3
+--R                              - 56D  + 48B D
+--R                            + 
+--R                                    2               2      2  2
+--R                              (- 72C  + 240A C + 24B  + 24A )D
+--R                            + 
+--R                                    2                2          3     3
+--R                              (24B C  + 48A B C - 24A B)D + 8A C  - 8A C
+--R                         *
+--R                             3
+--R                            a b
+--R                        + 
+--R                                          3                      2
+--R                              (64C - 96A)D  + (- 96B C - 192A B)D
+--R                            + 
+--R                                3         2      2       3            2      3
+--R                            (80C  - 192A C  + 48A C + 64A )D + 48A B C  + 16A B
+--R                         *
+--R                             4
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                              4      3  5                   3         2    4
+--R                          (- D  - B D )b  + ((- 14C + 151A)D  + 3B C D )a b
+--R                        + 
+--R                                  4        3       2              2     2  2
+--R                              174D  + 48B D  + (42C  - 336A C - 6B  - 6A )D
+--R                            + 
+--R                                     2               2          3     3
+--R                              (- 6B C  - 12A B C + 6A B)D - 2A C  + 2A C
+--R                         *
+--R                             2 3
+--R                            a b
+--R                        + 
+--R                                             3                    2
+--R                              (- 64C - 328A)D  + (24B C + 504A B)D
+--R                            + 
+--R                                    3         2         2      2         3
+--R                              (- 52C  + 516A C  + (- 24B  - 36A )C - 172A )D
+--R                            + 
+--R                                    3          2      2        3
+--R                              - 4B C  - 36A B C  + 12A B C - 4A B
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                 4         3          2               2  2
+--R                              64D  + 352B D  + (- 408C  + 432A C - 24A )D
+--R                            + 
+--R                                      2                2        4        3
+--R                              (- 48B C  - 96A B C - 48A B)D - 8C  - 32A C
+--R                            + 
+--R                                    2      2  2           2      3        2 2
+--R                              (- 24B  - 48A )C  + (- 48A B  - 32A )C - 24A B
+--R                            + 
+--R                                  4
+--R                              - 8A
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                      3                       2
+--R                              - 640A D  + (- 384B C + 384A B)D
+--R                            + 
+--R                                   3        2       2         3          3
+--R                              (320C  + (192B  + 192A )C - 128A )D - 64B C
+--R                            + 
+--R                                      2       2           3      3
+--R                              192A B C  - 192A B C + 64A B  + 64A B
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                     3 6
+--R                          (2C - 22A)D b
+--R                        + 
+--R                                4        3        2          2    5
+--R                          (- 72D  - 48B D  + (- 6C  + 66A C)D )a b
+--R                        + 
+--R                                               3                     2
+--R                              (- 242C + 1210A)D  + (102B C - 108A B)D
+--R                            + 
+--R                                 3         2      2     2        3        3
+--R                              (8C  - 111A C  + (6B  + 6A )C + 37A )D + B C
+--R                            + 
+--R                                    2     2
+--R                              6A B C  - 3A B C
+--R                         *
+--R                             2 4
+--R                            a b
+--R                        + 
+--R                                      3        2                 2       2  2
+--R                              - 892B D  + (882C  - 1800A C - 192B  - 186A )D
+--R                            + 
+--R                                       2                3       2        4
+--R                              (- 156B C  - 336A B C + 4B  + 228A B)D + 6C
+--R                            + 
+--R                                     3       2      2  2         2      3
+--R                              - 48A C  + (18B  + 24A )C  + (24A B  + 80A )C
+--R                            + 
+--R                                2 2     4
+--R                              6A B  + 2A
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                              3                      2
+--R                              (- 72C + 1848A)D  + (1512B C + 504A B)D
+--R                            + 
+--R                                        3         2         2       2          2
+--R                                  - 816C  + 816A C  + (- 24B  - 384A )C + 72A B
+--R                                + 
+--R                                       3
+--R                                  - 96A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   3           2       3       2           3
+--R                              96B C  - 384A B C  + (24B  + 240A B)C - 24A B
+--R                            + 
+--R                                    3
+--R                              - 144A B
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                  4         2                 2       2  2
+--R                              320D  + (- 48C  - 1056A C - 672B  - 624A )D
+--R                            + 
+--R                                       2                  3       2         4
+--R                              (- 384B C  - 1152A B C - 64B  + 576A B)D + 48C
+--R                            + 
+--R                                     3       2      2  2           2       3
+--R                              - 96A C  + (48B  + 96A )C  + (- 96A B  + 224A )C
+--R                            + 
+--R                                   4       2 2      4
+--R                              - 32B  - 144A B  - 16A
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                              3            2
+--R                              (- 256C - 256A)D  + 2304A B D
+--R                            + 
+--R                                        3         2        2       2           2
+--R                                  - 192C  + 768A C  + (768B  + 192A )C - 384A B
+--R                                + 
+--R                                        3
+--R                                  - 768A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3       2
+--R                              - 256B C  + 192A B C  + (- 128B  - 768A B)C
+--R                            + 
+--R                                    3      3
+--R                              256A B  + 64A B
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                             4       3  7                  3          2    6
+--R                          (8D  + 8B D )b  + ((128C - 616A)D  - 24B C D )a b
+--R                        + 
+--R                                    4         3
+--R                              - 393D  + 229B D
+--R                            + 
+--R                                     2                2      2  2
+--R                              (- 390C  + 1479A C + 45B  + 45A )D
+--R                            + 
+--R                                    2              3      2       4        3
+--R                              (39B C  + 84A B C - B  - 51A B)D - C  + 13A C
+--R                            + 
+--R                                   2     2  2          2      3
+--R                              (- 3B  - 3A )C  + (- 3A B  - 17A )C
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                             3                        2
+--R                              (226C - 1142A)D  + (- 786B C - 1530A B)D
+--R                            + 
+--R                                      3          2        2       2          2
+--R                                  414C  - 1710A C  + (150B  + 234A )C - 42A B
+--R                                + 
+--R                                      3
+--R                                  502A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3           2         3       2          3
+--R                              - 10B C  + 234A B C  + (- 14B  - 174A B)C + 2A B
+--R                            + 
+--R                                 3
+--R                              30A B
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                    4          3
+--R                              - 896D  - 1152B D
+--R                            + 
+--R                                    2                2       2  2
+--R                              (1152C  + 672A C + 816B  + 960A )D
+--R                            + 
+--R                                     2                   2            3
+--R                              (816B C  + 2016A B C - 624A B)D + 368A C
+--R                            + 
+--R                                  2       2  2          2       3        4
+--R                              (48B  + 192A )C  + (288A B  - 112A )C + 16B
+--R                            + 
+--R                                  2 2      4
+--R                              240A B  + 64A
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                               3                       2
+--R                              (- 256C + 2688A)D  + (1344B C - 4416A B)D
+--R                            + 
+--R                                        3          2           2       2
+--R                                  - 544C  - 1248A C  + (- 1728B  - 672A )C
+--R                                + 
+--R                                        2        3
+--R                                  384A B  + 1440A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2        3        2            3
+--R                              480B C  - 672A B C  + (128B  + 1632A B)C - 512A B
+--R                            + 
+--R                                    3
+--R                              - 160A B
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                       3         2                 2       2  2
+--R                              - 1664B D  + (2880C  - 3072A C - 768B  - 960A )D
+--R                            + 
+--R                                     2                  3        2          4
+--R                              (384B C  - 768A B C + 256B  + 1920A B)D + 192C
+--R                            + 
+--R                                   2       2  2          2       3         2 2
+--R                              (576B  + 384A )C  + (384A B  + 512A )C - 192A B
+--R                            + 
+--R                                   4
+--R                              - 64A
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                               3                      2
+--R                              (- 256C + 1536A)D  + (1536B C + 768A B)D
+--R                            + 
+--R                                      3         2          2       3         3
+--R                              (- 2048C  + 768A C  - 1536A B  - 256A )D - 512B C
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                        3 8
+--R                          (- 16C + 80A)D b
+--R                        + 
+--R                               4        3       2           2    7
+--R                          (160D  + 64B D  + (48C  - 240A C)D )a b
+--R                        + 
+--R                                             3                       2
+--R                              (584C - 1402A)D  + (- 126B C + 300A B)D
+--R                            + 
+--R                                       3         2         2      2         2
+--R                                  - 56C  + 330A C  + (- 36B  - 36A )C + 6A B
+--R                                + 
+--R                                        3
+--R                                  - 102A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3          2      3      2
+--R                              - 2B C  - 36A B C  + (2B  + 30A B)C
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                   4          3
+--R                              1336D  + 2950B D
+--R                            + 
+--R                                      2                 2       2  2
+--R                              (- 2244C  + 2586A C + 258B  + 222A )D
+--R                            + 
+--R                                     2                 3       2         4
+--R                              (138B C  + 312A B C - 14B  - 402A B)D - 20C
+--R                            + 
+--R                                   3         2       2  2            2       3
+--R                              22A C  + (- 66B  - 102A )C  + (- 114A B  - 158A )C
+--R                            + 
+--R                                  4      2 2      4
+--R                              - 2B  - 48A B  - 14A
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                             3                         2
+--R                              (284C - 5284A)D  + (- 5196B C + 1860A B)D
+--R                            + 
+--R                                       3         2         2       2           2
+--R                                  1652C  + 276A C  + (- 12B  + 492A )C - 444A B
+--R                                + 
+--R                                         3
+--R                                  - 1012A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2          3        2
+--R                              - 532B C  + 492A B C  + (- 148B  - 1164A B)C
+--R                            + 
+--R                                    3       3
+--R                              140A B  + 308A B
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              544D  + 4864B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 5520C  + 7968A C + 3264B  + 2832A )D
+--R                            + 
+--R                                     2                   3        2          4
+--R                              (480B C  + 3840A B C + 160B  - 4128A B)D - 464C
+--R                            + 
+--R                                      3          2        2  2
+--R                              - 128A C  + (- 912B  - 1344A )C
+--R                            + 
+--R                                       2        3         4       2 2      4
+--R                              (- 384A B  - 1664A )C + 160B  + 528A B  + 16A
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                                3                         2
+--R                              (- 1536C - 2688A)D  + (- 6528B C - 4224A B)D
+--R                            + 
+--R                                       3          2           2       2
+--R                                  3968C  - 2496A C  + (- 2496B  - 768A )C
+--R                                + 
+--R                                         2       3
+--R                                  2112A B  + 704A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3           2        3       2
+--R                              - 256B C  - 768A B C  + (704B  + 384A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 448A B  + 128A B
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                    4         3         2        2        2  2
+--R                              - 384D  - 768B D  + (3072C  + 2688B  + 1536A )D
+--R                            + 
+--R                                      2                    3       2          4
+--R                              (1920B C  + 3840A B C + 1024B  - 384A B)D - 128C
+--R                            + 
+--R                                      3        2       2  2          2       3
+--R                              - 128A C  + (384B  - 768A )C  + (768A B  - 896A )C
+--R                            + 
+--R                                  4       2 2       4
+--R                              256B  + 384A B  - 128A
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                     3                       2
+--R                              1536A D  + (1536B C - 6144A B)D
+--R                            + 
+--R                                      3           2       2          3
+--R                              (- 1280C  + (- 3072B  - 768A )C + 2048A )D
+--R                            + 
+--R                                   3           2        2             3       3
+--R                            1024B C  - 768A B C  + 3072A B C - 1024A B  - 256A B
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                4        3  9
+--R                          (- 16D  - 16B D )b
+--R                        + 
+--R                                           3          2    8
+--R                          ((- 288C + 816A)D  + 48B C D )a b
+--R                        + 
+--R                                    4          3
+--R                              - 252D  - 1236B D
+--R                            + 
+--R                                   2                2      2  2
+--R                              (888C  - 2076A C - 84B  - 84A )D
+--R                            + 
+--R                                      2                3       2        4
+--R                              (- 60B C  - 144A B C + 4B  + 108A B)D + 4C
+--R                            + 
+--R                                     3       2      2  2         2      3
+--R                              - 20A C  + (12B  + 12A )C  + (12A B  + 36A )C
+--R                         *
+--R                             2 7
+--R                            a b
+--R                        + 
+--R                                                3                       2
+--R                              (- 1704C + 5232A)D  + (3024B C + 1176A B)D
+--R                            + 
+--R                                        3          2          2       2
+--R                                  - 792C  + 1728A C  + (- 168B  - 312A )C
+--R                                + 
+--R                                        2       3
+--R                                  192A B  - 272A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3           2       3       2          3
+--R                              128B C  - 312A B C  + (64B  + 528A B)C - 8A B
+--R                            + 
+--R                                   3
+--R                              - 56A B
+--R                         *
+--R                             3 6
+--R                            a b
+--R                        + 
+--R                                     4          3
+--R                              - 1572D  - 5844B D
+--R                            + 
+--R                                    2                  2        2  2
+--R                              (5112C  - 8748A C - 3348B  - 3492A )D
+--R                            + 
+--R                                        2                  3        2          4
+--R                              (- 1836B C  - 5904A B C + 84B  + 3996A B)D + 252C
+--R                            + 
+--R                                      3        2       2  2
+--R                              - 708A C  + (540B  + 396A )C
+--R                            + 
+--R                                      2        3        4       2 2       4
+--R                              (- 36A B  + 1236A )C - 72B  - 576A B  - 120A
+--R                         *
+--R                             4 5
+--R                            a b
+--R                        + 
+--R                                              3                        2
+--R                              (4344C + 1416A)D  + (10872B C + 4680A B)D
+--R                            + 
+--R                                         3          2         2        2
+--R                                  - 3480C  + 1944A C  + (5256B  + 1656A )C
+--R                                + 
+--R                                          2      3
+--R                                  - 504A B  + 72A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3            2          3       2
+--R                              840B C  + 1656A B C  + (- 168B  - 360A B)C
+--R                            + 
+--R                                    3       3
+--R                              792A B  - 408A B
+--R                         *
+--R                             5 4
+--R                            a b
+--R                        + 
+--R                                  4          3
+--R                              544D  + 1024B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 4896C  + 1152A C - 5472B  - 2592A )D
+--R                            + 
+--R                                        2                    3       2
+--R                              (- 3168B C  - 6336A B C - 2304B  + 864A B)D
+--R                            + 
+--R                                  4         3          2        2  2
+--R                              384C  + 864A C  + (- 576B  + 2304A )C
+--R                            + 
+--R                                        2        3         4       2 2       4
+--R                              (- 1152A B  + 2208A )C - 576B  - 576A B  + 384A
+--R                         *
+--R                             6 3
+--R                            a b
+--R                        + 
+--R                                              3                         2
+--R                              (1536C - 4224A)D  + (- 4224B C + 8064A B)D
+--R                            + 
+--R                                    3          2         2        2          3
+--R                              (2496C  - 1728A C  + (5760B  + 1728A )C - 2496A )D
+--R                            + 
+--R                                       3            2        2             3
+--R                              - 1344B C  + 1728A B C  - 5184A B C + 1536A B
+--R                            + 
+--R                                  3
+--R                              192A B
+--R                         *
+--R                             7 2
+--R                            a b
+--R                        + 
+--R                                     3
+--R                              1536B D
+--R                            + 
+--R                                      2                  2        2  2
+--R                              (- 4992C  + 3840A C + 3072B  + 4224A )D
+--R                            + 
+--R                                       2                    3        2
+--R                              (- 768B C  + 4608A B C - 1024B  - 6912A B)D
+--R                            + 
+--R                                    4         3           2       2  2
+--R                              - 640C  + 512A C  + (- 1920B  - 768A )C
+--R                            + 
+--R                                       2        3          2 2       4
+--R                              (- 768A B  - 1536A )C + 1152A B  + 384A
+--R                         *
+--R                             8
+--R                            a b
+--R                        + 
+--R                                         2
+--R                              - 6144A B D
+--R                            + 
+--R                                       3           2        2            2
+--R                                  3072C  + (- 3072B  - 3072A )C + 6144A B
+--R                                + 
+--R                                       3
+--R                                  2048A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     3            2         3        2
+--R                              1024B C  - 3072A B C  + (2048B  + 3072A B)C
+--R                            + 
+--R                                       3        3
+--R                              - 1024A B  - 1024A B
+--R                         *
+--R                             9
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                                  3 10          3         2           2    9
+--R                      (32C - 96A)D b   + (128B D  + (- 96C  + 288A C)D )a b
+--R                    + 
+--R                                         3                       2
+--R                          (384C - 1080A)D  + (- 360B C - 240A B)D
+--R                        + 
+--R                              3         2       2      2          2      3
+--R                          (96C  - 312A C  + (48B  + 48A )C - 24A B  + 72A )D
+--R                        + 
+--R                                3          2        3      2
+--R                          - 8B C  + 48A B C  + (- 8B  - 72A B)C
+--R                     *
+--R                         2 8
+--R                        a b
+--R                    + 
+--R                              4          3
+--R                          144D  + 1272B D
+--R                        + 
+--R                                  2                 2       2  2
+--R                          (- 1008C  + 2568A C + 456B  + 504A )D
+--R                        + 
+--R                                 2                 3       2         4         3
+--R                          (264B C  + 864A B C - 24B  - 552A B)D - 32C  + 120A C
+--R                        + 
+--R                                2      2  2         2       3       4      2 2
+--R                          (- 72B  - 24A )C  + (24A B  - 152A )C + 8B  + 96A B
+--R                        + 
+--R                             4
+--R                          24A
+--R                     *
+--R                         3 7
+--R                        a b
+--R                    + 
+--R                                         3                         2
+--R                          (240C - 1944A)D  + (- 3240B C - 2304A B)D
+--R                        + 
+--R                                  3          2          2      2          2
+--R                              816C  - 2088A C  + (- 576B  - 96A )C - 24A B
+--R                            + 
+--R                                  3
+--R                              504A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3          2        3       2            3
+--R                          - 120B C  - 96A B C  + (- 8B  - 216A B)C - 144A B
+--R                        + 
+--R                             3
+--R                          16A B
+--R                     *
+--R                         4 6
+--R                        a b
+--R                    + 
+--R                               4          3
+--R                          1008D  + 1608B D
+--R                        + 
+--R                                 2                  2        2  2
+--R                          (- 720C  + 1368A C + 3384B  + 3240A )D
+--R                        + 
+--R                                  2                   3        2          4
+--R                          (2232B C  + 6048A B C + 216B  - 3096A B)D - 192C
+--R                        + 
+--R                                3          2       2  2          2        3
+--R                          648A C  + (- 216B  - 360A )C  + (360A B  - 1128A )C
+--R                        + 
+--R                              4       2 2      4
+--R                          120B  + 576A B  + 72A
+--R                     *
+--R                         5 5
+--R                        a b
+--R                    + 
+--R                                            3                         2
+--R                          (- 5648C + 4272A)D  + (- 2160B C - 2448A B)D
+--R                        + 
+--R                                    3          2           2        2
+--R                              - 144C  + 3168A C  + (- 6768B  - 3024A )C
+--R                            + 
+--R                                    2       3
+--R                              432A B  - 576A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  3            2        3        2             3
+--R                          - 384B C  - 3024A B C  + (144B  + 2592A B)C - 1008A B
+--R                        + 
+--R                              3
+--R                          240A B
+--R                     *
+--R                         6 4
+--R                        a b
+--R                    + 
+--R                                 4          3
+--R                          - 1152D  - 3008B D
+--R                        + 
+--R                                2                  2        2  2
+--R                          (8736C  - 5760A C - 2304B  - 6048A )D
+--R                        + 
+--R                                 2                    3        2          4
+--R                          (576B C  - 6912A B C + 2880B  + 9792A B)D + 480C
+--R                        + 
+--R                                   3         2        2  2           2       3
+--R                          - 2304A C  + (2592B  - 1152A )C  + (1152A B  + 768A )C
+--R                        + 
+--R                              4        2 2       4
+--R                          384B  - 1440A B  - 864A
+--R                     *
+--R                         7 3
+--R                        a b
+--R                    + 
+--R                                          3                       2
+--R                          (4992C - 1152A)D  + (5760B C + 4992A B)D
+--R                        + 
+--R                                  3         2         2        2            2
+--R                          (- 3840C  - 768A C  + (7296B  + 6144A )C - 6528A B )D
+--R                        + 
+--R                                3            2           3        2
+--R                          512B C  + 6144A B C  + (- 2176B  - 2304A B)C
+--R                        + 
+--R                                 3       3
+--R                          1152A B  + 768A B
+--R                     *
+--R                         8 2
+--R                        a b
+--R                    + 
+--R                                  2                  2        2  2
+--R                          (- 6912C  + 1536A C - 1536B  + 2304A )D
+--R                        + 
+--R                                    2        3        2          4          3
+--R                          (- 3072B C  - 3072B  - 6144A B)D - 256C  + 1536A C
+--R                        + 
+--R                                  2        2  2             2       3         4
+--R                          (- 2304B  + 1536A )C  + (- 1536A B  + 512A )C - 512B
+--R                        + 
+--R                              2 2       4
+--R                          768A B  + 768A
+--R                     *
+--R                         9
+--R                        a b
+--R                    + 
+--R                                3        2           2              2        3
+--R                          (3072C  - 3072A C + 6144A B )D - 3072A B C  + 2048B C
+--R                        + 
+--R                                 3
+--R                          - 1024A B
+--R                     *
+--R                         10
+--R                        a
+--R                 *
+--R                         2
+--R                    %%BN0
+--R                + 
+--R                         5             4          3     3 2  2  7
+--R                      (4D a b + (- 8C D  - 16A B D  - 8A D )a )c
+--R                    + 
+--R                             5 3          4          3     3 2    2
+--R                          - D b  + (- 6C D  + 12A B D  + 2A D )a b
+--R                        + 
+--R                                 5        4       2             2      2  3
+--R                              20D  - 12B D  + (24C  + 16A C + 8B  + 28A )D
+--R                            + 
+--R                                              2   2
+--R                              (- 24A B C + 12A B)D
+--R                         *
+--R                             2
+--R                            a b
+--R                        + 
+--R                                            4                   3
+--R                              (- 32C + 24A)D  + (48B C - 64A B)D
+--R                            + 
+--R                                    3        2      3  2           2      3
+--R                              (- 16C  + 72A B  - 32A )D  + (48A B C  + 16A B)D
+--R                            + 
+--R                                3 2     5
+--R                              8A C  - 8A
+--R                         *
+--R                             3
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                               4         3  4
+--R                          (2C D  - 2A B D )b
+--R                        + 
+--R                                   5        4        2             2      2  3
+--R                              - 43D  + 11B D  + (- 2C  - 12A C - 6B  - 19A )D
+--R                            + 
+--R                                          2   2
+--R                              (6A B C - 3A B)D
+--R                         *
+--R                               3
+--R                            a b
+--R                        + 
+--R                                          4                      3
+--R                              (48C - 10A)D  + (- 52B C + 208A B)D
+--R                            + 
+--R                                         3        2       2      2          2
+--R                                    - 12C  + 24A C  + (12B  + 24A )C - 30A B
+--R                                  + 
+--R                                       3
+--R                                    92A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                        2     3        3 2     5
+--R                              (- 12A B C  - 4A B)D - 2A C  + 2A
+--R                         *
+--R                             2 2
+--R                            a b
+--R                        + 
+--R                                  5         4       2             2      2  3
+--R                              - 4D  - 108B D  + (72C  - 64A C + 4B  + 56A )D
+--R                            + 
+--R                                               3       2   2
+--R                              (- 336A B C - 36B  - 144A B)D
+--R                            + 
+--R                                     4        3         2      2  2
+--R                                  20C  - 48A C  + (- 24B  - 60A )C
+--R                                + 
+--R                                          2      3        2 2      4
+--R                                  (- 48A B  - 40A )C - 24A B  - 16A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      3      2   2      3         4
+--R                              - 8A B C  - 12A B C  - 16A B C + 20A B
+--R                         *
+--R                             3
+--R                            a b
+--R                        + 
+--R                                   4                    3
+--R                              96A D  + (192B C - 96A B)D
+--R                            + 
+--R                                    3        2      2          2      3  2
+--R                              (- 64C  + 24A C  - 96B C + 288A B  + 40A )D
+--R                            + 
+--R                                      3           2      2           3      3
+--R                              (- 16B C  + 192A B C  - 48A B C - 96A B  + 64A B)D
+--R                            + 
+--R                                  5      2 3           2      3  2      4
+--R                              - 8C  - 16A C  + (- 72A B  + 32A )C  + 24A C
+--R                            + 
+--R                                   3 2      5
+--R                              - 24A B  - 32A
+--R                         *
+--R                             4
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                             5       4       2           2     2  3  5
+--R                          (9D  - 2B D  + (- C  + 2A C + B  + 3A )D )b
+--R                        + 
+--R                                        4                    3
+--R                              (59C + A)D  + (10B C - 114A B)D
+--R                            + 
+--R                                 3       2        2     2         2      3  2
+--R                              (4C  - 6A C  + (- 3B  - 6A )C + 3A B  - 20A )D
+--R                         *
+--R                               4
+--R                            a b
+--R                        + 
+--R                                   5         4
+--R                              - 65D  + 189B D
+--R                            + 
+--R                                     2               2       2  3
+--R                              (- 186C  - 144A C - 81B  - 312A )D
+--R                            + 
+--R                                    2                 3      2   2
+--R                              (12B C  + 312A B C + 13B  - 54A B)D
+--R                            + 
+--R                                      4        3      2      2  2
+--R                                  - 5C  + 12A C  + (6B  + 15A )C
+--R                                + 
+--R                                        2      3       2 2     4
+--R                                  (12A B  + 10A )C + 6A B  + 4A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    3     2   2     3        4
+--R                              2A B C  + 3A B C  + 4A B C - 5A B
+--R                         *
+--R                             2 3
+--R                            a b
+--R                        + 
+--R                                            4                       3
+--R                              (164C - 144A)D  + (- 504B C + 448A B)D
+--R                            + 
+--R                                     3         2        2       2           2
+--R                                  72C  + 282A C  + (228B  + 348A )C - 552A B
+--R                                + 
+--R                                      3
+--R                                  186A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                      3           2       3       2           3
+--R                                  4B C  - 336A B C  + (24B  + 180A B)C + 72A B
+--R                                + 
+--R                                        3
+--R                                  - 104A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                5       4      2      2  3         2      3  2
+--R                              2C  + 8A C  + (4B  + 24A )C  + (54A B  - 64A )C
+--R                            + 
+--R                                  2 2      4       3 2      5
+--R                              (24A B  - 10A )C - 2A B  + 72A
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                    5        4
+--R                              - 104D  - 72B D
+--R                            + 
+--R                                     2                2      2  3
+--R                              (- 108C  - 232A C + 136B  - 28A )D
+--R                            + 
+--R                                     2                3       2   2
+--R                              (252B C  - 120A B C - 8B  - 372A B)D
+--R                            + 
+--R                                      4         3      2 2          2      3
+--R                                  116C  - 128A C  + 12B C  + (456A B  - 16A )C
+--R                                + 
+--R                                     4       2 2      4
+--R                                  48B  + 300A B  - 68A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   4           3       3       2   2
+--R                              28B C  + 144A B C  + (36B  + 192A B)C
+--R                            + 
+--R                                     3      3         2 3      4
+--R                              (120A B  - 32A B)C + 36A B  + 84A B
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                    4           3
+--R                              128C D  - 128A B D
+--R                            + 
+--R                                     3        2          2      2          2
+--R                                  48C  + 96A C  + (- 384B  - 48A )C + 96A B
+--R                                + 
+--R                                      3
+--R                                  288A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                         3          2       3       2
+--R                                  - 64B C  - 96A B C  + (64B  - 192A B)C
+--R                                + 
+--R                                          3      3
+--R                                  - 384A B  - 32A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                   5        4       2      2  3
+--R                              - 32C  + 48A C  + (48B  - 64A )C
+--R                            + 
+--R                                       2      3  2        2 2      4          4
+--R                              (- 288A B  - 64A )C  + (144A B  + 96A )C + 32A B
+--R                            + 
+--R                                   3 2      5
+--R                              - 96A B  + 16A
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                  4          3  6
+--R                          (- 16C D  + 16A B D )b
+--R                        + 
+--R                                  5         4      2               2       2  3
+--R                              127D  - 107B D  + (5C  + 106A C + 53B  + 173A )D
+--R                            + 
+--R                                     2              3      2   2
+--R                              (- 3B C  - 54A B C - B  + 21A B)D
+--R                         *
+--R                               5
+--R                            a b
+--R                        + 
+--R                                             4                     3
+--R                              (- 229C + 37A)D  + (400B C - 690A B)D
+--R                            + 
+--R                                      3         2          2       2           2
+--R                                  116C  - 300A C  + (- 177B  - 315A )C + 189A B
+--R                                + 
+--R                                        3
+--R                                  - 347A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                      2        3      2           3      3
+--R                              (66A B C  + (- 6B  - 42A B)C - 12A B  + 20A B)D
+--R                            + 
+--R                                    4       2     2  3          2      3  2
+--R                              - 2A C  + (- B  - 5A )C  + (- 9A B  + 13A )C
+--R                            + 
+--R                                   2 2    4       3 2      5
+--R                              (- 6A B  + A )C + 2A B  - 15A
+--R                         *
+--R                             2 4
+--R                            a b
+--R                        + 
+--R                                  5         4       2               2      2  3
+--R                              212D  + 476B D  + (79C  + 650A C - 44B  + 55A )D
+--R                            + 
+--R                                       2                   3        2   2
+--R                              (- 231B C  + 1470A B C + 204B  + 1257A B)D
+--R                            + 
+--R                                        4         3        2       2  2
+--R                                  - 195C  + 360A C  + (129B  + 318A )C
+--R                                + 
+--R                                          2       3        4      2 2       4
+--R                                  (- 42A B  + 216A )C - 32B  - 63A B  + 133A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     4          3         3      2   2
+--R                              - 15B C  - 48A B C  + (- 25B  - 66A B)C
+--R                            + 
+--R                                      3       3         2 3       4
+--R                              (- 78A B  + 112A B)C - 17A B  - 175A B
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                          4                       3
+--R                              (4C - 260A)D  + (- 800B C - 320A B)D
+--R                            + 
+--R                                        3         2        2       2
+--R                                  - 140C  - 564A C  + (408B  - 564A )C
+--R                                + 
+--R                                           2       3
+--R                                  - 1320A B  - 780A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                          3            2          3       2
+--R                                  - 104B C  - 1368A B C  + (- 384B  - 984A B)C
+--R                                + 
+--R                                        3       3
+--R                                  384A B  - 488A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                 5         4          2      2  3
+--R                              56C  - 128A C  + (- 172B  - 64A )C
+--R                            + 
+--R                                     2       3  2         4       2 2       4
+--R                              (108A B  - 160A )C  + (- 60B  - 564A B  - 248A )C
+--R                            + 
+--R                                     4       3 2      5
+--R                              - 84A B  + 116A B  + 32A
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                   5         4
+--R                              - 48D  + 528B D
+--R                            + 
+--R                                     2                2      2  3
+--R                              (- 624C  + 352A C + 320B  + 16A )D
+--R                            + 
+--R                                     2                   3       2   2
+--R                              (432B C  + 2208A B C + 128B  + 432A B)D
+--R                            + 
+--R                                     4        3          2       2  2
+--R                                  32C  - 64A C  + (- 144B  + 672A )C
+--R                                + 
+--R                                          2       3        4       2 2
+--R                                  (1056A B  + 512A )C + 48B  + 624A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                     4           3         3       2   2
+--R                              - 64B C  + 128A B C  + (- 48B  + 288A B)C
+--R                            + 
+--R                                      3       3         5       2 3      4
+--R                              (- 32A B  - 192A B)C - 16B  - 176A B  - 32A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                            4                       3
+--R                              (128C - 384A)D  + (- 768B C + 256A B)D
+--R                            + 
+--R                                   3       2          2       3  2
+--R                              (448C  - 192A C - 768A B  + 128A )D
+--R                            + 
+--R                                          2       3        3            4
+--R                              (- 1152A B C  + 256B C - 384A B)D + 192A C
+--R                            + 
+--R                                  2 3       3 2       2 2          4       5
+--R                              192B C  - 384A C  + 576A B C + 128A B  + 192A
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                5        4      2             2      2  3  7
+--R                          (- 24D  + 16B D  + (8C  - 16A C - 8B  - 24A )D )b
+--R                        + 
+--R                                            4                      3
+--R                              (- 114C - 2A)D  + (- 68B C + 284A B)D
+--R                            + 
+--R                                  3        2       2      2          2      3  2
+--R                            (- 30C  + 54A C  + (30B  + 54A )C - 18A B  + 66A )D
+--R                         *
+--R                               6
+--R                            a b
+--R                        + 
+--R                                    5         4
+--R                              - 135D  - 552B D
+--R                            + 
+--R                                   2                2       2  3
+--R                              (318C  + 228A C + 186B  + 720A )D
+--R                            + 
+--R                                      2                 3      2   2
+--R                              (- 12B C  - 900A B C - 64B  - 90A B)D
+--R                            + 
+--R                                     4        3         2      2  2
+--R                                  39C  - 76A C  + (- 30B  - 72A )C
+--R                                + 
+--R                                          2      3       4      4
+--R                                  (- 12A B  - 48A )C + 5B  - 27A
+--R                             *
+--R                                D
+--R                            + 
+--R                                  4         3      3     2   2
+--R                              2B C  + 4A B C  + (4B  + 6A B)C
+--R                            + 
+--R                                    3      3        2 3      4
+--R                              (12A B  - 24A B)C + 2A B  + 36A B
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                             4                      3
+--R                              (- 515C + 93A)D  + (1044B C - 184A B)D
+--R                            + 
+--R                                      3         2          2        2
+--R                                  - 4C  - 924A C  + (- 828B  - 1182A )C
+--R                                + 
+--R                                         2     3
+--R                                  1104A B  - 6A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                        3           2       3       2
+--R                                  112B C  + 972A B C  + (64B  - 252A B)C
+--R                                + 
+--R                                          3       3
+--R                                  - 196A B  + 296A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                  5        4       2      2  3
+--R                              - 7C  + 13A C  + (62B  - 28A )C
+--R                            + 
+--R                                      2       3  2       4       2 2      4
+--R                              (- 42A B  + 184A )C  + (35B  + 144A B  + 91A )C
+--R                            + 
+--R                                   4      3 2       5
+--R                              39A B  + 56A B  - 141A
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                 5          4
+--R                              52D  - 1100B D
+--R                            + 
+--R                                    2                2       2  3
+--R                              (1418C  + 540A C - 648B  + 826A )D
+--R                            + 
+--R                                       2                   3       2   2
+--R                              (- 714B C  - 2316A B C - 168B  + 726A B)D
+--R                            + 
+--R                                        4         3        2      2  2
+--R                                  - 222C  + 736A C  + (630B  - 12A )C
+--R                                + 
+--R                                          2      3         4        2 2       4
+--R                                (- 1404A B  + 48A )C - 108B  - 1098A B  + 314A
+--R                             *
+--R                                D
+--R                            + 
+--R                                   4           3        3       2   2
+--R                              34B C  - 256A B C  + (138B  - 300A B)C
+--R                            + 
+--R                                    3       3         5       2 3      4
+--R                              (12A B  + 656A B)C + 36B  + 186A B  - 38A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                              4                       3
+--R                              (- 120C + 312A)D  + (1920B C - 1152A B)D
+--R                            + 
+--R                                        3         2        2        2
+--R                                  - 328C  - 936A C  + (528B  - 1368A )C
+--R                                + 
+--R                                         2       3
+--R                                  1296A B  - 984A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                        3            2       2            3
+--R                                  944B C  + 3120A B C  + 144A B C + 896A B
+--R                                + 
+--R                                      3
+--R                                  912A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                  5         4       2       2  3
+--R                              112C  - 240A C  + (24B  + 224A )C
+--R                            + 
+--R                                      2       3  2        4       2 2      4
+--R                              (1272A B  + 960A )C  + (200B  - 120A B  + 48A )C
+--R                            + 
+--R                                    4       3 2       5
+--R                              - 8A B  + 744A B  - 336A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                 5         4
+--R                              96D  + 480B D
+--R                            + 
+--R                                     2                2       2  3
+--R                              (- 384C  + 768A C - 768B  - 192A )D
+--R                            + 
+--R                                        2                   3       2   2
+--R                              (- 1152B C  + 1152A B C - 256B  + 960A B)D
+--R                            + 
+--R                                        4         3          2       2  2
+--R                                  - 544C  + 128A C  + (- 768B  + 384A )C
+--R                                + 
+--R                                          2       3         4        2 2       4
+--R                                (- 2304A B  + 512A )C - 288B  - 1536A B  + 288A
+--R                             *
+--R                                D
+--R                            + 
+--R                                      4            3          3        2   2
+--R                              - 352B C  - 1024A B C  + (- 384B  - 1152A B)C
+--R                            + 
+--R                                        3       3         5       2 3       4
+--R                              (- 1024A B  - 384A B)C - 32B  - 640A B  - 416A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                      4                        3
+--R                              - 384A D  + (- 768B C + 1536A B)D
+--R                            + 
+--R                                   3         2        2           2       3  2
+--R                              (256C  - 384A C  + 1536B C - 1152A B  - 640A )D
+--R                            + 
+--R                                        3           2       2             3
+--R                                  256B C  - 768A B C  + 768A B C + 1536A B
+--R                                + 
+--R                                        3
+--R                                  - 256A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                  5       2 3           2       3  2       4
+--R                              128C  + 256A C  + (1152A B  - 128A )C  - 384A C
+--R                            + 
+--R                                  3 2       5
+--R                              384A B  + 128A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                4          3  8
+--R                          (32C D  - 32A B D )b
+--R                        + 
+--R                                   5         4
+--R                              - 76D  + 252B D
+--R                            + 
+--R                                  2                2       2  3
+--R                              (12C  - 232A C - 116B  - 388A )D
+--R                            + 
+--R                                    2                3      2   2
+--R                              (12B C  + 120A B C + 4B  - 36A B)D
+--R                         *
+--R                               7
+--R                            a b
+--R                        + 
+--R                                           4                       3
+--R                              (807C + 31A)D  + (- 740B C + 356A B)D
+--R                            + 
+--R                                        3         2        2       2           2
+--R                                  - 274C  + 810A C  + (510B  + 870A )C - 282A B
+--R                                + 
+--R                                      3
+--R                                  426A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                         3           2      3       2
+--R                                  - 20B C  - 132A B C  + (4B  + 108A B)C
+--R                                + 
+--R                                       3      3
+--R                                  28A B  - 36A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                 5       4        2      2  3        2      3  2
+--R                              - C  + 3A C  + (- 6B  + 10A )C  + (6A B  - 30A )C
+--R                            + 
+--R                                   4     2 2     4         4      3 2      5
+--R                              (- 5B  - 6A B  - 9A )C - 5A B  - 18A B  + 27A
+--R                         *
+--R                             2 6
+--R                            a b
+--R                        + 
+--R                                 5         4
+--R                              48D  + 740B D
+--R                            + 
+--R                                      2               2        2  3
+--R                              (- 1472C  - 1808A C - 4B  - 1944A )D
+--R                            + 
+--R                                     2       3        2   2
+--R                              (816B C  - 228B  - 2760A B)D
+--R                            + 
+--R                                      4         3          2       2  2
+--R                                  376C  - 912A C  + (- 540B  - 600A )C
+--R                                + 
+--R                                         2       3        4       2 2       4
+--R                                  (312A B  - 416A )C + 68B  + 348A B  - 336A
+--R                             *
+--R                                D
+--R                            + 
+--R                                     4          3         3      2   2
+--R                              - 12B C  + 80A B C  + (- 44B  + 96A B)C
+--R                            + 
+--R                                    3       3         5      2 3       4
+--R                              (40A B  - 480A B)C - 16B  - 84A B  + 284A B
+--R                         *
+--R                             3 5
+--R                            a b
+--R                        + 
+--R                                            4                        3
+--R                              (256C + 584A)D  + (- 688B C + 2904A B)D
+--R                            + 
+--R                                      3          2         2        2
+--R                                  496C  + 3888A C  + (1116B  + 5532A )C
+--R                                + 
+--R                                        2        3
+--R                                  996A B  + 2140A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                          3           2        3        2
+--R                                  - 672B C  + 120A B C  + (712B  + 4200A B)C
+--R                                + 
+--R                                          3       3
+--R                                  - 256A B  + 336A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                    5         4        2       2  3
+--R                              - 156C  + 364A C  + (116B  + 268A )C
+--R                            + 
+--R                                       2       3  2
+--R                              (- 492A B  - 444A )C
+--R                            + 
+--R                                     4       2 2       4          4       3 2
+--R                              (- 100B  + 792A B  + 160A )C + 12A B  - 904A B
+--R                            + 
+--R                                  5
+--R                              352A
+--R                         *
+--R                             4 4
+--R                            a b
+--R                        + 
+--R                                   5          4
+--R                              - 80D  - 1040B D
+--R                            + 
+--R                                     2                 2       2  3
+--R                              (- 748C  - 2760A C + 816B  - 380A )D
+--R                            + 
+--R                                        2                   3        2   2
+--R                              (- 1044B C  - 7032A B C - 272B  - 4260A B)D
+--R                            + 
+--R                                      4          3           2        2  2
+--R                                  396C  - 2272A C  + (- 1716B  - 4152A )C
+--R                                + 
+--R                                          2        3        4       2 2        4
+--R                                (- 2040A B  - 3360A )C + 16B  - 180A B  - 1108A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    4           3          3        2   2
+--R                              188B C  - 128A B C  + (- 364B  - 1080A B)C
+--R                            + 
+--R                                       3        3         5       2 3       4
+--R                              (- 168A B  - 1408A B)C - 48B  + 244A B  + 124A B
+--R                         *
+--R                             5 3
+--R                            a b
+--R                        + 
+--R                                              4                      3
+--R                              (- 528C + 816A)D  + (3264B C - 768A B)D
+--R                            + 
+--R                                      3          2           2        2
+--R                                  816C  + 1680A C  + (- 1056B  + 2064A )C
+--R                                + 
+--R                                         2        3
+--R                                  4224A B  + 1584A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                        3            2         3        2
+--R                                  544B C  + 5280A B C  + (1280B  + 4320A B)C
+--R                                + 
+--R                                          3        3
+--R                                  - 768A B  + 1888A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                    5         4        2       2  3
+--R                              - 160C  + 320A C  + (496B  + 384A )C
+--R                            + 
+--R                                     2       3  2        4        2 2       4
+--R                              (144A B  + 800A )C  + (240B  + 1680A B  + 800A )C
+--R                            + 
+--R                                    4       3 2      5
+--R                              208A B  - 272A B  - 96A
+--R                         *
+--R                             6 2
+--R                            a b
+--R                        + 
+--R                                      4         2                 2       2  3
+--R                              - 384B D  + (1344C  - 384A C - 1344B  - 960A )D
+--R                            + 
+--R                                        2                  3       2   2
+--R                              (- 1728B C  - 3456A B C + 64B  + 576A B)D
+--R                            + 
+--R                                        4          3        2        2  2
+--R                                  - 448C  + 1024A C  + (960B  - 1728A )C
+--R                                + 
+--R                                            2        3         4        2 2
+--R                                  (- 3456A B  - 1408A )C - 192B  - 2112A B
+--R                                + 
+--R                                      4
+--R                                  256A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    4           3        3       2   2
+--R                              256B C  - 384A B C  + (192B  - 960A B)C
+--R                            + 
+--R                                     3        3         5       2 3       4
+--R                              (128A B  + 1024A B)C + 64B  + 704A B  - 192A B
+--R                         *
+--R                             7
+--R                            a b
+--R                        + 
+--R                                       3
+--R                              1536A B D
+--R                            + 
+--R                                        3         2         2       2
+--R                                  - 768C  - 384A C  + (1536B  + 768A )C
+--R                                + 
+--R                                           2       3
+--R                                  - 1536A B  - 640A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                        3            2           3       2
+--R                                  256B C  + 1536A B C  + (- 1024B  + 768A B)C
+--R                                + 
+--R                                         3       3
+--R                                  1536A B  + 512A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                  5         4          2       2  3
+--R                              128C  - 768A C  + (- 768B  + 256A )C
+--R                            + 
+--R                                      2        3  2           2 2       4
+--R                              (1152A B  + 1024A )C  + (- 2304A B  - 384A )C
+--R                            + 
+--R                                      4       3 2       5
+--R                              - 512A B  + 384A B  - 256A
+--R                         *
+--R                             8
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                          5        4         2              2      2  3  9
+--R                      (16D  - 32B D  + (- 16C  + 32A C + 16B  + 48A )D )b
+--R                    + 
+--R                                        4                    3
+--R                          (- 104C - 8A)D  + (112B C - 80A B)D
+--R                        + 
+--R                            3         2         2       2          2      3  2
+--R                        (56C  - 120A C  + (- 72B  - 120A )C + 24A B  - 72A )D
+--R                     *
+--R                           8
+--R                        a b
+--R                    + 
+--R                             5         4       2               2       2  3
+--R                          94D  - 214B D  + (76C  + 440A C + 76B  + 484A )D
+--R                        + 
+--R                                   2                 3       2   2
+--R                          (- 132B C  + 168A B C + 52B  + 468A B)D
+--R                        + 
+--R                                   4         3       2       2  2
+--R                              - 66C  + 152A C  + (84B  + 108A )C
+--R                            + 
+--R                                      2      3        4      2 2      4
+--R                              (- 24A B  + 72A )C - 10B  - 36A B  + 54A
+--R                         *
+--R                            D
+--R                        + 
+--R                              4         3      3      2   2          3      3
+--R                          2B C  - 8A B C  + (4B  - 12A B)C  + (- 8A B  + 72A B)C
+--R                        + 
+--R                            5      2 3      4
+--R                          2B  + 12A B  - 54A B
+--R                     *
+--R                         2 7
+--R                        a b
+--R                    + 
+--R                                          4                     3
+--R                          (- 662C - 182A)D  + (568B C - 824A B)D
+--R                        + 
+--R                                  3          2          2        2           2
+--R                              260C  - 1236A C  + (- 516B  - 1500A )C - 276A B
+--R                            + 
+--R                                    3
+--R                              - 772A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   3           2          3       2           3
+--R                              88B C  - 264A B C  + (- 136B  - 744A B)C + 40A B
+--R                            + 
+--R                                    3
+--R                              - 136A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5        4         2      2  3         2      3  2
+--R                          26C  - 62A C  + (- 28B  - 52A )C  + (60A B  + 28A )C
+--R                        + 
+--R                              4       2 2      4         4       3 2      5
+--R                          (10B  - 156A B  - 38A )C - 6A B  + 140A B  - 30A
+--R                     *
+--R                         3 6
+--R                        a b
+--R                    + 
+--R                                5         4
+--R                          - 236D  + 416B D
+--R                        + 
+--R                                2                 2       2  3
+--R                          (1408C  + 1664A C - 248B  + 904A )D
+--R                        + 
+--R                                   2                   3        2   2
+--R                          (- 456B C  + 2400A B C + 400B  + 3648A B)D
+--R                        + 
+--R                                    4          3        2        2  2
+--R                              - 412C  + 1232A C  + (768B  + 1488A )C
+--R                            + 
+--R                                     2        3        4       2 2       4
+--R                              (672A B  + 1088A )C - 28B  + 120A B  + 476A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 4          3       3       2   2
+--R                          - 16B C  + 80A B C  + (88B  + 264A B)C
+--R                        + 
+--R                                3       3         5      2 3       4
+--R                          (32A B  + 608A B)C + 16B  + 16A B  - 328A B
+--R                     *
+--R                         4 5
+--R                        a b
+--R                    + 
+--R                                         4                         3
+--R                          (1204C - 908A)D  + (- 2768B C - 1568A B)D
+--R                        + 
+--R                                     3          2         2        2
+--R                              - 1456C  - 2352A C  + (- 48B  - 4296A )C
+--R                            + 
+--R                                       2        3
+--R                              - 3648A B  - 1480A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    3            2           3        2
+--R                              256B C  - 3120A B C  + (- 1184B  - 6288A B)C
+--R                            + 
+--R                                     3        3
+--R                              - 80A B  - 1376A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5         4          2       2  3
+--R                          164C  - 428A C  + (- 280B  - 544A )C
+--R                        + 
+--R                                   2       3  2         4        2 2       4
+--R                          (- 120A B  - 112A )C  + (- 20B  - 1344A B  - 356A )C
+--R                        + 
+--R                                 4       3 2       5
+--R                          - 68A B  + 800A B  - 196A
+--R                     *
+--R                         5 4
+--R                        a b
+--R                    + 
+--R                              5         4
+--R                          288D  + 640B D
+--R                        + 
+--R                                  2                  2       2  3
+--R                          (- 1576C  + 1488A C + 1392B  + 760A )D
+--R                        + 
+--R                                  2                  3       2   2
+--R                          (4872B C  + 8304A B C + 16B  - 600A B)D
+--R                        + 
+--R                                  4         3         2        2  2
+--R                              968C  + 320A C  + (1128B  + 4800A )C
+--R                            + 
+--R                                      2        3         4        2 2       4
+--R                              (7152A B  + 3872A )C + 464B  + 3432A B  + 344A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4            3        3        2   2
+--R                          - 136B C  + 1376A B C  + (568B  + 3072A B)C
+--R                        + 
+--R                                  3       3         5       2 3       4
+--R                          (1040A B  + 512A B)C + 16B  - 392A B  + 872A B
+--R                     *
+--R                         6 3
+--R                        a b
+--R                    + 
+--R                                           4                        3
+--R                          (- 1248C + 288A)D  + (- 1152B C - 768A B)D
+--R                        + 
+--R                                  3          2           2       2           2
+--R                              288C  - 1152A C  + (- 4224B  + 288A )C + 576A B
+--R                            + 
+--R                                  3
+--R                              704A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                       3            2          3        2
+--R                              - 3584B C  - 7872A B C  + (- 896B  - 2688A B)C
+--R                            + 
+--R                                       3        3
+--R                              - 3200A B  - 2240A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5         4          2        2  3
+--R                          - 352C  + 448A C  + (- 544B  - 1024A )C
+--R                        + 
+--R                                    2        3  2
+--R                          (- 4800A B  - 2560A )C
+--R                        + 
+--R                                 4        2 2       4           4        3 2
+--R                          (- 800B  - 1056A B  - 416A )C - 224A B  - 2560A B
+--R                        + 
+--R                              5
+--R                          320A
+--R                     *
+--R                         7 2
+--R                        a b
+--R                    + 
+--R                                2                2       2  3
+--R                          (1728C  - 384A C + 384B  - 576A )D
+--R                        + 
+--R                                 2                    3        2   2
+--R                          (576B C  - 1152A B C + 1152B  + 1344A B)D
+--R                        + 
+--R                                  4          3         2        2  2
+--R                              320C  + 1536A C  + (2880B  - 1536A )C
+--R                            + 
+--R                                      2        3         4        2 2      4
+--R                              (1920A B  - 1792A )C + 384B  + 1344A B  - 64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4            3        3        2   2
+--R                          960B C  + 1792A B C  + (960B  + 1536A B)C
+--R                        + 
+--R                                  3        3          5        2 3       4
+--R                          (2176A B  + 2048A B)C + 128B  + 1984A B  + 320A B
+--R                     *
+--R                         8
+--R                        a b
+--R                    + 
+--R                                 3       2           2  2
+--R                          (- 768C  + 768A C - 1536A B )D
+--R                        + 
+--R                                    2        3        3            4       2 3
+--R                          (1536A B C  - 1024B C + 512A B)D - 768A C  - 768B C
+--R                        + 
+--R                               3 2        2 2          4       5
+--R                          1024A C  - 2304A B C - 512A B  - 256A
+--R                     *
+--R                         9
+--R                        a
+--R                 *
+--R                    %%BN0
+--R                + 
+--R                           5          4   7
+--R                      (2A D b - 4A C D a)c
+--R                    + 
+--R                                5         4  2
+--R                          (- B D  - 4A C D )b
+--R                        + 
+--R                                             5                  4
+--R                                (- 2C + 10A)D  + (2B C - 14A B)D
+--R                              + 
+--R                                      2     3  3
+--R                                (12A C  + 4A )D
+--R                         *
+--R                            a b
+--R                        + 
+--R                                 2             2  4            3
+--R                              (4C  - 16A C + 4A )D  + 32A B C D
+--R                            + 
+--R                                     3     3   2
+--R                              (- 8A C  - 8A C)D
+--R                         *
+--R                             2
+--R                            a
+--R                     *
+--R                         6
+--R                        c
+--R                    + 
+--R                                     5                 4        2     3  3  3
+--R                          ((C - 19A)D  + (2B C + 6A B)D  + (2A C  - 2A )D )b
+--R                        + 
+--R                                6       5      2             2      2  4
+--R                              3D  - 2B D  + (2C  + 28A C + 7B  + 18A )D
+--R                            + 
+--R                                     2              2   3          3     3   2
+--R                              (- 6B C  - 4A B C - 6A B)D  + (- 8A C  + 8A C)D
+--R                         *
+--R                               2
+--R                            a b
+--R                        + 
+--R                                           5                   4
+--R                              (- 16C + 8A)D  + (16B C - 80A B)D
+--R                            + 
+--R                                       3        2         2      2          2
+--R                                  - 12C  + 28A C  + (- 16B  - 68A )C + 32A B
+--R                                + 
+--R                                     3
+--R                                  20A
+--R                             *
+--R                                 3
+--R                                D
+--R                            + 
+--R                                   3          2      2         3   2
+--R                              (4B C  - 36A B C  + 12A B C - 12A B)D
+--R                            + 
+--R                                    4      3 2     5
+--R                              (10A C  - 12A C  + 2A )D
+--R                         *
+--R                             2
+--R                            a b
+--R                        + 
+--R                                  2              2  4
+--R                              (16C  - 16A C + 16A )D
+--R                            + 
+--R                                      2                 2   3
+--R                              (- 32B C  + 128A B C - 32A B)D
+--R                            + 
+--R                                      4        3      2 2           2      3
+--R                                    8C  - 32A C  + 48A C  + (- 96A B  - 32A )C
+--R                                  + 
+--R                                      4
+--R                                    8A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                      3      3            5     3 3     5
+--R                              (32A B C  + 32A B C)D - 4A C  + 8A C  - 4A C
+--R                         *
+--R                             3
+--R                            a
+--R                     *
+--R                         5
+--R                        c
+--R                    + 
+--R                                 6       5        2             2     2  4
+--R                              - D  + 8B D  + (- 2C  + 32A C - 3B  - 6A )D
+--R                            + 
+--R                                    2              2   3
+--R                              (- B C  - 6A B C + 3A B)D
+--R                         *
+--R                             4
+--R                            b
+--R                        + 
+--R                                          5                      4
+--R                              (14C - 46A)D  + (- 30B C + 130A B)D
+--R                            + 
+--R                                 3        2      2      2          2      3  3
+--R                              (4C  - 96A C  + (2B  + 12A )C - 18A B  - 48A )D
+--R                            + 
+--R                                   3          2      2     2
+--R                              (4B C  + 24A B C  - 12A B C)D
+--R                         *
+--R                               3
+--R                            a b
+--R                        + 
+--R                                 6        5        2              2      2  4
+--R                              10D  - 16B D  + (- 6C  + 76A C + 18B  + 58A )D
+--R                            + 
+--R                                    2                 3      2   3
+--R                              (24B C  - 240A B C - 16B  - 72A B)D
+--R                            + 
+--R                                    4        3       2      2  2
+--R                                  4C  + 64A C  + (18B  + 24A )C
+--R                                + 
+--R                                        2       3        2 2     4
+--R                                  (60A B  + 128A )C + 18A B  + 4A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                     4          3      2   2     3        4
+--R                              (- 5B C  - 28A B C  + 18A B C  + 4A B C - 5A B)D
+--R                         *
+--R                             2 2
+--R                            a b
+--R                        + 
+--R                                           5                    4
+--R                              (- 24C - 8A)D  + (120B C - 72A B)D
+--R                            + 
+--R                                       3        2         2       2           2
+--R                                  - 40C  + 40A C  + (- 48B  - 248A )C + 240A B
+--R                                + 
+--R                                     3
+--R                                  56A
+--R                             *
+--R                                 3
+--R                                D
+--R                            + 
+--R                                       3          2       3       2           3
+--R                                  40B C  - 72A B C  + (48B  + 312A B)C - 16A B
+--R                                + 
+--R                                       3
+--R                                  - 88A B
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                       5        4         2      2  3      3 2
+--R                                  - 10C  + 18A C  + (- 16B  - 36A )C  - 92A C
+--R                                + 
+--R                                        2 2      4        5
+--R                                  (- 48A B  - 18A )C + 10A
+--R                             *
+--R                                D
+--R                            + 
+--R                                  5          4      2   3      3   2      4
+--R                              2B C  + 10A B C  - 12A B C  - 12A B C  + 10A B C
+--R                            + 
+--R                                5
+--R                              2A B
+--R                         *
+--R                             3
+--R                            a b
+--R                        + 
+--R                                  2      2  4
+--R                              (16C  + 16A )D
+--R                            + 
+--R                                       2                  2   3
+--R                              (- 128B C  + 128A B C - 128A B)D
+--R                            + 
+--R                                     4        3       2       2  2
+--R                                  32C  - 64A C  + (96B  + 192A )C
+--R                                + 
+--R                                           2      3        2 2      4
+--R                                  (- 384A B  - 64A )C + 96A B  + 32A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                         4           3       2   2
+--R                                  - 32B C  + 128A B C  - 192A B C
+--R                                + 
+--R                                         3       3         4
+--R                                  (128A B  + 128A B)C - 32A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                6        5     2 4           2      3  3     4 2
+--R                              4C  - 16A C  - 4A C  + (- 32A B  + 32A )C  - 4A C
+--R                            + 
+--R                                    3 2      5       6
+--R                              (- 32A B  - 16A )C + 4A
+--R                         *
+--R                             4
+--R                            a
+--R                     *
+--R                         4
+--R                        c
+--R                    + 
+--R                                           5                     4
+--R                              (- 5C + 59A)D  + (- 10B C - 42A B)D
+--R                            + 
+--R                                3        2      2     2         2      3  3
+--R                              (C  - 13A C  + (3B  + 3A )C + 3A B  + 17A )D
+--R                         *
+--R                             5
+--R                            b
+--R                        + 
+--R                                   6        5
+--R                              - 22D  + 14B D
+--R                            + 
+--R                                    2               2       2  4
+--R                              (- 14C  - 112A C - 50B  - 162A )D
+--R                            + 
+--R                                    2                3       2   3
+--R                              (46B C  + 20A B C + 10B  + 102A B)D
+--R                            + 
+--R                                      4        3         2      2  2
+--R                                  - 4C  + 52A C  + (- 12B  - 12A )C
+--R                                + 
+--R                                          2      3
+--R                                  (- 12A B  - 68A )C
+--R                             *
+--R                                 2
+--R                                D
+--R                         *
+--R                               4
+--R                            a b
+--R                        + 
+--R                                          5                       4
+--R                              (72C + 40A)D  + (- 160B C + 288A B)D
+--R                            + 
+--R                                     3        2        2       2           2
+--R                                  66C  - 46A C  + (144B  + 598A )C - 304A B
+--R                                + 
+--R                                       3
+--R                                  - 58A
+--R                             *
+--R                                 3
+--R                                D
+--R                            + 
+--R                                         3           2         3       2
+--R                                  - 80B C  + 264A B C  + (- 32B  - 336A B)C
+--R                                + 
+--R                                     3
+--R                                  88A B
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                    5        4       2      2  3
+--R                                  5C  - 67A C  + (14B  + 10A )C
+--R                                + 
+--R                                       2      3  2        2 2    4       3 2
+--R                                  (6A B  + 98A )C  + (- 6A B  + A )C + 2A B
+--R                                + 
+--R                                       5
+--R                                  - 15A
+--R                             *
+--R                                D
+--R                         *
+--R                             2 3
+--R                            a b
+--R                        + 
+--R                                     5         2              2  4
+--R                              - 80B D  + (- 64C  - 128A C + 8B )D
+--R                            + 
+--R                                     2                 3       2   3
+--R                              (208B C  - 480A B C - 64B  - 176A B)D
+--R                            + 
+--R                                       4         3          2       2  2
+--R                                  - 41C  + 116A C  + (- 144B  - 582A )C
+--R                                + 
+--R                                         2      3       4      2 2      4
+--R                                  (672A B  - 12A )C + 8B  + 48A B  - 41A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                       4           3       2   2
+--R                                  50B C  - 328A B C  + 204A B C
+--R                                + 
+--R                                          3       3         4
+--R                                  (- 64A B  - 200A B)C - 14A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                  6        5        2     2  4
+--R                              - 2C  + 28A C  + (- 5B  + 2A )C
+--R                            + 
+--R                                   2      3  3       2 2     4  2
+--R                              (4A B  - 56A )C  + (18A B  + 2A )C
+--R                            + 
+--R                                 3 2      5       4 2     6
+--R                              (4A B  + 28A )C - 5A B  - 2A
+--R                         *
+--R                             3 2
+--R                            a b
+--R                        + 
+--R                                               4
+--R                              (192B C + 64A B)D
+--R                            + 
+--R                                       3         2          2       2
+--R                                  - 16C  + 208A C  + (- 320B  - 176A )C
+--R                                + 
+--R                                        2       3
+--R                                  256A B  + 112A
+--R                             *
+--R                                 3
+--R                                D
+--R                            + 
+--R                                       3           2       3        2
+--R                                  80B C  - 144A B C  + (64B  + 1008A B)C
+--R                                + 
+--R                                          3       3
+--R                                  - 320A B  - 304A B
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                       5       4         2       2  3
+--R                                  - 24C  - 8A C  + (- 16B  + 144A )C
+--R                                + 
+--R                                          2       3  2
+--R                                  (- 48A B  + 112A )C
+--R                                + 
+--R                                        4       2 2     4          4       3 2
+--R                                  (- 64B  - 432A B  + 8A )C - 32A B  + 112A B
+--R                                + 
+--R                                     5
+--R                                  24A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    5          4       3      2   3
+--R                              - 8B C  + 88A B C  + (16B  + 48A B)C
+--R                            + 
+--R                                    3      3   2       2 3      4         3 3
+--R                              (48A B  + 48A B)C  + (48A B  + 88A B)C + 16A B
+--R                            + 
+--R                                  5
+--R                              - 8A B
+--R                         *
+--R                             4
+--R                            a b
+--R                        + 
+--R                                       2       2   3
+--R                              (- 128B C  - 128A B)D
+--R                            + 
+--R                                     4         3        2       2  2
+--R                                  32C  - 128A C  + (384B  + 192A )C
+--R                                + 
+--R                                           2       3         2 2      4
+--R                                  (- 384A B  - 128A )C + 384A B  + 32A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                          4           3          3       2   2
+--R                                  - 128B C  + 256A B C  + (- 128B  - 768A B)C
+--R                                + 
+--R                                         3       3          2 3       4
+--R                                  (512A B  + 256A B)C - 128A B  - 128A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                 6       2      2  4         2 3
+--R                              16C  + (32B  - 16A )C  - 128A B C
+--R                            + 
+--R                                   2 2      4  2           4       3 2
+--R                              (192A B  - 16A )C  + (- 64A B  - 128A B )C
+--R                            + 
+--R                                 4 2      6
+--R                              32A B  + 16A
+--R                         *
+--R                             5
+--R                            a
+--R                     *
+--R                         3
+--R                        c
+--R                    + 
+--R                                6        5       2              2      2  4
+--R                              6D  - 22B D  + (10C  - 76A C + 18B  + 42A )D
+--R                            + 
+--R                                   2               3      2   3
+--R                              (2B C  + 36A B C - 2B  - 30A B)D
+--R                         *
+--R                             6
+--R                            b
+--R                        + 
+--R                                           5                     4
+--R                              (- 18C + 6A)D  + (148B C - 260A B)D
+--R                            + 
+--R                                       3         2         2       2           2
+--R                                  - 22C  + 262A C  + (- 34B  - 114A )C + 102A B
+--R                                + 
+--R                                      3
+--R                                  114A
+--R                             *
+--R                                 3
+--R                                D
+--R                            + 
+--R                                     3           2      3       2     2
+--R                              (- 8B C  - 144A B C  + (8B  + 120A B)C)D
+--R                         *
+--R                               5
+--R                            a b
+--R                        + 
+--R                                   6         5
+--R                              - 15D  + 136B D
+--R                            + 
+--R                                   2              2       2  4
+--R                              (- 8C  + 48A C - 22B  - 216A )D
+--R                            + 
+--R                                       2                  3       2   3
+--R                              (- 162B C  + 436A B C + 112B  + 486A B)D
+--R                            + 
+--R                                       4         3         2      2  2
+--R                                  - 11C  - 268A C  + (- 24B  - 18A )C
+--R                                + 
+--R                                           2       3       4       2 2      4
+--R                                  (- 288A B  - 300A )C - 3B  - 120A B  - 27A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                       4           3        3       2   2
+--R                                  12B C  + 184A B C  + (- 6B  - 144A B)C
+--R                                + 
+--R                                        3      3        2 3      4
+--R                                  (12A B  - 24A B)C + 2A B  + 36A B
+--R                             *
+--R                                D
+--R                         *
+--R                             2 4
+--R                            a b
+--R                        + 
+--R                                          5                       4
+--R                              (56C + 72A)D  + (- 464B C - 208A B)D
+--R                            + 
+--R                                     3         2        2       2           2
+--R                                  84C  - 300A C  + (448B  + 908A )C - 704A B
+--R                                + 
+--R                                     3
+--R                                  12A
+--R                             *
+--R                                 3
+--R                                D
+--R                            + 
+--R                                          3           2          3        2
+--R                                  - 208B C  + 336A B C  + (- 256B  - 1824A B)C
+--R                                + 
+--R                                        3       3
+--R                                  256A B  + 448A B
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                     5        4       2       2  3
+--R                                  48C  + 72A C  + (92B  + 160A )C
+--R                                + 
+--R                                         2       3  2
+--R                                  (108A B  + 272A )C
+--R                                + 
+--R                                      4       2 2       4          4      3 2
+--R                                  (40B  + 516A B  + 112A )C + 24A B  - 12A B
+--R                                + 
+--R                                       5
+--R                                  - 24A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    5          4      2   3
+--R                              - 6B C  - 78A B C  + 52A B C
+--R                            + 
+--R                                      3      3   2         2 3      4        5
+--R                              (- 16A B  + 52A B)C  + (- 16A B  - 78A B)C - 6A B
+--R                         *
+--R                             3 3
+--R                            a b
+--R                        + 
+--R                                    2                2      2  4
+--R                              (- 72C  - 240A C + 240B  - 72A )D
+--R                            + 
+--R                                     2                 3      2   3
+--R                              (480B C  + 576A B C + 96B  + 96A B)D
+--R                            + 
+--R                                       4         3          2        2  2
+--R                                  - 98C  + 456A C  + (- 768B  - 1068A )C
+--R                                + 
+--R                                          2       3         4      4
+--R                                  (1152A B  - 312A )C + 112B  + 30A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                        4           3        3        2   2
+--R                                  348B C  - 560A B C  + (224B  + 1512A B)C
+--R                                + 
+--R                                           3       3         5      2 3      4
+--R                                  (- 704A B  - 304A B)C + 16B  + 96A B  + 92A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                   6         2      2  4         2       3  3
+--R                              - 24C  + (- 42B  - 40A )C  + (40A B  - 128A )C
+--R                            + 
+--R                                    4       2 2      4  2           4      3 2
+--R                              (- 24B  - 348A B  - 40A )C  + (- 16A B  + 40A B )C
+--R                            + 
+--R                                   2 4      4 2      6
+--R                              - 24A B  - 42A B  - 24A
+--R                         *
+--R                             4 2
+--R                            a b
+--R                        + 
+--R                                     3         2          2      2           2
+--R                                  32C  + 288A C  + (- 576B  + 96A )C - 192A B
+--R                                + 
+--R                                     3
+--R                                  96A
+--R                             *
+--R                                 3
+--R                                D
+--R                            + 
+--R                                         3           2        3       2
+--R                                  - 32B C  - 864A B C  + (320B  + 672A B)C
+--R                                + 
+--R                                          3       3
+--R                                  - 448A B  - 544A B
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                     5         4        2       2  3
+--R                                  32C  - 256A C  + (160B  + 320A )C
+--R                                + 
+--R                                        2       3  2
+--R                                  (96A B  + 512A )C
+--R                                + 
+--R                                      4        2 2      4           4       3 2
+--R                                (- 32B  - 1056A B  - 96A )C + 160A B  + 544A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                     5          4         3       2   3
+--R                              - 96B C  + 32A B C  + (- 32B  - 192A B)C
+--R                            + 
+--R                                     3       3   2       5       2 3      4
+--R                              (160A B  - 192A B)C  + (32B  + 160A B  + 32A B)C
+--R                            + 
+--R                                   5      3 3      5
+--R                              32A B  - 32A B  - 96A B
+--R                         *
+--R                             5
+--R                            a b
+--R                        + 
+--R                                       3       2 2       3        2 2  2
+--R                              (- 128A C  + 384B C  - 128A C + 384A B )D
+--R                            + 
+--R                                          4           3          3       2   2
+--R                                  - 128B C  + 512A B C  + (- 512B  - 768A B)C
+--R                                + 
+--R                                         3       3          2 3       4
+--R                                  (512A B  + 512A B)C - 512A B  - 128A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                   5       2 4            2       3  3
+--R                              64A C  + 128B C  + (- 256A B  - 128A )C
+--R                            + 
+--R                                  4       2 2  2            4       3 2      5
+--R                              (64B  + 768A B )C  + (- 256A B  - 256A B  + 64A )C
+--R                            + 
+--R                                 2 4       4 2
+--R                              64A B  + 128A B
+--R                         *
+--R                             6
+--R                            a
+--R                     *
+--R                         2
+--R                        c
+--R                    + 
+--R                                         5                  4
+--R                              (4C - 60A)D  + (8B C + 72A B)D
+--R                            + 
+--R                                      3        2         2      2          2
+--R                                  - 4C  + 20A C  + (- 12B  - 12A )C - 12A B
+--R                                + 
+--R                                       3
+--R                                  - 36A
+--R                             *
+--R                                 3
+--R                                D
+--R                         *
+--R                             7
+--R                            b
+--R                        + 
+--R                                 6        5                2       2  4
+--R                              32D  - 48B D  + (208A C + 64B  + 336A )D
+--R                            + 
+--R                                       2                3       2   3
+--R                              (- 112B C  - 64A B C - 48B  - 336A B)D
+--R                            + 
+--R                                     4        3       2      2  2
+--R                                  16C  - 80A C  + (48B  + 48A )C
+--R                                + 
+--R                                        2       3
+--R                                  (48A B  + 144A )C
+--R                             *
+--R                                 2
+--R                                D
+--R                         *
+--R                               6
+--R                            a b
+--R                        + 
+--R                                              5                    4
+--R                              (- 145C - 177A)D  + (180B C + 84A B)D
+--R                            + 
+--R                                       3         2          2        2
+--R                                  - 54C  - 178A C  + (- 458B  - 1442A )C
+--R                                + 
+--R                                        2       3
+--R                                  470A B  - 294A
+--R                             *
+--R                                 3
+--R                                D
+--R                            + 
+--R                                        3           2        3        2
+--R                                  332B C  - 348A B C  + (140B  + 1188A B)C
+--R                                + 
+--R                                         3       3
+--R                                  - 20A B  - 180A B
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                       5         4         2      2  3
+--R                                  - 21C  + 103A C  + (- 66B  - 50A )C
+--R                                + 
+--R                                          2       3  2        4     2 2     4
+--R                                  (- 54A B  - 210A )C  + (- 5B  - 6A B  - 9A )C
+--R                                + 
+--R                                        4      3 2      5
+--R                                  - 5A B  - 18A B  + 27A
+--R                             *
+--R                                D
+--R                         *
+--R                             2 5
+--R                            a b
+--R                        + 
+--R                                   5        2                2       2  4
+--R                              60B D  + (213C  + 794A C - 280B  + 261A )D
+--R                            + 
+--R                                       2                 3       2   3
+--R                              (- 164B C  - 392A B C - 48B  + 348A B)D
+--R                            + 
+--R                                      4        3        2        2  2
+--R                                  118C  - 56A C  + (870B  + 2100A )C
+--R                                + 
+--R                                           2        3         4       2 2     4
+--R                                  (- 900A B  + 1256A )C - 104B  - 426A B  + 6A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                          4           3          3        2   2
+--R                                  - 352B C  + 480A B C  + (- 124B  - 1056A B)C
+--R                                + 
+--R                                         3       3         5      2 3
+--R                                  (104A B  + 160A B)C - 12B  - 92A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                6        5       2     2  4         2       3  3
+--R                              9C  - 42A C  + (30B  + 7A )C  + (24A B  + 116A )C
+--R                            + 
+--R                                 4      2 2     4  2         4      3 2      5
+--R                              (5B  - 12A B  + 7A )C  + (10A B  + 24A B  - 42A )C
+--R                            + 
+--R                                2 4      4 2     6
+--R                              5A B  + 30A B  + 9A
+--R                         *
+--R                             3 4
+--R                            a b
+--R                        + 
+--R                                                  4
+--R                              (- 224B C - 288A B)D
+--R                            + 
+--R                                       3          2        2       2           2
+--R                                  - 24C  - 1432A C  + (992B  - 712A )C + 352A B
+--R                                + 
+--R                                        3
+--R                                  - 328A
+--R                             *
+--R                                 3
+--R                                D
+--R                            + 
+--R                                          3           2          3        2
+--R                                  - 144B C  + 816A B C  + (- 320B  - 1776A B)C
+--R                                + 
+--R                                        3       3
+--R                                  832A B  + 336A B
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                       5         4          2        2  3
+--R                                  - 92C  + 100A C  + (- 488B  - 1208A )C
+--R                                + 
+--R                                           2        3  2
+--R                                  (- 168A B  - 1560A )C
+--R                                + 
+--R                                       4        2 2       4          4       3 2
+--R                                  (176B  + 1608A B  - 172A )C - 16A B  - 760A B
+--R                                + 
+--R                                       5
+--R                                  - 12A
+--R                             *
+--R                                D
+--R                            + 
+--R                                    5           4       3       2   3
+--R                              120B C  - 104A B C  + (16B  + 112A B)C
+--R                            + 
+--R                                      3       3   2         2 3       4
+--R                              (- 16A B  + 112A B)C  + (- 16A B  - 104A B)C
+--R                            + 
+--R                                 3 3       5
+--R                              16A B  + 120A B
+--R                         *
+--R                             4 3
+--R                            a b
+--R                        + 
+--R                                     2                  3       2   3
+--R                              (288B C  + 960A B C - 320B  + 288A B)D
+--R                            + 
+--R                                        4          3           2       2  2
+--R                                  - 236C  + 1264A C  + (- 1152B  + 696A )C
+--R                                + 
+--R                                         2       3         4       2 2       4
+--R                                (- 768A B  + 496A )C - 208B  - 384A B  + 276A
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                        4           3        3        2   2
+--R                                  280B C  - 608A B C  + (768B  + 2064A B)C
+--R                                + 
+--R                                          3      3         5       2 3      4
+--R                                (- 1280A B  - 96A B)C - 96B  + 256A B  + 24A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                 6        5      2       2  4
+--R                              24C  - 16A C  + (4B  + 232A )C
+--R                            + 
+--R                                     2       3  3         4       2 2       4  2
+--R                              (560A B  + 544A )C  + (- 96B  - 936A B  + 232A )C
+--R                            + 
+--R                                     4       3 2      5        6      2 4
+--R                              (192A B  + 560A B  - 16A )C - 16B  - 96A B
+--R                            + 
+--R                                4 2      6
+--R                              4A B  + 24A
+--R                         *
+--R                             5 2
+--R                            a b
+--R                        + 
+--R                                          3            2        3       2
+--R                                  - 128B C  - 1152A B C  + (768B  - 384A B)C
+--R                                + 
+--R                                        3       3
+--R                                  256A B  - 384A B
+--R                             *
+--R                                 2
+--R                                D
+--R                            + 
+--R                                      5         4        2       2  3
+--R                                  224C  - 512A C  + (320B  - 320A )C
+--R                                + 
+--R                                        2 2          2 2       4           4
+--R                                  960A B C  + (- 576A B  - 416A )C + 384A B
+--R                                + 
+--R                                      3 2
+--R                                  832A B
+--R                             *
+--R                                D
+--R                            + 
+--R                                     5          4          3       2   3
+--R                              - 96B C  + 32A B C  + (- 320B  - 448A B)C
+--R                            + 
+--R                                    3       3   2       2 3      4          3 3
+--R                              (64A B  - 448A B)C  + (64A B  + 32A B)C - 320A B
+--R                            + 
+--R                                   5
+--R                              - 96A B
+--R                         *
+--R                             6
+--R                            a b
+--R                        + 
+--R                                       3       3 2       3          2 3        6
+--R                              (512A B C  - 512B C  + 512A B C - 512A B )D - 64C
+--R                            + 
+--R                                   5        2      2  4            2       3  3
+--R                              64A C  + (128B  + 64A )C  + (- 512A B  - 128A )C
+--R                            + 
+--R                                   4       2 2      4  2
+--R                              (256B  + 768A B  + 64A )C
+--R                            + 
+--R                                       4       3 2      5         2 4       4 2
+--R                              (- 256A B  - 512A B  + 64A )C + 256A B  + 128A B
+--R                            + 
+--R                                   6
+--R                              - 64A
+--R                         *
+--R                             7
+--R                            a
+--R                     *
+--R                        c
+--R                    + 
+--R                              6        5        2              2      2  4
+--R                          - 8D  + 24B D  + (- 8C  + 48A C - 24B  - 72A )D
+--R                        + 
+--R                               2               3      2   3
+--R                          (8B C  - 48A B C + 8B  + 72A B)D
+--R                     *
+--R                         8
+--R                        b
+--R                    + 
+--R                                       5                      4
+--R                          (24C + 120A)D  + (- 144B C - 48A B)D
+--R                        + 
+--R                              3         2        2       2          2      3  3
+--R                          (40C  - 232A C  + (152B  + 312A )C - 72A B  + 72A )D
+--R                        + 
+--R                                  3           2         3       2     2
+--R                          (- 32B C  + 192A B C  + (- 32B  - 288A B)C)D
+--R                     *
+--R                           7
+--R                        a b
+--R                    + 
+--R                               6        5       2               2       2  4
+--R                          - 10D  - 78B D  + (28C  - 648A C + 84B  - 228A )D
+--R                        + 
+--R                                 2                 3      2   3
+--R                          (332B C  + 312A B C - 20B  - 84A B)D
+--R                        + 
+--R                                   4         3          2       2  2
+--R                              - 74C  + 408A C  + (- 324B  - 444A )C
+--R                            + 
+--R                                     2       3        4       2 2      4
+--R                              (120A B  - 360A )C + 22B  + 252A B  + 54A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3       3       2   2
+--R                              42B C  - 248A B C  + (44B  + 348A B)C
+--R                            + 
+--R                                     3      3        5      2 3      4
+--R                              (- 8A B  + 72A B)C + 2B  + 12A B  - 54A B
+--R                         *
+--R                            D
+--R                     *
+--R                         2 6
+--R                        a b
+--R                    + 
+--R                                      5                     4
+--R                          (84C - 12A)D  + (414B C + 318A B)D
+--R                        + 
+--R                                    3          2          2       2           2
+--R                              - 208C  + 1424A C  + (- 376B  + 912A )C - 216A B
+--R                            + 
+--R                                  3
+--R                              304A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                      3           2        3       2
+--R                              - 356B C  - 780A B C  + (196B  + 468A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 348A B  - 132A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2       2  3
+--R                              60C  - 308A C  + (272B  + 216A )C
+--R                            + 
+--R                                     2       3  2         4       2 2      4
+--R                              (144A B  + 536A )C  + (- 60B  - 912A B  - 84A )C
+--R                            + 
+--R                                  4       3 2      5
+--R                              4A B  + 240A B  - 36A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4         3       2   3
+--R                          - 18B C  + 102A B C  + (- 20B  - 116A B)C
+--R                        + 
+--R                               3       3   2        5     2 3       4          5
+--R                          (4A B  - 116A B)C  + (- 2B  + 4A B  + 102A B)C - 2A B
+--R                        + 
+--R                               3 3      5
+--R                          - 20A B  - 18A B
+--R                     *
+--R                         3 5
+--R                        a b
+--R                    + 
+--R                                 2              2      2  4
+--R                          (- 290C  + 60A C - 60B  + 30A )D
+--R                        + 
+--R                                   2                   3       2   3
+--R                          (- 880B C  - 1344A B C + 192B  - 528A B)D
+--R                        + 
+--R                                  4          3        2        2  2
+--R                              340C  - 1584A C  + (612B  - 1416A )C
+--R                            + 
+--R                                     2       3        4      2 2       4
+--R                              (840A B  - 816A )C + 88B  + 36A B  - 300A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4           3          3       2   2
+--R                              168B C  + 832A B C  + (- 400B  - 624A B)C
+--R                            + 
+--R                                    3       5       2 3       4
+--R                              832A B C + 32B  + 144A B  + 264A B
+--R                         *
+--R                            D
+--R                        + 
+--R                               6        5         2      2  4
+--R                          - 18C  + 84A C  + (- 72B  - 14A )C
+--R                        + 
+--R                                   2       3  3       4       2 2      4  2
+--R                          (- 224A B  - 232A )C  + (46B  + 720A B  - 14A )C
+--R                        + 
+--R                                  4       3 2      5       6      2 4      4 2
+--R                          (- 36A B  - 224A B  + 84A )C + 4B  + 46A B  - 72A B
+--R                        + 
+--R                               6
+--R                          - 18A
+--R                     *
+--R                         4 4
+--R                        a b
+--R                    + 
+--R                                    3         2        2       2           2
+--R                                528C  - 112A C  + (224B  - 144A )C + 288A B
+--R                              + 
+--R                                     3
+--R                                - 16A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3            2          3        2
+--R                              928B C  + 2208A B C  + (- 704B  + 1440A B)C
+--R                            + 
+--R                                      3       3
+--R                              - 192A B  + 672A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    5         4          2        2  3
+--R                              - 240C  + 880A C  + (- 400B  + 1056A )C
+--R                            + 
+--R                                        2       3  2
+--R                              (- 1296A B  + 608A )C
+--R                            + 
+--R                                    4       2 2       4           4       3 2
+--R                              (- 96B  + 528A B  + 720A )C - 416A B  - 624A B
+--R                            + 
+--R                                 5
+--R                              48A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4        3       2   3
+--R                          - 24B C  - 312A B C  + (224B  + 208A B)C
+--R                        + 
+--R                                   3       3   2         5       2 3       4
+--R                          (- 416A B  + 208A B)C  + (- 32B  - 416A B  - 312A B)C
+--R                        + 
+--R                                 5       3 3      5
+--R                          - 32A B  + 224A B  - 24A B
+--R                     *
+--R                         5 3
+--R                        a b
+--R                    + 
+--R                                    4        3          2       2  2
+--R                              - 536C  + 96A C  + (- 288B  + 240A )C
+--R                            + 
+--R                                       2      3         4       2 2      4
+--R                              (- 960A B  + 96A )C + 160B  - 288A B  - 24A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4            3        3        2   2
+--R                              - 480B C  - 1664A B C  + (896B  - 1344A B)C
+--R                            + 
+--R                                     3        3          5       2 3       4
+--R                              (256A B  - 1152A B)C + 128B  + 384A B  - 480A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6         5       2       2  4
+--R                          64C  - 192A C  + (72B  - 320A )C
+--R                        + 
+--R                                 2       3  3         4       2 2       4  2
+--R                          (736A B  - 128A )C  + (- 32B  - 720A B  - 320A )C
+--R                        + 
+--R                                 4       3 2       5        6      2 4      4 2
+--R                          (576A B  + 736A B  - 192A )C + 32B  - 32A B  + 72A B
+--R                        + 
+--R                             6
+--R                          64A
+--R                     *
+--R                         6 2
+--R                        a b
+--R                    + 
+--R                                  5        4        2       2  3
+--R                              288C  - 32A C  + (128B  - 192A )C
+--R                            + 
+--R                                      2      3  2          4       2 2      4
+--R                              (1152A B  - 64A )C  + (- 384B  + 384A B  - 96A )C
+--R                            + 
+--R                                      4       3 2      5
+--R                              - 128A B  + 384A B  + 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                               5           4          3       2   3
+--R                          96B C  + 480A B C  + (- 384B  + 448A B)C
+--R                        + 
+--R                                   3       3   2          5       2 3       4
+--R                          (- 128A B  + 448A B)C  + (- 128B  - 128A B  + 480A B)C
+--R                        + 
+--R                                  5       3 3      5
+--R                          - 128A B  - 384A B  + 96A B
+--R                     *
+--R                         7
+--R                        a b
+--R                    + 
+--R                               6      2 4         2 3        4      4  2
+--R                          - 64C  + 64A C  - 512A B C  + (256B  + 64A )C
+--R                        + 
+--R                                3 2        2 4      6
+--R                          - 512A B C + 256A B  - 64A
+--R                     *
+--R                         8
+--R                        a
+--R                 *
+--R                    x
+--R                + 
+--R                    3 3   7
+--R                  4A D a c
+--R                + 
+--R                          5     3 3  2
+--R                      (A D  - 2A D )b
+--R                    + 
+--R                             5               2  4     2   3     3   2
+--R                      (- 2B D  + (- 2A C - 4A )D  - 6A B D  + 6A C D )a b
+--R                    + 
+--R                                4        2        2      3  3      3   2
+--R                          4B C D  + (- 4A C + 4A B  + 16A )D  - 20A B D
+--R                        + 
+--R                                3 2     5
+--R                          (- 12A C  + 4A )D
+--R                     *
+--R                         2
+--R                        a
+--R                 *
+--R                     6
+--R                    c
+--R                + 
+--R                                  2  4     2   3  3
+--R                      ((- 2A C + A )D  + 3A B D )b
+--R                    + 
+--R                                   5                 4
+--R                          (C + 6A)D  + (4B C - 3A B)D
+--R                        + 
+--R                               2      2       3  3        2        3   2
+--R                          (6A C  + 14A C - 53A )D  + (- 9A B C + 2A B)D
+--R                     *
+--R                           2
+--R                        a b
+--R                    + 
+--R                            6        5        2             2  4
+--R                          2D  - 10B D  + (- 2C  - 2A C + 10B )D
+--R                        + 
+--R                                  2               3  3
+--R                          (- 12B C  + 12A B C - 2B )D
+--R                        + 
+--R                                 3      2 2        2      3        2 2      4  2
+--R                          (- 4A C  - 30A C  + (6A B  + 64A )C + 30A B  + 14A )D
+--R                        + 
+--R                              2   2      3         4        3 3     5
+--R                          (18A B C  + 12A B C - 10A B)D + 2A C  - 2A C
+--R                     *
+--R                         2
+--R                        a b
+--R                    + 
+--R                                5                   4
+--R                          - 4C D  + (16B C - 12A B)D
+--R                        + 
+--R                                 2         2      2          2     3  3
+--R                          (- 4A C  + (- 28B  - 16A )C + 16A B  - 4A )D
+--R                        + 
+--R                               3      2           3      3   2
+--R                          (8B C  + 24A B C - 20A B  - 80A B)D
+--R                        + 
+--R                              2 3           2      3  2     4       3 2      5
+--R                          (44A C  + (- 12A B  - 48A )C  + 4A C + 36A B  + 16A )D
+--R                        + 
+--R                             3   2     5
+--R                          20A B C  - 4A B
+--R                     *
+--R                         3
+--R                        a
+--R                 *
+--R                     5
+--R                    c
+--R                + 
+--R                             5         4       2     2       2      3  3  4
+--R                      (- 9A D  + 2A B D  + (A C  - 4A C - A B  + 19A )D )b
+--R                    + 
+--R                             6        5        2            2      2  4
+--R                          - D  + 17B D  + (- 2C  + 5A C - 5B  + 33A )D
+--R                        + 
+--R                                 2              3      2   3
+--R                          (- 2B C  - 10A B C + B  + 60A B)D
+--R                        + 
+--R                                 3      2 2        2      3       2 2     4  2
+--R                          (- 4A C  + 12A C  + (3A B  - 58A )C - 3A B  - 2A )D
+--R                     *
+--R                           3
+--R                        a b
+--R                    + 
+--R                                5                     4
+--R                          - 5A D  + (- 27B C - 52A B)D
+--R                        + 
+--R                             3        2       2      2          2      3  3
+--R                          (6C  + 10A C  + (12B  + 88A )C - 49A B  - 92A )D
+--R                        + 
+--R                               3        3       2          3       3   2
+--R                          (8B C  + (- 3B  - 102A B)C - 8A B  + 148A B)D
+--R                        + 
+--R                                  4      2 3          2      3  2
+--R                              5A C  - 20A C  + (- 6A B  + 93A )C
+--R                            + 
+--R                                    2 2     4       3 2      5
+--R                              (- 18A B  - 2A )C - 2A B  - 32A
+--R                         *
+--R                            D
+--R                        + 
+--R                              2   3     3   2     4        5
+--R                          - 3A B C  - 8A B C  + 5A B C + 2A B
+--R                     *
+--R                         2 2
+--R                        a b
+--R                    + 
+--R                             6        5      2              2      2  4
+--R                          10D  - 16B D  + (6C  + 28A C + 68B  + 50A )D
+--R                        + 
+--R                                  2                3     2   3
+--R                          (- 18B C  + 76A B C - 16B  + 2A B)D
+--R                        + 
+--R                                  4        3       2       2  2
+--R                              - 4C  + 22A C  + (18B  - 258A )C
+--R                            + 
+--R                                    2      3        4      2 2      4
+--R                              (36A B  + 94A )C + 10B  + 78A B  + 26A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4         3      3      2   2
+--R                              - 10B C  - 4A B C  + (6B  + 24A B)C
+--R                            + 
+--R                                    3       3         2 3      4
+--R                              (12A B  - 100A B)C - 54A B  - 94A B
+--R                         *
+--R                            D
+--R                        + 
+--R                                5     2 4        2      3  3
+--R                          - 2A C  - 6A C  + (2A B  - 12A )C
+--R                        + 
+--R                              2 2      4  2         3 2     5        4 2     6
+--R                        (- 30A B  - 16A )C  + (- 38A B  - 2A )C + 10A B  + 6A
+--R                     *
+--R                         3
+--R                        a b
+--R                    + 
+--R                                       5                   4
+--R                          (- 16C + 8A)D  + (40B C - 48A B)D
+--R                        + 
+--R                               3        2          2     2          2      3  3
+--R                          (- 4C  - 16A C  + (- 112B  + 4A )C + 72A B  - 80A )D
+--R                        + 
+--R                                     3          2       3      2           3
+--R                                32B C  + 12A B C  + (72B  + 96A B)C - 80A B
+--R                              + 
+--R                                  3
+--R                                4A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4         2       2  3
+--R                              - 52A C  + (- 12B  + 176A )C
+--R                            + 
+--R                                      2      3  2         2 2      4          4
+--R                              (- 48A B  - 64A )C  + (- 36A B  + 16A )C + 32A B
+--R                            + 
+--R                                  3 2      5
+--R                              144A B  - 12A
+--R                         *
+--R                            D
+--R                        + 
+--R                              5      2   3         3      3   2      4
+--R                          4B C  - 80A B C  + (20A B  + 80A B)C  - 20A B C
+--R                        + 
+--R                               3 3      5
+--R                          - 20A B  - 16A B
+--R                     *
+--R                         4
+--R                        a
+--R                 *
+--R                     4
+--R                    c
+--R                + 
+--R                                  2  4      2   3  5
+--R                      ((16A C - 8A )D  - 24A B D )b
+--R                    + 
+--R                                       5                     4
+--R                          (- 5C - 20A)D  + (- 26B C + 49A B)D
+--R                        + 
+--R                            3        2      2       2         2       3  3
+--R                          (C  - 34A C  + (3B  - 135A )C - 2A B  + 196A )D
+--R                        + 
+--R                                 2      2         3      3   2
+--R                          (3A B C  + 78A B C + A B  - 13A B)D
+--R                     *
+--R                           4
+--R                        a b
+--R                    + 
+--R                               6        5       2              2      2  4
+--R                          - 16D  + 47B D  + (12C  + 13A C - 99B  - 96A )D
+--R                        + 
+--R                                2                3       2   3
+--R                          (77B C  - 86A B C + 29B  - 102A B)D
+--R                        + 
+--R                                  4       3         2       2  2
+--R                              - 4C  - 4A C  + (- 15B  + 378A )C
+--R                            + 
+--R                                   2       3      4       2 2       4
+--R                              (3A B  - 335A )C - B  - 201A B  - 105A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 2   2        3      3         2 3      4
+--R                          (- 105A B C  + (6A B  - 48A B)C + 13A B  + 89A B)D
+--R                        + 
+--R                            2 4       2     3  3       2 2     4  2
+--R                          3A C  + (A B  - 9A )C  + (12A B  + 3A )C
+--R                        + 
+--R                             3 2      5       4 2     6
+--R                          (6A B  + 13A )C - 5A B  - 2A
+--R                     *
+--R                         2 3
+--R                        a b
+--R                    + 
+--R                                      5                      4
+--R                          (20C - 22A)D  + (- 114B C + 30A B)D
+--R                        + 
+--R                                    3         2        2       2          2
+--R                                - 2C  - 129A C  + (242B  + 254A )C + 38A B
+--R                              + 
+--R                                    3
+--R                                221A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                     3          2         3      2            3
+--R                              - 59B C  - 42A B C  + (- 86B  - 69A B)C + 146A B
+--R                            + 
+--R                                  3
+--R                              266A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                5        4       2       2  3
+--R                              5C  + 50A C  + (14B  - 388A )C
+--R                            + 
+--R                                    2       3  2        4       2 2      4
+--R                              (81A B  + 218A )C  + (- 6B  + 198A B  + 79A )C
+--R                            + 
+--R                                  4       3 2     5
+--R                              8A B  - 101A B  + 4A
+--R                         *
+--R                            D
+--R                        + 
+--R                                4       3      2   3        3      3   2
+--R                          7A B C  + (- B  + 82A B)C  + (2A B  - 68A B)C
+--R                        + 
+--R                              2 3      4         3 3      5
+--R                          (57A B  + 62A B)C + 14A B  + 13A B
+--R                     *
+--R                         3 2
+--R                        a b
+--R                    + 
+--R                            6        5       2              2      2  4
+--R                          8D  - 48B D  + (14C  - 20A C + 80B  + 38A )D
+--R                        + 
+--R                                2                 3       2   3
+--R                          (32B C  - 64A B C - 160B  - 272A B)D
+--R                        + 
+--R                                   4         3         2       2  2
+--R                              - 12C  + 344A C  + (- 84B  - 384A )C
+--R                            + 
+--R                                       2      3       4      2 2      4
+--R                              (- 264A B  - 72A )C + 8B  + 12A B  - 68A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4           3       2   2
+--R                              - 16B C  + 112A B C  + 336A B C
+--R                            + 
+--R                                      3       3         5       2 3      4
+--R                              (- 64A B  - 208A B)C - 16B  - 208A B  - 64A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              6       5         2      2  4        2      3  3
+--R                          - 2C  - 4A C  + (- 12B  + 66A )C  + (8A B  + 40A )C
+--R                        + 
+--R                                4      2 2      4  2
+--R                          (- 10B  + 48A B  - 14A )C
+--R                        + 
+--R                                  4     3 2      5        2 4       4 2      6
+--R                          (- 36A B  + 8A B  + 28A )C + 30A B  + 108A B  + 14A
+--R                     *
+--R                         4
+--R                        a b
+--R                    + 
+--R                                        5                   4
+--R                          (- 16C + 32A)D  + (96B C - 80A B)D
+--R                        + 
+--R                                3          2      2           2      3  3
+--R                          (- 16C  + (- 160B  + 80A )C + 224A B  - 64A )D
+--R                        + 
+--R                                  2       3          3       3   2
+--R                          (48A B C  + 288B C - 160A B  + 336A B)D
+--R                        + 
+--R                                 5         4         2       2  3      3 2
+--R                              16C  - 208A C  + (- 48B  + 160A )C  - 64A C
+--R                            + 
+--R                                    4       2 2      4           4       5
+--R                              (- 80B  - 144A B  + 80A )C + 128A B  - 112A
+--R                         *
+--R                            D
+--R                        + 
+--R                               5          4       2   3         3       3   2
+--R                          16B C  + 80A B C  - 320A B C  + (80A B  + 160A B)C
+--R                        + 
+--R                               4           5      3 3      5
+--R                          - 80A B C - 16A B  - 80A B  + 16A B
+--R                     *
+--R                         5
+--R                        a
+--R                 *
+--R                     3
+--R                    c
+--R                + 
+--R                            5          4          2      2        2      3  3  6
+--R                      (24A D  - 16A B D  + (- 8A C  + 32A C + 8A B  - 56A )D )b
+--R                    + 
+--R                            6        5       2              2      2  4
+--R                          6D  - 46B D  + (10C  - 26A C + 34B  - 52A )D
+--R                        + 
+--R                                2                3       2   3
+--R                          (10B C  + 56A B C - 10B  - 114A B)D
+--R                        + 
+--R                                   3       2 2           2       3        2 2
+--R                              30A C  - 102A C  + (- 30A B  + 170A )C + 18A B
+--R                            + 
+--R                                 4
+--R                              14A
+--R                         *
+--R                             2
+--R                            D
+--R                     *
+--R                           5
+--R                        a b
+--R                    + 
+--R                                      5                     4
+--R                          (10C + 65A)D  + (122B C + 258A B)D
+--R                        + 
+--R                                     3         2         2       2          2
+--R                                - 34C  + 108A C  + (- 90B  - 306A )C + 92A B
+--R                              + 
+--R                                     3
+--R                                - 22A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                     3         2       3       2           3
+--R                              - 38B C  - 6A B C  + (38B  + 336A B)C + 38A B
+--R                            + 
+--R                                    3
+--R                              - 290A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     4       2 3         2       3  2
+--R                              - 39A C  + 132A C  + (30A B  - 228A )C
+--R                            + 
+--R                                  2 2      4         4      3 2      5
+--R                              (48A B  - 16A )C - 5A B  - 32A B  + 63A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  4     2   3          3      3   2
+--R                          - 2A B C  - 2A B C  + (- 4A B  + 28A B)C
+--R                        + 
+--R                                2 3      4        5
+--R                          (- 14A B  - 42A B)C - 6A B
+--R                     *
+--R                         2 4
+--R                        a b
+--R                    + 
+--R                               6        5         2               2       2  4
+--R                          - 29D  + 67B D  + (- 40C  + 77A C - 276B  - 243A )D
+--R                        + 
+--R                                  2                  3      2   3
+--R                          (- 62B C  - 296A B C + 144B  + 28A B)D
+--R                        + 
+--R                                 4         3         2        2  2
+--R                              35C  - 372A C  + (- 30B  + 1110A )C
+--R                            + 
+--R                                      2     3        4       2 2      4
+--R                              (- 12A B  - 6A )C - 55B  - 156A B  + 13A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4          3         3       2   2
+--R                              51B C  - 76A B C  + (- 36B  - 252A B)C
+--R                            + 
+--R                                       3       3        5       2 3       4
+--R                              (- 144A B  + 420A B)C + 5B  + 230A B  + 225A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              5      2      2  4           2      3  3
+--R                          9A C  + (2B  - 15A )C  + (- 50A B  + 28A )C
+--R                        + 
+--R                             4      2 2      4  2          4      3 2      5
+--R                          (4B  - 12A B  + 40A )C  + (- 9A B  + 60A B  - 45A )C
+--R                        + 
+--R                               2 4       4 2      6
+--R                          - 31A B  - 108A B  - 33A
+--R                     *
+--R                         3 3
+--R                        a b
+--R                    + 
+--R                                      5                       4
+--R                          (82C + 22A)D  + (- 234B C + 342A B)D
+--R                        + 
+--R                              3         2        2      2           2       3  3
+--R                          (52C  - 486A C  + (624B  + 36A )C + 144A B  + 366A )D
+--R                        + 
+--R                                     3           2          3      2
+--R                              - 18B C  - 108A B C  + (- 424B  + 18A B)C
+--R                            + 
+--R                                    3       3
+--R                              272A B  - 692A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4        2       2  3
+--R                              - 12C  + 346A C  + (164B  - 796A )C
+--R                            + 
+--R                                   2       3  2        4      2 2       4
+--R                              (6A B  - 112A )C  + (142B  + 36A B  - 136A )C
+--R                            + 
+--R                                      4       3 2       5
+--R                              - 118A B  - 190A B  + 166A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5          4       3       2   3
+--R                          - 18B C  - 72A B C  + (42B  + 352A B)C
+--R                        + 
+--R                                   3       3   2       5      2 3      4
+--R                          (- 100A B  - 508A B)C  + (18B  - 90A B  - 62A B)C
+--R                        + 
+--R                               5      3 3       5
+--R                          10A B  - 28A B  - 108A B
+--R                     *
+--R                         4 2
+--R                        a b
+--R                    + 
+--R                              6        5         2               2      2  4
+--R                          - 8D  - 64B D  + (- 36C  - 152A C + 56B  - 36A )D
+--R                        + 
+--R                                 2                 3       2   3
+--R                          (272B C  - 96A B C - 224B  - 336A B)D
+--R                        + 
+--R                                   4         3          2       2  2
+--R                              - 96C  + 544A C  + (- 216B  + 192A )C
+--R                            + 
+--R                                       2      3         4       2 2       4
+--R                              (- 432A B  - 64A )C + 136B  + 456A B  - 224A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   4           3        3       2   2
+--R                              16B C  - 256A B C  + (208B  + 576A B)C
+--R                            + 
+--R                                     3      3         2 3       4
+--R                              (224A B  + 64A B)C - 48A B  + 432A B
+--R                         *
+--R                            D
+--R                        + 
+--R                              6        5         2       2  4
+--R                          - 4C  - 72A C  + (- 48B  + 100A )C
+--R                        + 
+--R                                   2      3  3        4       2 2      4  2
+--R                          (- 224A B  + 48A )C  + (- 4B  + 192A B  - 60A )C
+--R                        + 
+--R                                  4      3 2      5       6       2 4       4 2
+--R                          (- 24A B  + 96A B  + 24A )C + 8B  + 156A B  + 112A B
+--R                        + 
+--R                               6
+--R                          - 36A
+--R                     *
+--R                         5
+--R                        a b
+--R                    + 
+--R                               5                    4
+--R                          32A D  + (96B C - 128A B)D
+--R                        + 
+--R                                2          2      2           2      3  3
+--R                          (64A C  + (- 192B  + 64A )C + 256A B  + 64A )D
+--R                        + 
+--R                                   3        3       2            3       3   2
+--R                          (- 128B C  + (320B  - 384A B)C - 320A B  + 320A B)D
+--R                        + 
+--R                                 5         4      2 3          2       3  2
+--R                              64C  - 160A C  - 64A C  + (192A B  - 128A )C
+--R                            + 
+--R                                     4       4           4       3 2      5
+--R                              (- 320B  + 256A )C + 160A B  - 576A B  - 96A
+--R                         *
+--R                            D
+--R                        + 
+--R                                 5           4       2   3       3   2
+--R                          - 32B C  + 320A B C  - 320A B C  + 320A B C
+--R                        + 
+--R                              5       4           5       5
+--R                          (32B  - 160A B)C - 64A B  + 128A B
+--R                     *
+--R                         6
+--R                        a
+--R                 *
+--R                     2
+--R                    c
+--R                + 
+--R                                     2  4      2   3  7
+--R                      ((- 32A C + 16A )D  + 48A B D )b
+--R                    + 
+--R                                     5                    4
+--R                          (4C - 16A)D  + (40B C - 148A B)D
+--R                        + 
+--R                               3        2         2       2         2       3  3
+--R                          (- 4C  + 40A C  + (- 12B  + 316A )C + 8A B  - 192A )D
+--R                        + 
+--R                                    2       2          3      3   2
+--R                          (- 12A B C  - 168A B C - 4A B  + 20A B)D
+--R                     *
+--R                           6
+--R                        a b
+--R                    + 
+--R                             6        5         2                2       2  4
+--R                          24D  - 52B D  + (- 40C  - 215A C + 212B  + 405A )D
+--R                        + 
+--R                                   2                3       2   3
+--R                          (- 140B C  + 76A B C - 92B  + 548A B)D
+--R                        + 
+--R                                 4        3       2        2  2
+--R                              16C  + 82A C  + (60B  - 1026A )C
+--R                            + 
+--R                                       2       3       4       2 2       4
+--R                              (- 102A B  + 322A )C + 4B  + 330A B  + 198A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                     3       2   2          3      3         2 3
+--R                              20A B C  + 192A B C  + (- 4A B  + 60A B)C - 32A B
+--R                            + 
+--R                                    4
+--R                              - 176A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             5     2 4        2      3  3         2 2     4  2
+--R                          A C  - 7A C  + (6A B  + 14A )C  + (- 18A B  - 2A )C
+--R                        + 
+--R                               4     3 2      5       2 4      4 2     6
+--R                          (5A B  + 6A B  - 15A )C + 5A B  + 30A B  + 9A
+--R                     *
+--R                         2 5
+--R                        a b
+--R                    + 
+--R                                         5                     4
+--R                          (- 81C - 173A)D  + (239B C - 569A B)D
+--R                        + 
+--R                                 3         2          2       2           2
+--R                              42C  + 902A C  + (- 582B  - 474A )C - 778A B
+--R                            + 
+--R                                    3
+--R                              - 590A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2        3       2            3
+--R                              182B C  + 378A B C  + (350B  - 894A B)C - 310A B
+--R                            + 
+--R                                  3
+--R                              118A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                   5         4         2       2  3
+--R                              - 21C  - 141A C  + (- 86B  + 966A )C
+--R                            + 
+--R                                    2     3  2       4       2 2       4
+--R                              (66A B  + 6A )C  + (- B  - 546A B  - 273A )C
+--R                            + 
+--R                                     4      3 2       5
+--R                              - 17A B  - 34A B  - 217A
+--R                         *
+--R                            D
+--R                        + 
+--R                               5          4        3       2   3
+--R                          - B C  + 19A B C  + (- 6B  - 202A B)C
+--R                        + 
+--R                                3       3   2        5      2 3      4
+--R                          (66A B  + 158A B)C  + (- 5B  - 74A B  - 21A B)C
+--R                        + 
+--R                              5      3 3       5
+--R                          7A B  + 54A B  + 111A B
+--R                     *
+--R                         3 4
+--R                        a b
+--R                    + 
+--R                            6         5        2               2       2  4
+--R                          2D  + 188B D  + (- 2C  + 548A C + 30B  + 194A )D
+--R                        + 
+--R                                   2                  3       2   3
+--R                          (- 380B C  + 536A B C + 508B  + 928A B)D
+--R                        + 
+--R                                 4          3        2       2  2
+--R                              78C  - 1240A C  + (432B  - 372A )C
+--R                            + 
+--R                                      2       3        4       2 2       4
+--R                              (1620A B  + 356A )C - 70B  + 240A B  + 562A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                      4           3          3       2   2
+--R                              - 112B C  - 160A B C  + (- 312B  - 684A B)C
+--R                            + 
+--R                                     3       3         5       2 3       4
+--R                              (232A B  + 608A B)C + 24B  + 468A B  - 420A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6        5       2       2  4          2       3  3
+--R                          10C  + 48A C  + (26B  - 282A )C  + (180A B  - 124A )C
+--R                        + 
+--R                                4      2 2       4  2
+--R                          (- 34B  - 84A B  + 178A )C
+--R                        + 
+--R                                 4       3 2      5        6      2 4      4 2
+--R                          (168A B  + 240A B  + 60A )C - 10B  - 94A B  - 34A B
+--R                        + 
+--R                             6
+--R                          78A
+--R                     *
+--R                         4 3
+--R                        a b
+--R                    + 
+--R                                      5                       4
+--R                          (56C - 48A)D  + (- 576B C - 112A B)D
+--R                        + 
+--R                                    3         2       2       2           2
+--R                                200C  - 268A C  + (72B  - 600A )C - 840A B
+--R                              + 
+--R                                      3
+--R                                - 180A
+--R                         *
+--R                             3
+--R                            D
+--R                        + 
+--R                                    3           2           3      2
+--R                              156B C  + 744A B C  + (- 1048B  - 12A B)C
+--R                            + 
+--R                                      3        3
+--R                              - 440A B  - 1160A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    5         4          2       2  3
+--R                              - 124C  + 672A C  + (- 184B  + 544A )C
+--R                            + 
+--R                                       2       3  2        4       2 2       4
+--R                              (- 276A B  + 520A )C  + (240B  - 984A B  - 484A )C
+--R                            + 
+--R                                      4       3 2      5
+--R                              - 456A B  + 676A B  + 24A
+--R                         *
+--R                            D
+--R                        + 
+--R                               5           4       3       2   3
+--R                          40B C  - 132A B C  + (20B  + 808A B)C
+--R                        + 
+--R                                3       3   2         5       2 3       4
+--R                          (56A B  - 352A B)C  + (- 72B  - 244A B  + 368A B)C
+--R                        + 
+--R                               5       3 3      5
+--R                          24A B  - 120A B  - 92A B
+--R                     *
+--R                         5 2
+--R                        a b
+--R                    + 
+--R                               5          2               2      2  4
+--R                          32B D  + (- 120C  - 16A C + 160B  + 72A )D
+--R                        + 
+--R                                 2                 3       2   3
+--R                          (448B C  + 576A B C + 32B  + 192A B)D
+--R                        + 
+--R                                    4         3          2       2  2
+--R                              - 208C  - 288A C  + (- 240B  + 480A )C
+--R                            + 
+--R                                     2       3         4       2 2       4
+--R                              (192A B  + 288A )C + 288B  + 816A B  - 208A
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                    4            3        3       2   2
+--R                              256B C  - 1216A B C  + (384B  - 480A B)C
+--R                            + 
+--R                                     3       3         2 3       4
+--R                              (768A B  - 128A B)C - 64A B  + 608A B
+--R                         *
+--R                            D
+--R                        + 
+--R                             6         5        2       2  4
+--R                          40C  - 112A C  + (112B  - 104A )C
+--R                        + 
+--R                                   2       3  3         4       2 2       4  2
+--R                          (- 288A B  - 192A )C  + (- 56B  + 192A B  - 104A )C
+--R                        + 
+--R                                4       3 2      5         2 4       4 2      6
+--R                          (16A B  - 288A B  + 48A )C + 104A B  - 368A B  - 88A
+--R                     *
+--R                         6
+--R                        a b
+--R                    + 
+--R                                    4
+--R                          - 128A B D
+--R                        + 
+--R                              3        2          2      2           2      3  3
+--R                          (64C  + 64A C  + (- 192B  - 64A )C + 128A B  + 64A )D
+--R                        + 
+--R                                      3           2        3       2
+--R                              - 128B C  - 192A B C  + (128B  - 384A B)C
+--R                            + 
+--R                                      3      3
+--R                              - 320A B  - 64A B
+--R                         *
+--R                             2
+--R                            D
+--R                        + 
+--R                                 5         4        2      2  3
+--R                              64C  + 192A C  + (192B  - 64A )C
+--R                            + 
+--R                                     2       3  2          4       2 2       4
+--R                              (192A B  - 256A )C  + (- 320B  + 576A B  + 256A )C
+--R                            + 
+--R                                    4       3 2      5
+--R                              128A B  - 576A B  + 64A
+--R                         *
+--R                            D
+--R                        + 
+--R                                  5           4            3       3   2
+--R                          - 192B C  + 320A B C  + (- 320A B  + 320A B)C
+--R                        + 
+--R                               5       4           5       3 3       5
+--R                          (128B  - 320A B)C - 64A B  + 320A B  + 128A B
+--R                     *
+--R                         7
+--R                        a
+--R                 *
+--R                    c
+--R                + 
+--R                          5          4         2      2         2      3  3  8
+--R                  (- 16A D  + 32A B D  + (16A C  - 64A C - 16A B  + 48A )D )b
+--R                + 
+--R                          6        5        2               2      2  4
+--R                      - 8D  + 40B D  + (- 8C  + 152A C - 56B  - 64A )D
+--R                    + 
+--R                             2                3       2   3
+--R                      (- 8B C  - 64A B C + 24B  - 120A B)D
+--R                    + 
+--R                            3       2 2         2       3        2 2      4  2
+--R                    (- 56A C  + 216A C  + (72A B  - 136A )C - 24A B  - 24A )D
+--R                 *
+--R                       7
+--R                    a b
+--R                + 
+--R                                 5                      4
+--R                      (8C + 74A)D  + (- 216B C + 62A B)D
+--R                    + 
+--R                          3         2        2      2           2       3  3
+--R                      (56C  - 452A C  + (216B  - 80A )C + 172A B  + 260A )D
+--R                    + 
+--R                                 3          2          3       2           3
+--R                            24B C  + 12A B C  + (- 104B  + 264A B)C - 28A B
+--R                          + 
+--R                               3
+--R                            60A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4       2 3           2       3  2
+--R                          66A C  - 248A C  + (- 84A B  + 132A )C
+--R                        + 
+--R                                2 2      4          4       3 2     5
+--R                          (- 24A B  + 56A )C + 10A B  + 100A B  - 6A
+--R                     *
+--R                        D
+--R                    + 
+--R                              4      2   3          3      3   2
+--R                      - 2A B C  + 16A B C  + (- 4A B  - 44A B)C
+--R                    + 
+--R                          2 3      4          5      3 3      5
+--R                      (16A B  + 48A B)C - 2A B  - 20A B  - 18A B
+--R                 *
+--R                     2 6
+--R                    a b
+--R                + 
+--R                         6         5        2               2       2  4
+--R                      14D  - 104B D  + (124C  - 242A C + 38B  - 286A )D
+--R                    + 
+--R                             2                  3       2   3
+--R                      (416B C  + 392A B C - 144B  - 672A B)D
+--R                    + 
+--R                                4         3          2       2  2
+--R                          - 130C  + 628A C  + (- 288B  + 504A )C
+--R                        + 
+--R                                   2       3        4       2 2       4
+--R                          (- 348A B  - 188A )C + 74B  - 372A B  - 446A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                 4         3        3      2   2
+--R                          - 24B C  + 8A B C  + (128B  + 48A B)C
+--R                        + 
+--R                                 3       3        5       2 3       4
+--R                          (200A B  - 552A B)C - 8B  - 208A B  + 328A B
+--R                     *
+--R                        D
+--R                    + 
+--R                             5      2      2  4        2      3  3
+--R                      - 26A C  + (2B  + 94A )C  + (4A B  - 28A )C
+--R                    + 
+--R                         4       2 2      4  2           4       3 2      5
+--R                      (4B  + 120A B  - 76A )C  + (- 34A B  - 156A B  + 54A )C
+--R                    + 
+--R                        6      2 4      4 2      6
+--R                      2B  + 34A B  - 18A B  - 18A
+--R                 *
+--R                     3 5
+--R                    a b
+--R                + 
+--R                                    5                     4
+--R                      (- 58C + 74A)D  + (414B C + 422A B)D
+--R                    + 
+--R                                  3        2          2        2           2
+--R                            - 380C  + 28A C  + (- 348B  + 1020A )C + 684A B
+--R                          + 
+--R                                3
+--R                            204A
+--R                     *
+--R                         3
+--R                        D
+--R                    + 
+--R                                  3            2        3       2            3
+--R                          - 348B C  - 1404A B C  + (276B  + 660A B)C + 500A B
+--R                        + 
+--R                              3
+--R                          812A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                              5         4        2       2  3
+--R                          126C  - 438A C  + (180B  - 500A )C
+--R                        + 
+--R                                  2       3  2          4        2 2       4
+--R                          (- 84A B  - 340A )C  + (- 234B  + 1308A B  + 614A )C
+--R                        + 
+--R                                4       3 2       5
+--R                          138A B  - 356A B  + 250A
+--R                     *
+--R                        D
+--R                    + 
+--R                          5          4         3       2   3
+--R                      6B C  + 22A B C  + (- 44B  - 188A B)C
+--R                    + 
+--R                               3       3   2       5       2 3       4
+--R                      (- 204A B  + 412A B)C  + (14B  + 196A B  - 218A B)C
+--R                    + 
+--R                             5      3 3      5
+--R                      - 26A B  + 76A B  - 66A B
+--R                 *
+--R                     4 4
+--R                    a b
+--R                + 
+--R                           6        5       2                2      2  4
+--R                      - 24D  - 44B D  + (28C  - 212A C - 220B  + 32A )D
+--R                    + 
+--R                               2                   3       2   3
+--R                      (- 376B C  - 1600A B C - 112B  - 192A B)D
+--R                    + 
+--R                              4         3        2        2  2
+--R                          464C  + 448A C  + (864B  - 1008A )C
+--R                        + 
+--R                                   2       3         4       2 2       4
+--R                          (- 960A B  - 632A )C - 280B  - 840A B  + 232A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                               4            3       3       2   2
+--R                          84B C  + 1520A B C  + (32B  + 336A B)C
+--R                        + 
+--R                                    3       3         5       2 3        4
+--R                          (- 1216A B  - 336A B)C + 28B  - 136A B  - 1028A B
+--R                     *
+--R                        D
+--R                    + 
+--R                           6         5         2       2  4
+--R                      - 44C  + 124A C  + (- 52B  + 160A )C
+--R                    + 
+--R                             2       3  3        4       2 2       4  2
+--R                      (184A B  + 208A )C  + (172B  - 600A B  - 100A )C
+--R                    + 
+--R                              4      3 2       5        6       2 4       4 2
+--R                      (- 76A B  - 96A B  - 300A )C + 12B  - 128A B  + 228A B
+--R                    + 
+--R                         6
+--R                      16A
+--R                 *
+--R                     5 3
+--R                    a b
+--R                + 
+--R                                   5                   4
+--R                      (104C - 24A)D  + (72B C + 24A B)D
+--R                    + 
+--R                          3         2        2       2           2       3  3
+--R                      (80C  + 408A C  + (672B  - 272A )C + 112A B  - 152A )D
+--R                    + 
+--R                                  3            2        3       2            3
+--R                          - 216B C  + 1584A B C  + (240B  + 696A B)C + 608A B
+--R                        + 
+--R                              3
+--R                          272A B
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                5         4          2       2  3
+--R                          - 288C  - 360A C  + (- 912B  + 208A )C
+--R                        + 
+--R                                 2       3  2        4       2 2       4
+--R                          (168A B  + 464A )C  + (504B  - 240A B  - 400A )C
+--R                        + 
+--R                                4        3 2       5
+--R                          264A B  + 1336A B  - 200A
+--R                     *
+--R                        D
+--R                    + 
+--R                           5           4          3       2   3
+--R                      24B C  - 560A B C  + (- 136B  - 368A B)C
+--R                    + 
+--R                             3       3   2         5       2 3       4
+--R                      (528A B  - 368A B)C  + (- 88B  + 328A B  + 760A B)C
+--R                    + 
+--R                            5      3 3       5
+--R                      136A B  - 16A B  + 192A B
+--R                 *
+--R                     6 2
+--R                    a b
+--R                + 
+--R                             2              2      2  4
+--R                      (- 144C  + 32A C - 32B  + 48A )D
+--R                    + 
+--R                              2                  3      2   3
+--R                      (- 32B C  + 192A B C - 128B  - 96A B)D
+--R                    + 
+--R                               4         3          2       2  2
+--R                          - 64C  - 480A C  + (- 576B  + 288A )C
+--R                        + 
+--R                                   2       3        4       2 2      4
+--R                          (- 384A B  + 416A )C - 64B  - 384A B  - 32A
+--R                     *
+--R                         2
+--R                        D
+--R                    + 
+--R                                4           3          3       2   2
+--R                          480B C  - 448A B C  + (- 160B  - 384A B)C
+--R                        + 
+--R                                  3       3          5       2 3       4
+--R                          (- 64A B  - 192A B)C - 128B  - 736A B  + 160A B
+--R                     *
+--R                        D
+--R                    + 
+--R                         6        5        2      2  4         2 3
+--R                      80C  + 64A C  + (320B  + 16A )C  + 352A B C
+--R                    + 
+--R                             4       2 2       4  2
+--R                      (- 176B  + 480A B  + 176A )C
+--R                    + 
+--R                               4       3 2       5        6       2 4       4 2
+--R                      (- 160A B  - 288A B  + 192A )C - 32B  - 176A B  - 480A B
+--R                    + 
+--R                           6
+--R                      - 16A
+--R                 *
+--R                     7
+--R                    a b
+--R                + 
+--R                          3      2          2  3
+--R                      (64C  - 64A C + 128A B )D
+--R                    + 
+--R                                 2       3       3   2
+--R                      (- 192A B C  + 128B C - 64A B)D
+--R                    + 
+--R                             4       2 3       3 2       2 2          4      5
+--R                      (192A C  + 192B C  - 256A C  + 576A B C + 128A B  + 64A )D
+--R                    + 
+--R                              5         3 2        5       4          3 3
+--R                      - 192B C  - 320A B C  + (128B  - 320A B)C + 320A B
+--R                 *
+--R                     8
+--R                    a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------------+
+--R          |    |          2     2            2     2
+--R         \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R          +---------------------------------------+
+--R          |  +-----------------+
+--R          |  |          2     2            2     2
+--R         \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R  /
+--R                                  +-----------------------------------------+
+--R              +-----------------+ |    +-----------------+
+--R          +-+ |          2     2  |    |          2     2            2     2
+--R       4a\|2 \|- 4a c + b  + 8a  \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R    *
+--R        +---------------------------------------+
+--R        |  +-----------------+
+--R        |  |          2     2            2     2
+--R       \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R                                                    Type: Expression(Integer)
+--E 657
+
+--S 658 of 1070
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 658
+
+)clear all
+
+--S 659 of 1070
+t0:=x^4*(5+x+3*x^2+2*x^3)/(2+x+3*x^2+x^3+2*x^4)
+--R 
+--R
+--R           7     6    5     4
+--R         2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 3x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 659
+
+--S 660 of 1070
+r0:=5/4*x-3/4*x^2+1/3*x^3+1/4*x^4+1/3*log(1+x+x^2)-13/48*log(2-x+2*x^2)+_
+   1/24*atan((1-4*x)/sqrt(15))*sqrt(5/3)-10/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R            +-+      2               +-+     2
+--R       - 13\|3 log(2x  - x + 2) + 16\|3 log(x  + x + 1)
+--R     + 
+--R                            +--+                     +-+
+--R           +-+     (4x - 1)\|15             (2x + 1)\|3
+--R       - 2\|5 atan(-------------) - 160atan(------------)
+--R                         15                       3
+--R     + 
+--R           4      3      2        +-+
+--R       (12x  + 16x  - 36x  + 60x)\|3
+--R  /
+--R        +-+
+--R     48\|3
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +-+      2               +-+     2
+--R       - 13\|3 log(2x  - x + 2) + 16\|3 log(x  + x + 1)
+--R     + 
+--R                       +-+                        +-+
+--R         +-+         3\|5                (2x + 1)\|3
+--R       2\|5 atan(------------) - 160atan(------------)
+--R                          +-+                  3
+--R                 (4x - 1)\|3
+--R     + 
+--R           4      3      2        +-+
+--R       (12x  + 16x  - 36x  + 60x)\|3
+--R  /
+--R        +-+
+--R     48\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 661
+
+--S 662 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                          +--+                   +-+
+--R         +-+     (4x - 1)\|15      +-+         3\|5
+--R        \|5 atan(-------------) + \|5 atan(------------)
+--R                       15                           +-+
+--R                                           (4x - 1)\|3
+--R   (4)  ------------------------------------------------
+--R                                +-+
+--R                             24\|3
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R         +-+ +-+ +--+
+--R        \|3 \|5 \|15  - 15
+--R   (5)  ------------------
+--R            2
+--R        288x  - 144x + 288
+--R                                                    Type: Expression(Integer)
+--E 663
+
+)clear all
+
+--S 664 of 1070
+t0:=x^3*(5+x+3*x^2+2*x^3)/(2+x+3*x^2+x^3+2*x^4)
+--R 
+--R
+--R           6     5    4     3
+--R         2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 3x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 664
+
+--S 665 of 1070
+r0:=-3/2*x+1/2*x^2+1/3*x^3+2/3*log(1+x+x^2)-1/24*log(2-x+2*x^2)+_
+   5/12*atan((1-4*x)/sqrt(15))*sqrt(5/3)+8/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          +-+      2               +-+     2
+--R       - \|3 log(2x  - x + 2) + 16\|3 log(x  + x + 1)
+--R     + 
+--R                           +--+                    +-+
+--R          +-+     (4x - 1)\|15            (2x + 1)\|3        3      2        +-+
+--R     - 10\|5 atan(-------------) + 64atan(------------) + (8x  + 12x  - 36x)\|3
+--R                        15                      3
+--R  /
+--R        +-+
+--R     24\|3
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                         +-+
+--R          +-+      2               +-+     2               +-+         3\|5
+--R       - \|3 log(2x  - x + 2) + 16\|3 log(x  + x + 1) + 10\|5 atan(------------)
+--R                                                                            +-+
+--R                                                                   (4x - 1)\|3
+--R     + 
+--R                       +-+
+--R              (2x + 1)\|3        3      2        +-+
+--R       64atan(------------) + (8x  + 12x  - 36x)\|3
+--R                    3
+--R  /
+--R        +-+
+--R     24\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 666
+
+--S 667 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                           +--+                    +-+
+--R          +-+     (4x - 1)\|15       +-+         3\|5
+--R        5\|5 atan(-------------) + 5\|5 atan(------------)
+--R                        15                            +-+
+--R                                             (4x - 1)\|3
+--R   (4)  --------------------------------------------------
+--R                                 +-+
+--R                              12\|3
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          +-+ +-+ +--+
+--R        5\|3 \|5 \|15  - 75
+--R   (5)  -------------------
+--R             2
+--R         144x  - 72x + 144
+--R                                                    Type: Expression(Integer)
+--E 668
+
+)clear all
+
+--S 669 of 1070
+t0:=x^2*(5+x+3*x^2+2*x^3)/(2+x+3*x^2+x^3+2*x^4)
+--R 
+--R
+--R           5     4    3     2
+--R         2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 3x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 669
+
+--S 670 of 1070
+r0:=x+1/2*x^2-log(1+x+x^2)+1/4*log(2-x+2*x^2)+1/6*atan((1-4*x)/sqrt(15))*_
+   sqrt(5/3)+2/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                          +--+
+--R         +-+      2               +-+     2              +-+     (4x - 1)\|15
+--R       3\|3 log(2x  - x + 2) - 12\|3 log(x  + x + 1) - 2\|5 atan(-------------)
+--R                                                                       15
+--R     + 
+--R                      +-+
+--R             (2x + 1)\|3        2        +-+
+--R       8atan(------------) + (6x  + 12x)\|3
+--R                   3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                       +-+
+--R         +-+      2               +-+     2              +-+         3\|5
+--R       3\|3 log(2x  - x + 2) - 12\|3 log(x  + x + 1) + 2\|5 atan(------------)
+--R                                                                          +-+
+--R                                                                 (4x - 1)\|3
+--R     + 
+--R                      +-+
+--R             (2x + 1)\|3        2        +-+
+--R       8atan(------------) + (6x  + 12x)\|3
+--R                   3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 671
+
+--S 672 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                          +--+                   +-+
+--R         +-+     (4x - 1)\|15      +-+         3\|5
+--R        \|5 atan(-------------) + \|5 atan(------------)
+--R                       15                           +-+
+--R                                           (4x - 1)\|3
+--R   (4)  ------------------------------------------------
+--R                                +-+
+--R                              6\|3
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R         +-+ +-+ +--+
+--R        \|3 \|5 \|15  - 15
+--R   (5)  ------------------
+--R             2
+--R          72x  - 36x + 72
+--R                                                    Type: Expression(Integer)
+--E 673
+
+)clear all
+
+--S 674 of 1070
+t0:=x*(5+x+3*x^2+2*x^3)/(2+x+3*x^2+x^3+2*x^4)
+--R 
+--R
+--R            4     3    2
+--R          2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 3x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 674
+
+--S 675 of 1070
+r0:=x+1/3*log(1+x+x^2)+1/6*log(2-x+2*x^2)-1/3*atan((1-4*x)/sqrt(15))*_
+   sqrt(5/3)-10/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                        +--+
+--R        +-+      2              +-+     2              +-+     (4x - 1)\|15
+--R       \|3 log(2x  - x + 2) + 2\|3 log(x  + x + 1) + 2\|5 atan(-------------)
+--R                                                                     15
+--R     + 
+--R                         +-+
+--R                (2x + 1)\|3        +-+
+--R       - 20atan(------------) + 6x\|3
+--R                      3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                     +-+
+--R        +-+      2              +-+     2              +-+         3\|5
+--R       \|3 log(2x  - x + 2) + 2\|3 log(x  + x + 1) - 2\|5 atan(------------)
+--R                                                                        +-+
+--R                                                               (4x - 1)\|3
+--R     + 
+--R                         +-+
+--R                (2x + 1)\|3        +-+
+--R       - 20atan(------------) + 6x\|3
+--R                      3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 676
+
+--S 677 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                            +--+                   +-+
+--R           +-+     (4x - 1)\|15      +-+         3\|5
+--R        - \|5 atan(-------------) - \|5 atan(------------)
+--R                         15                           +-+
+--R                                             (4x - 1)\|3
+--R   (4)  --------------------------------------------------
+--R                                 +-+
+--R                               3\|3
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +-+ +-+ +--+
+--R        - \|3 \|5 \|15  + 15
+--R   (5)  --------------------
+--R              2
+--R           36x  - 18x + 36
+--R                                                    Type: Expression(Integer)
+--E 678
+
+)clear all
+
+--S 679 of 1070
+t0:=(5+x+3*x^2+2*x^3)/(2+x+3*x^2+x^3+2*x^4)
+--R 
+--R
+--R             3     2
+--R           2x  + 3x  + x + 5
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 3x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 679
+
+--S 680 of 1070
+r0:=2/3*log(1+x+x^2)-1/6*log(2-x+2*x^2)-1/3*atan((1-4*x)/sqrt(15))*_
+   sqrt(5/3)+8/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                          +--+
+--R          +-+      2              +-+     2              +-+     (4x - 1)\|15
+--R       - \|3 log(2x  - x + 2) + 4\|3 log(x  + x + 1) + 2\|5 atan(-------------)
+--R                                                                       15
+--R     + 
+--R                       +-+
+--R              (2x + 1)\|3
+--R       16atan(------------)
+--R                    3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                       +-+
+--R          +-+      2              +-+     2              +-+         3\|5
+--R       - \|3 log(2x  - x + 2) + 4\|3 log(x  + x + 1) - 2\|5 atan(------------)
+--R                                                                          +-+
+--R                                                                 (4x - 1)\|3
+--R     + 
+--R                       +-+
+--R              (2x + 1)\|3
+--R       16atan(------------)
+--R                    3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 681
+
+--S 682 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                            +--+                   +-+
+--R           +-+     (4x - 1)\|15      +-+         3\|5
+--R        - \|5 atan(-------------) - \|5 atan(------------)
+--R                         15                           +-+
+--R                                             (4x - 1)\|3
+--R   (4)  --------------------------------------------------
+--R                                 +-+
+--R                               3\|3
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R           +-+ +-+ +--+
+--R        - \|3 \|5 \|15  + 15
+--R   (5)  --------------------
+--R              2
+--R           36x  - 18x + 36
+--R                                                    Type: Expression(Integer)
+--E 683
+
+)clear all
+
+--S 684 of 1070
+t0:=(5+x+3*x^2+2*x^3)/(x*(2+x+3*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  ------------------------
+--R          5    4     3    2
+--R        2x  + x  + 3x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 684
+
+--S 685 of 1070
+r0:=5/2*log(x)-log(1+x+x^2)-1/4*log(2-x+2*x^2)+1/6*atan((1-4*x)/sqrt(15))*_
+   sqrt(5/3)+2/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           +-+      2               +-+     2               +-+
+--R       - 3\|3 log(2x  - x + 2) - 12\|3 log(x  + x + 1) + 30\|3 log(x)
+--R     + 
+--R                            +--+                   +-+
+--R           +-+     (4x - 1)\|15           (2x + 1)\|3
+--R       - 2\|5 atan(-------------) + 8atan(------------)
+--R                         15                     3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                                    Type: Expression(Integer)
+--E 685
+
+--S 686 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-+      2               +-+     2               +-+
+--R       - 3\|3 log(2x  - x + 2) - 12\|3 log(x  + x + 1) + 30\|3 log(x)
+--R     + 
+--R                       +-+                      +-+
+--R         +-+         3\|5              (2x + 1)\|3
+--R       2\|5 atan(------------) + 8atan(------------)
+--R                          +-+                3
+--R                 (4x - 1)\|3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 686
+
+--S 687 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                          +--+                   +-+
+--R         +-+     (4x - 1)\|15      +-+         3\|5
+--R        \|5 atan(-------------) + \|5 atan(------------)
+--R                       15                           +-+
+--R                                           (4x - 1)\|3
+--R   (4)  ------------------------------------------------
+--R                                +-+
+--R                              6\|3
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R         +-+ +-+ +--+
+--R        \|3 \|5 \|15  - 15
+--R   (5)  ------------------
+--R             2
+--R          72x  - 36x + 72
+--R                                                    Type: Expression(Integer)
+--E 688
+
+)clear all
+
+--S 689 of 1070
+t0:=(5+x+3*x^2+2*x^3)/(x^2*(2+x+3*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  -------------------------
+--R          6    5     4    3     2
+--R        2x  + x  + 3x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 689
+
+--S 690 of 1070
+r0:=(-5/2)/x-3/4*log(x)+1/3*log(1+x+x^2)+1/24*log(2-x+2*x^2)+_
+   5/12*atan((1-4*x)/sqrt(15))*sqrt(5/3)-10/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         +-+      2               +-+     2                +-+
+--R       x\|3 log(2x  - x + 2) + 8x\|3 log(x  + x + 1) - 18x\|3 log(x)
+--R     + 
+--R                              +--+                      +-+
+--R             +-+     (4x - 1)\|15              (2x + 1)\|3        +-+
+--R       - 10x\|5 atan(-------------) - 80x atan(------------) - 60\|3
+--R                           15                        3
+--R  /
+--R         +-+
+--R     24x\|3
+--R                                                    Type: Expression(Integer)
+--E 690
+
+--S 691 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         +-+      2               +-+     2                +-+
+--R       x\|3 log(2x  - x + 2) + 8x\|3 log(x  + x + 1) - 18x\|3 log(x)
+--R     + 
+--R                         +-+                         +-+
+--R           +-+         3\|5                 (2x + 1)\|3        +-+
+--R       10x\|5 atan(------------) - 80x atan(------------) - 60\|3
+--R                            +-+                   3
+--R                   (4x - 1)\|3
+--R  /
+--R         +-+
+--R     24x\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 691
+
+--S 692 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                           +--+                    +-+
+--R          +-+     (4x - 1)\|15       +-+         3\|5
+--R        5\|5 atan(-------------) + 5\|5 atan(------------)
+--R                        15                            +-+
+--R                                             (4x - 1)\|3
+--R   (4)  --------------------------------------------------
+--R                                 +-+
+--R                              12\|3
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          +-+ +-+ +--+
+--R        5\|3 \|5 \|15  - 75
+--R   (5)  -------------------
+--R             2
+--R         144x  - 72x + 144
+--R                                                    Type: Expression(Integer)
+--E 693
+
+)clear all
+
+--S 694 of 1070
+t0:=(5+x+3*x^2+2*x^3)/(x^3*(2+x+3*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  -------------------------
+--R          7    6     5    4     3
+--R        2x  + x  + 3x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 694
+
+--S 695 of 1070
+r0:=(-5/4)/x^2+3/4/x-15/8*log(x)+2/3*log(1+x+x^2)+13/48*log(2-x+2*x^2)+_
+   1/24*atan((1-4*x)/sqrt(15))*sqrt(5/3)+8/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          2 +-+      2               2 +-+     2               2 +-+
+--R       13x \|3 log(2x  - x + 2) + 32x \|3 log(x  + x + 1) - 90x \|3 log(x)
+--R     + 
+--R                              +--+                       +-+
+--R           2 +-+     (4x - 1)\|15         2     (2x + 1)\|3                +-+
+--R       - 2x \|5 atan(-------------) + 128x atan(------------) + (36x - 60)\|3
+--R                           15                         3
+--R  /
+--R        2 +-+
+--R     48x \|3
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 +-+      2               2 +-+     2               2 +-+
+--R       13x \|3 log(2x  - x + 2) + 32x \|3 log(x  + x + 1) - 90x \|3 log(x)
+--R     + 
+--R                         +-+                          +-+
+--R         2 +-+         3\|5            2     (2x + 1)\|3                +-+
+--R       2x \|5 atan(------------) + 128x atan(------------) + (36x - 60)\|3
+--R                            +-+                    3
+--R                   (4x - 1)\|3
+--R  /
+--R        2 +-+
+--R     48x \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 696
+
+--S 697 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                          +--+                   +-+
+--R         +-+     (4x - 1)\|15      +-+         3\|5
+--R        \|5 atan(-------------) + \|5 atan(------------)
+--R                       15                           +-+
+--R                                           (4x - 1)\|3
+--R   (4)  ------------------------------------------------
+--R                                +-+
+--R                             24\|3
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R         +-+ +-+ +--+
+--R        \|3 \|5 \|15  - 15
+--R   (5)  ------------------
+--R            2
+--R        288x  - 144x + 288
+--R                                                    Type: Expression(Integer)
+--E 698
+
+)clear all
+
+--S 699 of 1070
+t0:=x^3*(5+x+3*x^2+2*x^3)/(2+x+5*x^2+x^3+2*x^4)
+--R 
+--R
+--R           6     5    4     3
+--R         2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 5x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 699
+
+--S 700 of 1070
+r0:=1/28*x^2*(7-5*%i*sqrt(7))+1/42*x^3*(7-5*%i*sqrt(7))+1/28*x^2*_
+   (7+5*%i*sqrt(7))+1/42*x^3*(7+5*%i*sqrt(7))-1/28*x*(35-9*%i*sqrt(7))-_
+   1/28*x*(35+9*%i*sqrt(7))+3/112*log(4+4*x^2+x*(1-%i*sqrt(7)))*(7-_
+   11*%i*sqrt(7))+3/112*log(4+4*x^2+x*(1+%i*sqrt(7)))*(7+11*%i*sqrt(7))-_
+   11/4*atan((1+8*x+%i*sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*(9*%i-5*sqrt(7))/_
+   sqrt(14*(35-%i*sqrt(7)))+11/4*atan((1+8*x-%i*sqrt(7))/sqrt(2*_
+   (35+%i*sqrt(7))))*(9*%i+5*sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--R 
+--R
+--R   (2)
+--R                           +--------------+         +-+
+--R             +-+           |     +-+             %i\|7  + 8x + 1
+--R       (4620\|7  - 8316%i)\|14%i\|7  + 490 atan(-----------------)
+--R                                                 +--------------+
+--R                                                 |      +-+
+--R                                                \|- 2%i\|7  + 70
+--R     + 
+--R                             +----------------+        +-+
+--R               +-+           |       +-+            %i\|7  - 8x - 1
+--R       (- 4620\|7  - 8316%i)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                     +------------+
+--R                                                     |    +-+
+--R                                                    \|2%i\|7  + 70
+--R     + 
+--R                 +-+               +-+     2
+--R           (99%i\|7  + 63)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R                 +-+                 +-+     2                3       2
+--R         (- 99%i\|7  + 63)log(- %i x\|7  + 4x  + x + 4) + 112x  + 168x  - 840x
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R         +----------------+ +--------------+
+--R         |       +-+        |     +-+
+--R     336\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 700
+
+--S 701 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3
+--R          *
+--R            +------------------------------------------------------------------+
+--R            |          2                                     2
+--R           \|- 336%%BO1  + (- 224%%BO0 + 168)%%BO1 - 336%%BO0  + 168%%BO0 - 961
+--R         + 
+--R                +-+           +-+          +-+
+--R           - 12\|7 %%BO1 - 12\|7 %%BO0 + 9\|7
+--R      *
+--R         log
+--R                ((5831%%BO0 + 1568)%%BO1 + 1568%%BO0 + 2016)
+--R             *
+--R                ROOT
+--R                               2                                     2
+--R                     - 336%%BO1  + (- 224%%BO0 + 168)%%BO1 - 336%%BO0
+--R                   + 
+--R                     168%%BO0 - 961
+--R            + 
+--R                     +-+             +-+      2
+--R              (23324\|7 %%BO0 + 6272\|7 )%%BO1
+--R            + 
+--R                     +-+     2         +-+              +-+
+--R              (23324\|7 %%BO0  - 17493\|7 %%BO0 - 12768\|7 )%%BO1
+--R            + 
+--R                   +-+     2         +-+                        +-+
+--R              6272\|7 %%BO0  - 12768\|7 %%BO0 + (15488x - 3552)\|7
+--R     + 
+--R           -
+--R                3
+--R             *
+--R                ROOT
+--R                               2                                     2
+--R                     - 336%%BO1  + (- 224%%BO0 + 168)%%BO1 - 336%%BO0
+--R                   + 
+--R                     168%%BO0 - 961
+--R         + 
+--R                +-+           +-+          +-+
+--R           - 12\|7 %%BO1 - 12\|7 %%BO0 + 9\|7
+--R      *
+--R         log
+--R                ((- 5831%%BO0 - 1568)%%BO1 - 1568%%BO0 - 2016)
+--R             *
+--R                ROOT
+--R                               2                                     2
+--R                     - 336%%BO1  + (- 224%%BO0 + 168)%%BO1 - 336%%BO0
+--R                   + 
+--R                     168%%BO0 - 961
+--R            + 
+--R                     +-+             +-+      2
+--R              (23324\|7 %%BO0 + 6272\|7 )%%BO1
+--R            + 
+--R                     +-+     2         +-+              +-+
+--R              (23324\|7 %%BO0  - 17493\|7 %%BO0 - 12768\|7 )%%BO1
+--R            + 
+--R                   +-+     2         +-+                        +-+
+--R              6272\|7 %%BO0  - 12768\|7 %%BO0 + (15488x - 3552)\|7
+--R     + 
+--R            +-+
+--R         24\|7 %%BO1
+--R      *
+--R         log
+--R                                        2
+--R              (- 23324%%BO0 - 6272)%%BO1
+--R            + 
+--R                           2                                        3
+--R              (- 23324%%BO0  + 17493%%BO0 + 12768)%%BO1 - 23324%%BO0
+--R            + 
+--R                        2
+--R              17493%%BO0  - 53312%%BO0 + 7744x - 19136
+--R     + 
+--R          +-+                    3             2
+--R       24\|7 %%BO0 log(23324%%BO0  - 23765%%BO0  + 66080%%BO0 + 7744x + 26560)
+--R     + 
+--R          3      2        +-+
+--R       (8x  + 12x  - 60x)\|7
+--R  /
+--R        +-+
+--R     24\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 701
+
+--S 702 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +----------------+ +--------------+
+--R               |       +-+        |     +-+
+--R             2\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R          *
+--R            +------------------------------------------------------------------+
+--R            |          2                                     2
+--R           \|- 336%%BO1  + (- 224%%BO0 + 168)%%BO1 - 336%%BO0  + 168%%BO0 - 961
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 8\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BO1
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 8\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BO0
+--R         + 
+--R                 +----------------+ +--------------+
+--R             +-+ |       +-+        |     +-+
+--R           6\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R      *
+--R         log
+--R                ((5831%%BO0 + 1568)%%BO1 + 1568%%BO0 + 2016)
+--R             *
+--R                ROOT
+--R                               2                                     2
+--R                     - 336%%BO1  + (- 224%%BO0 + 168)%%BO1 - 336%%BO0
+--R                   + 
+--R                     168%%BO0 - 961
+--R            + 
+--R                     +-+             +-+      2
+--R              (23324\|7 %%BO0 + 6272\|7 )%%BO1
+--R            + 
+--R                     +-+     2         +-+              +-+
+--R              (23324\|7 %%BO0  - 17493\|7 %%BO0 - 12768\|7 )%%BO1
+--R            + 
+--R                   +-+     2         +-+                        +-+
+--R              6272\|7 %%BO0  - 12768\|7 %%BO0 + (15488x - 3552)\|7
+--R     + 
+--R           -
+--R                  +----------------+ +--------------+
+--R                  |       +-+        |     +-+
+--R                2\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R             *
+--R                ROOT
+--R                               2                                     2
+--R                     - 336%%BO1  + (- 224%%BO0 + 168)%%BO1 - 336%%BO0
+--R                   + 
+--R                     168%%BO0 - 961
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 8\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BO1
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 8\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BO0
+--R         + 
+--R                 +----------------+ +--------------+
+--R             +-+ |       +-+        |     +-+
+--R           6\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R      *
+--R         log
+--R                ((- 5831%%BO0 - 1568)%%BO1 - 1568%%BO0 - 2016)
+--R             *
+--R                ROOT
+--R                               2                                     2
+--R                     - 336%%BO1  + (- 224%%BO0 + 168)%%BO1 - 336%%BO0
+--R                   + 
+--R                     168%%BO0 - 961
+--R            + 
+--R                     +-+             +-+      2
+--R              (23324\|7 %%BO0 + 6272\|7 )%%BO1
+--R            + 
+--R                     +-+     2         +-+              +-+
+--R              (23324\|7 %%BO0  - 17493\|7 %%BO0 - 12768\|7 )%%BO1
+--R            + 
+--R                   +-+     2         +-+                        +-+
+--R              6272\|7 %%BO0  - 12768\|7 %%BO0 + (15488x - 3552)\|7
+--R     + 
+--R                +----------------+ +--------------+
+--R            +-+ |       +-+        |     +-+
+--R         16\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BO1
+--R      *
+--R         log
+--R                                        2
+--R              (- 23324%%BO0 - 6272)%%BO1
+--R            + 
+--R                           2                                        3
+--R              (- 23324%%BO0  + 17493%%BO0 + 12768)%%BO1 - 23324%%BO0
+--R            + 
+--R                        2
+--R              17493%%BO0  - 53312%%BO0 + 7744x - 19136
+--R     + 
+--R                +----------------+ +--------------+
+--R            +-+ |       +-+        |     +-+
+--R         16\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BO0
+--R      *
+--R                       3             2
+--R         log(23324%%BO0  - 23765%%BO0  + 66080%%BO0 + 7744x + 26560)
+--R     + 
+--R                          +--------------+         +-+
+--R              +-+         |     +-+             %i\|7  + 8x + 1
+--R       (396%i\|7  - 1540)\|14%i\|7  + 490 atan(-----------------)
+--R                                                +--------------+
+--R                                                |      +-+
+--R                                               \|- 2%i\|7  + 70
+--R     + 
+--R                          +----------------+        +-+
+--R              +-+         |       +-+            %i\|7  - 8x - 1
+--R       (396%i\|7  + 1540)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                  +------------+
+--R                                                  |    +-+
+--R                                                 \|2%i\|7  + 70
+--R     + 
+--R                +-+                 +-+     2
+--R           (- 3\|7  - 33%i)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R                +-+                   +-+     2
+--R           (- 3\|7  + 33%i)log(- %i x\|7  + 4x  + x + 4)
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R            +----------------+ +--------------+
+--R        +-+ |       +-+        |     +-+
+--R     16\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 702
+
+--S 703 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                                            +------------+
+--R                2            +-+         2                  |    +-+
+--R         ((- 23x  + 3x - 23)\|7  - 35%i x  - 49%i x - 35%i)\|2%i\|7  + 70
+--R      *
+--R          +--------------+
+--R          |     +-+
+--R         \|14%i\|7  + 490
+--R     + 
+--R                                                            +----------------+
+--R                2            +-+         2                  |       +-+
+--R         ((- 23x  + 3x - 23)\|7  + 35%i x  + 49%i x + 35%i)\|- 14%i\|7  + 490
+--R      *
+--R          +--------------+
+--R          |      +-+
+--R         \|- 2%i\|7  + 70
+--R     + 
+--R             2
+--R       21560x  - 4312x + 21560
+--R  /
+--R          4        3         2
+--R     6272x  + 3136x  + 15680x  + 3136x + 6272
+--R                                           Type: Expression(Complex(Integer))
+--E 703
+
+)clear all
+
+--S 704 of 1070
+t0:=x^2*(5+x+3*x^2+2*x^3)/(2+x+5*x^2+x^3+2*x^4)
+--R 
+--R
+--R           5     4    3     2
+--R         2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 5x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 704
+
+--S 705 of 1070
+r0:=1/14*x*(7-5*%i*sqrt(7))+1/28*x^2*(7-5*%i*sqrt(7))+1/14*x*_
+   (7+5*%i*sqrt(7))+1/28*x^2*(7+5*%i*sqrt(7))-1/56*log(4+4*x^2+x*_
+   (1+%i*sqrt(7)))*(35-9*%i*sqrt(7))-1/56*log(4+4*x^2+x*(1-%i*sqrt(7)))*_
+   (35+9*%i*sqrt(7))+1/2*atan((1+8*x+%i*sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*_
+   (53*%i-sqrt(7))/sqrt(14*(35-%i*sqrt(7)))-1/2*atan((1+8*x-%i*sqrt(7))/_
+   sqrt(2*(35+%i*sqrt(7))))*(53*%i+sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--R 
+--R
+--R   (2)
+--R                           +--------------+         +-+
+--R             +-+           |     +-+             %i\|7  + 8x + 1
+--R       (- 28\|7  + 1484%i)\|14%i\|7  + 490 atan(-----------------)
+--R                                                 +--------------+
+--R                                                 |      +-+
+--R                                                \|- 2%i\|7  + 70
+--R     + 
+--R                         +----------------+        +-+
+--R           +-+           |       +-+            %i\|7  - 8x - 1
+--R       (28\|7  + 1484%i)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                 +------------+
+--R                                                 |    +-+
+--R                                                \|2%i\|7  + 70
+--R     + 
+--R                +-+               +-+     2
+--R           (9%i\|7  - 35)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R                  +-+                 +-+     2               2
+--R           (- 9%i\|7  - 35)log(- %i x\|7  + 4x  + x + 4) + 28x  + 56x
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R        +----------------+ +--------------+
+--R        |       +-+        |     +-+
+--R     56\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 705
+
+--S 706 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +----------------------------------------------------------+
+--R            |         2                                 2
+--R           \|- 12%%BP1  + (- 8%%BP0 - 20)%%BP1 - 12%%BP0  - 20%%BP0 - 7
+--R         + 
+--R           - 2%%BP1 - 2%%BP0 - 5
+--R      *
+--R         log
+--R                ((5145%%BP0 + 12152)%%BP1 + 12152%%BP0 + 15008)
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |         2                                 2
+--R                \|- 12%%BP1  + (- 8%%BP0 - 20)%%BP1 - 12%%BP0  - 20%%BP0 - 7
+--R            + 
+--R                                       2
+--R              (10290%%BP0 + 24304)%%BP1
+--R            + 
+--R                         2                                        2
+--R              (10290%%BP0  + 25725%%BP0 + 30744)%%BP1 + 24304%%BP0  + 30744%%BP0
+--R            + 
+--R              16768x + 9824
+--R     + 
+--R              +----------------------------------------------------------+
+--R              |         2                                 2
+--R           - \|- 12%%BP1  + (- 8%%BP0 - 20)%%BP1 - 12%%BP0  - 20%%BP0 - 7
+--R         + 
+--R           - 2%%BP1 - 2%%BP0 - 5
+--R      *
+--R         log
+--R                ((- 5145%%BP0 - 12152)%%BP1 - 12152%%BP0 - 15008)
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |         2                                 2
+--R                \|- 12%%BP1  + (- 8%%BP0 - 20)%%BP1 - 12%%BP0  - 20%%BP0 - 7
+--R            + 
+--R                                       2
+--R              (10290%%BP0 + 24304)%%BP1
+--R            + 
+--R                         2                                        2
+--R              (10290%%BP0  + 25725%%BP0 + 30744)%%BP1 + 24304%%BP0  + 30744%%BP0
+--R            + 
+--R              16768x + 9824
+--R     + 
+--R         4%%BP1
+--R      *
+--R         log
+--R                                         2
+--R              (- 10290%%BP0 - 24304)%%BP1
+--R            + 
+--R                           2                                        3
+--R              (- 10290%%BP0  - 25725%%BP0 - 30744)%%BP1 - 10290%%BP0
+--R            + 
+--R                          2
+--R              - 25725%%BP0  - 20580%%BP0 + 8384x - 6176
+--R     + 
+--R                          3            2                                 2
+--R     4%%BP0 log(10290%%BP0  + 1421%%BP0  - 10164%%BP0 + 8384x + 544) + 2x  + 4x
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 706
+
+--S 707 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +----------------+ +--------------+
+--R                |       +-+        |     +-+
+--R             14\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R          *
+--R              +----------------------------------------------------------+
+--R              |         2                                 2
+--R             \|- 12%%BP1  + (- 8%%BP0 - 20)%%BP1 - 12%%BP0  - 20%%BP0 - 7
+--R         + 
+--R                +----------------+ +--------------+
+--R                |       +-+        |     +-+
+--R           - 28\|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BP1
+--R         + 
+--R                +----------------+ +--------------+
+--R                |       +-+        |     +-+
+--R           - 28\|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BP0
+--R         + 
+--R                +----------------+ +--------------+
+--R                |       +-+        |     +-+
+--R           - 70\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R      *
+--R         log
+--R                ((5145%%BP0 + 12152)%%BP1 + 12152%%BP0 + 15008)
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |         2                                 2
+--R                \|- 12%%BP1  + (- 8%%BP0 - 20)%%BP1 - 12%%BP0  - 20%%BP0 - 7
+--R            + 
+--R                                       2
+--R              (10290%%BP0 + 24304)%%BP1
+--R            + 
+--R                         2                                        2
+--R              (10290%%BP0  + 25725%%BP0 + 30744)%%BP1 + 24304%%BP0  + 30744%%BP0
+--R            + 
+--R              16768x + 9824
+--R     + 
+--R           -
+--R                   +----------------+ +--------------+
+--R                   |       +-+        |     +-+
+--R                14\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |         2                                 2
+--R                \|- 12%%BP1  + (- 8%%BP0 - 20)%%BP1 - 12%%BP0  - 20%%BP0 - 7
+--R         + 
+--R                +----------------+ +--------------+
+--R                |       +-+        |     +-+
+--R           - 28\|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BP1
+--R         + 
+--R                +----------------+ +--------------+
+--R                |       +-+        |     +-+
+--R           - 28\|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BP0
+--R         + 
+--R                +----------------+ +--------------+
+--R                |       +-+        |     +-+
+--R           - 70\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R      *
+--R         log
+--R                ((- 5145%%BP0 - 12152)%%BP1 - 12152%%BP0 - 15008)
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |         2                                 2
+--R                \|- 12%%BP1  + (- 8%%BP0 - 20)%%BP1 - 12%%BP0  - 20%%BP0 - 7
+--R            + 
+--R                                       2
+--R              (10290%%BP0 + 24304)%%BP1
+--R            + 
+--R                         2                                        2
+--R              (10290%%BP0  + 25725%%BP0 + 30744)%%BP1 + 24304%%BP0  + 30744%%BP0
+--R            + 
+--R              16768x + 9824
+--R     + 
+--R            +----------------+ +--------------+
+--R            |       +-+        |     +-+
+--R         56\|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BP1
+--R      *
+--R         log
+--R                                         2
+--R              (- 10290%%BP0 - 24304)%%BP1
+--R            + 
+--R                           2                                        3
+--R              (- 10290%%BP0  - 25725%%BP0 - 30744)%%BP1 - 10290%%BP0
+--R            + 
+--R                          2
+--R              - 25725%%BP0  - 20580%%BP0 + 8384x - 6176
+--R     + 
+--R            +----------------+ +--------------+
+--R            |       +-+        |     +-+
+--R         56\|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BP0
+--R      *
+--R                       3            2
+--R         log(10290%%BP0  + 1421%%BP0  - 10164%%BP0 + 8384x + 544)
+--R     + 
+--R                         +--------------+         +-+
+--R           +-+           |     +-+             %i\|7  + 8x + 1
+--R       (28\|7  - 1484%i)\|14%i\|7  + 490 atan(-----------------)
+--R                                               +--------------+
+--R                                               |      +-+
+--R                                              \|- 2%i\|7  + 70
+--R     + 
+--R                           +----------------+        +-+
+--R             +-+           |       +-+            %i\|7  - 8x - 1
+--R       (- 28\|7  - 1484%i)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                   +------------+
+--R                                                   |    +-+
+--R                                                  \|2%i\|7  + 70
+--R     + 
+--R                  +-+               +-+     2
+--R           (- 9%i\|7  + 35)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R                +-+                 +-+     2
+--R           (9%i\|7  + 35)log(- %i x\|7  + 4x  + x + 4)
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R        +----------------+ +--------------+
+--R        |       +-+        |     +-+
+--R     56\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 707
+
+--S 708 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                                      +------------+
+--R            2           +-+         2                 |    +-+
+--R         ((x  - 5x + 1)\|7  + 21%i x  + 7%i x + 21%i)\|2%i\|7  + 70
+--R      *
+--R          +--------------+
+--R          |     +-+
+--R         \|14%i\|7  + 490
+--R     + 
+--R                                                      +----------------+
+--R            2           +-+         2                 |       +-+
+--R         ((x  - 5x + 1)\|7  - 21%i x  - 7%i x - 21%i)\|- 14%i\|7  + 490
+--R      *
+--R          +--------------+
+--R          |      +-+
+--R         \|- 2%i\|7  + 70
+--R     + 
+--R             2
+--R       - 392x  + 5096x - 392
+--R  /
+--R          4        3        2
+--R     3136x  + 1568x  + 7840x  + 1568x + 3136
+--R                                           Type: Expression(Complex(Integer))
+--E 708
+
+)clear all
+
+--S 709 of 1070
+t0:=x*(5+x+3*x^2+2*x^3)/(2+x+5*x^2+x^3+2*x^4)
+--R 
+--R
+--R            4     3    2
+--R          2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 5x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 709
+
+--S 710 of 1070
+r0:=1/14*x*(7-5*%i*sqrt(7))+1/28*log(4+4*x^2+x*(1+%i*sqrt(7)))*(7-5*%i*_
+   sqrt(7))+1/14*x*(7+5*%i*sqrt(7))+1/28*log(4+4*x^2+x*(1-%i*sqrt(7)))*_
+   (7+5*%i*sqrt(7))+atan((1+8*x+%i*sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*_
+   (19*%i-7*sqrt(7))/sqrt(14*(35-%i*sqrt(7)))-atan((1+8*x-%i*sqrt(7))/_
+   sqrt(2*(35+%i*sqrt(7))))*(19*%i+7*sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--R 
+--R
+--R   (2)
+--R                           +--------------+         +-+
+--R              +-+          |     +-+             %i\|7  + 8x + 1
+--R       (- 196\|7  + 532%i)\|14%i\|7  + 490 atan(-----------------)
+--R                                                 +--------------+
+--R                                                 |      +-+
+--R                                                \|- 2%i\|7  + 70
+--R     + 
+--R                         +----------------+        +-+
+--R            +-+          |       +-+            %i\|7  - 8x - 1
+--R       (196\|7  + 532%i)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                 +------------+
+--R                                                 |    +-+
+--R                                                \|2%i\|7  + 70
+--R     + 
+--R                  +-+              +-+     2
+--R           (- 5%i\|7  + 7)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R                +-+                +-+     2
+--R           (5%i\|7  + 7)log(- %i x\|7  + 4x  + x + 4) + 28x
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R        +----------------+ +--------------+
+--R        |       +-+        |     +-+
+--R     28\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 710
+
+--S 711 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +------------------------------------------------------------+
+--R            |         2                                  2
+--R           \|- 21%%BQ1  + (- 14%%BQ0 + 14)%%BQ1 - 21%%BQ0  + 14%%BQ0 - 17
+--R         + 
+--R              +-+         +-+         +-+
+--R           - \|7 %%BQ1 - \|7 %%BQ0 + \|7
+--R      *
+--R         log
+--R                ((3773%%BQ0 - 2744)%%BQ1 - 2744%%BQ0 + 1512)
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |         2                                  2
+--R                \|- 21%%BQ1  + (- 14%%BQ0 + 14)%%BQ1 - 21%%BQ0  + 14%%BQ0 - 17
+--R            + 
+--R                    +-+             +-+      2
+--R              (3773\|7 %%BQ0 - 2744\|7 )%%BQ1
+--R            + 
+--R                    +-+     2        +-+             +-+              +-+     2
+--R              (3773\|7 %%BQ0  - 3773\|7 %%BQ0 + 1232\|7 )%%BQ1 - 2744\|7 %%BQ0
+--R            + 
+--R                   +-+                     +-+
+--R              1232\|7 %%BQ0 + (608x + 328)\|7
+--R     + 
+--R              +------------------------------------------------------------+
+--R              |         2                                  2
+--R           - \|- 21%%BQ1  + (- 14%%BQ0 + 14)%%BQ1 - 21%%BQ0  + 14%%BQ0 - 17
+--R         + 
+--R              +-+         +-+         +-+
+--R           - \|7 %%BQ1 - \|7 %%BQ0 + \|7
+--R      *
+--R         log
+--R                ((- 3773%%BQ0 + 2744)%%BQ1 + 2744%%BQ0 - 1512)
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |         2                                  2
+--R                \|- 21%%BQ1  + (- 14%%BQ0 + 14)%%BQ1 - 21%%BQ0  + 14%%BQ0 - 17
+--R            + 
+--R                    +-+             +-+      2
+--R              (3773\|7 %%BQ0 - 2744\|7 )%%BQ1
+--R            + 
+--R                    +-+     2        +-+             +-+              +-+     2
+--R              (3773\|7 %%BQ0  - 3773\|7 %%BQ0 + 1232\|7 )%%BQ1 - 2744\|7 %%BQ0
+--R            + 
+--R                   +-+                     +-+
+--R              1232\|7 %%BQ0 + (608x + 328)\|7
+--R     + 
+--R           +-+
+--R         2\|7 %%BQ1
+--R      *
+--R         log
+--R                                       2
+--R              (- 3773%%BQ0 + 2744)%%BQ1
+--R            + 
+--R                          2                                     3            2
+--R              (- 3773%%BQ0  + 3773%%BQ0 - 1232)%%BQ1 - 3773%%BQ0  + 3773%%BQ0
+--R            + 
+--R              - 3234%%BQ0 + 304x + 1760
+--R     + 
+--R       +-+                   3            2                                 +-+
+--R     2\|7 %%BQ0 log(3773%%BQ0  - 1029%%BQ0  + 2002%%BQ0 + 304x - 1936) + 2x\|7
+--R  /
+--R       +-+
+--R     2\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 711
+
+--S 712 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +----------------+ +--------------+
+--R               |       +-+        |     +-+
+--R             2\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R          *
+--R              +------------------------------------------------------------+
+--R              |         2                                  2
+--R             \|- 21%%BQ1  + (- 14%%BQ0 + 14)%%BQ1 - 21%%BQ0  + 14%%BQ0 - 17
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BQ1
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BQ0
+--R         + 
+--R                 +----------------+ +--------------+
+--R             +-+ |       +-+        |     +-+
+--R           2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R      *
+--R         log
+--R                ((3773%%BQ0 - 2744)%%BQ1 - 2744%%BQ0 + 1512)
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |         2                                  2
+--R                \|- 21%%BQ1  + (- 14%%BQ0 + 14)%%BQ1 - 21%%BQ0  + 14%%BQ0 - 17
+--R            + 
+--R                    +-+             +-+      2
+--R              (3773\|7 %%BQ0 - 2744\|7 )%%BQ1
+--R            + 
+--R                    +-+     2        +-+             +-+              +-+     2
+--R              (3773\|7 %%BQ0  - 3773\|7 %%BQ0 + 1232\|7 )%%BQ1 - 2744\|7 %%BQ0
+--R            + 
+--R                   +-+                     +-+
+--R              1232\|7 %%BQ0 + (608x + 328)\|7
+--R     + 
+--R           -
+--R                  +----------------+ +--------------+
+--R                  |       +-+        |     +-+
+--R                2\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |         2                                  2
+--R                \|- 21%%BQ1  + (- 14%%BQ0 + 14)%%BQ1 - 21%%BQ0  + 14%%BQ0 - 17
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BQ1
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BQ0
+--R         + 
+--R                 +----------------+ +--------------+
+--R             +-+ |       +-+        |     +-+
+--R           2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R      *
+--R         log
+--R                ((- 3773%%BQ0 + 2744)%%BQ1 + 2744%%BQ0 - 1512)
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |         2                                  2
+--R                \|- 21%%BQ1  + (- 14%%BQ0 + 14)%%BQ1 - 21%%BQ0  + 14%%BQ0 - 17
+--R            + 
+--R                    +-+             +-+      2
+--R              (3773\|7 %%BQ0 - 2744\|7 )%%BQ1
+--R            + 
+--R                    +-+     2        +-+             +-+              +-+     2
+--R              (3773\|7 %%BQ0  - 3773\|7 %%BQ0 + 1232\|7 )%%BQ1 - 2744\|7 %%BQ0
+--R            + 
+--R                   +-+                     +-+
+--R              1232\|7 %%BQ0 + (608x + 328)\|7
+--R     + 
+--R               +----------------+ +--------------+
+--R           +-+ |       +-+        |     +-+
+--R         4\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BQ1
+--R      *
+--R         log
+--R                                       2
+--R              (- 3773%%BQ0 + 2744)%%BQ1
+--R            + 
+--R                          2                                     3            2
+--R              (- 3773%%BQ0  + 3773%%BQ0 - 1232)%%BQ1 - 3773%%BQ0  + 3773%%BQ0
+--R            + 
+--R              - 3234%%BQ0 + 304x + 1760
+--R     + 
+--R               +----------------+ +--------------+
+--R           +-+ |       +-+        |     +-+
+--R         4\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BQ0
+--R      *
+--R                      3            2
+--R         log(3773%%BQ0  - 1029%%BQ0  + 2002%%BQ0 + 304x - 1936)
+--R     + 
+--R                          +--------------+         +-+
+--R               +-+        |     +-+             %i\|7  + 8x + 1
+--R       (- 76%i\|7  + 196)\|14%i\|7  + 490 atan(-----------------)
+--R                                                +--------------+
+--R                                                |      +-+
+--R                                               \|- 2%i\|7  + 70
+--R     + 
+--R                          +----------------+        +-+
+--R               +-+        |       +-+            %i\|7  - 8x - 1
+--R       (- 76%i\|7  - 196)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                  +------------+
+--R                                                  |    +-+
+--R                                                 \|2%i\|7  + 70
+--R     + 
+--R               +-+                +-+     2
+--R           (- \|7  + 5%i)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R               +-+                  +-+     2
+--R           (- \|7  - 5%i)log(- %i x\|7  + 4x  + x + 4)
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R           +----------------+ +--------------+
+--R       +-+ |       +-+        |     +-+
+--R     4\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 712
+
+--S 713 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                                    +------------+
+--R             2          +-+        2                |    +-+
+--R         ((3x  - x + 3)\|7  + 7%i x  + 7%i x + 7%i)\|2%i\|7  + 70
+--R      *
+--R          +--------------+
+--R          |     +-+
+--R         \|14%i\|7  + 490
+--R     + 
+--R                                                    +----------------+
+--R             2          +-+        2                |       +-+
+--R         ((3x  - x + 3)\|7  - 7%i x  - 7%i x - 7%i)\|- 14%i\|7  + 490
+--R      *
+--R          +--------------+
+--R          |      +-+
+--R         \|- 2%i\|7  + 70
+--R     + 
+--R              2
+--R       - 2744x  + 1176x - 2744
+--R  /
+--R          4       3        2
+--R     1568x  + 784x  + 3920x  + 784x + 1568
+--R                                           Type: Expression(Complex(Integer))
+--E 713
+
+)clear all
+
+--S 714 of 1070
+t0:=(5+x+3*x^2+2*x^3)/(2+x+5*x^2+x^3+2*x^4)
+--R 
+--R
+--R             3     2
+--R           2x  + 3x  + x + 5
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 5x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 714
+
+--S 715 of 1070
+r0:=1/28*log(4+4*x^2+x*(1+%i*sqrt(7)))*(7-5*%i*sqrt(7))+1/28*log(4+4*x^2+_
+   x*(1-%i*sqrt(7)))*(7+5*%i*sqrt(7))-atan((1+8*x+%i*sqrt(7))/sqrt(2*_
+   (35-%i*sqrt(7))))*(19*%i-7*sqrt(7))/sqrt(14*(35-%i*sqrt(7)))+_
+   atan((1+8*x-%i*sqrt(7))/sqrt(2*(35+%i*sqrt(7))))*(19*%i+7*sqrt(7))/_
+   sqrt(14*(35+%i*sqrt(7)))
+--R 
+--R
+--R   (2)
+--R                         +--------------+         +-+
+--R            +-+          |     +-+             %i\|7  + 8x + 1
+--R       (196\|7  - 532%i)\|14%i\|7  + 490 atan(-----------------)
+--R                                               +--------------+
+--R                                               |      +-+
+--R                                              \|- 2%i\|7  + 70
+--R     + 
+--R                           +----------------+        +-+
+--R              +-+          |       +-+            %i\|7  - 8x - 1
+--R       (- 196\|7  - 532%i)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                   +------------+
+--R                                                   |    +-+
+--R                                                  \|2%i\|7  + 70
+--R     + 
+--R                  +-+              +-+     2
+--R           (- 5%i\|7  + 7)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R                +-+                +-+     2
+--R           (5%i\|7  + 7)log(- %i x\|7  + 4x  + x + 4)
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R        +----------------+ +--------------+
+--R        |       +-+        |     +-+
+--R     28\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 715
+
+--S 716 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +------------------------------------------------------------+
+--R              |         2                                  2
+--R           - \|- 21%%BR1  + (- 14%%BR0 + 14)%%BR1 - 21%%BR0  + 14%%BR0 - 17
+--R         + 
+--R              +-+         +-+         +-+
+--R           - \|7 %%BR1 - \|7 %%BR0 + \|7
+--R      *
+--R         log
+--R                ((7203%%BR0 - 4900)%%BR1 - 4900%%BR0 + 3080)
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |         2                                  2
+--R                \|- 21%%BR1  + (- 14%%BR0 + 14)%%BR1 - 21%%BR0  + 14%%BR0 - 17
+--R            + 
+--R                      +-+             +-+      2
+--R              (- 7203\|7 %%BR0 + 4900\|7 )%%BR1
+--R            + 
+--R                      +-+     2        +-+             +-+
+--R              (- 7203\|7 %%BR0  + 7203\|7 %%BR0 - 1820\|7 )%%BR1
+--R            + 
+--R                   +-+     2        +-+                     +-+
+--R              4900\|7 %%BR0  - 1820\|7 %%BR0 + (608x - 792)\|7
+--R     + 
+--R            +------------------------------------------------------------+
+--R            |         2                                  2
+--R           \|- 21%%BR1  + (- 14%%BR0 + 14)%%BR1 - 21%%BR0  + 14%%BR0 - 17
+--R         + 
+--R              +-+         +-+         +-+
+--R           - \|7 %%BR1 - \|7 %%BR0 + \|7
+--R      *
+--R         log
+--R                ((- 7203%%BR0 + 4900)%%BR1 + 4900%%BR0 - 3080)
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |         2                                  2
+--R                \|- 21%%BR1  + (- 14%%BR0 + 14)%%BR1 - 21%%BR0  + 14%%BR0 - 17
+--R            + 
+--R                      +-+             +-+      2
+--R              (- 7203\|7 %%BR0 + 4900\|7 )%%BR1
+--R            + 
+--R                      +-+     2        +-+             +-+
+--R              (- 7203\|7 %%BR0  + 7203\|7 %%BR0 - 1820\|7 )%%BR1
+--R            + 
+--R                   +-+     2        +-+                     +-+
+--R              4900\|7 %%BR0  - 1820\|7 %%BR0 + (608x - 792)\|7
+--R     + 
+--R           +-+
+--R         2\|7 %%BR1
+--R      *
+--R         log
+--R                                     2             2
+--R              (7203%%BR0 - 4900)%%BR1  + (7203%%BR0  - 7203%%BR0 + 1820)%%BR1
+--R            + 
+--R                       3            2
+--R              7203%%BR0  - 7203%%BR0  + 6174%%BR0 + 304x - 3056
+--R     + 
+--R         +-+                     3            2
+--R       2\|7 %%BR0 log(- 7203%%BR0  + 2303%%BR0  - 4354%%BR0 + 304x + 4000)
+--R  /
+--R       +-+
+--R     2\|7
+--R                                         Type: Union(Expression(Integer),...)
+--E 716
+
+--S 717 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                  +----------------+ +--------------+
+--R                  |       +-+        |     +-+
+--R                2\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |         2                                  2
+--R                \|- 21%%BR1  + (- 14%%BR0 + 14)%%BR1 - 21%%BR0  + 14%%BR0 - 17
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BR1
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BR0
+--R         + 
+--R                 +----------------+ +--------------+
+--R             +-+ |       +-+        |     +-+
+--R           2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R      *
+--R         log
+--R                ((7203%%BR0 - 4900)%%BR1 - 4900%%BR0 + 3080)
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |         2                                  2
+--R                \|- 21%%BR1  + (- 14%%BR0 + 14)%%BR1 - 21%%BR0  + 14%%BR0 - 17
+--R            + 
+--R                      +-+             +-+      2
+--R              (- 7203\|7 %%BR0 + 4900\|7 )%%BR1
+--R            + 
+--R                      +-+     2        +-+             +-+
+--R              (- 7203\|7 %%BR0  + 7203\|7 %%BR0 - 1820\|7 )%%BR1
+--R            + 
+--R                   +-+     2        +-+                     +-+
+--R              4900\|7 %%BR0  - 1820\|7 %%BR0 + (608x - 792)\|7
+--R     + 
+--R               +----------------+ +--------------+
+--R               |       +-+        |     +-+
+--R             2\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R          *
+--R              +------------------------------------------------------------+
+--R              |         2                                  2
+--R             \|- 21%%BR1  + (- 14%%BR0 + 14)%%BR1 - 21%%BR0  + 14%%BR0 - 17
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BR1
+--R         + 
+--R                   +----------------+ +--------------+
+--R               +-+ |       +-+        |     +-+
+--R           - 2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BR0
+--R         + 
+--R                 +----------------+ +--------------+
+--R             +-+ |       +-+        |     +-+
+--R           2\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R      *
+--R         log
+--R                ((- 7203%%BR0 + 4900)%%BR1 + 4900%%BR0 - 3080)
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |         2                                  2
+--R                \|- 21%%BR1  + (- 14%%BR0 + 14)%%BR1 - 21%%BR0  + 14%%BR0 - 17
+--R            + 
+--R                      +-+             +-+      2
+--R              (- 7203\|7 %%BR0 + 4900\|7 )%%BR1
+--R            + 
+--R                      +-+     2        +-+             +-+
+--R              (- 7203\|7 %%BR0  + 7203\|7 %%BR0 - 1820\|7 )%%BR1
+--R            + 
+--R                   +-+     2        +-+                     +-+
+--R              4900\|7 %%BR0  - 1820\|7 %%BR0 + (608x - 792)\|7
+--R     + 
+--R               +----------------+ +--------------+
+--R           +-+ |       +-+        |     +-+
+--R         4\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BR1
+--R      *
+--R         log
+--R                                     2             2
+--R              (7203%%BR0 - 4900)%%BR1  + (7203%%BR0  - 7203%%BR0 + 1820)%%BR1
+--R            + 
+--R                       3            2
+--R              7203%%BR0  - 7203%%BR0  + 6174%%BR0 + 304x - 3056
+--R     + 
+--R               +----------------+ +--------------+
+--R           +-+ |       +-+        |     +-+
+--R         4\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490 %%BR0
+--R      *
+--R                        3            2
+--R         log(- 7203%%BR0  + 2303%%BR0  - 4354%%BR0 + 304x + 4000)
+--R     + 
+--R                        +--------------+         +-+
+--R             +-+        |     +-+             %i\|7  + 8x + 1
+--R       (76%i\|7  - 196)\|14%i\|7  + 490 atan(-----------------)
+--R                                              +--------------+
+--R                                              |      +-+
+--R                                             \|- 2%i\|7  + 70
+--R     + 
+--R                        +----------------+        +-+
+--R             +-+        |       +-+            %i\|7  - 8x - 1
+--R       (76%i\|7  + 196)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                +------------+
+--R                                                |    +-+
+--R                                               \|2%i\|7  + 70
+--R     + 
+--R               +-+                +-+     2
+--R           (- \|7  + 5%i)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R               +-+                  +-+     2
+--R           (- \|7  - 5%i)log(- %i x\|7  + 4x  + x + 4)
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R           +----------------+ +--------------+
+--R       +-+ |       +-+        |     +-+
+--R     4\|7 \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 717
+
+--S 718 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                                      +------------+
+--R               2          +-+        2                |    +-+
+--R         ((- 3x  + x - 3)\|7  - 7%i x  - 7%i x - 7%i)\|2%i\|7  + 70
+--R      *
+--R          +--------------+
+--R          |     +-+
+--R         \|14%i\|7  + 490
+--R     + 
+--R                                                      +----------------+
+--R               2          +-+        2                |       +-+
+--R         ((- 3x  + x - 3)\|7  + 7%i x  + 7%i x + 7%i)\|- 14%i\|7  + 490
+--R      *
+--R          +--------------+
+--R          |      +-+
+--R         \|- 2%i\|7  + 70
+--R     + 
+--R            2
+--R       2744x  - 1176x + 2744
+--R  /
+--R          4       3        2
+--R     1568x  + 784x  + 3920x  + 784x + 1568
+--R                                           Type: Expression(Complex(Integer))
+--E 718
+
+)clear all
+
+--S 719 of 1070
+t0:=(5+x+3*x^2+2*x^3)/(x*(2+x+5*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  ------------------------
+--R          5    4     3    2
+--R        2x  + x  + 5x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 719
+
+--S 720 of 1070
+--r0:=1/28*log(x)*(35-9*%i*sqrt(7))-1/56*log(4*%i+4*%i*x^2+x*(%i-sqrt(7)))*_
+--   (35-9*%i*sqrt(7))+1/28*log(x)*(35+9*%i*sqrt(7))-1/56*log(4*%i+_
+--   4*%i*x^2+x*(%i+sqrt(7)))*(35+9*%i*sqrt(7))-1/2*atanh((%i+8*%i*x-_
+--   sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*(53+%i*sqrt(7))/sqrt(14*(35-%i*_
+--   sqrt(7)))+1/2*atanh((%i+8*%i*x+sqrt(7))/sqrt(2*(35+%i*sqrt(7))))*_
+--   (53-%i*sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--E 720
+
+--S 721 of 1070
+--a0:=integrate(t0,x)
+--E 721
+
+--S 722 of 1070
+--m0:=a0-r0
+--E 722
+
+--S 723 of 1070
+--d0:=normalize(D(m0,x))
+--E 723
+
+)clear all
+
+--S 724 of 1070
+t0:=(5+x+3*x^2+2*x^3)/(x^2*(2+x+5*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  -------------------------
+--R          6    5     4    3     2
+--R        2x  + x  + 5x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 724
+
+--S 725 of 1070
+--r0:=1/28*(-35+9*%i*sqrt(7))/x+1/28*(-35-9*%i*sqrt(7))/x-_
+--   3/56*log(x)*(7-11*%i*sqrt(7))+3/112*log(4*%i+4*%i*x^2+x*(%i+sqrt(7)))*_
+--   (7-11*%i*sqrt(7))-3/56*log(x)*(7+11*%i*sqrt(7))+3/112*log(4*%i+_
+--   4*%i*x^2+x*(%i-sqrt(7)))*(7+11*%i*sqrt(7))+11/4*atanh((%i+8*%i*x-_
+--   sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*(9+5*%i*sqrt(7))/sqrt(14*(35-_
+--   %i*sqrt(7)))-11/4*atanh((%i+8*%i*x+sqrt(7))/sqrt(2*(35+%i*sqrt(7))))*_
+--   (9-5*%i*sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--E 725
+
+--S 726 of 1070
+--a0:=integrate(t0,x)
+--E 726
+
+--S 727 of 1070
+--m0:=a0-r0
+--E 727
+
+--S 728 of 1070
+--d0:=normalize(D(m0,x))
+--E 728
+
+)clear all
+
+--S 729 of 1070
+t0:=(5+x+3*x^2+2*x^3)/(x^3*(2+x+5*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  -------------------------
+--R          7    6     5    4     3
+--R        2x  + x  + 5x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 729
+
+--S 730 of 1070
+--r0:=1/56*(-35+9*%i*sqrt(7))/x^2-1/16*log(x)*(35-9*%i*sqrt(7))+_
+--   1/32*log(4*%i+4*%i*x^2+x*(%i-sqrt(7)))*(35-9*%i*sqrt(7))+_
+--   1/56*(-35-9*%i*sqrt(7))/x^2-1/16*log(x)*(35+9*%i*sqrt(7))+_
+--   1/32*log(4*%i+4*%i*x^2+x*(%i+sqrt(7)))*(35+9*%i*sqrt(7))+_
+--   3/56*(7-11*%i*sqrt(7))/x+3/56*(7+11*%i*sqrt(7))/x+_
+--   1/8*atanh((%i+8*%i*x-sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*(355-73*%i*_
+--   sqrt(7))/sqrt(14*(35-%i*sqrt(7)))-1/8*atanh((%i+8*%i*x+sqrt(7))/_
+--   sqrt(2*(35+%i*sqrt(7))))*(355+73*%i*sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--E 730
+
+--S 731 of 1070
+--a0:=integrate(t0,x)
+--E 731
+
+--S 732 of 1070
+--m0:=a0-r0
+--E 732
+
+--S 733 of 1070
+--d0:=normalize(D(m0,x))
+--E 733
+
+)clear all
+
+--S 734 of 1070
+t0:=1/(4*x^(3/2)+sqrt(x))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R                 +-+
+--R        (4x + 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 734
+
+--S 735 of 1070
+r0:=atan(2*sqrt(x))
+--R 
+--R
+--R               +-+
+--R   (2)  atan(2\|x )
+--R                                                    Type: Expression(Integer)
+--E 735
+
+--S 736 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+
+--R   (3)  atan(2\|x )
+--R                                         Type: Union(Expression(Integer),...)
+--E 736
+
+--S 737 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 738
+
+)clear all
+
+--S 739 of 1070
+t0:=1/(-x^(5/2)+sqrt(x))
+--R 
+--R
+--R                1
+--R   (1)  - ------------
+--R            2      +-+
+--R          (x  - 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 1070
+r0:=atan(sqrt(x))+atanh(sqrt(x))
+--R 
+--R
+--R               +-+          +-+
+--R   (2)  atanh(\|x ) + atan(\|x )
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +-+             +-+               +-+
+--R        log(\|x  + 1) - log(\|x  - 1) + 2atan(\|x )
+--R   (3)  -------------------------------------------
+--R                             2
+--R                                         Type: Union(Expression(Integer),...)
+--E 741
+
+--S 742 of 1070
+m0:=a0-r0
+--R 
+--R
+--R             +-+             +-+                +-+
+--R        log(\|x  + 1) - log(\|x  - 1) - 2atanh(\|x )
+--R   (4)  --------------------------------------------
+--R                              2
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 743
+
+)clear all
+
+--S 744 of 1070
+t0:=1/(-x^(1/4)+sqrt(x))
+--R 
+--R
+--R               1
+--R   (1)  - -----------
+--R          4+-+    +-+
+--R          \|x  - \|x
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 1070
+r0:=4*x^(1/4)+4*log(1-x^(1/4))+2*sqrt(x)
+--R 
+--R
+--R               4+-+         4+-+     +-+
+--R   (2)  4log(- \|x  + 1) + 4\|x  + 2\|x
+--R                                                    Type: Expression(Integer)
+--E 745
+
+--S 746 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4+-+         4+-+2    4+-+
+--R   (3)  4log(\|x  - 1) + 2\|x   + 4\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 746
+
+--S 747 of 1070
+m0:=a0-r0
+--R 
+--R
+--R             4+-+               4+-+         4+-+2     +-+
+--R   (4)  4log(\|x  - 1) - 4log(- \|x  + 1) + 2\|x   - 2\|x
+--R                                                    Type: Expression(Integer)
+--E 747
+
+--S 748 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 748
+
+)clear all
+
+--S 749 of 1070
+t0:=1/(x^(1/3)+sqrt(x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R        3+-+    +-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 1070
+r0:=6*x^(1/6)-3*x^(1/3)-6*log(1+x^(1/6))+2*sqrt(x)
+--R 
+--R
+--R               6+-+         6+-+    3+-+     +-+
+--R   (2)  - 6log(\|x  + 1) + 6\|x  - 3\|x  + 2\|x
+--R                                                    Type: Expression(Integer)
+--E 750
+
+--S 751 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R               6+-+         6+-+3    6+-+2    6+-+
+--R   (3)  - 6log(\|x  + 1) + 2\|x   - 3\|x   + 6\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 751
+
+--S 752 of 1070
+m0:=a0-r0
+--R 
+--R
+--R         6+-+3    6+-+2    3+-+     +-+
+--R   (4)  2\|x   - 3\|x   + 3\|x  - 2\|x
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 753
+
+)clear all
+
+--S 754 of 1070
+t0:=1/(x^(1/4)+sqrt(x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R        4+-+    +-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 1070
+r0:=-4*x^(1/4)+4*log(1+x^(1/4))+2*sqrt(x)
+--R 
+--R
+--R             4+-+         4+-+     +-+
+--R   (2)  4log(\|x  + 1) - 4\|x  + 2\|x
+--R                                                    Type: Expression(Integer)
+--E 755
+
+--S 756 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4+-+         4+-+2    4+-+
+--R   (3)  4log(\|x  + 1) + 2\|x   - 4\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 756
+
+--S 757 of 1070
+m0:=a0-r0
+--R 
+--R
+--R         4+-+2     +-+
+--R   (4)  2\|x   - 2\|x
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 758
+
+)clear all
+
+--S 759 of 1070
+t0:=1/(-x^(1/3)+x^(2/3))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R        3+-+2   3+-+
+--R        \|x   - \|x
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 1070
+r0:=3*x^(1/3)+3*log(1-x^(1/3))
+--R 
+--R
+--R               3+-+         3+-+
+--R   (2)  3log(- \|x  + 1) + 3\|x
+--R                                                    Type: Expression(Integer)
+--E 760
+
+--S 761 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3+-+         3+-+
+--R   (3)  3log(\|x  - 1) + 3\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 761
+
+--S 762 of 1070
+m0:=a0-r0
+--R 
+--R
+--R             3+-+               3+-+
+--R   (4)  3log(\|x  - 1) - 3log(- \|x  + 1)
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 763
+
+)clear all
+
+--S 764 of 1070
+t0:=1/(1/x^(1/4)+sqrt(x))
+--R 
+--R
+--R            4+-+
+--R            \|x
+--R   (1)  ------------
+--R         +-+4+-+
+--R        \|x \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 1070
+r0:=4/3*log(1+x^(1/4))-2/3*log(1-x^(1/4)+sqrt(x))+_
+   4*atan((1-2*x^(1/4))/sqrt(3))/sqrt(3)+2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R                                                                  4+-+
+--R         +-+    4+-+          +-+      4+-+    +-+               2\|x  - 1
+--R       4\|3 log(\|x  + 1) - 2\|3 log(- \|x  + \|x  + 1) - 12atan(---------)
+--R                                                                     +-+
+--R                                                                    \|3
+--R     + 
+--R         +-+ +-+
+--R       6\|3 \|x
+--R  /
+--R       +-+
+--R     3\|3
+--R                                                    Type: Expression(Integer)
+--E 765
+
+--S 766 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-+    4+-+2   4+-+          +-+    4+-+
+--R       - 2\|3 log(\|x   - \|x  + 1) + 4\|3 log(\|x  + 1)
+--R     + 
+--R                  +-+4+-+    +-+
+--R                2\|3 \|x  - \|3       +-+4+-+2
+--R       - 12atan(----------------) + 6\|3 \|x
+--R                        3
+--R  /
+--R       +-+
+--R     3\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 766
+
+--S 767 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           +-+    4+-+2   4+-+          +-+      4+-+    +-+
+--R       - 2\|3 log(\|x   - \|x  + 1) + 2\|3 log(- \|x  + \|x  + 1)
+--R     + 
+--R                  +-+4+-+    +-+            4+-+
+--R                2\|3 \|x  - \|3            2\|x  - 1      +-+4+-+2     +-+ +-+
+--R       - 12atan(----------------) + 12atan(---------) + 6\|3 \|x   - 6\|3 \|x
+--R                        3                      +-+
+--R                                              \|3
+--R  /
+--R       +-+
+--R     3\|3
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 768
+
+)clear all
+
+--S 769 of 1070
+t0:=1/(x^(1/4)+x^(1/3))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R        4+-+   3+-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 1070
+r0:=-12*x^(1/12)+6*x^(1/6)-4*x^(1/4)+3*x^(1/3)-12/5*x^(5/12)-_
+   12/7*x^(7/12)+3/2*x^(2/3)+12*log(1+x^(1/12))+2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R              12+-+           12+-+7      12+-+5      12+-+      6+-+      4+-+
+--R       840log( \|x  + 1) - 120 \|x   - 168 \|x   - 840 \|x  + 420\|x  - 280\|x
+--R     + 
+--R          3+-+2      3+-+       +-+
+--R       105\|x   + 210\|x  + 140\|x
+--R  /
+--R     70
+--R                                                    Type: Expression(Integer)
+--E 770
+
+--S 771 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              12+-+           12+-+8      12+-+7      12+-+6      12+-+5
+--R       840log( \|x  + 1) + 105 \|x   - 120 \|x   + 140 \|x   - 168 \|x
+--R     + 
+--R          12+-+4      12+-+3      12+-+2      12+-+
+--R       210 \|x   - 280 \|x   + 420 \|x   - 840 \|x
+--R  /
+--R     70
+--R                                         Type: Union(Expression(Integer),...)
+--E 771
+
+--S 772 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        12+-+8    12+-+6    12+-+4    12+-+3     12+-+2     6+-+    4+-+
+--R       3 \|x   + 4 \|x   + 6 \|x   - 8 \|x   + 12 \|x   - 12\|x  + 8\|x
+--R     + 
+--R          3+-+2    3+-+     +-+
+--R       - 3\|x   - 6\|x  - 4\|x
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 773
+
+)clear all
+
+--S 774 of 1070
+t0:=1/(1/x^(1/3)+1/x^(1/4))
+--R 
+--R
+--R          3+-+4+-+
+--R          \|x \|x
+--R   (1)  -----------
+--R        4+-+   3+-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 1070
+r0:=12*x^(1/12)-6*x^(1/6)+4*x^(1/4)-3*x^(1/3)+12/5*x^(5/12)+12/7*x^(7/12)-_
+   3/2*x^(2/3)+4/3*x^(3/4)-6/5*x^(5/6)+12/11*x^(11/12)-x+_
+   12/13*x^(13/12)-6/7*x^(7/6)+4/5*x^(5/4)-12*log(1+x^(1/12))-2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R                   12+-+             12+-+11        12+-+7        12+-+5
+--R       - 360360log( \|x  + 1) + 32760 \|x    + 51480 \|x   + 72072 \|x
+--R     + 
+--R                        12+-+        6+-+5                      6+-+
+--R       (27720x + 360360) \|x  - 36036\|x   + (- 25740x - 180180)\|x
+--R     + 
+--R            4+-+3                    4+-+        3+-+2        3+-+         +-+
+--R       40040\|x   + (24024x + 120120)\|x  - 45045\|x   - 90090\|x  - 60060\|x
+--R     + 
+--R       - 30030x
+--R  /
+--R     30030
+--R                                                    Type: Expression(Integer)
+--E 775
+
+--S 776 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   12+-+             12+-+11        12+-+10        12+-+9
+--R       - 360360log( \|x  + 1) + 32760 \|x    - 36036 \|x    + 40040 \|x
+--R     + 
+--R              12+-+8        12+-+7        12+-+6        12+-+5        12+-+4
+--R       - 45045 \|x   + 51480 \|x   - 60060 \|x   + 72072 \|x   - 90090 \|x
+--R     + 
+--R                        12+-+3                      12+-+2
+--R       (24024x + 120120) \|x   + (- 25740x - 180180) \|x
+--R     + 
+--R                        12+-+
+--R       (27720x + 360360) \|x  - 30030x
+--R  /
+--R     30030
+--R                                         Type: Union(Expression(Integer),...)
+--E 776
+
+--S 777 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            12+-+10      12+-+9      12+-+8      12+-+6      12+-+4
+--R       - 252 \|x    + 280 \|x   - 315 \|x   - 420 \|x   - 630 \|x
+--R     + 
+--R                   12+-+3                  12+-+2      6+-+5                6+-+
+--R       (168x + 840) \|x   + (- 180x - 1260) \|x   + 252\|x   + (180x + 1260)\|x
+--R     + 
+--R            4+-+3                 4+-+      3+-+2      3+-+       +-+
+--R       - 280\|x   + (- 168x - 840)\|x  + 315\|x   + 630\|x  + 420\|x
+--R  /
+--R     210
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 778
+
+)clear all
+
+--S 779 of 1070
+t0:=1/((-1)/x^(1/3)+sqrt(x))
+--R 
+--R
+--R            3+-+
+--R            \|x
+--R   (1)  ------------
+--R         +-+3+-+
+--R        \|x \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 1070
+r0:=6/5*log(1-x^(1/6))-3/10*log(2+2*x^(1/3)+x^(1/6)*(1+sqrt(5)))*_
+   (1-sqrt(5))-3/10*log(2+2*x^(1/3)+x^(1/6)*(1-sqrt(5)))*(1+sqrt(5))+_
+   2*sqrt(x)+6*atan((1+4*x^(1/6)-sqrt(5))/sqrt(2*(5+sqrt(5))))*_
+   sqrt(2/5/(5+sqrt(5)))-3/5*atan(1/2*(1+4*x^(1/6)+sqrt(5))*_
+   sqrt(1/10*(5+sqrt(5))))*sqrt(2*(5+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R          +-+ +-+     +-+       +-+     6+-+    3+-+
+--R       (3\|2 \|5  - 3\|2 )log((\|5  + 1)\|x  + 2\|x  + 2)
+--R     + 
+--R          +-+      6+-+
+--R       12\|2 log(- \|x  + 1)
+--R     + 
+--R            +-+ +-+     +-+         +-+     6+-+    3+-+
+--R       (- 3\|2 \|5  - 3\|2 )log((- \|5  + 1)\|x  + 2\|x  + 2)
+--R     + 
+--R                                                   +--------+
+--R               +----------+       6+-+    +-+      | +-+
+--R           +-+ |  +-+           (4\|x  + \|5  + 1)\|\|5  + 5
+--R       - 6\|2 \|2\|5  + 10 atan(-----------------------------)
+--R                                              +--+
+--R                                            2\|10
+--R     + 
+--R          +----------+      6+-+    +-+
+--R          |   +-+          4\|x  - \|5  + 1       +-+ +-+
+--R       12\|- \|5  + 5 atan(----------------) + 20\|2 \|x
+--R                              +----------+
+--R                              |  +-+
+--R                             \|2\|5  + 10
+--R  /
+--R        +-+
+--R     10\|2
+--R                                                    Type: Expression(Integer)
+--E 780
+
+--S 781 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +-------------------------------------------------------------+
+--R            |         2                                  2
+--R           \|- 75%%BS1  + (- 50%%BS0 - 60)%%BS1 - 75%%BS0  - 60%%BS0 - 108
+--R         + 
+--R           - 5%%BS1 - 5%%BS0 - 6
+--R      *
+--R         log
+--R                (5%%BS1 + 5%%BS0 + 6)
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |         2                                  2
+--R              \|- 75%%BS1  + (- 50%%BS0 - 60)%%BS1 - 75%%BS0  - 60%%BS0 - 108
+--R            + 
+--R                     2          2     6+-+
+--R              25%%BS1  + 25%%BS0  + 72\|x  + 36
+--R     + 
+--R              +-------------------------------------------------------------+
+--R              |         2                                  2
+--R           - \|- 75%%BS1  + (- 50%%BS0 - 60)%%BS1 - 75%%BS0  - 60%%BS0 - 108
+--R         + 
+--R           - 5%%BS1 - 5%%BS0 - 6
+--R      *
+--R         log
+--R                (- 5%%BS1 - 5%%BS0 - 6)
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |         2                                  2
+--R              \|- 75%%BS1  + (- 50%%BS0 - 60)%%BS1 - 75%%BS0  - 60%%BS0 - 108
+--R            + 
+--R                     2          2     6+-+
+--R              25%%BS1  + 25%%BS0  + 72\|x  + 36
+--R     + 
+--R                            2     6+-+          6+-+
+--R       10%%BS1 log(- 25%%BS1  + 36\|x ) + 12log(\|x  - 1)
+--R     + 
+--R                            2     6+-+      6+-+3
+--R       10%%BS0 log(- 25%%BS0  + 36\|x ) + 20\|x
+--R  /
+--R     10
+--R                                         Type: Union(Expression(Integer),...)
+--E 781
+
+--S 782 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-------------------------------------------------------------+
+--R            +-+ |         2                                  2
+--R           \|2 \|- 75%%BS1  + (- 50%%BS0 - 60)%%BS1 - 75%%BS0  - 60%%BS0 - 108
+--R         + 
+--R               +-+          +-+          +-+
+--R           - 5\|2 %%BS1 - 5\|2 %%BS0 - 6\|2
+--R      *
+--R         log
+--R                (5%%BS1 + 5%%BS0 + 6)
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |         2                                  2
+--R              \|- 75%%BS1  + (- 50%%BS0 - 60)%%BS1 - 75%%BS0  - 60%%BS0 - 108
+--R            + 
+--R                     2          2     6+-+
+--R              25%%BS1  + 25%%BS0  + 72\|x  + 36
+--R     + 
+--R           -
+--R                 +-+
+--R                \|2
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |         2                                  2
+--R              \|- 75%%BS1  + (- 50%%BS0 - 60)%%BS1 - 75%%BS0  - 60%%BS0 - 108
+--R         + 
+--R               +-+          +-+          +-+
+--R           - 5\|2 %%BS1 - 5\|2 %%BS0 - 6\|2
+--R      *
+--R         log
+--R                (- 5%%BS1 - 5%%BS0 - 6)
+--R             *
+--R               +-------------------------------------------------------------+
+--R               |         2                                  2
+--R              \|- 75%%BS1  + (- 50%%BS0 - 60)%%BS1 - 75%%BS0  - 60%%BS0 - 108
+--R            + 
+--R                     2          2     6+-+
+--R              25%%BS1  + 25%%BS0  + 72\|x  + 36
+--R     + 
+--R          +-+                   2     6+-+
+--R       10\|2 %%BS1 log(- 25%%BS1  + 36\|x )
+--R     + 
+--R            +-+ +-+     +-+       +-+     6+-+    3+-+
+--R       (- 3\|2 \|5  + 3\|2 )log((\|5  + 1)\|x  + 2\|x  + 2)
+--R     + 
+--R          +-+    6+-+           +-+      6+-+
+--R       12\|2 log(\|x  - 1) - 12\|2 log(- \|x  + 1)
+--R     + 
+--R          +-+ +-+     +-+         +-+     6+-+    3+-+
+--R       (3\|2 \|5  + 3\|2 )log((- \|5  + 1)\|x  + 2\|x  + 2)
+--R     + 
+--R          +-+                   2     6+-+
+--R       10\|2 %%BS0 log(- 25%%BS0  + 36\|x )
+--R     + 
+--R                                                 +--------+
+--R             +----------+       6+-+    +-+      | +-+
+--R         +-+ |  +-+           (4\|x  + \|5  + 1)\|\|5  + 5
+--R       6\|2 \|2\|5  + 10 atan(-----------------------------)
+--R                                            +--+
+--R                                          2\|10
+--R     + 
+--R            +----------+      6+-+    +-+
+--R            |   +-+          4\|x  - \|5  + 1       +-+6+-+3      +-+ +-+
+--R       - 12\|- \|5  + 5 atan(----------------) + 20\|2 \|x   - 20\|2 \|x
+--R                                +----------+
+--R                                |  +-+
+--R                               \|2\|5  + 10
+--R  /
+--R        +-+
+--R     10\|2
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                   +-+     2           +--+6+-+5
+--R               (2x\|5  + 2x  - 2x + 2)\|10 \|x
+--R             + 
+--R                   2 +-+    2       +--+6+-+4     2 +--+6+-+3      +--+6+-+
+--R               (- x \|5  + x  - 4x)\|10 \|x   + 2x \|10 \|x   + 2x\|10 \|x
+--R             + 
+--R                    +-+     2      +--+
+--R               (- x\|5  - 4x  + x)\|10
+--R          *
+--R              +--------+
+--R              | +-+
+--R             \|\|5  + 5
+--R         + 
+--R                                                             +----------+
+--R                2           +-+ +-+        2            +-+  |   +-+     6+-+5
+--R           ((- x  + 6x - 1)\|2 \|5  + (- 5x  + 10x - 5)\|2 )\|- \|5  + 5 \|x
+--R         + 
+--R                                                      +----------+
+--R                 2       +-+ +-+        2        +-+  |   +-+     6+-+4
+--R           ((- 3x  + 2x)\|2 \|5  + (- 5x  + 10x)\|2 )\|- \|5  + 5 \|x
+--R         + 
+--R                                    +----------+
+--R               2 +-+ +-+     2 +-+  |   +-+     6+-+3
+--R           (- x \|2 \|5  - 5x \|2 )\|- \|5  + 5 \|x
+--R         + 
+--R                                  +----------+
+--R                +-+ +-+      +-+  |   +-+     6+-+
+--R           (- x\|2 \|5  - 5x\|2 )\|- \|5  + 5 \|x
+--R         + 
+--R                                                  +----------+
+--R               2       +-+ +-+       2       +-+  |   +-+
+--R           ((2x  - 3x)\|2 \|5  + (10x  - 5x)\|2 )\|- \|5  + 5
+--R      *
+--R          +----------+
+--R          |  +-+
+--R         \|2\|5  + 10
+--R     + 
+--R              +-+        6+-+5       2 +-+       2 6+-+4       +-+
+--R       (- 40x\|5  - 200x)\|x   + (20x \|5  + 100x )\|x   + 20x\|5  + 100x
+--R  /
+--R            3      2        +-+       3       2        6+-+5
+--R       ((40x  - 80x  + 40x)\|5  + 200x  - 400x  + 200x)\|x
+--R     + 
+--R            3      2        +-+       3       2        6+-+4
+--R       ((40x  - 80x  + 40x)\|5  + 200x  - 400x  + 200x)\|x
+--R     + 
+--R            3      2  +-+       3       2 6+-+3
+--R       ((40x  - 80x )\|5  + 200x  - 400x )\|x
+--R     + 
+--R            3      2  +-+       3       2 6+-+2
+--R       ((40x  + 40x )\|5  + 200x  + 200x )\|x
+--R     + 
+--R              3      2  +-+       3       2 6+-+       4      3      2  +-+
+--R       ((- 80x  + 40x )\|5  - 400x  + 200x )\|x  + (40x  - 80x  + 40x )\|5
+--R     + 
+--R           4       3       2
+--R       200x  - 400x  + 200x
+--R                                                    Type: Expression(Integer)
+--E 783
+
+)clear all
+
+--S 784 of 1070
+t0:=sqrt(x)/(x+x^2)
+--R 
+--R
+--R          +-+
+--R         \|x
+--R   (1)  ------
+--R         2
+--R        x  + x
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 1070
+r0:=2*atan(sqrt(x))
+--R 
+--R
+--R               +-+
+--R   (2)  2atan(\|x )
+--R                                                    Type: Expression(Integer)
+--E 785
+
+--S 786 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+
+--R   (3)  2atan(\|x )
+--R                                         Type: Union(Expression(Integer),...)
+--E 786
+
+--S 787 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 788
+
+)clear all
+
+--S 789 of 1070
+t0:=x/(x+4*sqrt(x))
+--R 
+--R
+--R            x
+--R   (1)  ---------
+--R          +-+
+--R        4\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 1070
+r0:=x+32*log(4+sqrt(x))-8*sqrt(x)
+--R 
+--R
+--R               +-+          +-+
+--R   (2)  32log(\|x  + 4) - 8\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 790
+
+--S 791 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+          +-+
+--R   (3)  32log(\|x  + 4) - 8\|x  + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 791
+
+--S 792 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 792
+
+--S 793 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 793
+
+)clear all
+
+--S 794 of 1070
+t0:=sqrt(x)/(x^(1/3)+x)
+--R 
+--R
+--R           +-+
+--R          \|x
+--R   (1)  --------
+--R        3+-+
+--R        \|x  + x
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 1070
+r0:=3*atan(1-x^(1/6)*sqrt(2))/sqrt(2)-3*atan(1+x^(1/6)*sqrt(2))/sqrt(2)-_
+   3/2*log(1+x^(1/3)-x^(1/6)*sqrt(2))/sqrt(2)+3/2*log(1+x^(1/3)+_
+   x^(1/6)*sqrt(2))/sqrt(2)+2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R             +-+6+-+   3+-+                +-+6+-+   3+-+
+--R       3log(\|2 \|x  + \|x  + 1) - 3log(- \|2 \|x  + \|x  + 1)
+--R     + 
+--R                +-+6+-+               +-+6+-+          +-+ +-+
+--R       - 6atan(\|2 \|x  + 1) - 6atan(\|2 \|x  - 1) + 4\|2 \|x
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 795
+
+--S 796 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         +-+    6+-+2    +-+6+-+          +-+    6+-+2    +-+6+-+
+--R       3\|2 log(\|x   + \|2 \|x  + 1) - 3\|2 log(\|x   - \|2 \|x  + 1)
+--R     + 
+--R         +-+           1           +-+           1          6+-+3
+--R       6\|2 atan(------------) + 6\|2 atan(------------) + 8\|x
+--R                  +-+6+-+                   +-+6+-+
+--R                 \|2 \|x  - 1              \|2 \|x  + 1
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 796
+
+--S 797 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            6+-+2    +-+6+-+             6+-+2    +-+6+-+
+--R       3log(\|x   + \|2 \|x  + 1) - 3log(\|x   - \|2 \|x  + 1)
+--R     + 
+--R               +-+6+-+   3+-+                +-+6+-+   3+-+
+--R       - 3log(\|2 \|x  + \|x  + 1) + 3log(- \|2 \|x  + \|x  + 1)
+--R     + 
+--R              +-+6+-+               +-+6+-+                    1
+--R       6atan(\|2 \|x  + 1) + 6atan(\|2 \|x  - 1) + 6atan(------------)
+--R                                                          +-+6+-+
+--R                                                         \|2 \|x  - 1
+--R     + 
+--R                   1           +-+6+-+3     +-+ +-+
+--R       6atan(------------) + 4\|2 \|x   - 4\|2 \|x
+--R              +-+6+-+
+--R             \|2 \|x  + 1
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 797
+
+--S 798 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 798
+
+)clear all
+
+--S 799 of 1070
+t0:=x^(1/3)/(x^(1/4)+sqrt(x))
+--R 
+--R
+--R            3+-+
+--R            \|x
+--R   (1)  -----------
+--R        4+-+    +-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 799
+
+--S 800 of 1070
+r0:=-12*x^(1/12)+3*x^(1/3)-12/7*x^(7/12)+6/5*x^(5/6)+4*log(1+x^(1/12))-_
+   2*log(1-x^(1/12)+x^(1/6))-4*atan((1-2*x^(1/12))/sqrt(3))*sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                    12+-+
+--R              12+-+                12+-+   6+-+            +-+     2 \|x  - 1
+--R       140log( \|x  + 1) - 70log(-  \|x  + \|x  + 1) + 140\|3 atan(----------)
+--R                                                                       +-+
+--R                                                                      \|3
+--R     + 
+--R           12+-+7      12+-+     6+-+5      3+-+
+--R       - 60 \|x   - 420 \|x  + 42\|x   + 105\|x
+--R  /
+--R     35
+--R                                                    Type: Expression(Integer)
+--E 800
+
+--S 801 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                      12+-+
+--R               12+-+2   12+-+               12+-+            +-+     2 \|x  - 1
+--R       - 70log( \|x   -  \|x  + 1) + 140log( \|x  + 1) + 140\|3 atan(----------)
+--R                                                                         +-+
+--R                                                                        \|3
+--R     + 
+--R         12+-+10     12+-+7      12+-+4      12+-+
+--R       42 \|x    - 60 \|x   + 105 \|x   - 420 \|x
+--R  /
+--R     35
+--R                                         Type: Union(Expression(Integer),...)
+--E 801
+
+--S 802 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               12+-+2   12+-+                12+-+   6+-+         12+-+10
+--R       - 10log( \|x   -  \|x  + 1) + 10log(-  \|x  + \|x  + 1) + 6 \|x
+--R     + 
+--R         12+-+4    6+-+5     3+-+
+--R       15 \|x   - 6\|x   - 15\|x
+--R  /
+--R     5
+--R                                                    Type: Expression(Integer)
+--E 802
+
+--S 803 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 803
+
+)clear all
+
+--S 804 of 1070
+t0:=sqrt(x)/(x^(1/4)+x^(1/3))
+--R 
+--R
+--R             +-+
+--R            \|x
+--R   (1)  -----------
+--R        4+-+   3+-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 1070
+r0:=-12*x^(1/12)+6*x^(1/6)-4*x^(1/4)+3*x^(1/3)-12/5*x^(5/12)-12/7*x^(7/12)+_
+   3/2*x^(2/3)-4/3*x^(3/4)+6/5*x^(5/6)-12/11*x^(11/12)+x-_
+   12/13*x^(13/12)+6/7*x^(7/6)+12*log(1+x^(1/12))+2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R                 12+-+             12+-+11        12+-+7        12+-+5
+--R       360360log( \|x  + 1) - 32760 \|x    - 51480 \|x   - 72072 \|x
+--R     + 
+--R                          12+-+        6+-+5                    6+-+
+--R       (- 27720x - 360360) \|x  + 36036\|x   + (25740x + 180180)\|x
+--R     + 
+--R              4+-+3         4+-+        3+-+2        3+-+         +-+
+--R       - 40040\|x   - 120120\|x  + 45045\|x   + 90090\|x  + 60060\|x  + 30030x
+--R  /
+--R     30030
+--R                                                    Type: Expression(Integer)
+--E 805
+
+--S 806 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 12+-+             12+-+11        12+-+10        12+-+9
+--R       360360log( \|x  + 1) - 32760 \|x    + 36036 \|x    - 40040 \|x
+--R     + 
+--R            12+-+8        12+-+7        12+-+6        12+-+5        12+-+4
+--R       45045 \|x   - 51480 \|x   + 60060 \|x   - 72072 \|x   + 90090 \|x
+--R     + 
+--R               12+-+3                    12+-+2                      12+-+
+--R       - 120120 \|x   + (25740x + 180180) \|x   + (- 27720x - 360360) \|x
+--R     + 
+--R       30030x
+--R  /
+--R     30030
+--R                                         Type: Union(Expression(Integer),...)
+--E 806
+
+--S 807 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          12+-+10      12+-+9      12+-+8      12+-+6      12+-+4      12+-+3
+--R       252 \|x    - 280 \|x   + 315 \|x   + 420 \|x   + 630 \|x   - 840 \|x
+--R     + 
+--R                    12+-+2      6+-+5                  6+-+      4+-+3      4+-+
+--R       (180x + 1260) \|x   - 252\|x   + (- 180x - 1260)\|x  + 280\|x   + 840\|x
+--R     + 
+--R            3+-+2      3+-+       +-+
+--R       - 315\|x   - 630\|x  - 420\|x
+--R  /
+--R     210
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 808
+
+)clear all
+
+--S 809 of 1070
+t0:=sqrt(x)/((-1)/x^(1/3)+sqrt(x))
+--R 
+--R
+--R           +-+3+-+
+--R          \|x \|x
+--R   (1)  ------------
+--R         +-+3+-+
+--R        \|x \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 809
+
+--S 810 of 1070
+r0:=6*x^(1/6)+x+6/5*log(1-x^(1/6))-3/10*log(2+2*x^(1/3)+x^(1/6)*_
+   (1-sqrt(5)))*(1-sqrt(5))-3/10*log(2+2*x^(1/3)+x^(1/6)*(1+sqrt(5)))*_
+   (1+sqrt(5))-3/5*atan(1/2*(1+4*x^(1/6)+sqrt(5))*sqrt(1/10*_
+   (5+sqrt(5))))*sqrt(2*(5-sqrt(5)))-3/5*atan((1+4*x^(1/6)-sqrt(5))/_
+   sqrt(2*(5+sqrt(5))))*sqrt(2*(5+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R            +-+           +-+     6+-+    3+-+                6+-+
+--R       (- 3\|5  - 3)log((\|5  + 1)\|x  + 2\|x  + 2) + 12log(- \|x  + 1)
+--R     + 
+--R          +-+             +-+     6+-+    3+-+
+--R       (3\|5  - 3)log((- \|5  + 1)\|x  + 2\|x  + 2)
+--R     + 
+--R                                                 +--------+
+--R           +------------+       6+-+    +-+      | +-+
+--R           |    +-+           (4\|x  + \|5  + 1)\|\|5  + 5
+--R       - 6\|- 2\|5  + 10 atan(-----------------------------)
+--R                                            +--+
+--R                                          2\|10
+--R     + 
+--R           +----------+      6+-+    +-+
+--R           |  +-+           4\|x  - \|5  + 1      6+-+
+--R       - 6\|2\|5  + 10 atan(----------------) + 60\|x  + 10x
+--R                               +----------+
+--R                               |  +-+
+--R                              \|2\|5  + 10
+--R  /
+--R     10
+--R                                                    Type: Expression(Integer)
+--E 810
+
+--S 811 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +-------------------------------------------------------------+
+--R              |         2                                  2
+--R           - \|- 75%%BU1  + (- 50%%BU0 - 60)%%BU1 - 75%%BU0  - 60%%BU0 - 108
+--R         + 
+--R           - 5%%BU1 - 5%%BU0 - 6
+--R      *
+--R         log
+--R               +-------------------------------------------------------------+
+--R               |         2                                  2
+--R              \|- 75%%BU1  + (- 50%%BU0 - 60)%%BU1 - 75%%BU0  - 60%%BU0 - 108
+--R            + 
+--R                                  6+-+
+--R              5%%BU1 + 5%%BU0 + 12\|x  + 6
+--R     + 
+--R            +-------------------------------------------------------------+
+--R            |         2                                  2
+--R           \|- 75%%BU1  + (- 50%%BU0 - 60)%%BU1 - 75%%BU0  - 60%%BU0 - 108
+--R         + 
+--R           - 5%%BU1 - 5%%BU0 - 6
+--R      *
+--R         log
+--R                 +-------------------------------------------------------------+
+--R                 |         2                                  2
+--R              - \|- 75%%BU1  + (- 50%%BU0 - 60)%%BU1 - 75%%BU0  - 60%%BU0 - 108
+--R            + 
+--R                                  6+-+
+--R              5%%BU1 + 5%%BU0 + 12\|x  + 6
+--R     + 
+--R                               6+-+          6+-+
+--R       10%%BU1 log(- 5%%BU1 + 6\|x ) + 12log(\|x  - 1)
+--R     + 
+--R                               6+-+      6+-+
+--R       10%%BU0 log(- 5%%BU0 + 6\|x ) + 60\|x  + 10x
+--R  /
+--R     10
+--R                                         Type: Union(Expression(Integer),...)
+--E 811
+
+--S 812 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-------------------------------------------------------------+
+--R              |         2                                  2
+--R           - \|- 75%%BU1  + (- 50%%BU0 - 60)%%BU1 - 75%%BU0  - 60%%BU0 - 108
+--R         + 
+--R           - 5%%BU1 - 5%%BU0 - 6
+--R      *
+--R         log
+--R               +-------------------------------------------------------------+
+--R               |         2                                  2
+--R              \|- 75%%BU1  + (- 50%%BU0 - 60)%%BU1 - 75%%BU0  - 60%%BU0 - 108
+--R            + 
+--R                                  6+-+
+--R              5%%BU1 + 5%%BU0 + 12\|x  + 6
+--R     + 
+--R            +-------------------------------------------------------------+
+--R            |         2                                  2
+--R           \|- 75%%BU1  + (- 50%%BU0 - 60)%%BU1 - 75%%BU0  - 60%%BU0 - 108
+--R         + 
+--R           - 5%%BU1 - 5%%BU0 - 6
+--R      *
+--R         log
+--R                 +-------------------------------------------------------------+
+--R                 |         2                                  2
+--R              - \|- 75%%BU1  + (- 50%%BU0 - 60)%%BU1 - 75%%BU0  - 60%%BU0 - 108
+--R            + 
+--R                                  6+-+
+--R              5%%BU1 + 5%%BU0 + 12\|x  + 6
+--R     + 
+--R                               6+-+
+--R       10%%BU1 log(- 5%%BU1 + 6\|x )
+--R     + 
+--R          +-+           +-+     6+-+    3+-+              6+-+
+--R       (3\|5  + 3)log((\|5  + 1)\|x  + 2\|x  + 2) + 12log(\|x  - 1)
+--R     + 
+--R                 6+-+             +-+             +-+     6+-+    3+-+
+--R       - 12log(- \|x  + 1) + (- 3\|5  + 3)log((- \|5  + 1)\|x  + 2\|x  + 2)
+--R     + 
+--R                               6+-+
+--R       10%%BU0 log(- 5%%BU0 + 6\|x )
+--R     + 
+--R                                               +--------+
+--R         +------------+       6+-+    +-+      | +-+
+--R         |    +-+           (4\|x  + \|5  + 1)\|\|5  + 5
+--R       6\|- 2\|5  + 10 atan(-----------------------------)
+--R                                          +--+
+--R                                        2\|10
+--R     + 
+--R         +----------+      6+-+    +-+
+--R         |  +-+           4\|x  - \|5  + 1
+--R       6\|2\|5  + 10 atan(----------------)
+--R                             +----------+
+--R                             |  +-+
+--R                            \|2\|5  + 10
+--R  /
+--R     10
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                        +------------+
+--R               +-+     2           +--+ |    +-+      6+-+5
+--R           (2x\|5  + 2x  - 2x + 2)\|10 \|- 2\|5  + 10 \|x
+--R         + 
+--R                                     +------------+
+--R               2 +-+    2       +--+ |    +-+      6+-+4
+--R           (- x \|5  + x  - 4x)\|10 \|- 2\|5  + 10 \|x
+--R         + 
+--R                    +------------+                +------------+
+--R             2 +--+ |    +-+      6+-+3      +--+ |    +-+      6+-+
+--R           2x \|10 \|- 2\|5  + 10 \|x   + 2x\|10 \|- 2\|5  + 10 \|x
+--R         + 
+--R                                    +------------+
+--R                +-+     2      +--+ |    +-+
+--R           (- x\|5  - 4x  + x)\|10 \|- 2\|5  + 10
+--R      *
+--R          +--------+
+--R          | +-+
+--R         \|\|5  + 5
+--R     + 
+--R              +-+      2            6+-+5       2 +-+      2       6+-+4
+--R       (- 40x\|5  - 40x  + 40x - 40)\|x   + (20x \|5  - 20x  + 80x)\|x
+--R     + 
+--R            2 6+-+3     6+-+       +-+      2
+--R       - 40x  \|x  - 40x\|x  + 20x\|5  + 80x  - 20x
+--R  /
+--R            3      2        +-+       3       2        6+-+5
+--R       ((40x  - 80x  + 40x)\|5  + 200x  - 400x  + 200x)\|x
+--R     + 
+--R            3      2        +-+       3       2        6+-+4
+--R       ((40x  - 80x  + 40x)\|5  + 200x  - 400x  + 200x)\|x
+--R     + 
+--R            3      2  +-+       3       2 6+-+3
+--R       ((40x  - 80x )\|5  + 200x  - 400x )\|x
+--R     + 
+--R            3      2  +-+       3       2 6+-+2
+--R       ((40x  + 40x )\|5  + 200x  + 200x )\|x
+--R     + 
+--R              3      2  +-+       3       2 6+-+       4      3      2  +-+
+--R       ((- 80x  + 40x )\|5  - 400x  + 200x )\|x  + (40x  - 80x  + 40x )\|5
+--R     + 
+--R           4       3       2
+--R       200x  - 400x  + 200x
+--R                                                    Type: Expression(Integer)
+--E 813
+
+)clear all
+
+--S 814 of 1070
+t0:=(-x+x^3)/(6+2*x)
+--R 
+--R
+--R         3
+--R        x  - x
+--R   (1)  ------
+--R        2x + 6
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 814
+
+--S 815 of 1070
+r0:=4*x-3/4*x^2+1/6*x^3-12*log(3+x)
+--R 
+--R
+--R                            3     2
+--R        - 144log(x + 3) + 2x  - 9x  + 48x
+--R   (2)  ---------------------------------
+--R                        12
+--R                                                    Type: Expression(Integer)
+--E 815
+
+--S 816 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            3     2
+--R        - 144log(x + 3) + 2x  - 9x  + 48x
+--R   (3)  ---------------------------------
+--R                        12
+--R                                         Type: Union(Expression(Integer),...)
+--E 816
+
+--S 817 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 818
+
+)clear all
+
+--S 819 of 1070
+t0:=(x+x^3)/(-1+x)
+--R 
+--R
+--R         3
+--R        x  + x
+--R   (1)  ------
+--R         x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 819
+
+--S 820 of 1070
+r0:=2*x+1/2*x^2+1/3*x^3+2*log(1-x)
+--R 
+--R
+--R                           3     2
+--R        12log(- x + 1) + 2x  + 3x  + 12x
+--R   (2)  --------------------------------
+--R                        6
+--R                                                    Type: Expression(Integer)
+--E 820
+
+--S 821 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         3     2
+--R        12log(x - 1) + 2x  + 3x  + 12x
+--R   (3)  ------------------------------
+--R                       6
+--R                                         Type: Union(Expression(Integer),...)
+--E 821
+
+--S 822 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  2log(x - 1) - 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 822
+
+--S 823 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 823
+
+)clear all
+
+--S 824 of 1070
+t0:=(-x+4*x^3)/(5+x^2)^2
+--R 
+--R
+--R              3
+--R            4x  - x
+--R   (1)  --------------
+--R         4      2
+--R        x  + 10x  + 25
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 824
+
+--S 825 of 1070
+r0:=21/2/(5+x^2)+2*log(5+x^2)
+--R 
+--R
+--R           2           2
+--R        (4x  + 20)log(x  + 5) + 21
+--R   (2)  --------------------------
+--R                   2
+--R                 2x  + 10
+--R                                                    Type: Expression(Integer)
+--E 825
+
+--S 826 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2           2
+--R        (4x  + 20)log(x  + 5) + 21
+--R   (3)  --------------------------
+--R                   2
+--R                 2x  + 10
+--R                                         Type: Union(Expression(Integer),...)
+--E 826
+
+--S 827 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 827
+
+--S 828 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 828
+
+)clear all
+
+--S 829 of 1070
+t0:=(-x^2+2*x^4)/(1+2*x^2)
+--R 
+--R
+--R          4    2
+--R        2x  - x
+--R   (1)  --------
+--R           2
+--R         2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 829
+
+--S 830 of 1070
+r0:=-x+1/3*x^3+atan(x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R                +-+      3       +-+
+--R        3atan(x\|2 ) + (x  - 3x)\|2
+--R   (2)  ----------------------------
+--R                      +-+
+--R                    3\|2
+--R                                                    Type: Expression(Integer)
+--E 830
+
+--S 831 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +-+      3       +-+
+--R        3atan(x\|2 ) + (x  - 3x)\|2
+--R   (3)  ----------------------------
+--R                      +-+
+--R                    3\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 831
+
+--S 832 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 833
+
+)clear all
+
+--S 834 of 1070
+t0:=(x^3+x^4)/(1+x^2)
+--R 
+--R
+--R         4    3
+--R        x  + x
+--R   (1)  -------
+--R          2
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 834
+
+--S 835 of 1070
+r0:=-x+1/2*x^2+1/3*x^3+atan(x)-1/2*log(1+x^2)
+--R 
+--R
+--R                2                     3     2
+--R        - 3log(x  + 1) + 6atan(x) + 2x  + 3x  - 6x
+--R   (2)  ------------------------------------------
+--R                             6
+--R                                                    Type: Expression(Integer)
+--E 835
+
+--S 836 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2                     3     2
+--R        - 3log(x  + 1) + 6atan(x) + 2x  + 3x  - 6x
+--R   (3)  ------------------------------------------
+--R                             6
+--R                                         Type: Union(Expression(Integer),...)
+--E 836
+
+--S 837 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 838
+
+)clear all
+
+--S 839 of 1070
+t0:=(-2+4*x)/(-x+x^3)
+--R 
+--R
+--R        4x - 2
+--R   (1)  ------
+--R         3
+--R        x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 839
+
+--S 840 of 1070
+r0:=log(1-x)+2*log(x)-3*log(1+x)
+--R 
+--R
+--R   (2)  - 3log(x + 1) + 2log(x) + log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 840
+
+--S 841 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  - 3log(x + 1) + 2log(x) + log(x - 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 841
+
+--S 842 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  log(x - 1) - log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 843
+
+)clear all
+
+--S 844 of 1070
+t0:=(4+x)/(4*x+x^3)
+--R 
+--R
+--R         x + 4
+--R   (1)  -------
+--R         3
+--R        x  + 4x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 844
+
+--S 845 of 1070
+r0:=1/2*atan(1/2*x)+log(x)-1/2*log(4+x^2)
+--R 
+--R
+--R               2                       x
+--R        - log(x  + 4) + 2log(x) + atan(-)
+--R                                       2
+--R   (2)  ---------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 845
+
+--S 846 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2                       x
+--R        - log(x  + 4) + 2log(x) + atan(-)
+--R                                       2
+--R   (3)  ---------------------------------
+--R                        2
+--R                                         Type: Union(Expression(Integer),...)
+--E 846
+
+--S 847 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 848
+
+)clear all
+
+--S 849 of 1070
+t0:=(-x+2*x^3)/(1-x^2+x^4)
+--R 
+--R
+--R            3
+--R          2x  - x
+--R   (1)  -----------
+--R         4    2
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 849
+
+--S 850 of 1070
+r0:=1/2*log(1-x^2+x^4)
+--R 
+--R
+--R             4    2
+--R        log(x  - x  + 1)
+--R   (2)  ----------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 850
+
+--S 851 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             4    2
+--R        log(x  - x  + 1)
+--R   (3)  ----------------
+--R                2
+--R                                         Type: Union(Expression(Integer),...)
+--E 851
+
+--S 852 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 852
+
+--S 853 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 853
+
+)clear all
+
+--S 854 of 1070
+t0:=(-3+x)/(2*x+3*x^2+x^3)
+--R 
+--R
+--R            x - 3
+--R   (1)  -------------
+--R         3     2
+--R        x  + 3x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 854
+
+--S 855 of 1070
+r0:=-3/2*log(x)+4*log(1+x)-5/2*log(2+x)
+--R 
+--R
+--R        - 5log(x + 2) + 8log(x + 1) - 3log(x)
+--R   (2)  -------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 855
+
+--S 856 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 5log(x + 2) + 8log(x + 1) - 3log(x)
+--R   (3)  -------------------------------------
+--R                          2
+--R                                         Type: Union(Expression(Integer),...)
+--E 856
+
+--S 857 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 858
+
+)clear all
+
+--S 859 of 1070
+t0:=(2+4*x)/(x^2+2*x^3+x^4)
+--R 
+--R
+--R            4x + 2
+--R   (1)  -------------
+--R         4     3    2
+--R        x  + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 859
+
+--S 860 of 1070
+r0:=(-2)/(x*(1+x))
+--R 
+--R
+--R             2
+--R   (2)  - ------
+--R           2
+--R          x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 860
+
+--S 861 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R   (3)  - ------
+--R           2
+--R          x  + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 861
+
+--S 862 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 862
+
+--S 863 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 863
+
+)clear all
+
+--S 864 of 1070
+t0:=(1+x)/(-6*x+x^2+x^3)
+--R 
+--R
+--R            x + 1
+--R   (1)  ------------
+--R         3    2
+--R        x  + x  - 6x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 864
+
+--S 865 of 1070
+r0:=3/10*log(2-x)-1/6*log(x)-2/15*log(3+x)
+--R 
+--R
+--R        - 4log(x + 3) - 5log(x) + 9log(- x + 2)
+--R   (2)  ---------------------------------------
+--R                           30
+--R                                                    Type: Expression(Integer)
+--E 865
+
+--S 866 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 4log(x + 3) - 5log(x) + 9log(x - 2)
+--R   (3)  -------------------------------------
+--R                          30
+--R                                         Type: Union(Expression(Integer),...)
+--E 866
+
+--S 867 of 1070
+m0:=a0-r0
+--R 
+--R
+--R        3log(x - 2) - 3log(- x + 2)
+--R   (4)  ---------------------------
+--R                     10
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 868
+
+)clear all
+
+--S 869 of 1070
+t0:=(4*x^2+x^3)/(x+x^3)
+--R 
+--R
+--R         2
+--R        x  + 4x
+--R   (1)  -------
+--R          2
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 869
+
+--S 870 of 1070
+r0:=x-atan(x)+2*log(1+x^2)
+--R 
+--R
+--R              2
+--R   (2)  2log(x  + 1) - atan(x) + x
+--R                                                    Type: Expression(Integer)
+--E 870
+
+--S 871 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R   (3)  2log(x  + 1) - atan(x) + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 871
+
+--S 872 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 873
+
+)clear all
+
+--S 874 of 1070
+t0:=(x+2*x^3)/(x^2+x^4)^3
+--R 
+--R
+--R                 2
+--R               2x  + 1
+--R   (1)  --------------------
+--R         11     9     7    5
+--R        x   + 3x  + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 874
+
+--S 875 of 1070
+r0:=(-1/4)/(x^4*(1+x^2)^2)
+--R 
+--R
+--R                1
+--R                -
+--R                4
+--R   (2)  - -------------
+--R           8     6    4
+--R          x  + 2x  + x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 875
+
+--S 876 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 1
+--R   (3)  - ---------------
+--R            8     6     4
+--R          4x  + 8x  + 4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 876
+
+--S 877 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--S 878 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 878
+
+)clear all
+
+--S 879 of 1070
+t0:=(a*x^2+b*x^3)/(c*x^2+d*x^3)
+--R 
+--R
+--R        b x + a
+--R   (1)  -------
+--R        d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 879
+
+--S 880 of 1070
+r0:=b*x/d-(b*c-a*d)*log(c+d*x)/d^2
+--R 
+--R
+--R        (a d - b c)log(d x + c) + b d x
+--R   (2)  -------------------------------
+--R                        2
+--R                       d
+--R                                                    Type: Expression(Integer)
+--E 880
+
+--S 881 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (a d - b c)log(d x + c) + b d x
+--R   (3)  -------------------------------
+--R                        2
+--R                       d
+--R                                         Type: Union(Expression(Integer),...)
+--E 881
+
+--S 882 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 883
+
+)clear all
+
+--S 884 of 1070
+t0:=(x+x^2)/(-2*x-x^2+x^3)
+--R 
+--R
+--R          1
+--R   (1)  -----
+--R        x - 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 884
+
+--S 885 of 1070
+r0:=log(2-x)
+--R 
+--R
+--R   (2)  log(- x + 2)
+--R                                                    Type: Expression(Integer)
+--E 885
+
+--S 886 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  log(x - 2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 886
+
+--S 887 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  log(x - 2) - log(- x + 2)
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 888
+
+)clear all
+
+--S 889 of 1070
+t0:=x^3/(c+(a+b*x)^2)
+--R 
+--R
+--R                   3
+--R                  x
+--R   (1)  ----------------------
+--R         2 2                 2
+--R        b x  + 2a b x + c + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 889
+
+--S 890 of 1070
+r0:=-3*a*x/b^3+1/2*(a+b*x)^2/b^4+1/2*(3*a^2-c)*log(c+(a+b*x)^2)/b^4-_
+   a*(a^2-3*c)*atan((a+b*x)/sqrt(c))/(b^4*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                 3      b x + a
+--R       (6a c - 2a )atan(-------)
+--R                           +-+
+--R                          \|c
+--R     + 
+--R                 2      2 2                 2     2 2             2  +-+
+--R       ((- c + 3a )log(b x  + 2a b x + c + a ) + b x  - 4a b x + a )\|c
+--R  /
+--R       4 +-+
+--R     2b \|c
+--R                                                    Type: Expression(Integer)
+--E 890
+
+--S 891 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          2 2                 2  +---+
+--R                  3     (b x  + 2a b x - c + a )\|- c  + 2b c x + 2a c
+--R         (3a c - a )log(----------------------------------------------)
+--R                                     2 2                 2
+--R                                    b x  + 2a b x + c + a
+--R       + 
+--R                   2      2 2                 2     2 2           +---+
+--R         ((- c + 3a )log(b x  + 2a b x + c + a ) + b x  - 4a b x)\|- c
+--R    /
+--R         4 +---+
+--R       2b \|- c
+--R     ,
+--R
+--R                                    +-+
+--R                   3      (b x + a)\|c
+--R         (6a c - 2a )atan(-------------)
+--R                                c
+--R       + 
+--R                   2      2 2                 2     2 2           +-+
+--R         ((- c + 3a )log(b x  + 2a b x + c + a ) + b x  - 4a b x)\|c
+--R    /
+--R         4 +-+
+--R       2b \|c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 891
+
+--S 892 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            2 2                 2  +---+
+--R                3  +-+    (b x  + 2a b x - c + a )\|- c  + 2b c x + 2a c
+--R       (3a c - a )\|c log(----------------------------------------------)
+--R                                       2 2                 2
+--R                                      b x  + 2a b x + c + a
+--R     + 
+--R                   3  +---+     b x + a     2 +---+ +-+
+--R       (- 6a c + 2a )\|- c atan(-------) - a \|- c \|c
+--R                                   +-+
+--R                                  \|c
+--R  /
+--R       4 +---+ +-+
+--R     2b \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 892
+
+--S 893 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 893
+
+--S 894 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                                   +-+
+--R                  3      (b x + a)\|c                 3      b x + a     2 +-+
+--R        (6a c - 2a )atan(-------------) + (- 6a c + 2a )atan(-------) - a \|c
+--R                               c                                +-+
+--R                                                               \|c
+--R   (6)  ----------------------------------------------------------------------
+--R                                          4 +-+
+--R                                        2b \|c
+--R                                                    Type: Expression(Integer)
+--E 894
+
+--S 895 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 895
+
+)clear all
+
+--S 896 of 1070
+t0:=x^2/(c+(a+b*x)^2)
+--R 
+--R
+--R                   2
+--R                  x
+--R   (1)  ----------------------
+--R         2 2                 2
+--R        b x  + 2a b x + c + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 896
+
+--S 897 of 1070
+r0:=x/b^2-a*log(c+(a+b*x)^2)/b^3+(a^2-c)*atan((a+b*x)/sqrt(c))/(b^3*sqrt(c))
+--R 
+--R
+--R                2      b x + a              2 2                 2         +-+
+--R        (- c + a )atan(-------) + (- a log(b x  + 2a b x + c + a ) + b x)\|c
+--R                          +-+
+--R                         \|c
+--R   (2)  ---------------------------------------------------------------------
+--R                                         3 +-+
+--R                                        b \|c
+--R                                                    Type: Expression(Integer)
+--E 897
+
+--S 898 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                       2 2                 2  +---+
+--R               2     (b x  + 2a b x - c + a )\|- c  - 2b c x - 2a c
+--R         (c - a )log(----------------------------------------------)
+--R                                  2 2                 2
+--R                                 b x  + 2a b x + c + a
+--R       + 
+--R                    2 2                 2          +---+
+--R         (- 2a log(b x  + 2a b x + c + a ) + 2b x)\|- c
+--R    /
+--R         3 +---+
+--R       2b \|- c
+--R     ,
+--R                             +-+
+--R            2      (b x + a)\|c               2 2                 2         +-+
+--R    (- c + a )atan(-------------) + (- a log(b x  + 2a b x + c + a ) + b x)\|c
+--R                         c
+--R    ---------------------------------------------------------------------------]
+--R                                        3 +-+
+--R                                       b \|c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 898
+
+--S 899 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         2 2                 2  +---+
+--R             2  +-+    (b x  + 2a b x - c + a )\|- c  - 2b c x - 2a c
+--R       (c - a )\|c log(----------------------------------------------)
+--R                                    2 2                 2
+--R                                   b x  + 2a b x + c + a
+--R     + 
+--R               2  +---+     b x + a
+--R       (2c - 2a )\|- c atan(-------)
+--R                               +-+
+--R                              \|c
+--R  /
+--R       3 +---+ +-+
+--R     2b \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 899
+
+--S 900 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 900
+
+--S 901 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                                 +-+
+--R                2      (b x + a)\|c           2      b x + a
+--R        (- c + a )atan(-------------) + (c - a )atan(-------)
+--R                             c                          +-+
+--R                                                       \|c
+--R   (6)  -----------------------------------------------------
+--R                                 3 +-+
+--R                                b \|c
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 902
+
+)clear all
+
+--S 903 of 1070
+t0:=x/(c+(a+b*x)^2)
+--R 
+--R
+--R                   x
+--R   (1)  ----------------------
+--R         2 2                 2
+--R        b x  + 2a b x + c + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 903
+
+--S 904 of 1070
+r0:=1/2*log(c+(a+b*x)^2)/b^2-a*atan((a+b*x)/sqrt(c))/(b^2*sqrt(c))
+--R 
+--R
+--R                  b x + a         2 2                 2  +-+
+--R        - 2a atan(-------) + log(b x  + 2a b x + c + a )\|c
+--R                     +-+
+--R                    \|c
+--R   (2)  ----------------------------------------------------
+--R                                 2 +-+
+--R                               2b \|c
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2 2                 2  +---+
+--R               (b x  + 2a b x - c + a )\|- c  - 2b c x - 2a c
+--R         a log(----------------------------------------------)
+--R                            2 2                 2
+--R                           b x  + 2a b x + c + a
+--R       + 
+--R              2 2                 2  +---+
+--R         log(b x  + 2a b x + c + a )\|- c
+--R    /
+--R         2 +---+
+--R       2b \|- c
+--R     ,
+--R                        +-+
+--R              (b x + a)\|c          2 2                 2  +-+
+--R    - 2a atan(-------------) + log(b x  + 2a b x + c + a )\|c
+--R                    c
+--R    ----------------------------------------------------------]
+--R                                2 +-+
+--R                              2b \|c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 905
+
+--S 906 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2 2                 2  +---+
+--R         +-+    (b x  + 2a b x - c + a )\|- c  - 2b c x - 2a c
+--R       a\|c log(----------------------------------------------)
+--R                             2 2                 2
+--R                            b x  + 2a b x + c + a
+--R     + 
+--R          +---+     b x + a
+--R       2a\|- c atan(-------)
+--R                       +-+
+--R                      \|c
+--R  /
+--R       2 +---+ +-+
+--R     2b \|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 906
+
+--S 907 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 907
+
+--S 908 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                           +-+
+--R                 (b x + a)\|c            b x + a
+--R        - a atan(-------------) + a atan(-------)
+--R                       c                    +-+
+--R                                           \|c
+--R   (6)  -----------------------------------------
+--R                           2 +-+
+--R                          b \|c
+--R                                                    Type: Expression(Integer)
+--E 908
+
+--S 909 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 909
+
+)clear all
+
+--S 910 of 1070
+t0:=1/(c+(a+b*x)^2)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         2 2                 2
+--R        b x  + 2a b x + c + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 910
+
+--S 911 of 1070
+r0:=atan((a+b*x)/sqrt(c))/(b*sqrt(c))
+--R 
+--R
+--R             b x + a
+--R        atan(-------)
+--R                +-+
+--R               \|c
+--R   (2)  -------------
+--R              +-+
+--R            b\|c
+--R                                                    Type: Expression(Integer)
+--E 911
+
+--S 912 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2                 2  +---+
+--R        (b x  + 2a b x - c + a )\|- c  + 2b c x + 2a c                 +-+
+--R    log(----------------------------------------------)      (b x + a)\|c
+--R                     2 2                 2              atan(-------------)
+--R                    b x  + 2a b x + c + a                          c
+--R   [---------------------------------------------------,-------------------]
+--R                             +---+                               +-+
+--R                          2b\|- c                              b\|c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 912
+
+--S 913 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                 2 2                 2  +---+
+--R        +-+    (b x  + 2a b x - c + a )\|- c  + 2b c x + 2a c
+--R       \|c log(----------------------------------------------)
+--R                            2 2                 2
+--R                           b x  + 2a b x + c + a
+--R     + 
+--R           +---+     b x + a
+--R       - 2\|- c atan(-------)
+--R                        +-+
+--R                       \|c
+--R  /
+--R        +---+ +-+
+--R     2b\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 913
+
+--S 914 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 914
+
+--S 915 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                       +-+
+--R             (b x + a)\|c          b x + a
+--R        atan(-------------) - atan(-------)
+--R                   c                  +-+
+--R                                     \|c
+--R   (6)  -----------------------------------
+--R                         +-+
+--R                       b\|c
+--R                                                    Type: Expression(Integer)
+--E 915
+
+--S 916 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 916
+
+)clear all
+
+--S 917 of 1070
+t0:=1/(x*(c+(a+b*x)^2))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R         2 3         2         2
+--R        b x  + 2a b x  + (c + a )x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 917
+
+--S 918 of 1070
+r0:=log(x)/(a^2+c)-1/2*log(c+(a+b*x)^2)/(a^2+c)-a*atan((a+b*x)/sqrt(c))/_
+   ((a^2+c)*sqrt(c))
+--R 
+--R
+--R                  b x + a            2 2                 2             +-+
+--R        - 2a atan(-------) + (- log(b x  + 2a b x + c + a ) + 2log(x))\|c
+--R                     +-+
+--R                    \|c
+--R   (2)  ------------------------------------------------------------------
+--R                                          2  +-+
+--R                                  (2c + 2a )\|c
+--R                                                    Type: Expression(Integer)
+--E 918
+
+--S 919 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2 2                 2  +---+
+--R               (b x  + 2a b x - c + a )\|- c  - 2b c x - 2a c
+--R         a log(----------------------------------------------)
+--R                            2 2                 2
+--R                           b x  + 2a b x + c + a
+--R       + 
+--R                 2 2                 2             +---+
+--R         (- log(b x  + 2a b x + c + a ) + 2log(x))\|- c
+--R    /
+--R               2  +---+
+--R       (2c + 2a )\|- c
+--R     ,
+--R                        +-+
+--R              (b x + a)\|c             2 2                 2             +-+
+--R    - 2a atan(-------------) + (- log(b x  + 2a b x + c + a ) + 2log(x))\|c
+--R                    c
+--R    ------------------------------------------------------------------------]
+--R                                         2  +-+
+--R                                 (2c + 2a )\|c
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 919
+
+--S 920 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  2 2                 2  +---+
+--R         +-+    (b x  + 2a b x - c + a )\|- c  - 2b c x - 2a c
+--R       a\|c log(----------------------------------------------)
+--R                             2 2                 2
+--R                            b x  + 2a b x + c + a
+--R     + 
+--R          +---+     b x + a
+--R       2a\|- c atan(-------)
+--R                       +-+
+--R                      \|c
+--R  /
+--R             2  +---+ +-+
+--R     (2c + 2a )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 920
+
+--S 921 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 921
+
+--S 922 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                           +-+
+--R                 (b x + a)\|c            b x + a
+--R        - a atan(-------------) + a atan(-------)
+--R                       c                    +-+
+--R                                           \|c
+--R   (6)  -----------------------------------------
+--R                             2  +-+
+--R                       (c + a )\|c
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 923
+
+)clear all
+
+--S 924 of 1070
+t0:=1/(x^2*(c+(a+b*x)^2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R         2 4         3         2  2
+--R        b x  + 2a b x  + (c + a )x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 924
+
+--S 925 of 1070
+r0:=(-1)/((a^2+c)*x)-2*a*b*log(x)/(a^2+c)^2+a*b*log(c+(a+b*x)^2)/(a^2+c)^2+_
+   b*(a^2-c)*atan((a+b*x)/sqrt(c))/((a^2+c)^2*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                 2         b x + a
+--R       (- b c + a b)x atan(-------)
+--R                              +-+
+--R                             \|c
+--R     + 
+--R                   2 2                 2                         2  +-+
+--R       (a b x log(b x  + 2a b x + c + a ) - 2a b x log(x) - c - a )\|c
+--R  /
+--R       2     2     4   +-+
+--R     (c  + 2a c + a )x\|c
+--R                                                    Type: Expression(Integer)
+--E 925
+
+--S 926 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            2 2                 2  +---+
+--R                 2        (b x  + 2a b x - c + a )\|- c  - 2b c x - 2a c
+--R         (b c - a b)x log(----------------------------------------------)
+--R                                       2 2                 2
+--R                                      b x  + 2a b x + c + a
+--R       + 
+--R                      2 2                 2                           2  +---+
+--R         (2a b x log(b x  + 2a b x + c + a ) - 4a b x log(x) - 2c - 2a )\|- c
+--R    /
+--R          2     2      4   +---+
+--R       (2c  + 4a c + 2a )x\|- c
+--R     ,
+--R
+--R                                       +-+
+--R                   2         (b x + a)\|c
+--R         (- b c + a b)x atan(-------------)
+--R                                   c
+--R       + 
+--R                     2 2                 2                         2  +-+
+--R         (a b x log(b x  + 2a b x + c + a ) - 2a b x log(x) - c - a )\|c
+--R    /
+--R         2     2     4   +-+
+--R       (c  + 2a c + a )x\|c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 926
+
+--S 927 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            2 2                 2  +---+
+--R               2   +-+    (b x  + 2a b x - c + a )\|- c  - 2b c x - 2a c
+--R       (b c - a b)\|c log(----------------------------------------------)
+--R                                       2 2                 2
+--R                                      b x  + 2a b x + c + a
+--R     + 
+--R                 2   +---+     b x + a
+--R       (2b c - 2a b)\|- c atan(-------)
+--R                                  +-+
+--R                                 \|c
+--R  /
+--R        2     2      4  +---+ +-+
+--R     (2c  + 4a c + 2a )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 927
+
+--S 928 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 928
+
+--S 929 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                                    +-+
+--R                  2       (b x + a)\|c             2       b x + a
+--R        (- b c + a b)atan(-------------) + (b c - a b)atan(-------)
+--R                                c                             +-+
+--R                                                             \|c
+--R   (6)  -----------------------------------------------------------
+--R                              2     2     4  +-+
+--R                            (c  + 2a c + a )\|c
+--R                                                    Type: Expression(Integer)
+--E 929
+
+--S 930 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 930
+
+)clear all
+
+--S 931 of 1070
+t0:=1/(x^3*(c+(a+b*x)^2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R         2 5         4         2  3
+--R        b x  + 2a b x  + (c + a )x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 931
+
+--S 932 of 1070
+r0:=(-1/2)/((a^2+c)*x^2)+2*a*b/((a^2+c)^2*x)+b^2*(3*a^2-c)*log(x)/(a^2+c)^3-_
+   1/2*b^2*(3*a^2-c)*log(c+(a+b*x)^2)/(a^2+c)^3-a*b^2*(a^2-3*c)*_
+   atan((a+b*x)/sqrt(c))/((a^2+c)^3*sqrt(c))
+--R 
+--R
+--R   (2)
+--R            2      3 2  2     b x + a
+--R       (6a b c - 2a b )x atan(-------)
+--R                                 +-+
+--R                                \|c
+--R     + 
+--R             2      2 2  2     2 2                 2         2      2 2  2
+--R           (b c - 3a b )x log(b x  + 2a b x + c + a ) + (- 2b c + 6a b )x log(x)
+--R         + 
+--R                       3       2     2     4
+--R           (4a b c + 4a b)x - c  - 2a c - a
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R        3     2 2     4      6  2 +-+
+--R     (2c  + 6a c  + 6a c + 2a )x \|c
+--R                                                    Type: Expression(Integer)
+--E 932
+
+--S 933 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                2 2                 2  +---+
+--R              2     3 2  2    (b x  + 2a b x - c + a )\|- c  + 2b c x + 2a c
+--R         (3a b c - a b )x log(----------------------------------------------)
+--R                                           2 2                 2
+--R                                          b x  + 2a b x + c + a
+--R       + 
+--R               2      2 2  2     2 2                 2
+--R             (b c - 3a b )x log(b x  + 2a b x + c + a )
+--R           + 
+--R                  2      2 2  2                     3       2     2     4
+--R             (- 2b c + 6a b )x log(x) + (4a b c + 4a b)x - c  - 2a c - a
+--R        *
+--R            +---+
+--R           \|- c
+--R    /
+--R          3     2 2     4      6  2 +---+
+--R       (2c  + 6a c  + 6a c + 2a )x \|- c
+--R     ,
+--R
+--R                                          +-+
+--R              2      3 2  2     (b x + a)\|c
+--R         (6a b c - 2a b )x atan(-------------)
+--R                                      c
+--R       + 
+--R               2      2 2  2     2 2                 2
+--R             (b c - 3a b )x log(b x  + 2a b x + c + a )
+--R           + 
+--R                  2      2 2  2                     3       2     2     4
+--R             (- 2b c + 6a b )x log(x) + (4a b c + 4a b)x - c  - 2a c - a
+--R        *
+--R            +-+
+--R           \|c
+--R    /
+--R          3     2 2     4      6  2 +-+
+--R       (2c  + 6a c  + 6a c + 2a )x \|c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 933
+
+--S 934 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                2 2                 2  +---+
+--R            2     3 2  +-+    (b x  + 2a b x - c + a )\|- c  + 2b c x + 2a c
+--R       (3a b c - a b )\|c log(----------------------------------------------)
+--R                                           2 2                 2
+--R                                          b x  + 2a b x + c + a
+--R     + 
+--R              2      3 2  +---+     b x + a
+--R       (- 6a b c + 2a b )\|- c atan(-------)
+--R                                       +-+
+--R                                      \|c
+--R  /
+--R        3     2 2     4      6  +---+ +-+
+--R     (2c  + 6a c  + 6a c + 2a )\|- c \|c
+--R                                                    Type: Expression(Integer)
+--E 934
+
+--S 935 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 935
+
+--S 936 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                                      +-+
+--R             2     3 2      (b x + a)\|c            2     3 2      b x + a
+--R        (3a b c - a b )atan(-------------) + (- 3a b c + a b )atan(-------)
+--R                                  c                                   +-+
+--R                                                                     \|c
+--R   (6)  -------------------------------------------------------------------
+--R                              3     2 2     4     6  +-+
+--R                            (c  + 3a c  + 3a c + a )\|c
+--R                                                    Type: Expression(Integer)
+--E 936
+
+--S 937 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 937
+
+)clear all
+
+--S 938 of 1070
+t0:=1/(a+b*(c+d*x)^2)
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R           2 2                 2
+--R        b d x  + 2b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 938
+
+--S 939 of 1070
+r0:=atan((c+d*x)*sqrt(b)/sqrt(a))/(d*sqrt(a)*sqrt(b))
+--R 
+--R
+--R                       +-+
+--R             (d x + c)\|b
+--R        atan(-------------)
+--R                   +-+
+--R                  \|a
+--R   (2)  -------------------
+--R               +-+ +-+
+--R             d\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 939
+
+--S 940 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2 2                 2      +-----+
+--R        (b d x  + 2b c d x + b c  - a)\|- a b  + 2a b d x + 2a b c
+--R    log(----------------------------------------------------------)
+--R                          2 2                 2
+--R                       b d x  + 2b c d x + b c  + a
+--R   [---------------------------------------------------------------,
+--R                                  +-----+
+--R                               2d\|- a b
+--R                   +---+
+--R         (d x + c)\|a b
+--R    atan(---------------)
+--R                a
+--R    ---------------------]
+--R             +---+
+--R           d\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 940
+
+--S 941 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       2 2                 2      +-----+
+--R        +-+ +-+    (b d x  + 2b c d x + b c  - a)\|- a b  + 2a b d x + 2a b c
+--R       \|a \|b log(----------------------------------------------------------)
+--R                                     2 2                 2
+--R                                  b d x  + 2b c d x + b c  + a
+--R     + 
+--R                                 +-+
+--R           +-----+     (d x + c)\|b
+--R       - 2\|- a b atan(-------------)
+--R                             +-+
+--R                            \|a
+--R  /
+--R        +-----+ +-+ +-+
+--R     2d\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 941
+
+--S 942 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 942
+
+--S 943 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                               +---+                         +-+
+--R         +-+ +-+     (d x + c)\|a b      +---+     (d x + c)\|b
+--R        \|a \|b atan(---------------) - \|a b atan(-------------)
+--R                            a                            +-+
+--R                                                        \|a
+--R   (6)  ---------------------------------------------------------
+--R                               +-+ +-+ +---+
+--R                             d\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 943
+
+--S 944 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 944
+
+)clear all
+
+--S 945 of 1070
+t0:=1/(a+b*(c+d*x)^2)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 4 4     2   3 3      2 2         2 2      2 3                 2 4
+--R       b d x  + 4b c d x  + (6b c  + 2a b)d x  + (4b c  + 4a b c)d x + b c
+--R     + 
+--R             2    2
+--R       2a b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 945
+
+--S 946 of 1070
+r0:=1/2*(c+d*x)/(a*d*(a+b*(c+d*x)^2))+1/2*atan((c+d*x)*sqrt(b)/sqrt(a))/_
+   (a^(3/2)*d*sqrt(b))
+--R 
+--R
+--R                                                     +-+
+--R            2 2                 2          (d x + c)\|b               +-+ +-+
+--R        (b d x  + 2b c d x + b c  + a)atan(-------------) + (d x + c)\|a \|b
+--R                                                 +-+
+--R                                                \|a
+--R   (2)  ---------------------------------------------------------------------
+--R                        3 2           2           2     2    +-+ +-+
+--R                 (2a b d x  + 4a b c d x + (2a b c  + 2a )d)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 946
+
+--S 947 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               2 2                 2
+--R           (b d x  + 2b c d x + b c  + a)
+--R        *
+--R                   2 2                 2      +-----+
+--R               (b d x  + 2b c d x + b c  - a)\|- a b  + 2a b d x + 2a b c
+--R           log(----------------------------------------------------------)
+--R                                 2 2                 2
+--R                              b d x  + 2b c d x + b c  + a
+--R       + 
+--R                     +-----+
+--R         (2d x + 2c)\|- a b
+--R    /
+--R              3 2           2           2     2    +-----+
+--R       (4a b d x  + 8a b c d x + (4a b c  + 4a )d)\|- a b
+--R     ,
+--R                                                 +---+
+--R        2 2                 2          (d x + c)\|a b               +---+
+--R    (b d x  + 2b c d x + b c  + a)atan(---------------) + (d x + c)\|a b
+--R                                              a
+--R    ---------------------------------------------------------------------]
+--R                     3 2           2           2     2    +---+
+--R              (2a b d x  + 4a b c d x + (2a b c  + 2a )d)\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 947
+
+--S 948 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       2 2                 2      +-----+
+--R        +-+ +-+    (b d x  + 2b c d x + b c  - a)\|- a b  + 2a b d x + 2a b c
+--R       \|a \|b log(----------------------------------------------------------)
+--R                                     2 2                 2
+--R                                  b d x  + 2b c d x + b c  + a
+--R     + 
+--R                                 +-+
+--R           +-----+     (d x + c)\|b
+--R       - 2\|- a b atan(-------------)
+--R                             +-+
+--R                            \|a
+--R  /
+--R          +-----+ +-+ +-+
+--R     4a d\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 948
+
+--S 949 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 949
+
+--S 950 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                               +---+                         +-+
+--R         +-+ +-+     (d x + c)\|a b      +---+     (d x + c)\|b
+--R        \|a \|b atan(---------------) - \|a b atan(-------------)
+--R                            a                            +-+
+--R                                                        \|a
+--R   (6)  ---------------------------------------------------------
+--R                                 +-+ +-+ +---+
+--R                            2a d\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 950
+
+--S 951 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 951
+
+)clear all
+
+--S 952 of 1070
+t0:=1/(a+b*(c+d*x)^2)^3
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 6 6     3   5 5       3 2       2  4 4       3 3        2   3 3
+--R       b d x  + 6b c d x  + (15b c  + 3a b )d x  + (20b c  + 12a b c)d x
+--R     + 
+--R           3 4        2 2     2   2 2      3 5        2 3     2           3 6
+--R       (15b c  + 18a b c  + 3a b)d x  + (6b c  + 12a b c  + 6a b c)d x + b c
+--R     + 
+--R           2 4     2   2    3
+--R       3a b c  + 3a b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 952
+
+--S 953 of 1070
+r0:=1/4*(c+d*x)/(a*d*(a+b*(c+d*x)^2)^2)+3/8*(c+d*x)/(a^2*d*(a+b*(c+d*x)^2))+_
+   3/8*atan((c+d*x)*sqrt(b)/sqrt(a))/(a^(5/2)*d*sqrt(b))
+--R 
+--R
+--R   (2)
+--R             2 4 4      2   3 3       2 2         2 2       2 3
+--R           3b d x  + 12b c d x  + (18b c  + 6a b)d x  + (12b c  + 12a b c)d x
+--R         + 
+--R             2 4         2     2
+--R           3b c  + 6a b c  + 3a
+--R      *
+--R                        +-+
+--R              (d x + c)\|b
+--R         atan(-------------)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R            3 3         2 2        2                3         +-+ +-+
+--R       (3b d x  + 9b c d x  + (9b c  + 5a)d x + 3b c  + 5a c)\|a \|b
+--R  /
+--R           2 2 5 4      2 2   4 3       2 2 2      3   3 2
+--R         8a b d x  + 32a b c d x  + (48a b c  + 16a b)d x
+--R       + 
+--R             2 2 3      3     2       2 2 4      3   2     4
+--R         (32a b c  + 32a b c)d x + (8a b c  + 16a b c  + 8a )d
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 953
+
+--S 954 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               2 4 4      2   3 3       2 2         2 2       2 3
+--R             3b d x  + 12b c d x  + (18b c  + 6a b)d x  + (12b c  + 12a b c)d x
+--R           + 
+--R               2 4         2     2
+--R             3b c  + 6a b c  + 3a
+--R        *
+--R                   2 2                 2      +-----+
+--R               (b d x  + 2b c d x + b c  - a)\|- a b  + 2a b d x + 2a b c
+--R           log(----------------------------------------------------------)
+--R                                 2 2                 2
+--R                              b d x  + 2b c d x + b c  + a
+--R       + 
+--R              3 3          2 2         2                 3          +-----+
+--R         (6b d x  + 18b c d x  + (18b c  + 10a)d x + 6b c  + 10a c)\|- a b
+--R    /
+--R              2 2 5 4      2 2   4 3       2 2 2      3   3 2
+--R           16a b d x  + 64a b c d x  + (96a b c  + 32a b)d x
+--R         + 
+--R               2 2 3      3     2        2 2 4      3   2      4
+--R           (64a b c  + 64a b c)d x + (16a b c  + 32a b c  + 16a )d
+--R      *
+--R          +-----+
+--R         \|- a b
+--R     ,
+--R
+--R               2 4 4      2   3 3       2 2         2 2       2 3
+--R             3b d x  + 12b c d x  + (18b c  + 6a b)d x  + (12b c  + 12a b c)d x
+--R           + 
+--R               2 4         2     2
+--R             3b c  + 6a b c  + 3a
+--R        *
+--R                          +---+
+--R                (d x + c)\|a b
+--R           atan(---------------)
+--R                       a
+--R       + 
+--R              3 3         2 2        2                3         +---+
+--R         (3b d x  + 9b c d x  + (9b c  + 5a)d x + 3b c  + 5a c)\|a b
+--R    /
+--R             2 2 5 4      2 2   4 3       2 2 2      3   3 2
+--R           8a b d x  + 32a b c d x  + (48a b c  + 16a b)d x
+--R         + 
+--R               2 2 3      3     2       2 2 4      3   2     4
+--R           (32a b c  + 32a b c)d x + (8a b c  + 16a b c  + 8a )d
+--R      *
+--R          +---+
+--R         \|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 954
+
+--S 955 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        2 2                 2      +-----+
+--R         +-+ +-+    (b d x  + 2b c d x + b c  - a)\|- a b  + 2a b d x + 2a b c
+--R       3\|a \|b log(----------------------------------------------------------)
+--R                                      2 2                 2
+--R                                   b d x  + 2b c d x + b c  + a
+--R     + 
+--R                                 +-+
+--R           +-----+     (d x + c)\|b
+--R       - 6\|- a b atan(-------------)
+--R                             +-+
+--R                            \|a
+--R  /
+--R        2  +-----+ +-+ +-+
+--R     16a d\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 955
+
+--S 956 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                                +---+                          +-+
+--R          +-+ +-+     (d x + c)\|a b       +---+     (d x + c)\|b
+--R        3\|a \|b atan(---------------) - 3\|a b atan(-------------)
+--R                             a                             +-+
+--R                                                          \|a
+--R   (6)  -----------------------------------------------------------
+--R                               2  +-+ +-+ +---+
+--R                             8a d\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 957
+
+--S 958 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 958
+
+)clear all
+
+--S 959 of 1070
+t0:=1/(b*(c+d*x)^2+sqrt(-a))
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R         +---+      2 2                 2
+--R        \|- a  + b d x  + 2b c d x + b c
+--R                                                    Type: Expression(Integer)
+--E 959
+
+--S 960 of 1070
+r0:=atan((c+d*x)*sqrt(b)/(-a)^(1/4))/((-a)^(1/4)*d*sqrt(b))
+--R 
+--R
+--R                       +-+
+--R             (d x + c)\|b
+--R        atan(-------------)
+--R                 4+---+
+--R                 \|- a
+--R   (2)  -------------------
+--R             4+---+ +-+
+--R            d\|- a \|b
+--R                                                    Type: Expression(Integer)
+--E 960
+
+--S 961 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                               +---------+
+--R             2 2                 2  +---+      |    +---+
+--R        ((b d x  + 2b c d x + b c )\|- a  + a)\|- b\|- a   - 2a b d x - 2a b c
+--R    log(----------------------------------------------------------------------)
+--R                             2 2                 2  +---+
+--R                         (b d x  + 2b c d x + b c )\|- a  - a
+--R   [---------------------------------------------------------------------------,
+--R                                      +---------+
+--R                                      |    +---+
+--R                                   2d\|- b\|- a
+--R                   +-------+
+--R                   |  +---+
+--R         (d x + c)\|b\|- a
+--R    atan(-------------------)
+--R                 +---+
+--R                \|- a
+--R    -------------------------]
+--R             +-------+
+--R             |  +---+
+--R           d\|b\|- a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 961
+
+--S 962 of 1070
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         4+---+ +-+
+--R         \|- a \|b
+--R      *
+--R         log
+--R                                                       +---------+
+--R                     2 2                 2  +---+      |    +---+
+--R                ((b d x  + 2b c d x + b c )\|- a  + a)\|- b\|- a   - 2a b d x
+--R              + 
+--R                - 2a b c
+--R           /
+--R                  2 2                 2  +---+
+--R              (b d x  + 2b c d x + b c )\|- a  - a
+--R     + 
+--R                         +-+  +---------+
+--R               (d x + c)\|b   |    +---+
+--R       - 2atan(-------------)\|- b\|- a
+--R                   4+---+
+--R                   \|- a
+--R  /
+--R                  +---------+
+--R       4+---+ +-+ |    +---+
+--R     2d\|- a \|b \|- b\|- a
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 1070
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R               2 4 4     2   3 3     2 2 2 2     2 3       2 4      +---+4+---+2
+--R           (- b d x  - 4b c d x  - 6b c d x  - 4b c d x - b c  - a)\|- a \|- a
+--R         + 
+--R                2 4 4       2   3 3       2 2 2 2       2 3         2 4    2
+--R           - a b d x  - 4a b c d x  - 6a b c d x  - 4a b c d x - a b c  - a
+--R      *
+--R          +---------+
+--R          |    +---+
+--R         \|- b\|- a
+--R     + 
+--R                               +---+       2 3 3       2   2 2       2 2
+--R           (2a b d x + 2a b c)\|- a  + 2a b d x  + 6a b c d x  + 6a b c d x
+--R         + 
+--R               2 3
+--R           2a b c
+--R      *
+--R         4+---+2
+--R         \|- a
+--R     + 
+--R              2 3 3       2   2 2       2 2          2 3  +---+     2
+--R       (- 2a b d x  - 6a b c d x  - 6a b c d x - 2a b c )\|- a  + 2a b d x
+--R     + 
+--R         2
+--R       2a b c
+--R  /
+--R                    3 6 6     3   5 5      3 2 4 4      3 3 3 3
+--R                   b d x  + 6b c d x  + 15b c d x  + 20b c d x
+--R                 + 
+--R                       3 4        2 2      3 5                 3 6        2
+--R                   (15b c  + a b)d x  + (6b c  + 2a b c)d x + b c  + a b c
+--R              *
+--R                  +---+
+--R                 \|- a
+--R             + 
+--R                4 8 8     4   7 7      4 2 6 6      4 3 5 5
+--R               b d x  + 8b c d x  + 28b c d x  + 56b c d x
+--R             + 
+--R                   4 4      2  4 4       4 5       2   3 3
+--R               (70b c  + a b )d x  + (56b c  + 4a b c)d x
+--R             + 
+--R                   4 6       2 2  2 2      4 7       2 3        4 8      2 4
+--R               (28b c  + 6a b c )d x  + (8b c  + 4a b c )d x + b c  + a b c
+--R          *
+--R             4+---+2
+--R             \|- a
+--R         + 
+--R                   2 4 4       2   3 3       2 2 2 2       2 3         2 4    2
+--R             (- a b d x  - 4a b c d x  - 6a b c d x  - 4a b c d x - a b c  - a )
+--R          *
+--R              +---+
+--R             \|- a
+--R         + 
+--R                3 6 6       3   5 5        3 2 4 4        3 3 3 3
+--R           - a b d x  - 6a b c d x  - 15a b c d x  - 20a b c d x
+--R         + 
+--R                   3 4    2   2 2          3 5     2             3 6    2   2
+--R           (- 15a b c  - a b)d x  + (- 6a b c  - 2a b c)d x - a b c  - a b c
+--R      *
+--R          +---------+
+--R          |    +---+
+--R         \|- b\|- a
+--R     + 
+--R                 4 7 7      4   6 6      4 2 5 5      4 3 4 4
+--R               2b d x  + 14b c d x  + 42b c d x  + 70b c d x
+--R             + 
+--R                   4 4       2  3 3       4 5       2   2 2
+--R               (70b c  - 2a b )d x  + (42b c  - 6a b c)d x
+--R             + 
+--R                   4 6       2 2         4 7       2 3
+--R               (14b c  - 6a b c )d x + 2b c  - 2a b c
+--R          *
+--R              +---+
+--R             \|- a
+--R         + 
+--R                 3 5 5        3   4 4        3 2 3 3        3 3 2 2
+--R           - 4a b d x  - 20a b c d x  - 40a b c d x  - 40a b c d x
+--R         + 
+--R                  3 4          3 5
+--R           - 20a b c d x - 4a b c
+--R      *
+--R         4+---+2
+--R         \|- a
+--R     + 
+--R                 3 5 5        3   4 4        3 2 3 3        3 3 2 2
+--R           - 2a b d x  - 10a b c d x  - 20a b c d x  - 20a b c d x
+--R         + 
+--R                   3 4     2            3 5     2
+--R           (- 10a b c  + 2a b)d x - 2a b c  + 2a b c
+--R      *
+--R          +---+
+--R         \|- a
+--R     + 
+--R         2 2 3 3      2 2   2 2      2 2 2        2 2 3
+--R       4a b d x  + 12a b c d x  + 12a b c d x + 4a b c
+--R                                                    Type: Expression(Integer)
+--E 963
+
+--S 964 of 1070
+m0b:=a0.2-r0
+--R 
+--R
+--R                                 +-------+
+--R                                 |  +---+                    +-+  +-------+
+--R        4+---+ +-+     (d x + c)\|b\|- a           (d x + c)\|b   |  +---+
+--R        \|- a \|b atan(-------------------) - atan(-------------)\|b\|- a
+--R                               +---+                   4+---+
+--R                              \|- a                    \|- a
+--R   (6)  -------------------------------------------------------------------
+--R                                           +-------+
+--R                                4+---+ +-+ |  +---+
+--R                               d\|- a \|b \|b\|- a
+--R                                                    Type: Expression(Integer)
+--E 964
+
+--S 965 of 1070
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R        +---+4+---+2
+--R     - \|- a \|- a   - a
+--R  /
+--R               2 2                 2  +---+    2 4 4     2   3 3     2 2 2 2
+--R           (b d x  + 2b c d x + b c )\|- a  + b d x  + 4b c d x  + 6b c d x
+--R         + 
+--R             2 3       2 4
+--R           4b c d x + b c
+--R      *
+--R         4+---+2
+--R         \|- a
+--R     + 
+--R           +---+        2 2                     2
+--R       - a\|- a  - a b d x  - 2a b c d x - a b c
+--R                                                    Type: Expression(Integer)
+--E 965
+
+)clear all
+
+--S 966 of 1070
+t0:=1/(1+(c+d*x)^2)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         2 2             2
+--R        d x  + 2c d x + c  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 966
+
+--S 967 of 1070
+r0:=atan(c+d*x)/d
+--R 
+--R
+--R        atan(d x + c)
+--R   (2)  -------------
+--R              d
+--R                                                    Type: Expression(Integer)
+--E 967
+
+--S 968 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R        atan(d x + c)
+--R   (3)  -------------
+--R              d
+--R                                         Type: Union(Expression(Integer),...)
+--E 968
+
+--S 969 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 969
+
+--S 970 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 970
+
+)clear all
+
+--S 971 of 1070
+t0:=1/(1+(c+d*x)^2)^2
+--R 
+--R
+--R                                      1
+--R   (1)  -------------------------------------------------------------
+--R         4 4       3 3      2      2 2      3             4     2
+--R        d x  + 4c d x  + (6c  + 2)d x  + (4c  + 4c)d x + c  + 2c  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 971
+
+--S 972 of 1070
+r0:=1/2*(c+d*x)/(d*(1+(c+d*x)^2))+1/2*atan(c+d*x)/d
+--R 
+--R
+--R          2 2             2
+--R        (d x  + 2c d x + c  + 1)atan(d x + c) + d x + c
+--R   (2)  -----------------------------------------------
+--R                    3 2       2       2
+--R                  2d x  + 4c d x + (2c  + 2)d
+--R                                                    Type: Expression(Integer)
+--E 972
+
+--S 973 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2 2             2
+--R        (d x  + 2c d x + c  + 1)atan(d x + c) + d x + c
+--R   (3)  -----------------------------------------------
+--R                    3 2       2       2
+--R                  2d x  + 4c d x + (2c  + 2)d
+--R                                         Type: Union(Expression(Integer),...)
+--E 973
+
+--S 974 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 974
+
+--S 975 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 975
+
+)clear all
+
+--S 976 of 1070
+t0:=1/(1+(c+d*x)^2)^3
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        6 6       5 5       2      4 4       3        3 3
+--R       d x  + 6c d x  + (15c  + 3)d x  + (20c  + 12c)d x
+--R     + 
+--R           4      2      2 2      5      3             6     4     2
+--R       (15c  + 18c  + 3)d x  + (6c  + 12c  + 6c)d x + c  + 3c  + 3c  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 976
+
+--S 977 of 1070
+r0:=1/4*(c+d*x)/(d*(1+(c+d*x)^2)^2)+3/8*(c+d*x)/(d*(1+(c+d*x)^2))+_
+   3/8*atan(c+d*x)/d
+--R 
+--R
+--R   (2)
+--R            4 4        3 3       2      2 2       3               4     2
+--R         (3d x  + 12c d x  + (18c  + 6)d x  + (12c  + 12c)d x + 3c  + 6c  + 3)
+--R      *
+--R         atan(d x + c)
+--R     + 
+--R         3 3       2 2      2             3
+--R       3d x  + 9c d x  + (9c  + 5)d x + 3c  + 5c
+--R  /
+--R       5 4        4 3       2       3 2       3        2       4      2
+--R     8d x  + 32c d x  + (48c  + 16)d x  + (32c  + 32c)d x + (8c  + 16c  + 8)d
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4 4        3 3       2      2 2       3               4     2
+--R         (3d x  + 12c d x  + (18c  + 6)d x  + (12c  + 12c)d x + 3c  + 6c  + 3)
+--R      *
+--R         atan(d x + c)
+--R     + 
+--R         3 3       2 2      2             3
+--R       3d x  + 9c d x  + (9c  + 5)d x + 3c  + 5c
+--R  /
+--R       5 4        4 3       2       3 2       3        2       4      2
+--R     8d x  + 32c d x  + (48c  + 16)d x  + (32c  + 32c)d x + (8c  + 16c  + 8)d
+--R                                         Type: Union(Expression(Integer),...)
+--E 978
+
+--S 979 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 979
+
+--S 980 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 980
+
+)clear all
+
+--S 981 of 1070
+t0:=1/(1-(c+d*x)^2)
+--R 
+--R
+--R                     1
+--R   (1)  - ----------------------
+--R           2 2             2
+--R          d x  + 2c d x + c  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 981
+
+--S 982 of 1070
+r0:=atanh(c+d*x)/d
+--R 
+--R
+--R        atanh(d x + c)
+--R   (2)  --------------
+--R               d
+--R                                                    Type: Expression(Integer)
+--E 982
+
+--S 983 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(d x + c + 1) - log(d x + c - 1)
+--R   (3)  -----------------------------------
+--R                         2d
+--R                                         Type: Union(Expression(Integer),...)
+--E 983
+
+--S 984 of 1070
+m0:=a0-r0
+--R 
+--R
+--R        log(d x + c + 1) - log(d x + c - 1) - 2atanh(d x + c)
+--R   (4)  -----------------------------------------------------
+--R                                  2d
+--R                                                    Type: Expression(Integer)
+--E 984
+
+--S 985 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 985
+
+)clear all
+
+--S 986 of 1070
+t0:=1/(1-(c+d*x)^2)^2
+--R 
+--R
+--R                                      1
+--R   (1)  -------------------------------------------------------------
+--R         4 4       3 3      2      2 2      3             4     2
+--R        d x  + 4c d x  + (6c  - 2)d x  + (4c  - 4c)d x + c  - 2c  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 986
+
+--S 987 of 1070
+r0:=1/2*(c+d*x)/(d*(1-(c+d*x)^2))+1/2*atanh(c+d*x)/d
+--R 
+--R
+--R          2 2             2
+--R        (d x  + 2c d x + c  - 1)atanh(d x + c) - d x - c
+--R   (2)  ------------------------------------------------
+--R                     3 2       2       2
+--R                   2d x  + 4c d x + (2c  - 2)d
+--R                                                    Type: Expression(Integer)
+--E 987
+
+--S 988 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2 2             2
+--R       (d x  + 2c d x + c  - 1)log(d x + c + 1)
+--R     + 
+--R           2 2             2
+--R       (- d x  - 2c d x - c  + 1)log(d x + c - 1) - 2d x - 2c
+--R  /
+--R       3 2       2       2
+--R     4d x  + 8c d x + (4c  - 4)d
+--R                                         Type: Union(Expression(Integer),...)
+--E 988
+
+--S 989 of 1070
+m0:=a0-r0
+--R 
+--R
+--R        log(d x + c + 1) - log(d x + c - 1) - 2atanh(d x + c)
+--R   (4)  -----------------------------------------------------
+--R                                  4d
+--R                                                    Type: Expression(Integer)
+--E 989
+
+--S 990 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 990
+
+)clear all
+
+--S 991 of 1070
+t0:=1/(1-(c+d*x)^2)^3
+--R 
+--R
+--R   (1)
+--R   -
+--R        1
+--R     /
+--R           6 6       5 5       2      4 4       3        3 3
+--R          d x  + 6c d x  + (15c  - 3)d x  + (20c  - 12c)d x
+--R        + 
+--R              4      2      2 2      5      3             6     4     2
+--R          (15c  - 18c  + 3)d x  + (6c  - 12c  + 6c)d x + c  - 3c  + 3c  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 991
+
+--S 992 of 1070
+r0:=1/4*(c+d*x)/(d*(1-(c+d*x)^2)^2)+3/8*(c+d*x)/(d*(1-(c+d*x)^2))+_
+   3/8*atanh(c+d*x)/d
+--R 
+--R
+--R   (2)
+--R            4 4        3 3       2      2 2       3               4     2
+--R         (3d x  + 12c d x  + (18c  - 6)d x  + (12c  - 12c)d x + 3c  - 6c  + 3)
+--R      *
+--R         atanh(d x + c)
+--R     + 
+--R           3 3       2 2        2             3
+--R       - 3d x  - 9c d x  + (- 9c  + 5)d x - 3c  + 5c
+--R  /
+--R       5 4        4 3       2       3 2       3        2       4      2
+--R     8d x  + 32c d x  + (48c  - 16)d x  + (32c  - 32c)d x + (8c  - 16c  + 8)d
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4 4        3 3       2      2 2       3               4     2
+--R         (3d x  + 12c d x  + (18c  - 6)d x  + (12c  - 12c)d x + 3c  - 6c  + 3)
+--R      *
+--R         log(d x + c + 1)
+--R     + 
+--R               4 4        3 3         2      2 2         3               4     2
+--R           - 3d x  - 12c d x  + (- 18c  + 6)d x  + (- 12c  + 12c)d x - 3c  + 6c
+--R         + 
+--R           - 3
+--R      *
+--R         log(d x + c - 1)
+--R     + 
+--R           3 3        2 2         2              3
+--R       - 6d x  - 18c d x  + (- 18c  + 10)d x - 6c  + 10c
+--R  /
+--R        5 4        4 3       2       3 2       3        2        4      2
+--R     16d x  + 64c d x  + (96c  - 32)d x  + (64c  - 64c)d x + (16c  - 32c  + 16)d
+--R                                         Type: Union(Expression(Integer),...)
+--E 993
+
+--S 994 of 1070
+m0:=a0-r0
+--R 
+--R
+--R        3log(d x + c + 1) - 3log(d x + c - 1) - 6atanh(d x + c)
+--R   (4)  -------------------------------------------------------
+--R                                  16d
+--R                                                    Type: Expression(Integer)
+--E 994
+
+--S 995 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 995
+
+)clear all
+
+--S 996 of 1070
+t0:=1/(1-(1+x)^2)
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R           2
+--R          x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 996
+
+--S 997 of 1070
+r0:=atanh(1+x)
+--R 
+--R
+--R   (2)  atanh(x + 1)
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(x + 2) - log(x)
+--R   (3)  -------------------
+--R                 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 998
+
+--S 999 of 1070
+m0:=a0-r0
+--R 
+--R
+--R        log(x + 2) - log(x) - 2atanh(x + 1)
+--R   (4)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 999
+
+--S 1000 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+)clear all
+
+--S 1001 of 1070
+t0:=1/(1-(1+x)^2)^2
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         4     3     2
+--R        x  + 4x  + 4x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1001
+
+--S 1002 of 1070
+r0:=1/2*(1+x)/(1-(1+x)^2)+1/2*atanh(1+x)
+--R 
+--R
+--R          2
+--R        (x  + 2x)atanh(x + 1) - x - 1
+--R   (2)  -----------------------------
+--R                     2
+--R                   2x  + 4x
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+--S 1003 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2                       2
+--R        (x  + 2x)log(x + 2) + (- x  - 2x)log(x) - 2x - 2
+--R   (3)  ------------------------------------------------
+--R                              2
+--R                            4x  + 8x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1003
+
+--S 1004 of 1070
+m0:=a0-r0
+--R 
+--R
+--R        log(x + 2) - log(x) - 2atanh(x + 1)
+--R   (4)  -----------------------------------
+--R                         4
+--R                                                    Type: Expression(Integer)
+--E 1004
+
+--S 1005 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1005
+
+)clear all
+
+--S 1006 of 1070
+t0:=1/(1-(1+x)^2)^3
+--R 
+--R
+--R                    1
+--R   (1)  - ---------------------
+--R           6     5      4     3
+--R          x  + 6x  + 12x  + 8x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1006
+
+--S 1007 of 1070
+r0:=1/4*(1+x)/(1-(1+x)^2)^2+3/8*(1+x)/(1-(1+x)^2)+3/8*atanh(1+x)
+--R 
+--R
+--R           4      3      2                  3     2
+--R        (3x  + 12x  + 12x )atanh(x + 1) - 3x  - 9x  - 4x + 2
+--R   (2)  ----------------------------------------------------
+--R                            4      3      2
+--R                          8x  + 32x  + 32x
+--R                                                    Type: Expression(Integer)
+--E 1007
+
+--S 1008 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          4      3      2                   4      3      2            3      2
+--R       (3x  + 12x  + 12x )log(x + 2) + (- 3x  - 12x  - 12x )log(x) - 6x  - 18x
+--R     + 
+--R       - 8x + 4
+--R  /
+--R        4      3      2
+--R     16x  + 64x  + 64x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1008
+
+--S 1009 of 1070
+m0:=a0-r0
+--R 
+--R
+--R        3log(x + 2) - 3log(x) - 6atanh(x + 1)
+--R   (4)  -------------------------------------
+--R                          16
+--R                                                    Type: Expression(Integer)
+--E 1009
+
+--S 1010 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1010
+
+)clear all
+
+--S 1011 of 1070
+t0:=(1+(a+b*x)^2)^2/x
+--R 
+--R
+--R         4 4       3 3      2      2 2      3             4     2
+--R        b x  + 4a b x  + (6a  + 2)b x  + (4a  + 4a)b x + a  + 2a  + 1
+--R   (1)  -------------------------------------------------------------
+--R                                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1011
+
+--S 1012 of 1070
+r0:=a*(2+a^2)*b*x+1/2*(2+a^2)*(a+b*x)^2+1/3*a*(a+b*x)^3+1/4*(a+b*x)^4+_
+   (1+a^2)^2*log(x)
+--R 
+--R
+--R   (2)
+--R           4      2                 4 4        3 3       2       2 2
+--R       (12a  + 24a  + 12)log(x) + 3b x  + 16a b x  + (36a  + 12)b x
+--R     + 
+--R           3                4      2
+--R       (48a  + 48a)b x + 13a  + 12a
+--R  /
+--R     12
+--R                                                    Type: Expression(Integer)
+--E 1012
+
+--S 1013 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4      2                 4 4        3 3       2       2 2
+--R       (12a  + 24a  + 12)log(x) + 3b x  + 16a b x  + (36a  + 12)b x
+--R     + 
+--R           3
+--R       (48a  + 48a)b x
+--R  /
+--R     12
+--R                                         Type: Union(Expression(Integer),...)
+--E 1013
+
+--S 1014 of 1070
+m0:=a0-r0
+--R 
+--R
+--R             4      2
+--R        - 13a  - 12a
+--R   (4)  -------------
+--R              12
+--R                                                    Type: Expression(Integer)
+--E 1014
+
+--S 1015 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1015
+
+)clear all
+
+--S 1016 of 1070
+t0:=x^2/(1+(-1+x)^2)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         2
+--R        x  - 2x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1016
+
+--S 1017 of 1070
+r0:=x+log(1+(-1+x)^2)
+--R 
+--R
+--R             2
+--R   (2)  log(x  - 2x + 2) + x
+--R                                                    Type: Expression(Integer)
+--E 1017
+
+--S 1018 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R   (3)  log(x  - 2x + 2) + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1018
+
+--S 1019 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1019
+
+--S 1020 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1020
+
+)clear all
+
+--S 1021 of 1070
+t0:=x^2/sqrt(1-(1+x)^2)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         +---------+
+--R         |   2
+--R        \|- x  - 2x
+--R                                                    Type: Expression(Integer)
+--E 1021
+
+--S 1022 of 1070
+r0:=3/2*asin(1+x)+3/2*sqrt(1-(1+x)^2)-1/2*x*sqrt(1-(1+x)^2)
+--R 
+--R
+--R                  +---------+
+--R                  |   2
+--R        (- x + 3)\|- x  - 2x  + 3asin(x + 1)
+--R   (2)  ------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 1022
+
+--S 1023 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +---------+
+--R                 |   2                    +---------+
+--R                \|- x  - 2x               |   2
+--R        - 6atan(------------) + (- x + 3)\|- x  - 2x
+--R                      x
+--R   (3)  ---------------------------------------------
+--R                              2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1023
+
+--S 1024 of 1070
+m0:=a0-r0
+--R 
+--R
+--R                 +---------+
+--R                 |   2
+--R                \|- x  - 2x
+--R        - 6atan(------------) - 3asin(x + 1)
+--R                      x
+--R   (4)  ------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 1024
+
+--S 1025 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1025
+
+)clear all
+
+--S 1026 of 1070
+t0:=x^2/sqrt(1-(a+b*x)^2)
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R         +------------------------+
+--R         |   2 2             2
+--R        \|- b x  - 2a b x - a  + 1
+--R                                                    Type: Expression(Integer)
+--E 1026
+
+--S 1027 of 1070
+r0:=1/2*(1+2*a^2)*asin(a+b*x)/b^3+3/2*a*sqrt(1-(a+b*x)^2)/b^3-_
+   1/2*x*sqrt(1-(a+b*x)^2)/b^2
+--R 
+--R
+--R                     +------------------------+
+--R                     |   2 2             2           2
+--R        (- b x + 3a)\|- b x  - 2a b x - a  + 1  + (2a  + 1)asin(b x + a)
+--R   (2)  ----------------------------------------------------------------
+--R                                         3
+--R                                       2b
+--R                                                    Type: Expression(Integer)
+--E 1027
+
+--S 1028 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                           +------------------------+ +--------+
+--R               3              4     2      |   2 2             2      |   2
+--R           ((8a  + 4a)b x + 8a  - 4a  - 4)\|- b x  - 2a b x - a  + 1 \|- a  + 1
+--R         + 
+--R              4      2 2       5     3              6      4
+--R           (8a  - 2)b x  + (16a  - 8a  - 8a)b x + 8a  - 12a  + 4
+--R      *
+--R               +--------+    +------------------------+
+--R               |   2         |   2 2             2
+--R              \|- a  + 1  - \|- b x  - 2a b x - a  + 1
+--R         atan(-----------------------------------------)
+--R                                 b x
+--R     + 
+--R                                                                   +--------+
+--R            4 4     3 3        3       2 2        4     2          |   2
+--R       (2a b x  - 2b x  + (- 6a  - 3a)b x  + (- 4a  + 2a  + 2)b x)\|- a  + 1
+--R     + 
+--R               2      3 3      3      2 2      4     2
+--R         ((- 2a  + 1)b x  + (2a  + a)b x  + (4a  - 2a  - 2)b x)
+--R      *
+--R          +------------------------+
+--R          |   2 2             2
+--R         \|- b x  - 2a b x - a  + 1
+--R  /
+--R                              +------------------------+ +--------+
+--R            4       2      3  |   2 2             2      |   2
+--R       (4a b x + (4a  - 4)b )\|- b x  - 2a b x - a  + 1 \|- a  + 1
+--R     + 
+--R          2      5 2      3       4       4     2      3
+--R       (4a  - 2)b x  + (8a  - 8a)b x + (4a  - 8a  + 4)b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1028
+
+--S 1029 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +------------------------+ +--------+
+--R               3              4     2      |   2 2             2      |   2
+--R           ((8a  + 4a)b x + 8a  - 4a  - 4)\|- b x  - 2a b x - a  + 1 \|- a  + 1
+--R         + 
+--R              4      2 2       5     3              6      4
+--R           (8a  - 2)b x  + (16a  - 8a  - 8a)b x + 8a  - 12a  + 4
+--R      *
+--R               +--------+    +------------------------+
+--R               |   2         |   2 2             2
+--R              \|- a  + 1  - \|- b x  - 2a b x - a  + 1
+--R         atan(-----------------------------------------)
+--R                                 b x
+--R     + 
+--R                   3              4     2
+--R             ((- 4a  - 2a)b x - 4a  + 2a  + 2)asin(b x + a)
+--R          *
+--R              +------------------------+
+--R              |   2 2             2
+--R             \|- b x  - 2a b x - a  + 1
+--R         + 
+--R              3       2 2       4      2         5      3
+--R           (6a  - 3a)b x  + (12a  - 12a )b x + 6a  - 12a  + 6a
+--R      *
+--R          +--------+
+--R          |   2
+--R         \|- a  + 1
+--R     + 
+--R                                            +------------------------+
+--R             4     2         5      3       |   2 2             2
+--R       ((- 6a  + 6a )b x - 6a  + 12a  - 6a)\|- b x  - 2a b x - a  + 1
+--R     + 
+--R             4      2 2        5     3              6     4
+--R       ((- 4a  + 1)b x  + (- 8a  + 4a  + 4a)b x - 4a  + 6a  - 2)asin(b x + a)
+--R  /
+--R                              +------------------------+ +--------+
+--R            4       2      3  |   2 2             2      |   2
+--R       (4a b x + (4a  - 4)b )\|- b x  - 2a b x - a  + 1 \|- a  + 1
+--R     + 
+--R          2      5 2      3       4       4     2      3
+--R       (4a  - 2)b x  + (8a  - 8a)b x + (4a  - 8a  + 4)b
+--R                                                    Type: Expression(Integer)
+--E 1029
+
+--S 1030 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1030
+
+)clear all
+
+--S 1031 of 1070
+t0:=x^2/sqrt(1+(a+b*x)^2)
+--R 
+--R
+--R                     2
+--R                    x
+--R   (1)  -------------------------
+--R         +----------------------+
+--R         | 2 2             2
+--R        \|b x  + 2a b x + a  + 1
+--R                                                    Type: Expression(Integer)
+--E 1031
+
+--S 1032 of 1070
+r0:=-1/2*(1-2*a^2)*asinh(a+b*x)/b^3-3/2*a*sqrt(1+(a+b*x)^2)/b^3+_
+   1/2*x*sqrt(1+(a+b*x)^2)/b^2
+--R 
+--R
+--R                   +----------------------+
+--R                   | 2 2             2           2
+--R        (b x - 3a)\|b x  + 2a b x + a  + 1  + (2a  - 1)asinh(b x + a)
+--R   (2)  -------------------------------------------------------------
+--R                                       3
+--R                                     2b
+--R                                                    Type: Expression(Integer)
+--E 1032
+
+--S 1033 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         +----------------------+
+--R                  2              3       | 2 2             2
+--R           ((- 16a  + 8)b x - 16a  + 8a)\|b x  + 2a b x + a  + 1
+--R         + 
+--R               2      2 2       3                4
+--R           (16a  - 8)b x  + (32a  - 16a)b x + 16a  - 4
+--R      *
+--R              +----------------------+
+--R              | 2 2             2
+--R         log(\|b x  + 2a b x + a  + 1  - b x - a)
+--R     + 
+--R                                                        +----------------------+
+--R            3 3       2 2       2              3        | 2 2             2
+--R       (- 8b x  + 8a b x  + (26a  - 4)b x + 10a  + 12a)\|b x  + 2a b x + a  + 1
+--R     + 
+--R         4 4         2      2 2         3                4      2
+--R       8b x  + (- 34a  + 8)b x  + (- 36a  - 16a)b x - 10a  - 17a
+--R  /
+--R                        +----------------------+
+--R           4         3  | 2 2             2           5 2        4
+--R       (16b x + 16a b )\|b x  + 2a b x + a  + 1  - 16b x  - 32a b x
+--R     + 
+--R             2      3
+--R       (- 16a  - 8)b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1033
+
+--S 1034 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +----------------------+
+--R            2          | 2 2             2
+--R       (- 8a  + 4)log(\|b x  + 2a b x + a  + 1  - b x - a)
+--R     + 
+--R            2                        2
+--R       (- 8a  + 4)asinh(b x + a) - 7a
+--R  /
+--R       3
+--R     8b
+--R                                                    Type: Expression(Integer)
+--E 1034
+
+--S 1035 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1035
+
+)clear all
+
+--S 1036 of 1070
+--t0:=f((a+b*x)/x)
+--E 1036
+
+--S 1037 of 1070
+--r0:=Int(f(b+a/x),x)
+--E 1037
+
+--S 1038 of 1070
+--a0:=integrate(t0,x)
+--E 1038
+
+--S 1039 of 1070
+--m0:=a0-r0
+--E 1039
+
+--S 1040 of 1070
+--d0:=normalize(D(m0,x))
+--E 1040
+
+)clear all
+
+--S 1041 of 1070
+--t0:=f((a+b*x^2)/x^2)
+--E 1041
+
+--S 1042 of 1070
+--r0:=Int(f(b+a/x^2),x)
+--E 1042
+
+--S 1043 of 1070
+--a0:=integrate(t0,x)
+--E 1043
+
+--S 1044 of 1070
+--m0:=a0-r0
+--E 1044
+
+--S 1045 of 1070
+--d0:=normalize(D(m0,x))
+--E 1045
+
+)clear all
+
+--S 1046 of 1070
+--t0:=f(x/(a+b*x))
+--E 1046
+
+--S 1047 of 1070
+--r0:=Int(f(x/(a+b*x)),x)
+--E 1047
+
+--S 1048 of 1070
+--a0:=integrate(t0,x)
+--E 1048
+
+--S 1049 of 1070
+--m0:=a0-r0
+--E 1049
+
+--S 1050 of 1070
+--d0:=normalize(D(m0,x))
+--E 1050
+
+)clear all
+
+--S 1051 of 1070
+--t0:=f(x^2/(a+b*x^2))
+--E 1051
+
+--S 1052 of 1070
+--r0:=Int(f(x^2/(a+b*x^2)),x)
+--E 1052
+
+--S 1053 of 1070
+--a0:=integrate(t0,x)
+--E 1053
+
+--S 1054 of 1070
+--m0:=a0-r0
+--E 1054
+
+--S 1055 of 1070
+--d0:=normalize(D(m0,x))
+--E 1055
+
+)clear all
+
+--S 1056 of 1070
+--t0:=f(x^2/(a+b*x)^2)
+--E 1056
+
+--S 1057 of 1070
+--r0:=Int(f(x^2/(a+b*x)^2),x)
+--E 1057
+
+--S 1058 of 1070
+--a0:=integrate(t0,x)
+--E 1058
+
+--S 1059 of 1070
+--m0:=a0-r0
+--E 1059
+
+--S 1060 of 1070
+--d0:=normalize(D(m0,x))
+--E 1060
+
+)clear all
+
+--S 1061 of 1070
+--t0:=f(x^4/(a+b*x^2)^2)
+--E 1061
+
+--S 1062 of 1070
+--r0:=Int(f(x^4/(a+b*x^2)^2),x)
+--E 1062
+
+--S 1063 of 1070
+--a0:=integrate(t0,x)
+--E 1063
+
+--S 1064 of 1070
+--m0:=a0-r0
+--E 1064
+
+--S 1065 of 1070
+--d0:=normalize(D(m0,x))
+--E 1065
+
+)clear all
+
+--S 1066 of 1070
+t0:=sqrt(x-sqrt(-4+x^2))
+--R 
+--R
+--R         +---------------+
+--R         |   +------+
+--R         |   | 2
+--R   (1)  \|- \|x  - 4  + x
+--R                                                    Type: Expression(Integer)
+--E 1066
+
+--S 1067 of 1070
+r0:=2/3*(2*x+sqrt(-4+x^2))*sqrt(x-sqrt(-4+x^2))
+--R 
+--R
+--R                          +---------------+
+--R           +------+       |   +------+
+--R           | 2            |   | 2
+--R        (2\|x  - 4  + 4x)\|- \|x  - 4  + x
+--R   (2)  -----------------------------------
+--R                         3
+--R                                                    Type: Expression(Integer)
+--E 1067
+
+--S 1068 of 1070
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +------+
+--R             | 2          2
+--R        - 2x\|x  - 4  + 2x  + 8
+--R   (3)  -----------------------
+--R            +---------------+
+--R            |   +------+
+--R            |   | 2
+--R          3\|- \|x  - 4  + x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1068
+
+--S 1069 of 1070
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1069
+
+--S 1070 of 1070
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1070
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich22d.input.pamphlet b/src/input/rich22d.input.pamphlet
new file mode 100644
index 0000000..e4d49b9
--- /dev/null
+++ b/src/input/rich22d.input.pamphlet
@@ -0,0 +1,3540 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich22d.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Algebraic function problems.input
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich22d.output
+)spool rich22d.output
+)set message test on
+)set message auto off
+)clear all
+
+)clear all
+
+--S 1 of 801
+t0:=sqrt(1+sqrt(1-x^2))
+--E 1
+
+--S 2 of 801
+r0:=2/3*(1+x^2-sqrt(1-x^2))*sqrt(1+sqrt(1-x^2))/x
+--E 2
+
+--S 3 of 801
+a0:=integrate(t0,x)
+--E 3
+
+--S 4 of 801
+m0:=a0-r0
+--E 4
+
+--S 5 of 801
+d0:=normalize(D(m0,x))
+--E 5
+
+)clear all
+
+--S 6 of 801
+t0:=sqrt(a*x+b*sqrt(c+a^2*x^2/b^2))
+--E 6
+
+--S 7 of 801
+r0:=2/3*(2*a*x-b*sqrt(c+a^2*x^2/b^2))*sqrt(a*x+b*sqrt(c+a^2*x^2/b^2))/a
+--E 7
+
+--S 8 of 801
+a0:=integrate(t0,x)
+--E 8
+
+--S 9 of 801
+m0:=a0-r0
+--E 9
+
+--S 10 of 801
+d0:=normalize(D(m0,x))
+--E 10
+
+)clear all
+
+--S 11 of 801
+t0:=sqrt(a+b*sqrt(a^2/b^2+c*x^2))
+--E 11
+
+--S 12 of 801
+r0:=-2/3*(a^2/b^2-c*x^2-a*sqrt(a^2/b^2+c*x^2)/b)*sqrt(a+b*sqrt(a^2/b^2+c*x^2))/(c*x)
+--E 12
+
+--S 13 of 801
+a0:=integrate(t0,x)
+--E 13
+
+--S 14 of 801
+m0:=a0-r0
+--E 14
+
+--S 15 of 801
+d0:=normalize(D(m0,x))
+--E 15
+
+)clear all
+
+--S 16 of 801
+t0:=sqrt(b*x^2+sqrt(a+b^2*x^4))/sqrt(a+b^2*x^4)
+--E 16
+
+--S 17 of 801
+r0:=atanh(x*sqrt(2)*sqrt(b)/sqrt(b*x^2+sqrt(a+b^2*x^4)))/(sqrt(2)*sqrt(b))
+--E 17
+
+--S 18 of 801
+a0:=integrate(t0,x)
+--E 18
+
+--S 19 of 801
+m0:=a0-r0
+--E 19
+
+--S 20 of 801
+d0:=normalize(D(m0,x))
+--E 20
+
+)clear all
+
+--S 21 of 801
+t0:=sqrt(-b*x^2+sqrt(a+b^2*x^4))/sqrt(a+b^2*x^4)
+--E 21
+
+--S 22 of 801
+r0:=atan(x*sqrt(2)*sqrt(b)/sqrt(-b*x^2+sqrt(a+b^2*x^4)))/(sqrt(2)*sqrt(b))
+--E 22
+
+--S 23 of 801
+a0:=integrate(t0,x)
+--E 23
+
+--S 24 of 801
+m0:=a0-r0
+--E 24
+
+--S 25 of 801
+d0:=normalize(D(m0,x))
+--E 25
+
+)clear all
+
+--S 26 of 801
+t0:=sqrt(2*x^2+sqrt(3+4*x^4))/((c+d*x)*sqrt(3+4*x^4))
+--E 26
+
+--S 27 of 801
+--r0:=(1/2-1/2*%i)*atan((2*%i*c*x+d*sqrt(3))/(sqrt(-2*%i*x^2+sqrt(3))*sqrt(2*%i*c^2-d^2*sqrt(3))))/sqrt(2*%i*c^2-d^2*sqrt(3))+(-1/2-1/2*%i)*atanh((-2*%i*c*x+d*sqrt(3))/(sqrt(2*%i*x^2+sqrt(3))*sqrt(2*%i*c^2+d^2*sqrt(3))))/sqrt(2*%i*c^2+d^2*sqrt(3))
+--E 27
+
+--S 28 of 801
+--a0:=integrate(t0,x)
+--E 28
+
+--S 29 of 801
+--m0:=a0-r0
+--E 29
+
+--S 30 of 801
+--d0:=normalize(D(m0,x))
+--E 30
+
+)clear all
+
+--S 31 of 801
+t0:=sqrt(2*x^2+sqrt(3+4*x^4))/((c+d*x)^2*sqrt(3+4*x^4))
+--E 31
+
+--S 32 of 801
+--r0:=(1+%i)*c*atan((2*%i*c*x+d*sqrt(3))/(sqrt(-2*%i*x^2+sqrt(3))*sqrt(2*%i*c^2-d^2*sqrt(3))))/(2*%i*c^2-d^2*sqrt(3))^(3/2)+(1-%i)*c*atanh((-2*%i*c*x+d*sqrt(3))/(sqrt(2*%i*x^2+sqrt(3))*sqrt(2*%i*c^2+d^2*sqrt(3))))/(2*%i*c^2+d^2*sqrt(3))^(3/2)+(1/2-1/2*%i)*d*sqrt(-2*%i*x^2+sqrt(3))/((c+d*x)*(2*%i*c^2-d^2*sqrt(3)))+(-1/2-1/2*%i)*d*sqrt(2*%i*x^2+sqrt(3))/((c+d*x)*(2*%i*c^2+d^2*sqrt(3)))
+--E 32
+
+--S 33 of 801
+--a0:=integrate(t0,x)
+--E 33
+
+--S 34 of 801
+--m0:=a0-r0
+--E 34
+
+--S 35 of 801
+--d0:=normalize(D(m0,x))
+--E 35
+
+)clear all
+
+--S 36 of 801
+t0:=sqrt(1+sqrt(1+x^2))
+--E 36
+
+--S 37 of 801
+r0:=-2/3*(1-x^2-sqrt(1+x^2))*sqrt(1+sqrt(1+x^2))/x
+--E 37
+
+--S 38 of 801
+a0:=integrate(t0,x)
+--E 38
+
+--S 39 of 801
+m0:=a0-r0
+--E 39
+
+--S 40 of 801
+d0:=normalize(D(m0,x))
+--E 40
+
+)clear all
+
+--S 41 of 801
+t0:=sqrt(5+sqrt(25+x^2))
+--E 41
+
+--S 42 of 801
+r0:=-2/3*(25-x^2-5*sqrt(25+x^2))*sqrt(5+sqrt(25+x^2))/x
+--E 42
+
+--S 43 of 801
+a0:=integrate(t0,x)
+--E 43
+
+--S 44 of 801
+m0:=a0-r0
+--E 44
+
+--S 45 of 801
+d0:=normalize(D(m0,x))
+--E 45
+
+)clear all
+
+--S 46 of 801
+t0:=sqrt(1+sqrt(1-x^2))
+--E 46
+
+--S 47 of 801
+r0:=2/3*(1+x^2-sqrt(1-x^2))*sqrt(1+sqrt(1-x^2))/x
+--E 47
+
+--S 48 of 801
+a0:=integrate(t0,x)
+--E 48
+
+--S 49 of 801
+m0:=a0-r0
+--E 49
+
+--S 50 of 801
+d0:=normalize(D(m0,x))
+--E 50
+
+)clear all
+
+--S 51 of 801
+t0:=sqrt(x-sqrt(-4+x^2))
+--E 51
+
+--S 52 of 801
+r0:=2/3*(2*x+sqrt(-4+x^2))*sqrt(x-sqrt(-4+x^2))
+--E 52
+
+--S 53 of 801
+a0:=integrate(t0,x)
+--E 53
+
+--S 54 of 801
+m0:=a0-r0
+--E 54
+
+--S 55 of 801
+d0:=normalize(D(m0,x))
+--E 55
+
+)clear all
+
+--S 56 of 801
+t0:=(1-5*x^2)/(x^3*(1+x^2))
+--E 56
+
+--S 57 of 801
+r0:=(-1/2)/x^2+6*atanh(1+2*x^2)
+--E 57
+
+--S 58 of 801
+a0:=integrate(t0,x)
+--E 58
+
+--S 59 of 801
+m0:=a0-r0
+--E 59
+
+--S 60 of 801
+d0:=normalize(D(m0,x))
+--E 60
+
+)clear all
+
+--S 61 of 801
+t0:=2*x/((-1+x)*(5+x^2))
+--E 61
+
+--S 62 of 801
+r0:=1/3*log(1-x)-1/6*log(5+x^2)+1/3*atan(x/sqrt(5))*sqrt(5)
+--E 62
+
+--S 63 of 801
+a0:=integrate(t0,x)
+--E 63
+
+--S 64 of 801
+m0:=a0-r0
+--E 64
+
+--S 65 of 801
+d0:=normalize(D(m0,x))
+--E 65
+
+)clear all
+
+--S 66 of 801
+t0:=(2+x^2)/(2+x)
+--E 66
+
+--S 67 of 801
+r0:=-2*x+1/2*x^2+6*log(2+x)
+--E 67
+
+--S 68 of 801
+a0:=integrate(t0,x)
+--E 68
+
+--S 69 of 801
+m0:=a0-r0
+--E 69
+
+--S 70 of 801
+d0:=normalize(D(m0,x))
+--E 70
+
+)clear all
+
+--S 71 of 801
+t0:=1/((-3+x)*(4+x^2))
+--E 71
+
+--S 72 of 801
+r0:=-3/26*atan(1/2*x)+1/13*log(3-x)-1/26*log(4+x^2)
+--E 72
+
+--S 73 of 801
+a0:=integrate(t0,x)
+--E 73
+
+--S 74 of 801
+m0:=a0-r0
+--E 74
+
+--S 75 of 801
+d0:=normalize(D(m0,x))
+--E 75
+
+)clear all
+
+--S 76 of 801
+t0:=(-2+3*x^6)/(x*(5+2*x^6))
+--E 76
+
+--S 77 of 801
+r0:=-2/5*log(x)+19/60*log(5+2*x^6)
+--E 77
+
+--S 78 of 801
+a0:=integrate(t0,x)
+--E 78
+
+--S 79 of 801
+m0:=a0-r0
+--E 79
+
+--S 80 of 801
+d0:=normalize(D(m0,x))
+--E 80
+
+)clear all
+
+--S 81 of 801
+t0:=(3+2*x)/((-2+x)*(5+x))
+--E 81
+
+--S 82 of 801
+r0:=log(2-x)+log(5+x)
+--E 82
+
+--S 83 of 801
+a0:=integrate(t0,x)
+--E 83
+
+--S 84 of 801
+m0:=a0-r0
+--E 84
+
+--S 85 of 801
+d0:=normalize(D(m0,x))
+--E 85
+
+)clear all
+
+--S 86 of 801
+t0:=x^4/(4+5*x^2+x^4)
+--E 86
+
+--S 87 of 801
+r0:=x-8/3*atan(1/2*x)+1/3*atan(x)
+--E 87
+
+--S 88 of 801
+a0:=integrate(t0,x)
+--E 88
+
+--S 89 of 801
+m0:=a0-r0
+--E 89
+
+--S 90 of 801
+d0:=normalize(D(m0,x))
+--E 90
+
+)clear all
+
+--S 91 of 801
+t0:=1/((1+x)*(2+x)^2*(3+x)^3)
+--E 91
+
+--S 92 of 801
+r0:=1/(2+x)+1/4/(3+x)^2+5/4/(3+x)+1/8*log(1+x)+2*log(2+x)-17/8*log(3+x)
+--E 92
+
+--S 93 of 801
+a0:=integrate(t0,x)
+--E 93
+
+--S 94 of 801
+m0:=a0-r0
+--E 94
+
+--S 95 of 801
+d0:=normalize(D(m0,x))
+--E 95
+
+)clear all
+
+--S 96 of 801
+t0:=x/(-1+x^2)
+--E 96
+
+--S 97 of 801
+r0:=1/2*log(1-x^2)
+--E 97
+
+--S 98 of 801
+a0:=integrate(t0,x)
+--E 98
+
+--S 99 of 801
+m0:=a0-r0
+--E 99
+
+--S 100 of 801
+d0:=normalize(D(m0,x))
+--E 100
+
+)clear all
+
+--S 101 of 801
+t0:=1/(-1+x^2)^2
+--E 101
+
+--S 102 of 801
+r0:=1/2*x/(1-x^2)+1/2*atanh(x)
+--E 102
+
+--S 103 of 801
+a0:=integrate(t0,x)
+--E 103
+
+--S 104 of 801
+m0:=a0-r0
+--E 104
+
+--S 105 of 801
+d0:=normalize(D(m0,x))
+--E 105
+
+)clear all
+
+--S 106 of 801
+t0:=x^2/(1+x^2)^2
+--E 106
+
+--S 107 of 801
+r0:=-1/2*x/(1+x^2)+1/2*atan(x)
+--E 107
+
+--S 108 of 801
+a0:=integrate(t0,x)
+--E 108
+
+--S 109 of 801
+m0:=a0-r0
+--E 109
+
+--S 110 of 801
+d0:=normalize(D(m0,x))
+--E 110
+
+)clear all
+
+--S 111 of 801
+t0:=1/(2+3*x)
+--E 111
+
+--S 112 of 801
+r0:=1/3*log(2+3*x)
+--E 112
+
+--S 113 of 801
+a0:=integrate(t0,x)
+--E 113
+
+--S 114 of 801
+m0:=a0-r0
+--E 114
+
+--S 115 of 801
+d0:=normalize(D(m0,x))
+--E 115
+
+)clear all
+
+--S 116 of 801
+t0:=1/(a^2+x^2)
+--E 116
+
+--S 117 of 801
+r0:=atan(x/a)/a
+--E 117
+
+--S 118 of 801
+a0:=integrate(t0,x)
+--E 118
+
+--S 119 of 801
+m0:=a0-r0
+--E 119
+
+--S 120 of 801
+d0:=normalize(D(m0,x))
+--E 120
+
+)clear all
+
+--S 121 of 801
+t0:=1/(a+b*x^2)
+--E 121
+
+--S 122 of 801
+r0:=atan(x*sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b))
+--E 122
+
+--S 123 of 801
+a0:=integrate(t0,x)
+--E 123
+
+--S 124 of 801
+m0a:=a0.1-r0
+--E 124
+
+--S 125 of 801
+d0a:=normalize(D(m0a,x))
+--E 125
+
+--S 126 of 801
+m0b:=a0.2-r0
+--E 126
+
+--S 127 of 801
+d0b:=normalize(D(m0b,x))
+--E 127
+
+)clear all
+
+--S 128 of 801
+t0:=1/(2-x+x^2)
+--E 128
+
+--S 129 of 801
+r0:=-2*atan((1-2*x)/sqrt(7))/sqrt(7)
+--E 129
+
+--S 130 of 801
+a0:=integrate(t0,x)
+--E 130
+
+--S 131 of 801
+m0:=a0-r0
+--E 131
+
+--S 132 of 801
+d0:=normalize(D(m0,x))
+--E 132
+
+)clear all
+
+--S 133 of 801
+t0:=x^2*(4-x^2)^2
+--E 133
+
+--S 134 of 801
+r0:=16/3*x^3-8/5*x^5+1/7*x^7
+--E 134
+
+--S 135 of 801
+a0:=integrate(t0,x)
+--E 135
+
+--S 136 of 801
+m0:=a0-r0
+--E 136
+
+--S 137 of 801
+d0:=normalize(D(m0,x))
+--E 137
+
+)clear all
+
+--S 138 of 801
+t0:=x*(1-x^3)^2
+--E 138
+
+--S 139 of 801
+r0:=1/2*x^2-2/5*x^5+1/8*x^8
+--E 139
+
+--S 140 of 801
+a0:=integrate(t0,x)
+--E 140
+
+--S 141 of 801
+m0:=a0-r0
+--E 141
+
+--S 142 of 801
+d0:=normalize(D(m0,x))
+--E 142
+
+)clear all
+
+--S 143 of 801
+t0:=(-4+5*x^2+x^3)/x^2
+--E 143
+
+--S 144 of 801
+r0:=4/x+5*x+1/2*x^2
+--E 144
+
+--S 145 of 801
+a0:=integrate(t0,x)
+--E 145
+
+--S 146 of 801
+m0:=a0-r0
+--E 146
+
+--S 147 of 801
+d0:=normalize(D(m0,x))
+--E 147
+
+)clear all
+
+--S 148 of 801
+t0:=(-1+x)/(3-4*x+3*x^2)
+--E 148
+
+--S 149 of 801
+r0:=1/6*log(3-4*x+3*x^2)+1/3*atan((2-3*x)/sqrt(5))/sqrt(5)
+--E 149
+
+--S 150 of 801
+a0:=integrate(t0,x)
+--E 150
+
+--S 151 of 801
+m0:=a0-r0
+--E 151
+
+--S 152 of 801
+d0:=normalize(D(m0,x))
+--E 152
+
+)clear all
+
+--S 153 of 801
+t0:=(2+x^3)^2
+--E 153
+
+--S 154 of 801
+r0:=4*x+x^4+1/7*x^7
+--E 154
+
+--S 155 of 801
+a0:=integrate(t0,x)
+--E 155
+
+--S 156 of 801
+m0:=a0-r0
+--E 156
+
+--S 157 of 801
+d0:=normalize(D(m0,x))
+--E 157
+
+)clear all
+
+--S 158 of 801
+t0:=(-4+x^2)/(2+x)
+--E 158
+
+--S 159 of 801
+r0:=-2*x+1/2*x^2
+--E 159
+
+--S 160 of 801
+a0:=integrate(t0,x)
+--E 160
+
+--S 161 of 801
+m0:=a0-r0
+--E 161
+
+--S 162 of 801
+d0:=normalize(D(m0,x))
+--E 162
+
+)clear all
+
+--S 163 of 801
+t0:=1/((2+x)*(1+x^2))
+--E 163
+
+--S 164 of 801
+r0:=2/5*atan(x)+1/5*log(2+x)-1/10*log(1+x^2)
+--E 164
+
+--S 165 of 801
+a0:=integrate(t0,x)
+--E 165
+
+--S 166 of 801
+m0:=a0-r0
+--E 166
+
+--S 167 of 801
+d0:=normalize(D(m0,x))
+--E 167
+
+)clear all
+
+--S 168 of 801
+t0:=1/((1+x)*(1+x^2))
+--E 168
+
+--S 169 of 801
+r0:=1/2*atan(x)+1/2*log(1+x)-1/4*log(1+x^2)
+--E 169
+
+--S 170 of 801
+a0:=integrate(t0,x)
+--E 170
+
+--S 171 of 801
+m0:=a0-r0
+--E 171
+
+--S 172 of 801
+d0:=normalize(D(m0,x))
+--E 172
+
+)clear all
+
+--S 173 of 801
+t0:=x/((1+x)*(1+x^2))
+--E 173
+
+--S 174 of 801
+r0:=1/2*atan(x)-1/2*log(1+x)+1/4*log(1+x^2)
+--E 174
+
+--S 175 of 801
+a0:=integrate(t0,x)
+--E 175
+
+--S 176 of 801
+m0:=a0-r0
+--E 176
+
+--S 177 of 801
+d0:=normalize(D(m0,x))
+--E 177
+
+)clear all
+
+--S 178 of 801
+t0:=(2*x+x^2)/(1+x)^2
+--E 178
+
+--S 179 of 801
+r0:=(2+x)^2/(1+x)
+--E 179
+
+--S 180 of 801
+a0:=integrate(t0,x)
+--E 180
+
+--S 181 of 801
+m0:=a0-r0
+--E 181
+
+--S 182 of 801
+d0:=normalize(D(m0,x))
+--E 182
+
+)clear all
+
+--S 183 of 801
+t0:=(-10+x^2)/(4+9*x^2+2*x^4)
+--E 183
+
+--S 184 of 801
+r0:=atan(1/2*x)-3*atan(x*sqrt(2))/sqrt(2)
+--E 184
+
+--S 185 of 801
+a0:=integrate(t0,x)
+--E 185
+
+--S 186 of 801
+m0:=a0-r0
+--E 186
+
+--S 187 of 801
+d0:=normalize(D(m0,x))
+--E 187
+
+)clear all
+
+--S 188 of 801
+t0:=(31+5*x)/(11-4*x+3*x^2)
+--E 188
+
+--S 189 of 801
+r0:=5/6*log(11-4*x+3*x^2)-103/3*atan((2-3*x)/sqrt(29))/sqrt(29)
+--E 189
+
+--S 190 of 801
+a0:=integrate(t0,x)
+--E 190
+
+--S 191 of 801
+m0:=a0-r0
+--E 191
+
+--S 192 of 801
+d0:=normalize(D(m0,x))
+--E 192
+
+)clear all
+
+--S 193 of 801
+t0:=(3+x^2)/(-3+x^2)
+--E 193
+
+--S 194 of 801
+r0:=x-2*atanh(x/sqrt(3))*sqrt(3)
+--E 194
+
+--S 195 of 801
+a0:=integrate(t0,x)
+--E 195
+
+--S 196 of 801
+m0:=a0-r0
+--E 196
+
+--S 197 of 801
+d0:=normalize(D(m0,x))
+--E 197
+
+)clear all
+
+--S 198 of 801
+t0:=(-1+x^2)/(1+x^2)
+--E 198
+
+--S 199 of 801
+r0:=x-2*atan(x)
+--E 199
+
+--S 200 of 801
+a0:=integrate(t0,x)
+--E 200
+
+--S 201 of 801
+m0:=a0-r0
+--E 201
+
+--S 202 of 801
+d0:=normalize(D(m0,x))
+--E 202
+
+)clear all
+
+--S 203 of 801
+t0:=(-2+x^2+x^3)/x^4
+--E 203
+
+--S 204 of 801
+r0:=2/3/x^3+(-1)/x+log(x)
+--E 204
+
+--S 205 of 801
+a0:=integrate(t0,x)
+--E 205
+
+--S 206 of 801
+m0:=a0-r0
+--E 206
+
+--S 207 of 801
+d0:=normalize(D(m0,x))
+--E 207
+
+)clear all
+
+--S 208 of 801
+t0:=(1+x+x^3)/x^2
+--E 208
+
+--S 209 of 801
+r0:=(-1)/x+1/2*x^2+log(x)
+--E 209
+
+--S 210 of 801
+a0:=integrate(t0,x)
+--E 210
+
+--S 211 of 801
+m0:=a0-r0
+--E 211
+
+--S 212 of 801
+d0:=normalize(D(m0,x))
+--E 212
+
+)clear all
+
+--S 213 of 801
+t0:=(-2+x^2)/(x*(2+x^2))
+--E 213
+
+--S 214 of 801
+r0:=-log(x)+log(2+x^2)
+--E 214
+
+--S 215 of 801
+a0:=integrate(t0,x)
+--E 215
+
+--S 216 of 801
+m0:=a0-r0
+--E 216
+
+--S 217 of 801
+d0:=normalize(D(m0,x))
+--E 217
+
+)clear all
+
+--S 218 of 801
+t0:=(-3+x)*(-7+4*x^2)
+--E 218
+
+--S 219 of 801
+r0:=21*x-7/2*x^2-4*x^3+x^4
+--E 219
+
+--S 220 of 801
+a0:=integrate(t0,x)
+--E 220
+
+--S 221 of 801
+m0:=a0-r0
+--E 221
+
+--S 222 of 801
+d0:=normalize(D(m0,x))
+--E 222
+
+)clear all
+
+--S 223 of 801
+t0:=(-2+7*x)^3
+--E 223
+
+--S 224 of 801
+r0:=1/28*(2-7*x)^4
+--E 224
+
+--S 225 of 801
+a0:=integrate(t0,x)
+--E 225
+
+--S 226 of 801
+m0:=a0-r0
+--E 226
+
+--S 227 of 801
+d0:=normalize(D(m0,x))
+--E 227
+
+)clear all
+
+--S 228 of 801
+t0:=(-7+4*x^2)/(3+2*x)
+--E 228
+
+--S 229 of 801
+r0:=-3*x+x^2+log(3+2*x)
+--E 229
+
+--S 230 of 801
+a0:=integrate(t0,x)
+--E 230
+
+--S 231 of 801
+m0:=a0-r0
+--E 231
+
+--S 232 of 801
+d0:=normalize(D(m0,x))
+--E 232
+
+)clear all
+
+--S 233 of 801
+t0:=(1+x)/((-1+x)*x^2)
+--E 233
+
+--S 234 of 801
+r0:=1/x+2*log(1-x)-2*log(x)
+--E 234
+
+--S 235 of 801
+a0:=integrate(t0,x)
+--E 235
+
+--S 236 of 801
+m0:=a0-r0
+--E 236
+
+--S 237 of 801
+d0:=normalize(D(m0,x))
+--E 237
+
+)clear all
+
+--S 238 of 801
+t0:=(4+4*x)/(x^2*(1+x^2))
+--E 238
+
+--S 239 of 801
+r0:=(-4)/x-4*atan(x)+4*log(x)-2*log(1+x^2)
+--E 239
+
+--S 240 of 801
+a0:=integrate(t0,x)
+--E 240
+
+--S 241 of 801
+m0:=a0-r0
+--E 241
+
+--S 242 of 801
+d0:=normalize(D(m0,x))
+--E 242
+
+)clear all
+
+--S 243 of 801
+t0:=(24+8*x)/(x*(-4+x^2))
+--E 243
+
+--S 244 of 801
+r0:=5*log(2-x)-6*log(x)+log(2+x)
+--E 244
+
+--S 245 of 801
+a0:=integrate(t0,x)
+--E 245
+
+--S 246 of 801
+m0:=a0-r0
+--E 246
+
+--S 247 of 801
+d0:=normalize(D(m0,x))
+--E 247
+
+)clear all
+
+--S 248 of 801
+t0:=1/(4*x^2+4*x^3+x^4)
+--E 248
+
+--S 249 of 801
+r0a:=(-1/4)/x+(-1/4)/(2+x)+1/2*atanh(1+x)
+--E 249
+
+--S 250 of 801
+r0b:=(-1/4)/x+(-1/4)/(2+x)-1/4*log(x)+1/4*log(2+x)
+--E 250
+
+--S 251 of 801
+a0:=integrate(t0,x)
+--E 251
+
+--S 252 of 801
+m0a:=a0-r0a
+--E 252
+
+--S 253 of 801
+d0a:=D(m0a,x)
+--E 253
+
+--S 254 of 801
+m0b:=a0-r0b
+--E 254
+
+--S 255 of 801
+d0b:=D(m0b,x)
+--E 255
+
+)clear all
+
+--S 256 of 801
+t0:=(1+x^2)/(1+x)
+--E 256
+
+--S 257 of 801
+r0:=-x+1/2*x^2+2*log(1+x)
+--E 257
+
+--S 258 of 801
+a0:=integrate(t0,x)
+--E 258
+
+--S 259 of 801
+m0:=a0-r0
+--E 259
+
+--S 260 of 801
+d0:=normalize(D(m0,x))
+--E 260
+
+)clear all
+
+--S 261 of 801
+t0:=(-1+3*x-3*x^2+x^3)/x^2
+--E 261
+
+--S 262 of 801
+r0:=1/x-3*x+1/2*x^2+3*log(x)
+--E 262
+
+--S 263 of 801
+a0:=integrate(t0,x)
+--E 263
+
+--S 264 of 801
+m0:=a0-r0
+--E 264
+
+--S 265 of 801
+d0:=normalize(D(m0,x))
+--E 265
+
+)clear all
+
+--S 266 of 801
+t0:=(x+1/2*(3-sqrt(37)))*(x+1/2*(3+sqrt(37)))
+--E 266
+
+--S 267 of 801
+r0:=-7*x+3/2*x^2+1/3*x^3
+--E 267
+
+--S 268 of 801
+a0:=integrate(t0,x)
+--E 268
+
+--S 269 of 801
+m0:=a0-r0
+--E 269
+
+--S 270 of 801
+d0:=normalize(D(m0,x))
+--E 270
+
+)clear all
+
+--S 271 of 801
+t0:=(-4+x)/((1+x^(1/3))*sqrt(x))
+--E 271
+
+--S 272 of 801
+r0:=-30*x^(1/6)-6/5*x^(5/6)+6/7*x^(7/6)+30*atan(x^(1/6))+2*sqrt(x)
+--E 272
+
+--S 273 of 801
+a0:=integrate(t0,x)
+--E 273
+
+--S 274 of 801
+m0:=a0-r0
+--E 274
+
+--S 275 of 801
+d0:=normalize(D(m0,x))
+--E 275
+
+)clear all
+
+--S 276 of 801
+t0:=(1+sqrt(x))/(x^(5/6)+x^(7/6))
+--E 276
+
+--S 277 of 801
+r0:=3*x^(1/3)+6*atan(x^(1/6))-3*log(1+x^(1/3))
+--E 277
+
+--S 278 of 801
+a0:=integrate(t0,x)
+--E 278
+
+--S 279 of 801
+m0:=a0-r0
+--E 279
+
+--S 280 of 801
+d0:=normalize(D(m0,x))
+--E 280
+
+)clear all
+
+--S 281 of 801
+t0:=(1+sqrt(x))/((1+x^(1/3))*sqrt(x))
+--E 281
+
+--S 282 of 801
+r0:=6*x^(1/6)-3*x^(1/3)+3/2*x^(2/3)-6*atan(x^(1/6))+3*log(1+x^(1/3))
+--E 282
+
+--S 283 of 801
+a0:=integrate(t0,x)
+--E 283
+
+--S 284 of 801
+m0:=a0-r0
+--E 284
+
+--S 285 of 801
+d0:=normalize(D(m0,x))
+--E 285
+
+)clear all
+
+--S 286 of 801
+t0:=sqrt(2+b/x^2)/(b+2*x^2)
+--E 286
+
+--S 287 of 801
+r0:=-asinh(sqrt(b)/(x*sqrt(2)))/sqrt(b)
+--E 287
+
+--S 288 of 801
+a0:=integrate(t0,x)
+--E 288
+
+--S 289 of 801
+m0:=a0-r0
+--E 289
+
+--S 290 of 801
+d0:=normalize(D(m0,x))
+--E 290
+
+)clear all
+
+--S 291 of 801
+t0:=sqrt(2-b/x^2)/(-b+2*x^2)
+--E 291
+
+--S 292 of 801
+r0:=-asin(sqrt(b)/(x*sqrt(2)))/sqrt(b)
+--E 292
+
+--S 293 of 801
+a0:=integrate(t0,x)
+--E 293
+
+--S 294 of 801
+m0:=a0-r0
+--E 294
+
+--S 295 of 801
+d0:=normalize(D(m0,x))
+--E 295
+
+)clear all
+
+--S 296 of 801
+t0:=1/(sqrt(x)+sqrt(1+x))
+--E 296
+
+--S 297 of 801
+r0:=-2/3*x^(3/2)+2/3*(1+x)^(3/2)
+--E 297
+
+--S 298 of 801
+a0:=integrate(t0,x)
+--E 298
+
+--S 299 of 801
+m0:=a0-r0
+--E 299
+
+--S 300 of 801
+d0:=normalize(D(m0,x))
+--E 300
+
+)clear all
+
+--S 301 of 801
+t0:=1/(sqrt(-1+x)+sqrt(1+x))
+--E 301
+
+--S 302 of 801
+r0:=-1/3*(-1+x)^(3/2)+1/3*(1+x)^(3/2)
+--E 302
+
+--S 303 of 801
+a0:=integrate(t0,x)
+--E 303
+
+--S 304 of 801
+m0:=a0-r0
+--E 304
+
+--S 305 of 801
+d0:=normalize(D(m0,x))
+--E 305
+
+)clear all
+
+--S 306 of 801
+t0:=(x^(1/6)+(x^3)^(1/5))/sqrt(x)
+--E 306
+
+--S 307 of 801
+r0:=3/2*x^(2/3)+10/11*(x^3)^(1/5)*sqrt(x)
+--E 307
+
+--S 308 of 801
+--a0:=integrate(t0,x)
+--E 308
+
+--S 309 of 801
+--m0:=a0-r0
+--E 309
+
+--S 310 of 801
+--d0:=normalize(D(m0,x))
+--E 310
+
+)clear all
+
+--S 311 of 801
+t0:=(2+x)/sqrt(4*x-x^2)
+--E 311
+
+--S 312 of 801
+r0:=-4*asin(1-1/2*x)-sqrt(4*x-x^2)
+--E 312
+
+--S 313 of 801
+a0:=integrate(t0,x)
+--E 313
+
+--S 314 of 801
+m0:=a0-r0
+--E 314
+
+--S 315 of 801
+d0:=normalize(D(m0,x))
+--E 315
+
+)clear all
+
+--S 316 of 801
+t0:=(3+x)/(6*x+x^2)^(1/3)
+--E 316
+
+--S 317 of 801
+r0:=3/4*(6*x+x^2)^(2/3)
+--E 317
+
+--S 318 of 801
+a0:=integrate(t0,x)
+--E 318
+
+--S 319 of 801
+m0:=a0-r0
+--E 319
+
+--S 320 of 801
+d0:=normalize(D(m0,x))
+--E 320
+
+)clear all
+
+--S 321 of 801
+t0:=(4+x)/(6*x-x^2)^(3/2)
+--E 321
+
+--S 322 of 801
+r0:=1/9*(-12+7*x)/sqrt(6*x-x^2)
+--E 322
+
+--S 323 of 801
+a0:=integrate(t0,x)
+--E 323
+
+--S 324 of 801
+m0:=a0-r0
+--E 324
+
+--S 325 of 801
+d0:=normalize(D(m0,x))
+--E 325
+
+)clear all
+
+--S 326 of 801
+t0:=1/((1+x)*sqrt(2*x+x^2))
+--E 326
+
+--S 327 of 801
+r0:=atan(sqrt(2*x+x^2))
+--E 327
+
+--S 328 of 801
+a0:=integrate(t0,x)
+--E 328
+
+--S 329 of 801
+m0:=a0-r0
+--E 329
+
+--S 330 of 801
+d0:=normalize(D(m0,x))
+--E 330
+
+)clear all
+
+--S 331 of 801
+t0:=1/((1+2*x)*sqrt(x+x^2))
+--E 331
+
+--S 332 of 801
+r0:=atan(2*sqrt(x+x^2))
+--E 332
+
+--S 333 of 801
+a0:=integrate(t0,x)
+--E 333
+
+--S 334 of 801
+m0:=a0-r0
+--E 334
+
+--S 335 of 801
+d0:=normalize(D(m0,x))
+--E 335
+
+)clear all
+
+--S 336 of 801
+t0:=(-1+x)/sqrt(2*x-x^2)
+--E 336
+
+--S 337 of 801
+r0:=-sqrt(2*x-x^2)
+--E 337
+
+--S 338 of 801
+a0:=integrate(t0,x)
+--E 338
+
+--S 339 of 801
+m0:=a0-r0
+--E 339
+
+--S 340 of 801
+d0:=normalize(D(m0,x))
+--E 340
+
+)clear all
+
+--S 341 of 801
+t0:=sqrt(x-x^2)/(1+x)
+--E 341
+
+--S 342 of 801
+r0:=-3/2*asin(1-2*x)+atan(1/2*(1-3*x)/(sqrt(2)*sqrt(x-x^2)))*sqrt(2)+sqrt(x-x^2)
+--E 342
+
+--S 343 of 801
+a0:=integrate(t0,x)
+--E 343
+
+--S 344 of 801
+m0:=a0-r0
+--E 344
+
+--S 345 of 801
+d0:=normalize(D(m0,x))
+--E 345
+
+)clear all
+
+--S 346 of 801
+t0:=sqrt(x^(1/4)+x)
+--E 346
+
+--S 347 of 801
+r0:=-1/3*atanh(sqrt(x)/sqrt(x^(1/4)+x))+1/3*x^(1/4)*sqrt(x^(1/4)+x)+2/3*x*sqrt(x^(1/4)+x)
+--E 347
+
+--S 348 of 801
+--a0:=integrate(t0,x)
+--E 348
+
+--S 349 of 801
+--m0:=a0-r0
+--E 349
+
+--S 350 of 801
+--d0:=normalize(D(m0,x))
+--E 350
+
+)clear all
+
+--S 351 of 801
+t0:=sqrt(x+x^(3/2))
+--E 351
+
+--S 352 of 801
+r0:=32/105*(x+x^(3/2))^(3/2)/x^(3/2)-16/35*(x+x^(3/2))^(3/2)/x+4/7*(x+x^(3/2))^(3/2)/sqrt(x)
+--E 352
+
+--S 353 of 801
+a0:=integrate(t0,x)
+--E 353
+
+--S 354 of 801
+m0:=a0-r0
+--E 354
+
+--S 355 of 801
+d0:=normalize(D(m0,x))
+--E 355
+
+)clear all
+
+--S 356 of 801
+t0:=x*sqrt(x+x^(3/2))
+--E 356
+
+--S 357 of 801
+r0:=-32/99*(x+x^(3/2))^(3/2)+512/3465*(x+x^(3/2))^(3/2)/x^(3/2)-256/1155*(x+x^(3/2))^(3/2)/x+64/231*(x+x^(3/2))^(3/2)/sqrt(x)+4/11*(x+x^(3/2))^(3/2)*sqrt(x)
+--E 357
+
+--S 358 of 801
+a0:=integrate(t0,x)
+--E 358
+
+--S 359 of 801
+m0:=a0-r0
+--E 359
+
+--S 360 of 801
+d0:=normalize(D(m0,x))
+--E 360
+
+)clear all
+
+--S 361 of 801
+t0:=(1-x^2)*sqrt(1/(2-x^2))
+--E 361
+
+--S 362 of 801
+r0:=1/2*x/sqrt(1/(2-x^2))
+--E 362
+
+--S 363 of 801
+a0:=integrate(t0,x)
+--E 363
+
+--S 364 of 801
+m0:=a0-r0
+--E 364
+
+--S 365 of 801
+d0:=normalize(D(m0,x))
+--E 365
+
+)clear all
+
+--S 366 of 801
+t0:=sqrt(x^2+x^3-x^4)
+--E 366
+
+--S 367 of 801
+r0:=-1/8*(1-2*x)*sqrt(x^2+x^3-x^4)/x-1/3*(1+x-x^2)*sqrt(x^2+x^3-x^4)/x-5/16*asin((1-2*x)/sqrt(5))*sqrt(x^2+x^3-x^4)/(x*sqrt(1+x-x^2))
+--E 367
+
+--S 368 of 801
+a0:=integrate(t0,x)
+--E 368
+
+--S 369 of 801
+m0:=a0-r0
+--E 369
+
+--S 370 of 801
+d0:=normalize(D(m0,x))
+--E 370
+
+)clear all
+
+--S 371 of 801
+t0:=1/sqrt((a^2+x^2)^3)
+--E 371
+
+--S 372 of 801
+r0:=x*(a^2+x^2)/(a^2*sqrt((a^2+x^2)^3))
+--E 372
+
+--S 373 of 801
+a0:=integrate(t0,x)
+--E 373
+
+--S 374 of 801
+m0:=a0-r0
+--E 374
+
+--S 375 of 801
+d0:=normalize(D(m0,x))
+--E 375
+
+)clear all
+
+--S 376 of 801
+t0:=sqrt(x)/(1+x+sqrt(x))
+--E 376
+
+--S 377 of 801
+r0:=-log(1+x+sqrt(x))-2*atan((1+2*sqrt(x))/sqrt(3))/sqrt(3)+2*sqrt(x)
+--E 377
+
+--S 378 of 801
+a0:=integrate(t0,x)
+--E 378
+
+--S 379 of 801
+m0:=a0-r0
+--E 379
+
+--S 380 of 801
+d0:=normalize(D(m0,x))
+--E 380
+
+)clear all
+
+--S 381 of 801
+t0:=x/(1+x+sqrt(x))
+--E 381
+
+--S 382 of 801
+r0:=x+4*atan((1+2*sqrt(x))/sqrt(3))/sqrt(3)-2*sqrt(x)
+--E 382
+
+--S 383 of 801
+a0:=integrate(t0,x)
+--E 383
+
+--S 384 of 801
+m0:=a0-r0
+--E 384
+
+--S 385 of 801
+d0:=normalize(D(m0,x))
+--E 385
+
+)clear all
+
+--S 386 of 801
+t0:=1/(sqrt(x)*(1+x+sqrt(x))^(7/2))
+--E 386
+
+--S 387 of 801
+r0:=4/15*(1+2*sqrt(x))/(1+x+sqrt(x))^(5/2)+64/135*(1+2*sqrt(x))/(1+x+sqrt(x))^(3/2)+512/405*(1+2*sqrt(x))/sqrt(1+x+sqrt(x))
+--E 387
+
+--S 388 of 801
+a0:=integrate(t0,x)
+--E 388
+
+--S 389 of 801
+m0:=a0-r0
+--E 389
+
+--S 390 of 801
+d0:=normalize(D(m0,x))
+--E 390
+
+)clear all
+
+--S 391 of 801
+t0:=(-1+x)/(1+sqrt(1+x^2))
+--E 391
+
+--S 392 of 801
+r0:=(-1)/x-asinh(x)-log(1+sqrt(1+x^2))+sqrt(1+x^2)+sqrt(1+x^2)/x
+--E 392
+
+--S 393 of 801
+a0:=integrate(t0,x)
+--E 393
+
+--S 394 of 801
+m0:=a0-r0
+--E 394
+
+--S 395 of 801
+d0:=normalize(D(m0,x))
+--E 395
+
+)clear all
+
+--S 396 of 801
+t0:=(-x+x^3)/sqrt(-2+x^2)
+--E 396
+
+--S 397 of 801
+r0:=1/3*(-2+x^2)^(3/2)+sqrt(-2+x^2)
+--E 397
+
+--S 398 of 801
+a0:=integrate(t0,x)
+--E 398
+
+--S 399 of 801
+m0:=a0-r0
+--E 399
+
+--S 400 of 801
+d0:=normalize(D(m0,x))
+--E 400
+
+)clear all
+
+--S 401 of 801
+t0:=(x-x^2)/sqrt(1-x^2)
+--E 401
+
+--S 402 of 801
+r0:=-1/2*asin(x)-1/2*sqrt(1-x^2)-1/2*(1-x)*sqrt(1-x^2)
+--E 402
+
+--S 403 of 801
+a0:=integrate(t0,x)
+--E 403
+
+--S 404 of 801
+m0:=a0-r0
+--E 404
+
+--S 405 of 801
+d0:=normalize(D(m0,x))
+--E 405
+
+)clear all
+
+--S 406 of 801
+t0:=1/((1+x)^(2/3)*(-1+x^2)^(2/3))
+--E 406
+
+--S 407 of 801
+r0:=3/2*(-1+x^2)^(1/3)/(1+x)^(2/3)
+--E 407
+
+--S 408 of 801
+a0:=integrate(t0,x)
+--E 408
+
+--S 409 of 801
+m0:=a0-r0
+--E 409
+
+--S 410 of 801
+d0:=normalize(D(m0,x))
+--E 410
+
+)clear all
+
+--S 411 of 801
+t0:=x*sqrt(1-x^2)/(1+x)
+--E 411
+
+--S 412 of 801
+r0:=-1/2*(1-x^2)^(3/2)/(1+x)-1/2*asin(x)-1/2*sqrt(1-x^2)
+--E 412
+
+--S 413 of 801
+a0:=integrate(t0,x)
+--E 413
+
+--S 414 of 801
+m0:=a0-r0
+--E 414
+
+--S 415 of 801
+d0:=normalize(D(m0,x))
+--E 415
+
+)clear all
+
+--S 416 of 801
+t0:=x*(1+x)^2/sqrt(1-x^2)
+--E 416
+
+--S 417 of 801
+r0:=asin(x)-sqrt(1-x^2)-1/3*(1+x)*sqrt(1-x^2)-1/3*(1+x)^2*sqrt(1-x^2)
+--E 417
+
+--S 418 of 801
+a0:=integrate(t0,x)
+--E 418
+
+--S 419 of 801
+m0:=a0-r0
+--E 419
+
+--S 420 of 801
+d0:=normalize(D(m0,x))
+--E 420
+
+)clear all
+
+--S 421 of 801
+t0:=(-1+x^4)/(1+x^4)^(3/2)
+--E 421
+
+--S 422 of 801
+r0:=-x/sqrt(1+x^4)
+--E 422
+
+--S 423 of 801
+a0:=integrate(t0,x)
+--E 423
+
+--S 424 of 801
+m0:=a0-r0
+--E 424
+
+--S 425 of 801
+d0:=normalize(D(m0,x))
+--E 425
+
+)clear all
+
+--S 426 of 801
+t0:=(1-x^6)^(2/3)+(1-x^6)^(2/3)/x^6
+--E 426
+
+--S 427 of 801
+r0:=-1/5*(1-x^6)^(2/3)/x^5+1/5*x*(1-x^6)^(2/3)
+--E 427
+
+--S 428 of 801
+a0:=integrate(t0,x)
+--E 428
+
+--S 429 of 801
+m0:=a0-r0
+--E 429
+
+--S 430 of 801
+d0:=normalize(D(m0,x))
+--E 430
+
+)clear all
+
+--S 431 of 801
+t0:=1/2*x^(-1+m)*(2*a*m+b*(2*m-n)*x^n)/(a+b*x^n)^(3/2)
+--E 431
+
+--S 432 of 801
+r0:=x^m/sqrt(a+b*x^n)
+--E 432
+
+--S 433 of 801
+a0:=integrate(t0,x)
+--E 433
+
+--S 434 of 801
+m0:=a0-r0
+--E 434
+
+--S 435 of 801
+d0:=normalize(D(m0,x))
+--E 435
+
+)clear all
+
+--S 436 of 801
+t0:=(4+3*x^2+2*x^3)/(1+x)^4
+--E 436
+
+--S 437 of 801
+r0:=(-5/3)/(1+x)^3+3/(1+x)+2*log(1+x)
+--E 437
+
+--S 438 of 801
+a0:=integrate(t0,x)
+--E 438
+
+--S 439 of 801
+m0:=a0-r0
+--E 439
+
+--S 440 of 801
+d0:=normalize(D(m0,x))
+--E 440
+
+)clear all
+
+--S 441 of 801
+t0:=x/((1+x)^2*(1+x^2))
+--E 441
+
+--S 442 of 801
+r0:=1/2/(1+x)+1/2*atan(x)
+--E 442
+
+--S 443 of 801
+a0:=integrate(t0,x)
+--E 443
+
+--S 444 of 801
+m0:=a0-r0
+--E 444
+
+--S 445 of 801
+d0:=normalize(D(m0,x))
+--E 445
+
+)clear all
+
+--S 446 of 801
+t0:=(7-2*x+3*x^2-x^3+x^4)/(2+x)
+--E 446
+
+--S 447 of 801
+r0:=-20*x+9/2*x^2-x^3+1/4*x^4+47*log(2+x)
+--E 447
+
+--S 448 of 801
+a0:=integrate(t0,x)
+--E 448
+
+--S 449 of 801
+m0:=a0-r0
+--E 449
+
+--S 450 of 801
+d0:=normalize(D(m0,x))
+--E 450
+
+)clear all
+
+--S 451 of 801
+t0:=(-1+x^3)/(-1+x)
+--E 451
+
+--S 452 of 801
+r0:=x+1/2*x^2+1/3*x^3
+--E 452
+
+--S 453 of 801
+a0:=integrate(t0,x)
+--E 453
+
+--S 454 of 801
+m0:=a0-r0
+--E 454
+
+--S 455 of 801
+d0:=normalize(D(m0,x))
+--E 455
+
+)clear all
+
+--S 456 of 801
+t0:=(2+2*x)/((-1+x)^3*(1+x^2))
+--E 456
+
+--S 457 of 801
+r0:=(-1)/(1-x)^2+1/(-1+x)+atan(x)
+--E 457
+
+--S 458 of 801
+a0:=integrate(t0,x)
+--E 458
+
+--S 459 of 801
+m0:=a0-r0
+--E 459
+
+--S 460 of 801
+d0:=normalize(D(m0,x))
+--E 460
+
+)clear all
+
+--S 461 of 801
+t0:=(x-2*x^3)/sqrt(2+3*x)
+--E 461
+
+--S 462 of 801
+r0:=-10/81*(2+3*x)^(3/2)+8/135*(2+3*x)^(5/2)-4/567*(2+3*x)^(7/2)-4/81*sqrt(2+3*x)
+--E 462
+
+--S 463 of 801
+a0:=integrate(t0,x)
+--E 463
+
+--S 464 of 801
+m0:=a0-r0
+--E 464
+
+--S 465 of 801
+d0:=normalize(D(m0,x))
+--E 465
+
+)clear all
+
+--S 466 of 801
+t0:=1/((1+x)^(1/4)+sqrt(1+x))
+--E 466
+
+--S 467 of 801
+r0:=-4*(1+x)^(1/4)+4*log(1+(1+x)^(1/4))+2*sqrt(1+x)
+--E 467
+
+--S 468 of 801
+a0:=integrate(t0,x)
+--E 468
+
+--S 469 of 801
+m0:=a0-r0
+--E 469
+
+--S 470 of 801
+d0:=normalize(D(m0,x))
+--E 470
+
+)clear all
+
+--S 471 of 801
+t0:=(1+2*x)/sqrt(x+x^2)
+--E 471
+
+--S 472 of 801
+r0:=2*sqrt(x+x^2)
+--E 472
+
+--S 473 of 801
+a0:=integrate(t0,x)
+--E 473
+
+--S 474 of 801
+m0:=a0-r0
+--E 474
+
+--S 475 of 801
+d0:=normalize(D(m0,x))
+--E 475
+
+)clear all
+
+--S 476 of 801
+t0:=1/2/((1+x)*sqrt(x))
+--E 476
+
+--S 477 of 801
+r0:=atan(sqrt(x))
+--E 477
+
+--S 478 of 801
+a0:=integrate(t0,x)
+--E 478
+
+--S 479 of 801
+m0:=a0-r0
+--E 479
+
+--S 480 of 801
+d0:=normalize(D(m0,x))
+--E 480
+
+)clear all
+
+--S 481 of 801
+t0:=1/(x*sqrt(6*x-x^2))
+--E 481
+
+--S 482 of 801
+r0:=-1/3*sqrt(6*x-x^2)/x
+--E 482
+
+--S 483 of 801
+a0:=integrate(t0,x)
+--E 483
+
+--S 484 of 801
+m0:=a0-r0
+--E 484
+
+--S 485 of 801
+d0:=normalize(D(m0,x))
+--E 485
+
+)clear all
+
+--S 486 of 801
+t0:=sqrt(x)*(1+sqrt(x))
+--E 486
+
+--S 487 of 801
+r0:=2/3*x^(3/2)+1/2*x^2
+--E 487
+
+--S 488 of 801
+a0:=integrate(t0,x)
+--E 488
+
+--S 489 of 801
+m0:=a0-r0
+--E 489
+
+--S 490 of 801
+d0:=normalize(D(m0,x))
+--E 490
+
+)clear all
+
+--S 491 of 801
+t0:=(1-sqrt(x))/x^(1/3)
+--E 491
+
+--S 492 of 801
+r0:=3/2*x^(2/3)-6/7*x^(7/6)
+--E 492
+
+--S 493 of 801
+a0:=integrate(t0,x)
+--E 493
+
+--S 494 of 801
+m0:=a0-r0
+--E 494
+
+--S 495 of 801
+d0:=normalize(D(m0,x))
+--E 495
+
+)clear all
+
+--S 496 of 801
+t0:=sqrt(x)/(1+x^(1/3))
+--E 496
+
+--S 497 of 801
+r0:=-6*x^(1/6)-6/5*x^(5/6)+6/7*x^(7/6)+6*atan(x^(1/6))+2*sqrt(x)
+--E 497
+
+--S 498 of 801
+a0:=integrate(t0,x)
+--E 498
+
+--S 499 of 801
+m0:=a0-r0
+--E 499
+
+--S 500 of 801
+d0:=normalize(D(m0,x))
+--E 500
+
+)clear all
+
+--S 501 of 801
+t0:=(1+sqrt(x))^(1/3)/x
+--E 501
+
+--S 502 of 801
+r0:=2*log(1-(1+sqrt(x))^(1/3))-log(1+(1+sqrt(x))^(1/3)+(1+sqrt(x))^(2/3))-2*atan((1+2*(1+sqrt(x))^(1/3))/sqrt(3))*sqrt(3)+6*(1+sqrt(x))^(1/3)
+--E 502
+
+--S 503 of 801
+a0:=integrate(t0,x)
+--E 503
+
+--S 504 of 801
+m0:=a0-r0
+--E 504
+
+--S 505 of 801
+d0:=normalize(D(m0,x))
+--E 505
+
+)clear all
+
+--S 506 of 801
+t0:=1-sqrt(x)
+--E 506
+
+--S 507 of 801
+r0:=x-2/3*x^(3/2)
+--E 507
+
+--S 508 of 801
+a0:=integrate(t0,x)
+--E 508
+
+--S 509 of 801
+m0:=a0-r0
+--E 509
+
+--S 510 of 801
+d0:=normalize(D(m0,x))
+--E 510
+
+)clear all
+
+--S 511 of 801
+t0:=1-x^(1/4)
+--E 511
+
+--S 512 of 801
+r0:=x-4/5*x^(5/4)
+--E 512
+
+--S 513 of 801
+a0:=integrate(t0,x)
+--E 513
+
+--S 514 of 801
+m0:=a0-r0
+--E 514
+
+--S 515 of 801
+d0:=normalize(D(m0,x))
+--E 515
+
+)clear all
+
+--S 516 of 801
+t0:=(1-sqrt(x))/(1+x^(1/4))
+--E 516
+
+--S 517 of 801
+r0:=x-4/5*x^(5/4)
+--E 517
+
+--S 518 of 801
+a0:=integrate(t0,x)
+--E 518
+
+--S 519 of 801
+m0:=a0-r0
+--E 519
+
+--S 520 of 801
+d0:=normalize(D(m0,x))
+--E 520
+
+)clear all
+
+--S 521 of 801
+t0:=1/sqrt((a+b*x)*(c+d*x))
+--E 521
+
+--S 522 of 801
+r0:=atanh(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)*sqrt(a*c+(b*c+a*d)*x+b*d*x^2)))/(sqrt(b)*sqrt(d))
+--E 522
+
+--S 523 of 801
+a0:=integrate(t0,x)
+--E 523
+
+--S 524 of 801
+m0a:=a0.1-r0
+--E 524
+
+--S 525 of 801
+d0a:=normalize(D(m0a,x))
+--E 525
+
+--S 526 of 801
+m0b:=a0.2-r0
+--E 526
+
+--S 527 of 801
+d0b:=normalize(D(m0b,x))
+--E 527
+
+)clear all
+
+--S 528 of 801
+t0:=1/sqrt((a+b*x)*(c-d*x))
+--E 528
+
+--S 529 of 801
+r0:=-atan(1/2*(b*c-a*d-2*b*d*x)/(sqrt(b)*sqrt(d)*sqrt(a*c+(b*c-a*d)*x-b*d*x^2)))/(sqrt(b)*sqrt(d))
+--E 529
+
+--S 530 of 801
+a0:=integrate(t0,x)
+--E 530
+
+--S 531 of 801
+m0a:=a0.1-r0
+--E 531
+
+--S 532 of 801
+d0a:=normalize(D(m0a,x))
+--E 532
+
+--S 533 of 801
+m0b:=a0.2-r0
+--E 533
+
+--S 534 of 801
+d0b:=normalize(D(m0b,x))
+--E 534
+
+)clear all
+
+--S 535 of 801
+t0:=1/((1-x^2)*sqrt(x))
+--E 535
+
+--S 536 of 801
+r0:=atan(sqrt(x))+atanh(sqrt(x))
+--E 536
+
+--S 537 of 801
+a0:=integrate(t0,x)
+--E 537
+
+--S 538 of 801
+m0:=a0-r0
+--E 538
+
+--S 539 of 801
+d0:=normalize(D(m0,x))
+--E 539
+
+)clear all
+
+--S 540 of 801
+t0:=sqrt(x)/(x-x^3)
+--E 540
+
+--S 541 of 801
+r0:=atan(sqrt(x))+atanh(sqrt(x))
+--E 541
+
+--S 542 of 801
+a0:=integrate(t0,x)
+--E 542
+
+--S 543 of 801
+m0:=a0-r0
+--E 543
+
+--S 544 of 801
+d0:=normalize(D(m0,x))
+--E 544
+
+)clear all
+
+--S 545 of 801
+t0:=x/(2+x^2-sqrt(3)+x*(1+sqrt(3)))
+--E 545
+
+--S 546 of 801
+r0:=1/2*log(2+x^2-sqrt(3)+x*(1+sqrt(3)))+atanh((1+2*x+sqrt(3))/sqrt(2*(-2+3*sqrt(3))))*sqrt(1/23*(13+8*sqrt(3)))
+--E 546
+
+--S 547 of 801
+a0:=integrate(t0,x)
+--E 547
+
+--S 548 of 801
+m0:=a0-r0
+--E 548
+
+--S 549 of 801
+d0:=normalize(D(m0,x))
+--E 549
+
+)clear all
+
+--S 550 of 801
+t0:=sqrt(x^2+x^3)
+--E 550
+
+--S 551 of 801
+r0:=-4/15*(x^2+x^3)^(3/2)/x^3+2/5*(x^2+x^3)^(3/2)/x^2
+--E 551
+
+--S 552 of 801
+a0:=integrate(t0,x)
+--E 552
+
+--S 553 of 801
+m0:=a0-r0
+--E 553
+
+--S 554 of 801
+d0:=normalize(D(m0,x))
+--E 554
+
+)clear all
+
+--S 555 of 801
+t0:=1/((1+x)*sqrt(2*x+x^2))
+--E 555
+
+--S 556 of 801
+r0:=atan(sqrt(2*x+x^2))
+--E 556
+
+--S 557 of 801
+a0:=integrate(t0,x)
+--E 557
+
+--S 558 of 801
+m0:=a0-r0
+--E 558
+
+--S 559 of 801
+d0:=normalize(D(m0,x))
+--E 559
+
+)clear all
+
+--S 560 of 801
+t0:=sqrt(x)*sqrt(1-x-sqrt(x))
+--E 560
+
+--S 561 of 801
+r0:=45/64*asin((1+2*sqrt(x))/sqrt(5))+5/12*(1-x-sqrt(x))^(3/2)-1/2*(1-x-sqrt(x))^(3/2)*sqrt(x)+9/32*(1+2*sqrt(x))*sqrt(1-x-sqrt(x))
+--E 561
+
+--S 562 of 801
+a0:=integrate(t0,x)
+--E 562
+
+--S 563 of 801
+m0:=a0-r0
+--E 563
+
+--S 564 of 801
+d0:=normalize(D(m0,x))
+--E 564
+
+)clear all
+
+--S 565 of 801
+t0:=(1+sqrt(-3+x))^(1/3)
+--E 565
+
+--S 566 of 801
+r0:=-3/2*(1+sqrt(-3+x))^(4/3)+6/7*(1+sqrt(-3+x))^(7/3)
+--E 566
+
+--S 567 of 801
+a0:=integrate(t0,x)
+--E 567
+
+--S 568 of 801
+m0:=a0-r0
+--E 568
+
+--S 569 of 801
+d0:=normalize(D(m0,x))
+--E 569
+
+)clear all
+
+--S 570 of 801
+t0:=1/sqrt(3+sqrt(-1+2*x))
+--E 570
+
+--S 571 of 801
+r0:=2/3*(3+sqrt(-1+2*x))^(3/2)-6*sqrt(3+sqrt(-1+2*x))
+--E 571
+
+--S 572 of 801
+a0:=integrate(t0,x)
+--E 572
+
+--S 573 of 801
+m0:=a0-r0
+--E 573
+
+--S 574 of 801
+d0:=normalize(D(m0,x))
+--E 574
+
+)clear all
+
+--S 575 of 801
+t0:=sqrt(1-x)/(1+sqrt(x))
+--E 575
+
+--S 576 of 801
+r0:=-asin(sqrt(x))-sqrt(1-x)-(1-x)^(3/2)/(1+sqrt(x))
+--E 576
+
+--S 577 of 801
+--a0:=integrate(t0,x)
+--E 577
+
+--S 578 of 801
+--m0:=a0-r0
+--E 578
+
+--S 579 of 801
+--d0:=normalize(D(m0,x))
+--E 579
+
+)clear all
+
+--S 580 of 801
+t0:=sqrt(1-x)/(1-sqrt(x))
+--E 580
+
+--S 581 of 801
+r0:=asin(sqrt(x))-sqrt(1-x)-(1-x)^(3/2)/(1-sqrt(x))
+--E 581
+
+--S 582 of 801
+--a0:=integrate(t0,x)
+--E 582
+
+--S 583 of 801
+--m0:=a0-r0
+--E 583
+
+--S 584 of 801
+--d0:=normalize(D(m0,x))
+--E 584
+
+)clear all
+
+--S 585 of 801
+t0:=x/(x-sqrt(1+x^2))
+--E 585
+
+--S 586 of 801
+r0:=-1/3*x^3-1/3*(1+x^2)^(3/2)
+--E 586
+
+--S 587 of 801
+a0:=integrate(t0,x)
+--E 587
+
+--S 588 of 801
+m0:=a0-r0
+--E 588
+
+--S 589 of 801
+d0:=normalize(D(m0,x))
+--E 589
+
+)clear all
+
+--S 590 of 801
+t0:=x/(x-sqrt(1-x^2))
+--E 590
+
+--S 591 of 801
+r0:=1/2*x-1/2*atanh(x*sqrt(2))/sqrt(2)-1/2*atanh(sqrt(2)*sqrt(1-x^2))/sqrt(2)+1/2*sqrt(1-x^2)
+--E 591
+
+--S 592 of 801
+a0:=integrate(t0,x)
+--E 592
+
+--S 593 of 801
+m0:=a0-r0
+--E 593
+
+--S 594 of 801
+d0:=normalize(D(m0,x))
+--E 594
+
+)clear all
+
+--S 595 of 801
+t0:=x/(x-sqrt(1+2*x^2))
+--E 595
+
+--S 596 of 801
+r0:=-x+atan(x)+atan(sqrt(1+2*x^2))-sqrt(1+2*x^2)
+--E 596
+
+--S 597 of 801
+a0:=integrate(t0,x)
+--E 597
+
+--S 598 of 801
+m0:=a0-r0
+--E 598
+
+--S 599 of 801
+d0:=normalize(D(m0,x))
+--E 599
+
+)clear all
+
+--S 600 of 801
+t0:=1/(sqrt(-1+x)*sqrt(1+x)*sqrt(-1+2*x^2))
+--E 600
+
+--S 601 of 801
+--r0:=-%i*elliptic_f(%i*acosh(x),2)
+--E 601
+
+--S 602 of 801
+--a0:=integrate(t0,x)
+--E 602
+
+--S 603 of 801
+--m0:=a0-r0
+--E 603
+
+--S 604 of 801
+--d0:=normalize(D(m0,x))
+--E 604
+
+)clear all
+
+--S 605 of 801
+t0:=x/sqrt(-71-96*x+10*x^2+x^4)
+--E 605
+
+--S 606 of 801
+r0:=-1/8*log(-10001-3124*x^2+1408*x^3-54*x^4+128*x^5-20*x^6-x^8+(781-528*x+27*x^2-80*x^3+15*x^4+x^6)*sqrt(-71-96*x+10*x^2+x^4))
+--E 606
+
+--S 607 of 801
+a0:=integrate(t0,x)
+--E 607
+
+--S 608 of 801
+m0:=a0-r0
+--E 608
+
+--S 609 of 801
+d0:=normalize(D(m0,x))
+--E 609
+
+)clear all
+
+--S 610 of 801
+t0:=sqrt(x)*sqrt(x+sqrt(x))
+--E 610
+
+--S 611 of 801
+r0:=-5/32*atanh(sqrt(x)/sqrt(x+sqrt(x)))+5/32*sqrt(x+sqrt(x))+1/12*x*sqrt(x+sqrt(x))+1/2*x^(3/2)*sqrt(x+sqrt(x))-5/48*sqrt(x)*sqrt(x+sqrt(x))
+--E 611
+
+--S 612 of 801
+a0:=integrate(t0,x)
+--E 612
+
+--S 613 of 801
+m0:=a0-r0
+--E 613
+
+--S 614 of 801
+d0:=normalize(D(m0,x))
+--E 614
+
+)clear all
+
+--S 615 of 801
+t0:=1/((1+x^4)*sqrt(-x^2+sqrt(1+x^4)))
+--E 615
+
+--S 616 of 801
+r0:=acot(sqrt(-x^2+sqrt(1+x^4))/x)
+--E 616
+
+--S 617 of 801
+a0:=integrate(t0,x)
+--E 617
+
+--S 618 of 801
+m0:=a0-r0
+--E 618
+
+--S 619 of 801
+d0:=normalize(D(m0,x))
+--E 619
+
+)clear all
+
+--S 620 of 801
+t0:=(1+x^(1/3))/(1+sqrt(x))
+--E 620
+
+--S 621 of 801
+r0:=-3*x^(1/3)+6/5*x^(5/6)-4*log(1+x^(1/6))-log(1-x^(1/6)+x^(1/3))-2*atan((1-2*x^(1/6))/sqrt(3))*sqrt(3)+2*sqrt(x)
+--E 621
+
+--S 622 of 801
+a0:=integrate(t0,x)
+--E 622
+
+--S 623 of 801
+m0:=a0-r0
+--E 623
+
+--S 624 of 801
+d0:=normalize(D(m0,x))
+--E 624
+
+)clear all
+
+--S 625 of 801
+t0:=(1+x^(1/3))/(1+x^(1/4))
+--E 625
+
+--S 626 of 801
+r0:=12*x^(1/12)+4*x^(1/4)-3*x^(1/3)+12/7*x^(7/12)+4/3*x^(3/4)-6/5*x^(5/6)+12/13*x^(13/12)-8*log(1+x^(1/12))-2*log(1-x^(1/12)+x^(1/6))+4*atan((1-2*x^(1/12))/sqrt(3))*sqrt(3)-2*sqrt(x)
+--E 626
+
+--S 627 of 801
+a0:=integrate(t0,x)
+--E 627
+
+--S 628 of 801
+m0:=a0-r0
+--E 628
+
+--S 629 of 801
+d0:=normalize(D(m0,x))
+--E 629
+
+)clear all
+
+--S 630 of 801
+t0:=x^2/(-1+x^2+sqrt(1-x^2))
+--E 630
+
+--S 631 of 801
+r0:=x+asin(x)
+--E 631
+
+--S 632 of 801
+a0:=integrate(t0,x)
+--E 632
+
+--S 633 of 801
+m0:=a0-r0
+--E 633
+
+--S 634 of 801
+d0:=normalize(D(m0,x))
+--E 634
+
+)clear all
+
+--S 635 of 801
+t0:=sqrt((1+x)/x)
+--E 635
+
+--S 636 of 801
+r0:=atanh(sqrt(1+1/x))+x*sqrt(1+1/x)
+--E 636
+
+--S 637 of 801
+a0:=integrate(t0,x)
+--E 637
+
+--S 638 of 801
+m0:=a0-r0
+--E 638
+
+--S 639 of 801
+d0:=normalize(D(m0,x))
+--E 639
+
+)clear all
+
+--S 640 of 801
+t0:=sqrt((1-x)/x)
+--E 640
+
+--S 641 of 801
+r0:=-atan(sqrt(-1+1/x))+x*sqrt(-1+1/x)
+--E 641
+
+--S 642 of 801
+a0:=integrate(t0,x)
+--E 642
+
+--S 643 of 801
+m0:=a0-r0
+--E 643
+
+--S 644 of 801
+d0:=normalize(D(m0,x))
+--E 644
+
+)clear all
+
+--S 645 of 801
+t0:=sqrt((-1+x)/x)
+--E 645
+
+--S 646 of 801
+r0a:=-asinh(sqrt(-1+x))+sqrt(-1+x)*sqrt(x)
+--E 646
+
+--S 647 of 801
+r0b:=-atanh(sqrt(1+(-1)/x))+x*sqrt(1+(-1)/x)
+--E 647
+
+--S 648 of 801
+a0:=integrate(t0,x)
+--E 648
+
+--S 649 of 801
+m0a:=a0-r0a
+--E 649
+
+--S 650 of 801
+d0a:=D(m0a,x)
+--E 650
+
+--S 651 of 801
+m0b:=a0-r0b
+--E 651
+
+--S 652 of 801
+d0b:=D(m0b,x)
+--E 652
+
+)clear all
+
+--S 653 of 801
+t0:=sqrt((1+x)/x)/x
+--E 653
+
+--S 654 of 801
+r0:=2*atanh(sqrt(1+1/x))-2*sqrt(1+1/x)
+--E 654
+
+--S 655 of 801
+a0:=integrate(t0,x)
+--E 655
+
+--S 656 of 801
+m0:=a0-r0
+--E 656
+
+--S 657 of 801
+d0:=normalize(D(m0,x))
+--E 657
+
+)clear all
+
+--S 658 of 801
+t0:=sqrt(x/(1+x))
+--E 658
+
+--S 659 of 801
+r0:=-asinh(sqrt(x))+sqrt(x)*sqrt(1+x)
+--E 659
+
+--S 660 of 801
+a0:=integrate(t0,x)
+--E 660
+
+--S 661 of 801
+m0:=a0-r0
+--E 661
+
+--S 662 of 801
+d0:=normalize(D(m0,x))
+--E 662
+
+)clear all
+
+--S 663 of 801
+t0:=1/sqrt((-1-x)/x)
+--E 663
+
+--S 664 of 801
+r0:=atan(sqrt(-1+(-1)/x))-x*sqrt(-1+(-1)/x)
+--E 664
+
+--S 665 of 801
+a0:=integrate(t0,x)
+--E 665
+
+--S 666 of 801
+m0:=a0-r0
+--E 666
+
+--S 667 of 801
+d0:=normalize(D(m0,x))
+--E 667
+
+)clear all
+
+--S 668 of 801
+t0:=sqrt((4-x)*x)
+--E 668
+
+--S 669 of 801
+r0:=-2*asin(1-1/2*x)-sqrt(4*x-x^2)+1/2*x*sqrt(4*x-x^2)
+--E 669
+
+--S 670 of 801
+a0:=integrate(t0,x)
+--E 670
+
+--S 671 of 801
+m0:=a0-r0
+--E 671
+
+--S 672 of 801
+d0:=normalize(D(m0,x))
+--E 672
+
+)clear all
+
+--S 673 of 801
+t0:=1/sqrt((1-x)*x)
+--E 673
+
+--S 674 of 801
+r0:=-asin(1-2*x)
+--E 674
+
+--S 675 of 801
+a0:=integrate(t0,x)
+--E 675
+
+--S 676 of 801
+m0:=a0-r0
+--E 676
+
+--S 677 of 801
+d0:=normalize(D(m0,x))
+--E 677
+
+)clear all
+
+--S 678 of 801
+t0:=x/(x*(2+x))^(3/2)
+--E 678
+
+--S 679 of 801
+r0:=x/sqrt(2*x+x^2)
+--E 679
+
+--S 680 of 801
+a0:=integrate(t0,x)
+--E 680
+
+--S 681 of 801
+m0:=a0-r0
+--E 681
+
+--S 682 of 801
+d0:=normalize(D(m0,x))
+--E 682
+
+)clear all
+
+--S 683 of 801
+t0:=1/(1-x^2+sqrt(5)+x^2*sqrt(5))
+--E 683
+
+--S 684 of 801
+r0:=1/2*atan(x*sqrt(2/(3+sqrt(5))))
+--E 684
+
+--S 685 of 801
+a0:=integrate(t0,x)
+--E 685
+
+--S 686 of 801
+m0:=a0-r0
+--E 686
+
+--S 687 of 801
+d0:=normalize(D(m0,x))
+--E 687
+
+)clear all
+
+--S 688 of 801
+t0:=1/(b*x+c*(d+e*x)^2)
+--E 688
+
+--S 689 of 801
+r0:=-2*atanh((b+2*c*d*e+2*c*e^2*x)/(sqrt(b)*sqrt(b+4*c*d*e)))/(sqrt(b)*sqrt(b+4*c*d*e))
+--E 689
+
+--S 690 of 801
+a0:=integrate(t0,x)
+--E 690
+
+--S 691 of 801
+m0a:=a0.1-r0
+--E 691
+
+--S 692 of 801
+d0a:=normalize(D(m0a,x))
+--E 692
+
+--S 693 of 801
+m0b:=a0.2-r0
+--E 693
+
+--S 694 of 801
+d0b:=normalize(D(m0b,x))
+--E 694
+
+)clear all
+
+--S 695 of 801
+t0:=1/(a+b*x+c*(d+e*x)^2)
+--E 695
+
+--S 696 of 801
+r0:=-2*atanh((b+2*c*d*e+2*c*e^2*x)/sqrt(b^2+4*b*c*d*e-4*a*c*e^2))/sqrt(b^2+4*b*c*d*e-4*a*c*e^2)
+--E 696
+
+--S 697 of 801
+a0:=integrate(t0,x)
+--E 697
+
+--S 698 of 801
+m0a:=a0.1-r0
+--E 698
+
+--S 699 of 801
+d0a:=normalize(D(m0a,x))
+--E 699
+
+--S 700 of 801
+m0b:=a0.2-r0
+--E 700
+
+--S 701 of 801
+d0b:=normalize(D(m0b,x))
+--E 701
+
+)clear all
+
+--S 702 of 801
+t0:=sqrt((b-x)*(-a+x))
+--E 702
+
+--S 703 of 801
+r0:=-1/8*(a-b)^2*atan(1/2*(a+b-2*x)/sqrt(-a*b+(a+b)*x-x^2))-1/4*(a+b-2*x)*sqrt(-a*b+(a+b)*x-x^2)
+--E 703
+
+--S 704 of 801
+a0:=integrate(t0,x)
+--E 704
+
+--S 705 of 801
+m0:=a0-r0
+--E 705
+
+--S 706 of 801
+d0:=normalize(D(m0,x))
+--E 706
+
+)clear all
+
+--S 707 of 801
+t0:=1/sqrt((b-x)*(-a+x))
+--E 707
+
+--S 708 of 801
+r0:=-atan(1/2*(a+b-2*x)/sqrt(-a*b+(a+b)*x-x^2))
+--E 708
+
+--S 709 of 801
+a0:=integrate(t0,x)
+--E 709
+
+--S 710 of 801
+m0:=a0-r0
+--E 710
+
+--S 711 of 801
+d0:=normalize(D(m0,x))
+--E 711
+
+)clear all
+
+--S 712 of 801
+t0:=sqrt((1-x^2)*(3+x^2))
+--E 712
+
+--S 713 of 801
+--r0:=-2*elliptic_e(asin(x),-1/3)/sqrt(3)+4*elliptic_f(asin(x),-1/3)/sqrt(3)+1/3*x*sqrt(3-2*x^2-x^4)
+--E 713
+
+--S 714 of 801
+--a0:=integrate(t0,x)
+--E 714
+
+--S 715 of 801
+--m0:=a0-r0
+--E 715
+
+--S 716 of 801
+--d0:=normalize(D(m0,x))
+--E 716
+
+)clear all
+
+--S 717 of 801
+t0:=1/sqrt((1-x^2)*(3+x^2))
+--E 717
+
+--S 718 of 801
+--r0:=elliptic_f(asin(x),-1/3)/sqrt(3)
+--E 718
+
+--S 719 of 801
+--a0:=integrate(t0,x)
+--E 719
+
+--S 720 of 801
+--m0:=a0-r0
+--E 720
+
+--S 721 of 801
+--d0:=normalize(D(m0,x))
+--E 721
+
+)clear all
+
+--S 722 of 801
+t0:=x^2/(1+(-1+x^2)^2)
+--E 722
+
+--S 723 of 801
+r0:=-1/2*atan((-2*x+sqrt(2*(1+sqrt(2))))/sqrt(2*(-1+sqrt(2))))*sqrt(1/2*(1+sqrt(2)))+1/2*atan((2*x+sqrt(2*(1+sqrt(2))))/sqrt(2*(-1+sqrt(2))))*sqrt(1/2*(1+sqrt(2)))+1/4*log(x^2+sqrt(2)-x*sqrt(2*(1+sqrt(2))))/sqrt(2*(1+sqrt(2)))-1/4*log(x^2+sqrt(2)+x*sqrt(2*(1+sqrt(2))))/sqrt(2*(1+sqrt(2)))
+--E 723
+
+--S 724 of 801
+a0:=integrate(t0,x)
+--E 724
+
+--S 725 of 801
+m0:=a0-r0
+--E 725
+
+--S 726 of 801
+d0:=normalize(D(m0,x))
+--E 726
+
+)clear all
+
+--S 727 of 801
+t0:=1/sqrt(a*x+b*x^2)
+--E 727
+
+--S 728 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 728
+
+--S 729 of 801
+a0:=integrate(t0,x)
+--E 729
+
+--S 730 of 801
+m0a:=a0.1-r0
+--E 730
+
+--S 731 of 801
+d0a:=normalize(D(m0a,x))
+--E 731
+
+--S 732 of 801
+m0b:=a0.2-r0
+--E 732
+
+--S 733 of 801
+d0b:=normalize(D(m0b,x))
+--E 733
+
+)clear all
+
+--S 734 of 801
+t0:=1/sqrt(x*(a+b*x))
+--E 734
+
+--S 735 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 735
+
+--S 736 of 801
+a0:=integrate(t0,x)
+--E 736
+
+--S 737 of 801
+m0a:=a0.1-r0
+--E 737
+
+--S 738 of 801
+d0a:=normalize(D(m0a,x))
+--E 738
+
+--S 739 of 801
+m0b:=a0.2-r0
+--E 739
+
+--S 740 of 801
+d0b:=normalize(D(m0b,x))
+--E 740
+
+)clear all
+
+--S 741 of 801
+t0:=1/sqrt((b+a/x)*x^2)
+--E 741
+
+--S 742 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 742
+
+--S 743 of 801
+a0:=integrate(t0,x)
+--E 743
+
+--S 744 of 801
+m0a:=a0.1-r0
+--E 744
+
+--S 745 of 801
+d0a:=normalize(D(m0a,x))
+--E 745
+
+--S 746 of 801
+m0b:=a0.2-r0
+--E 746
+
+--S 747 of 801
+d0b:=normalize(D(m0b,x))
+--E 747
+
+)clear all
+
+--S 748 of 801
+t0:=1/sqrt((a/x^2+b/x)*x^3)
+--E 748
+
+--S 749 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 749
+
+--S 750 of 801
+a0:=integrate(t0,x)
+--E 750
+
+--S 751 of 801
+m0a:=a0.1-r0
+--E 751
+
+--S 752 of 801
+d0a:=normalize(D(m0a,x))
+--E 752
+
+--S 753 of 801
+m0b:=a0.2-r0
+--E 753
+
+--S 754 of 801
+d0b:=normalize(D(m0b,x))
+--E 754
+
+)clear all
+
+--S 755 of 801
+t0:=1/sqrt((a*x^2+b*x^3)/x)
+--E 755
+
+--S 756 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 756
+
+--S 757 of 801
+a0:=integrate(t0,x)
+--E 757
+
+--S 758 of 801
+m0a:=a0.1-r0
+--E 758
+
+--S 759 of 801
+d0a:=normalize(D(m0a,x))
+--E 759
+
+--S 760 of 801
+m0b:=a0.2-r0
+--E 760
+
+--S 761 of 801
+d0b:=normalize(D(m0b,x))
+--E 761
+
+)clear all
+
+--S 762 of 801
+t0:=1/sqrt((a*x^3+b*x^4)/x^2)
+--E 762
+
+--S 763 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 763
+
+--S 764 of 801
+a0:=integrate(t0,x)
+--E 764
+
+--S 765 of 801
+m0a:=a0.1-r0
+--E 765
+
+--S 766 of 801
+d0a:=normalize(D(m0a,x))
+--E 766
+
+--S 767 of 801
+m0b:=a0.2-r0
+--E 767
+
+--S 768 of 801
+d0b:=normalize(D(m0b,x))
+--E 768
+
+)clear all
+
+--S 769 of 801
+t0:=1/sqrt(a*c*x+b*c*x^2)
+--E 769
+
+--S 770 of 801
+r0:=2*atanh(x*sqrt(b)*sqrt(c)/sqrt(a*c*x+b*c*x^2))/(sqrt(b)*sqrt(c))
+--E 770
+
+--S 771 of 801
+a0:=integrate(t0,x)
+--E 771
+
+--S 772 of 801
+m0a:=a0.1-r0
+--E 772
+
+--S 773 of 801
+d0a:=normalize(D(m0a,x))
+--E 773
+
+--S 774 of 801
+m0b:=a0.2-r0
+--E 774
+
+--S 775 of 801
+d0b:=normalize(D(m0b,x))
+--E 775
+
+)clear all
+
+--S 776 of 801
+t0:=1/sqrt(c*(a*x+b*x^2))
+--E 776
+
+--S 777 of 801
+r0:=2*atanh(x*sqrt(b)*sqrt(c)/sqrt(a*c*x+b*c*x^2))/(sqrt(b)*sqrt(c))
+--E 777
+
+--S 778 of 801
+a0:=integrate(t0,x)
+--E 778
+
+--S 779 of 801
+m0a:=a0.1-r0
+--E 779
+
+--S 780 of 801
+d0a:=normalize(D(m0a,x))
+--E 780
+
+--S 781 of 801
+m0b:=a0.2-r0
+--E 781
+
+--S 782 of 801
+d0b:=normalize(D(m0b,x))
+--E 782
+
+)clear all
+
+--S 783 of 801
+t0:=1/sqrt(c*x*(a+b*x))
+--E 783
+
+--S 784 of 801
+r0:=2*atanh(x*sqrt(b)*sqrt(c)/sqrt(a*c*x+b*c*x^2))/(sqrt(b)*sqrt(c))
+--E 784
+
+--S 785 of 801
+a0:=integrate(t0,x)
+--E 785
+
+--S 786 of 801
+m0a:=a0.1-r0
+--E 786
+
+--S 787 of 801
+d0a:=normalize(D(m0a,x))
+--E 787
+
+--S 788 of 801
+m0b:=a0.2-r0
+--E 788
+
+--S 789 of 801
+d0b:=normalize(D(m0b,x))
+--E 789
+
+)clear all
+
+--S 790 of 801
+t0:=1/sqrt(c*(b+a/x)*x^2)
+--E 790
+
+--S 791 of 801
+r0:=2*atanh(x*sqrt(b)*sqrt(c)/sqrt(a*c*x+b*c*x^2))/(sqrt(b)*sqrt(c))
+--E 791
+
+--S 792 of 801
+a0:=integrate(t0,x)
+--E 792
+
+--S 793 of 801
+m0a:=a0.1-r0
+--E 793
+
+--S 794 of 801
+d0a:=normalize(D(m0a,x))
+--E 794
+
+--S 795 of 801
+m0b:=a0.2-r0
+--E 795
+
+--S 796 of 801
+d0b:=normalize(D(m0b,x))
+--E 796
+
+)clear all
+
+--S 797 of 801
+t0:=(a-c+b*x)/((1+x^2)*sqrt(a+b*x+c*x^2))
+--E 797
+
+--S 798 of 801
+r0:=-1/2*%i*atanh(1/2*(2*a-%i*b+(b-2*%i*c)*x)/(sqrt(a-%i*b-c)*sqrt(a+b*x+c*x^2)))*sqrt(a-%i*b-c)+1/2*%i*atanh(1/2*(2*a+%i*b+(b+2*%i*c)*x)/(sqrt(a+%i*b-c)*sqrt(a+b*x+c*x^2)))*sqrt(a+%i*b-c)
+--E 798
+
+--S 799 of 801
+a0:=integrate(t0,x)
+--E 799
+
+--S 800 of 801
+m0:=a0-r0
+--E 800
+
+--S 801 of 801
+d0:=D(m0,x)
+--E 801
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich23.input.pamphlet b/src/input/rich23.input.pamphlet
new file mode 100644
index 0000000..683037f
--- /dev/null
+++ b/src/input/rich23.input.pamphlet
@@ -0,0 +1,46457 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich23.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m Px (a+b x^n)^p.input|
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich23.output
+)spool rich23.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 953
+t0:=a/(d+e*x^3)
+--R 
+--R
+--R            a
+--R   (1)  --------
+--R           3
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1
+
+--S 2 of 953
+r0:=1/3*a*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*e^(1/3))-1/6*a*log(d^(2/3)-_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(2/3)*e^(1/3))-a*atan((d^(1/3)-_
+   2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+     3+-+   3+-+
+--R       - a\|3 log(x  \|e  - x\|d \|e  + \|d  ) + 2a\|3 log(x\|e  + \|d )
+--R     + 
+--R                 3+-+   3+-+
+--R               2x\|e  - \|d
+--R       6a atan(-------------)
+--R                   +-+3+-+
+--R                  \|3 \|d
+--R  /
+--R       +-+3+-+2 3+-+
+--R     6\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +---+2      +---+                     +---+
+--R           +-+     2 3| 2        3| 2      2       +-+     3| 2
+--R       - a\|3 log(x  \|d e  - d x\|d e  + d ) + 2a\|3 log(x\|d e  + d)
+--R     + 
+--R                      +---+
+--R                  +-+3| 2       +-+
+--R               2x\|3 \|d e  - d\|3
+--R       6a atan(--------------------)
+--R                        3d
+--R  /
+--R           +---+
+--R       +-+3| 2
+--R     6\|3 \|d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +---+2      +---+
+--R           +-+3+-+2 3+-+     2 3| 2        3| 2      2
+--R       - a\|3 \|d   \|e log(x  \|d e  - d x\|d e  + d )
+--R     + 
+--R                             +---+
+--R          +-+3+-+2 3+-+     3| 2
+--R       2a\|3 \|d   \|e log(x\|d e  + d)
+--R     + 
+--R             +---+
+--R         +-+3| 2       2 3+-+2   3+-+3+-+   3+-+2
+--R       a\|3 \|d e log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R                                                                  +---+
+--R                +---+                                         +-+3| 2       +-+
+--R            +-+3| 2       3+-+   3+-+       3+-+2 3+-+     2x\|3 \|d e  - d\|3
+--R       - 2a\|3 \|d e log(x\|e  + \|d ) + 6a \|d   \|e atan(--------------------)
+--R                                                                    3d
+--R     + 
+--R            +---+       3+-+   3+-+
+--R           3| 2       2x\|e  - \|d
+--R       - 6a\|d e atan(-------------)
+--R                          +-+3+-+
+--R                         \|3 \|d
+--R  /
+--R                     +---+
+--R       +-+3+-+2 3+-+3| 2
+--R     6\|3 \|d   \|e \|d e
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 953
+t0:=b*x/(d+e*x^3)
+--R 
+--R
+--R           b x
+--R   (1)  --------
+--R           3
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 6
+
+--S 7 of 953
+r0:=-1/3*b*log(d^(1/3)+e^(1/3)*x)/(d^(1/3)*e^(2/3))+1/6*b*log(d^(2/3)-_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(1/3)*e^(2/3))-b*atan((d^(1/3)-_
+   2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(1/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R         +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+     3+-+   3+-+
+--R       b\|3 log(x  \|e  - x\|d \|e  + \|d  ) - 2b\|3 log(x\|e  + \|d )
+--R     + 
+--R                 3+-+   3+-+
+--R               2x\|e  - \|d
+--R       6b atan(-------------)
+--R                   +-+3+-+
+--R                  \|3 \|d
+--R  /
+--R       +-+3+-+3+-+2
+--R     6\|3 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +------+2         +------+
+--R           +-+      3|     2        2 3|     2
+--R       - b\|3 log(x \|- d e    + e x  \|- d e  - d e)
+--R     + 
+--R                                                      +------+2
+--R                    +------+2                     +-+3|     2         +-+
+--R          +-+      3|     2                    2x\|3 \|- d e    - d e\|3
+--R       2b\|3 log(x \|- d e    + d e) - 6b atan(--------------------------)
+--R                                                          3d e
+--R  /
+--R           +------+
+--R       +-+3|     2
+--R     6\|3 \|- d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +------+
+--R           +-+3|     2      2 3+-+2   3+-+3+-+   3+-+2
+--R       - b\|3 \|- d e  log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R              +------+
+--R          +-+3|     2      3+-+   3+-+
+--R       2b\|3 \|- d e  log(x\|e  + \|d )
+--R     + 
+--R                              +------+2         +------+
+--R           +-+3+-+3+-+2      3|     2        2 3|     2
+--R       - b\|3 \|d \|e  log(x \|- d e    + e x  \|- d e  - d e)
+--R     + 
+--R                             +------+2             +------+       3+-+   3+-+
+--R          +-+3+-+3+-+2      3|     2              3|     2      2x\|e  - \|d
+--R       2b\|3 \|d \|e  log(x \|- d e    + d e) - 6b\|- d e  atan(-------------)
+--R                                                                    +-+3+-+
+--R                                                                   \|3 \|d
+--R     + 
+--R                                +------+2
+--R                            +-+3|     2         +-+
+--R           3+-+3+-+2     2x\|3 \|- d e    - d e\|3
+--R       - 6b\|d \|e  atan(--------------------------)
+--R                                    3d e
+--R  /
+--R           +------+
+--R       +-+3|     2 3+-+3+-+2
+--R     6\|3 \|- d e  \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 953
+t0:=(a+b*x)/(d+e*x^3)
+--R 
+--R
+--R         b x + a
+--R   (1)  --------
+--R           3
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 11
+
+--S 12 of 953
+r0:=-1/3*(b*d^(1/3)-a*e^(1/3))*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*e^(2/3))-_
+   1/6*(a-b*d^(1/3)/e^(1/3))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(1/3))-(b*d^(1/3)+a*e^(1/3))*atan((d^(1/3)-2*e^(1/3)*x)/_
+   (d^(1/3)*sqrt(3)))/(d^(2/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- a\|3 \|e  + b\|3 \|d )log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R           +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (2a\|3 \|e  - 2b\|3 \|d )log(x\|e  + \|d )
+--R     + 
+--R                               3+-+   3+-+
+--R          3+-+     3+-+      2x\|e  - \|d
+--R       (6a\|e  + 6b\|d )atan(-------------)
+--R                                 +-+3+-+
+--R                                \|3 \|d
+--R  /
+--R       +-+3+-+2 3+-+2
+--R     6\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +-------------------+
+--R             |           2
+--R             |- 9d e %%H0  - 4a b
+--R         (-  |-------------------  - %%H0)
+--R            \|        3d e
+--R      *
+--R         log
+--R                                     +-------------------+
+--R                                     |           2
+--R                   2           2     |- 9d e %%H0  - 4a b        2      2
+--R              (9b d e %%H0 - 3a d e) |-------------------  - 9b d e %%H0
+--R                                    \|        3d e
+--R            + 
+--R                  2              3      3          2
+--R              - 3a d e %%H0 + (2a e + 2b d)x - 2a b d
+--R     + 
+--R           +-------------------+
+--R           |           2
+--R           |- 9d e %%H0  - 4a b
+--R         ( |-------------------  - %%H0)
+--R          \|        3d e
+--R      *
+--R         log
+--R                                       +-------------------+
+--R                                       |           2
+--R                     2           2     |- 9d e %%H0  - 4a b        2      2
+--R              (- 9b d e %%H0 + 3a d e) |-------------------  - 9b d e %%H0
+--R                                      \|        3d e
+--R            + 
+--R                  2              3      3          2
+--R              - 3a d e %%H0 + (2a e + 2b d)x - 2a b d
+--R     + 
+--R                     2      2     2             3     3          2
+--R       2%%H0 log(9b d e %%H0  + 3a d e %%H0 + (a e + b d)x + 2a b d)
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 13
+
+--S 14 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +-------------------+
+--R                             |           2
+--R              +-+3+-+2 3+-+2 |- 9d e %%H0  - 4a b     +-+3+-+2 3+-+2
+--R         (- 3\|3 \|d   \|e   |------------------- - 3\|3 \|d   \|e  %%H)
+--R                            \|        3d e
+--R      *
+--R         log
+--R                                     +-------------------+
+--R                                     |           2
+--R                   2           2     |- 9d e %%H0  - 4a b        2      2
+--R              (9b d e %%H0 - 3a d e) |-------------------  - 9b d e %%H0
+--R                                    \|        3d e
+--R            + 
+--R                  2              3      3          2
+--R              - 3a d e %%H0 + (2a e + 2b d)x - 2a b d
+--R     + 
+--R                           +-------------------+
+--R                           |           2
+--R            +-+3+-+2 3+-+2 |- 9d e %%H0  - 4a b     +-+3+-+2 3+-+2
+--R         (3\|3 \|d   \|e   |------------------- - 3\|3 \|d   \|e  %%H)
+--R                          \|        3d e
+--R      *
+--R         log
+--R                                       +-------------------+
+--R                                       |           2
+--R                     2           2     |- 9d e %%H0  - 4a b        2      2
+--R              (- 9b d e %%H0 + 3a d e) |-------------------  - 9b d e %%H0
+--R                                      \|        3d e
+--R            + 
+--R                  2              3      3          2
+--R              - 3a d e %%H0 + (2a e + 2b d)x - 2a b d
+--R     + 
+--R           +-+3+-+2 3+-+2
+--R         6\|3 \|d   \|e  %%H0
+--R      *
+--R                 2      2     2             3     3          2
+--R         log(9b d e %%H0  + 3a d e %%H0 + (a e + b d)x + 2a b d)
+--R     + 
+--R          +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (a\|3 \|e  - b\|3 \|d )log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R             +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (- 2a\|3 \|e  + 2b\|3 \|d )log(x\|e  + \|d )
+--R     + 
+--R                                 3+-+   3+-+
+--R            3+-+     3+-+      2x\|e  - \|d
+--R       (- 6a\|e  - 6b\|d )atan(-------------)
+--R                                   +-+3+-+
+--R                                  \|3 \|d
+--R  /
+--R       +-+3+-+2 3+-+2
+--R     6\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 953
+t0:=c*x^2/(d+e*x^3)
+--R 
+--R
+--R             2
+--R          c x
+--R   (1)  --------
+--R           3
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 16
+
+--S 17 of 953
+r0:=1/3*c*log(d+e*x^3)/e
+--R 
+--R
+--R                 3
+--R        c log(e x  + d)
+--R   (2)  ---------------
+--R               3e
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 3
+--R        c log(e x  + d)
+--R   (3)  ---------------
+--R               3e
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 953
+t0:=(a+c*x^2)/(d+e*x^3)
+--R 
+--R
+--R           2
+--R        c x  + a
+--R   (1)  --------
+--R           3
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 21
+
+--S 22 of 953
+r0:=1/3*a*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*e^(1/3))-1/6*a*log(d^(2/3)-_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(2/3)*e^(1/3))+1/3*c*log(d+e*x^3)/e-_
+   a*atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R             +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+     3+-+   3+-+
+--R       - a e\|3 log(x  \|e  - x\|d \|e  + \|d  ) + 2a e\|3 log(x\|e  + \|d )
+--R     + 
+--R                   3+-+   3+-+
+--R                 2x\|e  - \|d        +-+       3     3+-+2 3+-+
+--R       6a e atan(-------------) + 2c\|3 log(e x  + d)\|d   \|e
+--R                     +-+3+-+
+--R                    \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                               +-------------------------+
+--R                                               |  2    2                2
+--R                                               |9e %%I0  - 6c e %%I0 + c
+--R          +-------------------------+     3d e |-------------------------
+--R          |  2    2                2           |             2
+--R          |9e %%I0  - 6c e %%I0 + c           \|           3e
+--R       2e |------------------------- atan(--------------------------------)
+--R          |             2                     3d e %%I0 - 2a e x - c d
+--R         \|           3e
+--R     + 
+--R         (- e %%I0 + c)
+--R      *
+--R             2 2    2            2        2          2 2 2                2 2
+--R       log(9d e %%I0  + (- 3a d e x - 6c d e)%%I0 + a e x  + a c d e x + c d )
+--R     + 
+--R       2e %%I0 log(3d e %%I0 + a e x - c d)
+--R  /
+--R     2e
+--R                                         Type: Union(Expression(Integer),...)
+--E 23
+
+--S 24 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +-------------------------+
+--R                          |  2    2                2
+--R            +-+3+-+2 3+-+ |9e %%I0  - 6c e %%I0 + c
+--R         6e\|3 \|d   \|e  |-------------------------
+--R                          |             2
+--R                         \|           3e
+--R      *
+--R                   +-------------------------+
+--R                   |  2    2                2
+--R                   |9e %%I0  - 6c e %%I0 + c
+--R              3d e |-------------------------
+--R                   |             2
+--R                  \|           3e
+--R         atan(--------------------------------)
+--R                  3d e %%I0 - 2a e x - c d
+--R     + 
+--R               +-+3+-+2 3+-+         +-+3+-+2 3+-+
+--R         (- 3e\|3 \|d   \|e %%I + 3c\|3 \|d   \|e)
+--R      *
+--R             2 2    2            2        2          2 2 2                2 2
+--R       log(9d e %%I0  + (- 3a d e x - 6c d e)%%I0 + a e x  + a c d e x + c d )
+--R     + 
+--R          +-+3+-+2 3+-+
+--R       6e\|3 \|d   \|e %%I0 log(3d e %%I0 + a e x - c d)
+--R     + 
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+     3+-+   3+-+
+--R       a e\|3 log(x  \|e  - x\|d \|e  + \|d  ) - 2a e\|3 log(x\|e  + \|d )
+--R     + 
+--R                     3+-+   3+-+
+--R                   2x\|e  - \|d        +-+       3     3+-+2 3+-+
+--R       - 6a e atan(-------------) - 2c\|3 log(e x  + d)\|d   \|e
+--R                       +-+3+-+
+--R                      \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 25
+
+)clear all
+
+--S 26 of 953
+t0:=(b*x+c*x^2)/(d+e*x^3)
+--R 
+--R
+--R           2
+--R        c x  + b x
+--R   (1)  ----------
+--R            3
+--R         e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 26
+
+--S 27 of 953
+r0:=-1/3*b*log(d^(1/3)+e^(1/3)*x)/(d^(1/3)*e^(2/3))+1/6*b*log(d^(2/3)-_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(1/3)*e^(2/3))+1/3*c*log(d+e*x^3)/e-_
+   b*atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(1/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+     3+-+   3+-+
+--R       b e\|3 log(x  \|e  - x\|d \|e  + \|d  ) - 2b e\|3 log(x\|e  + \|d )
+--R     + 
+--R                   3+-+   3+-+
+--R                 2x\|e  - \|d        +-+       3     3+-+3+-+2
+--R       6b e atan(-------------) + 2c\|3 log(e x  + d)\|d \|e
+--R                     +-+3+-+
+--R                    \|3 \|d
+--R  /
+--R        +-+3+-+3+-+2
+--R     6e\|3 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R               +-------------------------+
+--R               |  2    2                2
+--R               |9e %%R0  - 6c e %%R0 + c
+--R            2e |-------------------------
+--R               |             2
+--R              \|           3e
+--R         *
+--R                                      +-------------------------+
+--R                                      |  2    2                2
+--R                      2               |9e %%R0  - 6c e %%R0 + c
+--R                 (9d e %%R0 - 3c d e) |-------------------------
+--R                                      |             2
+--R                                     \|           3e
+--R            atan(------------------------------------------------)
+--R                          2    2                   2       2
+--R                      9d e %%R0  - 6c d e %%R0 - 2b e x + c d
+--R     + 
+--R                       2    2                  2       2
+--R       2e %%R0 log(9d e %%R0  - 6c d e %%R0 + b e x + c d)
+--R     + 
+--R         (- e %%R0 + c)
+--R      *
+--R                   2      2                              2   2    2
+--R         log(- 9d e x %%R0  + (6c d e x - 3b d e)%%R0 + b e x  - c d x + b c d)
+--R  /
+--R     2e
+--R                                         Type: Union(Expression(Integer),...)
+--E 28
+
+--S 29 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                            +-------------------------+
+--R                            |  2    2                2
+--R               +-+3+-+3+-+2 |9e %%R0  - 6c e %%R0 + c
+--R            6e\|3 \|d \|e   |-------------------------
+--R                            |             2
+--R                           \|           3e
+--R         *
+--R                                      +-------------------------+
+--R                                      |  2    2                2
+--R                      2               |9e %%R0  - 6c e %%R0 + c
+--R                 (9d e %%R0 - 3c d e) |-------------------------
+--R                                      |             2
+--R                                     \|           3e
+--R            atan(------------------------------------------------)
+--R                          2    2                   2       2
+--R                      9d e %%R0  - 6c d e %%R0 - 2b e x + c d
+--R     + 
+--R          +-+3+-+3+-+2             2    2                  2       2
+--R       6e\|3 \|d \|e  %%R0 log(9d e %%R0  - 6c d e %%R0 + b e x + c d)
+--R     + 
+--R             +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+     3+-+   3+-+
+--R       - b e\|3 log(x  \|e  - x\|d \|e  + \|d  ) + 2b e\|3 log(x\|e  + \|d )
+--R     + 
+--R               +-+3+-+3+-+2          +-+3+-+3+-+2
+--R         (- 3e\|3 \|d \|e  %%R0 + 3c\|3 \|d \|e  )
+--R      *
+--R                   2      2                              2   2    2
+--R         log(- 9d e x %%R0  + (6c d e x - 3b d e)%%R0 + b e x  - c d x + b c d)
+--R     + 
+--R                     3+-+   3+-+
+--R                   2x\|e  - \|d        +-+       3     3+-+3+-+2
+--R       - 6b e atan(-------------) - 2c\|3 log(e x  + d)\|d \|e
+--R                       +-+3+-+
+--R                      \|3 \|d
+--R  /
+--R        +-+3+-+3+-+2
+--R     6e\|3 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 953
+t0:=(a+b*x+c*x^2)/(d+e*x^3)
+--R 
+--R
+--R           2
+--R        c x  + b x + a
+--R   (1)  --------------
+--R              3
+--R           e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 31
+
+--S 32 of 953
+r0:=-1/3*(b*d^(1/3)-a*e^(1/3))*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*e^(2/3))-_
+   1/6*(a-b*d^(1/3)/e^(1/3))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(1/3))+1/3*c*log(d+e*x^3)/e-(b*d^(1/3)+a*e^(1/3))*_
+   atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              +-+3+-+       +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- a e\|3 \|e  + b e\|3 \|d )log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R             +-+3+-+        +-+3+-+      3+-+   3+-+
+--R       (2a e\|3 \|e  - 2b e\|3 \|d )log(x\|e  + \|d )
+--R     + 
+--R                                   3+-+   3+-+
+--R            3+-+       3+-+      2x\|e  - \|d        +-+       3     3+-+2 3+-+2
+--R       (6a e\|e  + 6b e\|d )atan(-------------) + 2c\|3 log(e x  + d)\|d   \|e
+--R                                     +-+3+-+
+--R                                    \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +-----------------------------------------+
+--R              |      2    2                           2
+--R              |- 9d e %%S0  + 6c d e %%S0 - 4a b e - c d
+--R         (- e |-----------------------------------------  - e %%S0 + c)
+--R              |                      2
+--R             \|                  3d e
+--R      *
+--R         log
+--R                     2 2         2   2         2
+--R                (9b d e %%S0 - 3a d e  - 3b c d e)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |      2    2                           2
+--R                 |- 9d e %%S0  + 6c d e %%S0 - 4a b e - c d
+--R                 |-----------------------------------------
+--R                 |                      2
+--R                \|                  3d e
+--R            + 
+--R                    2 2    2        2   2         2            3 2     3
+--R              - 9b d e %%S0  + (- 3a d e  + 6b c d e)%%S0 + (2a e  + 2b d e)x
+--R            + 
+--R                2        2          2 2
+--R              (a c - 2a b )d e - b c d
+--R     + 
+--R            +-----------------------------------------+
+--R            |      2    2                           2
+--R            |- 9d e %%S0  + 6c d e %%S0 - 4a b e - c d
+--R         (e |-----------------------------------------  - e %%S0 + c)
+--R            |                      2
+--R           \|                  3d e
+--R      *
+--R         log
+--R                       2 2         2   2         2
+--R                (- 9b d e %%S0 + 3a d e  + 3b c d e)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |      2    2                           2
+--R                 |- 9d e %%S0  + 6c d e %%S0 - 4a b e - c d
+--R                 |-----------------------------------------
+--R                 |                      2
+--R                \|                  3d e
+--R            + 
+--R                    2 2    2        2   2         2            3 2     3
+--R              - 9b d e %%S0  + (- 3a d e  + 6b c d e)%%S0 + (2a e  + 2b d e)x
+--R            + 
+--R                2        2          2 2
+--R              (a c - 2a b )d e - b c d
+--R     + 
+--R         2e %%S0
+--R      *
+--R         log
+--R                  2 2    2      2   2         2           3 2    3
+--R              9b d e %%S0  + (3a d e  - 6b c d e)%%S0 + (a e  + b d e)x
+--R            + 
+--R                  2        2          2 2
+--R              (- a c + 2a b )d e + b c d
+--R  /
+--R     2e
+--R                                         Type: Union(Expression(Integer),...)
+--E 33
+
+--S 34 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +-----------------------------------------+
+--R                               |      2    2                           2
+--R                +-+3+-+2 3+-+2 |- 9d e %%S0  + 6c d e %%S0 - 4a b e - c d
+--R           - 3e\|3 \|d   \|e   |-----------------------------------------
+--R                               |                      2
+--R                              \|                  3d e
+--R         + 
+--R                +-+3+-+2 3+-+2         +-+3+-+2 3+-+2
+--R           - 3e\|3 \|d   \|e  %%S + 3c\|3 \|d   \|e
+--R      *
+--R         log
+--R                     2 2         2   2         2
+--R                (9b d e %%S0 - 3a d e  - 3b c d e)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |      2    2                           2
+--R                 |- 9d e %%S0  + 6c d e %%S0 - 4a b e - c d
+--R                 |-----------------------------------------
+--R                 |                      2
+--R                \|                  3d e
+--R            + 
+--R                    2 2    2        2   2         2            3 2     3
+--R              - 9b d e %%S0  + (- 3a d e  + 6b c d e)%%S0 + (2a e  + 2b d e)x
+--R            + 
+--R                2        2          2 2
+--R              (a c - 2a b )d e - b c d
+--R     + 
+--R                             +-----------------------------------------+
+--R                             |      2    2                           2
+--R              +-+3+-+2 3+-+2 |- 9d e %%S0  + 6c d e %%S0 - 4a b e - c d
+--R           3e\|3 \|d   \|e   |-----------------------------------------
+--R                             |                      2
+--R                            \|                  3d e
+--R         + 
+--R                +-+3+-+2 3+-+2         +-+3+-+2 3+-+2
+--R           - 3e\|3 \|d   \|e  %%S + 3c\|3 \|d   \|e
+--R      *
+--R         log
+--R                       2 2         2   2         2
+--R                (- 9b d e %%S0 + 3a d e  + 3b c d e)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |      2    2                           2
+--R                 |- 9d e %%S0  + 6c d e %%S0 - 4a b e - c d
+--R                 |-----------------------------------------
+--R                 |                      2
+--R                \|                  3d e
+--R            + 
+--R                    2 2    2        2   2         2            3 2     3
+--R              - 9b d e %%S0  + (- 3a d e  + 6b c d e)%%S0 + (2a e  + 2b d e)x
+--R            + 
+--R                2        2          2 2
+--R              (a c - 2a b )d e - b c d
+--R     + 
+--R            +-+3+-+2 3+-+2
+--R         6e\|3 \|d   \|e  %%S0
+--R      *
+--R         log
+--R                  2 2    2      2   2         2           3 2    3
+--R              9b d e %%S0  + (3a d e  - 6b c d e)%%S0 + (a e  + b d e)x
+--R            + 
+--R                  2        2          2 2
+--R              (- a c + 2a b )d e + b c d
+--R     + 
+--R            +-+3+-+       +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (a e\|3 \|e  - b e\|3 \|d )log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R               +-+3+-+        +-+3+-+      3+-+   3+-+
+--R       (- 2a e\|3 \|e  + 2b e\|3 \|d )log(x\|e  + \|d )
+--R     + 
+--R                                   3+-+   3+-+
+--R            3+-+       3+-+      2x\|e  - \|d        +-+       3     3+-+2 3+-+2
+--R     (- 6a e\|e  - 6b e\|d )atan(-------------) - 2c\|3 log(e x  + d)\|d   \|e
+--R                                     +-+3+-+
+--R                                    \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 35
+
+)clear all
+
+--S 36 of 953
+t0:=a/(d-e*x^3)
+--R 
+--R
+--R              a
+--R   (1)  - --------
+--R             3
+--R          e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 36
+
+--S 37 of 953
+r0:=-1/3*a*log(d^(1/3)-e^(1/3)*x)/(d^(2/3)*e^(1/3))+1/6*a*log(d^(2/3)+_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(2/3)*e^(1/3))+a*atan((d^(1/3)+_
+   2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R         +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+       3+-+   3+-+
+--R       a\|3 log(x  \|e  + x\|d \|e  + \|d  ) - 2a\|3 log(- x\|e  + \|d )
+--R     + 
+--R                 3+-+   3+-+
+--R               2x\|e  + \|d
+--R       6a atan(-------------)
+--R                   +-+3+-+
+--R                  \|3 \|d
+--R  /
+--R       +-+3+-+2 3+-+
+--R     6\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +-----+2      +-----+                     +-----+
+--R           +-+     2 3|   2        3|   2      2       +-+     3|   2
+--R       - a\|3 log(x  \|- d e  - d x\|- d e  + d ) + 2a\|3 log(x\|- d e  + d)
+--R     + 
+--R                      +-----+
+--R                  +-+3|   2       +-+
+--R               2x\|3 \|- d e  - d\|3
+--R       6a atan(----------------------)
+--R                         3d
+--R  /
+--R           +-----+
+--R       +-+3|   2
+--R     6\|3 \|- d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 38
+
+--S 39 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-----+
+--R           +-+3|   2       2 3+-+2   3+-+3+-+   3+-+2
+--R       - a\|3 \|- d e log(x  \|e  + x\|d \|e  + \|d  )
+--R     + 
+--R                                +-----+2      +-----+
+--R           +-+3+-+2 3+-+     2 3|   2        3|   2      2
+--R       - a\|3 \|d   \|e log(x  \|- d e  - d x\|- d e  + d )
+--R     + 
+--R                             +-----+              +-----+
+--R          +-+3+-+2 3+-+     3|   2            +-+3|   2         3+-+   3+-+
+--R       2a\|3 \|d   \|e log(x\|- d e  + d + 2a\|3 \|- d e log(- x\|e  + \|d )
+--R     + 
+--R                                                                +-----+
+--R          +-----+       3+-+   3+-+                         +-+3|   2       +-+
+--R         3|   2       2x\|e  + \|d        3+-+2 3+-+     2x\|3 \|- d e  - d\|3
+--R     - 6a\|- d e atan(-------------) + 6a \|d   \|e atan(----------------------)
+--R                          +-+3+-+                                  3d
+--R                         \|3 \|d
+--R  /
+--R           +-----+
+--R       +-+3|   2  3+-+2 3+-+
+--R     6\|3 \|- d e \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 40
+
+)clear all
+
+--S 41 of 953
+t0:=b*x/(d-e*x^3)
+--R 
+--R
+--R             b x
+--R   (1)  - --------
+--R             3
+--R          e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 41
+
+--S 42 of 953
+r0:=-1/3*b*log(d^(1/3)-e^(1/3)*x)/(d^(1/3)*e^(2/3))+1/6*b*log(d^(2/3)+_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(1/3)*e^(2/3))-b*atan((d^(1/3)+_
+   2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(1/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R         +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+       3+-+   3+-+
+--R       b\|3 log(x  \|e  + x\|d \|e  + \|d  ) - 2b\|3 log(- x\|e  + \|d )
+--R     + 
+--R                   3+-+   3+-+
+--R                 2x\|e  + \|d
+--R       - 6b atan(-------------)
+--R                     +-+3+-+
+--R                    \|3 \|d
+--R  /
+--R       +-+3+-+3+-+2
+--R     6\|3 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +------+2
+--R          +-+      3|     2
+--R       2b\|3 log(x \|- d e    - d e)
+--R     + 
+--R                       +------+2         +------+
+--R           +-+        3|     2        2 3|     2
+--R       - b\|3 log(- x \|- d e    + e x  \|- d e  - d e)
+--R     + 
+--R                      +------+2
+--R                  +-+3|     2         +-+
+--R               2x\|3 \|- d e    + d e\|3
+--R       6b atan(--------------------------)
+--R                          3d e
+--R  /
+--R           +------+
+--R       +-+3|     2
+--R     6\|3 \|- d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 43
+
+--S 44 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +------+
+--R           +-+3|     2      2 3+-+2   3+-+3+-+   3+-+2
+--R       - b\|3 \|- d e  log(x  \|e  + x\|d \|e  + \|d  )
+--R     + 
+--R                             +------+2
+--R          +-+3+-+3+-+2      3|     2
+--R       2b\|3 \|d \|e  log(x \|- d e    - d e)
+--R     + 
+--R                                +------+2         +------+
+--R           +-+3+-+3+-+2        3|     2        2 3|     2
+--R       - b\|3 \|d \|e  log(- x \|- d e    + e x  \|- d e  - d e)
+--R     + 
+--R              +------+                         +------+       3+-+   3+-+
+--R          +-+3|     2        3+-+   3+-+      3|     2      2x\|e  + \|d
+--R       2b\|3 \|- d e  log(- x\|e  + \|d ) + 6b\|- d e  atan(-------------)
+--R                                                                +-+3+-+
+--R                                                               \|3 \|d
+--R     + 
+--R                              +------+2
+--R                          +-+3|     2         +-+
+--R         3+-+3+-+2     2x\|3 \|- d e    + d e\|3
+--R       6b\|d \|e  atan(--------------------------)
+--R                                  3d e
+--R  /
+--R           +------+
+--R       +-+3|     2 3+-+3+-+2
+--R     6\|3 \|- d e  \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 953
+t0:=(a+b*x)/(d-e*x^3)
+--R 
+--R
+--R        - b x - a
+--R   (1)  ---------
+--R            3
+--R         e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 46
+
+--S 47 of 953
+r0:=-1/3*(b*d^(1/3)+a*e^(1/3))*log(d^(1/3)-e^(1/3)*x)/(d^(2/3)*e^(2/3))+_
+   1/6*(b*d^(1/3)+a*e^(1/3))*log(d^(2/3)+d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(2/3))-(b*d^(1/3)-a*e^(1/3))*atan((d^(1/3)+2*e^(1/3)*x)/_
+   (d^(1/3)*sqrt(3)))/(d^(2/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (a\|3 \|e  + b\|3 \|d )log(x  \|e  + x\|d \|e  + \|d  )
+--R     + 
+--R             +-+3+-+      +-+3+-+        3+-+   3+-+
+--R       (- 2a\|3 \|e  - 2b\|3 \|d )log(- x\|e  + \|d )
+--R     + 
+--R                               3+-+   3+-+
+--R          3+-+     3+-+      2x\|e  + \|d
+--R       (6a\|e  - 6b\|d )atan(-------------)
+--R                                 +-+3+-+
+--R                                \|3 \|d
+--R  /
+--R       +-+3+-+2 3+-+2
+--R     6\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +-------------------+
+--R             |           2
+--R             |- 9d e %%V0  + 4a b
+--R         (-  |-------------------  - %%V0)
+--R            \|        3d e
+--R      *
+--R         log
+--R                                     +-------------------+
+--R                                     |           2
+--R                   2           2     |- 9d e %%V0  + 4a b        2      2
+--R              (9b d e %%V0 - 3a d e) |-------------------  - 9b d e %%V0
+--R                                    \|        3d e
+--R            + 
+--R                  2              3      3          2
+--R              - 3a d e %%V0 + (2a e - 2b d)x + 2a b d
+--R     + 
+--R           +-------------------+
+--R           |           2
+--R           |- 9d e %%V0  + 4a b
+--R         ( |-------------------  - %%V0)
+--R          \|        3d e
+--R      *
+--R         log
+--R                                       +-------------------+
+--R                                       |           2
+--R                     2           2     |- 9d e %%V0  + 4a b        2      2
+--R              (- 9b d e %%V0 + 3a d e) |-------------------  - 9b d e %%V0
+--R                                      \|        3d e
+--R            + 
+--R                  2              3      3          2
+--R              - 3a d e %%V0 + (2a e - 2b d)x + 2a b d
+--R     + 
+--R                     2      2     2             3     3          2
+--R       2%%V0 log(9b d e %%V0  + 3a d e %%V0 + (a e - b d)x - 2a b d)
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +-------------------+
+--R                             |           2
+--R              +-+3+-+2 3+-+2 |- 9d e %%V0  + 4a b     +-+3+-+2 3+-+2
+--R         (- 3\|3 \|d   \|e   |------------------- - 3\|3 \|d   \|e  %%V)
+--R                            \|        3d e
+--R      *
+--R         log
+--R                                     +-------------------+
+--R                                     |           2
+--R                   2           2     |- 9d e %%V0  + 4a b        2      2
+--R              (9b d e %%V0 - 3a d e) |-------------------  - 9b d e %%V0
+--R                                    \|        3d e
+--R            + 
+--R                  2              3      3          2
+--R              - 3a d e %%V0 + (2a e - 2b d)x + 2a b d
+--R     + 
+--R                           +-------------------+
+--R                           |           2
+--R            +-+3+-+2 3+-+2 |- 9d e %%V0  + 4a b     +-+3+-+2 3+-+2
+--R         (3\|3 \|d   \|e   |------------------- - 3\|3 \|d   \|e  %%V)
+--R                          \|        3d e
+--R      *
+--R         log
+--R                                       +-------------------+
+--R                                       |           2
+--R                     2           2     |- 9d e %%V0  + 4a b        2      2
+--R              (- 9b d e %%V0 + 3a d e) |-------------------  - 9b d e %%V0
+--R                                      \|        3d e
+--R            + 
+--R                  2              3      3          2
+--R              - 3a d e %%V0 + (2a e - 2b d)x + 2a b d
+--R     + 
+--R           +-+3+-+2 3+-+2
+--R         6\|3 \|d   \|e  %%V0
+--R      *
+--R                 2      2     2             3     3          2
+--R         log(9b d e %%V0  + 3a d e %%V0 + (a e - b d)x - 2a b d)
+--R     + 
+--R            +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- a\|3 \|e  - b\|3 \|d )log(x  \|e  + x\|d \|e  + \|d  )
+--R     + 
+--R           +-+3+-+      +-+3+-+        3+-+   3+-+
+--R       (2a\|3 \|e  + 2b\|3 \|d )log(- x\|e  + \|d )
+--R     + 
+--R                                 3+-+   3+-+
+--R            3+-+     3+-+      2x\|e  + \|d
+--R       (- 6a\|e  + 6b\|d )atan(-------------)
+--R                                   +-+3+-+
+--R                                  \|3 \|d
+--R  /
+--R       +-+3+-+2 3+-+2
+--R     6\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 953
+t0:=c*x^2/(d-e*x^3)
+--R 
+--R
+--R               2
+--R            c x
+--R   (1)  - --------
+--R             3
+--R          e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 51
+
+--S 52 of 953
+r0:=-1/3*c*log(d-e*x^3)/e
+--R 
+--R
+--R                     3
+--R          c log(- e x  + d)
+--R   (2)  - -----------------
+--R                  3e
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   3
+--R          c log(e x  - d)
+--R   (3)  - ---------------
+--R                 3e
+--R                                         Type: Union(Expression(Integer),...)
+--E 53
+
+--S 54 of 953
+m0:=a0-r0
+--R 
+--R
+--R                   3                   3
+--R        - c log(e x  - d) + c log(- e x  + d)
+--R   (4)  -------------------------------------
+--R                          3e
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 55
+
+)clear all
+
+--S 56 of 953
+t0:=(a+c*x^2)/(d-e*x^3)
+--R 
+--R
+--R             2
+--R        - c x  - a
+--R   (1)  ----------
+--R            3
+--R         e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 56
+
+--S 57 of 953
+r0:=-1/3*a*log(d^(1/3)-e^(1/3)*x)/(d^(2/3)*e^(1/3))+1/6*a*log(d^(2/3)+_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(2/3)*e^(1/3))-1/3*c*log(d-e*x^3)/e+_
+   a*atan((d^(1/3)+2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+       3+-+   3+-+
+--R       a e\|3 log(x  \|e  + x\|d \|e  + \|d  ) - 2a e\|3 log(- x\|e  + \|d )
+--R     + 
+--R                   3+-+   3+-+
+--R                 2x\|e  + \|d        +-+         3     3+-+2 3+-+
+--R       6a e atan(-------------) - 2c\|3 log(- e x  + d)\|d   \|e
+--R                     +-+3+-+
+--R                    \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 57
+
+--S 58 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                               +-------------------------+
+--R                                               |  2    2                2
+--R                                               |9e %%W0  + 6c e %%W0 + c
+--R          +-------------------------+     3d e |-------------------------
+--R          |  2    2                2           |             2
+--R          |9e %%W0  + 6c e %%W0 + c           \|           3e
+--R       2e |------------------------- atan(--------------------------------)
+--R          |             2                     3d e %%W0 - 2a e x + c d
+--R         \|           3e
+--R     + 
+--R         (- e %%W0 - c)
+--R      *
+--R             2 2    2            2        2          2 2 2                2 2
+--R       log(9d e %%W0  + (- 3a d e x + 6c d e)%%W0 + a e x  - a c d e x + c d )
+--R     + 
+--R       2e %%W0 log(3d e %%W0 + a e x + c d)
+--R  /
+--R     2e
+--R                                         Type: Union(Expression(Integer),...)
+--E 58
+
+--S 59 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +-------------------------+
+--R                          |  2    2                2
+--R            +-+3+-+2 3+-+ |9e %%W0  + 6c e %%W0 + c
+--R         6e\|3 \|d   \|e  |-------------------------
+--R                          |             2
+--R                         \|           3e
+--R      *
+--R                   +-------------------------+
+--R                   |  2    2                2
+--R                   |9e %%W0  + 6c e %%W0 + c
+--R              3d e |-------------------------
+--R                   |             2
+--R                  \|           3e
+--R         atan(--------------------------------)
+--R                  3d e %%W0 - 2a e x + c d
+--R     + 
+--R               +-+3+-+2 3+-+         +-+3+-+2 3+-+
+--R         (- 3e\|3 \|d   \|e %%W - 3c\|3 \|d   \|e)
+--R      *
+--R             2 2    2            2        2          2 2 2                2 2
+--R       log(9d e %%W0  + (- 3a d e x + 6c d e)%%W0 + a e x  - a c d e x + c d )
+--R     + 
+--R          +-+3+-+2 3+-+
+--R       6e\|3 \|d   \|e %%W0 log(3d e %%W0 + a e x + c d)
+--R     + 
+--R             +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+       3+-+   3+-+
+--R       - a e\|3 log(x  \|e  + x\|d \|e  + \|d  ) + 2a e\|3 log(- x\|e  + \|d )
+--R     + 
+--R                     3+-+   3+-+
+--R                   2x\|e  + \|d        +-+         3     3+-+2 3+-+
+--R       - 6a e atan(-------------) + 2c\|3 log(- e x  + d)\|d   \|e
+--R                       +-+3+-+
+--R                      \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 953
+t0:=(b*x+c*x^2)/(d-e*x^3)
+--R 
+--R
+--R             2
+--R        - c x  - b x
+--R   (1)  ------------
+--R             3
+--R          e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 61
+
+--S 62 of 953
+r0:=-1/3*b*log(d^(1/3)-e^(1/3)*x)/(d^(1/3)*e^(2/3))+1/6*b*log(d^(2/3)+_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(1/3)*e^(2/3))-1/3*c*log(d-e*x^3)/e-_
+   b*atan((d^(1/3)+2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(1/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+       3+-+   3+-+
+--R       b e\|3 log(x  \|e  + x\|d \|e  + \|d  ) - 2b e\|3 log(- x\|e  + \|d )
+--R     + 
+--R                     3+-+   3+-+
+--R                   2x\|e  + \|d        +-+         3     3+-+3+-+2
+--R       - 6b e atan(-------------) - 2c\|3 log(- e x  + d)\|d \|e
+--R                       +-+3+-+
+--R                      \|3 \|d
+--R  /
+--R        +-+3+-+3+-+2
+--R     6e\|3 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R               +-------------------------+
+--R               |  2    2                2
+--R               |9e %%X0  + 6c e %%X0 + c
+--R            2e |-------------------------
+--R               |             2
+--R              \|           3e
+--R         *
+--R                                      +-------------------------+
+--R                                      |  2    2                2
+--R                      2               |9e %%X0  + 6c e %%X0 + c
+--R                 (9d e %%X0 + 3c d e) |-------------------------
+--R                                      |             2
+--R                                     \|           3e
+--R            atan(------------------------------------------------)
+--R                          2    2                   2       2
+--R                      9d e %%X0  + 6c d e %%X0 + 2b e x + c d
+--R     + 
+--R         (- e %%X0 - c)
+--R      *
+--R                 2      2                              2   2    2
+--R         log(9d e x %%X0  + (6c d e x - 3b d e)%%X0 + b e x  + c d x - b c d)
+--R     + 
+--R                         2    2                  2       2
+--R       2e %%X0 log(- 9d e %%X0  - 6c d e %%X0 + b e x - c d)
+--R  /
+--R     2e
+--R                                         Type: Union(Expression(Integer),...)
+--E 63
+
+--S 64 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                            +-------------------------+
+--R                            |  2    2                2
+--R               +-+3+-+3+-+2 |9e %%X0  + 6c e %%X0 + c
+--R            6e\|3 \|d \|e   |-------------------------
+--R                            |             2
+--R                           \|           3e
+--R         *
+--R                                      +-------------------------+
+--R                                      |  2    2                2
+--R                      2               |9e %%X0  + 6c e %%X0 + c
+--R                 (9d e %%X0 + 3c d e) |-------------------------
+--R                                      |             2
+--R                                     \|           3e
+--R            atan(------------------------------------------------)
+--R                          2    2                   2       2
+--R                      9d e %%X0  + 6c d e %%X0 + 2b e x + c d
+--R     + 
+--R               +-+3+-+3+-+2          +-+3+-+3+-+2
+--R         (- 3e\|3 \|d \|e  %%X0 - 3c\|3 \|d \|e  )
+--R      *
+--R                 2      2                              2   2    2
+--R         log(9d e x %%X0  + (6c d e x - 3b d e)%%X0 + b e x  + c d x - b c d)
+--R     + 
+--R             +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+       3+-+   3+-+
+--R       - b e\|3 log(x  \|e  + x\|d \|e  + \|d  ) + 2b e\|3 log(- x\|e  + \|d )
+--R     + 
+--R          +-+3+-+3+-+2               2    2                  2       2
+--R       6e\|3 \|d \|e  %%X0 log(- 9d e %%X0  - 6c d e %%X0 + b e x - c d)
+--R     + 
+--R                   3+-+   3+-+
+--R                 2x\|e  + \|d        +-+         3     3+-+3+-+2
+--R       6b e atan(-------------) + 2c\|3 log(- e x  + d)\|d \|e
+--R                     +-+3+-+
+--R                    \|3 \|d
+--R  /
+--R        +-+3+-+3+-+2
+--R     6e\|3 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 65
+
+)clear all
+
+--S 66 of 953
+t0:=(a+b*x+c*x^2)/(d-e*x^3)
+--R 
+--R
+--R             2
+--R        - c x  - b x - a
+--R   (1)  ----------------
+--R               3
+--R            e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 66
+
+--S 67 of 953
+r0:=-1/3*(b*d^(1/3)+a*e^(1/3))*log(d^(1/3)-e^(1/3)*x)/(d^(2/3)*e^(2/3))+_
+   1/6*(b*d^(1/3)+a*e^(1/3))*log(d^(2/3)+d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(2/3))-1/3*c*log(d-e*x^3)/e-(b*d^(1/3)-a*e^(1/3))*_
+   atan((d^(1/3)+2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +-+3+-+       +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (a e\|3 \|e  + b e\|3 \|d )log(x  \|e  + x\|d \|e  + \|d  )
+--R     + 
+--R               +-+3+-+        +-+3+-+        3+-+   3+-+
+--R       (- 2a e\|3 \|e  - 2b e\|3 \|d )log(- x\|e  + \|d )
+--R     + 
+--R                                 3+-+   3+-+
+--R          3+-+       3+-+      2x\|e  + \|d        +-+         3     3+-+2 3+-+2
+--R     (6a e\|e  - 6b e\|d )atan(-------------) - 2c\|3 log(- e x  + d)\|d   \|e
+--R                                   +-+3+-+
+--R                                  \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +-----------------------------------------+
+--R              |      2    2                           2
+--R              |- 9d e %%Y0  - 6c d e %%Y0 + 4a b e - c d
+--R         (- e |-----------------------------------------  - e %%Y0 - c)
+--R              |                      2
+--R             \|                  3d e
+--R      *
+--R         log
+--R                     2 2         2   2         2
+--R                (9b d e %%Y0 - 3a d e  + 3b c d e)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |      2    2                           2
+--R                 |- 9d e %%Y0  - 6c d e %%Y0 + 4a b e - c d
+--R                 |-----------------------------------------
+--R                 |                      2
+--R                \|                  3d e
+--R            + 
+--R                    2 2    2        2   2         2            3 2     3
+--R              - 9b d e %%Y0  + (- 3a d e  - 6b c d e)%%Y0 + (2a e  - 2b d e)x
+--R            + 
+--R                  2        2          2 2
+--R              (- a c + 2a b )d e - b c d
+--R     + 
+--R            +-----------------------------------------+
+--R            |      2    2                           2
+--R            |- 9d e %%Y0  - 6c d e %%Y0 + 4a b e - c d
+--R         (e |-----------------------------------------  - e %%Y0 - c)
+--R            |                      2
+--R           \|                  3d e
+--R      *
+--R         log
+--R                       2 2         2   2         2
+--R                (- 9b d e %%Y0 + 3a d e  - 3b c d e)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |      2    2                           2
+--R                 |- 9d e %%Y0  - 6c d e %%Y0 + 4a b e - c d
+--R                 |-----------------------------------------
+--R                 |                      2
+--R                \|                  3d e
+--R            + 
+--R                    2 2    2        2   2         2            3 2     3
+--R              - 9b d e %%Y0  + (- 3a d e  - 6b c d e)%%Y0 + (2a e  - 2b d e)x
+--R            + 
+--R                  2        2          2 2
+--R              (- a c + 2a b )d e - b c d
+--R     + 
+--R         2e %%Y0
+--R      *
+--R         log
+--R                  2 2    2      2   2         2           3 2    3
+--R              9b d e %%Y0  + (3a d e  + 6b c d e)%%Y0 + (a e  - b d e)x
+--R            + 
+--R                2        2          2 2
+--R              (a c - 2a b )d e + b c d
+--R  /
+--R     2e
+--R                                         Type: Union(Expression(Integer),...)
+--E 68
+
+--S 69 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +-----------------------------------------+
+--R                               |      2    2                           2
+--R                +-+3+-+2 3+-+2 |- 9d e %%Y0  - 6c d e %%Y0 + 4a b e - c d
+--R           - 3e\|3 \|d   \|e   |-----------------------------------------
+--R                               |                      2
+--R                              \|                  3d e
+--R         + 
+--R                +-+3+-+2 3+-+2         +-+3+-+2 3+-+2
+--R           - 3e\|3 \|d   \|e  %%Y - 3c\|3 \|d   \|e
+--R      *
+--R         log
+--R                     2 2         2   2         2
+--R                (9b d e %%Y0 - 3a d e  + 3b c d e)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |      2    2                           2
+--R                 |- 9d e %%Y0  - 6c d e %%Y0 + 4a b e - c d
+--R                 |-----------------------------------------
+--R                 |                      2
+--R                \|                  3d e
+--R            + 
+--R                    2 2    2        2   2         2            3 2     3
+--R              - 9b d e %%Y0  + (- 3a d e  - 6b c d e)%%Y0 + (2a e  - 2b d e)x
+--R            + 
+--R                  2        2          2 2
+--R              (- a c + 2a b )d e - b c d
+--R     + 
+--R                             +-----------------------------------------+
+--R                             |      2    2                           2
+--R              +-+3+-+2 3+-+2 |- 9d e %%Y0  - 6c d e %%Y0 + 4a b e - c d
+--R           3e\|3 \|d   \|e   |-----------------------------------------
+--R                             |                      2
+--R                            \|                  3d e
+--R         + 
+--R                +-+3+-+2 3+-+2         +-+3+-+2 3+-+2
+--R           - 3e\|3 \|d   \|e  %%Y - 3c\|3 \|d   \|e
+--R      *
+--R         log
+--R                       2 2         2   2         2
+--R                (- 9b d e %%Y0 + 3a d e  - 3b c d e)
+--R             *
+--R                 +-----------------------------------------+
+--R                 |      2    2                           2
+--R                 |- 9d e %%Y0  - 6c d e %%Y0 + 4a b e - c d
+--R                 |-----------------------------------------
+--R                 |                      2
+--R                \|                  3d e
+--R            + 
+--R                    2 2    2        2   2         2            3 2     3
+--R              - 9b d e %%Y0  + (- 3a d e  - 6b c d e)%%Y0 + (2a e  - 2b d e)x
+--R            + 
+--R                  2        2          2 2
+--R              (- a c + 2a b )d e - b c d
+--R     + 
+--R            +-+3+-+2 3+-+2
+--R         6e\|3 \|d   \|e  %%Y0
+--R      *
+--R         log
+--R                  2 2    2      2   2         2           3 2    3
+--R              9b d e %%Y0  + (3a d e  + 6b c d e)%%Y0 + (a e  - b d e)x
+--R            + 
+--R                2        2          2 2
+--R              (a c - 2a b )d e + b c d
+--R     + 
+--R              +-+3+-+       +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- a e\|3 \|e  - b e\|3 \|d )log(x  \|e  + x\|d \|e  + \|d  )
+--R     + 
+--R             +-+3+-+        +-+3+-+        3+-+   3+-+
+--R       (2a e\|3 \|e  + 2b e\|3 \|d )log(- x\|e  + \|d )
+--R     + 
+--R                                     3+-+   3+-+
+--R              3+-+       3+-+      2x\|e  + \|d
+--R       (- 6a e\|e  + 6b e\|d )atan(-------------)
+--R                                       +-+3+-+
+--R                                      \|3 \|d
+--R     + 
+--R          +-+         3     3+-+2 3+-+2
+--R       2c\|3 log(- e x  + d)\|d   \|e
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 70
+
+)clear all
+
+--S 71 of 953
+t0:=-C*x^2/(a+b*x^3)+(B*x+C*x^2)/(a+b*x^3)
+--R 
+--R
+--R           B x
+--R   (1)  --------
+--R           3
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 71
+
+--S 72 of 953
+r0:=-1/3*B*log(a^(1/3)+b^(1/3)*x)/(a^(1/3)*b^(2/3))+1/6*B*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(1/3)*b^(2/3))-B*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(1/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R         +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+     3+-+   3+-+
+--R       B\|3 log(x  \|b  - x\|a \|b  + \|a  ) - 2B\|3 log(x\|b  + \|a )
+--R     + 
+--R                 3+-+   3+-+
+--R               2x\|b  - \|a
+--R       6B atan(-------------)
+--R                   +-+3+-+
+--R                  \|3 \|a
+--R  /
+--R       +-+3+-+3+-+2
+--R     6\|3 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                     +------+2         +------+
+--R           +-+      3|     2        2 3|     2
+--R       - B\|3 log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R                                                      +------+2
+--R                    +------+2                     +-+3|     2         +-+
+--R          +-+      3|     2                    2x\|3 \|- a b    - a b\|3
+--R       2B\|3 log(x \|- a b    + a b) - 6B atan(--------------------------)
+--R                                                          3a b
+--R  /
+--R           +------+
+--R       +-+3|     2
+--R     6\|3 \|- a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 73
+
+--S 74 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +------+
+--R           +-+3|     2      2 3+-+2   3+-+3+-+   3+-+2
+--R       - B\|3 \|- a b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              +------+
+--R          +-+3|     2      3+-+   3+-+
+--R       2B\|3 \|- a b  log(x\|b  + \|a )
+--R     + 
+--R                              +------+2         +------+
+--R           +-+3+-+3+-+2      3|     2        2 3|     2
+--R       - B\|3 \|a \|b  log(x \|- a b    + b x  \|- a b  - a b)
+--R     + 
+--R                             +------+2             +------+       3+-+   3+-+
+--R          +-+3+-+3+-+2      3|     2              3|     2      2x\|b  - \|a
+--R       2B\|3 \|a \|b  log(x \|- a b    + a b) - 6B\|- a b  atan(-------------)
+--R                                                                    +-+3+-+
+--R                                                                   \|3 \|a
+--R     + 
+--R                                +------+2
+--R                            +-+3|     2         +-+
+--R           3+-+3+-+2     2x\|3 \|- a b    - a b\|3
+--R       - 6B\|a \|b  atan(--------------------------)
+--R                                    3a b
+--R  /
+--R           +------+
+--R       +-+3|     2 3+-+3+-+2
+--R     6\|3 \|- a b  \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 953
+t0:=-C*x^2/(a+b*x^3)+(A+C*x^2)/(a+b*x^3)
+--R 
+--R
+--R            A
+--R   (1)  --------
+--R           3
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 76
+
+--S 77 of 953
+r0:=1/3*A*log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*b^(1/3))-1/6*A*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(2/3)*b^(1/3))-A*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+     3+-+   3+-+
+--R       - A\|3 log(x  \|b  - x\|a \|b  + \|a  ) + 2A\|3 log(x\|b  + \|a )
+--R     + 
+--R                 3+-+   3+-+
+--R               2x\|b  - \|a
+--R       6A atan(-------------)
+--R                   +-+3+-+
+--R                  \|3 \|a
+--R  /
+--R       +-+3+-+2 3+-+
+--R     6\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +---+2      +---+                     +---+
+--R           +-+     2 3| 2        3| 2      2       +-+     3| 2
+--R       - A\|3 log(x  \|a b  - a x\|a b  + a ) + 2A\|3 log(x\|a b  + a)
+--R     + 
+--R                      +---+
+--R                  +-+3| 2       +-+
+--R               2x\|3 \|a b  - a\|3
+--R       6A atan(--------------------)
+--R                        3a
+--R  /
+--R           +---+
+--R       +-+3| 2
+--R     6\|3 \|a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 78
+
+--S 79 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                +---+2      +---+
+--R           +-+3+-+2 3+-+     2 3| 2        3| 2      2
+--R       - A\|3 \|a   \|b log(x  \|a b  - a x\|a b  + a )
+--R     + 
+--R                             +---+
+--R          +-+3+-+2 3+-+     3| 2
+--R       2A\|3 \|a   \|b log(x\|a b  + a)
+--R     + 
+--R             +---+
+--R         +-+3| 2       2 3+-+2   3+-+3+-+   3+-+2
+--R       A\|3 \|a b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                                                                  +---+
+--R                +---+                                         +-+3| 2       +-+
+--R            +-+3| 2       3+-+   3+-+       3+-+2 3+-+     2x\|3 \|a b  - a\|3
+--R       - 2A\|3 \|a b log(x\|b  + \|a ) + 6A \|a   \|b atan(--------------------)
+--R                                                                    3a
+--R     + 
+--R            +---+       3+-+   3+-+
+--R           3| 2       2x\|b  - \|a
+--R       - 6A\|a b atan(-------------)
+--R                          +-+3+-+
+--R                         \|3 \|a
+--R  /
+--R                     +---+
+--R       +-+3+-+2 3+-+3| 2
+--R     6\|3 \|a   \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 80
+
+)clear all
+
+--S 81 of 953
+t0:=-C*x^2/(a+b*x^3)+(A+B*x+C*x^2)/(a+b*x^3)
+--R 
+--R
+--R         B x + A
+--R   (1)  --------
+--R           3
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 81
+
+--S 82 of 953
+r0:=1/3*(A*b^(1/3)-a^(1/3)*B)*log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*b^(2/3))-_
+   1/6*(A-a^(1/3)*B/b^(1/3))*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(2/3)*b^(1/3))-(A*b^(1/3)+a^(1/3)*B)*atan((a^(1/3)-2*b^(1/3)*x)/_
+   (a^(1/3)*sqrt(3)))/(a^(2/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- A\|3 \|b  + B\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (2A\|3 \|b  - 2B\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                               3+-+   3+-+
+--R          3+-+     3+-+      2x\|b  - \|a
+--R       (6A\|b  + 6B\|a )atan(-------------)
+--R                                 +-+3+-+
+--R                                \|3 \|a
+--R  /
+--R       +-+3+-+2 3+-+2
+--R     6\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +--------------------+
+--R             |            2
+--R             |- 9a b %%BB0  - 4A B
+--R         (-  |--------------------  - %%BB0)
+--R            \|        3a b
+--R      *
+--R         log
+--R                                      +--------------------+
+--R                                      |            2
+--R                   2            2     |- 9a b %%BB0  - 4A B        2       2
+--R              (9B a b %%BB0 - 3A a b) |--------------------  - 9B a b %%BB0
+--R                                     \|        3a b
+--R            + 
+--R                  2               3      3          2
+--R              - 3A a b %%BB0 + (2A b + 2B a)x - 2A B a
+--R     + 
+--R           +--------------------+
+--R           |            2
+--R           |- 9a b %%BB0  - 4A B
+--R         ( |--------------------  - %%BB0)
+--R          \|        3a b
+--R      *
+--R         log
+--R                                        +--------------------+
+--R                                        |            2
+--R                     2            2     |- 9a b %%BB0  - 4A B        2       2
+--R              (- 9B a b %%BB0 + 3A a b) |--------------------  - 9B a b %%BB0
+--R                                       \|        3a b
+--R            + 
+--R                  2               3      3          2
+--R              - 3A a b %%BB0 + (2A b + 2B a)x - 2A B a
+--R     + 
+--R                      2       2     2              3     3          2
+--R       2%%BB0 log(9B a b %%BB0  + 3A a b %%BB0 + (A b + B a)x + 2A B a)
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 83
+
+--S 84 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +--------------------+
+--R                             |            2
+--R              +-+3+-+2 3+-+2 |- 9a b %%BB0  - 4A B     +-+3+-+2 3+-+2
+--R         (- 3\|3 \|a   \|b   |-------------------- - 3\|3 \|a   \|b  %%BB)
+--R                            \|        3a b
+--R      *
+--R         log
+--R                                      +--------------------+
+--R                                      |            2
+--R                   2            2     |- 9a b %%BB0  - 4A B        2       2
+--R              (9B a b %%BB0 - 3A a b) |--------------------  - 9B a b %%BB0
+--R                                     \|        3a b
+--R            + 
+--R                  2               3      3          2
+--R              - 3A a b %%BB0 + (2A b + 2B a)x - 2A B a
+--R     + 
+--R                           +--------------------+
+--R                           |            2
+--R            +-+3+-+2 3+-+2 |- 9a b %%BB0  - 4A B     +-+3+-+2 3+-+2
+--R         (3\|3 \|a   \|b   |-------------------- - 3\|3 \|a   \|b  %%BB)
+--R                          \|        3a b
+--R      *
+--R         log
+--R                                        +--------------------+
+--R                                        |            2
+--R                     2            2     |- 9a b %%BB0  - 4A B        2       2
+--R              (- 9B a b %%BB0 + 3A a b) |--------------------  - 9B a b %%BB0
+--R                                       \|        3a b
+--R            + 
+--R                  2               3      3          2
+--R              - 3A a b %%BB0 + (2A b + 2B a)x - 2A B a
+--R     + 
+--R           +-+3+-+2 3+-+2
+--R         6\|3 \|a   \|b  %%BB0
+--R      *
+--R                 2       2     2              3     3          2
+--R         log(9B a b %%BB0  + 3A a b %%BB0 + (A b + B a)x + 2A B a)
+--R     + 
+--R          +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (A\|3 \|b  - B\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (- 2A\|3 \|b  + 2B\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                 3+-+   3+-+
+--R            3+-+     3+-+      2x\|b  - \|a
+--R       (- 6A\|b  - 6B\|a )atan(-------------)
+--R                                   +-+3+-+
+--R                                  \|3 \|a
+--R  /
+--R       +-+3+-+2 3+-+2
+--R     6\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 953
+t0:=(a+b*x)^2/(c+d*x^3)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                3
+--R             d x  + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 86
+
+--S 87 of 953
+r0:=-1/3*a*(2*b*c^(1/3)-a*d^(1/3))*log(c^(1/3)+d^(1/3)*x)/(c^(2/3)*d^(2/3))+_
+   1/6*a*(2*b*c^(1/3)-a*d^(1/3))*log(c^(2/3)-c^(1/3)*d^(1/3)*x+d^(2/3)*_
+   x^2)/(c^(2/3)*d^(2/3))+1/3*b^2*log(c+d*x^3)/d-a*(2*b*c^(1/3)+_
+   a*d^(1/3))*atan((c^(1/3)-2*d^(1/3)*x)/(c^(1/3)*sqrt(3)))/(c^(2/3)*_
+   d^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           2  +-+3+-+          +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- a d\|3 \|d  + 2a b d\|3 \|c )log(x  \|d  - x\|c \|d  + \|c  )
+--R     + 
+--R          2  +-+3+-+          +-+3+-+      3+-+   3+-+
+--R       (2a d\|3 \|d  - 4a b d\|3 \|c )log(x\|d  + \|c )
+--R     + 
+--R                                      3+-+   3+-+
+--R          2 3+-+          3+-+      2x\|d  - \|c
+--R       (6a d\|d  + 12a b d\|c )atan(-------------)
+--R                                        +-+3+-+
+--R                                       \|3 \|c
+--R     + 
+--R         2 +-+       3     3+-+2 3+-+2
+--R       2b \|3 log(d x  + c)\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +-------------------------------------------+
+--R              |      2     2     2              3       4
+--R              |- 9c d %%BC0  + 6b c d %%BC0 - 8a b d - b c               2
+--R         (- d |-------------------------------------------  - d %%BC0 + b )
+--R              |                       2
+--R             \|                   3c d
+--R      *
+--R         log
+--R                      2 2          3   2     3 2
+--R                (18b c d %%BC0 - 3a c d  - 6b c d)
+--R             *
+--R                 +-------------------------------------------+
+--R                 |      2     2     2              3       4
+--R                 |- 9c d %%BC0  + 6b c d %%BC0 - 8a b d - b c
+--R                 |-------------------------------------------
+--R                 |                       2
+--R                \|                   3c d
+--R            + 
+--R                     2 2     2        3   2      3 2
+--R              - 18b c d %%BC0  + (- 3a c d  + 12b c d)%%BC0
+--R            + 
+--R                 5 2      2 3          3 2        5 2
+--R              (2a d  + 16a b c d)x - 7a b c d - 2b c
+--R     + 
+--R            +-------------------------------------------+
+--R            |      2     2     2              3       4
+--R            |- 9c d %%BC0  + 6b c d %%BC0 - 8a b d - b c               2
+--R         (d |-------------------------------------------  - d %%BC0 + b )
+--R            |                       2
+--R           \|                   3c d
+--R      *
+--R         log
+--R                        2 2          3   2     3 2
+--R                (- 18b c d %%BC0 + 3a c d  + 6b c d)
+--R             *
+--R                 +-------------------------------------------+
+--R                 |      2     2     2              3       4
+--R                 |- 9c d %%BC0  + 6b c d %%BC0 - 8a b d - b c
+--R                 |-------------------------------------------
+--R                 |                       2
+--R                \|                   3c d
+--R            + 
+--R                     2 2     2        3   2      3 2
+--R              - 18b c d %%BC0  + (- 3a c d  + 12b c d)%%BC0
+--R            + 
+--R                 5 2      2 3          3 2        5 2
+--R              (2a d  + 16a b c d)x - 7a b c d - 2b c
+--R     + 
+--R         2d %%BC0
+--R      *
+--R         log
+--R                   2 2     2      3   2      3 2            5 2     2 3
+--R              18b c d %%BC0  + (3a c d  - 12b c d)%%BC0 + (a d  + 8a b c d)x
+--R            + 
+--R                3 2        5 2
+--R              7a b c d + 2b c
+--R  /
+--R     2d
+--R                                         Type: Union(Expression(Integer),...)
+--E 88
+
+--S 89 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +-------------------------------------------+
+--R                               |      2     2     2              3       4
+--R                +-+3+-+2 3+-+2 |- 9c d %%BC0  + 6b c d %%BC0 - 8a b d - b c
+--R           - 3d\|3 \|c   \|d   |-------------------------------------------
+--R                               |                       2
+--R                              \|                   3c d
+--R         + 
+--R                +-+3+-+2 3+-+2         2 +-+3+-+2 3+-+2
+--R           - 3d\|3 \|c   \|d  %%BC + 3b \|3 \|c   \|d
+--R      *
+--R         log
+--R                      2 2          3   2     3 2
+--R                (18b c d %%BC0 - 3a c d  - 6b c d)
+--R             *
+--R                 +-------------------------------------------+
+--R                 |      2     2     2              3       4
+--R                 |- 9c d %%BC0  + 6b c d %%BC0 - 8a b d - b c
+--R                 |-------------------------------------------
+--R                 |                       2
+--R                \|                   3c d
+--R            + 
+--R                     2 2     2        3   2      3 2
+--R              - 18b c d %%BC0  + (- 3a c d  + 12b c d)%%BC0
+--R            + 
+--R                 5 2      2 3          3 2        5 2
+--R              (2a d  + 16a b c d)x - 7a b c d - 2b c
+--R     + 
+--R                             +-------------------------------------------+
+--R                             |      2     2     2              3       4
+--R              +-+3+-+2 3+-+2 |- 9c d %%BC0  + 6b c d %%BC0 - 8a b d - b c
+--R           3d\|3 \|c   \|d   |-------------------------------------------
+--R                             |                       2
+--R                            \|                   3c d
+--R         + 
+--R                +-+3+-+2 3+-+2         2 +-+3+-+2 3+-+2
+--R           - 3d\|3 \|c   \|d  %%BC + 3b \|3 \|c   \|d
+--R      *
+--R         log
+--R                        2 2          3   2     3 2
+--R                (- 18b c d %%BC0 + 3a c d  + 6b c d)
+--R             *
+--R                 +-------------------------------------------+
+--R                 |      2     2     2              3       4
+--R                 |- 9c d %%BC0  + 6b c d %%BC0 - 8a b d - b c
+--R                 |-------------------------------------------
+--R                 |                       2
+--R                \|                   3c d
+--R            + 
+--R                     2 2     2        3   2      3 2
+--R              - 18b c d %%BC0  + (- 3a c d  + 12b c d)%%BC0
+--R            + 
+--R                 5 2      2 3          3 2        5 2
+--R              (2a d  + 16a b c d)x - 7a b c d - 2b c
+--R     + 
+--R            +-+3+-+2 3+-+2
+--R         6d\|3 \|c   \|d  %%BC0
+--R      *
+--R         log
+--R                   2 2     2      3   2      3 2            5 2     2 3
+--R              18b c d %%BC0  + (3a c d  - 12b c d)%%BC0 + (a d  + 8a b c d)x
+--R            + 
+--R                3 2        5 2
+--R              7a b c d + 2b c
+--R     + 
+--R         2  +-+3+-+          +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (a d\|3 \|d  - 2a b d\|3 \|c )log(x  \|d  - x\|c \|d  + \|c  )
+--R     + 
+--R            2  +-+3+-+          +-+3+-+      3+-+   3+-+
+--R       (- 2a d\|3 \|d  + 4a b d\|3 \|c )log(x\|d  + \|c )
+--R     + 
+--R                                        3+-+   3+-+
+--R            2 3+-+          3+-+      2x\|d  - \|c
+--R       (- 6a d\|d  - 12a b d\|c )atan(-------------)
+--R                                          +-+3+-+
+--R                                         \|3 \|c
+--R     + 
+--R           2 +-+       3     3+-+2 3+-+2
+--R       - 2b \|3 log(d x  + c)\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 953
+t0:=(a+b*x)^3/(c+d*x^3)
+--R 
+--R
+--R         3 3       2 2     2       3
+--R        b x  + 3a b x  + 3a b x + a
+--R   (1)  ----------------------------
+--R                     3
+--R                  d x  + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 91
+
+--S 92 of 953
+r0:=b^3*x/d-1/3*(b^3*c+3*a^2*b*c^(1/3)*d^(2/3)-a^3*d)*log(c^(1/3)+_
+   d^(1/3)*x)/(c^(2/3)*d^(4/3))+1/6*(b^3*c+3*a^2*b*c^(1/3)*d^(2/3)-_
+   a^3*d)*log(c^(2/3)-c^(1/3)*d^(1/3)*x+d^(2/3)*x^2)/(c^(2/3)*d^(4/3))+_
+   a*b^2*log(c+d*x^3)/d+(b^3*c-3*a^2*b*c^(1/3)*d^(2/3)-a^3*d)*_
+   atan((c^(1/3)-2*d^(1/3)*x)/(c^(1/3)*sqrt(3)))/(c^(2/3)*d^(4/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          2  +-+3+-+3+-+2       3     3   +-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (3a b\|3 \|c \|d   + (- a d + b c)\|3 )log(x  \|d  - x\|c \|d  + \|c  )
+--R     + 
+--R            2  +-+3+-+3+-+2      3      3   +-+      3+-+   3+-+
+--R       (- 6a b\|3 \|c \|d   + (2a d - 2b c)\|3 )log(x\|d  + \|c )
+--R     + 
+--R                                            3+-+   3+-+
+--R           2 3+-+3+-+2     3      3       2x\|d  - \|c
+--R       (18a b\|c \|d   + 6a d - 6b c)atan(-------------)
+--R                                              +-+3+-+
+--R                                             \|3 \|c
+--R     + 
+--R            2 +-+       3          3  +-+ 3+-+2 3+-+
+--R       (6a b \|3 log(d x  + c) + 6b x\|3 )\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 +-----------------------------------------------+
+--R                 |      2     2       2              5       2 4
+--R                 |- 3c d %%BD0  + 6a b c d %%BD0 - 4a b d + a b c
+--R             - d |-----------------------------------------------  - d %%BD0
+--R                 |                         2
+--R                \|                      c d
+--R           + 
+--R                 2
+--R             3a b
+--R      *
+--R         log
+--R                    2   2 3          6   3      3 3 2 2     6 3
+--R                (27a b c d %%BD0 - 3a c d  - 21a b c d  - 3b c d)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |      2     2       2              5       2 4
+--R                 |- 3c d %%BD0  + 6a b c d %%BD0 - 4a b d + a b c
+--R                 |-----------------------------------------------
+--R                 |                         2
+--R                \|                      c d
+--R            + 
+--R                   2   2 3     2        6   3      3 3 2 2     6 3
+--R              - 27a b c d %%BD0  + (- 3a c d  + 60a b c d  - 3b c d)%%BD0
+--R            + 
+--R                 9 3      6 3   2     3 6 2      9 3        7 2   2      4 5 2
+--R              (2a d  + 48a b c d  + 6a b c d - 2b c )x - 15a b c d  - 15a b c d
+--R            + 
+--R                  8 3
+--R              3a b c
+--R     + 
+--R            +-----------------------------------------------+
+--R            |      2     2       2              5       2 4
+--R            |- 3c d %%BD0  + 6a b c d %%BD0 - 4a b d + a b c                  2
+--R         (d |-----------------------------------------------  - d %%BD0 + 3a b )
+--R            |                         2
+--R           \|                      c d
+--R      *
+--R         log
+--R                      2   2 3          6   3      3 3 2 2     6 3
+--R                (- 27a b c d %%BD0 + 3a c d  + 21a b c d  + 3b c d)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |      2     2       2              5       2 4
+--R                 |- 3c d %%BD0  + 6a b c d %%BD0 - 4a b d + a b c
+--R                 |-----------------------------------------------
+--R                 |                         2
+--R                \|                      c d
+--R            + 
+--R                   2   2 3     2        6   3      3 3 2 2     6 3
+--R              - 27a b c d %%BD0  + (- 3a c d  + 60a b c d  - 3b c d)%%BD0
+--R            + 
+--R                 9 3      6 3   2     3 6 2      9 3        7 2   2      4 5 2
+--R              (2a d  + 48a b c d  + 6a b c d - 2b c )x - 15a b c d  - 15a b c d
+--R            + 
+--R                  8 3
+--R              3a b c
+--R     + 
+--R         2d %%BD0
+--R      *
+--R         log
+--R                 2   2 3     2      6   3      3 3 2 2     6 3
+--R              27a b c d %%BD0  + (3a c d  - 60a b c d  + 3b c d)%%BD0
+--R            + 
+--R                9 3      6 3   2     3 6 2     9 3        7 2   2      4 5 2
+--R              (a d  + 24a b c d  + 3a b c d - b c )x + 15a b c d  + 15a b c d
+--R            + 
+--R                    8 3
+--R              - 3a b c
+--R     + 
+--R         3
+--R       2b x
+--R  /
+--R     2d
+--R                                         Type: Union(Expression(Integer),...)
+--E 93
+
+--S 94 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              +-----------------------------------------------+
+--R                              |      2     2       2              5       2 4
+--R                +-+3+-+2 3+-+ |- 3c d %%BD0  + 6a b c d %%BD0 - 4a b d + a b c
+--R           - 3d\|3 \|c   \|d  |-----------------------------------------------
+--R                              |                         2
+--R                             \|                      c d
+--R         + 
+--R                +-+3+-+2 3+-+           2 +-+3+-+2 3+-+
+--R           - 3d\|3 \|c   \|d %%BD + 9a b \|3 \|c   \|d
+--R      *
+--R         log
+--R                    2   2 3          6   3      3 3 2 2     6 3
+--R                (27a b c d %%BD0 - 3a c d  - 21a b c d  - 3b c d)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |      2     2       2              5       2 4
+--R                 |- 3c d %%BD0  + 6a b c d %%BD0 - 4a b d + a b c
+--R                 |-----------------------------------------------
+--R                 |                         2
+--R                \|                      c d
+--R            + 
+--R                   2   2 3     2        6   3      3 3 2 2     6 3
+--R              - 27a b c d %%BD0  + (- 3a c d  + 60a b c d  - 3b c d)%%BD0
+--R            + 
+--R                 9 3      6 3   2     3 6 2      9 3        7 2   2      4 5 2
+--R              (2a d  + 48a b c d  + 6a b c d - 2b c )x - 15a b c d  - 15a b c d
+--R            + 
+--R                  8 3
+--R              3a b c
+--R     + 
+--R                            +-----------------------------------------------+
+--R                            |      2     2       2              5       2 4
+--R              +-+3+-+2 3+-+ |- 3c d %%BD0  + 6a b c d %%BD0 - 4a b d + a b c
+--R           3d\|3 \|c   \|d  |-----------------------------------------------
+--R                            |                         2
+--R                           \|                      c d
+--R         + 
+--R                +-+3+-+2 3+-+           2 +-+3+-+2 3+-+
+--R           - 3d\|3 \|c   \|d %%BD + 9a b \|3 \|c   \|d
+--R      *
+--R         log
+--R                      2   2 3          6   3      3 3 2 2     6 3
+--R                (- 27a b c d %%BD0 + 3a c d  + 21a b c d  + 3b c d)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |      2     2       2              5       2 4
+--R                 |- 3c d %%BD0  + 6a b c d %%BD0 - 4a b d + a b c
+--R                 |-----------------------------------------------
+--R                 |                         2
+--R                \|                      c d
+--R            + 
+--R                   2   2 3     2        6   3      3 3 2 2     6 3
+--R              - 27a b c d %%BD0  + (- 3a c d  + 60a b c d  - 3b c d)%%BD0
+--R            + 
+--R                 9 3      6 3   2     3 6 2      9 3        7 2   2      4 5 2
+--R              (2a d  + 48a b c d  + 6a b c d - 2b c )x - 15a b c d  - 15a b c d
+--R            + 
+--R                  8 3
+--R              3a b c
+--R     + 
+--R            +-+3+-+2 3+-+
+--R         6d\|3 \|c   \|d %%BD0
+--R      *
+--R         log
+--R                 2   2 3     2      6   3      3 3 2 2     6 3
+--R              27a b c d %%BD0  + (3a c d  - 60a b c d  + 3b c d)%%BD0
+--R            + 
+--R                9 3      6 3   2     3 6 2     9 3        7 2   2      4 5 2
+--R              (a d  + 24a b c d  + 3a b c d - b c )x + 15a b c d  + 15a b c d
+--R            + 
+--R                    8 3
+--R              - 3a b c
+--R     + 
+--R            2  +-+3+-+3+-+2     3     3   +-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- 3a b\|3 \|c \|d   + (a d - b c)\|3 )log(x  \|d  - x\|c \|d  + \|c  )
+--R     + 
+--R          2  +-+3+-+3+-+2        3      3   +-+      3+-+   3+-+
+--R       (6a b\|3 \|c \|d   + (- 2a d + 2b c)\|3 )log(x\|d  + \|c )
+--R     + 
+--R                                              3+-+   3+-+
+--R             2 3+-+3+-+2     3      3       2x\|d  - \|c
+--R       (- 18a b\|c \|d   - 6a d + 6b c)atan(-------------)
+--R                                                +-+3+-+
+--R                                               \|3 \|c
+--R     + 
+--R             2 +-+       3     3+-+2 3+-+
+--R       - 6a b \|3 log(d x  + c)\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 95
+
+)clear all
+
+--S 96 of 953
+t0:=(a+b*x)^4/(c+d*x^3)
+--R 
+--R
+--R         4 4       3 3     2 2 2     3       4
+--R        b x  + 4a b x  + 6a b x  + 4a b x + a
+--R   (1)  --------------------------------------
+--R                          3
+--R                       d x  + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 96
+
+--S 97 of 953
+r0:=4*a*b^3*x/d+1/2*b^4*x^2/d+1/3*(b*c^(1/3)*(b^3*c-4*a^3*d)-d^(1/3)*_
+   (4*a*b^3*c-a^4*d))*log(c^(1/3)+d^(1/3)*x)/(c^(2/3)*d^(5/3))-_
+   1/6*(b*c^(1/3)*(b^3*c-4*a^3*d)-d^(1/3)*(4*a*b^3*c-a^4*d))*log(c^(2/3)-_
+   c^(1/3)*d^(1/3)*x+d^(2/3)*x^2)/(c^(2/3)*d^(5/3))+2*a^2*b^2*_
+   log(c+d*x^3)/d+(b^4*c^(4/3)+4*a*b^3*c*d^(1/3)-4*a^3*b*c^(1/3)*d-_
+   a^4*d^(4/3))*atan((c^(1/3)-2*d^(1/3)*x)/(c^(1/3)*sqrt(3)))/_
+   (c^(2/3)*d^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              4        3   +-+3+-+      3       4   +-+3+-+
+--R         ((- a d + 4a b c)\|3 \|d  + (4a b d - b c)\|3 \|c )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|d  - x\|c \|d  + \|c  )
+--R     + 
+--R           4        3   +-+3+-+        3        4   +-+3+-+      3+-+   3+-+
+--R       ((2a d - 8a b c)\|3 \|d  + (- 8a b d + 2b c)\|3 \|c )log(x\|d  + \|c )
+--R     + 
+--R                                                           3+-+   3+-+
+--R           4         3  3+-+       3        4  3+-+      2x\|d  - \|c
+--R       ((6a d - 24a b c)\|d  + (24a b d - 6b c)\|c )atan(-------------)
+--R                                                             +-+3+-+
+--R                                                            \|3 \|c
+--R     + 
+--R           2 2 +-+       3           4 2        3   +-+ 3+-+2 3+-+2
+--R       (12a b \|3 log(d x  + c) + (3b x  + 24a b x)\|3 )\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BE0  + 36a b c d %%BE0 - 16a b d  + 32a b c d
+--R                     + 
+--R                              7 2
+--R                       - 16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R         + 
+--R                         2 2
+--R           - d %%BE0 + 6a b
+--R      *
+--R         log
+--R                        3   2 4     4 3 3           8   4      5 3 2 3
+--R                    (36a b c d  - 9b c d )%%BE0 - 3a c d  - 48a b c d
+--R                  + 
+--R                         2 6 3 2
+--R                    - 30a b c d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BE0  + 36a b c d %%BE0 - 16a b d  + 32a b c d
+--R                     + 
+--R                              7 2
+--R                       - 16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R            + 
+--R                    3   2 4     4 3 3      2
+--R              (- 36a b c d  + 9b c d )%%BE0
+--R            + 
+--R                   8   4       5 3 2 3      2 6 3 2
+--R              (- 3a c d  + 168a b c d  - 84a b c d )%%BE0
+--R            + 
+--R                 12 4       9 3   3       3 9 3      12 4        10 2   3
+--R              (2a  d  + 104a b c d  - 104a b c d - 2b  c )x - 26a  b c d
+--R            + 
+--R                   7 5 2 2      4 8 3        11 4
+--R              - 48a b c d  + 66a b c d + 8a b  c
+--R     + 
+--R             +-----------------------------------------------------------------+
+--R             |      3     2      2 2   2           7   2      4 4           7 2
+--R             |- 9c d %%BE0  + 36a b c d %%BE0 - 16a b d  + 32a b c d - 16a b c
+--R           d |-----------------------------------------------------------------
+--R             |                                  3
+--R            \|                              3c d
+--R         + 
+--R                         2 2
+--R           - d %%BE0 + 6a b
+--R      *
+--R         log
+--R                        3   2 4     4 3 3           8   4      5 3 2 3
+--R                  (- 36a b c d  + 9b c d )%%BE0 + 3a c d  + 48a b c d
+--R                + 
+--R                     2 6 3 2
+--R                  30a b c d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BE0  + 36a b c d %%BE0 - 16a b d  + 32a b c d
+--R                     + 
+--R                              7 2
+--R                       - 16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R            + 
+--R                    3   2 4     4 3 3      2
+--R              (- 36a b c d  + 9b c d )%%BE0
+--R            + 
+--R                   8   4       5 3 2 3      2 6 3 2
+--R              (- 3a c d  + 168a b c d  - 84a b c d )%%BE0
+--R            + 
+--R                 12 4       9 3   3       3 9 3      12 4        10 2   3
+--R              (2a  d  + 104a b c d  - 104a b c d - 2b  c )x - 26a  b c d
+--R            + 
+--R                   7 5 2 2      4 8 3        11 4
+--R              - 48a b c d  + 66a b c d + 8a b  c
+--R     + 
+--R         2d %%BE0
+--R      *
+--R         log
+--R                  3   2 4     4 3 3      2
+--R              (36a b c d  - 9b c d )%%BE0
+--R            + 
+--R                 8   4       5 3 2 3      2 6 3 2
+--R              (3a c d  - 168a b c d  + 84a b c d )%%BE0
+--R            + 
+--R                12 4      9 3   3      3 9 3     12 4        10 2   3
+--R              (a  d  + 52a b c d  - 52a b c d - b  c )x + 26a  b c d
+--R            + 
+--R                 7 5 2 2      4 8 3        11 4
+--R              48a b c d  - 66a b c d - 8a b  c
+--R     + 
+--R        4 2       3
+--R       b x  + 8a b x
+--R  /
+--R     2d
+--R                                         Type: Union(Expression(Integer),...)
+--E 98
+
+--S 99 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                   +-+3+-+2 3+-+2
+--R                3d\|3 \|c   \|d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BE0  + 36a b c d %%BE0 - 16a b d  + 32a b c d
+--R                     + 
+--R                              7 2
+--R                       - 16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R         + 
+--R                +-+3+-+2 3+-+2          2 2 +-+3+-+2 3+-+2
+--R           - 3d\|3 \|c   \|d  %%BE + 18a b \|3 \|c   \|d
+--R      *
+--R         log
+--R                        3   2 4     4 3 3           8   4      5 3 2 3
+--R                    (36a b c d  - 9b c d )%%BE0 - 3a c d  - 48a b c d
+--R                  + 
+--R                         2 6 3 2
+--R                    - 30a b c d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BE0  + 36a b c d %%BE0 - 16a b d  + 32a b c d
+--R                     + 
+--R                              7 2
+--R                       - 16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R            + 
+--R                    3   2 4     4 3 3      2
+--R              (- 36a b c d  + 9b c d )%%BE0
+--R            + 
+--R                   8   4       5 3 2 3      2 6 3 2
+--R              (- 3a c d  + 168a b c d  - 84a b c d )%%BE0
+--R            + 
+--R                 12 4       9 3   3       3 9 3      12 4        10 2   3
+--R              (2a  d  + 104a b c d  - 104a b c d - 2b  c )x - 26a  b c d
+--R            + 
+--R                   7 5 2 2      4 8 3        11 4
+--R              - 48a b c d  + 66a b c d + 8a b  c
+--R     + 
+--R                +-+3+-+2 3+-+2
+--R             3d\|3 \|c   \|d
+--R          *
+--R            +-----------------------------------------------------------------+
+--R            |      3     2      2 2   2           7   2      4 4           7 2
+--R            |- 9c d %%BE0  + 36a b c d %%BE0 - 16a b d  + 32a b c d - 16a b c
+--R            |-----------------------------------------------------------------
+--R            |                                  3
+--R           \|                              3c d
+--R         + 
+--R                +-+3+-+2 3+-+2          2 2 +-+3+-+2 3+-+2
+--R           - 3d\|3 \|c   \|d  %%BE + 18a b \|3 \|c   \|d
+--R      *
+--R         log
+--R                        3   2 4     4 3 3           8   4      5 3 2 3
+--R                  (- 36a b c d  + 9b c d )%%BE0 + 3a c d  + 48a b c d
+--R                + 
+--R                     2 6 3 2
+--R                  30a b c d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BE0  + 36a b c d %%BE0 - 16a b d  + 32a b c d
+--R                     + 
+--R                              7 2
+--R                       - 16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R            + 
+--R                    3   2 4     4 3 3      2
+--R              (- 36a b c d  + 9b c d )%%BE0
+--R            + 
+--R                   8   4       5 3 2 3      2 6 3 2
+--R              (- 3a c d  + 168a b c d  - 84a b c d )%%BE0
+--R            + 
+--R                 12 4       9 3   3       3 9 3      12 4        10 2   3
+--R              (2a  d  + 104a b c d  - 104a b c d - 2b  c )x - 26a  b c d
+--R            + 
+--R                   7 5 2 2      4 8 3        11 4
+--R              - 48a b c d  + 66a b c d + 8a b  c
+--R     + 
+--R            +-+3+-+2 3+-+2
+--R         6d\|3 \|c   \|d  %%BE0
+--R      *
+--R         log
+--R                  3   2 4     4 3 3      2
+--R              (36a b c d  - 9b c d )%%BE0
+--R            + 
+--R                 8   4       5 3 2 3      2 6 3 2
+--R              (3a c d  - 168a b c d  + 84a b c d )%%BE0
+--R            + 
+--R                12 4      9 3   3      3 9 3     12 4        10 2   3
+--R              (a  d  + 52a b c d  - 52a b c d - b  c )x + 26a  b c d
+--R            + 
+--R                 7 5 2 2      4 8 3        11 4
+--R              48a b c d  - 66a b c d - 8a b  c
+--R     + 
+--R            4        3   +-+3+-+        3       4   +-+3+-+
+--R         ((a d - 4a b c)\|3 \|d  + (- 4a b d + b c)\|3 \|c )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|d  - x\|c \|d  + \|c  )
+--R     + 
+--R             4        3   +-+3+-+      3        4   +-+3+-+      3+-+   3+-+
+--R       ((- 2a d + 8a b c)\|3 \|d  + (8a b d - 2b c)\|3 \|c )log(x\|d  + \|c )
+--R     + 
+--R                                                               3+-+   3+-+
+--R             4         3  3+-+         3        4  3+-+      2x\|d  - \|c
+--R       ((- 6a d + 24a b c)\|d  + (- 24a b d + 6b c)\|c )atan(-------------)
+--R                                                                 +-+3+-+
+--R                                                                \|3 \|c
+--R     + 
+--R            2 2 +-+       3     3+-+2 3+-+2
+--R       - 12a b \|3 log(d x  + c)\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 100
+
+)clear all
+
+--S 101 of 953
+t0:=(a+b*x)^2/(c-d*x^3)
+--R 
+--R
+--R           2 2             2
+--R        - b x  - 2a b x - a
+--R   (1)  --------------------
+--R                 3
+--R              d x  - c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 101
+
+--S 102 of 953
+r0:=-1/3*a*(2*b*c^(1/3)+a*d^(1/3))*log(c^(1/3)-d^(1/3)*x)/(c^(2/3)*d^(2/3))+_
+   1/6*a*(2*b*c^(1/3)+a*d^(1/3))*log(c^(2/3)+c^(1/3)*d^(1/3)*x+d^(2/3)*_
+   x^2)/(c^(2/3)*d^(2/3))-1/3*b^2*log(c-d*x^3)/d-a*(2*b*c^(1/3)-_
+   a*d^(1/3))*atan((c^(1/3)+2*d^(1/3)*x)/(c^(1/3)*sqrt(3)))/(c^(2/3)*_
+   d^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R         2  +-+3+-+          +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (a d\|3 \|d  + 2a b d\|3 \|c )log(x  \|d  + x\|c \|d  + \|c  )
+--R     + 
+--R            2  +-+3+-+          +-+3+-+        3+-+   3+-+
+--R       (- 2a d\|3 \|d  - 4a b d\|3 \|c )log(- x\|d  + \|c )
+--R     + 
+--R                                      3+-+   3+-+
+--R          2 3+-+          3+-+      2x\|d  + \|c
+--R       (6a d\|d  - 12a b d\|c )atan(-------------)
+--R                                        +-+3+-+
+--R                                       \|3 \|c
+--R     + 
+--R           2 +-+         3     3+-+2 3+-+2
+--R       - 2b \|3 log(- d x  + c)\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +-------------------------------------------+
+--R              |      2     2     2              3       4
+--R              |- 9c d %%BF0  - 6b c d %%BF0 + 8a b d - b c               2
+--R         (- d |-------------------------------------------  - d %%BF0 - b )
+--R              |                       2
+--R             \|                   3c d
+--R      *
+--R         log
+--R                      2 2          3   2     3 2
+--R                (18b c d %%BF0 - 3a c d  + 6b c d)
+--R             *
+--R                 +-------------------------------------------+
+--R                 |      2     2     2              3       4
+--R                 |- 9c d %%BF0  - 6b c d %%BF0 + 8a b d - b c
+--R                 |-------------------------------------------
+--R                 |                       2
+--R                \|                   3c d
+--R            + 
+--R                     2 2     2        3   2      3 2
+--R              - 18b c d %%BF0  + (- 3a c d  - 12b c d)%%BF0
+--R            + 
+--R                 5 2      2 3          3 2        5 2
+--R              (2a d  - 16a b c d)x + 7a b c d - 2b c
+--R     + 
+--R            +-------------------------------------------+
+--R            |      2     2     2              3       4
+--R            |- 9c d %%BF0  - 6b c d %%BF0 + 8a b d - b c               2
+--R         (d |-------------------------------------------  - d %%BF0 - b )
+--R            |                       2
+--R           \|                   3c d
+--R      *
+--R         log
+--R                        2 2          3   2     3 2
+--R                (- 18b c d %%BF0 + 3a c d  - 6b c d)
+--R             *
+--R                 +-------------------------------------------+
+--R                 |      2     2     2              3       4
+--R                 |- 9c d %%BF0  - 6b c d %%BF0 + 8a b d - b c
+--R                 |-------------------------------------------
+--R                 |                       2
+--R                \|                   3c d
+--R            + 
+--R                     2 2     2        3   2      3 2
+--R              - 18b c d %%BF0  + (- 3a c d  - 12b c d)%%BF0
+--R            + 
+--R                 5 2      2 3          3 2        5 2
+--R              (2a d  - 16a b c d)x + 7a b c d - 2b c
+--R     + 
+--R         2d %%BF0
+--R      *
+--R         log
+--R                   2 2     2      3   2      3 2            5 2     2 3
+--R              18b c d %%BF0  + (3a c d  + 12b c d)%%BF0 + (a d  - 8a b c d)x
+--R            + 
+--R                  3 2        5 2
+--R              - 7a b c d + 2b c
+--R  /
+--R     2d
+--R                                         Type: Union(Expression(Integer),...)
+--E 103
+
+--S 104 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +-------------------------------------------+
+--R                               |      2     2     2              3       4
+--R                +-+3+-+2 3+-+2 |- 9c d %%BF0  - 6b c d %%BF0 + 8a b d - b c
+--R           - 3d\|3 \|c   \|d   |-------------------------------------------
+--R                               |                       2
+--R                              \|                   3c d
+--R         + 
+--R                +-+3+-+2 3+-+2         2 +-+3+-+2 3+-+2
+--R           - 3d\|3 \|c   \|d  %%BF - 3b \|3 \|c   \|d
+--R      *
+--R         log
+--R                      2 2          3   2     3 2
+--R                (18b c d %%BF0 - 3a c d  + 6b c d)
+--R             *
+--R                 +-------------------------------------------+
+--R                 |      2     2     2              3       4
+--R                 |- 9c d %%BF0  - 6b c d %%BF0 + 8a b d - b c
+--R                 |-------------------------------------------
+--R                 |                       2
+--R                \|                   3c d
+--R            + 
+--R                     2 2     2        3   2      3 2
+--R              - 18b c d %%BF0  + (- 3a c d  - 12b c d)%%BF0
+--R            + 
+--R                 5 2      2 3          3 2        5 2
+--R              (2a d  - 16a b c d)x + 7a b c d - 2b c
+--R     + 
+--R                             +-------------------------------------------+
+--R                             |      2     2     2              3       4
+--R              +-+3+-+2 3+-+2 |- 9c d %%BF0  - 6b c d %%BF0 + 8a b d - b c
+--R           3d\|3 \|c   \|d   |-------------------------------------------
+--R                             |                       2
+--R                            \|                   3c d
+--R         + 
+--R                +-+3+-+2 3+-+2         2 +-+3+-+2 3+-+2
+--R           - 3d\|3 \|c   \|d  %%BF - 3b \|3 \|c   \|d
+--R      *
+--R         log
+--R                        2 2          3   2     3 2
+--R                (- 18b c d %%BF0 + 3a c d  - 6b c d)
+--R             *
+--R                 +-------------------------------------------+
+--R                 |      2     2     2              3       4
+--R                 |- 9c d %%BF0  - 6b c d %%BF0 + 8a b d - b c
+--R                 |-------------------------------------------
+--R                 |                       2
+--R                \|                   3c d
+--R            + 
+--R                     2 2     2        3   2      3 2
+--R              - 18b c d %%BF0  + (- 3a c d  - 12b c d)%%BF0
+--R            + 
+--R                 5 2      2 3          3 2        5 2
+--R              (2a d  - 16a b c d)x + 7a b c d - 2b c
+--R     + 
+--R            +-+3+-+2 3+-+2
+--R         6d\|3 \|c   \|d  %%BF0
+--R      *
+--R         log
+--R                   2 2     2      3   2      3 2            5 2     2 3
+--R              18b c d %%BF0  + (3a c d  + 12b c d)%%BF0 + (a d  - 8a b c d)x
+--R            + 
+--R                  3 2        5 2
+--R              - 7a b c d + 2b c
+--R     + 
+--R           2  +-+3+-+          +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- a d\|3 \|d  - 2a b d\|3 \|c )log(x  \|d  + x\|c \|d  + \|c  )
+--R     + 
+--R          2  +-+3+-+          +-+3+-+        3+-+   3+-+
+--R       (2a d\|3 \|d  + 4a b d\|3 \|c )log(- x\|d  + \|c )
+--R     + 
+--R                                        3+-+   3+-+
+--R            2 3+-+          3+-+      2x\|d  + \|c
+--R       (- 6a d\|d  + 12a b d\|c )atan(-------------)
+--R                                          +-+3+-+
+--R                                         \|3 \|c
+--R     + 
+--R         2 +-+         3     3+-+2 3+-+2
+--R       2b \|3 log(- d x  + c)\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 953
+t0:=(a+b*x)^3/(c-d*x^3)
+--R 
+--R
+--R           3 3       2 2     2       3
+--R        - b x  - 3a b x  - 3a b x - a
+--R   (1)  ------------------------------
+--R                      3
+--R                   d x  - c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 106
+
+--S 107 of 953
+r0:=-b^3*x/d-1/3*(b^3*c+3*a^2*b*c^(1/3)*d^(2/3)+a^3*d)*log(c^(1/3)-_
+   d^(1/3)*x)/(c^(2/3)*d^(4/3))+1/6*(b^3*c+3*a^2*b*c^(1/3)*d^(2/3)+a^3*d)*_
+   log(c^(2/3)+c^(1/3)*d^(1/3)*x+d^(2/3)*x^2)/(c^(2/3)*d^(4/3))-a*b^2*_
+   log(c-d*x^3)/d+(b^3*c-3*a^2*b*c^(1/3)*d^(2/3)+a^3*d)*atan((c^(1/3)+_
+   2*d^(1/3)*x)/(c^(1/3)*sqrt(3)))/(c^(2/3)*d^(4/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          2  +-+3+-+3+-+2     3     3   +-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (3a b\|3 \|c \|d   + (a d + b c)\|3 )log(x  \|d  + x\|c \|d  + \|c  )
+--R     + 
+--R            2  +-+3+-+3+-+2        3      3   +-+        3+-+   3+-+
+--R       (- 6a b\|3 \|c \|d   + (- 2a d - 2b c)\|3 )log(- x\|d  + \|c )
+--R     + 
+--R                                              3+-+   3+-+
+--R             2 3+-+3+-+2     3      3       2x\|d  + \|c
+--R       (- 18a b\|c \|d   + 6a d + 6b c)atan(-------------)
+--R                                                +-+3+-+
+--R                                               \|3 \|c
+--R     + 
+--R              2 +-+         3          3  +-+ 3+-+2 3+-+
+--R       (- 6a b \|3 log(- d x  + c) - 6b x\|3 )\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 +-----------------------------------------------+
+--R                 |      2     2       2              5       2 4
+--R                 |- 3c d %%BG0  - 6a b c d %%BG0 + 4a b d + a b c
+--R             - d |-----------------------------------------------  - d %%BG0
+--R                 |                         2
+--R                \|                      c d
+--R           + 
+--R                   2
+--R             - 3a b
+--R      *
+--R         log
+--R                    2   2 3          6   3      3 3 2 2     6 3
+--R                (27a b c d %%BG0 - 3a c d  + 21a b c d  - 3b c d)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |      2     2       2              5       2 4
+--R                 |- 3c d %%BG0  - 6a b c d %%BG0 + 4a b d + a b c
+--R                 |-----------------------------------------------
+--R                 |                         2
+--R                \|                      c d
+--R            + 
+--R                   2   2 3     2        6   3      3 3 2 2     6 3
+--R              - 27a b c d %%BG0  + (- 3a c d  - 60a b c d  - 3b c d)%%BG0
+--R            + 
+--R                 9 3      6 3   2     3 6 2      9 3        7 2   2      4 5 2
+--R              (2a d  - 48a b c d  + 6a b c d + 2b c )x + 15a b c d  - 15a b c d
+--R            + 
+--R                    8 3
+--R              - 3a b c
+--R     + 
+--R            +-----------------------------------------------+
+--R            |      2     2       2              5       2 4
+--R            |- 3c d %%BG0  - 6a b c d %%BG0 + 4a b d + a b c                  2
+--R         (d |-----------------------------------------------  - d %%BG0 - 3a b )
+--R            |                         2
+--R           \|                      c d
+--R      *
+--R         log
+--R                      2   2 3          6   3      3 3 2 2     6 3
+--R                (- 27a b c d %%BG0 + 3a c d  - 21a b c d  + 3b c d)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |      2     2       2              5       2 4
+--R                 |- 3c d %%BG0  - 6a b c d %%BG0 + 4a b d + a b c
+--R                 |-----------------------------------------------
+--R                 |                         2
+--R                \|                      c d
+--R            + 
+--R                   2   2 3     2        6   3      3 3 2 2     6 3
+--R              - 27a b c d %%BG0  + (- 3a c d  - 60a b c d  - 3b c d)%%BG0
+--R            + 
+--R                 9 3      6 3   2     3 6 2      9 3        7 2   2      4 5 2
+--R              (2a d  - 48a b c d  + 6a b c d + 2b c )x + 15a b c d  - 15a b c d
+--R            + 
+--R                    8 3
+--R              - 3a b c
+--R     + 
+--R         2d %%BG0
+--R      *
+--R         log
+--R                 2   2 3     2      6   3      3 3 2 2     6 3
+--R              27a b c d %%BG0  + (3a c d  + 60a b c d  + 3b c d)%%BG0
+--R            + 
+--R                9 3      6 3   2     3 6 2     9 3        7 2   2      4 5 2
+--R              (a d  - 24a b c d  + 3a b c d + b c )x - 15a b c d  + 15a b c d
+--R            + 
+--R                  8 3
+--R              3a b c
+--R     + 
+--R           3
+--R       - 2b x
+--R  /
+--R     2d
+--R                                         Type: Union(Expression(Integer),...)
+--E 108
+
+--S 109 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              +-----------------------------------------------+
+--R                              |      2     2       2              5       2 4
+--R                +-+3+-+2 3+-+ |- 3c d %%BG0  - 6a b c d %%BG0 + 4a b d + a b c
+--R           - 3d\|3 \|c   \|d  |-----------------------------------------------
+--R                              |                         2
+--R                             \|                      c d
+--R         + 
+--R                +-+3+-+2 3+-+           2 +-+3+-+2 3+-+
+--R           - 3d\|3 \|c   \|d %%BG - 9a b \|3 \|c   \|d
+--R      *
+--R         log
+--R                    2   2 3          6   3      3 3 2 2     6 3
+--R                (27a b c d %%BG0 - 3a c d  + 21a b c d  - 3b c d)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |      2     2       2              5       2 4
+--R                 |- 3c d %%BG0  - 6a b c d %%BG0 + 4a b d + a b c
+--R                 |-----------------------------------------------
+--R                 |                         2
+--R                \|                      c d
+--R            + 
+--R                   2   2 3     2        6   3      3 3 2 2     6 3
+--R              - 27a b c d %%BG0  + (- 3a c d  - 60a b c d  - 3b c d)%%BG0
+--R            + 
+--R                 9 3      6 3   2     3 6 2      9 3        7 2   2      4 5 2
+--R              (2a d  - 48a b c d  + 6a b c d + 2b c )x + 15a b c d  - 15a b c d
+--R            + 
+--R                    8 3
+--R              - 3a b c
+--R     + 
+--R                            +-----------------------------------------------+
+--R                            |      2     2       2              5       2 4
+--R              +-+3+-+2 3+-+ |- 3c d %%BG0  - 6a b c d %%BG0 + 4a b d + a b c
+--R           3d\|3 \|c   \|d  |-----------------------------------------------
+--R                            |                         2
+--R                           \|                      c d
+--R         + 
+--R                +-+3+-+2 3+-+           2 +-+3+-+2 3+-+
+--R           - 3d\|3 \|c   \|d %%BG - 9a b \|3 \|c   \|d
+--R      *
+--R         log
+--R                      2   2 3          6   3      3 3 2 2     6 3
+--R                (- 27a b c d %%BG0 + 3a c d  - 21a b c d  + 3b c d)
+--R             *
+--R                 +-----------------------------------------------+
+--R                 |      2     2       2              5       2 4
+--R                 |- 3c d %%BG0  - 6a b c d %%BG0 + 4a b d + a b c
+--R                 |-----------------------------------------------
+--R                 |                         2
+--R                \|                      c d
+--R            + 
+--R                   2   2 3     2        6   3      3 3 2 2     6 3
+--R              - 27a b c d %%BG0  + (- 3a c d  - 60a b c d  - 3b c d)%%BG0
+--R            + 
+--R                 9 3      6 3   2     3 6 2      9 3        7 2   2      4 5 2
+--R              (2a d  - 48a b c d  + 6a b c d + 2b c )x + 15a b c d  - 15a b c d
+--R            + 
+--R                    8 3
+--R              - 3a b c
+--R     + 
+--R            +-+3+-+2 3+-+
+--R         6d\|3 \|c   \|d %%BG0
+--R      *
+--R         log
+--R                 2   2 3     2      6   3      3 3 2 2     6 3
+--R              27a b c d %%BG0  + (3a c d  + 60a b c d  + 3b c d)%%BG0
+--R            + 
+--R                9 3      6 3   2     3 6 2     9 3        7 2   2      4 5 2
+--R              (a d  - 24a b c d  + 3a b c d + b c )x - 15a b c d  + 15a b c d
+--R            + 
+--R                  8 3
+--R              3a b c
+--R     + 
+--R            2  +-+3+-+3+-+2       3     3   +-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- 3a b\|3 \|c \|d   + (- a d - b c)\|3 )log(x  \|d  + x\|c \|d  + \|c  )
+--R     + 
+--R          2  +-+3+-+3+-+2      3      3   +-+        3+-+   3+-+
+--R       (6a b\|3 \|c \|d   + (2a d + 2b c)\|3 )log(- x\|d  + \|c )
+--R     + 
+--R                                            3+-+   3+-+
+--R           2 3+-+3+-+2     3      3       2x\|d  + \|c
+--R       (18a b\|c \|d   - 6a d - 6b c)atan(-------------)
+--R                                              +-+3+-+
+--R                                             \|3 \|c
+--R     + 
+--R           2 +-+         3     3+-+2 3+-+
+--R       6a b \|3 log(- d x  + c)\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 110
+
+)clear all
+
+--S 111 of 953
+t0:=(a+b*x)^4/(c-d*x^3)
+--R 
+--R
+--R           4 4       3 3     2 2 2     3       4
+--R        - b x  - 4a b x  - 6a b x  - 4a b x - a
+--R   (1)  ----------------------------------------
+--R                           3
+--R                        d x  - c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 111
+
+--S 112 of 953
+r0:=-4*a*b^3*x/d-1/2*b^4*x^2/d-1/3*(b*c^(1/3)*(b^3*c+4*a^3*d)+d^(1/3)*_
+   (4*a*b^3*c+a^4*d))*log(c^(1/3)-d^(1/3)*x)/(c^(2/3)*d^(5/3))+_
+   1/6*(b*c^(1/3)*(b^3*c+4*a^3*d)+d^(1/3)*(4*a*b^3*c+a^4*d))*_
+   log(c^(2/3)+c^(1/3)*d^(1/3)*x+d^(2/3)*x^2)/(c^(2/3)*d^(5/3))-_
+   2*a^2*b^2*log(c-d*x^3)/d-(b^4*c^(4/3)-4*a*b^3*c*d^(1/3)+_
+   4*a^3*b*c^(1/3)*d-a^4*d^(4/3))*atan((c^(1/3)+2*d^(1/3)*x)/_
+   (c^(1/3)*sqrt(3)))/(c^(2/3)*d^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            4        3   +-+3+-+      3       4   +-+3+-+
+--R         ((a d + 4a b c)\|3 \|d  + (4a b d + b c)\|3 \|c )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|d  + x\|c \|d  + \|c  )
+--R     + 
+--R               4        3   +-+3+-+        3        4   +-+3+-+
+--R         ((- 2a d - 8a b c)\|3 \|d  + (- 8a b d - 2b c)\|3 \|c )
+--R      *
+--R                3+-+   3+-+
+--R         log(- x\|d  + \|c )
+--R     + 
+--R                                                             3+-+   3+-+
+--R           4         3  3+-+         3        4  3+-+      2x\|d  + \|c
+--R       ((6a d + 24a b c)\|d  + (- 24a b d - 6b c)\|c )atan(-------------)
+--R                                                               +-+3+-+
+--R                                                              \|3 \|c
+--R     + 
+--R             2 2 +-+         3             4 2        3   +-+ 3+-+2 3+-+2
+--R       (- 12a b \|3 log(- d x  + c) + (- 3b x  - 24a b x)\|3 )\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BH0  - 36a b c d %%BH0 + 16a b d  + 32a b c d
+--R                     + 
+--R                            7 2
+--R                       16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R         + 
+--R                         2 2
+--R           - d %%BH0 - 6a b
+--R      *
+--R         log
+--R                        3   2 4     4 3 3           8   4      5 3 2 3
+--R                    (36a b c d  + 9b c d )%%BH0 - 3a c d  + 48a b c d
+--R                  + 
+--R                         2 6 3 2
+--R                    - 30a b c d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BH0  - 36a b c d %%BH0 + 16a b d  + 32a b c d
+--R                     + 
+--R                            7 2
+--R                       16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R            + 
+--R                    3   2 4     4 3 3      2
+--R              (- 36a b c d  - 9b c d )%%BH0
+--R            + 
+--R                   8   4       5 3 2 3      2 6 3 2
+--R              (- 3a c d  - 168a b c d  - 84a b c d )%%BH0
+--R            + 
+--R                 12 4       9 3   3       3 9 3      12 4        10 2   3
+--R              (2a  d  - 104a b c d  + 104a b c d - 2b  c )x + 26a  b c d
+--R            + 
+--R                   7 5 2 2      4 8 3        11 4
+--R              - 48a b c d  - 66a b c d + 8a b  c
+--R     + 
+--R             +-----------------------------------------------------------------+
+--R             |      3     2      2 2   2           7   2      4 4           7 2
+--R             |- 9c d %%BH0  - 36a b c d %%BH0 + 16a b d  + 32a b c d + 16a b c
+--R           d |-----------------------------------------------------------------
+--R             |                                  3
+--R            \|                              3c d
+--R         + 
+--R                         2 2
+--R           - d %%BH0 - 6a b
+--R      *
+--R         log
+--R                        3   2 4     4 3 3           8   4      5 3 2 3
+--R                  (- 36a b c d  - 9b c d )%%BH0 + 3a c d  - 48a b c d
+--R                + 
+--R                     2 6 3 2
+--R                  30a b c d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BH0  - 36a b c d %%BH0 + 16a b d  + 32a b c d
+--R                     + 
+--R                            7 2
+--R                       16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R            + 
+--R                    3   2 4     4 3 3      2
+--R              (- 36a b c d  - 9b c d )%%BH0
+--R            + 
+--R                   8   4       5 3 2 3      2 6 3 2
+--R              (- 3a c d  - 168a b c d  - 84a b c d )%%BH0
+--R            + 
+--R                 12 4       9 3   3       3 9 3      12 4        10 2   3
+--R              (2a  d  - 104a b c d  + 104a b c d - 2b  c )x + 26a  b c d
+--R            + 
+--R                   7 5 2 2      4 8 3        11 4
+--R              - 48a b c d  - 66a b c d + 8a b  c
+--R     + 
+--R         2d %%BH0
+--R      *
+--R         log
+--R                  3   2 4     4 3 3      2
+--R              (36a b c d  + 9b c d )%%BH0
+--R            + 
+--R                 8   4       5 3 2 3      2 6 3 2
+--R              (3a c d  + 168a b c d  + 84a b c d )%%BH0
+--R            + 
+--R                12 4      9 3   3      3 9 3     12 4        10 2   3
+--R              (a  d  - 52a b c d  + 52a b c d - b  c )x - 26a  b c d
+--R            + 
+--R                 7 5 2 2      4 8 3        11 4
+--R              48a b c d  + 66a b c d - 8a b  c
+--R     + 
+--R          4 2       3
+--R       - b x  - 8a b x
+--R  /
+--R     2d
+--R                                         Type: Union(Expression(Integer),...)
+--E 113
+
+--S 114 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                   +-+3+-+2 3+-+2
+--R                3d\|3 \|c   \|d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BH0  - 36a b c d %%BH0 + 16a b d  + 32a b c d
+--R                     + 
+--R                            7 2
+--R                       16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R         + 
+--R                +-+3+-+2 3+-+2          2 2 +-+3+-+2 3+-+2
+--R           - 3d\|3 \|c   \|d  %%BH - 18a b \|3 \|c   \|d
+--R      *
+--R         log
+--R                        3   2 4     4 3 3           8   4      5 3 2 3
+--R                    (36a b c d  + 9b c d )%%BH0 - 3a c d  + 48a b c d
+--R                  + 
+--R                         2 6 3 2
+--R                    - 30a b c d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BH0  - 36a b c d %%BH0 + 16a b d  + 32a b c d
+--R                     + 
+--R                            7 2
+--R                       16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R            + 
+--R                    3   2 4     4 3 3      2
+--R              (- 36a b c d  - 9b c d )%%BH0
+--R            + 
+--R                   8   4       5 3 2 3      2 6 3 2
+--R              (- 3a c d  - 168a b c d  - 84a b c d )%%BH0
+--R            + 
+--R                 12 4       9 3   3       3 9 3      12 4        10 2   3
+--R              (2a  d  - 104a b c d  + 104a b c d - 2b  c )x + 26a  b c d
+--R            + 
+--R                   7 5 2 2      4 8 3        11 4
+--R              - 48a b c d  - 66a b c d + 8a b  c
+--R     + 
+--R                +-+3+-+2 3+-+2
+--R             3d\|3 \|c   \|d
+--R          *
+--R            +-----------------------------------------------------------------+
+--R            |      3     2      2 2   2           7   2      4 4           7 2
+--R            |- 9c d %%BH0  - 36a b c d %%BH0 + 16a b d  + 32a b c d + 16a b c
+--R            |-----------------------------------------------------------------
+--R            |                                  3
+--R           \|                              3c d
+--R         + 
+--R                +-+3+-+2 3+-+2          2 2 +-+3+-+2 3+-+2
+--R           - 3d\|3 \|c   \|d  %%BH - 18a b \|3 \|c   \|d
+--R      *
+--R         log
+--R                        3   2 4     4 3 3           8   4      5 3 2 3
+--R                  (- 36a b c d  - 9b c d )%%BH0 + 3a c d  - 48a b c d
+--R                + 
+--R                     2 6 3 2
+--R                  30a b c d
+--R             *
+--R                ROOT
+--R                             3     2      2 2   2           7   2      4 4
+--R                       - 9c d %%BH0  - 36a b c d %%BH0 + 16a b d  + 32a b c d
+--R                     + 
+--R                            7 2
+--R                       16a b c
+--R                  /
+--R                         3
+--R                     3c d
+--R            + 
+--R                    3   2 4     4 3 3      2
+--R              (- 36a b c d  - 9b c d )%%BH0
+--R            + 
+--R                   8   4       5 3 2 3      2 6 3 2
+--R              (- 3a c d  - 168a b c d  - 84a b c d )%%BH0
+--R            + 
+--R                 12 4       9 3   3       3 9 3      12 4        10 2   3
+--R              (2a  d  - 104a b c d  + 104a b c d - 2b  c )x + 26a  b c d
+--R            + 
+--R                   7 5 2 2      4 8 3        11 4
+--R              - 48a b c d  - 66a b c d + 8a b  c
+--R     + 
+--R            +-+3+-+2 3+-+2
+--R         6d\|3 \|c   \|d  %%BH0
+--R      *
+--R         log
+--R                  3   2 4     4 3 3      2
+--R              (36a b c d  + 9b c d )%%BH0
+--R            + 
+--R                 8   4       5 3 2 3      2 6 3 2
+--R              (3a c d  + 168a b c d  + 84a b c d )%%BH0
+--R            + 
+--R                12 4      9 3   3      3 9 3     12 4        10 2   3
+--R              (a  d  - 52a b c d  + 52a b c d - b  c )x - 26a  b c d
+--R            + 
+--R                 7 5 2 2      4 8 3        11 4
+--R              48a b c d  + 66a b c d - 8a b  c
+--R     + 
+--R              4        3   +-+3+-+        3       4   +-+3+-+
+--R         ((- a d - 4a b c)\|3 \|d  + (- 4a b d - b c)\|3 \|c )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|d  + x\|c \|d  + \|c  )
+--R     + 
+--R           4        3   +-+3+-+      3        4   +-+3+-+        3+-+   3+-+
+--R       ((2a d + 8a b c)\|3 \|d  + (8a b d + 2b c)\|3 \|c )log(- x\|d  + \|c )
+--R     + 
+--R                                                             3+-+   3+-+
+--R             4         3  3+-+       3        4  3+-+      2x\|d  + \|c
+--R       ((- 6a d - 24a b c)\|d  + (24a b d + 6b c)\|c )atan(-------------)
+--R                                                               +-+3+-+
+--R                                                              \|3 \|c
+--R     + 
+--R          2 2 +-+         3     3+-+2 3+-+2
+--R       12a b \|3 log(- d x  + c)\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 115
+
+)clear all
+
+--S 116 of 953
+t0:=(a+b*x+c*x^2)^2/(d+e*x^3)
+--R 
+--R
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R   (1)  --------------------------------------------
+--R                             3
+--R                          e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 116
+
+--S 117 of 953
+r0:=2*b*c*x/e+1/2*c^2*x^2/e-1/3*(e^(1/3)*(2*b*c*d-a^2*e)-d^(1/3)*_
+   (c^2*d-2*a*b*e))*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*e^(5/3))+1/6*(e^(1/3)*_
+   (2*b*c*d-a^2*e)-d^(1/3)*(c^2*d-2*a*b*e))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+_
+   e^(2/3)*x^2)/(d^(2/3)*e^(5/3))+1/3*(b^2+2*a*c)*log(d+e*x^3)/e+_
+   (c^2*d^(4/3)+2*b*c*d*e^(1/3)-a*(2*b*d^(1/3)+a*e^(1/3))*e)*_
+   atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              2            +-+3+-+              2   +-+3+-+
+--R         ((- a e + 2b c d)\|3 \|e  + (2a b e - c d)\|3 \|d )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R           2            +-+3+-+                 2   +-+3+-+      3+-+   3+-+
+--R       ((2a e - 4b c d)\|3 \|e  + (- 4a b e + 2c d)\|3 \|d )log(x\|e  + \|d )
+--R     + 
+--R                                                           3+-+   3+-+
+--R           2            3+-+                2  3+-+      2x\|e  - \|d
+--R       ((6a e - 12b c d)\|e  + (12a b e - 6c d)\|d )atan(-------------)
+--R                                                             +-+3+-+
+--R                                                            \|3 \|d
+--R     + 
+--R                  2  +-+       3           2 2            +-+ 3+-+2 3+-+2
+--R       ((4a c + 2b )\|3 log(e x  + d) + (3c x  + 12b c x)\|3 )\|d   \|e
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                e
+--R             *
+--R                ROOT
+--R                             3     2              2    2          3   2
+--R                       - 9d e %%BI0  + (12a c + 6b )d e %%BI0 - 8a b e
+--R                     + 
+--R                             2     4           3 2
+--R                       (12a b c - b )d e - 8b c d
+--R                  /
+--R                         3
+--R                     3d e
+--R         + 
+--R                               2
+--R           - e %%BI0 + 2a c + b
+--R      *
+--R         log
+--R                          2 4     2 3 3           4   4       3 2 3
+--R                  (18a b d e  - 9c d e )%%BI0 - 3a d e  - 6a b d e
+--R                + 
+--R                       3     2 2  3 2
+--R                  (6a c  - 9b c )d e
+--R             *
+--R                ROOT
+--R                             3     2              2    2          3   2
+--R                       - 9d e %%BI0  + (12a c + 6b )d e %%BI0 - 8a b e
+--R                     + 
+--R                             2     4           3 2
+--R                       (12a b c - b )d e - 8b c d
+--R                  /
+--R                         3
+--R                     3d e
+--R            + 
+--R                        2 4     2 3 3      2
+--R              (- 18a b d e  + 9c d e )%%BI0
+--R            + 
+--R                     4   4       2           3  2 3           3      2 2  3 2
+--R                (- 3a d e  + (36a b c + 12a b )d e  + (- 12a c  - 18b c )d e )
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4         4         3 3    3           4      3 3  3
+--R                  2a e  + (- 12a b c + 16a b )d e  + (12a b c  - 16b c )d e
+--R                + 
+--R                      6 4
+--R                  - 2c d
+--R             *
+--R                x
+--R            + 
+--R                 5      4 2    3        3   2     2 3        5  2 2
+--R              (2a c - 7a b )d e  + (- 8a b c  + 4a b c - 2a b )d e
+--R            + 
+--R                 2 4       2 3     4 2  3        5 4
+--R              (2a c  - 4a b c  + 5b c )d e + 4b c d
+--R     + 
+--R             e
+--R          *
+--R             ROOT
+--R                          3     2              2    2          3   2
+--R                    - 9d e %%BI0  + (12a c + 6b )d e %%BI0 - 8a b e
+--R                  + 
+--R                          2     4           3 2
+--R                    (12a b c - b )d e - 8b c d
+--R               /
+--R                      3
+--R                  3d e
+--R         + 
+--R                               2
+--R           - e %%BI0 + 2a c + b
+--R      *
+--R         log
+--R                            2 4     2 3 3           4   4       3 2 3
+--R                  (- 18a b d e  + 9c d e )%%BI0 + 3a d e  + 6a b d e
+--R                + 
+--R                         3     2 2  3 2
+--R                  (- 6a c  + 9b c )d e
+--R             *
+--R                ROOT
+--R                             3     2              2    2          3   2
+--R                       - 9d e %%BI0  + (12a c + 6b )d e %%BI0 - 8a b e
+--R                     + 
+--R                             2     4           3 2
+--R                       (12a b c - b )d e - 8b c d
+--R                  /
+--R                         3
+--R                     3d e
+--R            + 
+--R                        2 4     2 3 3      2
+--R              (- 18a b d e  + 9c d e )%%BI0
+--R            + 
+--R                     4   4       2           3  2 3           3      2 2  3 2
+--R                (- 3a d e  + (36a b c + 12a b )d e  + (- 12a c  - 18b c )d e )
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4         4         3 3    3           4      3 3  3
+--R                  2a e  + (- 12a b c + 16a b )d e  + (12a b c  - 16b c )d e
+--R                + 
+--R                      6 4
+--R                  - 2c d
+--R             *
+--R                x
+--R            + 
+--R                 5      4 2    3        3   2     2 3        5  2 2
+--R              (2a c - 7a b )d e  + (- 8a b c  + 4a b c - 2a b )d e
+--R            + 
+--R                 2 4       2 3     4 2  3        5 4
+--R              (2a c  - 4a b c  + 5b c )d e + 4b c d
+--R     + 
+--R         2e %%BI0
+--R      *
+--R         log
+--R                      2 4     2 3 3      2
+--R              (18a b d e  - 9c d e )%%BI0
+--R            + 
+--R                 4   4         2           3  2 3         3      2 2  3 2
+--R              (3a d e  + (- 36a b c - 12a b )d e  + (12a c  + 18b c )d e )%%BI0
+--R            + 
+--R                6 4        4        3 3    3          4     3 3  3     6 4
+--R              (a e  + (- 6a b c + 8a b )d e  + (6a b c  - 8b c )d e - c d )x
+--R            + 
+--R                   5      4 2    3      3   2     2 3        5  2 2
+--R              (- 2a c + 7a b )d e  + (8a b c  - 4a b c + 2a b )d e
+--R            + 
+--R                   2 4       2 3     4 2  3        5 4
+--R              (- 2a c  + 4a b c  - 5b c )d e - 4b c d
+--R     + 
+--R        2 2
+--R       c x  + 4b c x
+--R  /
+--R     2e
+--R                                         Type: Union(Expression(Integer),...)
+--E 118
+
+--S 119 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                   +-+3+-+2 3+-+2
+--R                3e\|3 \|d   \|e
+--R             *
+--R                ROOT
+--R                             3     2              2    2          3   2
+--R                       - 9d e %%BI0  + (12a c + 6b )d e %%BI0 - 8a b e
+--R                     + 
+--R                             2     4           3 2
+--R                       (12a b c - b )d e - 8b c d
+--R                  /
+--R                         3
+--R                     3d e
+--R         + 
+--R                +-+3+-+2 3+-+2                 2  +-+3+-+2 3+-+2
+--R           - 3e\|3 \|d   \|e  %%BI + (6a c + 3b )\|3 \|d   \|e
+--R      *
+--R         log
+--R                          2 4     2 3 3           4   4       3 2 3
+--R                  (18a b d e  - 9c d e )%%BI0 - 3a d e  - 6a b d e
+--R                + 
+--R                       3     2 2  3 2
+--R                  (6a c  - 9b c )d e
+--R             *
+--R                ROOT
+--R                             3     2              2    2          3   2
+--R                       - 9d e %%BI0  + (12a c + 6b )d e %%BI0 - 8a b e
+--R                     + 
+--R                             2     4           3 2
+--R                       (12a b c - b )d e - 8b c d
+--R                  /
+--R                         3
+--R                     3d e
+--R            + 
+--R                        2 4     2 3 3      2
+--R              (- 18a b d e  + 9c d e )%%BI0
+--R            + 
+--R                     4   4       2           3  2 3           3      2 2  3 2
+--R                (- 3a d e  + (36a b c + 12a b )d e  + (- 12a c  - 18b c )d e )
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4         4         3 3    3           4      3 3  3
+--R                  2a e  + (- 12a b c + 16a b )d e  + (12a b c  - 16b c )d e
+--R                + 
+--R                      6 4
+--R                  - 2c d
+--R             *
+--R                x
+--R            + 
+--R                 5      4 2    3        3   2     2 3        5  2 2
+--R              (2a c - 7a b )d e  + (- 8a b c  + 4a b c - 2a b )d e
+--R            + 
+--R                 2 4       2 3     4 2  3        5 4
+--R              (2a c  - 4a b c  + 5b c )d e + 4b c d
+--R     + 
+--R                +-+3+-+2 3+-+2
+--R             3e\|3 \|d   \|e
+--R          *
+--R             ROOT
+--R                          3     2              2    2          3   2
+--R                    - 9d e %%BI0  + (12a c + 6b )d e %%BI0 - 8a b e
+--R                  + 
+--R                          2     4           3 2
+--R                    (12a b c - b )d e - 8b c d
+--R               /
+--R                      3
+--R                  3d e
+--R         + 
+--R                +-+3+-+2 3+-+2                 2  +-+3+-+2 3+-+2
+--R           - 3e\|3 \|d   \|e  %%BI + (6a c + 3b )\|3 \|d   \|e
+--R      *
+--R         log
+--R                            2 4     2 3 3           4   4       3 2 3
+--R                  (- 18a b d e  + 9c d e )%%BI0 + 3a d e  + 6a b d e
+--R                + 
+--R                         3     2 2  3 2
+--R                  (- 6a c  + 9b c )d e
+--R             *
+--R                ROOT
+--R                             3     2              2    2          3   2
+--R                       - 9d e %%BI0  + (12a c + 6b )d e %%BI0 - 8a b e
+--R                     + 
+--R                             2     4           3 2
+--R                       (12a b c - b )d e - 8b c d
+--R                  /
+--R                         3
+--R                     3d e
+--R            + 
+--R                        2 4     2 3 3      2
+--R              (- 18a b d e  + 9c d e )%%BI0
+--R            + 
+--R                     4   4       2           3  2 3           3      2 2  3 2
+--R                (- 3a d e  + (36a b c + 12a b )d e  + (- 12a c  - 18b c )d e )
+--R             *
+--R                %%BI0
+--R            + 
+--R                    6 4         4         3 3    3           4      3 3  3
+--R                  2a e  + (- 12a b c + 16a b )d e  + (12a b c  - 16b c )d e
+--R                + 
+--R                      6 4
+--R                  - 2c d
+--R             *
+--R                x
+--R            + 
+--R                 5      4 2    3        3   2     2 3        5  2 2
+--R              (2a c - 7a b )d e  + (- 8a b c  + 4a b c - 2a b )d e
+--R            + 
+--R                 2 4       2 3     4 2  3        5 4
+--R              (2a c  - 4a b c  + 5b c )d e + 4b c d
+--R     + 
+--R            +-+3+-+2 3+-+2
+--R         6e\|3 \|d   \|e  %%BI0
+--R      *
+--R         log
+--R                      2 4     2 3 3      2
+--R              (18a b d e  - 9c d e )%%BI0
+--R            + 
+--R                 4   4         2           3  2 3         3      2 2  3 2
+--R              (3a d e  + (- 36a b c - 12a b )d e  + (12a c  + 18b c )d e )%%BI0
+--R            + 
+--R                6 4        4        3 3    3          4     3 3  3     6 4
+--R              (a e  + (- 6a b c + 8a b )d e  + (6a b c  - 8b c )d e - c d )x
+--R            + 
+--R                   5      4 2    3      3   2     2 3        5  2 2
+--R              (- 2a c + 7a b )d e  + (8a b c  - 4a b c + 2a b )d e
+--R            + 
+--R                   2 4       2 3     4 2  3        5 4
+--R              (- 2a c  + 4a b c  - 5b c )d e - 4b c d
+--R     + 
+--R            2            +-+3+-+                2   +-+3+-+
+--R         ((a e - 2b c d)\|3 \|e  + (- 2a b e + c d)\|3 \|d )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R             2            +-+3+-+               2   +-+3+-+      3+-+   3+-+
+--R       ((- 2a e + 4b c d)\|3 \|e  + (4a b e - 2c d)\|3 \|d )log(x\|e  + \|d )
+--R     + 
+--R                                                               3+-+   3+-+
+--R             2            3+-+                  2  3+-+      2x\|e  - \|d
+--R       ((- 6a e + 12b c d)\|e  + (- 12a b e + 6c d)\|d )atan(-------------)
+--R                                                                 +-+3+-+
+--R                                                                \|3 \|d
+--R     + 
+--R                   2  +-+       3     3+-+2 3+-+2
+--R       (- 4a c - 2b )\|3 log(e x  + d)\|d   \|e
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 953
+t0:=(a+b*x+c*x^2)^3/(d+e*x^3)
+--R 
+--R
+--R   (1)
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R  /
+--R        3
+--R     e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 121
+
+--S 122 of 953
+r0:=-(c^3*d-b^3*e-6*a*b*c*e)*x/e^2+3/2*c*(b^2+a*c)*x^2/e+b*c^2*x^3/e+_
+   1/4*c^3*x^4/e+1/3*(c^3*d^2-6*a*b*c*d*e-e*(b^3*d-a^3*e)+3*d^(1/3)*_
+   e^(2/3)*(b^2*c*d+a*c^2*d-a^2*b*e))*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*_
+   e^(7/3))-1/6*(c^3*d^2-6*a*b*c*d*e-e*(b^3*d-a^3*e)+3*d^(1/3)*e^(2/3)*_
+   (b^2*c*d+a*c^2*d-a^2*b*e))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(7/3))-(b*c^2*d-a*b^2*e-a^2*c*e)*log(d+e*x^3)/e^2-_
+   (c^3*d^2-3*b^2*c*d^(4/3)*e^(2/3)-3*a*c^2*d^(4/3)*e^(2/3)-b^3*d*e-_
+   6*a*b*c*d*e+3*a^2*b*d^(1/3)*e^(5/3)+a^3*e^2)*atan((d^(1/3)-_
+   2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(7/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              2             2     2     +-+3+-+3+-+2
+--R           (6a b e + (- 6a c  - 6b c)d)\|3 \|d \|e
+--R         + 
+--R                3 2                3         3 2  +-+
+--R           (- 2a e  + (12a b c + 2b )d e - 2c d )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R                 2            2      2     +-+3+-+3+-+2
+--R           (- 12a b e + (12a c  + 12b c)d)\|3 \|d \|e
+--R         + 
+--R              3 2                  3         3 2  +-+
+--R           (4a e  + (- 24a b c - 4b )d e + 4c d )\|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|e  + \|d )
+--R     + 
+--R               2              2      2    3+-+3+-+2      3 2
+--R           (36a b e + (- 36a c  - 36b c)d)\|d \|e   + 12a e
+--R         + 
+--R                           3          3 2
+--R           (- 72a b c - 12b )d e + 12c d
+--R      *
+--R                3+-+   3+-+
+--R              2x\|e  - \|d
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|d
+--R     + 
+--R                2         2          2   +-+       3
+--R           ((12a c + 12a b )e - 12b c d)\|3 log(e x  + d)
+--R         + 
+--R                 3   4        2   3         2      2     2
+--R               3c e x  + 12b c e x  + (18a c  + 18b c)e x
+--R             + 
+--R                              3        3
+--R               ((72a b c + 12b )e - 12c d)x
+--R          *
+--R              +-+
+--R             \|3
+--R      *
+--R         3+-+2 3+-+
+--R         \|d   \|e
+--R  /
+--R        2 +-+3+-+2 3+-+
+--R     12e \|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                  2
+--R                2e
+--R             *
+--R                ROOT
+--R                             4     2       2        2    3       2 2 2
+--R                       - 3d e %%BJ0  + ((6a c + 6a b )d e  - 6b c d e )%%BJ0
+--R                     + 
+--R                           5   3     4 2      3 2     2 4    2
+--R                       - 4a b e  + (a c  + 22a b c + a b )d e
+--R                     + 
+--R                             2   3        3 2     5   2         5    2 4  3
+--R                       (- 22a b c  - 22a b c  - 4b c)d e + (4a c  + b c )d
+--R                  /
+--R                        4
+--R                     d e
+--R         + 
+--R               2           2        2         2
+--R           - 2e %%BJ0 + (6a c + 6a b )e - 6b c d
+--R      *
+--R         log
+--R                      2   2 6           2      2   3 5           6   6
+--R                  (27a b d e  + (- 27a c  - 27b c)d e )%%BJ0 - 3a d e
+--R                + 
+--R                     4         3 3  2 5       3 3      2 2 2       4      6  3 4
+--R                  (9a b c - 21a b )d e  + (21a c  - 27a b c  - 9a b c - 3b )d e
+--R                + 
+--R                         4      3 3  4 3     6 5 2
+--R                  (9a b c  - 21b c )d e  - 3c d e
+--R             *
+--R                ROOT
+--R                             4     2       2        2    3       2 2 2
+--R                       - 3d e %%BJ0  + ((6a c + 6a b )d e  - 6b c d e )%%BJ0
+--R                     + 
+--R                           5   3     4 2      3 2     2 4    2
+--R                       - 4a b e  + (a c  + 22a b c + a b )d e
+--R                     + 
+--R                             2   3        3 2     5   2         5    2 4  3
+--R                       (- 22a b c  - 22a b c  - 4b c)d e + (4a c  + b c )d
+--R                  /
+--R                        4
+--R                     d e
+--R            + 
+--R                    2   2 6         2      2   3 5      2
+--R              (- 27a b d e  + (27a c  + 27b c)d e )%%BJ0
+--R            + 
+--R                      6   6       4         3 3  2 5
+--R                  - 3a d e  + (90a b c + 60a b )d e
+--R                + 
+--R                        3 3       2 2 2        4      6  3 4
+--R                  (- 60a c  - 270a b c  - 90a b c - 3b )d e
+--R                + 
+--R                          4      3 3  4 3     6 5 2
+--R                  (90a b c  + 60b c )d e  - 3c d e
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    9 6         7         6 3    5
+--R                  2a e  + (- 36a b c + 48a b )d e
+--R                + 
+--R                     6 3      5 2 2      4 4      3 6  2 4
+--R                  (6a c  + 54a b c  - 90a b c + 6a b )d e
+--R                + 
+--R                      4   4       3 3 3      2 5 2        7      9  3 3
+--R                  (90a b c  - 120a b c  - 54a b c  - 36a b c - 2b )d e
+--R                + 
+--R                        3 6      2 2 5        4 4      6 3  4 2
+--R                  (- 48a c  + 54a b c  - 90a b c  - 48b c )d e
+--R                + 
+--R                            7     3 6  5      9 6
+--R                  (- 36a b c  - 6b c )d e + 2c d
+--R             *
+--R                x
+--R            + 
+--R                 8       7 2    5         6   2      5 3       4 5  2 4
+--R              (3a c - 15a b )d e  + (- 30a b c  + 48a b c - 15a b )d e
+--R            + 
+--R                  5 4      4 2 3      3 4 2      2 6        8  3 3
+--R              (15a c  + 15a b c  + 15a b c  + 30a b c + 3a b )d e
+--R            + 
+--R                  3   5      2 3 4        5 3      7 2  4 2
+--R              (48a b c  - 15a b c  + 48a b c  + 15b c )d e
+--R            + 
+--R                    2 7        2 6      4 5  5        8 6
+--R              (- 15a c  + 30a b c  + 15b c )d e - 3b c d
+--R     + 
+--R               2
+--R             2e
+--R          *
+--R             ROOT
+--R                          4     2       2        2    3       2 2 2
+--R                    - 3d e %%BJ0  + ((6a c + 6a b )d e  - 6b c d e )%%BJ0
+--R                  + 
+--R                        5   3     4 2      3 2     2 4    2
+--R                    - 4a b e  + (a c  + 22a b c + a b )d e
+--R                  + 
+--R                          2   3        3 2     5   2         5    2 4  3
+--R                    (- 22a b c  - 22a b c  - 4b c)d e + (4a c  + b c )d
+--R               /
+--R                     4
+--R                  d e
+--R         + 
+--R               2           2        2         2
+--R           - 2e %%BJ0 + (6a c + 6a b )e - 6b c d
+--R      *
+--R         log
+--R                        2   2 6         2      2   3 5           6   6
+--R                  (- 27a b d e  + (27a c  + 27b c)d e )%%BJ0 + 3a d e
+--R                + 
+--R                       4         3 3  2 5
+--R                  (- 9a b c + 21a b )d e
+--R                + 
+--R                        3 3      2 2 2       4      6  3 4
+--R                  (- 21a c  + 27a b c  + 9a b c + 3b )d e
+--R                + 
+--R                           4      3 3  4 3     6 5 2
+--R                  (- 9a b c  + 21b c )d e  + 3c d e
+--R             *
+--R                ROOT
+--R                             4     2       2        2    3       2 2 2
+--R                       - 3d e %%BJ0  + ((6a c + 6a b )d e  - 6b c d e )%%BJ0
+--R                     + 
+--R                           5   3     4 2      3 2     2 4    2
+--R                       - 4a b e  + (a c  + 22a b c + a b )d e
+--R                     + 
+--R                             2   3        3 2     5   2         5    2 4  3
+--R                       (- 22a b c  - 22a b c  - 4b c)d e + (4a c  + b c )d
+--R                  /
+--R                        4
+--R                     d e
+--R            + 
+--R                    2   2 6         2      2   3 5      2
+--R              (- 27a b d e  + (27a c  + 27b c)d e )%%BJ0
+--R            + 
+--R                      6   6       4         3 3  2 5
+--R                  - 3a d e  + (90a b c + 60a b )d e
+--R                + 
+--R                        3 3       2 2 2        4      6  3 4
+--R                  (- 60a c  - 270a b c  - 90a b c - 3b )d e
+--R                + 
+--R                          4      3 3  4 3     6 5 2
+--R                  (90a b c  + 60b c )d e  - 3c d e
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    9 6         7         6 3    5
+--R                  2a e  + (- 36a b c + 48a b )d e
+--R                + 
+--R                     6 3      5 2 2      4 4      3 6  2 4
+--R                  (6a c  + 54a b c  - 90a b c + 6a b )d e
+--R                + 
+--R                      4   4       3 3 3      2 5 2        7      9  3 3
+--R                  (90a b c  - 120a b c  - 54a b c  - 36a b c - 2b )d e
+--R                + 
+--R                        3 6      2 2 5        4 4      6 3  4 2
+--R                  (- 48a c  + 54a b c  - 90a b c  - 48b c )d e
+--R                + 
+--R                            7     3 6  5      9 6
+--R                  (- 36a b c  - 6b c )d e + 2c d
+--R             *
+--R                x
+--R            + 
+--R                 8       7 2    5         6   2      5 3       4 5  2 4
+--R              (3a c - 15a b )d e  + (- 30a b c  + 48a b c - 15a b )d e
+--R            + 
+--R                  5 4      4 2 3      3 4 2      2 6        8  3 3
+--R              (15a c  + 15a b c  + 15a b c  + 30a b c + 3a b )d e
+--R            + 
+--R                  3   5      2 3 4        5 3      7 2  4 2
+--R              (48a b c  - 15a b c  + 48a b c  + 15b c )d e
+--R            + 
+--R                    2 7        2 6      4 5  5        8 6
+--R              (- 15a c  + 30a b c  + 15b c )d e - 3b c d
+--R     + 
+--R           2
+--R         4e %%BJ0
+--R      *
+--R         log
+--R                  2   2 6           2      2   3 5      2
+--R              (27a b d e  + (- 27a c  - 27b c)d e )%%BJ0
+--R            + 
+--R                    6   6         4         3 3  2 5
+--R                  3a d e  + (- 90a b c - 60a b )d e
+--R                + 
+--R                      3 3       2 2 2        4      6  3 4
+--R                  (60a c  + 270a b c  + 90a b c + 3b )d e
+--R                + 
+--R                            4      3 3  4 3     6 5 2
+--R                  (- 90a b c  - 60b c )d e  + 3c d e
+--R             *
+--R                %%BJ0
+--R            + 
+--R                   9 6         7         6 3    5
+--R                  a e  + (- 18a b c + 24a b )d e
+--R                + 
+--R                     6 3      5 2 2      4 4      3 6  2 4
+--R                  (3a c  + 27a b c  - 45a b c + 3a b )d e
+--R                + 
+--R                      4   4      3 3 3      2 5 2        7     9  3 3
+--R                  (45a b c  - 60a b c  - 27a b c  - 18a b c - b )d e
+--R                + 
+--R                        3 6      2 2 5        4 4      6 3  4 2
+--R                  (- 24a c  + 27a b c  - 45a b c  - 24b c )d e
+--R                + 
+--R                            7     3 6  5     9 6
+--R                  (- 18a b c  - 3b c )d e + c d
+--R             *
+--R                x
+--R            + 
+--R                   8       7 2    5       6   2      5 3       4 5  2 4
+--R              (- 3a c + 15a b )d e  + (30a b c  - 48a b c + 15a b )d e
+--R            + 
+--R                    5 4      4 2 3      3 4 2      2 6        8  3 3
+--R              (- 15a c  - 15a b c  - 15a b c  - 30a b c - 3a b )d e
+--R            + 
+--R                    3   5      2 3 4        5 3      7 2  4 2
+--R              (- 48a b c  + 15a b c  - 48a b c  - 15b c )d e
+--R            + 
+--R                  2 7        2 6      4 5  5        8 6
+--R              (15a c  - 30a b c  - 15b c )d e + 3b c d
+--R     + 
+--R        3   4       2   3        2     2     2                 3       3
+--R       c e x  + 4b c e x  + (6a c  + 6b c)e x  + ((24a b c + 4b )e - 4c d)x
+--R  /
+--R       2
+--R     4e
+--R                                         Type: Union(Expression(Integer),...)
+--E 123
+
+--S 124 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                  2 +-+3+-+2 3+-+
+--R                3e \|3 \|d   \|e
+--R             *
+--R                ROOT
+--R                             4     2       2        2    3       2 2 2
+--R                       - 3d e %%BJ0  + ((6a c + 6a b )d e  - 6b c d e )%%BJ0
+--R                     + 
+--R                           5   3     4 2      3 2     2 4    2
+--R                       - 4a b e  + (a c  + 22a b c + a b )d e
+--R                     + 
+--R                             2   3        3 2     5   2         5    2 4  3
+--R                       (- 22a b c  - 22a b c  - 4b c)d e + (4a c  + b c )d
+--R                  /
+--R                        4
+--R                     d e
+--R         + 
+--R               2 +-+3+-+2 3+-+           2        2         2   +-+3+-+2 3+-+
+--R           - 3e \|3 \|d   \|e %%BJ + ((9a c + 9a b )e - 9b c d)\|3 \|d   \|e
+--R      *
+--R         log
+--R                      2   2 6           2      2   3 5           6   6
+--R                  (27a b d e  + (- 27a c  - 27b c)d e )%%BJ0 - 3a d e
+--R                + 
+--R                     4         3 3  2 5       3 3      2 2 2       4      6  3 4
+--R                  (9a b c - 21a b )d e  + (21a c  - 27a b c  - 9a b c - 3b )d e
+--R                + 
+--R                         4      3 3  4 3     6 5 2
+--R                  (9a b c  - 21b c )d e  - 3c d e
+--R             *
+--R                ROOT
+--R                             4     2       2        2    3       2 2 2
+--R                       - 3d e %%BJ0  + ((6a c + 6a b )d e  - 6b c d e )%%BJ0
+--R                     + 
+--R                           5   3     4 2      3 2     2 4    2
+--R                       - 4a b e  + (a c  + 22a b c + a b )d e
+--R                     + 
+--R                             2   3        3 2     5   2         5    2 4  3
+--R                       (- 22a b c  - 22a b c  - 4b c)d e + (4a c  + b c )d
+--R                  /
+--R                        4
+--R                     d e
+--R            + 
+--R                    2   2 6         2      2   3 5      2
+--R              (- 27a b d e  + (27a c  + 27b c)d e )%%BJ0
+--R            + 
+--R                      6   6       4         3 3  2 5
+--R                  - 3a d e  + (90a b c + 60a b )d e
+--R                + 
+--R                        3 3       2 2 2        4      6  3 4
+--R                  (- 60a c  - 270a b c  - 90a b c - 3b )d e
+--R                + 
+--R                          4      3 3  4 3     6 5 2
+--R                  (90a b c  + 60b c )d e  - 3c d e
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    9 6         7         6 3    5
+--R                  2a e  + (- 36a b c + 48a b )d e
+--R                + 
+--R                     6 3      5 2 2      4 4      3 6  2 4
+--R                  (6a c  + 54a b c  - 90a b c + 6a b )d e
+--R                + 
+--R                      4   4       3 3 3      2 5 2        7      9  3 3
+--R                  (90a b c  - 120a b c  - 54a b c  - 36a b c - 2b )d e
+--R                + 
+--R                        3 6      2 2 5        4 4      6 3  4 2
+--R                  (- 48a c  + 54a b c  - 90a b c  - 48b c )d e
+--R                + 
+--R                            7     3 6  5      9 6
+--R                  (- 36a b c  - 6b c )d e + 2c d
+--R             *
+--R                x
+--R            + 
+--R                 8       7 2    5         6   2      5 3       4 5  2 4
+--R              (3a c - 15a b )d e  + (- 30a b c  + 48a b c - 15a b )d e
+--R            + 
+--R                  5 4      4 2 3      3 4 2      2 6        8  3 3
+--R              (15a c  + 15a b c  + 15a b c  + 30a b c + 3a b )d e
+--R            + 
+--R                  3   5      2 3 4        5 3      7 2  4 2
+--R              (48a b c  - 15a b c  + 48a b c  + 15b c )d e
+--R            + 
+--R                    2 7        2 6      4 5  5        8 6
+--R              (- 15a c  + 30a b c  + 15b c )d e - 3b c d
+--R     + 
+--R               2 +-+3+-+2 3+-+
+--R             3e \|3 \|d   \|e
+--R          *
+--R             ROOT
+--R                          4     2       2        2    3       2 2 2
+--R                    - 3d e %%BJ0  + ((6a c + 6a b )d e  - 6b c d e )%%BJ0
+--R                  + 
+--R                        5   3     4 2      3 2     2 4    2
+--R                    - 4a b e  + (a c  + 22a b c + a b )d e
+--R                  + 
+--R                          2   3        3 2     5   2         5    2 4  3
+--R                    (- 22a b c  - 22a b c  - 4b c)d e + (4a c  + b c )d
+--R               /
+--R                     4
+--R                  d e
+--R         + 
+--R               2 +-+3+-+2 3+-+           2        2         2   +-+3+-+2 3+-+
+--R           - 3e \|3 \|d   \|e %%BJ + ((9a c + 9a b )e - 9b c d)\|3 \|d   \|e
+--R      *
+--R         log
+--R                        2   2 6         2      2   3 5           6   6
+--R                  (- 27a b d e  + (27a c  + 27b c)d e )%%BJ0 + 3a d e
+--R                + 
+--R                       4         3 3  2 5
+--R                  (- 9a b c + 21a b )d e
+--R                + 
+--R                        3 3      2 2 2       4      6  3 4
+--R                  (- 21a c  + 27a b c  + 9a b c + 3b )d e
+--R                + 
+--R                           4      3 3  4 3     6 5 2
+--R                  (- 9a b c  + 21b c )d e  + 3c d e
+--R             *
+--R                ROOT
+--R                             4     2       2        2    3       2 2 2
+--R                       - 3d e %%BJ0  + ((6a c + 6a b )d e  - 6b c d e )%%BJ0
+--R                     + 
+--R                           5   3     4 2      3 2     2 4    2
+--R                       - 4a b e  + (a c  + 22a b c + a b )d e
+--R                     + 
+--R                             2   3        3 2     5   2         5    2 4  3
+--R                       (- 22a b c  - 22a b c  - 4b c)d e + (4a c  + b c )d
+--R                  /
+--R                        4
+--R                     d e
+--R            + 
+--R                    2   2 6         2      2   3 5      2
+--R              (- 27a b d e  + (27a c  + 27b c)d e )%%BJ0
+--R            + 
+--R                      6   6       4         3 3  2 5
+--R                  - 3a d e  + (90a b c + 60a b )d e
+--R                + 
+--R                        3 3       2 2 2        4      6  3 4
+--R                  (- 60a c  - 270a b c  - 90a b c - 3b )d e
+--R                + 
+--R                          4      3 3  4 3     6 5 2
+--R                  (90a b c  + 60b c )d e  - 3c d e
+--R             *
+--R                %%BJ0
+--R            + 
+--R                    9 6         7         6 3    5
+--R                  2a e  + (- 36a b c + 48a b )d e
+--R                + 
+--R                     6 3      5 2 2      4 4      3 6  2 4
+--R                  (6a c  + 54a b c  - 90a b c + 6a b )d e
+--R                + 
+--R                      4   4       3 3 3      2 5 2        7      9  3 3
+--R                  (90a b c  - 120a b c  - 54a b c  - 36a b c - 2b )d e
+--R                + 
+--R                        3 6      2 2 5        4 4      6 3  4 2
+--R                  (- 48a c  + 54a b c  - 90a b c  - 48b c )d e
+--R                + 
+--R                            7     3 6  5      9 6
+--R                  (- 36a b c  - 6b c )d e + 2c d
+--R             *
+--R                x
+--R            + 
+--R                 8       7 2    5         6   2      5 3       4 5  2 4
+--R              (3a c - 15a b )d e  + (- 30a b c  + 48a b c - 15a b )d e
+--R            + 
+--R                  5 4      4 2 3      3 4 2      2 6        8  3 3
+--R              (15a c  + 15a b c  + 15a b c  + 30a b c + 3a b )d e
+--R            + 
+--R                  3   5      2 3 4        5 3      7 2  4 2
+--R              (48a b c  - 15a b c  + 48a b c  + 15b c )d e
+--R            + 
+--R                    2 7        2 6      4 5  5        8 6
+--R              (- 15a c  + 30a b c  + 15b c )d e - 3b c d
+--R     + 
+--R           2 +-+3+-+2 3+-+
+--R         6e \|3 \|d   \|e %%BJ0
+--R      *
+--R         log
+--R                  2   2 6           2      2   3 5      2
+--R              (27a b d e  + (- 27a c  - 27b c)d e )%%BJ0
+--R            + 
+--R                    6   6         4         3 3  2 5
+--R                  3a d e  + (- 90a b c - 60a b )d e
+--R                + 
+--R                      3 3       2 2 2        4      6  3 4
+--R                  (60a c  + 270a b c  + 90a b c + 3b )d e
+--R                + 
+--R                            4      3 3  4 3     6 5 2
+--R                  (- 90a b c  - 60b c )d e  + 3c d e
+--R             *
+--R                %%BJ0
+--R            + 
+--R                   9 6         7         6 3    5
+--R                  a e  + (- 18a b c + 24a b )d e
+--R                + 
+--R                     6 3      5 2 2      4 4      3 6  2 4
+--R                  (3a c  + 27a b c  - 45a b c + 3a b )d e
+--R                + 
+--R                      4   4      3 3 3      2 5 2        7     9  3 3
+--R                  (45a b c  - 60a b c  - 27a b c  - 18a b c - b )d e
+--R                + 
+--R                        3 6      2 2 5        4 4      6 3  4 2
+--R                  (- 24a c  + 27a b c  - 45a b c  - 24b c )d e
+--R                + 
+--R                            7     3 6  5     9 6
+--R                  (- 18a b c  - 3b c )d e + c d
+--R             *
+--R                x
+--R            + 
+--R                   8       7 2    5       6   2      5 3       4 5  2 4
+--R              (- 3a c + 15a b )d e  + (30a b c  - 48a b c + 15a b )d e
+--R            + 
+--R                    5 4      4 2 3      3 4 2      2 6        8  3 3
+--R              (- 15a c  - 15a b c  - 15a b c  - 30a b c - 3a b )d e
+--R            + 
+--R                    3   5      2 3 4        5 3      7 2  4 2
+--R              (- 48a b c  + 15a b c  - 48a b c  - 15b c )d e
+--R            + 
+--R                  2 7        2 6      4 5  5        8 6
+--R              (15a c  - 30a b c  - 15b c )d e + 3b c d
+--R     + 
+--R                2           2     2     +-+3+-+3+-+2
+--R           (- 3a b e + (3a c  + 3b c)d)\|3 \|d \|e
+--R         + 
+--R             3 2                3        3 2  +-+
+--R           (a e  + (- 6a b c - b )d e + c d )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R              2             2     2     +-+3+-+3+-+2
+--R           (6a b e + (- 6a c  - 6b c)d)\|3 \|d \|e
+--R         + 
+--R                3 2                3         3 2  +-+
+--R           (- 2a e  + (12a b c + 2b )d e - 2c d )\|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|e  + \|d )
+--R     + 
+--R                 2            2      2    3+-+3+-+2     3 2                3
+--R           (- 18a b e + (18a c  + 18b c)d)\|d \|e   - 6a e  + (36a b c + 6b )d e
+--R         + 
+--R               3 2
+--R           - 6c d
+--R      *
+--R                3+-+   3+-+
+--R              2x\|e  - \|d
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|d
+--R     + 
+--R             2        2         2   +-+       3     3+-+2 3+-+
+--R       ((- 6a c - 6a b )e + 6b c d)\|3 log(e x  + d)\|d   \|e
+--R  /
+--R       2 +-+3+-+2 3+-+
+--R     6e \|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 125
+
+)clear all
+
+--S 126 of 953
+t0:=(a+b*x+c*x^2)^4/(d+e*x^3)
+--R 
+--R
+--R   (1)
+--R        4 8       3 7        3     2 2  6           2     3   5
+--R       c x  + 4b c x  + (4a c  + 6b c )x  + (12a b c  + 4b c)x
+--R     + 
+--R          2 2        2     4  4       2          3  3      3      2 2  2
+--R       (6a c  + 12a b c + b )x  + (12a b c + 4a b )x  + (4a c + 6a b )x
+--R     + 
+--R         3       4
+--R       4a b x + a
+--R  /
+--R        3
+--R     e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 126
+
+--S 127 of 953
+r0:=-2*(3*b^2*c^2*d+2*a*c^3*d-2*a*b^3*e-6*a^2*b*c*e)*x/e^2-_
+   1/2*(4*b*c^3*d-b^4*e-12*a*b^2*c*e-6*a^2*c^2*e)*x^2/e^2-_
+   1/3*c*(c^3*d-4*b^3*e-12*a*b*c*e)*x^3/e^2+1/2*c^2*(3*b^2+2*a*c)*x^4/e+_
+   4/5*b*c^3*x^5/e+1/6*c^4*x^6/e+1/3*(e^(1/3)*(6*b^2*c^2*d^2+4*a*c^3*d^2-_
+   4*a*b^3*d*e-12*a^2*b*c*d*e+a^4*e^2)+d^(1/3)*(b^4*d*e+12*a*b^2*c*d*e+_
+   6*a^2*c^2*d*e-4*b*(c^3*d^2+a^3*e^2)))*log(d^(1/3)+e^(1/3)*x)/_
+   (d^(2/3)*e^(8/3))-1/6*(e^(1/3)*(6*b^2*c^2*d^2+4*a*c^3*d^2-4*a*b^3*d*e-_
+   12*a^2*b*c*d*e+a^4*e^2)+d^(1/3)*(b^4*d*e+12*a*b^2*c*d*e+6*a^2*c^2*d*e-_
+   4*b*(c^3*d^2+a^3*e^2)))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(8/3))+1/3*(c^4*d^2-12*a*b*c^2*d*e+6*a^2*b^2*e^2-4*c*e*_
+   (b^3*d-a^3*e))*log(d+e*x^3)/e^3-(b*d^(1/3)+a*e^(1/3))*(4*c^3*d^2+_
+   6*c^2*(b*d^(5/3)*e^(1/3)-a*d^(4/3)*e^(2/3))-12*a*b*c*d*e-_
+   e*(b^3*d+3*a*b^2*d^(2/3)*e^(1/3)-3*a^2*b*d^(1/3)*e^(2/3)-a^3*e))*_
+   atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(8/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                4 3       2           3    2           3      2 2  2   +-+3+-+
+--R           (- 5a e  + (60a b c + 20a b )d e  + (- 20a c  - 30b c )d e)\|3 \|e
+--R         + 
+--R               3   3         2 2        2      4    2        3 2   +-+3+-+
+--R           (20a b e  + (- 30a c  - 60a b c - 5b )d e  + 20b c d e)\|3 \|d
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R               4 3          2           3    2         3      2 2  2   +-+3+-+
+--R           (10a e  + (- 120a b c - 40a b )d e  + (40a c  + 60b c )d e)\|3 \|e
+--R         + 
+--R                 3   3       2 2         2       4    2        3 2   +-+3+-+
+--R           (- 40a b e  + (60a c  + 120a b c + 10b )d e  - 40b c d e)\|3 \|d
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|e  + \|d )
+--R     + 
+--R               4 3          2            3    2          3       2 2  2  3+-+
+--R           (30a e  + (- 360a b c - 120a b )d e  + (120a c  + 180b c )d e)\|e
+--R         + 
+--R                3   3          2 2         2       4    2         3 2  3+-+
+--R           (120a b e  + (- 180a c  - 360a b c - 30b )d e  + 120b c d e)\|d
+--R      *
+--R                3+-+   3+-+
+--R              2x\|e  - \|d
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|d
+--R     + 
+--R                  3       2 2  2              2      3           4 2  +-+
+--R             ((40a c + 60a b )e  + (- 120a b c  - 40b c)d e + 10c d )\|3
+--R          *
+--R                    3
+--R             log(e x  + d)
+--R         + 
+--R                 4 2 6        3 2 5         3      2 2  2 4
+--R               5c e x  + 24b c e x  + (30a c  + 45b c )e x
+--R             + 
+--R                         2      3   2      4     3
+--R               ((120a b c  + 40b c)e  - 10c d e)x
+--R             + 
+--R                    2 2         2       4  2        3     2
+--R               ((90a c  + 180a b c + 15b )e  - 60b c d e)x
+--R             + 
+--R                     2            3  2            3       2 2
+--R               ((360a b c + 120a b )e  + (- 120a c  - 180b c )d e)x
+--R          *
+--R              +-+
+--R             \|3
+--R      *
+--R         3+-+2 3+-+2
+--R         \|d   \|e
+--R  /
+--R        3 +-+3+-+2 3+-+2
+--R     30e \|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                   3
+--R                15e
+--R             *
+--R                ROOT
+--R                             6     2
+--R                       - 9d e %%BK0
+--R                     + 
+--R                               3       2 2    5             2      3   2 4
+--R                           (24a c + 36a b )d e  + (- 72a b c  - 24b c)d e
+--R                         + 
+--R                             4 3 3
+--R                           6c d e
+--R                      *
+--R                         %%BK0
+--R                     + 
+--R                            7   5      6 2       5 2       4 4    4
+--R                       - 16a b e  + (8a c  + 192a b c + 32a b )d e
+--R                     + 
+--R                              4   3       3 3 2       2 5         7  2 3
+--R                       (- 272a b c  - 592a b c  - 192a b c - 16a b )d e
+--R                     + 
+--R                           3 5       2 2 4         4 3     6 2  3 2
+--R                       (88a c  + 372a b c  + 272a b c  + 8b c )d e
+--R                     + 
+--R                                 6      3 5  4     8 5
+--R                       (- 40a b c  - 88b c )d e - c d
+--R                  /
+--R                         6
+--R                     3d e
+--R         + 
+--R                3            3       2 2  2              2      3           4 2
+--R           - 15e %%BK0 + (60a c + 90a b )e  + (- 180a b c  - 60b c)d e + 15c d
+--R      *
+--R         log
+--R                        3   2 8         2 2         2      4  3 7        3 4 6
+--R                    (36a b d e  + (- 54a c  - 108a b c - 9b )d e  + 36b c d e )
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                      8   8       6         5 3  2 7
+--R                  - 3a d e  + (24a b c - 48a b )d e
+--R                + 
+--R                      5 3      4 2 2      3 4       2 6  3 6
+--R                  (48a c  - 72a b c  - 12a b c - 30a b )d e
+--R                + 
+--R                      3   4      2 3 3        5 2      7   4 5
+--R                  (12a b c  - 48a b c  - 36a b c  - 12b c)d e
+--R                + 
+--R                        2 6        2 5      4 4  5 4        7 6 3
+--R                  (- 30a c  + 36a b c  - 57b c )d e  - 12b c d e
+--R             *
+--R                ROOT
+--R                             6     2
+--R                       - 9d e %%BK0
+--R                     + 
+--R                               3       2 2    5             2      3   2 4
+--R                           (24a c + 36a b )d e  + (- 72a b c  - 24b c)d e
+--R                         + 
+--R                             4 3 3
+--R                           6c d e
+--R                      *
+--R                         %%BK0
+--R                     + 
+--R                            7   5      6 2       5 2       4 4    4
+--R                       - 16a b e  + (8a c  + 192a b c + 32a b )d e
+--R                     + 
+--R                              4   3       3 3 2       2 5         7  2 3
+--R                       (- 272a b c  - 592a b c  - 192a b c - 16a b )d e
+--R                     + 
+--R                           3 5       2 2 4         4 3     6 2  3 2
+--R                       (88a c  + 372a b c  + 272a b c  + 8b c )d e
+--R                     + 
+--R                                 6      3 5  4     8 5
+--R                       (- 40a b c  - 88b c )d e - c d
+--R                  /
+--R                         6
+--R                     3d e
+--R            + 
+--R                    3   2 8       2 2         2      4  3 7        3 4 6      2
+--R              (- 36a b d e  + (54a c  + 108a b c + 9b )d e  - 36b c d e )%%BK0
+--R            + 
+--R                      8   8        6          5 3  2 7
+--R                  - 3a d e  + (168a b c + 168a b )d e
+--R                + 
+--R                         5 3        4 2 2       3 4       2 6  3 6
+--R                  (- 168a c  - 1260a b c  - 840a b c - 84a b )d e
+--R                + 
+--R                       3   4        2 3 3         5 2      7   4 5
+--R                  (840a b c  + 1680a b c  + 504a b c  + 24b c)d e
+--R                + 
+--R                        2 6         2 5       4 4  5 4        7 6 3
+--R                  (- 84a c  - 504a b c  - 210b c )d e  + 24b c d e
+--R             *
+--R                %%BK0
+--R            + 
+--R                    12 8         10          9 3    7
+--R                  2a  e  + (- 72a  b c + 104a b )d e
+--R                + 
+--R                      9 3       8 2 2       7 4   2 6
+--R                  (24a c  + 324a b c  - 576a b c)d e
+--R                + 
+--R                       7   4       6 3 3       4 7        3 9  3 5
+--R                  (288a b c  - 672a b c  - 576a b c - 104a b )d e
+--R                + 
+--R                         6 6       3 6 3       2 8 2        10      12  4 4
+--R                  (- 336a c  - 672a b c  - 324a b c  - 72a b  c - 2b  )d e
+--R                + 
+--R                         4   7         7 4      9 3  5 3
+--R                  (- 288a b c  - 288a b c  + 24b c )d e
+--R                + 
+--R                       3 9         4 7       6 6  6 2       3 9 7
+--R                  (128a c  - 288a b c  + 336b c )d e  + 128b c d e
+--R             *
+--R                x
+--R            + 
+--R                 11       10 2    7         9   2       8 3       7 5  2 6
+--R              (4a  c - 26a  b )d e  + (- 76a b c  + 204a b c - 48a b )d e
+--R            + 
+--R                  8 4       7 2 3       6 4 2       5 6       4 8  3 5
+--R              (57a c  + 192a b c  - 168a b c  + 336a b c + 66a b )d e
+--R            + 
+--R                      6   5       5 3 4       4 5 3       3 7 2       2 9
+--R                  168a b c  - 168a b c  + 336a b c  + 240a b c  + 104a b c
+--R                + 
+--R                      11
+--R                  8a b
+--R             *
+--R                 4 4
+--R                d e
+--R            + 
+--R                          5 7      4 2 6       3 4 5      2 6 4         8 3
+--R                    - 168a c  + 84a b c  + 168a b c  + 84a b c  + 120a b c
+--R                  + 
+--R                      10 2
+--R                    4b  c
+--R             *
+--R                 5 3
+--R                d e
+--R            + 
+--R                    3   8      2 3 7         5 6       7 5  6 2
+--R              (- 84a b c  - 48a b c  + 168a b c  - 120b c )d e
+--R            + 
+--R                  2 10        2 9       4 8  7        11 8
+--R              (22a c   + 28a b c  - 123b c )d e - 4b c  d
+--R     + 
+--R                3
+--R             15e
+--R          *
+--R             ROOT
+--R                          6     2
+--R                    - 9d e %%BK0
+--R                  + 
+--R                              3       2 2    5             2      3   2 4
+--R                          (24a c + 36a b )d e  + (- 72a b c  - 24b c)d e
+--R                        + 
+--R                            4 3 3
+--R                          6c d e
+--R                   *
+--R                      %%BK0
+--R                  + 
+--R                         7   5      6 2       5 2       4 4    4
+--R                    - 16a b e  + (8a c  + 192a b c + 32a b )d e
+--R                  + 
+--R                           4   3       3 3 2       2 5         7  2 3
+--R                    (- 272a b c  - 592a b c  - 192a b c - 16a b )d e
+--R                  + 
+--R                        3 5       2 2 4         4 3     6 2  3 2
+--R                    (88a c  + 372a b c  + 272a b c  + 8b c )d e
+--R                  + 
+--R                              6      3 5  4     8 5
+--R                    (- 40a b c  - 88b c )d e - c d
+--R               /
+--R                      6
+--R                  3d e
+--R         + 
+--R                3            3       2 2  2              2      3           4 2
+--R           - 15e %%BK0 + (60a c + 90a b )e  + (- 180a b c  - 60b c)d e + 15c d
+--R      *
+--R         log
+--R                          3   2 8       2 2         2      4  3 7        3 4 6
+--R                    (- 36a b d e  + (54a c  + 108a b c + 9b )d e  - 36b c d e )
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                    8   8         6         5 3  2 7
+--R                  3a d e  + (- 24a b c + 48a b )d e
+--R                + 
+--R                        5 3      4 2 2      3 4       2 6  3 6
+--R                  (- 48a c  + 72a b c  + 12a b c + 30a b )d e
+--R                + 
+--R                        3   4      2 3 3        5 2      7   4 5
+--R                  (- 12a b c  + 48a b c  + 36a b c  + 12b c)d e
+--R                + 
+--R                      2 6        2 5      4 4  5 4        7 6 3
+--R                  (30a c  - 36a b c  + 57b c )d e  + 12b c d e
+--R             *
+--R                ROOT
+--R                             6     2
+--R                       - 9d e %%BK0
+--R                     + 
+--R                               3       2 2    5             2      3   2 4
+--R                           (24a c + 36a b )d e  + (- 72a b c  - 24b c)d e
+--R                         + 
+--R                             4 3 3
+--R                           6c d e
+--R                      *
+--R                         %%BK0
+--R                     + 
+--R                            7   5      6 2       5 2       4 4    4
+--R                       - 16a b e  + (8a c  + 192a b c + 32a b )d e
+--R                     + 
+--R                              4   3       3 3 2       2 5         7  2 3
+--R                       (- 272a b c  - 592a b c  - 192a b c - 16a b )d e
+--R                     + 
+--R                           3 5       2 2 4         4 3     6 2  3 2
+--R                       (88a c  + 372a b c  + 272a b c  + 8b c )d e
+--R                     + 
+--R                                 6      3 5  4     8 5
+--R                       (- 40a b c  - 88b c )d e - c d
+--R                  /
+--R                         6
+--R                     3d e
+--R            + 
+--R                    3   2 8       2 2         2      4  3 7        3 4 6      2
+--R              (- 36a b d e  + (54a c  + 108a b c + 9b )d e  - 36b c d e )%%BK0
+--R            + 
+--R                      8   8        6          5 3  2 7
+--R                  - 3a d e  + (168a b c + 168a b )d e
+--R                + 
+--R                         5 3        4 2 2       3 4       2 6  3 6
+--R                  (- 168a c  - 1260a b c  - 840a b c - 84a b )d e
+--R                + 
+--R                       3   4        2 3 3         5 2      7   4 5
+--R                  (840a b c  + 1680a b c  + 504a b c  + 24b c)d e
+--R                + 
+--R                        2 6         2 5       4 4  5 4        7 6 3
+--R                  (- 84a c  - 504a b c  - 210b c )d e  + 24b c d e
+--R             *
+--R                %%BK0
+--R            + 
+--R                    12 8         10          9 3    7
+--R                  2a  e  + (- 72a  b c + 104a b )d e
+--R                + 
+--R                      9 3       8 2 2       7 4   2 6
+--R                  (24a c  + 324a b c  - 576a b c)d e
+--R                + 
+--R                       7   4       6 3 3       4 7        3 9  3 5
+--R                  (288a b c  - 672a b c  - 576a b c - 104a b )d e
+--R                + 
+--R                         6 6       3 6 3       2 8 2        10      12  4 4
+--R                  (- 336a c  - 672a b c  - 324a b c  - 72a b  c - 2b  )d e
+--R                + 
+--R                         4   7         7 4      9 3  5 3
+--R                  (- 288a b c  - 288a b c  + 24b c )d e
+--R                + 
+--R                       3 9         4 7       6 6  6 2       3 9 7
+--R                  (128a c  - 288a b c  + 336b c )d e  + 128b c d e
+--R             *
+--R                x
+--R            + 
+--R                 11       10 2    7         9   2       8 3       7 5  2 6
+--R              (4a  c - 26a  b )d e  + (- 76a b c  + 204a b c - 48a b )d e
+--R            + 
+--R                  8 4       7 2 3       6 4 2       5 6       4 8  3 5
+--R              (57a c  + 192a b c  - 168a b c  + 336a b c + 66a b )d e
+--R            + 
+--R                      6   5       5 3 4       4 5 3       3 7 2       2 9
+--R                  168a b c  - 168a b c  + 336a b c  + 240a b c  + 104a b c
+--R                + 
+--R                      11
+--R                  8a b
+--R             *
+--R                 4 4
+--R                d e
+--R            + 
+--R                          5 7      4 2 6       3 4 5      2 6 4         8 3
+--R                    - 168a c  + 84a b c  + 168a b c  + 84a b c  + 120a b c
+--R                  + 
+--R                      10 2
+--R                    4b  c
+--R             *
+--R                 5 3
+--R                d e
+--R            + 
+--R                    3   8      2 3 7         5 6       7 5  6 2
+--R              (- 84a b c  - 48a b c  + 168a b c  - 120b c )d e
+--R            + 
+--R                  2 10        2 9       4 8  7        11 8
+--R              (22a c   + 28a b c  - 123b c )d e - 4b c  d
+--R     + 
+--R            3
+--R         30e %%BK0
+--R      *
+--R         log
+--R                  3   2 8         2 2         2      4  3 7        3 4 6      2
+--R              (36a b d e  + (- 54a c  - 108a b c - 9b )d e  + 36b c d e )%%BK0
+--R            + 
+--R                    8   8          6          5 3  2 7
+--R                  3a d e  + (- 168a b c - 168a b )d e
+--R                + 
+--R                       5 3        4 2 2       3 4       2 6  3 6
+--R                  (168a c  + 1260a b c  + 840a b c + 84a b )d e
+--R                + 
+--R                         3   4        2 3 3         5 2      7   4 5
+--R                  (- 840a b c  - 1680a b c  - 504a b c  - 24b c)d e
+--R                + 
+--R                      2 6         2 5       4 4  5 4        7 6 3
+--R                  (84a c  + 504a b c  + 210b c )d e  - 24b c d e
+--R             *
+--R                %%BK0
+--R            + 
+--R                   12 8         10         9 3    7
+--R                  a  e  + (- 36a  b c + 52a b )d e
+--R                + 
+--R                      9 3       8 2 2       7 4   2 6
+--R                  (12a c  + 162a b c  - 288a b c)d e
+--R                + 
+--R                       7   4       6 3 3       4 7       3 9  3 5
+--R                  (144a b c  - 336a b c  - 288a b c - 52a b )d e
+--R                + 
+--R                         6 6       3 6 3       2 8 2        10     12  4 4
+--R                  (- 168a c  - 336a b c  - 162a b c  - 36a b  c - b  )d e
+--R                + 
+--R                         4   7         7 4      9 3  5 3
+--R                  (- 144a b c  - 144a b c  + 12b c )d e
+--R                + 
+--R                      3 9         4 7       6 6  6 2      3 9 7
+--R                  (64a c  - 144a b c  + 168b c )d e  + 64b c d e
+--R             *
+--R                x
+--R            + 
+--R                   11       10 2    7       9   2       8 3       7 5  2 6
+--R              (- 4a  c + 26a  b )d e  + (76a b c  - 204a b c + 48a b )d e
+--R            + 
+--R                    8 4       7 2 3       6 4 2       5 6       4 8  3 5
+--R              (- 57a c  - 192a b c  + 168a b c  - 336a b c - 66a b )d e
+--R            + 
+--R                        6   5       5 3 4       4 5 3       3 7 2       2 9
+--R                  - 168a b c  + 168a b c  - 336a b c  - 240a b c  - 104a b c
+--R                + 
+--R                        11
+--R                  - 8a b
+--R             *
+--R                 4 4
+--R                d e
+--R            + 
+--R                     5 7      4 2 6       3 4 5      2 6 4         8 3     10 2
+--R                (168a c  - 84a b c  - 168a b c  - 84a b c  - 120a b c  - 4b  c )
+--R             *
+--R                 5 3
+--R                d e
+--R            + 
+--R                  3   8      2 3 7         5 6       7 5  6 2
+--R              (84a b c  + 48a b c  - 168a b c  + 120b c )d e
+--R            + 
+--R                    2 10        2 9       4 8  7        11 8
+--R              (- 22a c   - 28a b c  + 123b c )d e + 4b c  d
+--R     + 
+--R         4 2 6        3 2 5         3      2 2  2 4
+--R       5c e x  + 24b c e x  + (30a c  + 45b c )e x
+--R     + 
+--R                 2      3   2      4     3
+--R       ((120a b c  + 40b c)e  - 10c d e)x
+--R     + 
+--R            2 2         2       4  2        3     2
+--R       ((90a c  + 180a b c + 15b )e  - 60b c d e)x
+--R     + 
+--R             2            3  2            3       2 2
+--R       ((360a b c + 120a b )e  + (- 120a c  - 180b c )d e)x
+--R  /
+--R        3
+--R     30e
+--R                                         Type: Union(Expression(Integer),...)
+--E 128
+
+--S 129 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                  3 +-+3+-+2 3+-+2
+--R                3e \|3 \|d   \|e
+--R             *
+--R                ROOT
+--R                             6     2
+--R                       - 9d e %%BK0
+--R                     + 
+--R                               3       2 2    5             2      3   2 4
+--R                           (24a c + 36a b )d e  + (- 72a b c  - 24b c)d e
+--R                         + 
+--R                             4 3 3
+--R                           6c d e
+--R                      *
+--R                         %%BK0
+--R                     + 
+--R                            7   5      6 2       5 2       4 4    4
+--R                       - 16a b e  + (8a c  + 192a b c + 32a b )d e
+--R                     + 
+--R                              4   3       3 3 2       2 5         7  2 3
+--R                       (- 272a b c  - 592a b c  - 192a b c - 16a b )d e
+--R                     + 
+--R                           3 5       2 2 4         4 3     6 2  3 2
+--R                       (88a c  + 372a b c  + 272a b c  + 8b c )d e
+--R                     + 
+--R                                 6      3 5  4     8 5
+--R                       (- 40a b c  - 88b c )d e - c d
+--R                  /
+--R                         6
+--R                     3d e
+--R         + 
+--R               3 +-+3+-+2 3+-+2
+--R           - 3e \|3 \|d   \|e  %%BK0
+--R         + 
+--R                3       2 2  2             2      3          4 2  +-+3+-+2 3+-+2
+--R           ((12a c + 18a b )e  + (- 36a b c  - 12b c)d e + 3c d )\|3 \|d   \|e
+--R      *
+--R         log
+--R                        3   2 8         2 2         2      4  3 7        3 4 6
+--R                    (36a b d e  + (- 54a c  - 108a b c - 9b )d e  + 36b c d e )
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                      8   8       6         5 3  2 7
+--R                  - 3a d e  + (24a b c - 48a b )d e
+--R                + 
+--R                      5 3      4 2 2      3 4       2 6  3 6
+--R                  (48a c  - 72a b c  - 12a b c - 30a b )d e
+--R                + 
+--R                      3   4      2 3 3        5 2      7   4 5
+--R                  (12a b c  - 48a b c  - 36a b c  - 12b c)d e
+--R                + 
+--R                        2 6        2 5      4 4  5 4        7 6 3
+--R                  (- 30a c  + 36a b c  - 57b c )d e  - 12b c d e
+--R             *
+--R                ROOT
+--R                             6     2
+--R                       - 9d e %%BK0
+--R                     + 
+--R                               3       2 2    5             2      3   2 4
+--R                           (24a c + 36a b )d e  + (- 72a b c  - 24b c)d e
+--R                         + 
+--R                             4 3 3
+--R                           6c d e
+--R                      *
+--R                         %%BK0
+--R                     + 
+--R                            7   5      6 2       5 2       4 4    4
+--R                       - 16a b e  + (8a c  + 192a b c + 32a b )d e
+--R                     + 
+--R                              4   3       3 3 2       2 5         7  2 3
+--R                       (- 272a b c  - 592a b c  - 192a b c - 16a b )d e
+--R                     + 
+--R                           3 5       2 2 4         4 3     6 2  3 2
+--R                       (88a c  + 372a b c  + 272a b c  + 8b c )d e
+--R                     + 
+--R                                 6      3 5  4     8 5
+--R                       (- 40a b c  - 88b c )d e - c d
+--R                  /
+--R                         6
+--R                     3d e
+--R            + 
+--R                    3   2 8       2 2         2      4  3 7        3 4 6      2
+--R              (- 36a b d e  + (54a c  + 108a b c + 9b )d e  - 36b c d e )%%BK0
+--R            + 
+--R                      8   8        6          5 3  2 7
+--R                  - 3a d e  + (168a b c + 168a b )d e
+--R                + 
+--R                         5 3        4 2 2       3 4       2 6  3 6
+--R                  (- 168a c  - 1260a b c  - 840a b c - 84a b )d e
+--R                + 
+--R                       3   4        2 3 3         5 2      7   4 5
+--R                  (840a b c  + 1680a b c  + 504a b c  + 24b c)d e
+--R                + 
+--R                        2 6         2 5       4 4  5 4        7 6 3
+--R                  (- 84a c  - 504a b c  - 210b c )d e  + 24b c d e
+--R             *
+--R                %%BK0
+--R            + 
+--R                    12 8         10          9 3    7
+--R                  2a  e  + (- 72a  b c + 104a b )d e
+--R                + 
+--R                      9 3       8 2 2       7 4   2 6
+--R                  (24a c  + 324a b c  - 576a b c)d e
+--R                + 
+--R                       7   4       6 3 3       4 7        3 9  3 5
+--R                  (288a b c  - 672a b c  - 576a b c - 104a b )d e
+--R                + 
+--R                         6 6       3 6 3       2 8 2        10      12  4 4
+--R                  (- 336a c  - 672a b c  - 324a b c  - 72a b  c - 2b  )d e
+--R                + 
+--R                         4   7         7 4      9 3  5 3
+--R                  (- 288a b c  - 288a b c  + 24b c )d e
+--R                + 
+--R                       3 9         4 7       6 6  6 2       3 9 7
+--R                  (128a c  - 288a b c  + 336b c )d e  + 128b c d e
+--R             *
+--R                x
+--R            + 
+--R                 11       10 2    7         9   2       8 3       7 5  2 6
+--R              (4a  c - 26a  b )d e  + (- 76a b c  + 204a b c - 48a b )d e
+--R            + 
+--R                  8 4       7 2 3       6 4 2       5 6       4 8  3 5
+--R              (57a c  + 192a b c  - 168a b c  + 336a b c + 66a b )d e
+--R            + 
+--R                      6   5       5 3 4       4 5 3       3 7 2       2 9
+--R                  168a b c  - 168a b c  + 336a b c  + 240a b c  + 104a b c
+--R                + 
+--R                      11
+--R                  8a b
+--R             *
+--R                 4 4
+--R                d e
+--R            + 
+--R                          5 7      4 2 6       3 4 5      2 6 4         8 3
+--R                    - 168a c  + 84a b c  + 168a b c  + 84a b c  + 120a b c
+--R                  + 
+--R                      10 2
+--R                    4b  c
+--R             *
+--R                 5 3
+--R                d e
+--R            + 
+--R                    3   8      2 3 7         5 6       7 5  6 2
+--R              (- 84a b c  - 48a b c  + 168a b c  - 120b c )d e
+--R            + 
+--R                  2 10        2 9       4 8  7        11 8
+--R              (22a c   + 28a b c  - 123b c )d e - 4b c  d
+--R     + 
+--R               3 +-+3+-+2 3+-+2
+--R             3e \|3 \|d   \|e
+--R          *
+--R             ROOT
+--R                          6     2
+--R                    - 9d e %%BK0
+--R                  + 
+--R                              3       2 2    5             2      3   2 4
+--R                          (24a c + 36a b )d e  + (- 72a b c  - 24b c)d e
+--R                        + 
+--R                            4 3 3
+--R                          6c d e
+--R                   *
+--R                      %%BK0
+--R                  + 
+--R                         7   5      6 2       5 2       4 4    4
+--R                    - 16a b e  + (8a c  + 192a b c + 32a b )d e
+--R                  + 
+--R                           4   3       3 3 2       2 5         7  2 3
+--R                    (- 272a b c  - 592a b c  - 192a b c - 16a b )d e
+--R                  + 
+--R                        3 5       2 2 4         4 3     6 2  3 2
+--R                    (88a c  + 372a b c  + 272a b c  + 8b c )d e
+--R                  + 
+--R                              6      3 5  4     8 5
+--R                    (- 40a b c  - 88b c )d e - c d
+--R               /
+--R                      6
+--R                  3d e
+--R         + 
+--R               3 +-+3+-+2 3+-+2
+--R           - 3e \|3 \|d   \|e  %%BK0
+--R         + 
+--R                3       2 2  2             2      3          4 2  +-+3+-+2 3+-+2
+--R           ((12a c + 18a b )e  + (- 36a b c  - 12b c)d e + 3c d )\|3 \|d   \|e
+--R      *
+--R         log
+--R                          3   2 8       2 2         2      4  3 7        3 4 6
+--R                    (- 36a b d e  + (54a c  + 108a b c + 9b )d e  - 36b c d e )
+--R                 *
+--R                    %%BK0
+--R                + 
+--R                    8   8         6         5 3  2 7
+--R                  3a d e  + (- 24a b c + 48a b )d e
+--R                + 
+--R                        5 3      4 2 2      3 4       2 6  3 6
+--R                  (- 48a c  + 72a b c  + 12a b c + 30a b )d e
+--R                + 
+--R                        3   4      2 3 3        5 2      7   4 5
+--R                  (- 12a b c  + 48a b c  + 36a b c  + 12b c)d e
+--R                + 
+--R                      2 6        2 5      4 4  5 4        7 6 3
+--R                  (30a c  - 36a b c  + 57b c )d e  + 12b c d e
+--R             *
+--R                ROOT
+--R                             6     2
+--R                       - 9d e %%BK0
+--R                     + 
+--R                               3       2 2    5             2      3   2 4
+--R                           (24a c + 36a b )d e  + (- 72a b c  - 24b c)d e
+--R                         + 
+--R                             4 3 3
+--R                           6c d e
+--R                      *
+--R                         %%BK0
+--R                     + 
+--R                            7   5      6 2       5 2       4 4    4
+--R                       - 16a b e  + (8a c  + 192a b c + 32a b )d e
+--R                     + 
+--R                              4   3       3 3 2       2 5         7  2 3
+--R                       (- 272a b c  - 592a b c  - 192a b c - 16a b )d e
+--R                     + 
+--R                           3 5       2 2 4         4 3     6 2  3 2
+--R                       (88a c  + 372a b c  + 272a b c  + 8b c )d e
+--R                     + 
+--R                                 6      3 5  4     8 5
+--R                       (- 40a b c  - 88b c )d e - c d
+--R                  /
+--R                         6
+--R                     3d e
+--R            + 
+--R                    3   2 8       2 2         2      4  3 7        3 4 6      2
+--R              (- 36a b d e  + (54a c  + 108a b c + 9b )d e  - 36b c d e )%%BK0
+--R            + 
+--R                      8   8        6          5 3  2 7
+--R                  - 3a d e  + (168a b c + 168a b )d e
+--R                + 
+--R                         5 3        4 2 2       3 4       2 6  3 6
+--R                  (- 168a c  - 1260a b c  - 840a b c - 84a b )d e
+--R                + 
+--R                       3   4        2 3 3         5 2      7   4 5
+--R                  (840a b c  + 1680a b c  + 504a b c  + 24b c)d e
+--R                + 
+--R                        2 6         2 5       4 4  5 4        7 6 3
+--R                  (- 84a c  - 504a b c  - 210b c )d e  + 24b c d e
+--R             *
+--R                %%BK0
+--R            + 
+--R                    12 8         10          9 3    7
+--R                  2a  e  + (- 72a  b c + 104a b )d e
+--R                + 
+--R                      9 3       8 2 2       7 4   2 6
+--R                  (24a c  + 324a b c  - 576a b c)d e
+--R                + 
+--R                       7   4       6 3 3       4 7        3 9  3 5
+--R                  (288a b c  - 672a b c  - 576a b c - 104a b )d e
+--R                + 
+--R                         6 6       3 6 3       2 8 2        10      12  4 4
+--R                  (- 336a c  - 672a b c  - 324a b c  - 72a b  c - 2b  )d e
+--R                + 
+--R                         4   7         7 4      9 3  5 3
+--R                  (- 288a b c  - 288a b c  + 24b c )d e
+--R                + 
+--R                       3 9         4 7       6 6  6 2       3 9 7
+--R                  (128a c  - 288a b c  + 336b c )d e  + 128b c d e
+--R             *
+--R                x
+--R            + 
+--R                 11       10 2    7         9   2       8 3       7 5  2 6
+--R              (4a  c - 26a  b )d e  + (- 76a b c  + 204a b c - 48a b )d e
+--R            + 
+--R                  8 4       7 2 3       6 4 2       5 6       4 8  3 5
+--R              (57a c  + 192a b c  - 168a b c  + 336a b c + 66a b )d e
+--R            + 
+--R                      6   5       5 3 4       4 5 3       3 7 2       2 9
+--R                  168a b c  - 168a b c  + 336a b c  + 240a b c  + 104a b c
+--R                + 
+--R                      11
+--R                  8a b
+--R             *
+--R                 4 4
+--R                d e
+--R            + 
+--R                          5 7      4 2 6       3 4 5      2 6 4         8 3
+--R                    - 168a c  + 84a b c  + 168a b c  + 84a b c  + 120a b c
+--R                  + 
+--R                      10 2
+--R                    4b  c
+--R             *
+--R                 5 3
+--R                d e
+--R            + 
+--R                    3   8      2 3 7         5 6       7 5  6 2
+--R              (- 84a b c  - 48a b c  + 168a b c  - 120b c )d e
+--R            + 
+--R                  2 10        2 9       4 8  7        11 8
+--R              (22a c   + 28a b c  - 123b c )d e - 4b c  d
+--R     + 
+--R           3 +-+3+-+2 3+-+2
+--R         6e \|3 \|d   \|e  %%BK0
+--R      *
+--R         log
+--R                  3   2 8         2 2         2      4  3 7        3 4 6      2
+--R              (36a b d e  + (- 54a c  - 108a b c - 9b )d e  + 36b c d e )%%BK0
+--R            + 
+--R                    8   8          6          5 3  2 7
+--R                  3a d e  + (- 168a b c - 168a b )d e
+--R                + 
+--R                       5 3        4 2 2       3 4       2 6  3 6
+--R                  (168a c  + 1260a b c  + 840a b c + 84a b )d e
+--R                + 
+--R                         3   4        2 3 3         5 2      7   4 5
+--R                  (- 840a b c  - 1680a b c  - 504a b c  - 24b c)d e
+--R                + 
+--R                      2 6         2 5       4 4  5 4        7 6 3
+--R                  (84a c  + 504a b c  + 210b c )d e  - 24b c d e
+--R             *
+--R                %%BK0
+--R            + 
+--R                   12 8         10         9 3    7
+--R                  a  e  + (- 36a  b c + 52a b )d e
+--R                + 
+--R                      9 3       8 2 2       7 4   2 6
+--R                  (12a c  + 162a b c  - 288a b c)d e
+--R                + 
+--R                       7   4       6 3 3       4 7       3 9  3 5
+--R                  (144a b c  - 336a b c  - 288a b c - 52a b )d e
+--R                + 
+--R                         6 6       3 6 3       2 8 2        10     12  4 4
+--R                  (- 168a c  - 336a b c  - 162a b c  - 36a b  c - b  )d e
+--R                + 
+--R                         4   7         7 4      9 3  5 3
+--R                  (- 144a b c  - 144a b c  + 12b c )d e
+--R                + 
+--R                      3 9         4 7       6 6  6 2      3 9 7
+--R                  (64a c  - 144a b c  + 168b c )d e  + 64b c d e
+--R             *
+--R                x
+--R            + 
+--R                   11       10 2    7       9   2       8 3       7 5  2 6
+--R              (- 4a  c + 26a  b )d e  + (76a b c  - 204a b c + 48a b )d e
+--R            + 
+--R                    8 4       7 2 3       6 4 2       5 6       4 8  3 5
+--R              (- 57a c  - 192a b c  + 168a b c  - 336a b c - 66a b )d e
+--R            + 
+--R                        6   5       5 3 4       4 5 3       3 7 2       2 9
+--R                  - 168a b c  + 168a b c  - 336a b c  - 240a b c  - 104a b c
+--R                + 
+--R                        11
+--R                  - 8a b
+--R             *
+--R                 4 4
+--R                d e
+--R            + 
+--R                     5 7      4 2 6       3 4 5      2 6 4         8 3     10 2
+--R                (168a c  - 84a b c  - 168a b c  - 84a b c  - 120a b c  - 4b  c )
+--R             *
+--R                 5 3
+--R                d e
+--R            + 
+--R                  3   8      2 3 7         5 6       7 5  6 2
+--R              (84a b c  + 48a b c  - 168a b c  + 120b c )d e
+--R            + 
+--R                    2 10        2 9       4 8  7        11 8
+--R              (- 22a c   - 28a b c  + 123b c )d e + 4b c  d
+--R     + 
+--R             4 3         2          3    2        3     2 2  2   +-+3+-+
+--R           (a e  + (- 12a b c - 4a b )d e  + (4a c  + 6b c )d e)\|3 \|e
+--R         + 
+--R                3   3      2 2        2     4    2       3 2   +-+3+-+
+--R           (- 4a b e  + (6a c  + 12a b c + b )d e  - 4b c d e)\|3 \|d
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R                4 3       2          3    2          3      2 2  2   +-+3+-+
+--R           (- 2a e  + (24a b c + 8a b )d e  + (- 8a c  - 12b c )d e)\|3 \|e
+--R         + 
+--R              3   3         2 2        2      4    2       3 2   +-+3+-+
+--R           (8a b e  + (- 12a c  - 24a b c - 2b )d e  + 8b c d e)\|3 \|d
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|e  + \|d )
+--R     + 
+--R                4 3       2           3    2           3      2 2  2  3+-+
+--R           (- 6a e  + (72a b c + 24a b )d e  + (- 24a c  - 36b c )d e)\|e
+--R         + 
+--R                 3   3       2 2        2      4    2        3 2  3+-+
+--R           (- 24a b e  + (36a c  + 72a b c + 6b )d e  - 24b c d e)\|d
+--R      *
+--R                3+-+   3+-+
+--R              2x\|e  - \|d
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|d
+--R     + 
+--R               3       2 2  2           2     3          4 2  +-+       3
+--R         ((- 8a c - 12a b )e  + (24a b c  + 8b c)d e - 2c d )\|3 log(e x  + d)
+--R      *
+--R         3+-+2 3+-+2
+--R         \|d   \|e
+--R  /
+--R       3 +-+3+-+2 3+-+2
+--R     6e \|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 130
+
+)clear all
+
+--S 131 of 953
+t0:=(1+x)/(1+x^3)
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R         2
+--R        x  - x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 131
+
+--S 132 of 953
+r0:=-2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                       +-+
+--R              (2x - 1)\|3
+--R        2atan(------------)
+--R                    3
+--R   (2)  -------------------
+--R                 +-+
+--R                \|3
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       +-+
+--R              (2x - 1)\|3
+--R        2atan(------------)
+--R                    3
+--R   (3)  -------------------
+--R                 +-+
+--R                \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 133
+
+--S 134 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 953
+t0:=(1-x)/(1-x^3)
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R         2
+--R        x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 136
+
+--S 137 of 953
+r0:=2*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                       +-+
+--R              (2x + 1)\|3
+--R        2atan(------------)
+--R                    3
+--R   (2)  -------------------
+--R                 +-+
+--R                \|3
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       +-+
+--R              (2x + 1)\|3
+--R        2atan(------------)
+--R                    3
+--R   (3)  -------------------
+--R                 +-+
+--R                \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 138
+
+--S 139 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 140
+
+)clear all
+
+--S 141 of 953
+t0:=(1+x)/(1-x^3)
+--R 
+--R
+--R        - x - 1
+--R   (1)  -------
+--R          3
+--R         x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 141
+
+--S 142 of 953
+r0:=-2/3*log(1-x)+1/3*log(1+x+x^2)
+--R 
+--R
+--R             2
+--R        log(x  + x + 1) - 2log(- x + 1)
+--R   (2)  -------------------------------
+--R                       3
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R        log(x  + x + 1) - 2log(x - 1)
+--R   (3)  -----------------------------
+--R                      3
+--R                                         Type: Union(Expression(Integer),...)
+--E 143
+
+--S 144 of 953
+m0:=a0-r0
+--R 
+--R
+--R        - 2log(x - 1) + 2log(- x + 1)
+--R   (4)  -----------------------------
+--R                      3
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 145
+
+)clear all
+
+--S 146 of 953
+t0:=(1-x)/(1+x^3)
+--R 
+--R
+--R        - x + 1
+--R   (1)  -------
+--R          3
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 146
+
+--S 147 of 953
+r0:=2/3*log(1+x)-1/3*log(1-x+x^2)
+--R 
+--R
+--R               2
+--R        - log(x  - x + 1) + 2log(x + 1)
+--R   (2)  -------------------------------
+--R                       3
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R        - log(x  - x + 1) + 2log(x + 1)
+--R   (3)  -------------------------------
+--R                       3
+--R                                         Type: Union(Expression(Integer),...)
+--E 148
+
+--S 149 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 953
+t0:=(3-x)/(1-x^3)
+--R 
+--R
+--R         x - 3
+--R   (1)  ------
+--R         3
+--R        x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 151
+
+--S 152 of 953
+r0:=-2/3*log(1-x)+1/3*log(1+x+x^2)+4*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                  +-+
+--R         +-+     2              +-+                      (2x + 1)\|3
+--R        \|3 log(x  + x + 1) - 2\|3 log(- x + 1) + 12atan(------------)
+--R                                                               3
+--R   (2)  --------------------------------------------------------------
+--R                                       +-+
+--R                                     3\|3
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                                +-+
+--R         +-+     2              +-+                    (2x + 1)\|3
+--R        \|3 log(x  + x + 1) - 2\|3 log(x - 1) + 12atan(------------)
+--R                                                             3
+--R   (3)  ------------------------------------------------------------
+--R                                      +-+
+--R                                    3\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 153
+
+--S 154 of 953
+m0:=a0-r0
+--R 
+--R
+--R        - 2log(x - 1) + 2log(- x + 1)
+--R   (4)  -----------------------------
+--R                      3
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 155
+
+)clear all
+
+--S 156 of 953
+t0:=(c+d*x)/(c^3+d^3*x^3)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         2 2            2
+--R        d x  - c d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 156
+
+--S 157 of 953
+r0:=-2*atan((c-2*d*x)/(c*sqrt(3)))/(c*d*sqrt(3))
+--R 
+--R
+--R                         +-+
+--R              (2d x - c)\|3
+--R        2atan(--------------)
+--R                    3c
+--R   (2)  ---------------------
+--R                   +-+
+--R               c d\|3
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         +-+
+--R              (2d x - c)\|3
+--R        2atan(--------------)
+--R                    3c
+--R   (3)  ---------------------
+--R                   +-+
+--R               c d\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 158
+
+--S 159 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 160
+
+)clear all
+
+--S 161 of 953
+t0:=(c-d*x)/(c^3-d^3*x^3)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         2 2            2
+--R        d x  + c d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 161
+
+--S 162 of 953
+r0:=2*atan((c+2*d*x)/(c*sqrt(3)))/(c*d*sqrt(3))
+--R 
+--R
+--R                         +-+
+--R              (2d x + c)\|3
+--R        2atan(--------------)
+--R                    3c
+--R   (2)  ---------------------
+--R                   +-+
+--R               c d\|3
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         +-+
+--R              (2d x + c)\|3
+--R        2atan(--------------)
+--R                    3c
+--R   (3)  ---------------------
+--R                   +-+
+--R               c d\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 163
+
+--S 164 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 953
+t0:=(1-x+3*x^2)/(-1+x^3)
+--R 
+--R
+--R          2
+--R        3x  - x + 1
+--R   (1)  -----------
+--R            3
+--R           x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 166
+
+--S 167 of 953
+r0:=log(1-x^3)-2*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                           +-+
+--R         +-+       3              (2x + 1)\|3
+--R        \|3 log(- x  + 1) - 2atan(------------)
+--R                                        3
+--R   (2)  ---------------------------------------
+--R                           +-+
+--R                          \|3
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                              +-+
+--R         +-+     2             +-+                   (2x + 1)\|3
+--R        \|3 log(x  + x + 1) + \|3 log(x - 1) - 2atan(------------)
+--R                                                           3
+--R   (3)  ----------------------------------------------------------
+--R                                    +-+
+--R                                   \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 168
+
+--S 169 of 953
+m0:=a0-r0
+--R 
+--R
+--R             2                                3
+--R   (4)  log(x  + x + 1) + log(x - 1) - log(- x  + 1)
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 170
+
+)clear all
+
+--S 171 of 953
+t0:=(1+x+4*x^2)/(-1+x^3)
+--R 
+--R
+--R          2
+--R        4x  + x + 1
+--R   (1)  -----------
+--R            3
+--R           x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 171
+
+--S 172 of 953
+r0:=2*log(1-x)+log(1+x+x^2)
+--R 
+--R
+--R             2
+--R   (2)  log(x  + x + 1) + 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R   (3)  log(x  + x + 1) + 2log(x - 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 173
+
+--S 174 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  2log(x - 1) - 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 175
+
+)clear all
+
+--S 176 of 953
+t0:=(-3+x^2)/(-1+x^3)
+--R 
+--R
+--R         2
+--R        x  - 3
+--R   (1)  ------
+--R         3
+--R        x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 176
+
+--S 177 of 953
+r0:=-2/3*log(1-x)+5/6*log(1+x+x^2)+atan((1+2*x)/sqrt(3))*sqrt(3)
+--R 
+--R
+--R                                                              +-+
+--R              2                              +-+     (2x + 1)\|3
+--R        5log(x  + x + 1) - 4log(- x + 1) + 6\|3 atan(------------)
+--R                                                           3
+--R   (2)  ----------------------------------------------------------
+--R                                     6
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                     +-+
+--R              2                            +-+      \|3
+--R        5log(x  + x + 1) - 4log(x - 1) - 6\|3 atan(------)
+--R                                                   2x + 1
+--R   (3)  --------------------------------------------------
+--R                                 6
+--R                                         Type: Union(Expression(Integer),...)
+--E 178
+
+--S 179 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +-+                +-+
+--R                                     +-+     (2x + 1)\|3       +-+      \|3
+--R   - 2log(x - 1) + 2log(- x + 1) - 3\|3 atan(------------) - 3\|3 atan(------)
+--R                                                   3                   2x + 1
+--R   ---------------------------------------------------------------------------
+--R                                        3
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 953
+t0:=(-1+x)/(1-x+x^2)
+--R 
+--R
+--R           x - 1
+--R   (1)  ----------
+--R         2
+--R        x  - x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 181
+
+--S 182 of 953
+r0:=1/2*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                             +-+
+--R         +-+     2                  (2x - 1)\|3
+--R        \|3 log(x  - x + 1) - 2atan(------------)
+--R                                          3
+--R   (2)  -----------------------------------------
+--R                            +-+
+--R                          2\|3
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                             +-+
+--R         +-+     2                  (2x - 1)\|3
+--R        \|3 log(x  - x + 1) - 2atan(------------)
+--R                                          3
+--R   (3)  -----------------------------------------
+--R                            +-+
+--R                          2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 183
+
+--S 184 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 185
+
+)clear all
+
+--S 186 of 953
+t0:=(-1+x^2)/(1+x^3)
+--R 
+--R
+--R           x - 1
+--R   (1)  ----------
+--R         2
+--R        x  - x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 186
+
+--S 187 of 953
+r0:=1/2*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                             +-+
+--R         +-+     2                  (2x - 1)\|3
+--R        \|3 log(x  - x + 1) - 2atan(------------)
+--R                                          3
+--R   (2)  -----------------------------------------
+--R                            +-+
+--R                          2\|3
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                             +-+
+--R         +-+     2                  (2x - 1)\|3
+--R        \|3 log(x  - x + 1) - 2atan(------------)
+--R                                          3
+--R   (3)  -----------------------------------------
+--R                            +-+
+--R                          2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 188
+
+--S 189 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 190
+
+)clear all
+
+--S 191 of 953
+t0:=(-4+3*x)/(4-2*x+x^2)
+--R 
+--R
+--R           3x - 4
+--R   (1)  -----------
+--R         2
+--R        x  - 2x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 191
+
+--S 192 of 953
+r0:=3/2*log(4-2*x+x^2)+atan((1-x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                              +-+
+--R          +-+     2                   (x - 1)\|3
+--R        3\|3 log(x  - 2x + 4) - 2atan(-----------)
+--R                                           3
+--R   (2)  ------------------------------------------
+--R                             +-+
+--R                           2\|3
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                              +-+
+--R          +-+     2                   (x - 1)\|3
+--R        3\|3 log(x  - 2x + 4) - 2atan(-----------)
+--R                                           3
+--R   (3)  ------------------------------------------
+--R                             +-+
+--R                           2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 193
+
+--S 194 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 953
+t0:=(-8+2*x+3*x^2)/(8+x^3)
+--R 
+--R
+--R           3x - 4
+--R   (1)  -----------
+--R         2
+--R        x  - 2x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 196
+
+--S 197 of 953
+r0:=3/2*log(4-2*x+x^2)+atan((1-x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                              +-+
+--R          +-+     2                   (x - 1)\|3
+--R        3\|3 log(x  - 2x + 4) - 2atan(-----------)
+--R                                           3
+--R   (2)  ------------------------------------------
+--R                             +-+
+--R                           2\|3
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                              +-+
+--R          +-+     2                   (x - 1)\|3
+--R        3\|3 log(x  - 2x + 4) - 2atan(-----------)
+--R                                           3
+--R   (3)  ------------------------------------------
+--R                             +-+
+--R                           2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 198
+
+--S 199 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 200
+
+)clear all
+
+--S 201 of 953
+t0:=(a+a*x+c*x^2)/(1-x^3)
+--R 
+--R
+--R             2
+--R        - c x  - a x - a
+--R   (1)  ----------------
+--R              3
+--R             x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 201
+
+--S 202 of 953
+r0:=-1/3*(2*a+c)*log(1-x)+1/3*(a-c)*log(1+x+x^2)
+--R 
+--R
+--R                      2
+--R        (- c + a)log(x  + x + 1) + (- c - 2a)log(- x + 1)
+--R   (2)  -------------------------------------------------
+--R                                3
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      2
+--R        (- c + a)log(x  + x + 1) + (- c - 2a)log(x - 1)
+--R   (3)  -----------------------------------------------
+--R                               3
+--R                                         Type: Union(Expression(Integer),...)
+--E 203
+
+--S 204 of 953
+m0:=a0-r0
+--R 
+--R
+--R        (- c - 2a)log(x - 1) + (c + 2a)log(- x + 1)
+--R   (4)  -------------------------------------------
+--R                             3
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 205
+
+)clear all
+
+--S 206 of 953
+t0:=(a+b*x+c*x^2)/(1-x^3)
+--R 
+--R
+--R             2
+--R        - c x  - b x - a
+--R   (1)  ----------------
+--R              3
+--R             x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 206
+
+--S 207 of 953
+r0:=-1/3*(a+b+c)*log(1-x)+1/6*(a+b-2*c)*log(1+x+x^2)+_
+   (a-b)*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                      +-+     2                             +-+
+--R       (- 2c + b + a)\|3 log(x  + x + 1) + (- 2c - 2b - 2a)\|3 log(- x + 1)
+--R     + 
+--R                                +-+
+--R                       (2x + 1)\|3
+--R       (- 6b + 6a)atan(------------)
+--R                             3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 207
+
+--S 208 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +-+     2                             +-+
+--R       (- 2c + b + a)\|3 log(x  + x + 1) + (- 2c - 2b - 2a)\|3 log(x - 1)
+--R     + 
+--R                                +-+
+--R                       (2x + 1)\|3
+--R       (- 6b + 6a)atan(------------)
+--R                             3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 208
+
+--S 209 of 953
+m0:=a0-r0
+--R 
+--R
+--R        (- c - b - a)log(x - 1) + (c + b + a)log(- x + 1)
+--R   (4)  -------------------------------------------------
+--R                                3
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 953
+t0:=x*(1+2*x)/(1+x^3)
+--R 
+--R
+--R          2
+--R        2x  + x
+--R   (1)  -------
+--R          3
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 211
+
+--S 212 of 953
+r0:=1/3*log(1+x)+5/6*log(1-x+x^2)-atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                +-+
+--R          +-+     2              +-+                   (2x - 1)\|3
+--R        5\|3 log(x  - x + 1) + 2\|3 log(x + 1) + 6atan(------------)
+--R                                                             3
+--R   (2)  ------------------------------------------------------------
+--R                                      +-+
+--R                                    6\|3
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                                +-+
+--R          +-+     2              +-+                   (2x - 1)\|3
+--R        5\|3 log(x  - x + 1) + 2\|3 log(x + 1) + 6atan(------------)
+--R                                                             3
+--R   (3)  ------------------------------------------------------------
+--R                                      +-+
+--R                                    6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 213
+
+--S 214 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 215
+
+)clear all
+
+--S 216 of 953
+t0:=(2*x^2+x^4)/(1+x^3)
+--R 
+--R
+--R         4     2
+--R        x  + 2x
+--R   (1)  --------
+--R          3
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 216
+
+--S 217 of 953
+r0:=1/2*x^2+log(1+x)+1/2*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                               +-+
+--R         +-+     2              +-+                   (2x - 1)\|3      2 +-+
+--R        \|3 log(x  - x + 1) + 2\|3 log(x + 1) - 2atan(------------) + x \|3
+--R                                                            3
+--R   (2)  --------------------------------------------------------------------
+--R                                          +-+
+--R                                        2\|3
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                               +-+
+--R         +-+     2              +-+                   (2x - 1)\|3      2 +-+
+--R        \|3 log(x  - x + 1) + 2\|3 log(x + 1) - 2atan(------------) + x \|3
+--R                                                            3
+--R   (3)  --------------------------------------------------------------------
+--R                                          +-+
+--R                                        2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 218
+
+--S 219 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 220
+
+)clear all
+
+--S 221 of 953
+t0:=x*(1+2*x)/(-1+x^3)
+--R 
+--R
+--R          2
+--R        2x  + x
+--R   (1)  -------
+--R          3
+--R         x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 221
+
+--S 222 of 953
+r0:=log(1-x)+1/2*log(1+x+x^2)+atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                 +-+
+--R         +-+     2              +-+                     (2x + 1)\|3
+--R        \|3 log(x  + x + 1) + 2\|3 log(- x + 1) + 2atan(------------)
+--R                                                              3
+--R   (2)  -------------------------------------------------------------
+--R                                      +-+
+--R                                    2\|3
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                               +-+
+--R         +-+     2              +-+                   (2x + 1)\|3
+--R        \|3 log(x  + x + 1) + 2\|3 log(x - 1) + 2atan(------------)
+--R                                                            3
+--R   (3)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 223
+
+--S 224 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  log(x - 1) - log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 953
+t0:=(2*x^2+x^4)/(-1+x^3)
+--R 
+--R
+--R         4     2
+--R        x  + 2x
+--R   (1)  --------
+--R          3
+--R         x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 226
+
+--S 227 of 953
+r0:=1/2*x^2+log(1-x)+1/2*log(1+x+x^2)+atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                 +-+
+--R         +-+     2              +-+                     (2x + 1)\|3      2 +-+
+--R        \|3 log(x  + x + 1) + 2\|3 log(- x + 1) + 2atan(------------) + x \|3
+--R                                                              3
+--R   (2)  ----------------------------------------------------------------------
+--R                                           +-+
+--R                                         2\|3
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                               +-+
+--R         +-+     2              +-+                   (2x + 1)\|3      2 +-+
+--R        \|3 log(x  + x + 1) + 2\|3 log(x - 1) + 2atan(------------) + x \|3
+--R                                                            3
+--R   (3)  --------------------------------------------------------------------
+--R                                          +-+
+--R                                        2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 228
+
+--S 229 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  log(x - 1) - log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 230
+
+)clear all
+
+--S 231 of 953
+t0:=(1-x+4*x^3)/(1+x^3)
+--R 
+--R
+--R          3
+--R        4x  - x + 1
+--R   (1)  -----------
+--R            3
+--R           x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 231
+
+--S 232 of 953
+r0:=4*x-2/3*log(1+x)+1/3*log(1-x+x^2)+4*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                +-+
+--R         +-+     2              +-+                    (2x - 1)\|3         +-+
+--R        \|3 log(x  - x + 1) - 2\|3 log(x + 1) - 12atan(------------) + 12x\|3
+--R                                                             3
+--R   (2)  ----------------------------------------------------------------------
+--R                                           +-+
+--R                                         3\|3
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                                +-+
+--R         +-+     2              +-+                    (2x - 1)\|3         +-+
+--R        \|3 log(x  - x + 1) - 2\|3 log(x + 1) - 12atan(------------) + 12x\|3
+--R                                                             3
+--R   (3)  ----------------------------------------------------------------------
+--R                                           +-+
+--R                                         3\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 233
+
+--S 234 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 235
+
+)clear all
+
+--S 236 of 953
+t0:=(c+d*x+e*x^2)*(a+b*x^3)^p
+--R 
+--R
+--R            2               3     p
+--R   (1)  (e x  + d x + c)(b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 953
+--r0:=1/3*e*(a+b*x^3)^(1+p)/(b*(1+p))+c*x*(a+b*x^3)^p*_
+--   hypergeometric(1/3,-p,4/3,-b*x^3/a)/((a+b*x^3)/a)^p+_
+--   1/2*d*x^2*(a+b*x^3)^p*hypergeometric(2/3,-p,5/3,-b*x^3/a)/((a+b*x^3)/a)^p
+--E 237
+
+--S 238 of 953
+--a0:=integrate(t0,x)
+--E 238
+
+--S 239 of 953
+--m0:=a0-r0
+--E 239
+
+--S 240 of 953
+--d0:=D(m0,x)
+--E 240
+
+)clear all
+
+--S 241 of 953
+t0:=(c+d*x+e*x^2)*(a+b*x^3)^4
+--R 
+--R
+--R   (1)
+--R      4   14    4   13    4   12       3   11       3   10       3   9
+--R     b e x   + b d x   + b c x   + 4a b e x   + 4a b d x   + 4a b c x
+--R   + 
+--R       2 2   8     2 2   7     2 2   6     3     5     3     4     3     3
+--R     6a b e x  + 6a b d x  + 6a b c x  + 4a b e x  + 4a b d x  + 4a b c x
+--R   + 
+--R      4   2    4       4
+--R     a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 241
+
+--S 242 of 953
+r0:=a^4*c*x+1/2*a^4*d*x^2+a^3*b*c*x^4+4/5*a^3*b*d*x^5+6/7*a^2*b^2*c*x^7+_
+   3/4*a^2*b^2*d*x^8+2/5*a*b^3*c*x^10+4/11*a*b^3*d*x^11+1/13*b^4*c*x^13+_
+   1/14*b^4*d*x^14+1/15*e*(a+b*x^3)^5/b
+--R 
+--R
+--R   (2)
+--R        1  5   15    1  5   14    1  5   13   1    4   12    4    4   11
+--R       -- b e x   + -- b d x   + -- b c x   + - a b e x   + -- a b d x
+--R       15           14           13           3             11
+--R     + 
+--R       2    4   10   2  2 3   9   3  2 3   8   6  2 3   7   2  3 2   6
+--R       - a b c x   + - a b e x  + - a b d x  + - a b c x  + - a b e x
+--R       5             3            4            7            3
+--R     + 
+--R       4  3 2   5    3 2   4   1  4     3   1  4     2    4         1  5
+--R       - a b d x  + a b c x  + - a b e x  + - a b d x  + a b c x + -- a e
+--R       5                       3            2                      15
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 242
+
+--S 243 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  4   15    1  4   14    1  4   13   1    3   12    4    3   11
+--R     -- b e x   + -- b d x   + -- b c x   + - a b e x   + -- a b d x
+--R     15           14           13           3             11
+--R   + 
+--R     2    3   10   2  2 2   9   3  2 2   8   6  2 2   7   2  3     6
+--R     - a b c x   + - a b e x  + - a b d x  + - a b c x  + - a b e x
+--R     5             3            4            7            3
+--R   + 
+--R     4  3     5    3     4   1  4   3   1  4   2    4
+--R     - a b d x  + a b c x  + - a e x  + - a d x  + a c x
+--R     5                       3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 243
+
+--S 244 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1  5
+--R          -- a e
+--R          15
+--R   (4)  - ------
+--R             b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 244
+
+--S 245 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 245
+
+)clear all
+
+--S 246 of 953
+t0:=(c+d*x+e*x^2)*(a+b*x^3)^3
+--R 
+--R
+--R   (1)
+--R      3   11    3   10    3   9       2   8       2   7       2   6     2     5
+--R     b e x   + b d x   + b c x  + 3a b e x  + 3a b d x  + 3a b c x  + 3a b e x
+--R   + 
+--R       2     4     2     3    3   2    3       3
+--R     3a b d x  + 3a b c x  + a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 246
+
+--S 247 of 953
+r0:=a^3*c*x+1/2*a^3*d*x^2+3/4*a^2*b*c*x^4+3/5*a^2*b*d*x^5+3/7*a*b^2*c*x^7+_
+   3/8*a*b^2*d*x^8+1/10*b^3*c*x^10+1/11*b^3*d*x^11+1/12*e*(a+b*x^3)^4/b
+--R 
+--R
+--R   (2)
+--R        1  4   12    1  4   11    1  4   10   1    3   9   3    3   8
+--R       -- b e x   + -- b d x   + -- b c x   + - a b e x  + - a b d x
+--R       12           11           10           3            8
+--R     + 
+--R       3    3   7   1  2 2   6   3  2 2   5   3  2 2   4   1  3     3
+--R       - a b c x  + - a b e x  + - a b d x  + - a b c x  + - a b e x
+--R       7            2            5            4            3
+--R     + 
+--R       1  3     2    3         1  4
+--R       - a b d x  + a b c x + -- a e
+--R       2                      12
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 247
+
+--S 248 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3   12    1  3   11    1  3   10   1    2   9   3    2   8   3    2   7
+--R     -- b e x   + -- b d x   + -- b c x   + - a b e x  + - a b d x  + - a b c x
+--R     12           11           10           3            8            7
+--R   + 
+--R     1  2     6   3  2     5   3  2     4   1  3   3   1  3   2    3
+--R     - a b e x  + - a b d x  + - a b c x  + - a e x  + - a d x  + a c x
+--R     2            5            4            3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 248
+
+--S 249 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1  4
+--R          -- a e
+--R          12
+--R   (4)  - ------
+--R             b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 249
+
+--S 250 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 250
+
+)clear all
+
+--S 251 of 953
+t0:=(c+d*x+e*x^2)*(a+b*x^3)^2
+--R 
+--R
+--R   (1)
+--R      2   8    2   7    2   6           5           4           3    2   2
+--R     b e x  + b d x  + b c x  + 2a b e x  + 2a b d x  + 2a b c x  + a e x
+--R   + 
+--R      2       2
+--R     a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 251
+
+--S 252 of 953
+r0:=a^2*c*x+1/2*a^2*d*x^2+1/2*a*b*c*x^4+2/5*a*b*d*x^5+1/7*b^2*c*x^7+_
+   1/8*b^2*d*x^8+1/9*e*(a+b*x^3)^3/b
+--R 
+--R
+--R   (2)
+--R       1  3   9   1  3   8   1  3   7   1    2   6   2    2   5   1    2   4
+--R       - b e x  + - b d x  + - b c x  + - a b e x  + - a b d x  + - a b c x
+--R       9          8          7          3            5            2
+--R     + 
+--R       1  2     3   1  2     2    2        1  3
+--R       - a b e x  + - a b d x  + a b c x + - a e
+--R       3            2                      9
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 252
+
+--S 253 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1  2   9   1  2   8   1  2   7   1        6   2        5   1        4
+--R     - b e x  + - b d x  + - b c x  + - a b e x  + - a b d x  + - a b c x
+--R     9          8          7          3            5            2
+--R   + 
+--R     1  2   3   1  2   2    2
+--R     - a e x  + - a d x  + a c x
+--R     3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 253
+
+--S 254 of 953
+m0:=a0-r0
+--R 
+--R
+--R          1  3
+--R          - a e
+--R          9
+--R   (4)  - -----
+--R            b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 254
+
+--S 255 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 255
+
+)clear all
+
+--S 256 of 953
+t0:=(c+d*x+e*x^2)*(a+b*x^3)
+--R 
+--R
+--R             5        4        3        2
+--R   (1)  b e x  + b d x  + b c x  + a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 256
+
+--S 257 of 953
+r0:=a*c*x+1/2*a*d*x^2+1/3*a*e*x^3+1/4*b*c*x^4+1/5*b*d*x^5+1/6*b*e*x^6
+--R 
+--R
+--R        1      6   1      5   1      4   1      3   1      2
+--R   (2)  - b e x  + - b d x  + - b c x  + - a e x  + - a d x  + a c x
+--R        6          5          4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 257
+
+--S 258 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1      6   1      5   1      4   1      3   1      2
+--R   (3)  - b e x  + - b d x  + - b c x  + - a e x  + - a d x  + a c x
+--R        6          5          4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 258
+
+--S 259 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 259
+
+--S 260 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 260
+
+)clear all
+
+--S 261 of 953
+t0:=(c+d*x+e*x^2)/(a+b*x^3)
+--R 
+--R
+--R           2
+--R        e x  + d x + c
+--R   (1)  --------------
+--R              3
+--R           b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 261
+
+--S 262 of 953
+r0:=1/3*(b^(1/3)*c-a^(1/3)*d)*log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*b^(2/3))-_
+   1/6*(c-a^(1/3)*d/b^(1/3))*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(2/3)*b^(1/3))+1/3*e*log(a+b*x^3)/b-(b^(1/3)*c+a^(1/3)*d)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              +-+3+-+       +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b c\|3 \|b  + b d\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             +-+3+-+        +-+3+-+      3+-+   3+-+
+--R       (2b c\|3 \|b  - 2b d\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                   3+-+   3+-+
+--R            3+-+       3+-+      2x\|b  - \|a        +-+       3     3+-+2 3+-+2
+--R       (6b c\|b  + 6b d\|a )atan(-------------) + 2e\|3 log(b x  + a)\|a   \|b
+--R                                     +-+3+-+
+--R                                    \|3 \|a
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6b\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +--------------------------------------------+
+--R              |      2     2                     2
+--R              |- 9a b %%BL0  + 6a b e %%BL0 - a e  - 4b c d
+--R         (- b |--------------------------------------------  - b %%BL0 + e)
+--R              |                        2
+--R             \|                    3a b
+--R      *
+--R         log
+--R                   2 2            2            2 2
+--R                (9a b d %%BL0 - 3a b d e - 3a b c )
+--R             *
+--R                 +--------------------------------------------+
+--R                 |      2     2                     2
+--R                 |- 9a b %%BL0  + 6a b e %%BL0 - a e  - 4b c d
+--R                 |--------------------------------------------
+--R                 |                        2
+--R                \|                    3a b
+--R            + 
+--R                  2 2       2      2            2 2                3     2 3
+--R              - 9a b d %%BL0  + (6a b d e - 3a b c )%%BL0 + (2a b d  + 2b c )x
+--R            + 
+--R                 2   2        2            2
+--R              - a d e  + a b c e - 2a b c d
+--R     + 
+--R            +--------------------------------------------+
+--R            |      2     2                     2
+--R            |- 9a b %%BL0  + 6a b e %%BL0 - a e  - 4b c d
+--R         (b |--------------------------------------------  - b %%BL0 + e)
+--R            |                        2
+--R           \|                    3a b
+--R      *
+--R         log
+--R                     2 2            2            2 2
+--R                (- 9a b d %%BL0 + 3a b d e + 3a b c )
+--R             *
+--R                 +--------------------------------------------+
+--R                 |      2     2                     2
+--R                 |- 9a b %%BL0  + 6a b e %%BL0 - a e  - 4b c d
+--R                 |--------------------------------------------
+--R                 |                        2
+--R                \|                    3a b
+--R            + 
+--R                  2 2       2      2            2 2                3     2 3
+--R              - 9a b d %%BL0  + (6a b d e - 3a b c )%%BL0 + (2a b d  + 2b c )x
+--R            + 
+--R                 2   2        2            2
+--R              - a d e  + a b c e - 2a b c d
+--R     + 
+--R         2b %%BL0
+--R      *
+--R         log
+--R                2 2       2        2            2 2               3    2 3
+--R              9a b d %%BL0  + (- 6a b d e + 3a b c )%%BL0 + (a b d  + b c )x
+--R            + 
+--R               2   2        2            2
+--R              a d e  - a b c e + 2a b c d
+--R  /
+--R     2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 263
+
+--S 264 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +--------------------------------------------+
+--R                               |      2     2                     2
+--R                +-+3+-+2 3+-+2 |- 9a b %%BL0  + 6a b e %%BL0 - a e  - 4b c d
+--R           - 3b\|3 \|a   \|b   |--------------------------------------------
+--R                               |                        2
+--R                              \|                    3a b
+--R         + 
+--R                +-+3+-+2 3+-+2          +-+3+-+2 3+-+2
+--R           - 3b\|3 \|a   \|b  %%BL + 3e\|3 \|a   \|b
+--R      *
+--R         log
+--R                   2 2            2            2 2
+--R                (9a b d %%BL0 - 3a b d e - 3a b c )
+--R             *
+--R                 +--------------------------------------------+
+--R                 |      2     2                     2
+--R                 |- 9a b %%BL0  + 6a b e %%BL0 - a e  - 4b c d
+--R                 |--------------------------------------------
+--R                 |                        2
+--R                \|                    3a b
+--R            + 
+--R                  2 2       2      2            2 2                3     2 3
+--R              - 9a b d %%BL0  + (6a b d e - 3a b c )%%BL0 + (2a b d  + 2b c )x
+--R            + 
+--R                 2   2        2            2
+--R              - a d e  + a b c e - 2a b c d
+--R     + 
+--R                             +--------------------------------------------+
+--R                             |      2     2                     2
+--R              +-+3+-+2 3+-+2 |- 9a b %%BL0  + 6a b e %%BL0 - a e  - 4b c d
+--R           3b\|3 \|a   \|b   |--------------------------------------------
+--R                             |                        2
+--R                            \|                    3a b
+--R         + 
+--R                +-+3+-+2 3+-+2          +-+3+-+2 3+-+2
+--R           - 3b\|3 \|a   \|b  %%BL + 3e\|3 \|a   \|b
+--R      *
+--R         log
+--R                     2 2            2            2 2
+--R                (- 9a b d %%BL0 + 3a b d e + 3a b c )
+--R             *
+--R                 +--------------------------------------------+
+--R                 |      2     2                     2
+--R                 |- 9a b %%BL0  + 6a b e %%BL0 - a e  - 4b c d
+--R                 |--------------------------------------------
+--R                 |                        2
+--R                \|                    3a b
+--R            + 
+--R                  2 2       2      2            2 2                3     2 3
+--R              - 9a b d %%BL0  + (6a b d e - 3a b c )%%BL0 + (2a b d  + 2b c )x
+--R            + 
+--R                 2   2        2            2
+--R              - a d e  + a b c e - 2a b c d
+--R     + 
+--R            +-+3+-+2 3+-+2
+--R         6b\|3 \|a   \|b  %%BL0
+--R      *
+--R         log
+--R                2 2       2        2            2 2               3    2 3
+--R              9a b d %%BL0  + (- 6a b d e + 3a b c )%%BL0 + (a b d  + b c )x
+--R            + 
+--R               2   2        2            2
+--R              a d e  - a b c e + 2a b c d
+--R     + 
+--R            +-+3+-+       +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (b c\|3 \|b  - b d\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               +-+3+-+        +-+3+-+      3+-+   3+-+
+--R       (- 2b c\|3 \|b  + 2b d\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                   3+-+   3+-+
+--R            3+-+       3+-+      2x\|b  - \|a        +-+       3     3+-+2 3+-+2
+--R     (- 6b c\|b  - 6b d\|a )atan(-------------) - 2e\|3 log(b x  + a)\|a   \|b
+--R                                     +-+3+-+
+--R                                    \|3 \|a
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6b\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 265
+
+)clear all
+
+--S 266 of 953
+t0:=(c+d*x+e*x^2)/(a+b*x^3)^2
+--R 
+--R
+--R              2
+--R           e x  + d x + c
+--R   (1)  -------------------
+--R         2 6         3    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 266
+
+--S 267 of 953
+r0:=-1/3*e/(b*(a+b*x^3))+1/3*x*(c+d*x)/(a*(a+b*x^3))+1/9*(2*b^(1/3)*c-_
+   a^(1/3)*d)*log(a^(1/3)+b^(1/3)*x)/(a^(5/3)*b^(2/3))-1/18*(2*b^(1/3)*c-_
+   a^(1/3)*d)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(5/3)*b^(2/3))-_
+   1/3*(2*b^(1/3)*c+a^(1/3)*d)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(5/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R               2   3           +-+3+-+     2   3          +-+3+-+
+--R         ((- 2b c x  - 2a b c)\|3 \|b  + (b d x  + a b d)\|3 \|a )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             2   3           +-+3+-+        2   3           +-+3+-+
+--R         ((4b c x  + 4a b c)\|3 \|b  + (- 2b d x  - 2a b d)\|3 \|a )
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                                                                 3+-+   3+-+
+--R            2   3           3+-+      2   3          3+-+      2x\|b  - \|a
+--R       ((12b c x  + 12a b c)\|b  + (6b d x  + 6a b d)\|a )atan(-------------)
+--R                                                                   +-+3+-+
+--R                                                                  \|3 \|a
+--R     + 
+--R              2                  +-+3+-+2 3+-+2
+--R       (6b d x  + 6b c x - 6a e)\|3 \|a   \|b
+--R  /
+--R           2 3      2   +-+3+-+2 3+-+2
+--R     (18a b x  + 18a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                             +---------------------+
+--R                             |     3       2
+--R                 2 3     2   |- 81a b %%BM0  - 8c d           2 3     2
+--R         ((- 3a b x  - 3a b) |---------------------  + (- 3a b x  - 3a b)%%BM0)
+--R                             |           3
+--R                            \|        27a b
+--R      *
+--R         log
+--R                                         +---------------------+
+--R                                         |     3       2
+--R                  4               2   2  |- 81a b %%BM0  - 8c d
+--R              (81a b d %%BM0 - 36a b c ) |---------------------
+--R                                         |           3
+--R                                        \|        27a b
+--R            + 
+--R                   4         2      2   2             3        3           2
+--R              - 81a b d %%BM0  - 36a b c %%BM0 + (2a d  + 16b c )x - 4a c d
+--R     + 
+--R                           +---------------------+
+--R                           |     3       2
+--R               2 3     2   |- 81a b %%BM0  - 8c d           2 3     2
+--R         ((3a b x  + 3a b) |---------------------  + (- 3a b x  - 3a b)%%BM0)
+--R                           |           3
+--R                          \|        27a b
+--R      *
+--R         log
+--R                                           +---------------------+
+--R                                           |     3       2
+--R                    4               2   2  |- 81a b %%BM0  - 8c d
+--R              (- 81a b d %%BM0 + 36a b c ) |---------------------
+--R                                           |           3
+--R                                          \|        27a b
+--R            + 
+--R                   4         2      2   2             3        3           2
+--R              - 81a b d %%BM0  - 36a b c %%BM0 + (2a d  + 16b c )x - 4a c d
+--R     + 
+--R              2 3     2
+--R         (6a b x  + 6a b)%%BM0
+--R      *
+--R                4         2      2   2            3       3           2
+--R         log(81a b d %%BM0  + 36a b c %%BM0 + (a d  + 8b c )x + 4a c d )
+--R     + 
+--R             2
+--R       2b d x  + 2b c x - 2a e
+--R  /
+--R         2 3     2
+--R     6a b x  + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 268
+
+--S 269 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              +---------------------+
+--R                              |     3       2
+--R               +-+3+-+2 3+-+2 |- 81a b %%BM0  - 8c d      +-+3+-+2 3+-+2
+--R         (- 9a\|3 \|a   \|b   |--------------------- - 9a\|3 \|a   \|b  %%BM)
+--R                              |           3
+--R                             \|        27a b
+--R      *
+--R         log
+--R                                         +---------------------+
+--R                                         |     3       2
+--R                  4               2   2  |- 81a b %%BM0  - 8c d
+--R              (81a b d %%BM0 - 36a b c ) |---------------------
+--R                                         |           3
+--R                                        \|        27a b
+--R            + 
+--R                   4         2      2   2             3        3           2
+--R              - 81a b d %%BM0  - 36a b c %%BM0 + (2a d  + 16b c )x - 4a c d
+--R     + 
+--R                            +---------------------+
+--R                            |     3       2
+--R             +-+3+-+2 3+-+2 |- 81a b %%BM0  - 8c d      +-+3+-+2 3+-+2
+--R         (9a\|3 \|a   \|b   |--------------------- - 9a\|3 \|a   \|b  %%BM)
+--R                            |           3
+--R                           \|        27a b
+--R      *
+--R         log
+--R                                           +---------------------+
+--R                                           |     3       2
+--R                    4               2   2  |- 81a b %%BM0  - 8c d
+--R              (- 81a b d %%BM0 + 36a b c ) |---------------------
+--R                                           |           3
+--R                                          \|        27a b
+--R            + 
+--R                   4         2      2   2             3        3           2
+--R              - 81a b d %%BM0  - 36a b c %%BM0 + (2a d  + 16b c )x - 4a c d
+--R     + 
+--R             +-+3+-+2 3+-+2
+--R         18a\|3 \|a   \|b  %%BM0
+--R      *
+--R                4         2      2   2            3       3           2
+--R         log(81a b d %%BM0  + 36a b c %%BM0 + (a d  + 8b c )x + 4a c d )
+--R     + 
+--R           +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (2c\|3 \|b  - d\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (- 4c\|3 \|b  + 2d\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                  3+-+   3+-+
+--R             3+-+     3+-+      2x\|b  - \|a
+--R       (- 12c\|b  - 6d\|a )atan(-------------)
+--R                                    +-+3+-+
+--R                                   \|3 \|a
+--R  /
+--R         +-+3+-+2 3+-+2
+--R     18a\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 953
+t0:=(c+d*x+e*x^2)/(a+b*x^3)^3
+--R 
+--R
+--R                   2
+--R                e x  + d x + c
+--R   (1)  -----------------------------
+--R         3 9       2 6     2   3    3
+--R        b x  + 3a b x  + 3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 271
+
+--S 272 of 953
+r0:=-1/6*e/(b*(a+b*x^3)^2)+1/6*x*(c+d*x)/(a*(a+b*x^3)^2)+_
+   1/18*x*(5*c+4*d*x)/(a^2*(a+b*x^3))+1/27*(5*b^(1/3)*c-2*a^(1/3)*d)*_
+   log(a^(1/3)+b^(1/3)*x)/(a^(8/3)*b^(2/3))-1/54*(5*b^(1/3)*c-2*a^(1/3)*d)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(8/3)*b^(2/3))-_
+   1/9*(5*b^(1/3)*c+2*a^(1/3)*d)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(8/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                3   6        2   3     2     +-+3+-+
+--R           (- 5b c x  - 10a b c x  - 5a b c)\|3 \|b
+--R         + 
+--R              3   6       2   3     2     +-+3+-+
+--R           (2b d x  + 4a b d x  + 2a b d)\|3 \|a
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               3   6        2   3      2     +-+3+-+
+--R           (10b c x  + 20a b c x  + 10a b c)\|3 \|b
+--R         + 
+--R                3   6       2   3     2     +-+3+-+
+--R           (- 4b d x  - 8a b d x  - 4a b d)\|3 \|a
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R               3   6        2   3      2    3+-+
+--R           (30b c x  + 60a b c x  + 30a b c)\|b
+--R         + 
+--R               3   6        2   3      2    3+-+
+--R           (12b d x  + 24a b d x  + 12a b d)\|a
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R           2   5      2   4            2                 2   +-+3+-+2 3+-+2
+--R       (12b d x  + 15b c x  + 21a b d x  + 24a b c x - 9a e)\|3 \|a   \|b
+--R  /
+--R         2 3 6       3 2 3      4   +-+3+-+2 3+-+2
+--R     (54a b x  + 108a b x  + 54a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         +-----------------------+
+--R                                         |      5       2
+--R                2 3 6      3 2 3     4   |- 729a b %%BN0  - 40c d
+--R           (- 9a b x  - 18a b x  - 9a b) |-----------------------
+--R                                         |             5
+--R                                        \|         243a b
+--R         + 
+--R                2 3 6      3 2 3     4
+--R           (- 9a b x  - 18a b x  - 9a b)%%BN0
+--R      *
+--R         log
+--R                                            +-----------------------+
+--R                                            |      5       2
+--R                    6                3   2  |- 729a b %%BN0  - 40c d
+--R              (1458a b d %%BN0 - 675a b c ) |-----------------------
+--R                                            |             5
+--R                                           \|         243a b
+--R            + 
+--R                   6         2       3   2              3         3            2
+--R            - 1458a b d %%BN0  - 675a b c %%BN0 + (16a d  + 250b c )x - 40a c d
+--R     + 
+--R                                       +-----------------------+
+--R                                       |      5       2
+--R              2 3 6      3 2 3     4   |- 729a b %%BN0  - 40c d
+--R           (9a b x  + 18a b x  + 9a b) |-----------------------
+--R                                       |             5
+--R                                      \|         243a b
+--R         + 
+--R                2 3 6      3 2 3     4
+--R           (- 9a b x  - 18a b x  - 9a b)%%BN0
+--R      *
+--R         log
+--R                                              +-----------------------+
+--R                                              |      5       2
+--R                      6                3   2  |- 729a b %%BN0  - 40c d
+--R              (- 1458a b d %%BN0 + 675a b c ) |-----------------------
+--R                                              |             5
+--R                                             \|         243a b
+--R            + 
+--R                   6         2       3   2              3         3            2
+--R            - 1458a b d %%BN0  - 675a b c %%BN0 + (16a d  + 250b c )x - 40a c d
+--R     + 
+--R             2 3 6      3 2 3      4
+--R         (18a b x  + 36a b x  + 18a b)%%BN0
+--R      *
+--R                  6         2       3   2             3         3            2
+--R         log(1458a b d %%BN0  + 675a b c %%BN0 + (8a d  + 125b c )x + 40a c d )
+--R     + 
+--R         2   5     2   4           2                2
+--R       4b d x  + 5b c x  + 7a b d x  + 8a b c x - 3a e
+--R  /
+--R        2 3 6      3 2 3      4
+--R     18a b x  + 36a b x  + 18a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 273
+
+--S 274 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 +-----------------------+
+--R                                 |      5       2
+--R                2 +-+3+-+2 3+-+2 |- 729a b %%BN0  - 40c d
+--R           - 27a \|3 \|a   \|b   |-----------------------
+--R                                 |             5
+--R                                \|         243a b
+--R         + 
+--R                2 +-+3+-+2 3+-+2
+--R           - 27a \|3 \|a   \|b  %%BN0
+--R      *
+--R         log
+--R                                            +-----------------------+
+--R                                            |      5       2
+--R                    6                3   2  |- 729a b %%BN0  - 40c d
+--R              (1458a b d %%BN0 - 675a b c ) |-----------------------
+--R                                            |             5
+--R                                           \|         243a b
+--R            + 
+--R                   6         2       3   2              3         3            2
+--R            - 1458a b d %%BN0  - 675a b c %%BN0 + (16a d  + 250b c )x - 40a c d
+--R     + 
+--R                                 +-----------------------+
+--R                                 |      5       2
+--R                2 +-+3+-+2 3+-+2 |- 729a b %%BN0  - 40c d
+--R             27a \|3 \|a   \|b   |-----------------------
+--R                                 |             5
+--R                                \|         243a b
+--R           + 
+--R                  2 +-+3+-+2 3+-+2
+--R             - 27a \|3 \|a   \|b  %%BN0
+--R      *
+--R         log
+--R                                              +-----------------------+
+--R                                              |      5       2
+--R                      6                3   2  |- 729a b %%BN0  - 40c d
+--R              (- 1458a b d %%BN0 + 675a b c ) |-----------------------
+--R                                              |             5
+--R                                             \|         243a b
+--R            + 
+--R                   6         2       3   2              3         3            2
+--R            - 1458a b d %%BN0  - 675a b c %%BN0 + (16a d  + 250b c )x - 40a c d
+--R     + 
+--R            2 +-+3+-+2 3+-+2
+--R         54a \|3 \|a   \|b  %%BN0
+--R      *
+--R                  6         2       3   2             3         3            2
+--R         log(1458a b d %%BN0  + 675a b c %%BN0 + (8a d  + 125b c )x + 40a c d )
+--R     + 
+--R           +-+3+-+      +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (5c\|3 \|b  - 2d\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (- 10c\|3 \|b  + 4d\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                   3+-+   3+-+
+--R             3+-+      3+-+      2x\|b  - \|a
+--R       (- 30c\|b  - 12d\|a )atan(-------------)
+--R                                     +-+3+-+
+--R                                    \|3 \|a
+--R  /
+--R        2 +-+3+-+2 3+-+2
+--R     54a \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 275
+
+)clear all
+
+--S 276 of 953
+t0:=(c+d*x+e*x^2)/(a+b*x^3)^4
+--R 
+--R
+--R                        2
+--R                     e x  + d x + c
+--R   (1)  ----------------------------------------
+--R         4 12       3 9     2 2 6     3   3    4
+--R        b x   + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 276
+
+--S 277 of 953
+r0:=-1/9*e/(b*(a+b*x^3)^3)+1/9*x*(c+d*x)/(a*(a+b*x^3)^3)+1/54*x*_
+   (8*c+7*d*x)/(a^2*(a+b*x^3)^2)+2/81*x*(10*c+7*d*x)/(a^3*(a+b*x^3))+_
+   2/243*(20*b^(1/3)*c-7*a^(1/3)*d)*log(a^(1/3)+b^(1/3)*x)/(a^(11/3)*_
+   b^(2/3))-1/243*(20*b^(1/3)*c-7*a^(1/3)*d)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+_
+   b^(2/3)*x^2)/(a^(11/3)*b^(2/3))-2/81*(20*b^(1/3)*c+7*a^(1/3)*d)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(11/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                 4   9         3   6       2 2   3      3     +-+3+-+
+--R           (- 40b c x  - 120a b c x  - 120a b c x  - 40a b c)\|3 \|b
+--R         + 
+--R               4   9        3   6      2 2   3      3     +-+3+-+
+--R           (14b d x  + 42a b d x  + 42a b d x  + 14a b d)\|3 \|a
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               4   9         3   6       2 2   3      3     +-+3+-+
+--R           (80b c x  + 240a b c x  + 240a b c x  + 80a b c)\|3 \|b
+--R         + 
+--R                 4   9        3   6      2 2   3      3     +-+3+-+
+--R           (- 28b d x  - 84a b d x  - 84a b d x  - 28a b d)\|3 \|a
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                4   9         3   6       2 2   3       3    3+-+
+--R           (240b c x  + 720a b c x  + 720a b c x  + 240a b c)\|b
+--R         + 
+--R               4   9         3   6       2 2   3      3    3+-+
+--R           (84b d x  + 252a b d x  + 252a b d x  + 84a b d)\|a
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R              3   8       3   7         2   5         2   4       2     2
+--R           84b d x  + 120b c x  + 231a b d x  + 312a b c x  + 201a b d x
+--R         + 
+--R               2           3
+--R           246a b c x - 54a e
+--R      *
+--R          +-+3+-+2 3+-+2
+--R         \|3 \|a   \|b
+--R  /
+--R          3 4 9        4 3 6        5 2 3       6   +-+3+-+2 3+-+2
+--R     (486a b x  + 1458a b x  + 1458a b x  + 486a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   3 4 9       4 3 6       5 2 3      6
+--R             (- 81a b x  - 243a b x  - 243a b x  - 81a b)
+--R          *
+--R              +---------------------------+
+--R              |        7       2
+--R              |- 59049a b %%BO0  - 2240c d
+--R              |---------------------------
+--R              |                7
+--R             \|          19683a b
+--R         + 
+--R                 3 4 9       4 3 6       5 2 3      6
+--R           (- 81a b x  - 243a b x  - 243a b x  - 81a b)%%BO0
+--R      *
+--R         log
+--R                                                 +---------------------------+
+--R                                                 |        7       2
+--R                      8                   4   2  |- 59049a b %%BO0  - 2240c d
+--R              (413343a b d %%BO0 - 194400a b c ) |---------------------------
+--R                                                 |                7
+--R                                                \|          19683a b
+--R            + 
+--R                       8         2          4   2                3           3
+--R              - 413343a b d %%BO0  - 194400a b c %%BO0 + (2744a d  + 64000b c )x
+--R            + 
+--R                         2
+--R              - 7840a c d
+--R     + 
+--R                 3 4 9       4 3 6       5 2 3      6
+--R             (81a b x  + 243a b x  + 243a b x  + 81a b)
+--R          *
+--R              +---------------------------+
+--R              |        7       2
+--R              |- 59049a b %%BO0  - 2240c d
+--R              |---------------------------
+--R              |                7
+--R             \|          19683a b
+--R         + 
+--R                 3 4 9       4 3 6       5 2 3      6
+--R           (- 81a b x  - 243a b x  - 243a b x  - 81a b)%%BO0
+--R      *
+--R         log
+--R                                                   +---------------------------+
+--R                                                   |        7       2
+--R                        8                   4   2  |- 59049a b %%BO0  - 2240c d
+--R              (- 413343a b d %%BO0 + 194400a b c ) |---------------------------
+--R                                                   |                7
+--R                                                  \|          19683a b
+--R            + 
+--R                       8         2          4   2                3           3
+--R              - 413343a b d %%BO0  - 194400a b c %%BO0 + (2744a d  + 64000b c )x
+--R            + 
+--R                         2
+--R              - 7840a c d
+--R     + 
+--R              3 4 9       4 3 6       5 2 3       6
+--R         (162a b x  + 486a b x  + 486a b x  + 162a b)%%BO0
+--R      *
+--R         log
+--R                     8         2          4   2                3           3
+--R              413343a b d %%BO0  + 194400a b c %%BO0 + (1372a d  + 32000b c )x
+--R            + 
+--R                       2
+--R              7840a c d
+--R     + 
+--R          3   8      3   7        2   5         2   4      2     2      2
+--R       28b d x  + 40b c x  + 77a b d x  + 104a b c x  + 67a b d x  + 82a b c x
+--R     + 
+--R            3
+--R       - 18a e
+--R  /
+--R         3 4 9       4 3 6       5 2 3       6
+--R     162a b x  + 486a b x  + 486a b x  + 162a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 278
+
+--S 279 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  +---------------------------+
+--R                                  |        7       2
+--R                 3 +-+3+-+2 3+-+2 |- 59049a b %%BO0  - 2240c d
+--R           - 243a \|3 \|a   \|b   |---------------------------
+--R                                  |                7
+--R                                 \|          19683a b
+--R         + 
+--R                 3 +-+3+-+2 3+-+2
+--R           - 243a \|3 \|a   \|b  %%BO0
+--R      *
+--R         log
+--R                                                 +---------------------------+
+--R                                                 |        7       2
+--R                      8                   4   2  |- 59049a b %%BO0  - 2240c d
+--R              (413343a b d %%BO0 - 194400a b c ) |---------------------------
+--R                                                 |                7
+--R                                                \|          19683a b
+--R            + 
+--R                       8         2          4   2                3           3
+--R              - 413343a b d %%BO0  - 194400a b c %%BO0 + (2744a d  + 64000b c )x
+--R            + 
+--R                         2
+--R              - 7840a c d
+--R     + 
+--R                                +---------------------------+
+--R                                |        7       2
+--R               3 +-+3+-+2 3+-+2 |- 59049a b %%BO0  - 2240c d
+--R           243a \|3 \|a   \|b   |---------------------------
+--R                                |                7
+--R                               \|          19683a b
+--R         + 
+--R                 3 +-+3+-+2 3+-+2
+--R           - 243a \|3 \|a   \|b  %%BO0
+--R      *
+--R         log
+--R                                                   +---------------------------+
+--R                                                   |        7       2
+--R                        8                   4   2  |- 59049a b %%BO0  - 2240c d
+--R              (- 413343a b d %%BO0 + 194400a b c ) |---------------------------
+--R                                                   |                7
+--R                                                  \|          19683a b
+--R            + 
+--R                       8         2          4   2                3           3
+--R              - 413343a b d %%BO0  - 194400a b c %%BO0 + (2744a d  + 64000b c )x
+--R            + 
+--R                         2
+--R              - 7840a c d
+--R     + 
+--R             3 +-+3+-+2 3+-+2
+--R         486a \|3 \|a   \|b  %%BO0
+--R      *
+--R         log
+--R                     8         2          4   2                3           3
+--R              413343a b d %%BO0  + 194400a b c %%BO0 + (1372a d  + 32000b c )x
+--R            + 
+--R                       2
+--R              7840a c d
+--R     + 
+--R            +-+3+-+       +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (40c\|3 \|b  - 14d\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              +-+3+-+       +-+3+-+      3+-+   3+-+
+--R       (- 80c\|3 \|b  + 28d\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                    3+-+   3+-+
+--R              3+-+      3+-+      2x\|b  - \|a
+--R       (- 240c\|b  - 84d\|a )atan(-------------)
+--R                                      +-+3+-+
+--R                                     \|3 \|a
+--R  /
+--R         3 +-+3+-+2 3+-+2
+--R     486a \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 953
+t0:=x^2*(c+d*x+e*x^2)*(a+b*x^3)^p
+--R 
+--R
+--R            4      3      2     3     p
+--R   (1)  (e x  + d x  + c x )(b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 953
+--r0:=1/3*c*(a+b*x^3)^(1+p)/(b*(1+p))+d*x*(a+b*x^3)^(1+p)/(b*(4+3*p))+_
+--   e*x^2*(a+b*x^3)^(1+p)/(b*(5+3*p))-a*d*x*(a+b*x^3)^p*_
+--   hypergeometric(1/3,-p,4/3,-b*x^3/a)/(b*(4+3*p)*((a+b*x^3)/a)^p)-_
+--   a*e*x^2*(a+b*x^3)^p*hypergeometric(2/3,-p,5/3,-b*x^3/a)/(b*(5+3*p)*_
+--   ((a+b*x^3)/a)^p)
+--E 282
+
+--S 283 of 953
+--a0:=integrate(t0,x)
+--E 283
+
+--S 284 of 953
+--m0:=a0-r0
+--E 284
+
+--S 285 of 953
+--d0:=D(m0,x)
+--E 285
+
+)clear all
+
+--S 286 of 953
+t0:=x^2*(c+d*x+e*x^2)*(a+b*x^3)^4
+--R 
+--R
+--R   (1)
+--R      4   16    4   15    4   14       3   13       3   12       3   11
+--R     b e x   + b d x   + b c x   + 4a b e x   + 4a b d x   + 4a b c x
+--R   + 
+--R       2 2   10     2 2   9     2 2   8     3     7     3     6     3     5
+--R     6a b e x   + 6a b d x  + 6a b c x  + 4a b e x  + 4a b d x  + 4a b c x
+--R   + 
+--R      4   4    4   3    4   2
+--R     a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 286
+
+--S 287 of 953
+r0:=1/4*a^4*d*x^4+1/5*a^4*e*x^5+4/7*a^3*b*d*x^7+1/2*a^3*b*e*x^8+_
+   3/5*a^2*b^2*d*x^10+6/11*a^2*b^2*e*x^11+4/13*a*b^3*d*x^13+_
+   2/7*a*b^3*e*x^14+1/16*b^4*d*x^16+1/17*b^4*e*x^17+1/15*c*(a+b*x^3)^5/b
+--R 
+--R
+--R   (2)
+--R        1  5   17    1  5   16    1  5   15   2    4   14    4    4   13
+--R       -- b e x   + -- b d x   + -- b c x   + - a b e x   + -- a b d x
+--R       17           16           15           7             13
+--R     + 
+--R       1    4   12    6  2 3   11   3  2 3   10   2  2 3   9   1  3 2   8
+--R       - a b c x   + -- a b e x   + - a b d x   + - a b c x  + - a b e x
+--R       3             11             5             3            2
+--R     + 
+--R       4  3 2   7   2  3 2   6   1  4     5   1  4     4   1  4     3    1  5
+--R       - a b d x  + - a b c x  + - a b e x  + - a b d x  + - a b c x  + -- a c
+--R       7            3            5            4            3            15
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 287
+
+--S 288 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  4   17    1  4   16    1  4   15   2    3   14    4    3   13
+--R     -- b e x   + -- b d x   + -- b c x   + - a b e x   + -- a b d x
+--R     17           16           15           7             13
+--R   + 
+--R     1    3   12    6  2 2   11   3  2 2   10   2  2 2   9   1  3     8
+--R     - a b c x   + -- a b e x   + - a b d x   + - a b c x  + - a b e x
+--R     3             11             5             3            2
+--R   + 
+--R     4  3     7   2  3     6   1  4   5   1  4   4   1  4   3
+--R     - a b d x  + - a b c x  + - a e x  + - a d x  + - a c x
+--R     7            3            5          4          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 288
+
+--S 289 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1  5
+--R          -- a c
+--R          15
+--R   (4)  - ------
+--R             b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 289
+
+--S 290 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 290
+
+)clear all
+
+--S 291 of 953
+t0:=x^2*(c+d*x+e*x^2)*(a+b*x^3)^3
+--R 
+--R
+--R   (1)
+--R      3   13    3   12    3   11       2   10       2   9       2   8
+--R     b e x   + b d x   + b c x   + 3a b e x   + 3a b d x  + 3a b c x
+--R   + 
+--R       2     7     2     6     2     5    3   4    3   3    3   2
+--R     3a b e x  + 3a b d x  + 3a b c x  + a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 291
+
+--S 292 of 953
+r0:=1/4*a^3*d*x^4+1/5*a^3*e*x^5+3/7*a^2*b*d*x^7+3/8*a^2*b*e*x^8+_
+   3/10*a*b^2*d*x^10+3/11*a*b^2*e*x^11+1/13*b^3*d*x^13+1/14*b^3*e*x^14+_
+   1/12*c*(a+b*x^3)^4/b
+--R 
+--R
+--R   (2)
+--R        1  4   14    1  4   13    1  4   12    3    3   11    3    3   10
+--R       -- b e x   + -- b d x   + -- b c x   + -- a b e x   + -- a b d x
+--R       14           13           12           11             10
+--R     + 
+--R       1    3   9   3  2 2   8   3  2 2   7   1  2 2   6   1  3     5
+--R       - a b c x  + - a b e x  + - a b d x  + - a b c x  + - a b e x
+--R       3            8            7            2            5
+--R     + 
+--R       1  3     4   1  3     3    1  4
+--R       - a b d x  + - a b c x  + -- a c
+--R       4            3            12
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 292
+
+--S 293 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3   14    1  3   13    1  3   12    3    2   11    3    2   10
+--R     -- b e x   + -- b d x   + -- b c x   + -- a b e x   + -- a b d x
+--R     14           13           12           11             10
+--R   + 
+--R     1    2   9   3  2     8   3  2     7   1  2     6   1  3   5   1  3   4
+--R     - a b c x  + - a b e x  + - a b d x  + - a b c x  + - a e x  + - a d x
+--R     3            8            7            2            5          4
+--R   + 
+--R     1  3   3
+--R     - a c x
+--R     3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 293
+
+--S 294 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1  4
+--R          -- a c
+--R          12
+--R   (4)  - ------
+--R             b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 294
+
+--S 295 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 295
+
+)clear all
+
+--S 296 of 953
+t0:=x^2*(c+d*x+e*x^2)*(a+b*x^3)^2
+--R 
+--R
+--R   (1)
+--R      2   10    2   9    2   8           7           6           5    2   4
+--R     b e x   + b d x  + b c x  + 2a b e x  + 2a b d x  + 2a b c x  + a e x
+--R   + 
+--R      2   3    2   2
+--R     a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 296
+
+--S 297 of 953
+r0:=1/4*a^2*d*x^4+1/5*a^2*e*x^5+2/7*a*b*d*x^7+1/4*a*b*e*x^8+1/10*b^2*d*x^10+_
+   1/11*b^2*e*x^11+1/9*c*(a+b*x^3)^3/b
+--R 
+--R
+--R   (2)
+--R        1  3   11    1  3   10   1  3   9   1    2   8   2    2   7   1    2   6
+--R       -- b e x   + -- b d x   + - b c x  + - a b e x  + - a b d x  + - a b c x
+--R       11           10           9          4            7            3
+--R     + 
+--R       1  2     5   1  2     4   1  2     3   1  3
+--R       - a b e x  + - a b d x  + - a b c x  + - a c
+--R       5            4            3            9
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 297
+
+--S 298 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  2   11    1  2   10   1  2   9   1        8   2        7   1        6
+--R     -- b e x   + -- b d x   + - b c x  + - a b e x  + - a b d x  + - a b c x
+--R     11           10           9          4            7            3
+--R   + 
+--R     1  2   5   1  2   4   1  2   3
+--R     - a e x  + - a d x  + - a c x
+--R     5          4          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 298
+
+--S 299 of 953
+m0:=a0-r0
+--R 
+--R
+--R          1  3
+--R          - a c
+--R          9
+--R   (4)  - -----
+--R            b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 299
+
+--S 300 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 300
+
+)clear all
+
+--S 301 of 953
+t0:=x^2*(c+d*x+e*x^2)*(a+b*x^3)
+--R 
+--R
+--R             7        6        5        4        3        2
+--R   (1)  b e x  + b d x  + b c x  + a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 301
+
+--S 302 of 953
+r0:=1/3*a*c*x^3+1/4*a*d*x^4+1/5*a*e*x^5+1/6*b*c*x^6+1/7*b*d*x^7+1/8*b*e*x^8
+--R 
+--R
+--R        1      8   1      7   1      6   1      5   1      4   1      3
+--R   (2)  - b e x  + - b d x  + - b c x  + - a e x  + - a d x  + - a c x
+--R        8          7          6          5          4          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 302
+
+--S 303 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1      8   1      7   1      6   1      5   1      4   1      3
+--R   (3)  - b e x  + - b d x  + - b c x  + - a e x  + - a d x  + - a c x
+--R        8          7          6          5          4          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 303
+
+--S 304 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 304
+
+--S 305 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 305
+
+)clear all
+
+--S 306 of 953
+t0:=x^2*(c+d*x+e*x^2)/(a+b*x^3)
+--R 
+--R
+--R           4      3      2
+--R        e x  + d x  + c x
+--R   (1)  ------------------
+--R                3
+--R             b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 306
+
+--S 307 of 953
+r0:=d*x/b+1/2*e*x^2/b-1/3*a^(1/3)*(b^(1/3)*d-a^(1/3)*e)*log(a^(1/3)+_
+   b^(1/3)*x)/b^(5/3)+1/6*a^(1/3)*(d-a^(1/3)*e/b^(1/3))*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/b^(4/3)+1/3*c*log(a+b*x^3)/b+a^(1/3)*_
+   (b^(1/3)*d+a^(1/3)*e)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/_
+   (b^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          +-+3+-+3+-+     +-+3+-+2      2 3+-+2   3+-+3+-+   3+-+2
+--R       (d\|3 \|a \|b  - e\|3 \|a  )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             +-+3+-+3+-+      +-+3+-+2      3+-+   3+-+
+--R       (- 2d\|3 \|a \|b  + 2e\|3 \|a  )log(x\|b  + \|a )
+--R     + 
+--R                                       3+-+   3+-+
+--R            3+-+3+-+      3+-+2      2x\|b  - \|a
+--R       (- 6d\|a \|b  - 6e \|a  )atan(-------------)
+--R                                         +-+3+-+
+--R                                        \|3 \|a
+--R     + 
+--R           +-+       3             2         +-+ 3+-+2
+--R       (2c\|3 log(b x  + a) + (3e x  + 6d x)\|3 )\|b
+--R  /
+--R        +-+3+-+2
+--R     6b\|3 \|b
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +----------------------------------------+
+--R              |    3     2     2                      2
+--R              |- 9b %%BP0  + 6b c %%BP0 - 4a d e - b c
+--R         (- b |----------------------------------------  - b %%BP0 + c)
+--R              |                     3
+--R             \|                   3b
+--R      *
+--R         log
+--R                   3            2        2 2
+--R                (9b e %%BP0 - 3b c e + 3b d )
+--R             *
+--R                 +----------------------------------------+
+--R                 |    3     2     2                      2
+--R                 |- 9b %%BP0  + 6b c %%BP0 - 4a d e - b c
+--R                 |----------------------------------------
+--R                 |                     3
+--R                \|                   3b
+--R            + 
+--R                  3       2      2        2 2              3       3           2
+--R              - 9b e %%BP0  + (6b c e + 3b d )%%BP0 + (2a e  + 2b d )x - 2a d e
+--R            + 
+--R                   2         2
+--R              - b c e - b c d
+--R     + 
+--R            +----------------------------------------+
+--R            |    3     2     2                      2
+--R            |- 9b %%BP0  + 6b c %%BP0 - 4a d e - b c
+--R         (b |----------------------------------------  - b %%BP0 + c)
+--R            |                     3
+--R           \|                   3b
+--R      *
+--R         log
+--R                     3            2        2 2
+--R                (- 9b e %%BP0 + 3b c e - 3b d )
+--R             *
+--R                 +----------------------------------------+
+--R                 |    3     2     2                      2
+--R                 |- 9b %%BP0  + 6b c %%BP0 - 4a d e - b c
+--R                 |----------------------------------------
+--R                 |                     3
+--R                \|                   3b
+--R            + 
+--R                  3       2      2        2 2              3       3           2
+--R              - 9b e %%BP0  + (6b c e + 3b d )%%BP0 + (2a e  + 2b d )x - 2a d e
+--R            + 
+--R                   2         2
+--R              - b c e - b c d
+--R     + 
+--R         2b %%BP0
+--R      *
+--R         log
+--R                3       2        2        2 2             3      3           2
+--R              9b e %%BP0  + (- 6b c e - 3b d )%%BP0 + (a e  + b d )x + 2a d e
+--R            + 
+--R                 2         2
+--R              b c e + b c d
+--R     + 
+--R          2
+--R       e x  + 2d x
+--R  /
+--R     2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 308
+
+--S 309 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         +----------------------------------------+
+--R                         |    3     2     2                      2
+--R                +-+3+-+2 |- 9b %%BP0  + 6b c %%BP0 - 4a d e - b c
+--R           - 3b\|3 \|b   |----------------------------------------
+--R                         |                     3
+--R                        \|                   3b
+--R         + 
+--R                +-+3+-+2           +-+3+-+2
+--R           - 3b\|3 \|b  %%BP0 + 3c\|3 \|b
+--R      *
+--R         log
+--R                   3            2        2 2
+--R                (9b e %%BP0 - 3b c e + 3b d )
+--R             *
+--R                 +----------------------------------------+
+--R                 |    3     2     2                      2
+--R                 |- 9b %%BP0  + 6b c %%BP0 - 4a d e - b c
+--R                 |----------------------------------------
+--R                 |                     3
+--R                \|                   3b
+--R            + 
+--R                  3       2      2        2 2              3       3           2
+--R              - 9b e %%BP0  + (6b c e + 3b d )%%BP0 + (2a e  + 2b d )x - 2a d e
+--R            + 
+--R                   2         2
+--R              - b c e - b c d
+--R     + 
+--R                       +----------------------------------------+
+--R                       |    3     2     2                      2
+--R              +-+3+-+2 |- 9b %%BP0  + 6b c %%BP0 - 4a d e - b c
+--R           3b\|3 \|b   |----------------------------------------
+--R                       |                     3
+--R                      \|                   3b
+--R         + 
+--R                +-+3+-+2           +-+3+-+2
+--R           - 3b\|3 \|b  %%BP0 + 3c\|3 \|b
+--R      *
+--R         log
+--R                     3            2        2 2
+--R                (- 9b e %%BP0 + 3b c e - 3b d )
+--R             *
+--R                 +----------------------------------------+
+--R                 |    3     2     2                      2
+--R                 |- 9b %%BP0  + 6b c %%BP0 - 4a d e - b c
+--R                 |----------------------------------------
+--R                 |                     3
+--R                \|                   3b
+--R            + 
+--R                  3       2      2        2 2              3       3           2
+--R              - 9b e %%BP0  + (6b c e + 3b d )%%BP0 + (2a e  + 2b d )x - 2a d e
+--R            + 
+--R                   2         2
+--R              - b c e - b c d
+--R     + 
+--R            +-+3+-+2
+--R         6b\|3 \|b  %%BP0
+--R      *
+--R         log
+--R                3       2        2        2 2             3      3           2
+--R              9b e %%BP0  + (- 6b c e - 3b d )%%BP0 + (a e  + b d )x + 2a d e
+--R            + 
+--R                 2         2
+--R              b c e + b c d
+--R     + 
+--R            +-+3+-+3+-+     +-+3+-+2      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- d\|3 \|a \|b  + e\|3 \|a  )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           +-+3+-+3+-+      +-+3+-+2      3+-+   3+-+
+--R       (2d\|3 \|a \|b  - 2e\|3 \|a  )log(x\|b  + \|a )
+--R     + 
+--R                                     3+-+   3+-+
+--R          3+-+3+-+      3+-+2      2x\|b  - \|a        +-+       3     3+-+2
+--R       (6d\|a \|b  + 6e \|a  )atan(-------------) - 2c\|3 log(b x  + a)\|b
+--R                                       +-+3+-+
+--R                                      \|3 \|a
+--R  /
+--R        +-+3+-+2
+--R     6b\|3 \|b
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 310
+
+)clear all
+
+--S 311 of 953
+t0:=x^2*(c+d*x+e*x^2)/(a+b*x^3)^2
+--R 
+--R
+--R            4      3      2
+--R         e x  + d x  + c x
+--R   (1)  -------------------
+--R         2 6         3    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 311
+
+--S 312 of 953
+r0:=1/3*(-c-d*x-e*x^2)/(b*(a+b*x^3))+1/9*(b^(1/3)*d-2*a^(1/3)*e)*_
+   log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*b^(5/3))-1/18*(d-2*a^(1/3)*e/b^(1/3))*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(2/3)*b^(4/3))-_
+   1/3*(b^(1/3)*d+2*a^(1/3)*e)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(2/3)*b^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                  3        +-+3+-+          3         +-+3+-+
+--R         ((- b d x  - a d)\|3 \|b  + (2b e x  + 2a e)\|3 \|a )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               3         +-+3+-+            3         +-+3+-+      3+-+   3+-+
+--R       ((2b d x  + 2a d)\|3 \|b  + (- 4b e x  - 4a e)\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                                             3+-+   3+-+
+--R               3        3+-+           3         3+-+      2x\|b  - \|a
+--R       ((6b d x  + 6a d)\|b  + (12b e x  + 12a e)\|a )atan(-------------)
+--R                                                               +-+3+-+
+--R                                                              \|3 \|a
+--R     + 
+--R              2              +-+3+-+2 3+-+2
+--R       (- 6e x  - 6d x - 6c)\|3 \|a   \|b
+--R  /
+--R         2 3          +-+3+-+2 3+-+2
+--R     (18b x  + 18a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                           +---------------------+
+--R                           |       3     2
+--R               2 3         |- 81a b %%BQ0  - 8d e         2 3
+--R         ((- 3b x  - 3a b) |---------------------  + (- 3b x  - 3a b)%%BQ0)
+--R                           |             3
+--R                          \|        27a b
+--R      *
+--R         log
+--R                                         +---------------------+
+--R                                         |       3     2
+--R                   2 3              2 2  |- 81a b %%BQ0  - 8d e
+--R              (162a b e %%BQ0 - 9a b d ) |---------------------
+--R                                         |             3
+--R                                        \|        27a b
+--R            + 
+--R                    2 3       2       2 2              3       3           2
+--R              - 162a b e %%BQ0  - 9a b d %%BQ0 + (16a e  + 2b d )x - 8a d e
+--R     + 
+--R                         +---------------------+
+--R                         |       3     2
+--R             2 3         |- 81a b %%BQ0  - 8d e         2 3
+--R         ((3b x  + 3a b) |---------------------  + (- 3b x  - 3a b)%%BQ0)
+--R                         |             3
+--R                        \|        27a b
+--R      *
+--R         log
+--R                                           +---------------------+
+--R                                           |       3     2
+--R                     2 3              2 2  |- 81a b %%BQ0  - 8d e
+--R              (- 162a b e %%BQ0 + 9a b d ) |---------------------
+--R                                           |             3
+--R                                          \|        27a b
+--R            + 
+--R                    2 3       2       2 2              3       3           2
+--R              - 162a b e %%BQ0  - 9a b d %%BQ0 + (16a e  + 2b d )x - 8a d e
+--R     + 
+--R            2 3
+--R         (6b x  + 6a b)%%BQ0
+--R      *
+--R                 2 3       2       2 2             3      3           2
+--R         log(162a b e %%BQ0  + 9a b d %%BQ0 + (8a e  + b d )x + 8a d e )
+--R     + 
+--R             2
+--R       - 2e x  - 2d x - 2c
+--R  /
+--R       2 3
+--R     6b x  + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 313
+
+--S 314 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              +---------------------+
+--R                              |       3     2
+--R               +-+3+-+2 3+-+2 |- 81a b %%BQ0  - 8d e      +-+3+-+2 3+-+2
+--R         (- 9b\|3 \|a   \|b   |--------------------- - 9b\|3 \|a   \|b  %%BQ)
+--R                              |             3
+--R                             \|        27a b
+--R      *
+--R         log
+--R                                         +---------------------+
+--R                                         |       3     2
+--R                   2 3              2 2  |- 81a b %%BQ0  - 8d e
+--R              (162a b e %%BQ0 - 9a b d ) |---------------------
+--R                                         |             3
+--R                                        \|        27a b
+--R            + 
+--R                    2 3       2       2 2              3       3           2
+--R              - 162a b e %%BQ0  - 9a b d %%BQ0 + (16a e  + 2b d )x - 8a d e
+--R     + 
+--R                            +---------------------+
+--R                            |       3     2
+--R             +-+3+-+2 3+-+2 |- 81a b %%BQ0  - 8d e      +-+3+-+2 3+-+2
+--R         (9b\|3 \|a   \|b   |--------------------- - 9b\|3 \|a   \|b  %%BQ)
+--R                            |             3
+--R                           \|        27a b
+--R      *
+--R         log
+--R                                           +---------------------+
+--R                                           |       3     2
+--R                     2 3              2 2  |- 81a b %%BQ0  - 8d e
+--R              (- 162a b e %%BQ0 + 9a b d ) |---------------------
+--R                                           |             3
+--R                                          \|        27a b
+--R            + 
+--R                    2 3       2       2 2              3       3           2
+--R              - 162a b e %%BQ0  - 9a b d %%BQ0 + (16a e  + 2b d )x - 8a d e
+--R     + 
+--R             +-+3+-+2 3+-+2
+--R         18b\|3 \|a   \|b  %%BQ0
+--R      *
+--R                 2 3       2       2 2             3      3           2
+--R         log(162a b e %%BQ0  + 9a b d %%BQ0 + (8a e  + b d )x + 8a d e )
+--R     + 
+--R          +-+3+-+      +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (d\|3 \|b  - 2e\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (- 2d\|3 \|b  + 4e\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                  3+-+   3+-+
+--R            3+-+      3+-+      2x\|b  - \|a
+--R       (- 6d\|b  - 12e\|a )atan(-------------)
+--R                                    +-+3+-+
+--R                                   \|3 \|a
+--R  /
+--R         +-+3+-+2 3+-+2
+--R     18b\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 953
+t0:=x^2*(c+d*x+e*x^2)/(a+b*x^3)^3
+--R 
+--R
+--R                 4      3      2
+--R              e x  + d x  + c x
+--R   (1)  -----------------------------
+--R         3 9       2 6     2   3    3
+--R        b x  + 3a b x  + 3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 316
+
+--S 317 of 953
+r0:=1/6*(-c-d*x-e*x^2)/(b*(a+b*x^3)^2)+1/18*x*(d+2*e*x)/(a*b*(a+b*x^3))+_
+   1/27*(b^(1/3)*d-a^(1/3)*e)*log(a^(1/3)+b^(1/3)*x)/(a^(5/3)*b^(5/3))-_
+   1/54*(d-a^(1/3)*e/b^(1/3))*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(5/3)*b^(4/3))-1/9*(b^(1/3)*d+a^(1/3)*e)*atan((a^(1/3)-2*b^(1/3)*x)/_
+   (a^(1/3)*sqrt(3)))/(a^(5/3)*b^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R               2   6           3    2   +-+3+-+
+--R           (- b d x  - 2a b d x  - a d)\|3 \|b
+--R         + 
+--R             2   6           3    2   +-+3+-+
+--R           (b e x  + 2a b e x  + a e)\|3 \|a
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              2   6           3     2   +-+3+-+
+--R           (2b d x  + 4a b d x  + 2a d)\|3 \|b
+--R         + 
+--R                2   6           3     2   +-+3+-+
+--R           (- 2b e x  - 4a b e x  - 2a e)\|3 \|a
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R             2   6            3     2  3+-+      2   6            3     2  3+-+
+--R         ((6b d x  + 12a b d x  + 6a d)\|b  + (6b e x  + 12a b e x  + 6a e)\|a )
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R              5         4         2                  +-+3+-+2 3+-+2
+--R       (6b e x  + 3b d x  - 3a e x  - 6a d x - 9a c)\|3 \|a   \|b
+--R  /
+--R           3 6       2 2 3      3   +-+3+-+2 3+-+2
+--R     (54a b x  + 108a b x  + 54a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         +----------------------+
+--R                                         |      3 3     2
+--R                  3 6      2 2 3     3   |- 729a b %%BR0  - 4d e
+--R           (- 9a b x  - 18a b x  - 9a b) |----------------------
+--R                                         |            3 3
+--R                                        \|        243a b
+--R         + 
+--R                  3 6      2 2 3     3
+--R           (- 9a b x  - 18a b x  - 9a b)%%BR0
+--R      *
+--R         log
+--R                                          +----------------------+
+--R                                          |      3 3     2
+--R                   4 3             2 2 2  |- 729a b %%BR0  - 4d e
+--R              (729a b e %%BR0 - 27a b d ) |----------------------
+--R                                          |            3 3
+--R                                         \|        243a b
+--R            + 
+--R                    4 3       2      2 2 2             3       3           2
+--R              - 729a b e %%BR0  - 27a b d %%BR0 + (2a e  + 2b d )x - 2a d e
+--R     + 
+--R                                       +----------------------+
+--R                                       |      3 3     2
+--R                3 6      2 2 3     3   |- 729a b %%BR0  - 4d e
+--R           (9a b x  + 18a b x  + 9a b) |----------------------
+--R                                       |            3 3
+--R                                      \|        243a b
+--R         + 
+--R                  3 6      2 2 3     3
+--R           (- 9a b x  - 18a b x  - 9a b)%%BR0
+--R      *
+--R         log
+--R                                            +----------------------+
+--R                                            |      3 3     2
+--R                     4 3             2 2 2  |- 729a b %%BR0  - 4d e
+--R              (- 729a b e %%BR0 + 27a b d ) |----------------------
+--R                                            |            3 3
+--R                                           \|        243a b
+--R            + 
+--R                    4 3       2      2 2 2             3       3           2
+--R              - 729a b e %%BR0  - 27a b d %%BR0 + (2a e  + 2b d )x - 2a d e
+--R     + 
+--R               3 6      2 2 3      3
+--R         (18a b x  + 36a b x  + 18a b)%%BR0
+--R      *
+--R                 4 3       2      2 2 2            3      3           2
+--R         log(729a b e %%BR0  + 27a b d %%BR0 + (a e  + b d )x + 2a d e )
+--R     + 
+--R             5        4        2
+--R       2b e x  + b d x  - a e x  - 2a d x - 3a c
+--R  /
+--R          3 6      2 2 3      3
+--R     18a b x  + 36a b x  + 18a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 318
+
+--S 319 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  +----------------------+
+--R                                  |      3 3     2
+--R                   +-+3+-+2 3+-+2 |- 729a b %%BR0  - 4d e
+--R           - 27a b\|3 \|a   \|b   |----------------------
+--R                                  |            3 3
+--R                                 \|        243a b
+--R         + 
+--R                   +-+3+-+2 3+-+2
+--R           - 27a b\|3 \|a   \|b  %%BR0
+--R      *
+--R         log
+--R                                          +----------------------+
+--R                                          |      3 3     2
+--R                   4 3             2 2 2  |- 729a b %%BR0  - 4d e
+--R              (729a b e %%BR0 - 27a b d ) |----------------------
+--R                                          |            3 3
+--R                                         \|        243a b
+--R            + 
+--R                    4 3       2      2 2 2             3       3           2
+--R              - 729a b e %%BR0  - 27a b d %%BR0 + (2a e  + 2b d )x - 2a d e
+--R     + 
+--R                                  +----------------------+
+--R                                  |      3 3     2
+--R                   +-+3+-+2 3+-+2 |- 729a b %%BR0  - 4d e
+--R             27a b\|3 \|a   \|b   |----------------------
+--R                                  |            3 3
+--R                                 \|        243a b
+--R           + 
+--R                     +-+3+-+2 3+-+2
+--R             - 27a b\|3 \|a   \|b  %%BR0
+--R      *
+--R         log
+--R                                            +----------------------+
+--R                                            |      3 3     2
+--R                     4 3             2 2 2  |- 729a b %%BR0  - 4d e
+--R              (- 729a b e %%BR0 + 27a b d ) |----------------------
+--R                                            |            3 3
+--R                                           \|        243a b
+--R            + 
+--R                    4 3       2      2 2 2             3       3           2
+--R              - 729a b e %%BR0  - 27a b d %%BR0 + (2a e  + 2b d )x - 2a d e
+--R     + 
+--R               +-+3+-+2 3+-+2
+--R         54a b\|3 \|a   \|b  %%BR0
+--R      *
+--R                 4 3       2      2 2 2            3      3           2
+--R         log(729a b e %%BR0  + 27a b d %%BR0 + (a e  + b d )x + 2a d e )
+--R     + 
+--R          +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (d\|3 \|b  - e\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (- 2d\|3 \|b  + 2e\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                 3+-+   3+-+
+--R            3+-+     3+-+      2x\|b  - \|a
+--R       (- 6d\|b  - 6e\|a )atan(-------------)
+--R                                   +-+3+-+
+--R                                  \|3 \|a
+--R  /
+--R           +-+3+-+2 3+-+2
+--R     54a b\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 320
+
+)clear all
+
+--S 321 of 953
+t0:=x^2*(c+d*x+e*x^2)/(a+b*x^3)^4
+--R 
+--R
+--R                      4      3      2
+--R                   e x  + d x  + c x
+--R   (1)  ----------------------------------------
+--R         4 12       3 9     2 2 6     3   3    4
+--R        b x   + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 321
+
+--S 322 of 953
+r0:=1/9*(-c-d*x-e*x^2)/(b*(a+b*x^3)^3)+1/54*x*(d+2*e*x)/(a*b*(a+b*x^3)^2)+_
+   1/162*x*(5*d+8*e*x)/(a^2*b*(a+b*x^3))+1/243*(5*b^(1/3)*d-4*a^(1/3)*e)*_
+   log(a^(1/3)+b^(1/3)*x)/(a^(8/3)*b^(5/3))-1/486*(5*b^(1/3)*d-_
+   4*a^(1/3)*e)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(8/3)*_
+   b^(5/3))-1/81*(5*b^(1/3)*d+4*a^(1/3)*e)*atan((a^(1/3)-2*b^(1/3)*x)/_
+   (a^(1/3)*sqrt(3)))/(a^(8/3)*b^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                3   9        2   6      2     3     3   +-+3+-+
+--R           (- 5b d x  - 15a b d x  - 15a b d x  - 5a d)\|3 \|b
+--R         + 
+--R              3   9        2   6      2     3     3   +-+3+-+
+--R           (4b e x  + 12a b e x  + 12a b e x  + 4a e)\|3 \|a
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               3   9        2   6      2     3      3   +-+3+-+
+--R           (10b d x  + 30a b d x  + 30a b d x  + 10a d)\|3 \|b
+--R         + 
+--R                3   9        2   6      2     3     3   +-+3+-+
+--R           (- 8b e x  - 24a b e x  - 24a b e x  - 8a e)\|3 \|a
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R               3   9        2   6      2     3      3  3+-+
+--R           (30b d x  + 90a b d x  + 90a b d x  + 30a d)\|b
+--R         + 
+--R               3   9        2   6      2     3      3  3+-+
+--R           (24b e x  + 72a b e x  + 72a b e x  + 24a e)\|a
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R              2   8      2   7            5            4      2   2      2
+--R           24b e x  + 15b d x  + 66a b e x  + 39a b d x  - 12a e x  - 30a d x
+--R         + 
+--R                2
+--R           - 54a c
+--R      *
+--R          +-+3+-+2 3+-+2
+--R         \|3 \|a   \|b
+--R  /
+--R          2 4 9        3 3 6        4 2 3       5   +-+3+-+2 3+-+2
+--R     (486a b x  + 1458a b x  + 1458a b x  + 486a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   2 4 9       3 3 6       4 2 3      5
+--R             (- 81a b x  - 243a b x  - 243a b x  - 81a b)
+--R          *
+--R              +-------------------------+
+--R              |        5 3     2
+--R              |- 59049a b %%BS0  - 80d e
+--R              |-------------------------
+--R              |              5 3
+--R             \|        19683a b
+--R         + 
+--R                 2 4 9       3 3 6       4 2 3      5
+--R           (- 81a b x  - 243a b x  - 243a b x  - 81a b)%%BS0
+--R      *
+--R         log
+--R                                               +-------------------------+
+--R                                               |        5 3     2
+--R                      6 3               3 2 2  |- 59049a b %%BS0  - 80d e
+--R              (236196a b e %%BS0 - 6075a b d ) |-------------------------
+--R                                               |              5 3
+--R                                              \|        19683a b
+--R            + 
+--R                       6 3       2        3 2 2               3         3
+--R              - 236196a b e %%BS0  - 6075a b d %%BS0 + (128a e  + 250b d )x
+--R            + 
+--R                        2
+--R              - 160a d e
+--R     + 
+--R                 2 4 9       3 3 6       4 2 3      5
+--R             (81a b x  + 243a b x  + 243a b x  + 81a b)
+--R          *
+--R              +-------------------------+
+--R              |        5 3     2
+--R              |- 59049a b %%BS0  - 80d e
+--R              |-------------------------
+--R              |              5 3
+--R             \|        19683a b
+--R         + 
+--R                 2 4 9       3 3 6       4 2 3      5
+--R           (- 81a b x  - 243a b x  - 243a b x  - 81a b)%%BS0
+--R      *
+--R         log
+--R                                                 +-------------------------+
+--R                                                 |        5 3     2
+--R                        6 3               3 2 2  |- 59049a b %%BS0  - 80d e
+--R              (- 236196a b e %%BS0 + 6075a b d ) |-------------------------
+--R                                                 |              5 3
+--R                                                \|        19683a b
+--R            + 
+--R                       6 3       2        3 2 2               3         3
+--R              - 236196a b e %%BS0  - 6075a b d %%BS0 + (128a e  + 250b d )x
+--R            + 
+--R                        2
+--R              - 160a d e
+--R     + 
+--R              2 4 9       3 3 6       4 2 3       5
+--R         (162a b x  + 486a b x  + 486a b x  + 162a b)%%BS0
+--R      *
+--R         log
+--R                     6 3       2        3 2 2              3         3
+--R              236196a b e %%BS0  + 6075a b d %%BS0 + (64a e  + 125b d )x
+--R            + 
+--R                      2
+--R              160a d e
+--R     + 
+--R         2   8     2   7            5            4     2   2      2         2
+--R       8b e x  + 5b d x  + 22a b e x  + 13a b d x  - 4a e x  - 10a d x - 18a c
+--R  /
+--R         2 4 9       3 3 6       4 2 3       5
+--R     162a b x  + 486a b x  + 486a b x  + 162a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 323
+
+--S 324 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   +-------------------------+
+--R                                   |        5 3     2
+--R                 2  +-+3+-+2 3+-+2 |- 59049a b %%BS0  - 80d e
+--R           - 243a b\|3 \|a   \|b   |-------------------------
+--R                                   |              5 3
+--R                                  \|        19683a b
+--R         + 
+--R                 2  +-+3+-+2 3+-+2
+--R           - 243a b\|3 \|a   \|b  %%BS0
+--R      *
+--R         log
+--R                                               +-------------------------+
+--R                                               |        5 3     2
+--R                      6 3               3 2 2  |- 59049a b %%BS0  - 80d e
+--R              (236196a b e %%BS0 - 6075a b d ) |-------------------------
+--R                                               |              5 3
+--R                                              \|        19683a b
+--R            + 
+--R                       6 3       2        3 2 2               3         3
+--R              - 236196a b e %%BS0  - 6075a b d %%BS0 + (128a e  + 250b d )x
+--R            + 
+--R                        2
+--R              - 160a d e
+--R     + 
+--R                                 +-------------------------+
+--R                                 |        5 3     2
+--R               2  +-+3+-+2 3+-+2 |- 59049a b %%BS0  - 80d e
+--R           243a b\|3 \|a   \|b   |-------------------------
+--R                                 |              5 3
+--R                                \|        19683a b
+--R         + 
+--R                 2  +-+3+-+2 3+-+2
+--R           - 243a b\|3 \|a   \|b  %%BS0
+--R      *
+--R         log
+--R                                                 +-------------------------+
+--R                                                 |        5 3     2
+--R                        6 3               3 2 2  |- 59049a b %%BS0  - 80d e
+--R              (- 236196a b e %%BS0 + 6075a b d ) |-------------------------
+--R                                                 |              5 3
+--R                                                \|        19683a b
+--R            + 
+--R                       6 3       2        3 2 2               3         3
+--R              - 236196a b e %%BS0  - 6075a b d %%BS0 + (128a e  + 250b d )x
+--R            + 
+--R                        2
+--R              - 160a d e
+--R     + 
+--R             2  +-+3+-+2 3+-+2
+--R         486a b\|3 \|a   \|b  %%BS0
+--R      *
+--R         log
+--R                     6 3       2        3 2 2              3         3
+--R              236196a b e %%BS0  + 6075a b d %%BS0 + (64a e  + 125b d )x
+--R            + 
+--R                      2
+--R              160a d e
+--R     + 
+--R           +-+3+-+      +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (5d\|3 \|b  - 4e\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (- 10d\|3 \|b  + 8e\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                   3+-+   3+-+
+--R             3+-+      3+-+      2x\|b  - \|a
+--R       (- 30d\|b  - 24e\|a )atan(-------------)
+--R                                     +-+3+-+
+--R                                    \|3 \|a
+--R  /
+--R         2  +-+3+-+2 3+-+2
+--R     486a b\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 325
+
+)clear all
+
+--S 326 of 953
+t0:=(1-x)*x^4/(1+x^3)
+--R 
+--R
+--R           5    4
+--R        - x  + x
+--R   (1)  ---------
+--R           3
+--R          x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 326
+
+--S 327 of 953
+r0:=1/2*x^2-1/3*x^3+2/3*log(1+x)+1/6*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                              +-+
+--R        +-+     2              +-+                   (2x - 1)\|3
+--R       \|3 log(x  - x + 1) + 4\|3 log(x + 1) - 6atan(------------)
+--R                                                           3
+--R     + 
+--R            3     2  +-+
+--R       (- 2x  + 3x )\|3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                              +-+
+--R        +-+     2              +-+                   (2x - 1)\|3
+--R       \|3 log(x  - x + 1) + 4\|3 log(x + 1) - 6atan(------------)
+--R                                                           3
+--R     + 
+--R            3     2  +-+
+--R       (- 2x  + 3x )\|3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 328
+
+--S 329 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 953
+t0:=(1-x)*x^3/(1+x^3)
+--R 
+--R
+--R           4    3
+--R        - x  + x
+--R   (1)  ---------
+--R           3
+--R          x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 331
+
+--S 332 of 953
+r0:=x-1/2*x^2-2/3*log(1+x)+1/3*log(1-x+x^2)
+--R 
+--R
+--R              2                            2
+--R        2log(x  - x + 1) - 4log(x + 1) - 3x  + 6x
+--R   (2)  -----------------------------------------
+--R                            6
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2                            2
+--R        2log(x  - x + 1) - 4log(x + 1) - 3x  + 6x
+--R   (3)  -----------------------------------------
+--R                            6
+--R                                         Type: Union(Expression(Integer),...)
+--E 333
+
+--S 334 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 335
+
+)clear all
+
+--S 336 of 953
+t0:=(1-x)*x^2/(1+x^3)
+--R 
+--R
+--R           3    2
+--R        - x  + x
+--R   (1)  ---------
+--R           3
+--R          x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 336
+
+--S 337 of 953
+r0:=-x+2/3*log(1+x)+1/6*log(1-x+x^2)-atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                               +-+
+--R         +-+     2              +-+                   (2x - 1)\|3        +-+
+--R        \|3 log(x  - x + 1) + 4\|3 log(x + 1) + 6atan(------------) - 6x\|3
+--R                                                            3
+--R   (2)  --------------------------------------------------------------------
+--R                                          +-+
+--R                                        6\|3
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                               +-+
+--R         +-+     2              +-+                   (2x - 1)\|3        +-+
+--R        \|3 log(x  - x + 1) + 4\|3 log(x + 1) + 6atan(------------) - 6x\|3
+--R                                                            3
+--R   (3)  --------------------------------------------------------------------
+--R                                          +-+
+--R                                        6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 338
+
+--S 339 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 340
+
+)clear all
+
+--S 341 of 953
+t0:=(1-x)*x/(1+x^3)
+--R 
+--R
+--R           2
+--R        - x  + x
+--R   (1)  --------
+--R          3
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 341
+
+--S 342 of 953
+r0:=-2/3*log(1+x)-1/6*log(1-x+x^2)-atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                 +-+
+--R           +-+     2              +-+                   (2x - 1)\|3
+--R        - \|3 log(x  - x + 1) - 4\|3 log(x + 1) + 6atan(------------)
+--R                                                              3
+--R   (2)  -------------------------------------------------------------
+--R                                      +-+
+--R                                    6\|3
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                                 +-+
+--R           +-+     2              +-+                   (2x - 1)\|3
+--R        - \|3 log(x  - x + 1) - 4\|3 log(x + 1) + 6atan(------------)
+--R                                                              3
+--R   (3)  -------------------------------------------------------------
+--R                                      +-+
+--R                                    6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 343
+
+--S 344 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 953
+t0:=(1-x)/(x*(1+x^3))
+--R 
+--R
+--R        - x + 1
+--R   (1)  -------
+--R          4
+--R         x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 346
+
+--S 347 of 953
+r0:=log(x)-2/3*log(1+x)-1/6*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                          +-+
+--R      +-+     2              +-+               +-+               (2x - 1)\|3
+--R   - \|3 log(x  - x + 1) - 4\|3 log(x + 1) + 6\|3 log(x) - 6atan(------------)
+--R                                                                       3
+--R   ---------------------------------------------------------------------------
+--R                                        +-+
+--R                                      6\|3
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                          +-+
+--R      +-+     2              +-+               +-+               (2x - 1)\|3
+--R   - \|3 log(x  - x + 1) - 4\|3 log(x + 1) + 6\|3 log(x) - 6atan(------------)
+--R                                                                       3
+--R   ---------------------------------------------------------------------------
+--R                                        +-+
+--R                                      6\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 348
+
+--S 349 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 350
+
+)clear all
+
+--S 351 of 953
+t0:=(1-x)/(x^2*(1+x^3))
+--R 
+--R
+--R        - x + 1
+--R   (1)  -------
+--R         5    2
+--R        x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 351
+
+--S 352 of 953
+r0:=(-1)/x-log(x)+2/3*log(1+x)+1/6*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         +-+     2               +-+                +-+
+--R       x\|3 log(x  - x + 1) + 4x\|3 log(x + 1) - 6x\|3 log(x)
+--R     + 
+--R                          +-+
+--R                 (2x - 1)\|3       +-+
+--R       - 6x atan(------------) - 6\|3
+--R                       3
+--R  /
+--R        +-+
+--R     6x\|3
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         +-+     2               +-+                +-+
+--R       x\|3 log(x  - x + 1) + 4x\|3 log(x + 1) - 6x\|3 log(x)
+--R     + 
+--R                          +-+
+--R                 (2x - 1)\|3       +-+
+--R       - 6x atan(------------) - 6\|3
+--R                       3
+--R  /
+--R        +-+
+--R     6x\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 353
+
+--S 354 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+--S 355 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 355
+
+)clear all
+
+--S 356 of 953
+t0:=(1-x)/(x^3*(1+x^3))
+--R 
+--R
+--R        - x + 1
+--R   (1)  -------
+--R         6    3
+--R        x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 356
+
+--S 357 of 953
+r0:=(-1/2)/x^2+1/x-2/3*log(1+x)+1/3*log(1-x+x^2)
+--R 
+--R
+--R          2     2              2
+--R        2x log(x  - x + 1) - 4x log(x + 1) + 6x - 3
+--R   (2)  -------------------------------------------
+--R                              2
+--R                            6x
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2     2              2
+--R        2x log(x  - x + 1) - 4x log(x + 1) + 6x - 3
+--R   (3)  -------------------------------------------
+--R                              2
+--R                            6x
+--R                                         Type: Union(Expression(Integer),...)
+--E 358
+
+--S 359 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 953
+t0:=a*(e+f*x^4)^2
+--R 
+--R
+--R           2 8           4      2
+--R   (1)  a f x  + 2a e f x  + a e
+--R                                                    Type: Polynomial(Integer)
+--E 361
+
+--S 362 of 953
+r0:=a*e^2*x+2/5*a*e*f*x^5+1/9*a*f^2*x^9
+--R 
+--R
+--R        1    2 9   2        5      2
+--R   (2)  - a f x  + - a e f x  + a e x
+--R        9          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 362
+
+--S 363 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R        1    2 9   2        5      2
+--R   (3)  - a f x  + - a e f x  + a e x
+--R        9          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 363
+
+--S 364 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 364
+
+--S 365 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 365
+
+)clear all
+
+--S 366 of 953
+t0:=b*x*(e+f*x^4)^2
+--R 
+--R
+--R           2 9           5      2
+--R   (1)  b f x  + 2b e f x  + b e x
+--R                                                    Type: Polynomial(Integer)
+--E 366
+
+--S 367 of 953
+r0:=1/2*b*e^2*x^2+1/3*b*e*f*x^6+1/10*b*f^2*x^10
+--R 
+--R
+--R         1    2 10   1        6   1    2 2
+--R   (2)  -- b f x   + - b e f x  + - b e x
+--R        10           3            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 367
+
+--S 368 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1    2 10   1        6   1    2 2
+--R   (3)  -- b f x   + - b e f x  + - b e x
+--R        10           3            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 368
+
+--S 369 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 369
+
+--S 370 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 370
+
+)clear all
+
+--S 371 of 953
+t0:=(a+b*x)*(e+f*x^4)^2
+--R 
+--R
+--R           2 9      2 8           5           4      2       2
+--R   (1)  b f x  + a f x  + 2b e f x  + 2a e f x  + b e x + a e
+--R                                                    Type: Polynomial(Integer)
+--E 371
+
+--S 372 of 953
+r0:=a*e^2*x+1/2*b*e^2*x^2+2/5*a*e*f*x^5+1/3*b*e*f*x^6+1/9*a*f^2*x^9+_
+   1/10*b*f^2*x^10
+--R 
+--R
+--R         1    2 10   1    2 9   1        6   2        5   1    2 2      2
+--R   (2)  -- b f x   + - a f x  + - b e f x  + - a e f x  + - b e x  + a e x
+--R        10           9          3            5            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 372
+
+--S 373 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1    2 10   1    2 9   1        6   2        5   1    2 2      2
+--R   (3)  -- b f x   + - a f x  + - b e f x  + - a e f x  + - b e x  + a e x
+--R        10           9          3            5            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 373
+
+--S 374 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 374
+
+--S 375 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 375
+
+)clear all
+
+--S 376 of 953
+t0:=c*x^2*(e+f*x^4)^2
+--R 
+--R
+--R           2 10           6      2 2
+--R   (1)  c f x   + 2c e f x  + c e x
+--R                                                    Type: Polynomial(Integer)
+--E 376
+
+--S 377 of 953
+r0:=1/3*c*e^2*x^3+2/7*c*e*f*x^7+1/11*c*f^2*x^11
+--R 
+--R
+--R         1    2 11   2        7   1    2 3
+--R   (2)  -- c f x   + - c e f x  + - c e x
+--R        11           7            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 377
+
+--S 378 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1    2 11   2        7   1    2 3
+--R   (3)  -- c f x   + - c e f x  + - c e x
+--R        11           7            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 378
+
+--S 379 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 379
+
+--S 380 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 380
+
+)clear all
+
+--S 381 of 953
+t0:=(a+c*x^2)*(e+f*x^4)^2
+--R 
+--R
+--R           2 10      2 8           6           4      2 2      2
+--R   (1)  c f x   + a f x  + 2c e f x  + 2a e f x  + c e x  + a e
+--R                                                    Type: Polynomial(Integer)
+--E 381
+
+--S 382 of 953
+r0:=a*e^2*x+1/3*c*e^2*x^3+2/5*a*e*f*x^5+2/7*c*e*f*x^7+1/9*a*f^2*x^9+_
+   1/11*c*f^2*x^11
+--R 
+--R
+--R         1    2 11   1    2 9   2        7   2        5   1    2 3      2
+--R   (2)  -- c f x   + - a f x  + - c e f x  + - a e f x  + - c e x  + a e x
+--R        11           9          7            5            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 382
+
+--S 383 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1    2 11   1    2 9   2        7   2        5   1    2 3      2
+--R   (3)  -- c f x   + - a f x  + - c e f x  + - a e f x  + - c e x  + a e x
+--R        11           9          7            5            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 383
+
+--S 384 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 384
+
+--S 385 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 385
+
+)clear all
+
+--S 386 of 953
+t0:=(b*x+c*x^2)*(e+f*x^4)^2
+--R 
+--R
+--R           2 10      2 9           6           5      2 2      2
+--R   (1)  c f x   + b f x  + 2c e f x  + 2b e f x  + c e x  + b e x
+--R                                                    Type: Polynomial(Integer)
+--E 386
+
+--S 387 of 953
+r0:=1/2*b*e^2*x^2+1/3*c*e^2*x^3+1/3*b*e*f*x^6+2/7*c*e*f*x^7+1/10*b*f^2*x^10+_
+   1/11*c*f^2*x^11
+--R 
+--R
+--R   (2)
+--R    1    2 11    1    2 10   2        7   1        6   1    2 3   1    2 2
+--R   -- c f x   + -- b f x   + - c e f x  + - b e f x  + - c e x  + - b e x
+--R   11           10           7            3            3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 387
+
+--S 388 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R    1    2 11    1    2 10   2        7   1        6   1    2 3   1    2 2
+--R   -- c f x   + -- b f x   + - c e f x  + - b e f x  + - c e x  + - b e x
+--R   11           10           7            3            3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 388
+
+--S 389 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 389
+
+--S 390 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 390
+
+)clear all
+
+--S 391 of 953
+t0:=(a+b*x+c*x^2)*(e+f*x^4)^2
+--R 
+--R
+--R   (1)
+--R        2 10      2 9      2 8           6           5           4      2 2
+--R     c f x   + b f x  + a f x  + 2c e f x  + 2b e f x  + 2a e f x  + c e x
+--R   + 
+--R        2       2
+--R     b e x + a e
+--R                                                    Type: Polynomial(Integer)
+--E 391
+
+--S 392 of 953
+r0:=a*e^2*x+1/2*b*e^2*x^2+1/3*c*e^2*x^3+2/5*a*e*f*x^5+1/3*b*e*f*x^6+_
+   2/7*c*e*f*x^7+1/9*a*f^2*x^9+1/10*b*f^2*x^10+1/11*c*f^2*x^11
+--R 
+--R
+--R   (2)
+--R      1    2 11    1    2 10   1    2 9   2        7   1        6   2        5
+--R     -- c f x   + -- b f x   + - a f x  + - c e f x  + - b e f x  + - a e f x
+--R     11           10           9          7            3            5
+--R   + 
+--R     1    2 3   1    2 2      2
+--R     - c e x  + - b e x  + a e x
+--R     3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 392
+
+--S 393 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    2 11    1    2 10   1    2 9   2        7   1        6   2        5
+--R     -- c f x   + -- b f x   + - a f x  + - c e f x  + - b e f x  + - a e f x
+--R     11           10           9          7            3            5
+--R   + 
+--R     1    2 3   1    2 2      2
+--R     - c e x  + - b e x  + a e x
+--R     3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 393
+
+--S 394 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 394
+
+--S 395 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 395
+
+)clear all
+
+--S 396 of 953
+t0:=d*x^3*(e+f*x^4)^2
+--R 
+--R
+--R           2 11           7      2 3
+--R   (1)  d f x   + 2d e f x  + d e x
+--R                                                    Type: Polynomial(Integer)
+--E 396
+
+--S 397 of 953
+r0:=1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R         1    3 12   1      2 8   1    2   4    1    3
+--R        -- d f x   + - d e f x  + - d e f x  + -- d e
+--R        12           4            4            12
+--R   (2)  ----------------------------------------------
+--R                               f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 397
+
+--S 398 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1    2 12   1        8   1    2 4
+--R   (3)  -- d f x   + - d e f x  + - d e x
+--R        12           4            4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 398
+
+--S 399 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1    3
+--R          -- d e
+--R          12
+--R   (4)  - -------
+--R             f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 399
+
+--S 400 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 400
+
+)clear all
+
+--S 401 of 953
+t0:=(a+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R           2 11      2 8           7           4      2 3      2
+--R   (1)  d f x   + a f x  + 2d e f x  + 2a e f x  + d e x  + a e
+--R                                                    Type: Polynomial(Integer)
+--E 401
+
+--S 402 of 953
+r0:=a*e^2*x+2/5*a*e*f*x^5+1/9*a*f^2*x^9+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12   1    3 9   1      2 8   2      2 5   1    2   4      2
+--R       -- d f x   + - a f x  + - d e f x  + - a e f x  + - d e f x  + a e f x
+--R       12           9          4            5            4
+--R     + 
+--R        1    3
+--R       -- d e
+--R       12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 402
+
+--S 403 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R         1    2 12   1    2 9   1        8   2        5   1    2 4      2
+--R   (3)  -- d f x   + - a f x  + - d e f x  + - a e f x  + - d e x  + a e x
+--R        12           9          4            5            4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 403
+
+--S 404 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1    3
+--R          -- d e
+--R          12
+--R   (4)  - -------
+--R             f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 404
+
+--S 405 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 405
+
+)clear all
+
+--S 406 of 953
+t0:=(b*x+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R           2 11      2 9           7           5      2 3      2
+--R   (1)  d f x   + b f x  + 2d e f x  + 2b e f x  + d e x  + b e x
+--R                                                    Type: Polynomial(Integer)
+--E 406
+
+--S 407 of 953
+r0:=1/2*b*e^2*x^2+1/3*b*e*f*x^6+1/10*b*f^2*x^10+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 10   1      2 8   1      2 6   1    2   4
+--R       -- d f x   + -- b f x   + - d e f x  + - b e f x  + - d e f x
+--R       12           10           4            3            4
+--R     + 
+--R       1    2   2    1    3
+--R       - b e f x  + -- d e
+--R       2            12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 407
+
+--S 408 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R    1    2 12    1    2 10   1        8   1        6   1    2 4   1    2 2
+--R   -- d f x   + -- b f x   + - d e f x  + - b e f x  + - d e x  + - b e x
+--R   12           10           4            3            4          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 408
+
+--S 409 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1    3
+--R          -- d e
+--R          12
+--R   (4)  - -------
+--R             f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 409
+
+--S 410 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 410
+
+)clear all
+
+--S 411 of 953
+t0:=(a+b*x+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R   (1)
+--R        2 11      2 9      2 8           7           5           4      2 3
+--R     d f x   + b f x  + a f x  + 2d e f x  + 2b e f x  + 2a e f x  + d e x
+--R   + 
+--R        2       2
+--R     b e x + a e
+--R                                                    Type: Polynomial(Integer)
+--E 411
+
+--S 412 of 953
+r0:=a*e^2*x+1/2*b*e^2*x^2+2/5*a*e*f*x^5+1/3*b*e*f*x^6+1/9*a*f^2*x^9+_
+   1/10*b*f^2*x^10+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 10   1    3 9   1      2 8   1      2 6   2      2 5
+--R       -- d f x   + -- b f x   + - a f x  + - d e f x  + - b e f x  + - a e f x
+--R       12           10           9          4            3            5
+--R     + 
+--R       1    2   4   1    2   2      2       1    3
+--R       - d e f x  + - b e f x  + a e f x + -- d e
+--R       4            2                      12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 412
+
+--S 413 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    2 12    1    2 10   1    2 9   1        8   1        6   2        5
+--R     -- d f x   + -- b f x   + - a f x  + - d e f x  + - b e f x  + - a e f x
+--R     12           10           9          4            3            5
+--R   + 
+--R     1    2 4   1    2 2      2
+--R     - d e x  + - b e x  + a e x
+--R     4          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 413
+
+--S 414 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1    3
+--R          -- d e
+--R          12
+--R   (4)  - -------
+--R             f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 414
+
+--S 415 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 415
+
+)clear all
+
+--S 416 of 953
+t0:=(c*x^2+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R           2 11      2 10           7           6      2 3      2 2
+--R   (1)  d f x   + c f x   + 2d e f x  + 2c e f x  + d e x  + c e x
+--R                                                    Type: Polynomial(Integer)
+--E 416
+
+--S 417 of 953
+r0:=1/3*c*e^2*x^3+2/7*c*e*f*x^7+1/11*c*f^2*x^11+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 11   1      2 8   2      2 7   1    2   4
+--R       -- d f x   + -- c f x   + - d e f x  + - c e f x  + - d e f x
+--R       12           11           4            7            4
+--R     + 
+--R       1    2   3    1    3
+--R       - c e f x  + -- d e
+--R       3            12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 417
+
+--S 418 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R    1    2 12    1    2 11   1        8   2        7   1    2 4   1    2 3
+--R   -- d f x   + -- c f x   + - d e f x  + - c e f x  + - d e x  + - c e x
+--R   12           11           4            7            4          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 418
+
+--S 419 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1    3
+--R          -- d e
+--R          12
+--R   (4)  - -------
+--R             f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 419
+
+--S 420 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 420
+
+)clear all
+
+--S 421 of 953
+t0:=(a+c*x^2+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R   (1)
+--R        2 11      2 10      2 8           7           6           4      2 3
+--R     d f x   + c f x   + a f x  + 2d e f x  + 2c e f x  + 2a e f x  + d e x
+--R   + 
+--R        2 2      2
+--R     c e x  + a e
+--R                                                    Type: Polynomial(Integer)
+--E 421
+
+--S 422 of 953
+r0:=a*e^2*x+1/3*c*e^2*x^3+2/5*a*e*f*x^5+2/7*c*e*f*x^7+1/9*a*f^2*x^9+_
+   1/11*c*f^2*x^11+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 11   1    3 9   1      2 8   2      2 7   2      2 5
+--R       -- d f x   + -- c f x   + - a f x  + - d e f x  + - c e f x  + - a e f x
+--R       12           11           9          4            7            5
+--R     + 
+--R       1    2   4   1    2   3      2       1    3
+--R       - d e f x  + - c e f x  + a e f x + -- d e
+--R       4            3                      12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 422
+
+--S 423 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    2 12    1    2 11   1    2 9   1        8   2        7   2        5
+--R     -- d f x   + -- c f x   + - a f x  + - d e f x  + - c e f x  + - a e f x
+--R     12           11           9          4            7            5
+--R   + 
+--R     1    2 4   1    2 3      2
+--R     - d e x  + - c e x  + a e x
+--R     4          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 423
+
+--S 424 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1    3
+--R          -- d e
+--R          12
+--R   (4)  - -------
+--R             f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 424
+
+--S 425 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 425
+
+)clear all
+
+--S 426 of 953
+t0:=(b*x+c*x^2+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R   (1)
+--R        2 11      2 10      2 9           7           6           5      2 3
+--R     d f x   + c f x   + b f x  + 2d e f x  + 2c e f x  + 2b e f x  + d e x
+--R   + 
+--R        2 2      2
+--R     c e x  + b e x
+--R                                                    Type: Polynomial(Integer)
+--E 426
+
+--S 427 of 953
+r0:=1/2*b*e^2*x^2+1/3*c*e^2*x^3+1/3*b*e*f*x^6+2/7*c*e*f*x^7+_
+   1/10*b*f^2*x^10+1/11*c*f^2*x^11+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 11    1    3 10   1      2 8   2      2 7
+--R       -- d f x   + -- c f x   + -- b f x   + - d e f x  + - c e f x
+--R       12           11           10           4            7
+--R     + 
+--R       1      2 6   1    2   4   1    2   3   1    2   2    1    3
+--R       - b e f x  + - d e f x  + - c e f x  + - b e f x  + -- d e
+--R       3            4            3            2            12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 427
+
+--S 428 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    2 12    1    2 11    1    2 10   1        8   2        7   1        6
+--R     -- d f x   + -- c f x   + -- b f x   + - d e f x  + - c e f x  + - b e f x
+--R     12           11           10           4            7            3
+--R   + 
+--R     1    2 4   1    2 3   1    2 2
+--R     - d e x  + - c e x  + - b e x
+--R     4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 428
+
+--S 429 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1    3
+--R          -- d e
+--R          12
+--R   (4)  - -------
+--R             f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 429
+
+--S 430 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 430
+
+)clear all
+
+--S 431 of 953
+t0:=(a+b*x+c*x^2+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R   (1)
+--R        2 11      2 10      2 9      2 8           7           6           5
+--R     d f x   + c f x   + b f x  + a f x  + 2d e f x  + 2c e f x  + 2b e f x
+--R   + 
+--R             4      2 3      2 2      2       2
+--R     2a e f x  + d e x  + c e x  + b e x + a e
+--R                                                    Type: Polynomial(Integer)
+--E 431
+
+--S 432 of 953
+r0:=a*e^2*x+1/2*b*e^2*x^2+1/3*c*e^2*x^3+2/5*a*e*f*x^5+1/3*b*e*f*x^6+_
+   2/7*c*e*f*x^7+1/9*a*f^2*x^9+1/10*b*f^2*x^10+1/11*c*f^2*x^11+_
+   1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 11    1    3 10   1    3 9   1      2 8   2      2 7
+--R       -- d f x   + -- c f x   + -- b f x   + - a f x  + - d e f x  + - c e f x
+--R       12           11           10           9          4            7
+--R     + 
+--R       1      2 6   2      2 5   1    2   4   1    2   3   1    2   2      2
+--R       - b e f x  + - a e f x  + - d e f x  + - c e f x  + - b e f x  + a e f x
+--R       3            5            4            3            2
+--R     + 
+--R        1    3
+--R       -- d e
+--R       12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 432
+
+--S 433 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1    2 12    1    2 11    1    2 10   1    2 9   1        8   2        7
+--R     -- d f x   + -- c f x   + -- b f x   + - a f x  + - d e f x  + - c e f x
+--R     12           11           10           9          4            7
+--R   + 
+--R     1        6   2        5   1    2 4   1    2 3   1    2 2      2
+--R     - b e f x  + - a e f x  + - d e x  + - c e x  + - b e x  + a e x
+--R     3            5            4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 433
+
+--S 434 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1    3
+--R          -- d e
+--R          12
+--R   (4)  - -------
+--R             f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 434
+
+--S 435 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 435
+
+)clear all
+
+--S 436 of 953
+t0:=a/(e+f*x^4)
+--R 
+--R
+--R            a
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 436
+
+--S 437 of 953
+r0:=-1/2*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(3/4)*f^(1/4)*sqrt(2))+_
+   1/2*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(3/4)*f^(1/4)*sqrt(2))-_
+   1/4*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(3/4)*_
+   f^(1/4)*sqrt(2))+1/4*a*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R       a log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                            +-+4+-+   4+-+
+--R                   +-+4+-+4+-+    2 +-+    +-+            x\|2 \|f  + \|e
+--R       - a log(- x\|2 \|e \|f  + x \|f  + \|e ) + 2a atan(----------------)
+--R                                                                4+-+
+--R                                                                \|e
+--R     + 
+--R                 +-+4+-+   4+-+
+--R               x\|2 \|f  - \|e
+--R       2a atan(----------------)
+--R                     4+-+
+--R                     \|e
+--R  /
+--R       +-+4+-+3 4+-+
+--R     4\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      +--------+        +--------+          +--------+          +--------+
+--R      |     4           |     4             |     4             |     4
+--R      |    a            |    a              |    a              |    a
+--R      |- ------ log(4e  |- ------ + a x) -  |- ------ log(- 4e  |- ------ + a x)
+--R     4|      3         4|      3           4|      3           4|      3
+--R     \|  256e f        \|  256e f          \|  256e f          \|  256e f
+--R   + 
+--R                             +--------+
+--R                             |     4
+--R                             |    a
+--R          +--------+     4e  |- ------
+--R          |     4           4|      3
+--R          |    a            \|  256e f
+--R     - 2  |- ------ atan(-------------)
+--R         4|      3            a x
+--R         \|  256e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 438
+
+--S 439 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R       - a log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              +--------+                  +--------+
+--R              |     4                     |     4
+--R         +-+  |    a    4+-+3 4+-+        |    a
+--R       4\|2   |- ------ \|e   \|f log(4e  |- ------ + a x)
+--R             4|      3                   4|      3
+--R             \|  256e f                  \|  256e f
+--R     + 
+--R                +--------+                    +--------+
+--R                |     4                       |     4
+--R           +-+  |    a    4+-+3 4+-+          |    a
+--R       - 4\|2   |- ------ \|e   \|f log(- 4e  |- ------ + a x)
+--R               4|      3                     4|      3
+--R               \|  256e f                    \|  256e f
+--R     + 
+--R                                                          +-+4+-+   4+-+
+--R                 +-+4+-+4+-+    2 +-+    +-+            x\|2 \|f  + \|e
+--R       a log(- x\|2 \|e \|f  + x \|f  + \|e ) - 2a atan(----------------)
+--R                                                              4+-+
+--R                                                              \|e
+--R     + 
+--R                                                                       +--------+
+--R                                                                       |     4
+--R                                                                       |    a
+--R                                          +--------+               4e  |- ------
+--R                 +-+4+-+   4+-+           |     4                     4|      3
+--R               x\|2 \|f  - \|e       +-+  |    a    4+-+3 4+-+        \|  256e f
+--R     - 2a atan(----------------) - 8\|2   |- ------ \|e   \|f atan(-------------)
+--R                     4+-+                4|      3                      a x
+--R                     \|e                 \|  256e f
+--R  /
+--R       +-+4+-+3 4+-+
+--R     4\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                2 +-+4+-+2        6        2  +-+          4       4+-+2
+--R           (2a x \|e \|e   + a f x  + a e x )\|f  + (3a f x  + a e)\|e
+--R         + 
+--R                   4        +-+
+--R           (- a f x  - a e)\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R               4 +-+ +-+      2 6           2
+--R       - 2a f x \|e \|f  - a f x  - 3a e f x
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 440
+
+)clear all
+
+--S 441 of 953
+t0:=b*x/(e+f*x^4)
+--R 
+--R
+--R           b x
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 441
+
+--S 442 of 953
+r0:=1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R                2 +-+
+--R               x \|f
+--R        b atan(------)
+--R                 +-+
+--R                \|e
+--R   (2)  --------------
+--R             +-+ +-+
+--R           2\|e \|f
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   4      +-----+         2
+--R               (f x  - e)\|- e f  + 2e f x           2 +---+
+--R         b log(----------------------------)        x \|e f
+--R                            4                b atan(--------)
+--R                         f x  + e                       e
+--R   (3)  [-----------------------------------,----------------]
+--R                        +-----+                     +---+
+--R                      4\|- e f                    2\|e f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 443
+
+--S 444 of 953
+m0a:=a0.1-r0
+--R 
+--R
+--R                         4      +-----+         2                    2 +-+
+--R          +-+ +-+    (f x  - e)\|- e f  + 2e f x        +-----+     x \|f
+--R        b\|e \|f log(----------------------------) - 2b\|- e f atan(------)
+--R                                  4                                   +-+
+--R                               f x  + e                              \|e
+--R   (4)  -------------------------------------------------------------------
+--R                                   +-----+ +-+ +-+
+--R                                 4\|- e f \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 953
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 953
+m0b:=a0.2-r0
+--R 
+--R
+--R                       2 +---+                 2 +-+
+--R          +-+ +-+     x \|e f       +---+     x \|f
+--R        b\|e \|f atan(--------) - b\|e f atan(------)
+--R                          e                     +-+
+--R                                               \|e
+--R   (6)  ---------------------------------------------
+--R                         +-+ +-+ +---+
+--R                       2\|e \|f \|e f
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 953
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 953
+t0:=(a+b*x)/(e+f*x^4)
+--R 
+--R
+--R         b x + a
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 448
+
+--S 449 of 953
+r0:=-1/2*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(3/4)*f^(1/4)*sqrt(2))+_
+   1/2*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(3/4)*f^(1/4)*sqrt(2))-_
+   1/4*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(3/4)*_
+   f^(1/4)*sqrt(2))+1/4*a*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))+1/2*b*atan(x^2*sqrt(f)/_
+   sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R         +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       a\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       - a\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                        +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R          +-+ +-+     x\|2 \|f  + \|e        +-+ +-+     x\|2 \|f  - \|e
+--R       2a\|e \|f atan(----------------) + 2a\|e \|f atan(----------------)
+--R                            4+-+                               4+-+
+--R                            \|e                                \|e
+--R     + 
+--R                             2 +-+
+--R          +-+4+-+3 4+-+     x \|f
+--R       2b\|2 \|e   \|f atan(------)
+--R                              +-+
+--R                             \|e
+--R  /
+--R       +-+ +-+4+-+3 +-+4+-+
+--R     4\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6e f %%BU1  - 4e f %%BU0 %%BU1 - 6e f %%BU0  - b
+--R              |---------------------------------------------------  - %%BU1
+--R             \|                        2e f
+--R           + 
+--R             - %%BU0
+--R      *
+--R         log
+--R                      2 3            2   2            2   2            4
+--R                  (64b e f %%BU0 - 8a b e f)%%BU1 - 8a b e f %%BU0 + 2a e f
+--R                + 
+--R                      4 2
+--R                  - 4b e
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6e f %%BU1  - 4e f %%BU0 %%BU1 - 6e f %%BU0  - b
+--R                 |---------------------------------------------------
+--R                \|                        2e f
+--R            + 
+--R                  2 3            2   2       2
+--R              (64b e f %%BU0 - 8a b e f)%%BU1
+--R            + 
+--R                  2 3       2     4        4 2           2   2       2
+--R              (64b e f %%BU0  - 2a e f + 4b e )%%BU1 - 8a b e f %%BU0
+--R            + 
+--R                   4        4 2           5        4       2 3
+--R              (- 2a e f + 4b e )%%BU0 + (a f - 4a b e)x + a b e
+--R     + 
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6e f %%BU1  - 4e f %%BU0 %%BU1 - 6e f %%BU0  - b
+--R           -  |---------------------------------------------------  - %%BU1
+--R             \|                        2e f
+--R         + 
+--R           - %%BU0
+--R      *
+--R         log
+--R                        2 3            2   2            2   2            4
+--R                  (- 64b e f %%BU0 + 8a b e f)%%BU1 + 8a b e f %%BU0 - 2a e f
+--R                + 
+--R                    4 2
+--R                  4b e
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6e f %%BU1  - 4e f %%BU0 %%BU1 - 6e f %%BU0  - b
+--R                 |---------------------------------------------------
+--R                \|                        2e f
+--R            + 
+--R                  2 3            2   2       2
+--R              (64b e f %%BU0 - 8a b e f)%%BU1
+--R            + 
+--R                  2 3       2     4        4 2           2   2       2
+--R              (64b e f %%BU0  - 2a e f + 4b e )%%BU1 - 8a b e f %%BU0
+--R            + 
+--R                   4        4 2           5        4       2 3
+--R              (- 2a e f + 4b e )%%BU0 + (a f - 4a b e)x + a b e
+--R     + 
+--R         2%%BU1
+--R      *
+--R         log
+--R                     2 3             2   2       2
+--R              (- 128b e f %%BU0 + 16a b e f)%%BU1
+--R            + 
+--R                     2 3       2     4        4 2             2 3       3
+--R              (- 128b e f %%BU0  + 4a e f - 8b e )%%BU1 - 128b e f %%BU0
+--R            + 
+--R                   4 2          5        4        2 3
+--R              - 16b e %%BU0 + (a f - 4a b e)x + 3a b e
+--R     + 
+--R         2%%BU0
+--R      *
+--R         log
+--R                  2 3       3      2   2       2      4        4 2
+--R              128b e f %%BU0  + 16a b e f %%BU0  + (4a e f + 8b e )%%BU0
+--R            + 
+--R                5        4        2 3
+--R              (a f - 4a b e)x - 5a b e
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 450
+
+--S 451 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+ +-+4+-+3 +-+4+-+
+--R             2\|2 \|e \|e  \|f \|f
+--R          *
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6e f %%BU1  - 4e f %%BU0 %%BU1 - 6e f %%BU0  - b
+--R              |---------------------------------------------------
+--R             \|                        2e f
+--R         + 
+--R               +-+ +-+4+-+3 +-+4+-+          +-+ +-+4+-+3 +-+4+-+
+--R           - 2\|2 \|e \|e  \|f \|f %%BU1 - 2\|2 \|e \|e  \|f \|f %%BU0
+--R      *
+--R         log
+--R                      2 3            2   2            2   2            4
+--R                  (64b e f %%BU0 - 8a b e f)%%BU1 - 8a b e f %%BU0 + 2a e f
+--R                + 
+--R                      4 2
+--R                  - 4b e
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6e f %%BU1  - 4e f %%BU0 %%BU1 - 6e f %%BU0  - b
+--R                 |---------------------------------------------------
+--R                \|                        2e f
+--R            + 
+--R                  2 3            2   2       2
+--R              (64b e f %%BU0 - 8a b e f)%%BU1
+--R            + 
+--R                  2 3       2     4        4 2           2   2       2
+--R              (64b e f %%BU0  - 2a e f + 4b e )%%BU1 - 8a b e f %%BU0
+--R            + 
+--R                   4        4 2           5        4       2 3
+--R              (- 2a e f + 4b e )%%BU0 + (a f - 4a b e)x + a b e
+--R     + 
+--R           -
+--R                  +-+ +-+4+-+3 +-+4+-+
+--R                2\|2 \|e \|e  \|f \|f
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6e f %%BU1  - 4e f %%BU0 %%BU1 - 6e f %%BU0  - b
+--R                 |---------------------------------------------------
+--R                \|                        2e f
+--R         + 
+--R               +-+ +-+4+-+3 +-+4+-+          +-+ +-+4+-+3 +-+4+-+
+--R           - 2\|2 \|e \|e  \|f \|f %%BU1 - 2\|2 \|e \|e  \|f \|f %%BU0
+--R      *
+--R         log
+--R                        2 3            2   2            2   2            4
+--R                  (- 64b e f %%BU0 + 8a b e f)%%BU1 + 8a b e f %%BU0 - 2a e f
+--R                + 
+--R                    4 2
+--R                  4b e
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6e f %%BU1  - 4e f %%BU0 %%BU1 - 6e f %%BU0  - b
+--R                 |---------------------------------------------------
+--R                \|                        2e f
+--R            + 
+--R                  2 3            2   2       2
+--R              (64b e f %%BU0 - 8a b e f)%%BU1
+--R            + 
+--R                  2 3       2     4        4 2           2   2       2
+--R              (64b e f %%BU0  - 2a e f + 4b e )%%BU1 - 8a b e f %%BU0
+--R            + 
+--R                   4        4 2           5        4       2 3
+--R              (- 2a e f + 4b e )%%BU0 + (a f - 4a b e)x + a b e
+--R     + 
+--R           +-+ +-+4+-+3 +-+4+-+
+--R         4\|2 \|e \|e  \|f \|f %%BU1
+--R      *
+--R         log
+--R                     2 3             2   2       2
+--R              (- 128b e f %%BU0 + 16a b e f)%%BU1
+--R            + 
+--R                     2 3       2     4        4 2             2 3       3
+--R              (- 128b e f %%BU0  + 4a e f - 8b e )%%BU1 - 128b e f %%BU0
+--R            + 
+--R                   4 2          5        4        2 3
+--R              - 16b e %%BU0 + (a f - 4a b e)x + 3a b e
+--R     + 
+--R           +-+ +-+4+-+3 +-+4+-+
+--R         4\|2 \|e \|e  \|f \|f %%BU0
+--R      *
+--R         log
+--R                  2 3       3      2   2       2      4        4 2
+--R              128b e f %%BU0  + 16a b e f %%BU0  + (4a e f + 8b e )%%BU0
+--R            + 
+--R                5        4        2 3
+--R              (a f - 4a b e)x - 5a b e
+--R     + 
+--R           +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       - a\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R         +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       a\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                          +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|f  + \|e        +-+ +-+     x\|2 \|f  - \|e
+--R       - 2a\|e \|f atan(----------------) - 2a\|e \|f atan(----------------)
+--R                              4+-+                               4+-+
+--R                              \|e                                \|e
+--R     + 
+--R                               2 +-+
+--R            +-+4+-+3 4+-+     x \|f
+--R       - 2b\|2 \|e   \|f atan(------)
+--R                                +-+
+--R                               \|e
+--R  /
+--R       +-+ +-+4+-+3 +-+4+-+
+--R     4\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                2 +-+4+-+2        6        2  +-+          4       4+-+2
+--R           (2a x \|e \|e   + a f x  + a e x )\|f  + (3a f x  + a e)\|e
+--R         + 
+--R                   4        +-+
+--R           (- a f x  - a e)\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R               4 +-+ +-+      2 6           2
+--R       - 2a f x \|e \|f  - a f x  - 3a e f x
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 452
+
+)clear all
+
+--S 453 of 953
+t0:=c*x^2/(e+f*x^4)
+--R 
+--R
+--R             2
+--R          c x
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 453
+
+--S 454 of 953
+r0:=-1/2*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(1/4)*f^(3/4)*sqrt(2))+_
+   1/2*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(1/4)*f^(3/4)*sqrt(2))+_
+   1/4*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(1/4)*_
+   f^(3/4)*sqrt(2))-1/4*c*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R       - c log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                          +-+4+-+   4+-+
+--R                 +-+4+-+4+-+    2 +-+    +-+            x\|2 \|f  + \|e
+--R       c log(- x\|2 \|e \|f  + x \|f  + \|e ) + 2c atan(----------------)
+--R                                                              4+-+
+--R                                                              \|e
+--R     + 
+--R                 +-+4+-+   4+-+
+--R               x\|2 \|f  - \|e
+--R       2c atan(----------------)
+--R                     4+-+
+--R                     \|e
+--R  /
+--R       +-+4+-+4+-+3
+--R     4\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      +---------+            +---------+3
+--R      |      4               |      4
+--R      |     c             2  |     c        3
+--R      |- ------- log(64e f   |- -------  + c x)
+--R     4|        3            4|        3
+--R     \|  256e f             \|  256e f
+--R   + 
+--R        +---------+              +---------+3
+--R        |      4                 |      4
+--R        |     c               2  |     c        3
+--R     -  |- ------- log(- 64e f   |- -------  + c x)
+--R       4|        3              4|        3
+--R       \|  256e f               \|  256e f
+--R   + 
+--R                                +---------+3
+--R                                |      4
+--R                             2  |     c
+--R        +---------+     64e f   |- -------
+--R        |      4               4|        3
+--R        |     c                \|  256e f
+--R     2  |- ------- atan(-------------------)
+--R       4|        3               3
+--R       \|  256e f               c x
+--R                                         Type: Union(Expression(Integer),...)
+--E 455
+
+--S 456 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R       c log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              +---------+                     +---------+3
+--R              |      4                        |      4
+--R         +-+  |     c    4+-+4+-+3         2  |     c        3
+--R       4\|2   |- ------- \|e \|f  log(64e f   |- -------  + c x)
+--R             4|        3                     4|        3
+--R             \|  256e f                      \|  256e f
+--R     + 
+--R                +---------+                       +---------+3
+--R                |      4                          |      4
+--R           +-+  |     c    4+-+4+-+3           2  |     c        3
+--R       - 4\|2   |- ------- \|e \|f  log(- 64e f   |- -------  + c x)
+--R               4|        3                       4|        3
+--R               \|  256e f                        \|  256e f
+--R     + 
+--R                                                            +-+4+-+   4+-+
+--R                   +-+4+-+4+-+    2 +-+    +-+            x\|2 \|f  + \|e
+--R       - c log(- x\|2 \|e \|f  + x \|f  + \|e ) - 2c atan(----------------)
+--R                                                                4+-+
+--R                                                                \|e
+--R     + 
+--R                   +-+4+-+   4+-+
+--R                 x\|2 \|f  - \|e
+--R       - 2c atan(----------------)
+--R                       4+-+
+--R                       \|e
+--R     + 
+--R                                               +---------+3
+--R                                               |      4
+--R                                            2  |     c
+--R              +---------+              64e f   |- -------
+--R              |      4                        4|        3
+--R         +-+  |     c    4+-+4+-+3            \|  256e f
+--R       8\|2   |- ------- \|e \|f  atan(-------------------)
+--R             4|        3                        3
+--R             \|  256e f                        c x
+--R  /
+--R       +-+4+-+4+-+3
+--R     4\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            4 +-+4+-+2 +-+         6         2 4+-+2 4+-+2
+--R       (2c x \|e \|e  \|f  + (c f x  + 3c e x )\|e  )\|f
+--R     + 
+--R                6        2 4+-+2         2 +-+  +-+         4        +-+4+-+2
+--R       ((- c f x  - c e x )\|e   - 2c e x \|e )\|f  + (c f x  + c e)\|e \|e
+--R     + 
+--R                 4      2
+--R       - 3c e f x  - c e
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 457
+
+)clear all
+
+--S 458 of 953
+t0:=(a+c*x^2)/(e+f*x^4)
+--R 
+--R
+--R           2
+--R        c x  + a
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 458
+
+--S 459 of 953
+r0:=1/4*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-_
+   a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))-1/4*log(e^(1/4)*f^(1/4)*x*_
+   sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-a*sqrt(f))/(e^(3/4)*f^(3/4)*_
+   sqrt(2))-1/2*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+a*sqrt(f))/_
+   (e^(3/4)*f^(3/4)*sqrt(2))+1/2*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))*_
+   (c*sqrt(e)+a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R          +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (a\|f  - c\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R            +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- a\|f  + c\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|f  + \|e
+--R       (2a\|f  + 2c\|e )atan(----------------)
+--R                                   4+-+
+--R                                   \|e
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|f  - \|e
+--R       (2a\|f  + 2c\|e )atan(----------------)
+--R                                   4+-+
+--R                                   \|e
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +-------------------------------------+
+--R             |     +------------------------+
+--R             |     |   4 2     2 2       4 2
+--R             |     |- a f  + 2a c e f - c e
+--R             |4e f |------------------------  - a c
+--R             |     |            3 3
+--R             |    \|         64e f
+--R             |-------------------------------------
+--R            \|                 2e f
+--R         *
+--R            log
+--R                             +------------------------+
+--R                             |   4 2     2 2       4 2
+--R                         3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                   (16c e f  |------------------------  - 2a e f  + 2a c e f)
+--R                             |            3 3
+--R                            \|         64e f
+--R                *
+--R                    +-------------------------------------+
+--R                    |     +------------------------+
+--R                    |     |   4 2     2 2       4 2
+--R                    |     |- a f  + 2a c e f - c e
+--R                    |4e f |------------------------  - a c
+--R                    |     |            3 3
+--R                    |    \|         64e f
+--R                    |-------------------------------------
+--R                   \|                 2e f
+--R               + 
+--R                   4 2    4 2
+--R                 (a f  - c e )x
+--R     + 
+--R          +---------------------------------------+
+--R          |       +------------------------+
+--R          |       |   4 2     2 2       4 2
+--R          |       |- a f  + 2a c e f - c e
+--R          |- 4e f |------------------------  - a c
+--R          |       |            3 3
+--R          |      \|         64e f
+--R          |---------------------------------------
+--R         \|                  2e f
+--R      *
+--R         log
+--R                          +------------------------+
+--R                          |   4 2     2 2       4 2
+--R                      3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (16c e f  |------------------------  + 2a e f  - 2a c e f)
+--R                          |            3 3
+--R                         \|         64e f
+--R             *
+--R                 +---------------------------------------+
+--R                 |       +------------------------+
+--R                 |       |   4 2     2 2       4 2
+--R                 |       |- a f  + 2a c e f - c e
+--R                 |- 4e f |------------------------  - a c
+--R                 |       |            3 3
+--R                 |      \|         64e f
+--R                 |---------------------------------------
+--R                \|                  2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R     + 
+--R       -
+--R             +---------------------------------------+
+--R             |       +------------------------+
+--R             |       |   4 2     2 2       4 2
+--R             |       |- a f  + 2a c e f - c e
+--R             |- 4e f |------------------------  - a c
+--R             |       |            3 3
+--R             |      \|         64e f
+--R             |---------------------------------------
+--R            \|                  2e f
+--R         *
+--R            log
+--R                               +------------------------+
+--R                               |   4 2     2 2       4 2
+--R                           3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                   (- 16c e f  |------------------------  - 2a e f  + 2a c e f)
+--R                               |            3 3
+--R                              \|         64e f
+--R                *
+--R                    +---------------------------------------+
+--R                    |       +------------------------+
+--R                    |       |   4 2     2 2       4 2
+--R                    |       |- a f  + 2a c e f - c e
+--R                    |- 4e f |------------------------  - a c
+--R                    |       |            3 3
+--R                    |      \|         64e f
+--R                    |---------------------------------------
+--R                   \|                  2e f
+--R               + 
+--R                   4 2    4 2
+--R                 (a f  - c e )x
+--R     + 
+--R          +-------------------------------------+
+--R          |     +------------------------+
+--R          |     |   4 2     2 2       4 2
+--R          |     |- a f  + 2a c e f - c e
+--R          |4e f |------------------------  - a c
+--R          |     |            3 3
+--R          |    \|         64e f
+--R          |-------------------------------------
+--R         \|                 2e f
+--R      *
+--R         log
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                        3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (- 16c e f  |------------------------  + 2a e f  - 2a c e f)
+--R                            |            3 3
+--R                           \|         64e f
+--R             *
+--R                 +-------------------------------------+
+--R                 |     +------------------------+
+--R                 |     |   4 2     2 2       4 2
+--R                 |     |- a f  + 2a c e f - c e
+--R                 |4e f |------------------------  - a c
+--R                 |     |            3 3
+--R                 |    \|         64e f
+--R                 |-------------------------------------
+--R                \|                 2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 460
+
+--S 461 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                             +-------------------------------------+
+--R                             |     +------------------------+
+--R                             |     |   4 2     2 2       4 2
+--R                             |     |- a f  + 2a c e f - c e
+--R                             |4e f |------------------------  - a c
+--R                             |     |            3 3
+--R              +-+4+-+3 4+-+3 |    \|         64e f
+--R            2\|2 \|e   \|f   |-------------------------------------
+--R                            \|                 2e f
+--R         *
+--R            log
+--R                             +------------------------+
+--R                             |   4 2     2 2       4 2
+--R                         3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                   (16c e f  |------------------------  - 2a e f  + 2a c e f)
+--R                             |            3 3
+--R                            \|         64e f
+--R                *
+--R                    +-------------------------------------+
+--R                    |     +------------------------+
+--R                    |     |   4 2     2 2       4 2
+--R                    |     |- a f  + 2a c e f - c e
+--R                    |4e f |------------------------  - a c
+--R                    |     |            3 3
+--R                    |    \|         64e f
+--R                    |-------------------------------------
+--R                   \|                 2e f
+--R               + 
+--R                   4 2    4 2
+--R                 (a f  - c e )x
+--R     + 
+--R                          +---------------------------------------+
+--R                          |       +------------------------+
+--R                          |       |   4 2     2 2       4 2
+--R                          |       |- a f  + 2a c e f - c e
+--R                          |- 4e f |------------------------  - a c
+--R                          |       |            3 3
+--R           +-+4+-+3 4+-+3 |      \|         64e f
+--R         2\|2 \|e   \|f   |---------------------------------------
+--R                         \|                  2e f
+--R      *
+--R         log
+--R                          +------------------------+
+--R                          |   4 2     2 2       4 2
+--R                      3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (16c e f  |------------------------  + 2a e f  - 2a c e f)
+--R                          |            3 3
+--R                         \|         64e f
+--R             *
+--R                 +---------------------------------------+
+--R                 |       +------------------------+
+--R                 |       |   4 2     2 2       4 2
+--R                 |       |- a f  + 2a c e f - c e
+--R                 |- 4e f |------------------------  - a c
+--R                 |       |            3 3
+--R                 |      \|         64e f
+--R                 |---------------------------------------
+--R                \|                  2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R     + 
+--R       -
+--R                             +---------------------------------------+
+--R                             |       +------------------------+
+--R                             |       |   4 2     2 2       4 2
+--R                             |       |- a f  + 2a c e f - c e
+--R                             |- 4e f |------------------------  - a c
+--R                             |       |            3 3
+--R              +-+4+-+3 4+-+3 |      \|         64e f
+--R            2\|2 \|e   \|f   |---------------------------------------
+--R                            \|                  2e f
+--R         *
+--R            log
+--R                               +------------------------+
+--R                               |   4 2     2 2       4 2
+--R                           3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                   (- 16c e f  |------------------------  - 2a e f  + 2a c e f)
+--R                               |            3 3
+--R                              \|         64e f
+--R                *
+--R                    +---------------------------------------+
+--R                    |       +------------------------+
+--R                    |       |   4 2     2 2       4 2
+--R                    |       |- a f  + 2a c e f - c e
+--R                    |- 4e f |------------------------  - a c
+--R                    |       |            3 3
+--R                    |      \|         64e f
+--R                    |---------------------------------------
+--R                   \|                  2e f
+--R               + 
+--R                   4 2    4 2
+--R                 (a f  - c e )x
+--R     + 
+--R                          +-------------------------------------+
+--R                          |     +------------------------+
+--R                          |     |   4 2     2 2       4 2
+--R                          |     |- a f  + 2a c e f - c e
+--R                          |4e f |------------------------  - a c
+--R                          |     |            3 3
+--R           +-+4+-+3 4+-+3 |    \|         64e f
+--R         2\|2 \|e   \|f   |-------------------------------------
+--R                         \|                 2e f
+--R      *
+--R         log
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                        3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (- 16c e f  |------------------------  + 2a e f  - 2a c e f)
+--R                            |            3 3
+--R                           \|         64e f
+--R             *
+--R                 +-------------------------------------+
+--R                 |     +------------------------+
+--R                 |     |   4 2     2 2       4 2
+--R                 |     |- a f  + 2a c e f - c e
+--R                 |4e f |------------------------  - a c
+--R                 |     |            3 3
+--R                 |    \|         64e f
+--R                 |-------------------------------------
+--R                \|                 2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R     + 
+--R            +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- a\|f  + c\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R          +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (a\|f  - c\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|f  + \|e
+--R       (- 2a\|f  - 2c\|e )atan(----------------)
+--R                                     4+-+
+--R                                     \|e
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|f  - \|e
+--R       (- 2a\|f  - 2c\|e )atan(----------------)
+--R                                     4+-+
+--R                                     \|e
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4       2  +-+4+-+2        6         4        2  +-+
+--R           ((4c x  + 4a x )\|e \|e   - a f x  - 2c e x  + a e x )\|f
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2c f x  + 2a f x  + 2c e x  + 2a e)\|e
+--R         + 
+--R                   6         4        2  +-+
+--R           (- c f x  - 2a f x  + c e x )\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R                   4         2       4+-+2
+--R             (a f x  - 2c e x  - a e)\|e
+--R           + 
+--R                     6        4        2        +-+
+--R             (- c f x  - a f x  - c e x  - a e)\|e
+--R      *
+--R          +-+
+--R         \|f
+--R     + 
+--R           4         2        +-+4+-+2      2 6           4           2      2
+--R     (c f x  - 2a f x  - c e)\|e \|e   + a f x  - 3c e f x  - 3a e f x  + c e
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 953
+t0:=(b*x+c*x^2)/(e+f*x^4)
+--R 
+--R
+--R           2
+--R        c x  + b x
+--R   (1)  ----------
+--R            4
+--R         f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 463
+
+--S 464 of 953
+r0:=-1/2*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(1/4)*f^(3/4)*sqrt(2))+_
+   1/2*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(1/4)*f^(3/4)*sqrt(2))+_
+   1/4*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(1/4)*_
+   f^(3/4)*sqrt(2))-1/4*c*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))+1/2*b*atan(x^2*sqrt(f)/_
+   sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R           +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       - c\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R         +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       c\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                        +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R          +-+ +-+     x\|2 \|f  + \|e        +-+ +-+     x\|2 \|f  - \|e
+--R       2c\|e \|f atan(----------------) + 2c\|e \|f atan(----------------)
+--R                            4+-+                               4+-+
+--R                            \|e                                \|e
+--R     + 
+--R                            2 +-+
+--R          +-+4+-+4+-+3     x \|f
+--R       2b\|2 \|e \|f  atan(------)
+--R                             +-+
+--R                            \|e
+--R  /
+--R       +-+ +-+4+-+ +-+4+-+3
+--R     4\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6e f %%BX1  - 4e f %%BX0 %%BX1 - 6e f %%BX0  - b
+--R           -  |---------------------------------------------------  - %%BX1
+--R             \|                        2e f
+--R         + 
+--R           - %%BX0
+--R      *
+--R         log
+--R                     2 2 2           3   2            3   2          2 2
+--R                ((32c e f %%BX0 + 16b e f )%%BX1 + 16b e f %%BX0 + 2b c e f)
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6e f %%BX1  - 4e f %%BX0 %%BX1 - 6e f %%BX0  - b
+--R                 |---------------------------------------------------
+--R                \|                        2e f
+--R            + 
+--R                    2 2 2           3   2      2
+--R              (- 32c e f %%BX0 - 16b e f )%%BX1
+--R            + 
+--R                    2 2 2     2     2 2               3   2     2
+--R              (- 32c e f %%BX0  + 2b c e f)%%BX1 - 16b e f %%BX0
+--R            + 
+--R                2 2               4       5        5       4
+--R              2b c e f %%BX0 + (4b c f - c e)x - 2b f + b c e
+--R     + 
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6e f %%BX1  - 4e f %%BX0 %%BX1 - 6e f %%BX0  - b
+--R              |---------------------------------------------------  - %%BX1
+--R             \|                        2e f
+--R           + 
+--R             - %%BX0
+--R      *
+--R         log
+--R                       2 2 2           3   2            3   2          2 2
+--R                ((- 32c e f %%BX0 - 16b e f )%%BX1 - 16b e f %%BX0 - 2b c e f)
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6e f %%BX1  - 4e f %%BX0 %%BX1 - 6e f %%BX0  - b
+--R                 |---------------------------------------------------
+--R                \|                        2e f
+--R            + 
+--R                    2 2 2           3   2      2
+--R              (- 32c e f %%BX0 - 16b e f )%%BX1
+--R            + 
+--R                    2 2 2     2     2 2               3   2     2
+--R              (- 32c e f %%BX0  + 2b c e f)%%BX1 - 16b e f %%BX0
+--R            + 
+--R                2 2               4       5        5       4
+--R              2b c e f %%BX0 + (4b c f - c e)x - 2b f + b c e
+--R     + 
+--R         2%%BX1
+--R      *
+--R         log
+--R                  2 2 2           3   2      2
+--R              (64c e f %%BX0 + 32b e f )%%BX1
+--R            + 
+--R                  2 2 2     2     2 2               2 2 2     3     2 2
+--R              (64c e f %%BX0  - 4b c e f)%%BX1 + 64c e f %%BX0  + 8b c e f %%BX0
+--R            + 
+--R                 4       5        5       4
+--R              (4b c f - c e)x + 2b f + b c e
+--R     + 
+--R         2%%BX0
+--R      *
+--R         log
+--R                   2 2 2     3      3   2     2      2 2
+--R              - 64c e f %%BX0  + 32b e f %%BX0  - 12b c e f %%BX0
+--R            + 
+--R                 4       5        5        4
+--R              (4b c f - c e)x + 2b f - 3b c e
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 465
+
+--S 466 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                  +-+ +-+4+-+ +-+4+-+3
+--R                2\|2 \|e \|e \|f \|f
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6e f %%BX1  - 4e f %%BX0 %%BX1 - 6e f %%BX0  - b
+--R                 |---------------------------------------------------
+--R                \|                        2e f
+--R         + 
+--R               +-+ +-+4+-+ +-+4+-+3          +-+ +-+4+-+ +-+4+-+3
+--R           - 2\|2 \|e \|e \|f \|f  %%BX1 - 2\|2 \|e \|e \|f \|f  %%BX0
+--R      *
+--R         log
+--R                     2 2 2           3   2            3   2          2 2
+--R                ((32c e f %%BX0 + 16b e f )%%BX1 + 16b e f %%BX0 + 2b c e f)
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6e f %%BX1  - 4e f %%BX0 %%BX1 - 6e f %%BX0  - b
+--R                 |---------------------------------------------------
+--R                \|                        2e f
+--R            + 
+--R                    2 2 2           3   2      2
+--R              (- 32c e f %%BX0 - 16b e f )%%BX1
+--R            + 
+--R                    2 2 2     2     2 2               3   2     2
+--R              (- 32c e f %%BX0  + 2b c e f)%%BX1 - 16b e f %%BX0
+--R            + 
+--R                2 2               4       5        5       4
+--R              2b c e f %%BX0 + (4b c f - c e)x - 2b f + b c e
+--R     + 
+--R               +-+ +-+4+-+ +-+4+-+3
+--R             2\|2 \|e \|e \|f \|f
+--R          *
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6e f %%BX1  - 4e f %%BX0 %%BX1 - 6e f %%BX0  - b
+--R              |---------------------------------------------------
+--R             \|                        2e f
+--R         + 
+--R               +-+ +-+4+-+ +-+4+-+3          +-+ +-+4+-+ +-+4+-+3
+--R           - 2\|2 \|e \|e \|f \|f  %%BX1 - 2\|2 \|e \|e \|f \|f  %%BX0
+--R      *
+--R         log
+--R                       2 2 2           3   2            3   2          2 2
+--R                ((- 32c e f %%BX0 - 16b e f )%%BX1 - 16b e f %%BX0 - 2b c e f)
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6e f %%BX1  - 4e f %%BX0 %%BX1 - 6e f %%BX0  - b
+--R                 |---------------------------------------------------
+--R                \|                        2e f
+--R            + 
+--R                    2 2 2           3   2      2
+--R              (- 32c e f %%BX0 - 16b e f )%%BX1
+--R            + 
+--R                    2 2 2     2     2 2               3   2     2
+--R              (- 32c e f %%BX0  + 2b c e f)%%BX1 - 16b e f %%BX0
+--R            + 
+--R                2 2               4       5        5       4
+--R              2b c e f %%BX0 + (4b c f - c e)x - 2b f + b c e
+--R     + 
+--R           +-+ +-+4+-+ +-+4+-+3
+--R         4\|2 \|e \|e \|f \|f  %%BX1
+--R      *
+--R         log
+--R                  2 2 2           3   2      2
+--R              (64c e f %%BX0 + 32b e f )%%BX1
+--R            + 
+--R                  2 2 2     2     2 2               2 2 2     3     2 2
+--R              (64c e f %%BX0  - 4b c e f)%%BX1 + 64c e f %%BX0  + 8b c e f %%BX0
+--R            + 
+--R                 4       5        5       4
+--R              (4b c f - c e)x + 2b f + b c e
+--R     + 
+--R         +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       c\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       - c\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+ +-+4+-+ +-+4+-+3
+--R         4\|2 \|e \|e \|f \|f  %%BX0
+--R      *
+--R         log
+--R                   2 2 2     3      3   2     2      2 2
+--R              - 64c e f %%BX0  + 32b e f %%BX0  - 12b c e f %%BX0
+--R            + 
+--R                 4       5        5        4
+--R              (4b c f - c e)x + 2b f - 3b c e
+--R     + 
+--R                          +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|f  + \|e        +-+ +-+     x\|2 \|f  - \|e
+--R       - 2c\|e \|f atan(----------------) - 2c\|e \|f atan(----------------)
+--R                              4+-+                               4+-+
+--R                              \|e                                \|e
+--R     + 
+--R                              2 +-+
+--R            +-+4+-+4+-+3     x \|f
+--R       - 2b\|2 \|e \|f  atan(------)
+--R                               +-+
+--R                              \|e
+--R  /
+--R       +-+ +-+4+-+ +-+4+-+3
+--R     4\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            4 +-+4+-+2 +-+         6         2 4+-+2 4+-+2
+--R       (2c x \|e \|e  \|f  + (c f x  + 3c e x )\|e  )\|f
+--R     + 
+--R                6        2 4+-+2         2 +-+  +-+         4        +-+4+-+2
+--R       ((- c f x  - c e x )\|e   - 2c e x \|e )\|f  + (c f x  + c e)\|e \|e
+--R     + 
+--R                 4      2
+--R       - 3c e f x  - c e
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 467
+
+)clear all
+
+--S 468 of 953
+t0:=(a+b*x+c*x^2)/(e+f*x^4)
+--R 
+--R
+--R           2
+--R        c x  + b x + a
+--R   (1)  --------------
+--R              4
+--R           f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 468
+
+--S 469 of 953
+r0:=1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))+1/4*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-a*sqrt(f))/_
+   (e^(3/4)*f^(3/4)*sqrt(2))-1/4*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))*(c*sqrt(e)-a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))-_
+   1/2*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+a*sqrt(f))/_
+   (e^(3/4)*f^(3/4)*sqrt(2))+1/2*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))*_
+   (c*sqrt(e)+a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              +-+       +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- c e\|f  + a f\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R            +-+       +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (c e\|f  - a f\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                   +-+4+-+   4+-+
+--R             +-+        +-+      x\|2 \|f  + \|e
+--R       (2c e\|f  + 2a f\|e )atan(----------------)
+--R                                       4+-+
+--R                                       \|e
+--R     + 
+--R                                 +-+4+-+   4+-+                           2 +-+
+--R           +-+        +-+      x\|2 \|f  - \|e        +-+4+-+3 4+-+3     x \|f
+--R     (2c e\|f  + 2a f\|e )atan(----------------) + 2b\|2 \|e   \|f  atan(------)
+--R                                     4+-+                                  +-+
+--R                                     \|e                                  \|e
+--R  /
+--R       +-+ +-+4+-+3 +-+4+-+3
+--R     4\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +----------------------------------------------------------+
+--R              |            2                                2           2
+--R              |- 6e f %%BY1  - 4e f %%BY0 %%BY1 - 6e f %%BY0  - 2a c - b
+--R           -  |----------------------------------------------------------
+--R             \|                           2e f
+--R         + 
+--R           - %%BY1 - %%BY0
+--R      *
+--R         log
+--R                           2         2  3 3      3 4 2           3   2 3
+--R                      ((32a c - 64a b )e f  - 32c e f )%%BY0 + 8a b e f
+--R                    + 
+--R                              2      3   3 2
+--R                      (24a b c  - 16b c)e f
+--R                 *
+--R                    %%BY1
+--R                + 
+--R                     3   2 3           2      3   3 2           5   3
+--R                  (8a b e f  + (24a b c  - 16b c)e f )%%BY0 - 2a e f
+--R                + 
+--R                       2 2        4  2 2        4     2 3  3
+--R                  (- 6a b c + 4a b )e f  + (2a c  - 2b c )e f
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            2                                2           2
+--R                 |- 6e f %%BY1  - 4e f %%BY0 %%BY1 - 6e f %%BY0  - 2a c - b
+--R                 |----------------------------------------------------------
+--R                \|                           2e f
+--R            + 
+--R                         2         2  3 3      3 4 2           3   2 3
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%BY0 - 8a b e f
+--R                + 
+--R                            2      3   3 2
+--R                  (- 24a b c  + 16b c)e f
+--R             *
+--R                     2
+--R                %%BY1
+--R            + 
+--R                         2         2  3 3      3 4 2      2     5   3
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%BY0  - 2a e f
+--R                + 
+--R                       2 2        4  2 2        4     2 3  3
+--R                  (- 6a b c + 4a b )e f  + (2a c  - 2b c )e f
+--R             *
+--R                %%BY1
+--R            + 
+--R                   3   2 3             2      3   3 2      2
+--R              (- 8a b e f  + (- 24a b c  + 16b c)e f )%%BY0
+--R            + 
+--R                   5   3        2 2        4  2 2        4     2 3  3
+--R              (- 2a e f  + (- 6a b c + 4a b )e f  + (2a c  - 2b c )e f)%%BY0
+--R            + 
+--R                   6 3       4 2     3 2      2 4    2
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2     6 3
+--R                  (- a c  + 8a b c  - 4b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4       3 3    2        2   3      3 2     5   2       5 3
+--R              (- 3a b c + a b )e f  + (- 4a b c  - a b c  + 2b c)e f - b c e
+--R     + 
+--R            +----------------------------------------------------------+
+--R            |            2                                2           2
+--R            |- 6e f %%BY1  - 4e f %%BY0 %%BY1 - 6e f %%BY0  - 2a c - b
+--R            |----------------------------------------------------------  - %%BY1
+--R           \|                           2e f
+--R         + 
+--R           - %%BY0
+--R      *
+--R         log
+--R                             2         2  3 3      3 4 2           3   2 3
+--R                      ((- 32a c + 64a b )e f  + 32c e f )%%BY0 - 8a b e f
+--R                    + 
+--R                                2      3   3 2
+--R                      (- 24a b c  + 16b c)e f
+--R                 *
+--R                    %%BY1
+--R                + 
+--R                       3   2 3             2      3   3 2           5   3
+--R                  (- 8a b e f  + (- 24a b c  + 16b c)e f )%%BY0 + 2a e f
+--R                + 
+--R                     2 2        4  2 2          4     2 3  3
+--R                  (6a b c - 4a b )e f  + (- 2a c  + 2b c )e f
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            2                                2           2
+--R                 |- 6e f %%BY1  - 4e f %%BY0 %%BY1 - 6e f %%BY0  - 2a c - b
+--R                 |----------------------------------------------------------
+--R                \|                           2e f
+--R            + 
+--R                         2         2  3 3      3 4 2           3   2 3
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%BY0 - 8a b e f
+--R                + 
+--R                            2      3   3 2
+--R                  (- 24a b c  + 16b c)e f
+--R             *
+--R                     2
+--R                %%BY1
+--R            + 
+--R                         2         2  3 3      3 4 2      2     5   3
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%BY0  - 2a e f
+--R                + 
+--R                       2 2        4  2 2        4     2 3  3
+--R                  (- 6a b c + 4a b )e f  + (2a c  - 2b c )e f
+--R             *
+--R                %%BY1
+--R            + 
+--R                   3   2 3             2      3   3 2      2
+--R              (- 8a b e f  + (- 24a b c  + 16b c)e f )%%BY0
+--R            + 
+--R                   5   3        2 2        4  2 2        4     2 3  3
+--R              (- 2a e f  + (- 6a b c + 4a b )e f  + (2a c  - 2b c )e f)%%BY0
+--R            + 
+--R                   6 3       4 2     3 2      2 4    2
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2     6 3
+--R                  (- a c  + 8a b c  - 4b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4       3 3    2        2   3      3 2     5   2       5 3
+--R              (- 3a b c + a b )e f  + (- 4a b c  - a b c  + 2b c)e f - b c e
+--R     + 
+--R         2%%BY1
+--R      *
+--R         log
+--R                       2          2  3 3      3 4 2            3   2 3
+--R                  ((64a c - 128a b )e f  - 64c e f )%%BY0 + 16a b e f
+--R                + 
+--R                          2      3   3 2
+--R                  (48a b c  - 32b c)e f
+--R             *
+--R                     2
+--R                %%BY1
+--R            + 
+--R                       2          2  3 3      3 4 2      2     5   3
+--R                  ((64a c - 128a b )e f  - 64c e f )%%BY0  + 4a e f
+--R                + 
+--R                      2 2        4  2 2          4     2 3  3
+--R                  (12a b c - 8a b )e f  + (- 4a c  + 4b c )e f
+--R             *
+--R                %%BY1
+--R            + 
+--R                   2          2  3 3      3 4 2      3
+--R              ((64a c - 128a b )e f  - 64c e f )%%BY0
+--R            + 
+--R                   3 2      2 2         4  2 2           4     2 3  3
+--R              ((16a c  - 24a b c - 16a b )e f  + (- 16a c  - 8b c )e f)%%BY0
+--R            + 
+--R                   6 3       4 2     3 2      2 4    2
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2     6 3
+--R                  (- a c  + 8a b c  - 4b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                4        3 3    2      2   3       3 2     5   2       5 3
+--R              (a b c + 3a b )e f  + (8a b c  - 3a b c  - 2b c)e f - b c e
+--R     + 
+--R         2%%BY0
+--R      *
+--R         log
+--R                     2          2  3 3      3 4 2      3
+--R              ((- 64a c + 128a b )e f  + 64c e f )%%BY0
+--R            + 
+--R                  3   2 3           2      3   3 2      2
+--R              (16a b e f  + (48a b c  - 32b c)e f )%%BY0
+--R            + 
+--R                    5   3         3 2      2 2        4  2 2
+--R                  4a e f  + (- 16a c  + 36a b c + 8a b )e f
+--R                + 
+--R                        4      2 3  3
+--R                  (12a c  + 12b c )e f
+--R             *
+--R                %%BY0
+--R            + 
+--R                   6 3       4 2     3 2      2 4    2
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2     6 3
+--R                  (- a c  + 8a b c  - 4b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                 4        3 3    2        3 2     5   2        5 3
+--R              (5a b c - 5a b )e f  + (5a b c  - 2b c)e f + 3b c e
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 470
+
+--S 471 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                  +-+ +-+4+-+3 +-+4+-+3
+--R                2\|2 \|e \|e  \|f \|f
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            2                                2           2
+--R                 |- 6e f %%BY1  - 4e f %%BY0 %%BY1 - 6e f %%BY0  - 2a c - b
+--R                 |----------------------------------------------------------
+--R                \|                           2e f
+--R         + 
+--R               +-+ +-+4+-+3 +-+4+-+3          +-+ +-+4+-+3 +-+4+-+3
+--R           - 2\|2 \|e \|e  \|f \|f  %%BY1 - 2\|2 \|e \|e  \|f \|f  %%BY0
+--R      *
+--R         log
+--R                           2         2  3 3      3 4 2           3   2 3
+--R                      ((32a c - 64a b )e f  - 32c e f )%%BY0 + 8a b e f
+--R                    + 
+--R                              2      3   3 2
+--R                      (24a b c  - 16b c)e f
+--R                 *
+--R                    %%BY1
+--R                + 
+--R                     3   2 3           2      3   3 2           5   3
+--R                  (8a b e f  + (24a b c  - 16b c)e f )%%BY0 - 2a e f
+--R                + 
+--R                       2 2        4  2 2        4     2 3  3
+--R                  (- 6a b c + 4a b )e f  + (2a c  - 2b c )e f
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            2                                2           2
+--R                 |- 6e f %%BY1  - 4e f %%BY0 %%BY1 - 6e f %%BY0  - 2a c - b
+--R                 |----------------------------------------------------------
+--R                \|                           2e f
+--R            + 
+--R                         2         2  3 3      3 4 2           3   2 3
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%BY0 - 8a b e f
+--R                + 
+--R                            2      3   3 2
+--R                  (- 24a b c  + 16b c)e f
+--R             *
+--R                     2
+--R                %%BY1
+--R            + 
+--R                         2         2  3 3      3 4 2      2     5   3
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%BY0  - 2a e f
+--R                + 
+--R                       2 2        4  2 2        4     2 3  3
+--R                  (- 6a b c + 4a b )e f  + (2a c  - 2b c )e f
+--R             *
+--R                %%BY1
+--R            + 
+--R                   3   2 3             2      3   3 2      2
+--R              (- 8a b e f  + (- 24a b c  + 16b c)e f )%%BY0
+--R            + 
+--R                   5   3        2 2        4  2 2        4     2 3  3
+--R              (- 2a e f  + (- 6a b c + 4a b )e f  + (2a c  - 2b c )e f)%%BY0
+--R            + 
+--R                   6 3       4 2     3 2      2 4    2
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2     6 3
+--R                  (- a c  + 8a b c  - 4b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4       3 3    2        2   3      3 2     5   2       5 3
+--R              (- 3a b c + a b )e f  + (- 4a b c  - a b c  + 2b c)e f - b c e
+--R     + 
+--R               +-+ +-+4+-+3 +-+4+-+3
+--R             2\|2 \|e \|e  \|f \|f
+--R          *
+--R              +----------------------------------------------------------+
+--R              |            2                                2           2
+--R              |- 6e f %%BY1  - 4e f %%BY0 %%BY1 - 6e f %%BY0  - 2a c - b
+--R              |----------------------------------------------------------
+--R             \|                           2e f
+--R         + 
+--R               +-+ +-+4+-+3 +-+4+-+3          +-+ +-+4+-+3 +-+4+-+3
+--R           - 2\|2 \|e \|e  \|f \|f  %%BY1 - 2\|2 \|e \|e  \|f \|f  %%BY0
+--R      *
+--R         log
+--R                             2         2  3 3      3 4 2           3   2 3
+--R                      ((- 32a c + 64a b )e f  + 32c e f )%%BY0 - 8a b e f
+--R                    + 
+--R                                2      3   3 2
+--R                      (- 24a b c  + 16b c)e f
+--R                 *
+--R                    %%BY1
+--R                + 
+--R                       3   2 3             2      3   3 2           5   3
+--R                  (- 8a b e f  + (- 24a b c  + 16b c)e f )%%BY0 + 2a e f
+--R                + 
+--R                     2 2        4  2 2          4     2 3  3
+--R                  (6a b c - 4a b )e f  + (- 2a c  + 2b c )e f
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            2                                2           2
+--R                 |- 6e f %%BY1  - 4e f %%BY0 %%BY1 - 6e f %%BY0  - 2a c - b
+--R                 |----------------------------------------------------------
+--R                \|                           2e f
+--R            + 
+--R                         2         2  3 3      3 4 2           3   2 3
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%BY0 - 8a b e f
+--R                + 
+--R                            2      3   3 2
+--R                  (- 24a b c  + 16b c)e f
+--R             *
+--R                     2
+--R                %%BY1
+--R            + 
+--R                         2         2  3 3      3 4 2      2     5   3
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%BY0  - 2a e f
+--R                + 
+--R                       2 2        4  2 2        4     2 3  3
+--R                  (- 6a b c + 4a b )e f  + (2a c  - 2b c )e f
+--R             *
+--R                %%BY1
+--R            + 
+--R                   3   2 3             2      3   3 2      2
+--R              (- 8a b e f  + (- 24a b c  + 16b c)e f )%%BY0
+--R            + 
+--R                   5   3        2 2        4  2 2        4     2 3  3
+--R              (- 2a e f  + (- 6a b c + 4a b )e f  + (2a c  - 2b c )e f)%%BY0
+--R            + 
+--R                   6 3       4 2     3 2      2 4    2
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2     6 3
+--R                  (- a c  + 8a b c  - 4b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4       3 3    2        2   3      3 2     5   2       5 3
+--R              (- 3a b c + a b )e f  + (- 4a b c  - a b c  + 2b c)e f - b c e
+--R     + 
+--R           +-+ +-+4+-+3 +-+4+-+3
+--R         4\|2 \|e \|e  \|f \|f  %%BY1
+--R      *
+--R         log
+--R                       2          2  3 3      3 4 2            3   2 3
+--R                  ((64a c - 128a b )e f  - 64c e f )%%BY0 + 16a b e f
+--R                + 
+--R                          2      3   3 2
+--R                  (48a b c  - 32b c)e f
+--R             *
+--R                     2
+--R                %%BY1
+--R            + 
+--R                       2          2  3 3      3 4 2      2     5   3
+--R                  ((64a c - 128a b )e f  - 64c e f )%%BY0  + 4a e f
+--R                + 
+--R                      2 2        4  2 2          4     2 3  3
+--R                  (12a b c - 8a b )e f  + (- 4a c  + 4b c )e f
+--R             *
+--R                %%BY1
+--R            + 
+--R                   2          2  3 3      3 4 2      3
+--R              ((64a c - 128a b )e f  - 64c e f )%%BY0
+--R            + 
+--R                   3 2      2 2         4  2 2           4     2 3  3
+--R              ((16a c  - 24a b c - 16a b )e f  + (- 16a c  - 8b c )e f)%%BY0
+--R            + 
+--R                   6 3       4 2     3 2      2 4    2
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2     6 3
+--R                  (- a c  + 8a b c  - 4b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                4        3 3    2      2   3       3 2     5   2       5 3
+--R              (a b c + 3a b )e f  + (8a b c  - 3a b c  - 2b c)e f - b c e
+--R     + 
+--R            +-+       +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (c e\|f  - a f\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              +-+       +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- c e\|f  + a f\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+ +-+4+-+3 +-+4+-+3
+--R         4\|2 \|e \|e  \|f \|f  %%BY0
+--R      *
+--R         log
+--R                     2          2  3 3      3 4 2      3
+--R              ((- 64a c + 128a b )e f  + 64c e f )%%BY0
+--R            + 
+--R                  3   2 3           2      3   3 2      2
+--R              (16a b e f  + (48a b c  - 32b c)e f )%%BY0
+--R            + 
+--R                    5   3         3 2      2 2        4  2 2
+--R                  4a e f  + (- 16a c  + 36a b c + 8a b )e f
+--R                + 
+--R                        4      2 3  3
+--R                  (12a c  + 12b c )e f
+--R             *
+--R                %%BY0
+--R            + 
+--R                   6 3       4 2     3 2      2 4    2
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2     6 3
+--R                  (- a c  + 8a b c  - 4b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                 4        3 3    2        3 2     5   2        5 3
+--R              (5a b c - 5a b )e f  + (5a b c  - 2b c)e f + 3b c e
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|f  + \|e
+--R       (- 2c e\|f  - 2a f\|e )atan(----------------)
+--R                                         4+-+
+--R                                         \|e
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|f  - \|e
+--R       (- 2c e\|f  - 2a f\|e )atan(----------------)
+--R                                         4+-+
+--R                                         \|e
+--R     + 
+--R                                2 +-+
+--R            +-+4+-+3 4+-+3     x \|f
+--R       - 2b\|2 \|e   \|f  atan(------)
+--R                                 +-+
+--R                                \|e
+--R  /
+--R       +-+ +-+4+-+3 +-+4+-+3
+--R     4\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4       2  +-+4+-+2        6         4        2  +-+
+--R           ((4c x  + 4a x )\|e \|e   - a f x  - 2c e x  + a e x )\|f
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2c f x  + 2a f x  + 2c e x  + 2a e)\|e
+--R         + 
+--R                   6         4        2  +-+
+--R           (- c f x  - 2a f x  + c e x )\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R                   4         2       4+-+2
+--R             (a f x  - 2c e x  - a e)\|e
+--R           + 
+--R                     6        4        2        +-+
+--R             (- c f x  - a f x  - c e x  - a e)\|e
+--R      *
+--R          +-+
+--R         \|f
+--R     + 
+--R           4         2        +-+4+-+2      2 6           4           2      2
+--R     (c f x  - 2a f x  - c e)\|e \|e   + a f x  - 3c e f x  - 3a e f x  + c e
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+)clear all
+
+--S 473 of 953
+t0:=d*x^3/(e+f*x^4)
+--R 
+--R
+--R             3
+--R          d x
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 473
+
+--S 474 of 953
+r0:=1/4*d*log(e+f*x^4)/f
+--R 
+--R
+--R                 4
+--R        d log(f x  + e)
+--R   (2)  ---------------
+--R               4f
+--R                                                    Type: Expression(Integer)
+--E 474
+
+--S 475 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 4
+--R        d log(f x  + e)
+--R   (3)  ---------------
+--R               4f
+--R                                         Type: Union(Expression(Integer),...)
+--E 475
+
+--S 476 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 953
+t0:=(a+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3
+--R        d x  + a
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 478
+
+--S 479 of 953
+r0:=1/4*d*log(e+f*x^4)/f-1/2*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(3/4)*f^(1/4)*sqrt(2))+1/2*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(3/4)*f^(1/4)*sqrt(2))-1/4*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))+1/4*a*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R       a f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                                +-+4+-+   4+-+
+--R                     +-+4+-+4+-+    2 +-+    +-+              x\|2 \|f  + \|e
+--R       - a f log(- x\|2 \|e \|f  + x \|f  + \|e ) + 2a f atan(----------------)
+--R                                                                    4+-+
+--R                                                                    \|e
+--R     + 
+--R                   +-+4+-+   4+-+
+--R                 x\|2 \|f  - \|e       +-+       4     4+-+3 4+-+
+--R       2a f atan(----------------) + d\|2 log(f x  + e)\|e   \|f
+--R                       4+-+
+--R                       \|e
+--R  /
+--R        +-+4+-+3 4+-+
+--R     4f\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +-----------+            +-----------+
+--R           |  +-------+             |  +-------+
+--R           |  |     4               |  |     4
+--R           |  |    a                |  |    a
+--R       (2f |2 |- -----   + d)log(2e |2 |- -----   + a x)
+--R           |  |     3               |  |     3
+--R          \| \|  64e f             \| \|  64e f
+--R     + 
+--R             +-----------+              +-----------+
+--R             |  +-------+               |  +-------+
+--R             |  |     4                 |  |     4
+--R             |  |    a                  |  |    a
+--R       (- 2f |2 |- -----   + d)log(- 2e |2 |- -----   + a x)
+--R             |  |     3                 |  |     3
+--R            \| \|  64e f               \| \|  64e f
+--R     + 
+--R                                 +-----------+
+--R                                 |  +-------+
+--R                                 |  |     4
+--R            +-----------+        |  |    a
+--R            |  +-------+      2e |2 |- -----                +-------+
+--R            |  |     4           |  |     3                 |     4
+--R            |  |    a           \| \|  64e f              2 |    a       2 2
+--R       - 4f |2 |- -----  atan(----------------) + d log(8e  |- -----  + a x )
+--R            |  |     3               a x                    |     3
+--R           \| \|  64e f                                    \|  64e f
+--R  /
+--R     4f
+--R                                         Type: Union(Expression(Integer),...)
+--E 480
+
+--S 481 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           +-----------+
+--R                           |  +-------+
+--R                           |  |     4
+--R             +-+4+-+3 4+-+ |  |    a        +-+4+-+3 4+-+
+--R         (2f\|2 \|e   \|f  |2 |- -----  + d\|2 \|e   \|f)
+--R                           |  |     3
+--R                          \| \|  64e f
+--R      *
+--R                +-----------+
+--R                |  +-------+
+--R                |  |     4
+--R                |  |    a
+--R         log(2e |2 |- -----   + a x)
+--R                |  |     3
+--R               \| \|  64e f
+--R     + 
+--R                             +-----------+
+--R                             |  +-------+
+--R                             |  |     4
+--R               +-+4+-+3 4+-+ |  |    a        +-+4+-+3 4+-+
+--R         (- 2f\|2 \|e   \|f  |2 |- -----  + d\|2 \|e   \|f)
+--R                             |  |     3
+--R                            \| \|  64e f
+--R      *
+--R                  +-----------+
+--R                  |  +-------+
+--R                  |  |     4
+--R                  |  |    a
+--R         log(- 2e |2 |- -----   + a x)
+--R                  |  |     3
+--R                 \| \|  64e f
+--R     + 
+--R                                               +-----------+
+--R                                               |  +-------+
+--R                                               |  |     4
+--R                          +-----------+        |  |    a
+--R                          |  +-------+      2e |2 |- -----
+--R                          |  |     4           |  |     3
+--R            +-+4+-+3 4+-+ |  |    a           \| \|  64e f
+--R       - 4f\|2 \|e   \|f  |2 |- -----  atan(----------------)
+--R                          |  |     3               a x
+--R                         \| \|  64e f
+--R     + 
+--R                   +-+4+-+4+-+    2 +-+    +-+
+--R       - a f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                              +-------+
+--R                              |     4
+--R         +-+4+-+3 4+-+      2 |    a       2 2
+--R       d\|2 \|e   \|f log(8e  |- -----  + a x )
+--R                              |     3
+--R                             \|  64e f
+--R     + 
+--R                                                              +-+4+-+   4+-+
+--R                   +-+4+-+4+-+    2 +-+    +-+              x\|2 \|f  + \|e
+--R       a f log(- x\|2 \|e \|f  + x \|f  + \|e ) - 2a f atan(----------------)
+--R                                                                  4+-+
+--R                                                                  \|e
+--R     + 
+--R                     +-+4+-+   4+-+
+--R                   x\|2 \|f  - \|e       +-+       4     4+-+3 4+-+
+--R       - 2a f atan(----------------) - d\|2 log(f x  + e)\|e   \|f
+--R                         4+-+
+--R                         \|e
+--R  /
+--R        +-+4+-+3 4+-+
+--R     4f\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                2 +-+4+-+2        6        2  +-+          4       4+-+2
+--R           (2a x \|e \|e   + a f x  + a e x )\|f  + (3a f x  + a e)\|e
+--R         + 
+--R                   4        +-+
+--R           (- a f x  - a e)\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R               4 +-+ +-+      2 6           2
+--R       - 2a f x \|e \|f  - a f x  - 3a e f x
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 482
+
+)clear all
+
+--S 483 of 953
+t0:=(b*x+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3
+--R        d x  + b x
+--R   (1)  ----------
+--R            4
+--R         f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 483
+
+--S 484 of 953
+r0:=1/4*d*log(e+f*x^4)/f+1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R                   2 +-+
+--R                  x \|f              4      +-+ +-+
+--R        2b f atan(------) + d log(f x  + e)\|e \|f
+--R                    +-+
+--R                   \|e
+--R   (2)  -------------------------------------------
+--R                            +-+ +-+
+--R                         4f\|e \|f
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4      +-----+         2
+--R            (f x  - e)\|- e f  + 2e f x              4      +-----+
+--R    b f log(----------------------------) + d log(f x  + e)\|- e f
+--R                         4
+--R                      f x  + e
+--R   [---------------------------------------------------------------,
+--R                                  +-----+
+--R                               4f\|- e f
+--R               2 +---+
+--R              x \|e f              4      +---+
+--R    2b f atan(--------) + d log(f x  + e)\|e f
+--R                  e
+--R    -------------------------------------------]
+--R                         +---+
+--R                      4f\|e f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 485
+
+--S 486 of 953
+m0a:=a0.1-r0
+--R 
+--R
+--R                         4      +-----+         2                    2 +-+
+--R          +-+ +-+    (f x  - e)\|- e f  + 2e f x        +-----+     x \|f
+--R        b\|e \|f log(----------------------------) - 2b\|- e f atan(------)
+--R                                  4                                   +-+
+--R                               f x  + e                              \|e
+--R   (4)  -------------------------------------------------------------------
+--R                                   +-----+ +-+ +-+
+--R                                 4\|- e f \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 953
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 953
+m0b:=a0.2-r0
+--R 
+--R
+--R                       2 +---+                 2 +-+
+--R          +-+ +-+     x \|e f       +---+     x \|f
+--R        b\|e \|f atan(--------) - b\|e f atan(------)
+--R                          e                     +-+
+--R                                               \|e
+--R   (6)  ---------------------------------------------
+--R                         +-+ +-+ +---+
+--R                       2\|e \|f \|e f
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 953
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 953
+t0:=(a+b*x+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3
+--R        d x  + b x + a
+--R   (1)  --------------
+--R              4
+--R           f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 490
+
+--S 491 of 953
+r0:=1/4*d*log(e+f*x^4)/f-1/2*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(3/4)*f^(1/4)*sqrt(2))+1/2*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(3/4)*f^(1/4)*sqrt(2))-1/4*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))+1/4*a*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))+_
+   1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R           +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       a f\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       - a f\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                          +-+4+-+   4+-+                       +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|f  + \|e          +-+ +-+     x\|2 \|f  - \|e
+--R       2a f\|e \|f atan(----------------) + 2a f\|e \|f atan(----------------)
+--R                              4+-+                                 4+-+
+--R                              \|e                                  \|e
+--R     + 
+--R                               2 +-+
+--R            +-+4+-+3 4+-+     x \|f      +-+       4      +-+4+-+3 +-+4+-+
+--R       2b f\|2 \|e   \|f atan(------ + d\|2 log(f x  + e)\|e \|e  \|f \|f
+--R                                +-+
+--R                               \|e
+--R  /
+--R        +-+ +-+4+-+3 +-+4+-+
+--R     4f\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             f
+--R          *
+--R             ROOT
+--R                          2     2          2                           2     2
+--R                    - 6e f %%CA1  + (- 4e f %%CA0 + 4d e f)%%CA1 - 6e f %%CA0
+--R                  + 
+--R                                    2     2
+--R                    4d e f %%CA0 - b f - d e
+--R               /
+--R                      2
+--R                  2e f
+--R         + 
+--R           - f %%CA1 - f %%CA0 + d
+--R      *
+--R         log
+--R                      2 3 3          2   2 3      2   3 2
+--R                  (64b e f %%CA0 - 8a b e f  - 16b d e f )%%CA1
+--R                + 
+--R                       2   2 3      2   3 2           4   3      2        4  2 2
+--R                  (- 8a b e f  - 16b d e f )%%CA0 + 2a e f  + (4a b d - 4b )e f
+--R                + 
+--R                    2 2 3
+--R                  4b d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CA1  + (- 4e f %%CA0 + 4d e f)%%CA1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CA0  + 4d e f %%CA0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                  2 3 3          2   2 3      2   3 2      2
+--R              (64b e f %%CA0 - 8a b e f  - 16b d e f )%%CA1
+--R            + 
+--R                     2 3 3     2      2   3 2          4   3
+--R                  64b e f %%CA0  - 64b d e f %%CA0 - 2a e f
+--R                + 
+--R                     2        4  2 2      2 2 3
+--R                  (4a b d + 4b )e f  + 12b d e f
+--R             *
+--R                %%CA1
+--R            + 
+--R                   2   2 3      2   3 2      2
+--R              (- 8a b e f  - 16b d e f )%%CA0
+--R            + 
+--R                   4   3      2        4  2 2      2 2 3
+--R              (- 2a e f  + (4a b d + 4b )e f  + 12b d e f)%%CA0
+--R            + 
+--R                5 3       4   2       4     2 3    2       2   2     4   2
+--R              (a f  - 4a b e f )x + (a d + a b )e f  + (- a b d  - 2b d)e f
+--R            + 
+--R                  2 3 3
+--R              - 2b d e
+--R     + 
+--R           -
+--R                f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CA1  + (- 4e f %%CA0 + 4d e f)%%CA1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CA0  + 4d e f %%CA0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R         + 
+--R           - f %%CA1 - f %%CA0 + d
+--R      *
+--R         log
+--R                        2 3 3          2   2 3      2   3 2
+--R                  (- 64b e f %%CA0 + 8a b e f  + 16b d e f )%%CA1
+--R                + 
+--R                     2   2 3      2   3 2           4   3        2        4  2 2
+--R                  (8a b e f  + 16b d e f )%%CA0 - 2a e f  + (- 4a b d + 4b )e f
+--R                + 
+--R                      2 2 3
+--R                  - 4b d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CA1  + (- 4e f %%CA0 + 4d e f)%%CA1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CA0  + 4d e f %%CA0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                  2 3 3          2   2 3      2   3 2      2
+--R              (64b e f %%CA0 - 8a b e f  - 16b d e f )%%CA1
+--R            + 
+--R                     2 3 3     2      2   3 2          4   3
+--R                  64b e f %%CA0  - 64b d e f %%CA0 - 2a e f
+--R                + 
+--R                     2        4  2 2      2 2 3
+--R                  (4a b d + 4b )e f  + 12b d e f
+--R             *
+--R                %%CA1
+--R            + 
+--R                   2   2 3      2   3 2      2
+--R              (- 8a b e f  - 16b d e f )%%CA0
+--R            + 
+--R                   4   3      2        4  2 2      2 2 3
+--R              (- 2a e f  + (4a b d + 4b )e f  + 12b d e f)%%CA0
+--R            + 
+--R                5 3       4   2       4     2 3    2       2   2     4   2
+--R              (a f  - 4a b e f )x + (a d + a b )e f  + (- a b d  - 2b d)e f
+--R            + 
+--R                  2 3 3
+--R              - 2b d e
+--R     + 
+--R         2f %%CA1
+--R      *
+--R         log
+--R                     2 3 3           2   2 3      2   3 2      2
+--R              (- 128b e f %%CA0 + 16a b e f  + 32b d e f )%%CA1
+--R            + 
+--R                        2 3 3     2       2   3 2          4   3
+--R                  - 128b e f %%CA0  + 128b d e f %%CA0 + 4a e f
+--R                + 
+--R                       2        4  2 2      2 2 3
+--R                  (- 8a b d - 8b )e f  - 24b d e f
+--R             *
+--R                %%CA1
+--R            + 
+--R                    2 3 3     3       2   3 2     2
+--R              - 128b e f %%CA0  + 128b d e f %%CA0
+--R            + 
+--R                    4 2 2      2 2 3            5 3       4   2
+--R              (- 16b e f  - 48b d e f)%%CA0 + (a f  - 4a b e f )x
+--R            + 
+--R                  4      2 3    2     2   2     4   2      2 3 3
+--R              (- a d + 3a b )e f  + (a b d  + 6b d)e f + 6b d e
+--R     + 
+--R         2f %%CA0
+--R      *
+--R         log
+--R                  2 3 3     3       2   2 3      2   3 2      2
+--R              128b e f %%CA0  + (16a b e f  - 96b d e f )%%CA0
+--R            + 
+--R                 4   3        2        4  2 2      2 2 3
+--R              (4a e f  + (- 8a b d + 8b )e f  + 24b d e f)%%CA0
+--R            + 
+--R                5 3       4   2         4      2 3    2     2   2     4   2
+--R              (a f  - 4a b e f )x + (- a d - 5a b )e f  + (a b d  - 2b d)e f
+--R            + 
+--R                  2 3 3
+--R              - 2b d e
+--R  /
+--R     2f
+--R                                         Type: Union(Expression(Integer),...)
+--E 492
+
+--S 493 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+ +-+4+-+3 +-+4+-+
+--R             2f\|2 \|e \|e  \|f \|f
+--R          *
+--R             ROOT
+--R                          2     2          2                           2     2
+--R                    - 6e f %%CA1  + (- 4e f %%CA0 + 4d e f)%%CA1 - 6e f %%CA0
+--R                  + 
+--R                                    2     2
+--R                    4d e f %%CA0 - b f - d e
+--R               /
+--R                      2
+--R                  2e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+           +-+ +-+4+-+3 +-+4+-+
+--R           - 2f\|2 \|e \|e  \|f \|f %%CA1 - 2f\|2 \|e \|e  \|f \|f %%CA0
+--R         + 
+--R              +-+ +-+4+-+3 +-+4+-+
+--R           2d\|2 \|e \|e  \|f \|f
+--R      *
+--R         log
+--R                      2 3 3          2   2 3      2   3 2
+--R                  (64b e f %%CA0 - 8a b e f  - 16b d e f )%%CA1
+--R                + 
+--R                       2   2 3      2   3 2           4   3      2        4  2 2
+--R                  (- 8a b e f  - 16b d e f )%%CA0 + 2a e f  + (4a b d - 4b )e f
+--R                + 
+--R                    2 2 3
+--R                  4b d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CA1  + (- 4e f %%CA0 + 4d e f)%%CA1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CA0  + 4d e f %%CA0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                  2 3 3          2   2 3      2   3 2      2
+--R              (64b e f %%CA0 - 8a b e f  - 16b d e f )%%CA1
+--R            + 
+--R                     2 3 3     2      2   3 2          4   3
+--R                  64b e f %%CA0  - 64b d e f %%CA0 - 2a e f
+--R                + 
+--R                     2        4  2 2      2 2 3
+--R                  (4a b d + 4b )e f  + 12b d e f
+--R             *
+--R                %%CA1
+--R            + 
+--R                   2   2 3      2   3 2      2
+--R              (- 8a b e f  - 16b d e f )%%CA0
+--R            + 
+--R                   4   3      2        4  2 2      2 2 3
+--R              (- 2a e f  + (4a b d + 4b )e f  + 12b d e f)%%CA0
+--R            + 
+--R                5 3       4   2       4     2 3    2       2   2     4   2
+--R              (a f  - 4a b e f )x + (a d + a b )e f  + (- a b d  - 2b d)e f
+--R            + 
+--R                  2 3 3
+--R              - 2b d e
+--R     + 
+--R           -
+--R                   +-+ +-+4+-+3 +-+4+-+
+--R                2f\|2 \|e \|e  \|f \|f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CA1  + (- 4e f %%CA0 + 4d e f)%%CA1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CA0  + 4d e f %%CA0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+           +-+ +-+4+-+3 +-+4+-+
+--R           - 2f\|2 \|e \|e  \|f \|f %%CA1 - 2f\|2 \|e \|e  \|f \|f %%CA0
+--R         + 
+--R              +-+ +-+4+-+3 +-+4+-+
+--R           2d\|2 \|e \|e  \|f \|f
+--R      *
+--R         log
+--R                        2 3 3          2   2 3      2   3 2
+--R                  (- 64b e f %%CA0 + 8a b e f  + 16b d e f )%%CA1
+--R                + 
+--R                     2   2 3      2   3 2           4   3        2        4  2 2
+--R                  (8a b e f  + 16b d e f )%%CA0 - 2a e f  + (- 4a b d + 4b )e f
+--R                + 
+--R                      2 2 3
+--R                  - 4b d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CA1  + (- 4e f %%CA0 + 4d e f)%%CA1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CA0  + 4d e f %%CA0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                  2 3 3          2   2 3      2   3 2      2
+--R              (64b e f %%CA0 - 8a b e f  - 16b d e f )%%CA1
+--R            + 
+--R                     2 3 3     2      2   3 2          4   3
+--R                  64b e f %%CA0  - 64b d e f %%CA0 - 2a e f
+--R                + 
+--R                     2        4  2 2      2 2 3
+--R                  (4a b d + 4b )e f  + 12b d e f
+--R             *
+--R                %%CA1
+--R            + 
+--R                   2   2 3      2   3 2      2
+--R              (- 8a b e f  - 16b d e f )%%CA0
+--R            + 
+--R                   4   3      2        4  2 2      2 2 3
+--R              (- 2a e f  + (4a b d + 4b )e f  + 12b d e f)%%CA0
+--R            + 
+--R                5 3       4   2       4     2 3    2       2   2     4   2
+--R              (a f  - 4a b e f )x + (a d + a b )e f  + (- a b d  - 2b d)e f
+--R            + 
+--R                  2 3 3
+--R              - 2b d e
+--R     + 
+--R            +-+ +-+4+-+3 +-+4+-+
+--R         4f\|2 \|e \|e  \|f \|f %%CA1
+--R      *
+--R         log
+--R                     2 3 3           2   2 3      2   3 2      2
+--R              (- 128b e f %%CA0 + 16a b e f  + 32b d e f )%%CA1
+--R            + 
+--R                        2 3 3     2       2   3 2          4   3
+--R                  - 128b e f %%CA0  + 128b d e f %%CA0 + 4a e f
+--R                + 
+--R                       2        4  2 2      2 2 3
+--R                  (- 8a b d - 8b )e f  - 24b d e f
+--R             *
+--R                %%CA1
+--R            + 
+--R                    2 3 3     3       2   3 2     2
+--R              - 128b e f %%CA0  + 128b d e f %%CA0
+--R            + 
+--R                    4 2 2      2 2 3            5 3       4   2
+--R              (- 16b e f  - 48b d e f)%%CA0 + (a f  - 4a b e f )x
+--R            + 
+--R                  4      2 3    2     2   2     4   2      2 3 3
+--R              (- a d + 3a b )e f  + (a b d  + 6b d)e f + 6b d e
+--R     + 
+--R            +-+ +-+4+-+3 +-+4+-+
+--R         4f\|2 \|e \|e  \|f \|f %%CA0
+--R      *
+--R         log
+--R                  2 3 3     3       2   2 3      2   3 2      2
+--R              128b e f %%CA0  + (16a b e f  - 96b d e f )%%CA0
+--R            + 
+--R                 4   3        2        4  2 2      2 2 3
+--R              (4a e f  + (- 8a b d + 8b )e f  + 24b d e f)%%CA0
+--R            + 
+--R                5 3       4   2         4      2 3    2     2   2     4   2
+--R              (a f  - 4a b e f )x + (- a d - 5a b )e f  + (a b d  - 2b d)e f
+--R            + 
+--R                  2 3 3
+--R              - 2b d e
+--R     + 
+--R             +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       - a f\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       a f\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                            +-+4+-+   4+-+                       +-+4+-+   4+-+
+--R              +-+ +-+     x\|2 \|f  + \|e          +-+ +-+     x\|2 \|f  - \|e
+--R       - 2a f\|e \|f atan(----------------) - 2a f\|e \|f atan(----------------)
+--R                                4+-+                                 4+-+
+--R                                \|e                                  \|e
+--R     + 
+--R                                 2 +-+
+--R              +-+4+-+3 4+-+     x \|f      +-+       4      +-+4+-+3 +-+4+-+
+--R       - 2b f\|2 \|e   \|f atan(------ - d\|2 log(f x  + e)\|e \|e  \|f \|f
+--R                                  +-+
+--R                                 \|e
+--R  /
+--R        +-+ +-+4+-+3 +-+4+-+
+--R     4f\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                2 +-+4+-+2        6        2  +-+          4       4+-+2
+--R           (2a x \|e \|e   + a f x  + a e x )\|f  + (3a f x  + a e)\|e
+--R         + 
+--R                   4        +-+
+--R           (- a f x  - a e)\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R               4 +-+ +-+      2 6           2
+--R       - 2a f x \|e \|f  - a f x  - 3a e f x
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 494
+
+)clear all
+
+--S 495 of 953
+t0:=(c*x^2+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x
+--R   (1)  -----------
+--R             4
+--R          f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 495
+
+--S 496 of 953
+r0:=1/4*d*log(e+f*x^4)/f-1/2*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(1/4)*f^(3/4)*sqrt(2))+1/2*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(1/4)*f^(3/4)*sqrt(2))+1/4*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))-1/4*c*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   +-+4+-+4+-+    2 +-+    +-+
+--R       - c f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                              +-+4+-+   4+-+
+--R                   +-+4+-+4+-+    2 +-+    +-+              x\|2 \|f  + \|e
+--R       c f log(- x\|2 \|e \|f  + x \|f  + \|e ) + 2c f atan(----------------)
+--R                                                                  4+-+
+--R                                                                  \|e
+--R     + 
+--R                   +-+4+-+   4+-+
+--R                 x\|2 \|f  - \|e       +-+       4     4+-+4+-+3
+--R       2c f atan(----------------) + d\|2 log(f x  + e)\|e \|f
+--R                       4+-+
+--R                       \|e
+--R  /
+--R        +-+4+-+4+-+3
+--R     4f\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +------------+                           +------------+
+--R           |  +--------+                 +--------+ |  +--------+
+--R           |  |     4                    |     4    |  |     4
+--R           |  |    c                   2 |    c     |  |    c         3
+--R       (2f |2 |- ------   + d)log(16e f  |- ------  |2 |- ------   + c x)
+--R           |  |       3                  |       3  |  |       3
+--R          \| \|  64e f                  \|  64e f  \| \|  64e f
+--R     + 
+--R             +------------+                             +------------+
+--R             |  +--------+                   +--------+ |  +--------+
+--R             |  |     4                      |     4    |  |     4
+--R             |  |    c                     2 |    c     |  |    c         3
+--R       (- 2f |2 |- ------   + d)log(- 16e f  |- ------  |2 |- ------   + c x)
+--R             |  |       3                    |       3  |  |       3
+--R            \| \|  64e f                    \|  64e f  \| \|  64e f
+--R     + 
+--R                                               +------------+
+--R                                    +--------+ |  +--------+
+--R                                    |     4    |  |     4
+--R          +------------+          2 |    c     |  |    c
+--R          |  +--------+      16e f  |- ------  |2 |- ------
+--R          |  |     4                |       3  |  |       3
+--R          |  |    c                \|  64e f  \| \|  64e f
+--R       4f |2 |- ------  atan(--------------------------------)
+--R          |  |       3                       3
+--R         \| \|  64e f                       c x
+--R     + 
+--R                    +--------+
+--R                    |     4
+--R                    |    c        2 2
+--R       d log(- 8e f |- ------  + c x )
+--R                    |       3
+--R                   \|  64e f
+--R  /
+--R     4f
+--R                                         Type: Union(Expression(Integer),...)
+--E 497
+
+--S 498 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +------------+
+--R                          |  +--------+
+--R                          |  |     4
+--R             +-+4+-+4+-+3 |  |    c          +-+4+-+4+-+3
+--R         (2f\|2 \|e \|f   |2 |- ------   + d\|2 \|e \|f  )
+--R                          |  |       3
+--R                         \| \|  64e f
+--R      *
+--R                               +------------+
+--R                    +--------+ |  +--------+
+--R                    |     4    |  |     4
+--R                  2 |    c     |  |    c         3
+--R         log(16e f  |- ------  |2 |- ------   + c x)
+--R                    |       3  |  |       3
+--R                   \|  64e f  \| \|  64e f
+--R     + 
+--R                            +------------+
+--R                            |  +--------+
+--R                            |  |     4
+--R               +-+4+-+4+-+3 |  |    c          +-+4+-+4+-+3
+--R         (- 2f\|2 \|e \|f   |2 |- ------   + d\|2 \|e \|f  )
+--R                            |  |       3
+--R                           \| \|  64e f
+--R      *
+--R                                 +------------+
+--R                      +--------+ |  +--------+
+--R                      |     4    |  |     4
+--R                    2 |    c     |  |    c         3
+--R         log(- 16e f  |- ------  |2 |- ------   + c x)
+--R                      |       3  |  |       3
+--R                     \|  64e f  \| \|  64e f
+--R     + 
+--R                                                            +------------+
+--R                                                 +--------+ |  +--------+
+--R                                                 |     4    |  |     4
+--R                       +------------+          2 |    c     |  |    c
+--R                       |  +--------+      16e f  |- ------  |2 |- ------
+--R                       |  |     4                |       3  |  |       3
+--R          +-+4+-+4+-+3 |  |    c                \|  64e f  \| \|  64e f
+--R       4f\|2 \|e \|f   |2 |- ------  atan(--------------------------------)
+--R                       |  |       3                       3
+--R                      \| \|  64e f                       c x
+--R     + 
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R       c f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                +--------+
+--R                                |     4
+--R         +-+4+-+4+-+3           |    c        2 2
+--R       d\|2 \|e \|f  log(- 8e f |- ------  + c x )
+--R                                |       3
+--R                               \|  64e f
+--R     + 
+--R                                                                +-+4+-+   4+-+
+--R                     +-+4+-+4+-+    2 +-+    +-+              x\|2 \|f  + \|e
+--R       - c f log(- x\|2 \|e \|f  + x \|f  + \|e ) - 2c f atan(----------------)
+--R                                                                    4+-+
+--R                                                                    \|e
+--R     + 
+--R                     +-+4+-+   4+-+
+--R                   x\|2 \|f  - \|e       +-+       4     4+-+4+-+3
+--R       - 2c f atan(----------------) - d\|2 log(f x  + e)\|e \|f
+--R                         4+-+
+--R                         \|e
+--R  /
+--R        +-+4+-+4+-+3
+--R     4f\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            4 +-+4+-+2 +-+         6         2 4+-+2 4+-+2
+--R       (2c x \|e \|e  \|f  + (c f x  + 3c e x )\|e  )\|f
+--R     + 
+--R                6        2 4+-+2         2 +-+  +-+         4        +-+4+-+2
+--R       ((- c f x  - c e x )\|e   - 2c e x \|e )\|f  + (c f x  + c e)\|e \|e
+--R     + 
+--R                 4      2
+--R       - 3c e f x  - c e
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 499
+
+)clear all
+
+--S 500 of 953
+t0:=(a+c*x^2+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + a
+--R   (1)  ---------------
+--R               4
+--R            f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 500
+
+--S 501 of 953
+r0:=1/4*d*log(e+f*x^4)/f+1/4*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))*(c*sqrt(e)-a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))-_
+   1/4*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-_
+   a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))-1/2*atan(1-f^(1/4)*x*_
+   sqrt(2)/e^(1/4))*(c*sqrt(e)+a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))+_
+   1/2*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+a*sqrt(f))/_
+   (e^(3/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            +-+       +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (a f\|f  - c f\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              +-+       +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- a f\|f  + c f\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                   +-+4+-+   4+-+
+--R             +-+        +-+      x\|2 \|f  + \|e
+--R       (2a f\|f  + 2c f\|e )atan(----------------)
+--R                                       4+-+
+--R                                       \|e
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R           +-+        +-+      x\|2 \|f  - \|e       +-+       4     4+-+3 4+-+3
+--R     (2a f\|f  + 2c f\|e )atan(----------------) + d\|2 log(f x  + e)\|e   \|f
+--R                                     4+-+
+--R                                     \|e
+--R  /
+--R        +-+4+-+3 4+-+3
+--R     4f\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +-------------------------------------+
+--R               |     +------------------------+
+--R               |     |   4 2     2 2       4 2
+--R               |     |- a f  + 2a c e f - c e
+--R               |4e f |------------------------  - a c
+--R               |     |            3 3
+--R               |    \|         64e f
+--R         (- 2f |-------------------------------------  + d)
+--R              \|                 2e f
+--R      *
+--R         log
+--R                          +------------------------+
+--R                          |   4 2     2 2       4 2
+--R                      3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (16c e f  |------------------------  - 2a e f  + 2a c e f)
+--R                          |            3 3
+--R                         \|         64e f
+--R             *
+--R                 +-------------------------------------+
+--R                 |     +------------------------+
+--R                 |     |   4 2     2 2       4 2
+--R                 |     |- a f  + 2a c e f - c e
+--R                 |4e f |------------------------  - a c
+--R                 |     |            3 3
+--R                 |    \|         64e f
+--R                 |-------------------------------------
+--R                \|                 2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R     + 
+--R             +---------------------------------------+
+--R             |       +------------------------+
+--R             |       |   4 2     2 2       4 2
+--R             |       |- a f  + 2a c e f - c e
+--R             |- 4e f |------------------------  - a c
+--R             |       |            3 3
+--R             |      \|         64e f
+--R         (2f |---------------------------------------  + d)
+--R            \|                  2e f
+--R      *
+--R         log
+--R                          +------------------------+
+--R                          |   4 2     2 2       4 2
+--R                      3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (16c e f  |------------------------  + 2a e f  - 2a c e f)
+--R                          |            3 3
+--R                         \|         64e f
+--R             *
+--R                 +---------------------------------------+
+--R                 |       +------------------------+
+--R                 |       |   4 2     2 2       4 2
+--R                 |       |- a f  + 2a c e f - c e
+--R                 |- 4e f |------------------------  - a c
+--R                 |       |            3 3
+--R                 |      \|         64e f
+--R                 |---------------------------------------
+--R                \|                  2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R     + 
+--R               +---------------------------------------+
+--R               |       +------------------------+
+--R               |       |   4 2     2 2       4 2
+--R               |       |- a f  + 2a c e f - c e
+--R               |- 4e f |------------------------  - a c
+--R               |       |            3 3
+--R               |      \|         64e f
+--R         (- 2f |---------------------------------------  + d)
+--R              \|                  2e f
+--R      *
+--R         log
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                        3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (- 16c e f  |------------------------  - 2a e f  + 2a c e f)
+--R                            |            3 3
+--R                           \|         64e f
+--R             *
+--R                 +---------------------------------------+
+--R                 |       +------------------------+
+--R                 |       |   4 2     2 2       4 2
+--R                 |       |- a f  + 2a c e f - c e
+--R                 |- 4e f |------------------------  - a c
+--R                 |       |            3 3
+--R                 |      \|         64e f
+--R                 |---------------------------------------
+--R                \|                  2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R     + 
+--R             +-------------------------------------+
+--R             |     +------------------------+
+--R             |     |   4 2     2 2       4 2
+--R             |     |- a f  + 2a c e f - c e
+--R             |4e f |------------------------  - a c
+--R             |     |            3 3
+--R             |    \|         64e f
+--R         (2f |-------------------------------------  + d)
+--R            \|                 2e f
+--R      *
+--R         log
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                        3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (- 16c e f  |------------------------  + 2a e f  - 2a c e f)
+--R                            |            3 3
+--R                           \|         64e f
+--R             *
+--R                 +-------------------------------------+
+--R                 |     +------------------------+
+--R                 |     |   4 2     2 2       4 2
+--R                 |     |- a f  + 2a c e f - c e
+--R                 |4e f |------------------------  - a c
+--R                 |     |            3 3
+--R                 |    \|         64e f
+--R                 |-------------------------------------
+--R                \|                 2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R  /
+--R     4f
+--R                                         Type: Union(Expression(Integer),...)
+--E 502
+
+--S 503 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               +-------------------------------------+
+--R                               |     +------------------------+
+--R                               |     |   4 2     2 2       4 2
+--R                               |     |- a f  + 2a c e f - c e
+--R                               |4e f |------------------------  - a c
+--R                               |     |            3 3
+--R                +-+4+-+3 4+-+3 |    \|         64e f
+--R           - 2f\|2 \|e   \|f   |-------------------------------------
+--R                              \|                 2e f
+--R         + 
+--R             +-+4+-+3 4+-+3
+--R           d\|2 \|e   \|f
+--R      *
+--R         log
+--R                          +------------------------+
+--R                          |   4 2     2 2       4 2
+--R                      3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (16c e f  |------------------------  - 2a e f  + 2a c e f)
+--R                          |            3 3
+--R                         \|         64e f
+--R             *
+--R                 +-------------------------------------+
+--R                 |     +------------------------+
+--R                 |     |   4 2     2 2       4 2
+--R                 |     |- a f  + 2a c e f - c e
+--R                 |4e f |------------------------  - a c
+--R                 |     |            3 3
+--R                 |    \|         64e f
+--R                 |-------------------------------------
+--R                \|                 2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R     + 
+--R                             +---------------------------------------+
+--R                             |       +------------------------+
+--R                             |       |   4 2     2 2       4 2
+--R                             |       |- a f  + 2a c e f - c e
+--R                             |- 4e f |------------------------  - a c
+--R                             |       |            3 3
+--R              +-+4+-+3 4+-+3 |      \|         64e f
+--R           2f\|2 \|e   \|f   |---------------------------------------
+--R                            \|                  2e f
+--R         + 
+--R             +-+4+-+3 4+-+3
+--R           d\|2 \|e   \|f
+--R      *
+--R         log
+--R                          +------------------------+
+--R                          |   4 2     2 2       4 2
+--R                      3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (16c e f  |------------------------  + 2a e f  - 2a c e f)
+--R                          |            3 3
+--R                         \|         64e f
+--R             *
+--R                 +---------------------------------------+
+--R                 |       +------------------------+
+--R                 |       |   4 2     2 2       4 2
+--R                 |       |- a f  + 2a c e f - c e
+--R                 |- 4e f |------------------------  - a c
+--R                 |       |            3 3
+--R                 |      \|         64e f
+--R                 |---------------------------------------
+--R                \|                  2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R     + 
+--R                               +---------------------------------------+
+--R                               |       +------------------------+
+--R                               |       |   4 2     2 2       4 2
+--R                               |       |- a f  + 2a c e f - c e
+--R                               |- 4e f |------------------------  - a c
+--R                               |       |            3 3
+--R                +-+4+-+3 4+-+3 |      \|         64e f
+--R           - 2f\|2 \|e   \|f   |---------------------------------------
+--R                              \|                  2e f
+--R         + 
+--R             +-+4+-+3 4+-+3
+--R           d\|2 \|e   \|f
+--R      *
+--R         log
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                        3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (- 16c e f  |------------------------  - 2a e f  + 2a c e f)
+--R                            |            3 3
+--R                           \|         64e f
+--R             *
+--R                 +---------------------------------------+
+--R                 |       +------------------------+
+--R                 |       |   4 2     2 2       4 2
+--R                 |       |- a f  + 2a c e f - c e
+--R                 |- 4e f |------------------------  - a c
+--R                 |       |            3 3
+--R                 |      \|         64e f
+--R                 |---------------------------------------
+--R                \|                  2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R     + 
+--R                             +-------------------------------------+
+--R                             |     +------------------------+
+--R                             |     |   4 2     2 2       4 2
+--R                             |     |- a f  + 2a c e f - c e
+--R                             |4e f |------------------------  - a c
+--R                             |     |            3 3
+--R              +-+4+-+3 4+-+3 |    \|         64e f
+--R           2f\|2 \|e   \|f   |-------------------------------------
+--R                            \|                 2e f
+--R         + 
+--R             +-+4+-+3 4+-+3
+--R           d\|2 \|e   \|f
+--R      *
+--R         log
+--R                            +------------------------+
+--R                            |   4 2     2 2       4 2
+--R                        3 2 |- a f  + 2a c e f - c e       3   2       2 2
+--R                (- 16c e f  |------------------------  + 2a e f  - 2a c e f)
+--R                            |            3 3
+--R                           \|         64e f
+--R             *
+--R                 +-------------------------------------+
+--R                 |     +------------------------+
+--R                 |     |   4 2     2 2       4 2
+--R                 |     |- a f  + 2a c e f - c e
+--R                 |4e f |------------------------  - a c
+--R                 |     |            3 3
+--R                 |    \|         64e f
+--R                 |-------------------------------------
+--R                \|                 2e f
+--R            + 
+--R                4 2    4 2
+--R              (a f  - c e )x
+--R     + 
+--R              +-+       +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- a f\|f  + c f\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R            +-+       +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (a f\|f  - c f\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|f  + \|e
+--R       (- 2a f\|f  - 2c f\|e )atan(----------------)
+--R                                         4+-+
+--R                                         \|e
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|f  - \|e
+--R       (- 2a f\|f  - 2c f\|e )atan(----------------)
+--R                                         4+-+
+--R                                         \|e
+--R     + 
+--R           +-+       4     4+-+3 4+-+3
+--R       - d\|2 log(f x  + e)\|e   \|f
+--R  /
+--R        +-+4+-+3 4+-+3
+--R     4f\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4       2  +-+4+-+2        6         4        2  +-+
+--R           ((4c x  + 4a x )\|e \|e   - a f x  - 2c e x  + a e x )\|f
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2c f x  + 2a f x  + 2c e x  + 2a e)\|e
+--R         + 
+--R                   6         4        2  +-+
+--R           (- c f x  - 2a f x  + c e x )\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R                   4         2       4+-+2
+--R             (a f x  - 2c e x  - a e)\|e
+--R           + 
+--R                     6        4        2        +-+
+--R             (- c f x  - a f x  - c e x  - a e)\|e
+--R      *
+--R          +-+
+--R         \|f
+--R     + 
+--R           4         2        +-+4+-+2      2 6           4           2      2
+--R     (c f x  - 2a f x  - c e)\|e \|e   + a f x  - 3c e f x  - 3a e f x  + c e
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 953
+t0:=(b*x+c*x^2+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + b x
+--R   (1)  -----------------
+--R                4
+--R             f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 505
+
+--S 506 of 953
+r0:=1/4*d*log(e+f*x^4)/f-1/2*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(1/4)*f^(3/4)*sqrt(2))+1/2*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(1/4)*f^(3/4)*sqrt(2))+1/4*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))-1/4*c*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))+_
+   1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R             +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       - c f\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       c f\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                          +-+4+-+   4+-+                       +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|f  + \|e          +-+ +-+     x\|2 \|f  - \|e
+--R       2c f\|e \|f atan(----------------) + 2c f\|e \|f atan(----------------)
+--R                              4+-+                                 4+-+
+--R                              \|e                                  \|e
+--R     + 
+--R                              2 +-+
+--R            +-+4+-+4+-+3     x \|f       +-+       4      +-+4+-+ +-+4+-+3
+--R       2b f\|2 \|e \|f  atan(------) + d\|2 log(f x  + e)\|e \|e \|f \|f
+--R                               +-+
+--R                              \|e
+--R  /
+--R        +-+ +-+4+-+ +-+4+-+3
+--R     4f\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CD1  + (- 4e f %%CD0 + 4d e f)%%CD1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CD0  + 4d e f %%CD0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R         + 
+--R           - f %%CD1 - f %%CD0 + d
+--R      *
+--R         log
+--R                      2 2 3           3   3     2   2 2
+--R                  (32c e f %%CD0 + 16b e f  - 8c d e f )%%CD1
+--R                + 
+--R                      3   3     2   2 2              3      2 2    2     2 2 2
+--R                  (16b e f  - 8c d e f )%%CD0 + (- 8b d + 2b c )e f  + 2c d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CD1  + (- 4e f %%CD0 + 4d e f)%%CD1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CD0  + 4d e f %%CD0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                    2 2 3           3   3     2   2 2      2
+--R              (- 32c e f %%CD0 - 16b e f  + 8c d e f )%%CD1
+--R            + 
+--R                       2 2 3     2      2   2 2           3      2 2    2
+--R                  - 32c e f %%CD0  + 32c d e f %%CD0 + (8b d + 2b c )e f
+--R                + 
+--R                      2 2 2
+--R                  - 6c d e f
+--R             *
+--R                %%CD1
+--R            + 
+--R                    3   3     2   2 2      2
+--R              (- 16b e f  + 8c d e f )%%CD0
+--R            + 
+--R                  3      2 2    2     2 2 2             4   2    5          5 2
+--R              ((8b d + 2b c )e f  - 6c d e f)%%CD0 + (4b c f  - c e f)x - 2b f
+--R            + 
+--R                   3 2    2 2       4        2 3 2
+--R              (- 2b d  - b c d + b c )e f + c d e
+--R     + 
+--R             f
+--R          *
+--R             ROOT
+--R                          2     2          2                           2     2
+--R                    - 6e f %%CD1  + (- 4e f %%CD0 + 4d e f)%%CD1 - 6e f %%CD0
+--R                  + 
+--R                                    2     2
+--R                    4d e f %%CD0 - b f - d e
+--R               /
+--R                      2
+--R                  2e f
+--R         + 
+--R           - f %%CD1 - f %%CD0 + d
+--R      *
+--R         log
+--R                        2 2 3           3   3     2   2 2
+--R                  (- 32c e f %%CD0 - 16b e f  + 8c d e f )%%CD1
+--R                + 
+--R                        3   3     2   2 2            3      2 2    2     2 2 2
+--R                  (- 16b e f  + 8c d e f )%%CD0 + (8b d - 2b c )e f  - 2c d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CD1  + (- 4e f %%CD0 + 4d e f)%%CD1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CD0  + 4d e f %%CD0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                    2 2 3           3   3     2   2 2      2
+--R              (- 32c e f %%CD0 - 16b e f  + 8c d e f )%%CD1
+--R            + 
+--R                       2 2 3     2      2   2 2           3      2 2    2
+--R                  - 32c e f %%CD0  + 32c d e f %%CD0 + (8b d + 2b c )e f
+--R                + 
+--R                      2 2 2
+--R                  - 6c d e f
+--R             *
+--R                %%CD1
+--R            + 
+--R                    3   3     2   2 2      2
+--R              (- 16b e f  + 8c d e f )%%CD0
+--R            + 
+--R                  3      2 2    2     2 2 2             4   2    5          5 2
+--R              ((8b d + 2b c )e f  - 6c d e f)%%CD0 + (4b c f  - c e f)x - 2b f
+--R            + 
+--R                   3 2    2 2       4        2 3 2
+--R              (- 2b d  - b c d + b c )e f + c d e
+--R     + 
+--R         2f %%CD1
+--R      *
+--R         log
+--R                  2 2 3           3   3      2   2 2      2
+--R              (64c e f %%CD0 + 32b e f  - 16c d e f )%%CD1
+--R            + 
+--R                     2 2 3     2      2   2 2              3      2 2    2
+--R                  64c e f %%CD0  - 64c d e f %%CD0 + (- 16b d - 4b c )e f
+--R                + 
+--R                     2 2 2
+--R                  12c d e f
+--R             *
+--R                %%CD1
+--R            + 
+--R                 2 2 3     3      2   2 2     2      2 2   2      2 2 2
+--R              64c e f %%CD0  - 64c d e f %%CD0  + (8b c e f  + 24c d e f)%%CD0
+--R            + 
+--R                 4   2    5          5 2      3 2    2 2       4         2 3 2
+--R              (4b c f  - c e f)x + 2b f  + (2b d  - b c d + b c )e f - 3c d e
+--R     + 
+--R         2f %%CD0
+--R      *
+--R         log
+--R                   2 2 3     3       3   3      2   2 2      2
+--R              - 64c e f %%CD0  + (32b e f  + 48c d e f )%%CD0
+--R            + 
+--R                     3       2 2    2      2 2 2             4   2    5
+--R              ((- 16b d - 12b c )e f  - 12c d e f)%%CD0 + (4b c f  - c e f)x
+--R            + 
+--R                5 2      3 2     2 2        4        2 3 2
+--R              2b f  + (2b d  + 3b c d - 3b c )e f + c d e
+--R  /
+--R     2f
+--R                                         Type: Union(Expression(Integer),...)
+--E 507
+
+--S 508 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                   +-+ +-+4+-+ +-+4+-+3
+--R                2f\|2 \|e \|e \|f \|f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CD1  + (- 4e f %%CD0 + 4d e f)%%CD1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CD0  + 4d e f %%CD0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R         + 
+--R                +-+ +-+4+-+ +-+4+-+3           +-+ +-+4+-+ +-+4+-+3
+--R           - 2f\|2 \|e \|e \|f \|f  %%CD1 - 2f\|2 \|e \|e \|f \|f  %%CD0
+--R         + 
+--R              +-+ +-+4+-+ +-+4+-+3
+--R           2d\|2 \|e \|e \|f \|f
+--R      *
+--R         log
+--R                      2 2 3           3   3     2   2 2
+--R                  (32c e f %%CD0 + 16b e f  - 8c d e f )%%CD1
+--R                + 
+--R                      3   3     2   2 2              3      2 2    2     2 2 2
+--R                  (16b e f  - 8c d e f )%%CD0 + (- 8b d + 2b c )e f  + 2c d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CD1  + (- 4e f %%CD0 + 4d e f)%%CD1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CD0  + 4d e f %%CD0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                    2 2 3           3   3     2   2 2      2
+--R              (- 32c e f %%CD0 - 16b e f  + 8c d e f )%%CD1
+--R            + 
+--R                       2 2 3     2      2   2 2           3      2 2    2
+--R                  - 32c e f %%CD0  + 32c d e f %%CD0 + (8b d + 2b c )e f
+--R                + 
+--R                      2 2 2
+--R                  - 6c d e f
+--R             *
+--R                %%CD1
+--R            + 
+--R                    3   3     2   2 2      2
+--R              (- 16b e f  + 8c d e f )%%CD0
+--R            + 
+--R                  3      2 2    2     2 2 2             4   2    5          5 2
+--R              ((8b d + 2b c )e f  - 6c d e f)%%CD0 + (4b c f  - c e f)x - 2b f
+--R            + 
+--R                   3 2    2 2       4        2 3 2
+--R              (- 2b d  - b c d + b c )e f + c d e
+--R     + 
+--R                +-+ +-+4+-+ +-+4+-+3
+--R             2f\|2 \|e \|e \|f \|f
+--R          *
+--R             ROOT
+--R                          2     2          2                           2     2
+--R                    - 6e f %%CD1  + (- 4e f %%CD0 + 4d e f)%%CD1 - 6e f %%CD0
+--R                  + 
+--R                                    2     2
+--R                    4d e f %%CD0 - b f - d e
+--R               /
+--R                      2
+--R                  2e f
+--R         + 
+--R                +-+ +-+4+-+ +-+4+-+3           +-+ +-+4+-+ +-+4+-+3
+--R           - 2f\|2 \|e \|e \|f \|f  %%CD1 - 2f\|2 \|e \|e \|f \|f  %%CD0
+--R         + 
+--R              +-+ +-+4+-+ +-+4+-+3
+--R           2d\|2 \|e \|e \|f \|f
+--R      *
+--R         log
+--R                        2 2 3           3   3     2   2 2
+--R                  (- 32c e f %%CD0 - 16b e f  + 8c d e f )%%CD1
+--R                + 
+--R                        3   3     2   2 2            3      2 2    2     2 2 2
+--R                  (- 16b e f  + 8c d e f )%%CD0 + (8b d - 2b c )e f  - 2c d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CD1  + (- 4e f %%CD0 + 4d e f)%%CD1
+--R                     + 
+--R                             2     2                   2     2
+--R                       - 6e f %%CD0  + 4d e f %%CD0 - b f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                    2 2 3           3   3     2   2 2      2
+--R              (- 32c e f %%CD0 - 16b e f  + 8c d e f )%%CD1
+--R            + 
+--R                       2 2 3     2      2   2 2           3      2 2    2
+--R                  - 32c e f %%CD0  + 32c d e f %%CD0 + (8b d + 2b c )e f
+--R                + 
+--R                      2 2 2
+--R                  - 6c d e f
+--R             *
+--R                %%CD1
+--R            + 
+--R                    3   3     2   2 2      2
+--R              (- 16b e f  + 8c d e f )%%CD0
+--R            + 
+--R                  3      2 2    2     2 2 2             4   2    5          5 2
+--R              ((8b d + 2b c )e f  - 6c d e f)%%CD0 + (4b c f  - c e f)x - 2b f
+--R            + 
+--R                   3 2    2 2       4        2 3 2
+--R              (- 2b d  - b c d + b c )e f + c d e
+--R     + 
+--R            +-+ +-+4+-+ +-+4+-+3
+--R         4f\|2 \|e \|e \|f \|f  %%CD1
+--R      *
+--R         log
+--R                  2 2 3           3   3      2   2 2      2
+--R              (64c e f %%CD0 + 32b e f  - 16c d e f )%%CD1
+--R            + 
+--R                     2 2 3     2      2   2 2              3      2 2    2
+--R                  64c e f %%CD0  - 64c d e f %%CD0 + (- 16b d - 4b c )e f
+--R                + 
+--R                     2 2 2
+--R                  12c d e f
+--R             *
+--R                %%CD1
+--R            + 
+--R                 2 2 3     3      2   2 2     2      2 2   2      2 2 2
+--R              64c e f %%CD0  - 64c d e f %%CD0  + (8b c e f  + 24c d e f)%%CD0
+--R            + 
+--R                 4   2    5          5 2      3 2    2 2       4         2 3 2
+--R              (4b c f  - c e f)x + 2b f  + (2b d  - b c d + b c )e f - 3c d e
+--R     + 
+--R           +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       c f\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       - c f\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R            +-+ +-+4+-+ +-+4+-+3
+--R         4f\|2 \|e \|e \|f \|f  %%CD0
+--R      *
+--R         log
+--R                   2 2 3     3       3   3      2   2 2      2
+--R              - 64c e f %%CD0  + (32b e f  + 48c d e f )%%CD0
+--R            + 
+--R                     3       2 2    2      2 2 2             4   2    5
+--R              ((- 16b d - 12b c )e f  - 12c d e f)%%CD0 + (4b c f  - c e f)x
+--R            + 
+--R                5 2      3 2     2 2        4        2 3 2
+--R              2b f  + (2b d  + 3b c d - 3b c )e f + c d e
+--R     + 
+--R                            +-+4+-+   4+-+                       +-+4+-+   4+-+
+--R              +-+ +-+     x\|2 \|f  + \|e          +-+ +-+     x\|2 \|f  - \|e
+--R       - 2c f\|e \|f atan(----------------) - 2c f\|e \|f atan(----------------)
+--R                                4+-+                                 4+-+
+--R                                \|e                                  \|e
+--R     + 
+--R                                2 +-+
+--R              +-+4+-+4+-+3     x \|f       +-+       4      +-+4+-+ +-+4+-+3
+--R       - 2b f\|2 \|e \|f  atan(------) - d\|2 log(f x  + e)\|e \|e \|f \|f
+--R                                 +-+
+--R                                \|e
+--R  /
+--R        +-+ +-+4+-+ +-+4+-+3
+--R     4f\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            4 +-+4+-+2 +-+         6         2 4+-+2 4+-+2
+--R       (2c x \|e \|e  \|f  + (c f x  + 3c e x )\|e  )\|f
+--R     + 
+--R                6        2 4+-+2         2 +-+  +-+         4        +-+4+-+2
+--R       ((- c f x  - c e x )\|e   - 2c e x \|e )\|f  + (c f x  + c e)\|e \|e
+--R     + 
+--R                 4      2
+--R       - 3c e f x  - c e
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 509
+
+)clear all
+
+--S 510 of 953
+t0:=(a+b*x+c*x^2+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + b x + a
+--R   (1)  ---------------------
+--R                  4
+--R               f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 510
+
+--S 511 of 953
+r0:=1/4*d*log(e+f*x^4)/f+1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))+_
+   1/4*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-_
+   a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))-1/4*log(e^(1/4)*f^(1/4)*x*_
+   sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-a*sqrt(f))/(e^(3/4)*f^(3/4)*_
+   sqrt(2))-1/2*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+_
+   a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))+1/2*atan(1+f^(1/4)*x*_
+   sqrt(2)/e^(1/4))*(c*sqrt(e)+a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                +-+      2 +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- c e f\|f  + a f \|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              +-+      2 +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (c e f\|f  - a f \|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R               +-+       2 +-+      x\|2 \|f  + \|e
+--R       (2c e f\|f  + 2a f \|e )atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R               +-+       2 +-+      x\|2 \|f  - \|e
+--R       (2c e f\|f  + 2a f \|e )atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                2 +-+
+--R            +-+4+-+3 4+-+3     x \|f      +-+       4      +-+4+-+3 +-+4+-+3
+--R       2b f\|2 \|e   \|f  atan(------ + d\|2 log(f x  + e)\|e \|e  \|f \|f
+--R                                 +-+
+--R                                \|e
+--R  /
+--R        +-+ +-+4+-+3 +-+4+-+3
+--R     4f\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CE1  + (- 4e f %%CE0 + 4d e f)%%CE1
+--R                     + 
+--R                             2     2                             2      2
+--R                       - 6e f %%CE0  + 4d e f %%CE0 + (- 2a c - b )f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R         + 
+--R           - f %%CE1 - f %%CE0 + d
+--R      *
+--R         log
+--R                           2         2  3 4      3 4 3           3   2 4
+--R                      ((32a c - 64a b )e f  - 32c e f )%%CE0 + 8a b e f
+--R                    + 
+--R                            2         2            2      3   3 3     3   4 2
+--R                      ((- 8a c + 16a b )d + 24a b c  - 16b c)e f  + 8c d e f
+--R                 *
+--R                    %%CE1
+--R                + 
+--R                        3   2 4         2         2            2      3   3 3
+--R                      8a b e f  + ((- 8a c + 16a b )d + 24a b c  - 16b c)e f
+--R                    + 
+--R                        3   4 2
+--R                      8c d e f
+--R                 *
+--R                    %%CE0
+--R                + 
+--R                      5   4        3        2 2        4  2 3
+--R                  - 2a e f  + (- 4a b d - 6a b c + 4a b )e f
+--R                + 
+--R                      2        2  2             2     3          4     2 3  3 2
+--R                  ((2a c - 4a b )d  + (- 12a b c  + 8b c)d + 2a c  - 2b c )e f
+--R                + 
+--R                      3 2 4
+--R                  - 2c d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CE1  + (- 4e f %%CE0 + 4d e f)%%CE1
+--R                     + 
+--R                             2     2                             2      2
+--R                       - 6e f %%CE0  + 4d e f %%CE0 + (- 2a c - b )f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                         2         2  3 4      3 4 3           3   2 4
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%CE0 - 8a b e f
+--R                + 
+--R                      2         2            2      3   3 3     3   4 2
+--R                  ((8a c - 16a b )d - 24a b c  + 16b c)e f  - 8c d e f
+--R             *
+--R                     2
+--R                %%CE1
+--R            + 
+--R                         2         2  3 4      3 4 3      2
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%CE0
+--R                + 
+--R                       2         2    3 3      3   4 2           5   4
+--R                  ((32a c - 64a b )d e f  - 32c d e f )%%CE0 - 2a e f
+--R                + 
+--R                     3        2 2        4  2 3
+--R                  (4a b d - 6a b c + 4a b )e f
+--R                + 
+--R                        2         2  2           2     3          4     2 3  3 2
+--R                  ((- 6a c + 12a b )d  + (12a b c  - 8b c)d + 2a c  - 2b c )e f
+--R                + 
+--R                    3 2 4
+--R                  6c d e f
+--R             *
+--R                %%CE1
+--R            + 
+--R                      3   2 4       2         2            2      3   3 3
+--R                  - 8a b e f  + ((8a c - 16a b )d - 24a b c  + 16b c)e f
+--R                + 
+--R                      3   4 2
+--R                  - 8c d e f
+--R             *
+--R                     2
+--R                %%CE0
+--R            + 
+--R                      5   4      3        2 2        4  2 3
+--R                  - 2a e f  + (4a b d - 6a b c + 4a b )e f
+--R                + 
+--R                        2         2  2           2     3          4     2 3  3 2
+--R                  ((- 6a c + 12a b )d  + (12a b c  - 8b c)d + 2a c  - 2b c )e f
+--R                + 
+--R                    3 2 4
+--R                  6c d e f
+--R             *
+--R                %%CE0
+--R            + 
+--R                   6 4       4 2     3 2      2 4    3
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2 2    6 3
+--R                  (- a c  + 8a b c  - 4b c )e f  + c e f
+--R             *
+--R                x
+--R            + 
+--R                5      4       3 3    3
+--R              (a d - 3a b c + a b )e f
+--R            + 
+--R                  3   2      2 2        4       2   3      3 2     5   2 2
+--R              (- a b d  + (3a b c - 2a b )d - 4a b c  - a b c  + 2b c)e f
+--R            + 
+--R                      2        2  3            2     3   2         4    2 3
+--R                    (a c - 2a b )d  + (- 3a b c  + 2b c)d  + (- a c  + b c )d
+--R                  + 
+--R                         5
+--R                    - b c
+--R             *
+--R                 3
+--R                e f
+--R            + 
+--R                 3 3 4
+--R              - c d e
+--R     + 
+--R             f
+--R          *
+--R             ROOT
+--R                          2     2          2                           2     2
+--R                    - 6e f %%CE1  + (- 4e f %%CE0 + 4d e f)%%CE1 - 6e f %%CE0
+--R                  + 
+--R                                              2      2
+--R                    4d e f %%CE0 + (- 2a c - b )f - d e
+--R               /
+--R                      2
+--R                  2e f
+--R         + 
+--R           - f %%CE1 - f %%CE0 + d
+--R      *
+--R         log
+--R                             2         2  3 4      3 4 3           3   2 4
+--R                      ((- 32a c + 64a b )e f  + 32c e f )%%CE0 - 8a b e f
+--R                    + 
+--R                          2         2            2      3   3 3     3   4 2
+--R                      ((8a c - 16a b )d - 24a b c  + 16b c)e f  - 8c d e f
+--R                 *
+--R                    %%CE1
+--R                + 
+--R                          3   2 4       2         2            2      3   3 3
+--R                      - 8a b e f  + ((8a c - 16a b )d - 24a b c  + 16b c)e f
+--R                    + 
+--R                          3   4 2
+--R                      - 8c d e f
+--R                 *
+--R                    %%CE0
+--R                + 
+--R                    5   4      3        2 2        4  2 3
+--R                  2a e f  + (4a b d + 6a b c - 4a b )e f
+--R                + 
+--R                        2        2  2           2     3          4     2 3  3 2
+--R                  ((- 2a c + 4a b )d  + (12a b c  - 8b c)d - 2a c  + 2b c )e f
+--R                + 
+--R                    3 2 4
+--R                  2c d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CE1  + (- 4e f %%CE0 + 4d e f)%%CE1
+--R                     + 
+--R                             2     2                             2      2
+--R                       - 6e f %%CE0  + 4d e f %%CE0 + (- 2a c - b )f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                         2         2  3 4      3 4 3           3   2 4
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%CE0 - 8a b e f
+--R                + 
+--R                      2         2            2      3   3 3     3   4 2
+--R                  ((8a c - 16a b )d - 24a b c  + 16b c)e f  - 8c d e f
+--R             *
+--R                     2
+--R                %%CE1
+--R            + 
+--R                         2         2  3 4      3 4 3      2
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%CE0
+--R                + 
+--R                       2         2    3 3      3   4 2           5   4
+--R                  ((32a c - 64a b )d e f  - 32c d e f )%%CE0 - 2a e f
+--R                + 
+--R                     3        2 2        4  2 3
+--R                  (4a b d - 6a b c + 4a b )e f
+--R                + 
+--R                        2         2  2           2     3          4     2 3  3 2
+--R                  ((- 6a c + 12a b )d  + (12a b c  - 8b c)d + 2a c  - 2b c )e f
+--R                + 
+--R                    3 2 4
+--R                  6c d e f
+--R             *
+--R                %%CE1
+--R            + 
+--R                      3   2 4       2         2            2      3   3 3
+--R                  - 8a b e f  + ((8a c - 16a b )d - 24a b c  + 16b c)e f
+--R                + 
+--R                      3   4 2
+--R                  - 8c d e f
+--R             *
+--R                     2
+--R                %%CE0
+--R            + 
+--R                      5   4      3        2 2        4  2 3
+--R                  - 2a e f  + (4a b d - 6a b c + 4a b )e f
+--R                + 
+--R                        2         2  2           2     3          4     2 3  3 2
+--R                  ((- 6a c + 12a b )d  + (12a b c  - 8b c)d + 2a c  - 2b c )e f
+--R                + 
+--R                    3 2 4
+--R                  6c d e f
+--R             *
+--R                %%CE0
+--R            + 
+--R                   6 4       4 2     3 2      2 4    3
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2 2    6 3
+--R                  (- a c  + 8a b c  - 4b c )e f  + c e f
+--R             *
+--R                x
+--R            + 
+--R                5      4       3 3    3
+--R              (a d - 3a b c + a b )e f
+--R            + 
+--R                  3   2      2 2        4       2   3      3 2     5   2 2
+--R              (- a b d  + (3a b c - 2a b )d - 4a b c  - a b c  + 2b c)e f
+--R            + 
+--R                      2        2  3            2     3   2         4    2 3
+--R                    (a c - 2a b )d  + (- 3a b c  + 2b c)d  + (- a c  + b c )d
+--R                  + 
+--R                         5
+--R                    - b c
+--R             *
+--R                 3
+--R                e f
+--R            + 
+--R                 3 3 4
+--R              - c d e
+--R     + 
+--R         2f %%CE1
+--R      *
+--R         log
+--R                       2          2  3 4      3 4 3            3   2 4
+--R                  ((64a c - 128a b )e f  - 64c e f )%%CE0 + 16a b e f
+--R                + 
+--R                         2         2            2      3   3 3      3   4 2
+--R                  ((- 16a c + 32a b )d + 48a b c  - 32b c)e f  + 16c d e f
+--R             *
+--R                     2
+--R                %%CE1
+--R            + 
+--R                       2          2  3 4      3 4 3      2
+--R                  ((64a c - 128a b )e f  - 64c e f )%%CE0
+--R                + 
+--R                         2          2    3 3      3   4 2           5   4
+--R                  ((- 64a c + 128a b )d e f  + 64c d e f )%%CE0 + 4a e f
+--R                + 
+--R                       3         2 2        4  2 3
+--R                  (- 8a b d + 12a b c - 8a b )e f
+--R                + 
+--R                         2         2  2             2      3          4     2 3
+--R                    ((12a c - 24a b )d  + (- 24a b c  + 16b c)d - 4a c  + 4b c )
+--R                 *
+--R                     3 2
+--R                    e f
+--R                + 
+--R                       3 2 4
+--R                  - 12c d e f
+--R             *
+--R                %%CE1
+--R            + 
+--R                   2          2  3 4      3 4 3      3
+--R              ((64a c - 128a b )e f  - 64c e f )%%CE0
+--R            + 
+--R                     2          2    3 3      3   4 2      2
+--R              ((- 64a c + 128a b )d e f  + 64c d e f )%%CE0
+--R            + 
+--R                      3 2      2 2         4  2 3
+--R                  (16a c  - 24a b c - 16a b )e f
+--R                + 
+--R                       2         2  2        4     2 3  3 2      3 2 4
+--R                  ((24a c - 48a b )d  - 16a c  - 8b c )e f  - 24c d e f
+--R             *
+--R                %%CE0
+--R            + 
+--R                   6 4       4 2     3 2      2 4    3
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2 2    6 3
+--R                  (- a c  + 8a b c  - 4b c )e f  + c e f
+--R             *
+--R                x
+--R            + 
+--R                  5     4        3 3    3
+--R              (- a d + a b c + 3a b )e f
+--R            + 
+--R                     3   2        3 2     2 2        4       2   3       3 2
+--R                    a b d  + (- 4a c  + 3a b c + 6a b )d + 8a b c  - 3a b c
+--R                  + 
+--R                        5
+--R                    - 2b c
+--R             *
+--R                 2 2
+--R                e f
+--R            + 
+--R                         2        2  3          2     3   2        4    2 3
+--R                    (- 3a c + 6a b )d  + (3a b c  - 2b c)d  + (5a c  + b c )d
+--R                  + 
+--R                         5
+--R                    - b c
+--R             *
+--R                 3
+--R                e f
+--R            + 
+--R                3 3 4
+--R              3c d e
+--R     + 
+--R         2f %%CE0
+--R      *
+--R         log
+--R                     2          2  3 4      3 4 3      3
+--R              ((- 64a c + 128a b )e f  + 64c e f )%%CE0
+--R            + 
+--R                     3   2 4        2         2            2      3   3 3
+--R                  16a b e f  + ((48a c - 96a b )d + 48a b c  - 32b c)e f
+--R                + 
+--R                       3   4 2
+--R                  - 48c d e f
+--R             *
+--R                     2
+--R                %%CE0
+--R            + 
+--R                    5   4        3         3 2      2 2        4  2 3
+--R                  4a e f  + (- 8a b d - 16a c  + 36a b c + 8a b )e f
+--R                + 
+--R                            2         2  2             2      3           4
+--R                      (- 12a c + 24a b )d  + (- 24a b c  + 16b c)d + 12a c
+--R                    + 
+--R                         2 3
+--R                      12b c
+--R                 *
+--R                     3 2
+--R                    e f
+--R                + 
+--R                     3 2 4
+--R                  12c d e f
+--R             *
+--R                %%CE0
+--R            + 
+--R                   6 4       4 2     3 2      2 4    3
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2 2    6 3
+--R                  (- a c  + 8a b c  - 4b c )e f  + c e f
+--R             *
+--R                x
+--R            + 
+--R                  5      4        3 3    3
+--R              (- a d + 5a b c - 5a b )e f
+--R            + 
+--R                3   2      3 2     2 2        4         3 2     5   2 2
+--R              (a b d  + (4a c  - 9a b c - 2a b )d + 5a b c  - 2b c)e f
+--R            + 
+--R                    2        2  3          2     3   2          4     2 3
+--R                  (a c - 2a b )d  + (3a b c  - 2b c)d  + (- 3a c  - 3b c )d
+--R                + 
+--R                      5
+--R                  3b c
+--R             *
+--R                 3
+--R                e f
+--R            + 
+--R                 3 3 4
+--R              - c d e
+--R  /
+--R     2f
+--R                                         Type: Union(Expression(Integer),...)
+--E 512
+
+--S 513 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                   +-+ +-+4+-+3 +-+4+-+3
+--R                2f\|2 \|e \|e  \|f \|f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CE1  + (- 4e f %%CE0 + 4d e f)%%CE1
+--R                     + 
+--R                             2     2                             2      2
+--R                       - 6e f %%CE0  + 4d e f %%CE0 + (- 2a c - b )f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 2f\|2 \|e \|e  \|f \|f  %%CE1 - 2f\|2 \|e \|e  \|f \|f  %%CE0
+--R         + 
+--R              +-+ +-+4+-+3 +-+4+-+3
+--R           2d\|2 \|e \|e  \|f \|f
+--R      *
+--R         log
+--R                           2         2  3 4      3 4 3           3   2 4
+--R                      ((32a c - 64a b )e f  - 32c e f )%%CE0 + 8a b e f
+--R                    + 
+--R                            2         2            2      3   3 3     3   4 2
+--R                      ((- 8a c + 16a b )d + 24a b c  - 16b c)e f  + 8c d e f
+--R                 *
+--R                    %%CE1
+--R                + 
+--R                        3   2 4         2         2            2      3   3 3
+--R                      8a b e f  + ((- 8a c + 16a b )d + 24a b c  - 16b c)e f
+--R                    + 
+--R                        3   4 2
+--R                      8c d e f
+--R                 *
+--R                    %%CE0
+--R                + 
+--R                      5   4        3        2 2        4  2 3
+--R                  - 2a e f  + (- 4a b d - 6a b c + 4a b )e f
+--R                + 
+--R                      2        2  2             2     3          4     2 3  3 2
+--R                  ((2a c - 4a b )d  + (- 12a b c  + 8b c)d + 2a c  - 2b c )e f
+--R                + 
+--R                      3 2 4
+--R                  - 2c d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CE1  + (- 4e f %%CE0 + 4d e f)%%CE1
+--R                     + 
+--R                             2     2                             2      2
+--R                       - 6e f %%CE0  + 4d e f %%CE0 + (- 2a c - b )f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                         2         2  3 4      3 4 3           3   2 4
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%CE0 - 8a b e f
+--R                + 
+--R                      2         2            2      3   3 3     3   4 2
+--R                  ((8a c - 16a b )d - 24a b c  + 16b c)e f  - 8c d e f
+--R             *
+--R                     2
+--R                %%CE1
+--R            + 
+--R                         2         2  3 4      3 4 3      2
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%CE0
+--R                + 
+--R                       2         2    3 3      3   4 2           5   4
+--R                  ((32a c - 64a b )d e f  - 32c d e f )%%CE0 - 2a e f
+--R                + 
+--R                     3        2 2        4  2 3
+--R                  (4a b d - 6a b c + 4a b )e f
+--R                + 
+--R                        2         2  2           2     3          4     2 3  3 2
+--R                  ((- 6a c + 12a b )d  + (12a b c  - 8b c)d + 2a c  - 2b c )e f
+--R                + 
+--R                    3 2 4
+--R                  6c d e f
+--R             *
+--R                %%CE1
+--R            + 
+--R                      3   2 4       2         2            2      3   3 3
+--R                  - 8a b e f  + ((8a c - 16a b )d - 24a b c  + 16b c)e f
+--R                + 
+--R                      3   4 2
+--R                  - 8c d e f
+--R             *
+--R                     2
+--R                %%CE0
+--R            + 
+--R                      5   4      3        2 2        4  2 3
+--R                  - 2a e f  + (4a b d - 6a b c + 4a b )e f
+--R                + 
+--R                        2         2  2           2     3          4     2 3  3 2
+--R                  ((- 6a c + 12a b )d  + (12a b c  - 8b c)d + 2a c  - 2b c )e f
+--R                + 
+--R                    3 2 4
+--R                  6c d e f
+--R             *
+--R                %%CE0
+--R            + 
+--R                   6 4       4 2     3 2      2 4    3
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2 2    6 3
+--R                  (- a c  + 8a b c  - 4b c )e f  + c e f
+--R             *
+--R                x
+--R            + 
+--R                5      4       3 3    3
+--R              (a d - 3a b c + a b )e f
+--R            + 
+--R                  3   2      2 2        4       2   3      3 2     5   2 2
+--R              (- a b d  + (3a b c - 2a b )d - 4a b c  - a b c  + 2b c)e f
+--R            + 
+--R                      2        2  3            2     3   2         4    2 3
+--R                    (a c - 2a b )d  + (- 3a b c  + 2b c)d  + (- a c  + b c )d
+--R                  + 
+--R                         5
+--R                    - b c
+--R             *
+--R                 3
+--R                e f
+--R            + 
+--R                 3 3 4
+--R              - c d e
+--R     + 
+--R                +-+ +-+4+-+3 +-+4+-+3
+--R             2f\|2 \|e \|e  \|f \|f
+--R          *
+--R             ROOT
+--R                          2     2          2                           2     2
+--R                    - 6e f %%CE1  + (- 4e f %%CE0 + 4d e f)%%CE1 - 6e f %%CE0
+--R                  + 
+--R                                              2      2
+--R                    4d e f %%CE0 + (- 2a c - b )f - d e
+--R               /
+--R                      2
+--R                  2e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 2f\|2 \|e \|e  \|f \|f  %%CE1 - 2f\|2 \|e \|e  \|f \|f  %%CE0
+--R         + 
+--R              +-+ +-+4+-+3 +-+4+-+3
+--R           2d\|2 \|e \|e  \|f \|f
+--R      *
+--R         log
+--R                             2         2  3 4      3 4 3           3   2 4
+--R                      ((- 32a c + 64a b )e f  + 32c e f )%%CE0 - 8a b e f
+--R                    + 
+--R                          2         2            2      3   3 3     3   4 2
+--R                      ((8a c - 16a b )d - 24a b c  + 16b c)e f  - 8c d e f
+--R                 *
+--R                    %%CE1
+--R                + 
+--R                          3   2 4       2         2            2      3   3 3
+--R                      - 8a b e f  + ((8a c - 16a b )d - 24a b c  + 16b c)e f
+--R                    + 
+--R                          3   4 2
+--R                      - 8c d e f
+--R                 *
+--R                    %%CE0
+--R                + 
+--R                    5   4      3        2 2        4  2 3
+--R                  2a e f  + (4a b d + 6a b c - 4a b )e f
+--R                + 
+--R                        2        2  2           2     3          4     2 3  3 2
+--R                  ((- 2a c + 4a b )d  + (12a b c  - 8b c)d - 2a c  + 2b c )e f
+--R                + 
+--R                    3 2 4
+--R                  2c d e f
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6e f %%CE1  + (- 4e f %%CE0 + 4d e f)%%CE1
+--R                     + 
+--R                             2     2                             2      2
+--R                       - 6e f %%CE0  + 4d e f %%CE0 + (- 2a c - b )f - d e
+--R                  /
+--R                         2
+--R                     2e f
+--R            + 
+--R                         2         2  3 4      3 4 3           3   2 4
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%CE0 - 8a b e f
+--R                + 
+--R                      2         2            2      3   3 3     3   4 2
+--R                  ((8a c - 16a b )d - 24a b c  + 16b c)e f  - 8c d e f
+--R             *
+--R                     2
+--R                %%CE1
+--R            + 
+--R                         2         2  3 4      3 4 3      2
+--R                  ((- 32a c + 64a b )e f  + 32c e f )%%CE0
+--R                + 
+--R                       2         2    3 3      3   4 2           5   4
+--R                  ((32a c - 64a b )d e f  - 32c d e f )%%CE0 - 2a e f
+--R                + 
+--R                     3        2 2        4  2 3
+--R                  (4a b d - 6a b c + 4a b )e f
+--R                + 
+--R                        2         2  2           2     3          4     2 3  3 2
+--R                  ((- 6a c + 12a b )d  + (12a b c  - 8b c)d + 2a c  - 2b c )e f
+--R                + 
+--R                    3 2 4
+--R                  6c d e f
+--R             *
+--R                %%CE1
+--R            + 
+--R                      3   2 4       2         2            2      3   3 3
+--R                  - 8a b e f  + ((8a c - 16a b )d - 24a b c  + 16b c)e f
+--R                + 
+--R                      3   4 2
+--R                  - 8c d e f
+--R             *
+--R                     2
+--R                %%CE0
+--R            + 
+--R                      5   4      3        2 2        4  2 3
+--R                  - 2a e f  + (4a b d - 6a b c + 4a b )e f
+--R                + 
+--R                        2         2  2           2     3          4     2 3  3 2
+--R                  ((- 6a c + 12a b )d  + (12a b c  - 8b c)d + 2a c  - 2b c )e f
+--R                + 
+--R                    3 2 4
+--R                  6c d e f
+--R             *
+--R                %%CE0
+--R            + 
+--R                   6 4       4 2     3 2      2 4    3
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2 2    6 3
+--R                  (- a c  + 8a b c  - 4b c )e f  + c e f
+--R             *
+--R                x
+--R            + 
+--R                5      4       3 3    3
+--R              (a d - 3a b c + a b )e f
+--R            + 
+--R                  3   2      2 2        4       2   3      3 2     5   2 2
+--R              (- a b d  + (3a b c - 2a b )d - 4a b c  - a b c  + 2b c)e f
+--R            + 
+--R                      2        2  3            2     3   2         4    2 3
+--R                    (a c - 2a b )d  + (- 3a b c  + 2b c)d  + (- a c  + b c )d
+--R                  + 
+--R                         5
+--R                    - b c
+--R             *
+--R                 3
+--R                e f
+--R            + 
+--R                 3 3 4
+--R              - c d e
+--R     + 
+--R            +-+ +-+4+-+3 +-+4+-+3
+--R         4f\|2 \|e \|e  \|f \|f  %%CE1
+--R      *
+--R         log
+--R                       2          2  3 4      3 4 3            3   2 4
+--R                  ((64a c - 128a b )e f  - 64c e f )%%CE0 + 16a b e f
+--R                + 
+--R                         2         2            2      3   3 3      3   4 2
+--R                  ((- 16a c + 32a b )d + 48a b c  - 32b c)e f  + 16c d e f
+--R             *
+--R                     2
+--R                %%CE1
+--R            + 
+--R                       2          2  3 4      3 4 3      2
+--R                  ((64a c - 128a b )e f  - 64c e f )%%CE0
+--R                + 
+--R                         2          2    3 3      3   4 2           5   4
+--R                  ((- 64a c + 128a b )d e f  + 64c d e f )%%CE0 + 4a e f
+--R                + 
+--R                       3         2 2        4  2 3
+--R                  (- 8a b d + 12a b c - 8a b )e f
+--R                + 
+--R                         2         2  2             2      3          4     2 3
+--R                    ((12a c - 24a b )d  + (- 24a b c  + 16b c)d - 4a c  + 4b c )
+--R                 *
+--R                     3 2
+--R                    e f
+--R                + 
+--R                       3 2 4
+--R                  - 12c d e f
+--R             *
+--R                %%CE1
+--R            + 
+--R                   2          2  3 4      3 4 3      3
+--R              ((64a c - 128a b )e f  - 64c e f )%%CE0
+--R            + 
+--R                     2          2    3 3      3   4 2      2
+--R              ((- 64a c + 128a b )d e f  + 64c d e f )%%CE0
+--R            + 
+--R                      3 2      2 2         4  2 3
+--R                  (16a c  - 24a b c - 16a b )e f
+--R                + 
+--R                       2         2  2        4     2 3  3 2      3 2 4
+--R                  ((24a c - 48a b )d  - 16a c  - 8b c )e f  - 24c d e f
+--R             *
+--R                %%CE0
+--R            + 
+--R                   6 4       4 2     3 2      2 4    3
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2 2    6 3
+--R                  (- a c  + 8a b c  - 4b c )e f  + c e f
+--R             *
+--R                x
+--R            + 
+--R                  5     4        3 3    3
+--R              (- a d + a b c + 3a b )e f
+--R            + 
+--R                     3   2        3 2     2 2        4       2   3       3 2
+--R                    a b d  + (- 4a c  + 3a b c + 6a b )d + 8a b c  - 3a b c
+--R                  + 
+--R                        5
+--R                    - 2b c
+--R             *
+--R                 2 2
+--R                e f
+--R            + 
+--R                         2        2  3          2     3   2        4    2 3
+--R                    (- 3a c + 6a b )d  + (3a b c  - 2b c)d  + (5a c  + b c )d
+--R                  + 
+--R                         5
+--R                    - b c
+--R             *
+--R                 3
+--R                e f
+--R            + 
+--R                3 3 4
+--R              3c d e
+--R     + 
+--R              +-+      2 +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (c e f\|f  - a f \|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                +-+      2 +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- c e f\|f  + a f \|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R            +-+ +-+4+-+3 +-+4+-+3
+--R         4f\|2 \|e \|e  \|f \|f  %%CE0
+--R      *
+--R         log
+--R                     2          2  3 4      3 4 3      3
+--R              ((- 64a c + 128a b )e f  + 64c e f )%%CE0
+--R            + 
+--R                     3   2 4        2         2            2      3   3 3
+--R                  16a b e f  + ((48a c - 96a b )d + 48a b c  - 32b c)e f
+--R                + 
+--R                       3   4 2
+--R                  - 48c d e f
+--R             *
+--R                     2
+--R                %%CE0
+--R            + 
+--R                    5   4        3         3 2      2 2        4  2 3
+--R                  4a e f  + (- 8a b d - 16a c  + 36a b c + 8a b )e f
+--R                + 
+--R                            2         2  2             2      3           4
+--R                      (- 12a c + 24a b )d  + (- 24a b c  + 16b c)d + 12a c
+--R                    + 
+--R                         2 3
+--R                      12b c
+--R                 *
+--R                     3 2
+--R                    e f
+--R                + 
+--R                     3 2 4
+--R                  12c d e f
+--R             *
+--R                %%CE0
+--R            + 
+--R                   6 4       4 2     3 2      2 4    3
+--R                  a f  + (- a c  + 8a b c - 4a b )e f
+--R                + 
+--R                      2 4       2 3     4 2  2 2    6 3
+--R                  (- a c  + 8a b c  - 4b c )e f  + c e f
+--R             *
+--R                x
+--R            + 
+--R                  5      4        3 3    3
+--R              (- a d + 5a b c - 5a b )e f
+--R            + 
+--R                3   2      3 2     2 2        4         3 2     5   2 2
+--R              (a b d  + (4a c  - 9a b c - 2a b )d + 5a b c  - 2b c)e f
+--R            + 
+--R                    2        2  3          2     3   2          4     2 3
+--R                  (a c - 2a b )d  + (3a b c  - 2b c)d  + (- 3a c  - 3b c )d
+--R                + 
+--R                      5
+--R                  3b c
+--R             *
+--R                 3
+--R                e f
+--R            + 
+--R                 3 3 4
+--R              - c d e
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R                 +-+       2 +-+      x\|2 \|f  + \|e
+--R       (- 2c e f\|f  - 2a f \|e )atan(----------------)
+--R                                            4+-+
+--R                                            \|e
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R                 +-+       2 +-+      x\|2 \|f  - \|e
+--R       (- 2c e f\|f  - 2a f \|e )atan(----------------)
+--R                                            4+-+
+--R                                            \|e
+--R     + 
+--R                                  2 +-+
+--R              +-+4+-+3 4+-+3     x \|f      +-+       4      +-+4+-+3 +-+4+-+3
+--R       - 2b f\|2 \|e   \|f  atan(------ - d\|2 log(f x  + e)\|e \|e  \|f \|f
+--R                                   +-+
+--R                                  \|e
+--R  /
+--R        +-+ +-+4+-+3 +-+4+-+3
+--R     4f\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 513
+
+--S 514 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4       2  +-+4+-+2        6         4        2  +-+
+--R           ((4c x  + 4a x )\|e \|e   - a f x  - 2c e x  + a e x )\|f
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2c f x  + 2a f x  + 2c e x  + 2a e)\|e
+--R         + 
+--R                   6         4        2  +-+
+--R           (- c f x  - 2a f x  + c e x )\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R                   4         2       4+-+2
+--R             (a f x  - 2c e x  - a e)\|e
+--R           + 
+--R                     6        4        2        +-+
+--R             (- c f x  - a f x  - c e x  - a e)\|e
+--R      *
+--R          +-+
+--R         \|f
+--R     + 
+--R           4         2        +-+4+-+2      2 6           4           2      2
+--R     (c f x  - 2a f x  - c e)\|e \|e   + a f x  - 3c e f x  - 3a e f x  + c e
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4f x  + 4e x )\|e \|e  \|f  + (2f x  + 4e f x  + 2e )\|e  )\|f
+--R     + 
+--R             2 6     2   2
+--R       - 4e f x  - 4e f x
+--R                                                    Type: Expression(Integer)
+--E 514
+
+)clear all
+
+--S 515 of 953
+t0:=a/(e+f*x^4)^2
+--R 
+--R
+--R                 a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 515
+
+--S 516 of 953
+r0:=1/4*a*x/(e*(e+f*x^4))-3/8*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(7/4)*f^(1/4)*sqrt(2))+3/8*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(7/4)*f^(1/4)*sqrt(2))-3/16*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))+3/16*a*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              4              +-+4+-+4+-+    2 +-+    +-+
+--R       (3a f x  + 3a e)log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                4                +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a f x  - 3a e)log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                              +-+4+-+   4+-+
+--R              4             x\|2 \|f  + \|e
+--R       (6a f x  + 6a e)atan(----------------)
+--R                                  4+-+
+--R                                  \|e
+--R     + 
+--R                              +-+4+-+   4+-+
+--R              4             x\|2 \|f  - \|e          +-+4+-+3 4+-+
+--R       (6a f x  + 6a e)atan(----------------) + 4a x\|2 \|e   \|f
+--R                                  4+-+
+--R                                  \|e
+--R  /
+--R             4      2  +-+4+-+3 4+-+
+--R     (16e f x  + 16e )\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        +----------+          +----------+
+--R                        |       4             |       4
+--R              4     2   |    81a           2  |    81a
+--R       (4e f x  + 4e )  |- -------- log(16e   |- -------- + 3a x)
+--R                       4|        7           4|        7
+--R                       \|  65536e f          \|  65536e f
+--R     + 
+--R                          +----------+            +----------+
+--R                          |       4               |       4
+--R                4     2   |    81a             2  |    81a
+--R       (- 4e f x  - 4e )  |- -------- log(- 16e   |- -------- + 3a x)
+--R                         4|        7             4|        7
+--R                         \|  65536e f            \|  65536e f
+--R     + 
+--R                                                 +----------+
+--R                                                 |       4
+--R                                              2  |    81a
+--R                          +----------+     16e   |- --------
+--R                          |       4             4|        7
+--R                4     2   |    81a              \|  65536e f
+--R       (- 8e f x  - 8e )  |- -------- atan(----------------- + a x
+--R                         4|        7              3a x
+--R                         \|  65536e f
+--R  /
+--R           4     2
+--R     4e f x  + 4e
+--R                                         Type: Union(Expression(Integer),...)
+--E 517
+
+--S 518 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +-+4+-+4+-+    2 +-+    +-+
+--R       - 3a log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                +----------+                    +----------+
+--R                |       4                       |       4
+--R           +-+  |    81a    4+-+3 4+-+       2  |    81a
+--R       16e\|2   |- -------- \|e   \|f log(16e   |- -------- + 3a x)
+--R               4|        7                     4|        7
+--R               \|  65536e f                    \|  65536e f
+--R     + 
+--R                  +----------+                      +----------+
+--R                  |       4                         |       4
+--R             +-+  |    81a    4+-+3 4+-+         2  |    81a
+--R       - 16e\|2   |- -------- \|e   \|f log(- 16e   |- -------- + 3a x)
+--R                 4|        7                       4|        7
+--R                 \|  65536e f                      \|  65536e f
+--R     + 
+--R                                                           +-+4+-+   4+-+
+--R                  +-+4+-+4+-+    2 +-+    +-+            x\|2 \|f  + \|e
+--R       3a log(- x\|2 \|e \|f  + x \|f  + \|e ) - 6a atan(----------------)
+--R                                                               4+-+
+--R                                                               \|e
+--R     + 
+--R                   +-+4+-+   4+-+
+--R                 x\|2 \|f  - \|e
+--R       - 6a atan(----------------)
+--R                       4+-+
+--R                       \|e
+--R     + 
+--R                                                   +----------+
+--R                                                   |       4
+--R                                                2  |    81a
+--R                  +----------+               16e   |- --------
+--R                  |       4                       4|        7
+--R             +-+  |    81a    4+-+3 4+-+          \|  65536e f
+--R       - 32e\|2   |- -------- \|e   \|f atan(-----------------)
+--R                 4|        7                        3a x
+--R                 \|  65536e f
+--R  /
+--R         +-+4+-+3 4+-+
+--R     16e\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                2 +-+4+-+2         6         2  +-+          4        4+-+2
+--R           (6a x \|e \|e   + 3a f x  + 3a e x )\|f  + (9a f x  + 3a e)\|e
+--R         + 
+--R                    4         +-+
+--R           (- 3a f x  - 3a e)\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R               4 +-+ +-+       2 6           2
+--R       - 6a f x \|e \|f  - 3a f x  - 9a e f x
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 519
+
+)clear all
+
+--S 520 of 953
+t0:=b*x/(e+f*x^4)^2
+--R 
+--R
+--R                b x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 520
+
+--S 521 of 953
+r0:=1/4*b*x^2/(e*(e+f*x^4))+1/4*b*atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))
+--R 
+--R
+--R                            2 +-+
+--R              4            x \|f        2 +-+ +-+
+--R        (b f x  + b e)atan(------) + b x \|e \|f
+--R                             +-+
+--R                            \|e
+--R   (2)  -----------------------------------------
+--R                        4     2  +-+ +-+
+--R                 (4e f x  + 4e )\|e \|f
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          4      +-----+         2
+--R          4           (f x  - e)\|- e f  + 2e f x         2 +-----+
+--R    (b f x  + b e)log(----------------------------) + 2b x \|- e f
+--R                                   4
+--R                                f x  + e
+--R   [---------------------------------------------------------------,
+--R                               4     2  +-----+
+--R                        (8e f x  + 8e )\|- e f
+--R                        2 +---+
+--R          4            x \|e f        2 +---+
+--R    (b f x  + b e)atan(--------) + b x \|e f
+--R                           e
+--R    -----------------------------------------]
+--R                     4     2  +---+
+--R              (4e f x  + 4e )\|e f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 522
+
+--S 523 of 953
+m0a:=a0.1-r0
+--R 
+--R
+--R                         4      +-----+         2                    2 +-+
+--R          +-+ +-+    (f x  - e)\|- e f  + 2e f x        +-----+     x \|f
+--R        b\|e \|f log(----------------------------) - 2b\|- e f atan(------)
+--R                                  4                                   +-+
+--R                               f x  + e                              \|e
+--R   (4)  -------------------------------------------------------------------
+--R                                    +-----+ +-+ +-+
+--R                                 8e\|- e f \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 953
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 953
+m0b:=a0.2-r0
+--R 
+--R
+--R                       2 +---+                 2 +-+
+--R          +-+ +-+     x \|e f       +---+     x \|f
+--R        b\|e \|f atan(--------) - b\|e f atan(------)
+--R                          e                     +-+
+--R                                               \|e
+--R   (6)  ---------------------------------------------
+--R                          +-+ +-+ +---+
+--R                       4e\|e \|f \|e f
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 953
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 526
+
+)clear all
+
+--S 527 of 953
+t0:=(a+b*x)/(e+f*x^4)^2
+--R 
+--R
+--R              b x + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 527
+
+--S 528 of 953
+r0:=1/4*x*(a+b*x)/(e*(e+f*x^4))-3/8*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(7/4)*f^(1/4)*sqrt(2))+3/8*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(7/4)*f^(1/4)*sqrt(2))-3/16*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))+3/16*a*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))+_
+   1/4*b*atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R              4         +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       (3a f x  + 3a e)\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                4         +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a f x  - 3a e)\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R              4         +-+ +-+     x\|2 \|f  + \|e
+--R       (6a f x  + 6a e)\|e \|f atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R              4         +-+ +-+     x\|2 \|f  - \|e
+--R       (6a f x  + 6a e)\|e \|f atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                           2 +-+
+--R              4         +-+4+-+3 4+-+     x \|f
+--R       (4b f x  + 4b e)\|2 \|e   \|f atan(------)
+--R                                            +-+
+--R                                           \|e
+--R     + 
+--R            2         +-+ +-+4+-+3 +-+4+-+
+--R       (4b x  + 4a x)\|2 \|e \|e  \|f \|f
+--R  /
+--R             4      2  +-+ +-+4+-+3 +-+4+-+
+--R     (16e f x  + 16e )\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 528
+
+--S 529 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    4     2
+--R             (2e f x  + 2e )
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CG1  - 16e f %%CG0 %%CG1 - 24e f %%CG0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                    4     2                  4     2
+--R           (- 2e f x  - 2e )%%CG1 + (- 2e f x  - 2e )%%CG0
+--R      *
+--R         log
+--R                         2 6               2   4               2   4
+--R                  (16384b e f %%CG0 - 2304a b e f)%%CG1 - 2304a b e f %%CG0
+--R                + 
+--R                      4 2        4 3
+--R                  648a e f - 256b e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CG1  - 16e f %%CG0 %%CG1 - 24e f %%CG0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                     2 6               2   4       2
+--R              (16384b e f %%CG0 - 2304a b e f)%%CG1
+--R            + 
+--R                     2 6       2       4 2        4 3              2   4       2
+--R              (16384b e f %%CG0  - 648a e f + 256b e )%%CG1 - 2304a b e f %%CG0
+--R            + 
+--R                     4 2        4 3              5          4         2 3
+--R              (- 648a e f + 256b e )%%CG0 + (243a f - 192a b e)x + 72a b e
+--R     + 
+--R                      4     2
+--R             (- 2e f x  - 2e )
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CG1  - 16e f %%CG0 %%CG1 - 24e f %%CG0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                    4     2                  4     2
+--R           (- 2e f x  - 2e )%%CG1 + (- 2e f x  - 2e )%%CG0
+--R      *
+--R         log
+--R                           2 6               2   4               2   4
+--R                  (- 16384b e f %%CG0 + 2304a b e f)%%CG1 + 2304a b e f %%CG0
+--R                + 
+--R                        4 2        4 3
+--R                  - 648a e f + 256b e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CG1  - 16e f %%CG0 %%CG1 - 24e f %%CG0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                     2 6               2   4       2
+--R              (16384b e f %%CG0 - 2304a b e f)%%CG1
+--R            + 
+--R                     2 6       2       4 2        4 3              2   4       2
+--R              (16384b e f %%CG0  - 648a e f + 256b e )%%CG1 - 2304a b e f %%CG0
+--R            + 
+--R                     4 2        4 3              5          4         2 3
+--R              (- 648a e f + 256b e )%%CG0 + (243a f - 192a b e)x + 72a b e
+--R     + 
+--R                4     2
+--R         (4e f x  + 4e )%%CG1
+--R      *
+--R         log
+--R                       2 6               2   4       2
+--R              (- 32768b e f %%CG0 + 4608a b e f)%%CG1
+--R            + 
+--R                       2 6       2        4 2        4 3
+--R              (- 32768b e f %%CG0  + 1296a e f - 512b e )%%CG1
+--R            + 
+--R                      2 6       3        4 3             5          4
+--R              - 32768b e f %%CG0  - 1024b e %%CG0 + (243a f - 192a b e)x
+--R            + 
+--R                  2 3
+--R              216a b e
+--R     + 
+--R                4     2
+--R         (4e f x  + 4e )%%CG0
+--R      *
+--R         log
+--R                    2 6       3        2   4       2
+--R              32768b e f %%CG0  + 4608a b e f %%CG0
+--R            + 
+--R                    4 2        4 3              5          4          2 3
+--R              (1296a e f + 512b e )%%CG0 + (243a f - 192a b e)x - 360a b e
+--R     + 
+--R          2
+--R       b x  + a x
+--R  /
+--R           4     2
+--R     4e f x  + 4e
+--R                                         Type: Union(Expression(Integer),...)
+--E 529
+
+--S 530 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+ +-+4+-+3 +-+4+-+
+--R             8e\|2 \|e \|e  \|f \|f
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CG1  - 16e f %%CG0 %%CG1 - 24e f %%CG0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+           +-+ +-+4+-+3 +-+4+-+
+--R           - 8e\|2 \|e \|e  \|f \|f %%CG1 - 8e\|2 \|e \|e  \|f \|f %%CG0
+--R      *
+--R         log
+--R                         2 6               2   4               2   4
+--R                  (16384b e f %%CG0 - 2304a b e f)%%CG1 - 2304a b e f %%CG0
+--R                + 
+--R                      4 2        4 3
+--R                  648a e f - 256b e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CG1  - 16e f %%CG0 %%CG1 - 24e f %%CG0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                     2 6               2   4       2
+--R              (16384b e f %%CG0 - 2304a b e f)%%CG1
+--R            + 
+--R                     2 6       2       4 2        4 3              2   4       2
+--R              (16384b e f %%CG0  - 648a e f + 256b e )%%CG1 - 2304a b e f %%CG0
+--R            + 
+--R                     4 2        4 3              5          4         2 3
+--R              (- 648a e f + 256b e )%%CG0 + (243a f - 192a b e)x + 72a b e
+--R     + 
+--R           -
+--R                   +-+ +-+4+-+3 +-+4+-+
+--R                8e\|2 \|e \|e  \|f \|f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CG1  - 16e f %%CG0 %%CG1 - 24e f %%CG0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+           +-+ +-+4+-+3 +-+4+-+
+--R           - 8e\|2 \|e \|e  \|f \|f %%CG1 - 8e\|2 \|e \|e  \|f \|f %%CG0
+--R      *
+--R         log
+--R                           2 6               2   4               2   4
+--R                  (- 16384b e f %%CG0 + 2304a b e f)%%CG1 + 2304a b e f %%CG0
+--R                + 
+--R                        4 2        4 3
+--R                  - 648a e f + 256b e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CG1  - 16e f %%CG0 %%CG1 - 24e f %%CG0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                     2 6               2   4       2
+--R              (16384b e f %%CG0 - 2304a b e f)%%CG1
+--R            + 
+--R                     2 6       2       4 2        4 3              2   4       2
+--R              (16384b e f %%CG0  - 648a e f + 256b e )%%CG1 - 2304a b e f %%CG0
+--R            + 
+--R                     4 2        4 3              5          4         2 3
+--R              (- 648a e f + 256b e )%%CG0 + (243a f - 192a b e)x + 72a b e
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+
+--R         16e\|2 \|e \|e  \|f \|f %%CG1
+--R      *
+--R         log
+--R                       2 6               2   4       2
+--R              (- 32768b e f %%CG0 + 4608a b e f)%%CG1
+--R            + 
+--R                       2 6       2        4 2        4 3
+--R              (- 32768b e f %%CG0  + 1296a e f - 512b e )%%CG1
+--R            + 
+--R                      2 6       3        4 3             5          4
+--R              - 32768b e f %%CG0  - 1024b e %%CG0 + (243a f - 192a b e)x
+--R            + 
+--R                  2 3
+--R              216a b e
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+
+--R         16e\|2 \|e \|e  \|f \|f %%CG0
+--R      *
+--R         log
+--R                    2 6       3        2   4       2
+--R              32768b e f %%CG0  + 4608a b e f %%CG0
+--R            + 
+--R                    4 2        4 3              5          4          2 3
+--R              (1296a e f + 512b e )%%CG0 + (243a f - 192a b e)x - 360a b e
+--R     + 
+--R            +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       - 3a\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R          +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       3a\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                          +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|f  + \|e        +-+ +-+     x\|2 \|f  - \|e
+--R       - 6a\|e \|f atan(----------------) - 6a\|e \|f atan(----------------)
+--R                              4+-+                               4+-+
+--R                              \|e                                \|e
+--R     + 
+--R                               2 +-+
+--R            +-+4+-+3 4+-+     x \|f
+--R       - 4b\|2 \|e   \|f atan(------)
+--R                                +-+
+--R                               \|e
+--R  /
+--R         +-+ +-+4+-+3 +-+4+-+
+--R     16e\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                2 +-+4+-+2         6         2  +-+          4        4+-+2
+--R           (6a x \|e \|e   + 3a f x  + 3a e x )\|f  + (9a f x  + 3a e)\|e
+--R         + 
+--R                    4         +-+
+--R           (- 3a f x  - 3a e)\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R               4 +-+ +-+       2 6           2
+--R       - 6a f x \|e \|f  - 3a f x  - 9a e f x
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 531
+
+)clear all
+
+--S 532 of 953
+t0:=c*x^2/(e+f*x^4)^2
+--R 
+--R
+--R                   2
+--R                c x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 532
+
+--S 533 of 953
+r0:=1/4*c*x^3/(e*(e+f*x^4))-1/8*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(5/4)*f^(3/4)*sqrt(2))+1/8*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(5/4)*f^(3/4)*sqrt(2))+1/16*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))-1/16*c*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               4             +-+4+-+4+-+    2 +-+    +-+
+--R       (- c f x  - c e)log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             4               +-+4+-+4+-+    2 +-+    +-+
+--R       (c f x  + c e)log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                              +-+4+-+   4+-+
+--R              4             x\|2 \|f  + \|e
+--R       (2c f x  + 2c e)atan(----------------)
+--R                                  4+-+
+--R                                  \|e
+--R     + 
+--R                              +-+4+-+   4+-+
+--R              4             x\|2 \|f  - \|e         3 +-+4+-+4+-+3
+--R       (2c f x  + 2c e)atan(----------------) + 4c x \|2 \|e \|f
+--R                                  4+-+
+--R                                  \|e
+--R  /
+--R             4      2  +-+4+-+4+-+3
+--R     (16e f x  + 16e )\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        +-----------+              +-----------+3
+--R                        |       4                  |       4
+--R              4     2   |      c              4 2  |      c         3
+--R       (4e f x  + 4e )  |- --------- log(4096e f   |- ---------  + c x)
+--R                       4|        5 3              4|        5 3
+--R                       \|  65536e f               \|  65536e f
+--R     + 
+--R                          +-----------+                +-----------+3
+--R                          |       4                    |       4
+--R                4     2   |      c                4 2  |      c         3
+--R       (- 4e f x  - 4e )  |- --------- log(- 4096e f   |- ---------  + c x)
+--R                         4|        5 3                4|        5 3
+--R                         \|  65536e f                 \|  65536e f
+--R     + 
+--R                                                    +-----------+3
+--R                                                    |       4
+--R                                               4 2  |      c
+--R                        +-----------+     4096e f   |- ---------
+--R                        |       4                  4|        5 3
+--R              4     2   |      c                   \|  65536e f        3
+--R       (8e f x  + 8e )  |- --------- atan(----------------------- + c x
+--R                       4|        5 3                 3
+--R                       \|  65536e f                 c x
+--R  /
+--R           4     2
+--R     4e f x  + 4e
+--R                                         Type: Union(Expression(Integer),...)
+--E 534
+
+--S 535 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R       c log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                +-----------+                       +-----------+3
+--R                |       4                           |       4
+--R           +-+  |      c     4+-+4+-+3         4 2  |      c         3
+--R       16e\|2   |- --------- \|e \|f  log(4096e f   |- ---------  + c x)
+--R               4|        5 3                       4|        5 3
+--R               \|  65536e f                        \|  65536e f
+--R     + 
+--R                  +-----------+                         +-----------+3
+--R                  |       4                             |       4
+--R             +-+  |      c     4+-+4+-+3           4 2  |      c         3
+--R       - 16e\|2   |- --------- \|e \|f  log(- 4096e f   |- ---------  + c x)
+--R                 4|        5 3                         4|        5 3
+--R                 \|  65536e f                          \|  65536e f
+--R     + 
+--R                                                            +-+4+-+   4+-+
+--R                   +-+4+-+4+-+    2 +-+    +-+            x\|2 \|f  + \|e
+--R       - c log(- x\|2 \|e \|f  + x \|f  + \|e ) - 2c atan(----------------)
+--R                                                                4+-+
+--R                                                                \|e
+--R     + 
+--R                   +-+4+-+   4+-+
+--R                 x\|2 \|f  - \|e
+--R       - 2c atan(----------------)
+--R                       4+-+
+--R                       \|e
+--R     + 
+--R                                                     +-----------+3
+--R                                                     |       4
+--R                                                4 2  |      c
+--R                +-----------+              4096e f   |- ---------
+--R                |       4                           4|        5 3
+--R           +-+  |      c     4+-+4+-+3              \|  65536e f
+--R       32e\|2   |- --------- \|e \|f  atan(-----------------------)
+--R               4|        5 3                          3
+--R               \|  65536e f                          c x
+--R  /
+--R         +-+4+-+4+-+3
+--R     16e\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            4 +-+4+-+2 +-+         6         2 4+-+2 4+-+2
+--R       (2c x \|e \|e  \|f  + (c f x  + 3c e x )\|e  )\|f
+--R     + 
+--R                6        2 4+-+2         2 +-+  +-+         4        +-+4+-+2
+--R       ((- c f x  - c e x )\|e   - 2c e x \|e )\|f  + (c f x  + c e)\|e \|e
+--R     + 
+--R                 4      2
+--R       - 3c e f x  - c e
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 536
+
+)clear all
+
+--S 537 of 953
+t0:=(a+c*x^2)/(e+f*x^4)^2
+--R 
+--R
+--R                 2
+--R              c x  + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 537
+
+--S 538 of 953
+r0:=1/4*x*(a+c*x^2)/(e*(e+f*x^4))+1/16*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))-_
+   1/16*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-_
+   3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))-1/8*atan(1-f^(1/4)*x*_
+   sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))+_
+   1/8*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/_
+   (e^(7/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 4         +-+           4        +-+
+--R         ((3a f x  + 3a e)\|f  + (- c f x  - c e)\|e )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                   4         +-+         4        +-+
+--R         ((- 3a f x  - 3a e)\|f  + (c f x  + c e)\|e )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                           +-+4+-+   4+-+
+--R               4         +-+          4         +-+      x\|2 \|f  + \|e
+--R       ((6a f x  + 6a e)\|f  + (2c f x  + 2c e)\|e )atan(----------------)
+--R                                                               4+-+
+--R                                                               \|e
+--R     + 
+--R                                                           +-+4+-+   4+-+
+--R               4         +-+          4         +-+      x\|2 \|f  - \|e
+--R       ((6a f x  + 6a e)\|f  + (2c f x  + 2c e)\|e )atan(----------------)
+--R                                                               4+-+
+--R                                                               \|e
+--R     + 
+--R            3         +-+4+-+3 4+-+3
+--R       (4c x  + 4a x)\|2 \|e   \|f
+--R  /
+--R             4      2  +-+4+-+3 4+-+3
+--R     (16e f x  + 16e )\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                           +------------------------------------------+
+--R                           |      +---------------------------+
+--R                           |      |     4 2      2 2       4 2
+--R                           |   3  |- 81a f  + 18a c e f - c e
+--R                           |64e f |---------------------------  - 3a c
+--R                           |      |               7 3
+--R                  4     2  |     \|         16384e f
+--R         (- 2e f x  - 2e ) |------------------------------------------
+--R                           |                      3
+--R                          \|                   32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                    1024c e f  |---------------------------  - 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                  + 
+--R                         2 3
+--R                    24a c e f
+--R             *
+--R                 +------------------------------------------+
+--R                 |      +---------------------------+
+--R                 |      |     4 2      2 2       4 2
+--R                 |   3  |- 81a f  + 18a c e f - c e
+--R                 |64e f |---------------------------  - 3a c
+--R                 |      |               7 3
+--R                 |     \|         16384e f
+--R                 |------------------------------------------
+--R                 |                      3
+--R                \|                   32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R                         +--------------------------------------------+
+--R                         |        +---------------------------+
+--R                         |        |     4 2      2 2       4 2
+--R                         |     3  |- 81a f  + 18a c e f - c e
+--R                         |- 64e f |---------------------------  - 3a c
+--R                         |        |               7 3
+--R                4     2  |       \|         16384e f
+--R         (2e f x  + 2e ) |--------------------------------------------
+--R                         |                       3
+--R                        \|                    32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                    1024c e f  |---------------------------  + 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                  + 
+--R                           2 3
+--R                    - 24a c e f
+--R             *
+--R                 +--------------------------------------------+
+--R                 |        +---------------------------+
+--R                 |        |     4 2      2 2       4 2
+--R                 |     3  |- 81a f  + 18a c e f - c e
+--R                 |- 64e f |---------------------------  - 3a c
+--R                 |        |               7 3
+--R                 |       \|         16384e f
+--R                 |--------------------------------------------
+--R                 |                       3
+--R                \|                    32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R                           +--------------------------------------------+
+--R                           |        +---------------------------+
+--R                           |        |     4 2      2 2       4 2
+--R                           |     3  |- 81a f  + 18a c e f - c e
+--R                           |- 64e f |---------------------------  - 3a c
+--R                           |        |               7 3
+--R                  4     2  |       \|         16384e f
+--R         (- 2e f x  - 2e ) |--------------------------------------------
+--R                           |                       3
+--R                          \|                    32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                  - 1024c e f  |---------------------------  - 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                + 
+--R                       2 3
+--R                  24a c e f
+--R             *
+--R                 +--------------------------------------------+
+--R                 |        +---------------------------+
+--R                 |        |     4 2      2 2       4 2
+--R                 |     3  |- 81a f  + 18a c e f - c e
+--R                 |- 64e f |---------------------------  - 3a c
+--R                 |        |               7 3
+--R                 |       \|         16384e f
+--R                 |--------------------------------------------
+--R                 |                       3
+--R                \|                    32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R                         +------------------------------------------+
+--R                         |      +---------------------------+
+--R                         |      |     4 2      2 2       4 2
+--R                         |   3  |- 81a f  + 18a c e f - c e
+--R                         |64e f |---------------------------  - 3a c
+--R                         |      |               7 3
+--R                4     2  |     \|         16384e f
+--R         (2e f x  + 2e ) |------------------------------------------
+--R                         |                      3
+--R                        \|                   32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                  - 1024c e f  |---------------------------  + 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                + 
+--R                         2 3
+--R                  - 24a c e f
+--R             *
+--R                 +------------------------------------------+
+--R                 |      +---------------------------+
+--R                 |      |     4 2      2 2       4 2
+--R                 |   3  |- 81a f  + 18a c e f - c e
+--R                 |64e f |---------------------------  - 3a c
+--R                 |      |               7 3
+--R                 |     \|         16384e f
+--R                 |------------------------------------------
+--R                 |                      3
+--R                \|                   32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R          3
+--R       c x  + a x
+--R  /
+--R           4     2
+--R     4e f x  + 4e
+--R                                         Type: Union(Expression(Integer),...)
+--E 539
+
+--S 540 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                              +------------------------------------------+
+--R                              |      +---------------------------+
+--R                              |      |     4 2      2 2       4 2
+--R                              |   3  |- 81a f  + 18a c e f - c e
+--R                              |64e f |---------------------------  - 3a c
+--R                              |      |               7 3
+--R               +-+4+-+3 4+-+3 |     \|         16384e f
+--R            8e\|2 \|e   \|f   |------------------------------------------
+--R                              |                      3
+--R                             \|                   32e f
+--R         *
+--R            log
+--R                                +---------------------------+
+--R                                |     4 2      2 2       4 2
+--R                            6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                     1024c e f  |---------------------------  - 216a e f
+--R                                |               7 3
+--R                               \|         16384e f
+--R                   + 
+--R                          2 3
+--R                     24a c e f
+--R                *
+--R                    +------------------------------------------+
+--R                    |      +---------------------------+
+--R                    |      |     4 2      2 2       4 2
+--R                    |   3  |- 81a f  + 18a c e f - c e
+--R                    |64e f |---------------------------  - 3a c
+--R                    |      |               7 3
+--R                    |     \|         16384e f
+--R                    |------------------------------------------
+--R                    |                      3
+--R                   \|                   32e f
+--R               + 
+--R                     4 2    4 2
+--R                 (81a f  - c e )x
+--R     + 
+--R                           +--------------------------------------------+
+--R                           |        +---------------------------+
+--R                           |        |     4 2      2 2       4 2
+--R                           |     3  |- 81a f  + 18a c e f - c e
+--R                           |- 64e f |---------------------------  - 3a c
+--R                           |        |               7 3
+--R            +-+4+-+3 4+-+3 |       \|         16384e f
+--R         8e\|2 \|e   \|f   |--------------------------------------------
+--R                           |                       3
+--R                          \|                    32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                    1024c e f  |---------------------------  + 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                  + 
+--R                           2 3
+--R                    - 24a c e f
+--R             *
+--R                 +--------------------------------------------+
+--R                 |        +---------------------------+
+--R                 |        |     4 2      2 2       4 2
+--R                 |     3  |- 81a f  + 18a c e f - c e
+--R                 |- 64e f |---------------------------  - 3a c
+--R                 |        |               7 3
+--R                 |       \|         16384e f
+--R                 |--------------------------------------------
+--R                 |                       3
+--R                \|                    32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R       -
+--R                              +--------------------------------------------+
+--R                              |        +---------------------------+
+--R                              |        |     4 2      2 2       4 2
+--R                              |     3  |- 81a f  + 18a c e f - c e
+--R                              |- 64e f |---------------------------  - 3a c
+--R                              |        |               7 3
+--R               +-+4+-+3 4+-+3 |       \|         16384e f
+--R            8e\|2 \|e   \|f   |--------------------------------------------
+--R                              |                       3
+--R                             \|                    32e f
+--R         *
+--R            log
+--R                                  +---------------------------+
+--R                                  |     4 2      2 2       4 2
+--R                              6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                     - 1024c e f  |---------------------------  - 216a e f
+--R                                  |               7 3
+--R                                 \|         16384e f
+--R                   + 
+--R                          2 3
+--R                     24a c e f
+--R                *
+--R                    +--------------------------------------------+
+--R                    |        +---------------------------+
+--R                    |        |     4 2      2 2       4 2
+--R                    |     3  |- 81a f  + 18a c e f - c e
+--R                    |- 64e f |---------------------------  - 3a c
+--R                    |        |               7 3
+--R                    |       \|         16384e f
+--R                    |--------------------------------------------
+--R                    |                       3
+--R                   \|                    32e f
+--R               + 
+--R                     4 2    4 2
+--R                 (81a f  - c e )x
+--R     + 
+--R                           +------------------------------------------+
+--R                           |      +---------------------------+
+--R                           |      |     4 2      2 2       4 2
+--R                           |   3  |- 81a f  + 18a c e f - c e
+--R                           |64e f |---------------------------  - 3a c
+--R                           |      |               7 3
+--R            +-+4+-+3 4+-+3 |     \|         16384e f
+--R         8e\|2 \|e   \|f   |------------------------------------------
+--R                           |                      3
+--R                          \|                   32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                  - 1024c e f  |---------------------------  + 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                + 
+--R                         2 3
+--R                  - 24a c e f
+--R             *
+--R                 +------------------------------------------+
+--R                 |      +---------------------------+
+--R                 |      |     4 2      2 2       4 2
+--R                 |   3  |- 81a f  + 18a c e f - c e
+--R                 |64e f |---------------------------  - 3a c
+--R                 |      |               7 3
+--R                 |     \|         16384e f
+--R                 |------------------------------------------
+--R                 |                      3
+--R                \|                   32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R             +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a\|f  + c\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (3a\|f  - c\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|f  + \|e
+--R       (- 6a\|f  - 2c\|e )atan(----------------)
+--R                                     4+-+
+--R                                     \|e
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|f  - \|e
+--R       (- 6a\|f  - 2c\|e )atan(----------------)
+--R                                     4+-+
+--R                                     \|e
+--R  /
+--R         +-+4+-+3 4+-+3
+--R     16e\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 540
+
+--S 541 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4        2  +-+4+-+2         6         4         2  +-+
+--R           ((4c x  + 12a x )\|e \|e   - 3a f x  - 2c e x  + 3a e x )\|f
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2c f x  + 6a f x  + 2c e x  + 6a e)\|e
+--R         + 
+--R                   6         4        2  +-+
+--R           (- c f x  - 6a f x  + c e x )\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R                  4         2        4+-+2
+--R           (3a f x  - 2c e x  - 3a e)\|e
+--R         + 
+--R                   6         4        2         +-+
+--R           (- c f x  - 3a f x  - c e x  - 3a e)\|e
+--R      *
+--R          +-+
+--R         \|f
+--R     + 
+--R           4         2        +-+4+-+2       2 6           4           2      2
+--R     (c f x  - 6a f x  - c e)\|e \|e   + 3a f x  - 3c e f x  - 9a e f x  + c e
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 541
+
+)clear all
+
+--S 542 of 953
+t0:=(b*x+c*x^2)/(e+f*x^4)^2
+--R 
+--R
+--R                2
+--R             c x  + b x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 542
+
+--S 543 of 953
+r0:=1/4*x^2*(b+c*x)/(e*(e+f*x^4))-1/8*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(5/4)*f^(3/4)*sqrt(2))+1/8*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(5/4)*f^(3/4)*sqrt(2))+1/16*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))-1/16*c*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))+_
+   1/4*b*atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R               4        +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       (- c f x  - c e)\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             4        +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       (c f x  + c e)\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R              4         +-+ +-+     x\|2 \|f  + \|e
+--R       (2c f x  + 2c e)\|e \|f atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R              4         +-+ +-+     x\|2 \|f  - \|e
+--R       (2c f x  + 2c e)\|e \|f atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                          2 +-+
+--R              4         +-+4+-+4+-+3     x \|f
+--R       (4b f x  + 4b e)\|2 \|e \|f  atan(------)
+--R                                           +-+
+--R                                          \|e
+--R     + 
+--R            3       2  +-+ +-+4+-+ +-+4+-+3
+--R       (4c x  + 4b x )\|2 \|e \|e \|f \|f
+--R  /
+--R             4      2  +-+ +-+4+-+ +-+4+-+3
+--R     (16e f x  + 16e )\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      4     2
+--R             (- 2e f x  - 2e )
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CJ1  - 16e f %%CJ0 %%CJ1 - 24e f %%CJ0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                    4     2                  4     2
+--R           (- 2e f x  - 2e )%%CJ1 + (- 2e f x  - 2e )%%CJ0
+--R      *
+--R         log
+--R                        2 5 2             3 3 2              3 3 2
+--R                  (2048c e f %%CJ0 + 2048b e f )%%CJ1 + 2048b e f %%CJ0
+--R                + 
+--R                     2 2 2
+--R                  32b c e f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CJ1  - 16e f %%CJ0 %%CJ1 - 24e f %%CJ0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                      2 5 2             3 3 2      2
+--R              (- 2048c e f %%CJ0 - 2048b e f )%%CJ1
+--R            + 
+--R                      2 5 2     2      2 2 2               3 3 2     2
+--R              (- 2048c e f %%CJ0  + 32b c e f)%%CJ1 - 2048b e f %%CJ0
+--R            + 
+--R                 2 2 2              4       5         5        4
+--R              32b c e f %%CJ0 + (64b c f - c e)x - 64b f + 2b c e
+--R     + 
+--R                    4     2
+--R             (2e f x  + 2e )
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CJ1  - 16e f %%CJ0 %%CJ1 - 24e f %%CJ0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                    4     2                  4     2
+--R           (- 2e f x  - 2e )%%CJ1 + (- 2e f x  - 2e )%%CJ0
+--R      *
+--R         log
+--R                          2 5 2             3 3 2              3 3 2
+--R                  (- 2048c e f %%CJ0 - 2048b e f )%%CJ1 - 2048b e f %%CJ0
+--R                + 
+--R                       2 2 2
+--R                  - 32b c e f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CJ1  - 16e f %%CJ0 %%CJ1 - 24e f %%CJ0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                      2 5 2             3 3 2      2
+--R              (- 2048c e f %%CJ0 - 2048b e f )%%CJ1
+--R            + 
+--R                      2 5 2     2      2 2 2               3 3 2     2
+--R              (- 2048c e f %%CJ0  + 32b c e f)%%CJ1 - 2048b e f %%CJ0
+--R            + 
+--R                 2 2 2              4       5         5        4
+--R              32b c e f %%CJ0 + (64b c f - c e)x - 64b f + 2b c e
+--R     + 
+--R                4     2
+--R         (4e f x  + 4e )%%CJ1
+--R      *
+--R         log
+--R                    2 5 2             3 3 2      2
+--R              (4096c e f %%CJ0 + 4096b e f )%%CJ1
+--R            + 
+--R                    2 5 2     2      2 2 2               2 5 2     3
+--R              (4096c e f %%CJ0  - 64b c e f)%%CJ1 + 4096c e f %%CJ0
+--R            + 
+--R                  2 2 2              4       5         5        4
+--R              128b c e f %%CJ0 + (64b c f - c e)x + 64b f + 2b c e
+--R     + 
+--R                4     2
+--R         (4e f x  + 4e )%%CJ0
+--R      *
+--R         log
+--R                     2 5 2     3        3 3 2     2       2 2 2
+--R              - 4096c e f %%CJ0  + 4096b e f %%CJ0  - 192b c e f %%CJ0
+--R            + 
+--R                  4       5         5        4
+--R              (64b c f - c e)x + 64b f - 6b c e
+--R     + 
+--R          3      2
+--R       c x  + b x
+--R  /
+--R           4     2
+--R     4e f x  + 4e
+--R                                         Type: Union(Expression(Integer),...)
+--E 544
+
+--S 545 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                   +-+ +-+4+-+ +-+4+-+3
+--R                8e\|2 \|e \|e \|f \|f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CJ1  - 16e f %%CJ0 %%CJ1 - 24e f %%CJ0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R         + 
+--R                +-+ +-+4+-+ +-+4+-+3           +-+ +-+4+-+ +-+4+-+3
+--R           - 8e\|2 \|e \|e \|f \|f  %%CJ1 - 8e\|2 \|e \|e \|f \|f  %%CJ0
+--R      *
+--R         log
+--R                        2 5 2             3 3 2              3 3 2
+--R                  (2048c e f %%CJ0 + 2048b e f )%%CJ1 + 2048b e f %%CJ0
+--R                + 
+--R                     2 2 2
+--R                  32b c e f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CJ1  - 16e f %%CJ0 %%CJ1 - 24e f %%CJ0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                      2 5 2             3 3 2      2
+--R              (- 2048c e f %%CJ0 - 2048b e f )%%CJ1
+--R            + 
+--R                      2 5 2     2      2 2 2               3 3 2     2
+--R              (- 2048c e f %%CJ0  + 32b c e f)%%CJ1 - 2048b e f %%CJ0
+--R            + 
+--R                 2 2 2              4       5         5        4
+--R              32b c e f %%CJ0 + (64b c f - c e)x - 64b f + 2b c e
+--R     + 
+--R                +-+ +-+4+-+ +-+4+-+3
+--R             8e\|2 \|e \|e \|f \|f
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CJ1  - 16e f %%CJ0 %%CJ1 - 24e f %%CJ0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                +-+ +-+4+-+ +-+4+-+3           +-+ +-+4+-+ +-+4+-+3
+--R           - 8e\|2 \|e \|e \|f \|f  %%CJ1 - 8e\|2 \|e \|e \|f \|f  %%CJ0
+--R      *
+--R         log
+--R                          2 5 2             3 3 2              3 3 2
+--R                  (- 2048c e f %%CJ0 - 2048b e f )%%CJ1 - 2048b e f %%CJ0
+--R                + 
+--R                       2 2 2
+--R                  - 32b c e f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CJ1  - 16e f %%CJ0 %%CJ1 - 24e f %%CJ0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                      2 5 2             3 3 2      2
+--R              (- 2048c e f %%CJ0 - 2048b e f )%%CJ1
+--R            + 
+--R                      2 5 2     2      2 2 2               3 3 2     2
+--R              (- 2048c e f %%CJ0  + 32b c e f)%%CJ1 - 2048b e f %%CJ0
+--R            + 
+--R                 2 2 2              4       5         5        4
+--R              32b c e f %%CJ0 + (64b c f - c e)x - 64b f + 2b c e
+--R     + 
+--R             +-+ +-+4+-+ +-+4+-+3
+--R         16e\|2 \|e \|e \|f \|f  %%CJ1
+--R      *
+--R         log
+--R                    2 5 2             3 3 2      2
+--R              (4096c e f %%CJ0 + 4096b e f )%%CJ1
+--R            + 
+--R                    2 5 2     2      2 2 2               2 5 2     3
+--R              (4096c e f %%CJ0  - 64b c e f)%%CJ1 + 4096c e f %%CJ0
+--R            + 
+--R                  2 2 2              4       5         5        4
+--R              128b c e f %%CJ0 + (64b c f - c e)x + 64b f + 2b c e
+--R     + 
+--R         +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       c\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       - c\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             +-+ +-+4+-+ +-+4+-+3
+--R         16e\|2 \|e \|e \|f \|f  %%CJ0
+--R      *
+--R         log
+--R                     2 5 2     3        3 3 2     2       2 2 2
+--R              - 4096c e f %%CJ0  + 4096b e f %%CJ0  - 192b c e f %%CJ0
+--R            + 
+--R                  4       5         5        4
+--R              (64b c f - c e)x + 64b f - 6b c e
+--R     + 
+--R                          +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|f  + \|e        +-+ +-+     x\|2 \|f  - \|e
+--R       - 2c\|e \|f atan(----------------) - 2c\|e \|f atan(----------------)
+--R                              4+-+                               4+-+
+--R                              \|e                                \|e
+--R     + 
+--R                              2 +-+
+--R            +-+4+-+4+-+3     x \|f
+--R       - 4b\|2 \|e \|f  atan(------)
+--R                               +-+
+--R                              \|e
+--R  /
+--R         +-+ +-+4+-+ +-+4+-+3
+--R     16e\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            4 +-+4+-+2 +-+         6         2 4+-+2 4+-+2
+--R       (2c x \|e \|e  \|f  + (c f x  + 3c e x )\|e  )\|f
+--R     + 
+--R                6        2 4+-+2         2 +-+  +-+         4        +-+4+-+2
+--R       ((- c f x  - c e x )\|e   - 2c e x \|e )\|f  + (c f x  + c e)\|e \|e
+--R     + 
+--R                 4      2
+--R       - 3c e f x  - c e
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 546
+
+)clear all
+
+--S 547 of 953
+t0:=(a+b*x+c*x^2)/(e+f*x^4)^2
+--R 
+--R
+--R              2
+--R           c x  + b x + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 547
+
+--S 548 of 953
+r0:=1/4*x*(a+b*x+c*x^2)/(e*(e+f*x^4))+1/4*b*atan(x^2*sqrt(f)/sqrt(e))/_
+   (e^(3/2)*sqrt(f))+1/16*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*_
+   sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))-_
+   1/16*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-_
+   3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))-1/8*atan(1-f^(1/4)*x*_
+   sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))+_
+   1/8*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/_
+   (e^(7/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                    4      2  +-+        2 4           +-+
+--R         ((- c e f x  - c e )\|f  + (3a f x  + 3a e f)\|e )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                  4      2  +-+          2 4           +-+
+--R         ((c e f x  + c e )\|f  + (- 3a f x  - 3a e f)\|e )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                                +-+4+-+   4+-+
+--R                 4       2  +-+        2 4           +-+      x\|2 \|f  + \|e
+--R       ((2c e f x  + 2c e )\|f  + (6a f x  + 6a e f)\|e )atan(----------------)
+--R                                                                    4+-+
+--R                                                                    \|e
+--R     + 
+--R                                                                +-+4+-+   4+-+
+--R                 4       2  +-+        2 4           +-+      x\|2 \|f  - \|e
+--R       ((2c e f x  + 2c e )\|f  + (6a f x  + 6a e f)\|e )atan(----------------)
+--R                                                                    4+-+
+--R                                                                    \|e
+--R     + 
+--R                                            2 +-+
+--R              4         +-+4+-+3 4+-+3     x \|f
+--R       (4b f x  + 4b e)\|2 \|e   \|f  atan(------)
+--R                                             +-+
+--R                                            \|e
+--R     + 
+--R            3       2         +-+ +-+4+-+3 +-+4+-+3
+--R       (4c x  + 4b x  + 4a x)\|2 \|e \|e  \|f \|f
+--R  /
+--R             4      2  +-+ +-+4+-+3 +-+4+-+3
+--R     (16e f x  + 16e )\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      4     2
+--R             (- 2e f x  - 2e )
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |     3       2      3                   3       2            2
+--R              |- 48e f %%CK1  - 32e f %%CK0 %%CK1 - 48e f %%CK0  - 3a c - 2b
+--R              |--------------------------------------------------------------
+--R              |                                3
+--R             \|                             16e f
+--R         + 
+--R                    4     2                  4     2
+--R           (- 2e f x  - 2e )%%CK1 + (- 2e f x  - 2e )%%CK0
+--R      *
+--R         log
+--R                              2            2  6 3        3 7 2
+--R                      ((18432a c - 49152a b )e f  - 2048c e f )%%CK0
+--R                    + 
+--R                           3   4 3             2        3   5 2
+--R                      6912a b e f  + (2304a b c  - 2048b c)e f
+--R                 *
+--R                    %%CK1
+--R                + 
+--R                        3   4 3             2        3   5 2              5 2 3
+--R                  (6912a b e f  + (2304a b c  - 2048b c)e f )%%CK0 - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48e f %%CK1  - 32e f %%CK0 %%CK1 - 48e f %%CK0  - 3a c - 2b
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16e f
+--R            + 
+--R                            2            2  6 3        3 7 2
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CK0
+--R                + 
+--R                         3   4 3               2        3   5 2
+--R                  - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R             *
+--R                     2
+--R                %%CK1
+--R            + 
+--R                            2            2  6 3        3 7 2      2        5 2 3
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CK0  - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R                %%CK1
+--R            + 
+--R                      3   4 3               2        3   5 2      2
+--R              (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CK0
+--R            + 
+--R                           5 2 3          2 2          4  3 2
+--R                    - 1944a e f  + (- 864a b c + 768a b )e f
+--R                  + 
+--R                          4      2 3  4
+--R                    (24a c  - 32b c )e f
+--R             *
+--R                %%CK0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                     4          3 3    2         2   3        3 2      5   2
+--R              (- 486a b c + 216a b )e f  + (- 72a b c  - 24a b c  + 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R                    4     2
+--R             (2e f x  + 2e )
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |     3       2      3                   3       2            2
+--R              |- 48e f %%CK1  - 32e f %%CK0 %%CK1 - 48e f %%CK0  - 3a c - 2b
+--R              |--------------------------------------------------------------
+--R              |                                3
+--R             \|                             16e f
+--R         + 
+--R                    4     2                  4     2
+--R           (- 2e f x  - 2e )%%CK1 + (- 2e f x  - 2e )%%CK0
+--R      *
+--R         log
+--R                                2            2  6 3        3 7 2
+--R                      ((- 18432a c + 49152a b )e f  + 2048c e f )%%CK0
+--R                    + 
+--R                             3   4 3               2        3   5 2
+--R                      - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R                 *
+--R                    %%CK1
+--R                + 
+--R                          3   4 3               2        3   5 2
+--R                  (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CK0
+--R                + 
+--R                     5 2 3        2 2          4  3 2           4      2 3  4
+--R                1944a e f  + (864a b c - 768a b )e f  + (- 24a c  + 32b c )e f
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48e f %%CK1  - 32e f %%CK0 %%CK1 - 48e f %%CK0  - 3a c - 2b
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16e f
+--R            + 
+--R                            2            2  6 3        3 7 2
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CK0
+--R                + 
+--R                         3   4 3               2        3   5 2
+--R                  - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R             *
+--R                     2
+--R                %%CK1
+--R            + 
+--R                            2            2  6 3        3 7 2      2        5 2 3
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CK0  - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R                %%CK1
+--R            + 
+--R                      3   4 3               2        3   5 2      2
+--R              (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CK0
+--R            + 
+--R                           5 2 3          2 2          4  3 2
+--R                    - 1944a e f  + (- 864a b c + 768a b )e f
+--R                  + 
+--R                          4      2 3  4
+--R                    (24a c  - 32b c )e f
+--R             *
+--R                %%CK0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                     4          3 3    2         2   3        3 2      5   2
+--R              (- 486a b c + 216a b )e f  + (- 72a b c  - 24a b c  + 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R                4     2
+--R         (4e f x  + 4e )%%CK1
+--R      *
+--R         log
+--R                          2            2  6 3        3 7 2               3   4 3
+--R                  ((36864a c - 98304a b )e f  - 4096c e f )%%CK0 + 13824a b e f
+--R                + 
+--R                            2        3   5 2
+--R                  (4608a b c  - 4096b c)e f
+--R             *
+--R                     2
+--R                %%CK1
+--R            + 
+--R                          2            2  6 3        3 7 2      2        5 2 3
+--R                  ((36864a c - 98304a b )e f  - 4096c e f )%%CK0  + 3888a e f
+--R                + 
+--R                        2 2           4  3 2           4      2 3  4
+--R                  (1728a b c - 1536a b )e f  + (- 48a c  + 64b c )e f
+--R             *
+--R                %%CK1
+--R            + 
+--R                      2            2  6 3        3 7 2      3
+--R              ((36864a c - 98304a b )e f  - 4096c e f )%%CK0
+--R            + 
+--R                          3 2        2 2           4  3 2
+--R                    (1728a c  - 3456a b c - 3072a b )e f
+--R                  + 
+--R                             4       2 3  4
+--R                    (- 192a c  - 128b c )e f
+--R             *
+--R                %%CK0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4          3 3    2        2   3        3 2      5   2
+--R              (162a b c + 648a b )e f  + (144a b c  - 72a b c  - 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R                4     2
+--R         (4e f x  + 4e )%%CK0
+--R      *
+--R         log
+--R                        2            2  6 3        3 7 2      3
+--R              ((- 36864a c + 98304a b )e f  + 4096c e f )%%CK0
+--R            + 
+--R                     3   4 3             2        3   5 2      2
+--R              (13824a b e f  + (4608a b c  - 4096b c)e f )%%CK0
+--R            + 
+--R                       5 2 3           3 2        2 2           4  3 2
+--R                  3888a e f  + (- 1728a c  + 5184a b c + 1536a b )e f
+--R                + 
+--R                         4       2 3  4
+--R                  (144a c  + 192b c )e f
+--R             *
+--R                %%CK0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4           3 3    2          3 2      5   2        5 3
+--R              (810a b c - 1080a b )e f  + (120a b c  - 64b c)e f + 6b c e
+--R     + 
+--R          3      2
+--R       c x  + b x  + a x
+--R  /
+--R           4     2
+--R     4e f x  + 4e
+--R                                         Type: Union(Expression(Integer),...)
+--E 549
+
+--S 550 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                   +-+ +-+4+-+3 +-+4+-+3
+--R                8e\|2 \|e \|e  \|f \|f
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48e f %%CK1  - 32e f %%CK0 %%CK1 - 48e f %%CK0  - 3a c - 2b
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 8e\|2 \|e \|e  \|f \|f  %%CK1 - 8e\|2 \|e \|e  \|f \|f  %%CK0
+--R      *
+--R         log
+--R                              2            2  6 3        3 7 2
+--R                      ((18432a c - 49152a b )e f  - 2048c e f )%%CK0
+--R                    + 
+--R                           3   4 3             2        3   5 2
+--R                      6912a b e f  + (2304a b c  - 2048b c)e f
+--R                 *
+--R                    %%CK1
+--R                + 
+--R                        3   4 3             2        3   5 2              5 2 3
+--R                  (6912a b e f  + (2304a b c  - 2048b c)e f )%%CK0 - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48e f %%CK1  - 32e f %%CK0 %%CK1 - 48e f %%CK0  - 3a c - 2b
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16e f
+--R            + 
+--R                            2            2  6 3        3 7 2
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CK0
+--R                + 
+--R                         3   4 3               2        3   5 2
+--R                  - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R             *
+--R                     2
+--R                %%CK1
+--R            + 
+--R                            2            2  6 3        3 7 2      2        5 2 3
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CK0  - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R                %%CK1
+--R            + 
+--R                      3   4 3               2        3   5 2      2
+--R              (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CK0
+--R            + 
+--R                           5 2 3          2 2          4  3 2
+--R                    - 1944a e f  + (- 864a b c + 768a b )e f
+--R                  + 
+--R                          4      2 3  4
+--R                    (24a c  - 32b c )e f
+--R             *
+--R                %%CK0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                     4          3 3    2         2   3        3 2      5   2
+--R              (- 486a b c + 216a b )e f  + (- 72a b c  - 24a b c  + 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R                +-+ +-+4+-+3 +-+4+-+3
+--R             8e\|2 \|e \|e  \|f \|f
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |     3       2      3                   3       2            2
+--R              |- 48e f %%CK1  - 32e f %%CK0 %%CK1 - 48e f %%CK0  - 3a c - 2b
+--R              |--------------------------------------------------------------
+--R              |                                3
+--R             \|                             16e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 8e\|2 \|e \|e  \|f \|f  %%CK1 - 8e\|2 \|e \|e  \|f \|f  %%CK0
+--R      *
+--R         log
+--R                                2            2  6 3        3 7 2
+--R                      ((- 18432a c + 49152a b )e f  + 2048c e f )%%CK0
+--R                    + 
+--R                             3   4 3               2        3   5 2
+--R                      - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R                 *
+--R                    %%CK1
+--R                + 
+--R                          3   4 3               2        3   5 2
+--R                  (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CK0
+--R                + 
+--R                     5 2 3        2 2          4  3 2           4      2 3  4
+--R                1944a e f  + (864a b c - 768a b )e f  + (- 24a c  + 32b c )e f
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48e f %%CK1  - 32e f %%CK0 %%CK1 - 48e f %%CK0  - 3a c - 2b
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16e f
+--R            + 
+--R                            2            2  6 3        3 7 2
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CK0
+--R                + 
+--R                         3   4 3               2        3   5 2
+--R                  - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R             *
+--R                     2
+--R                %%CK1
+--R            + 
+--R                            2            2  6 3        3 7 2      2        5 2 3
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CK0  - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R                %%CK1
+--R            + 
+--R                      3   4 3               2        3   5 2      2
+--R              (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CK0
+--R            + 
+--R                           5 2 3          2 2          4  3 2
+--R                    - 1944a e f  + (- 864a b c + 768a b )e f
+--R                  + 
+--R                          4      2 3  4
+--R                    (24a c  - 32b c )e f
+--R             *
+--R                %%CK0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                     4          3 3    2         2   3        3 2      5   2
+--R              (- 486a b c + 216a b )e f  + (- 72a b c  - 24a b c  + 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+3
+--R         16e\|2 \|e \|e  \|f \|f  %%CK1
+--R      *
+--R         log
+--R                          2            2  6 3        3 7 2               3   4 3
+--R                  ((36864a c - 98304a b )e f  - 4096c e f )%%CK0 + 13824a b e f
+--R                + 
+--R                            2        3   5 2
+--R                  (4608a b c  - 4096b c)e f
+--R             *
+--R                     2
+--R                %%CK1
+--R            + 
+--R                          2            2  6 3        3 7 2      2        5 2 3
+--R                  ((36864a c - 98304a b )e f  - 4096c e f )%%CK0  + 3888a e f
+--R                + 
+--R                        2 2           4  3 2           4      2 3  4
+--R                  (1728a b c - 1536a b )e f  + (- 48a c  + 64b c )e f
+--R             *
+--R                %%CK1
+--R            + 
+--R                      2            2  6 3        3 7 2      3
+--R              ((36864a c - 98304a b )e f  - 4096c e f )%%CK0
+--R            + 
+--R                          3 2        2 2           4  3 2
+--R                    (1728a c  - 3456a b c - 3072a b )e f
+--R                  + 
+--R                             4       2 3  4
+--R                    (- 192a c  - 128b c )e f
+--R             *
+--R                %%CK0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4          3 3    2        2   3        3 2      5   2
+--R              (162a b c + 648a b )e f  + (144a b c  - 72a b c  - 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R            +-+        +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (c e\|f  - 3a f\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              +-+        +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- c e\|f  + 3a f\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+3
+--R         16e\|2 \|e \|e  \|f \|f  %%CK0
+--R      *
+--R         log
+--R                        2            2  6 3        3 7 2      3
+--R              ((- 36864a c + 98304a b )e f  + 4096c e f )%%CK0
+--R            + 
+--R                     3   4 3             2        3   5 2      2
+--R              (13824a b e f  + (4608a b c  - 4096b c)e f )%%CK0
+--R            + 
+--R                       5 2 3           3 2        2 2           4  3 2
+--R                  3888a e f  + (- 1728a c  + 5184a b c + 1536a b )e f
+--R                + 
+--R                         4       2 3  4
+--R                  (144a c  + 192b c )e f
+--R             *
+--R                %%CK0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4           3 3    2          3 2      5   2        5 3
+--R              (810a b c - 1080a b )e f  + (120a b c  - 64b c)e f + 6b c e
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|f  + \|e
+--R       (- 2c e\|f  - 6a f\|e )atan(----------------)
+--R                                         4+-+
+--R                                         \|e
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|f  - \|e
+--R       (- 2c e\|f  - 6a f\|e )atan(----------------)
+--R                                         4+-+
+--R                                         \|e
+--R     + 
+--R                                2 +-+
+--R            +-+4+-+3 4+-+3     x \|f
+--R       - 4b\|2 \|e   \|f  atan(------)
+--R                                 +-+
+--R                                \|e
+--R  /
+--R         +-+ +-+4+-+3 +-+4+-+3
+--R     16e\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4        2  +-+4+-+2         6         4         2  +-+
+--R           ((4c x  + 12a x )\|e \|e   - 3a f x  - 2c e x  + 3a e x )\|f
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2c f x  + 6a f x  + 2c e x  + 6a e)\|e
+--R         + 
+--R                   6         4        2  +-+
+--R           (- c f x  - 6a f x  + c e x )\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R                  4         2        4+-+2
+--R           (3a f x  - 2c e x  - 3a e)\|e
+--R         + 
+--R                   6         4        2         +-+
+--R           (- c f x  - 3a f x  - c e x  - 3a e)\|e
+--R      *
+--R          +-+
+--R         \|f
+--R     + 
+--R           4         2        +-+4+-+2       2 6           4           2      2
+--R     (c f x  - 6a f x  - c e)\|e \|e   + 3a f x  - 3c e f x  - 9a e f x  + c e
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 551
+
+)clear all
+
+--S 552 of 953
+t0:=d*x^3/(e+f*x^4)^2
+--R 
+--R
+--R                   3
+--R                d x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 552
+
+--S 553 of 953
+r0:=-1/4*d/(f*(e+f*x^4))
+--R 
+--R
+--R              1
+--R              - d
+--R              4
+--R   (2)  - ----------
+--R           2 4
+--R          f x  + e f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 553
+
+--S 554 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                d
+--R   (3)  - ------------
+--R            2 4
+--R          4f x  + 4e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 554
+
+--S 555 of 953
+m0a:=a0.1-r0
+--R 
+--R   There are 33 exposed and 3 unexposed library operations named elt 
+--R      having 2 argument(s) but none was determined to be applicable. 
+--R      Use HyperDoc Browse, or issue
+--R                               )display op elt
+--R      to learn more about the available operations. Perhaps 
+--R      package-calling the operation or using coercions on the arguments
+--R      will allow you to apply the operation.
+--R 
+--R   Cannot find a definition or applicable library operation named elt 
+--R      with argument type(s) 
+--R                             Expression(Integer)
+--R                               PositiveInteger
+--R      
+--R      Perhaps you should use "@" to indicate the required return type, 
+--R      or "$" to specify which version of the function you need.
+--E 555
+
+--S 556 of 953
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Polynomial(Integer)
+--E 556
+
+--S 557 of 953
+m0b:=a0.2-r0
+--R 
+--R   There are 33 exposed and 3 unexposed library operations named elt 
+--R      having 2 argument(s) but none was determined to be applicable. 
+--R      Use HyperDoc Browse, or issue
+--R                               )display op elt
+--R      to learn more about the available operations. Perhaps 
+--R      package-calling the operation or using coercions on the arguments
+--R      will allow you to apply the operation.
+--R 
+--R   Cannot find a definition or applicable library operation named elt 
+--R      with argument type(s) 
+--R                             Expression(Integer)
+--R                               PositiveInteger
+--R      
+--R      Perhaps you should use "@" to indicate the required return type, 
+--R      or "$" to specify which version of the function you need.
+--E 557
+
+--S 558 of 953
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Polynomial(Integer)
+--E 558
+
+)clear all
+
+--S 559 of 953
+t0:=(a+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R                 3
+--R              d x  + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 559
+
+--S 560 of 953
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*a*x/(e*(e+f*x^4))-3/8*a*atan(1-f^(1/4)*x*_
+   sqrt(2)/e^(1/4))/(e^(7/4)*f^(1/4)*sqrt(2))+3/8*a*atan(1+f^(1/4)*x*_
+   sqrt(2)/e^(1/4))/(e^(7/4)*f^(1/4)*sqrt(2))-3/16*a*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))+_
+   3/16*a*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*_
+   f^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            2 4                +-+4+-+4+-+    2 +-+    +-+
+--R       (3a f x  + 3a e f)log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              2 4                  +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a f x  - 3a e f)log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                +-+4+-+   4+-+
+--R            2 4               x\|2 \|f  + \|e
+--R       (6a f x  + 6a e f)atan(----------------)
+--R                                    4+-+
+--R                                    \|e
+--R     + 
+--R                                +-+4+-+   4+-+
+--R            2 4               x\|2 \|f  - \|e                     +-+4+-+3 4+-+
+--R       (6a f x  + 6a e f)atan(----------------) + (4a f x - 4d e)\|2 \|e   \|f
+--R                                    4+-+
+--R                                    \|e
+--R  /
+--R           2 4      2   +-+4+-+3 4+-+
+--R     (16e f x  + 16e f)\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         +----------+          +----------+
+--R                         |       4             |       4
+--R            2 4     2    |    81a           2  |    81a
+--R       (4e f x  + 4e f)  |- -------- log(16e   |- -------- + 3a x)
+--R                        4|        7           4|        7
+--R                        \|  65536e f          \|  65536e f
+--R     + 
+--R                           +----------+            +----------+
+--R                           |       4               |       4
+--R              2 4     2    |    81a             2  |    81a
+--R       (- 4e f x  - 4e f)  |- -------- log(- 16e   |- -------- + 3a x)
+--R                          4|        7             4|        7
+--R                          \|  65536e f            \|  65536e f
+--R     + 
+--R                                                  +----------+
+--R                                                  |       4
+--R                                               2  |    81a
+--R                           +----------+     16e   |- --------
+--R                           |       4             4|        7
+--R              2 4     2    |    81a              \|  65536e f
+--R       (- 8e f x  - 8e f)  |- -------- atan(----------------- + a f x - d e
+--R                          4|        7              3a x
+--R                          \|  65536e f
+--R  /
+--R         2 4     2
+--R     4e f x  + 4e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 561
+
+--S 562 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +-+4+-+4+-+    2 +-+    +-+
+--R       - 3a log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                +----------+                    +----------+
+--R                |       4                       |       4
+--R           +-+  |    81a    4+-+3 4+-+       2  |    81a
+--R       16e\|2   |- -------- \|e   \|f log(16e   |- -------- + 3a x)
+--R               4|        7                     4|        7
+--R               \|  65536e f                    \|  65536e f
+--R     + 
+--R                  +----------+                      +----------+
+--R                  |       4                         |       4
+--R             +-+  |    81a    4+-+3 4+-+         2  |    81a
+--R       - 16e\|2   |- -------- \|e   \|f log(- 16e   |- -------- + 3a x)
+--R                 4|        7                       4|        7
+--R                 \|  65536e f                      \|  65536e f
+--R     + 
+--R                                                           +-+4+-+   4+-+
+--R                  +-+4+-+4+-+    2 +-+    +-+            x\|2 \|f  + \|e
+--R       3a log(- x\|2 \|e \|f  + x \|f  + \|e ) - 6a atan(----------------)
+--R                                                               4+-+
+--R                                                               \|e
+--R     + 
+--R                   +-+4+-+   4+-+
+--R                 x\|2 \|f  - \|e
+--R       - 6a atan(----------------)
+--R                       4+-+
+--R                       \|e
+--R     + 
+--R                                                   +----------+
+--R                                                   |       4
+--R                                                2  |    81a
+--R                  +----------+               16e   |- --------
+--R                  |       4                       4|        7
+--R             +-+  |    81a    4+-+3 4+-+          \|  65536e f
+--R       - 32e\|2   |- -------- \|e   \|f atan(-----------------)
+--R                 4|        7                        3a x
+--R                 \|  65536e f
+--R  /
+--R         +-+4+-+3 4+-+
+--R     16e\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                2 +-+4+-+2         6         2  +-+          4        4+-+2
+--R           (6a x \|e \|e   + 3a f x  + 3a e x )\|f  + (9a f x  + 3a e)\|e
+--R         + 
+--R                    4         +-+
+--R           (- 3a f x  - 3a e)\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R               4 +-+ +-+       2 6           2
+--R       - 6a f x \|e \|f  - 3a f x  - 9a e f x
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 563
+
+)clear all
+
+--S 564 of 953
+t0:=(b*x+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R                3
+--R             d x  + b x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 564
+
+--S 565 of 953
+r0:=1/4*(-d*e+b*f*x^2)/(e*f*(e+f*x^4))+1/4*b*atan(x^2*sqrt(f)/sqrt(e))/_
+   (e^(3/2)*sqrt(f))
+--R 
+--R
+--R                              2 +-+
+--R            2 4              x \|f           2        +-+ +-+
+--R        (b f x  + b e f)atan(------) + (b f x  - d e)\|e \|f
+--R                               +-+
+--R                              \|e
+--R   (2)  -----------------------------------------------------
+--R                            2 4     2   +-+ +-+
+--R                       (4e f x  + 4e f)\|e \|f
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                            4      +-----+         2
+--R        2 4             (f x  - e)\|- e f  + 2e f x            2         +-----+
+--R    (b f x  + b e f)log(----------------------------) + (2b f x  - 2d e)\|- e f
+--R                                     4
+--R                                  f x  + e
+--R   [----------------------------------------------------------------------------
+--R                                   2 4     2   +-----+
+--R                              (8e f x  + 8e f)\|- e f
+--R     ,
+--R                          2 +---+
+--R        2 4              x \|e f           2        +---+
+--R    (b f x  + b e f)atan(--------) + (b f x  - d e)\|e f
+--R                             e
+--R    -----------------------------------------------------]
+--R                         2 4     2   +---+
+--R                    (4e f x  + 4e f)\|e f
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 566
+
+--S 567 of 953
+m0:=a0-r0
+--R 
+--R   There are 12 exposed and 3 unexposed library operations named - 
+--R      having 2 argument(s) but none was determined to be applicable. 
+--R      Use HyperDoc Browse, or issue
+--R                                )display op -
+--R      to learn more about the available operations. Perhaps 
+--R      package-calling the operation or using coercions on the arguments
+--R      will allow you to apply the operation.
+--R 
+--R   Cannot find a definition or applicable library operation named - 
+--R      with argument type(s) 
+--R                          List(Expression(Integer))
+--R                             Expression(Integer)
+--R      
+--R      Perhaps you should use "@" to indicate the required return type, 
+--R      or "$" to specify which version of the function you need.
+--E 567
+
+--S 568 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Polynomial(Integer)
+--E 568
+
+)clear all
+
+--S 569 of 953
+t0:=(a+b*x+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R              3
+--R           d x  + b x + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 569
+
+--S 570 of 953
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*x*(a+b*x)/(e*(e+f*x^4))-3/8*a*atan(1-f^(1/4)*_
+   x*sqrt(2)/e^(1/4))/(e^(7/4)*f^(1/4)*sqrt(2))+3/8*a*atan(1+f^(1/4)*x*_
+   sqrt(2)/e^(1/4))/(e^(7/4)*f^(1/4)*sqrt(2))-3/16*a*log(-e^(1/4)*f^(1/4)*_
+   x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))+3/16*a*_
+   log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*_
+   sqrt(2))+1/4*b*atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R            2 4           +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       (3a f x  + 3a e f)\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              2 4           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a f x  - 3a e f)\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R            2 4           +-+ +-+     x\|2 \|f  + \|e
+--R       (6a f x  + 6a e f)\|e \|f atan(----------------)
+--R                                            4+-+
+--R                                            \|e
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R            2 4           +-+ +-+     x\|2 \|f  - \|e
+--R       (6a f x  + 6a e f)\|e \|f atan(----------------)
+--R                                            4+-+
+--R                                            \|e
+--R     + 
+--R                                             2 +-+
+--R            2 4           +-+4+-+3 4+-+     x \|f
+--R       (4b f x  + 4b e f)\|2 \|e   \|f atan(------)
+--R                                              +-+
+--R                                             \|e
+--R     + 
+--R              2                  +-+ +-+4+-+3 +-+4+-+
+--R       (4b f x  + 4a f x - 4d e)\|2 \|e \|e  \|f \|f
+--R  /
+--R           2 4      2   +-+ +-+4+-+3 +-+4+-+
+--R     (16e f x  + 16e f)\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2 4     2
+--R             (2e f x  + 2e f)
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CM1  - 16e f %%CM0 %%CM1 - 24e f %%CM0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                  2 4     2                 2 4     2
+--R           (- 2e f x  - 2e f)%%CM1 + (- 2e f x  - 2e f)%%CM0
+--R      *
+--R         log
+--R                         2 6               2   4               2   4
+--R                  (16384b e f %%CM0 - 2304a b e f)%%CM1 - 2304a b e f %%CM0
+--R                + 
+--R                      4 2        4 3
+--R                  648a e f - 256b e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CM1  - 16e f %%CM0 %%CM1 - 24e f %%CM0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                     2 6               2   4       2
+--R              (16384b e f %%CM0 - 2304a b e f)%%CM1
+--R            + 
+--R                     2 6       2       4 2        4 3              2   4       2
+--R              (16384b e f %%CM0  - 648a e f + 256b e )%%CM1 - 2304a b e f %%CM0
+--R            + 
+--R                     4 2        4 3              5          4         2 3
+--R              (- 648a e f + 256b e )%%CM0 + (243a f - 192a b e)x + 72a b e
+--R     + 
+--R                    2 4     2
+--R             (- 2e f x  - 2e f)
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CM1  - 16e f %%CM0 %%CM1 - 24e f %%CM0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                  2 4     2                 2 4     2
+--R           (- 2e f x  - 2e f)%%CM1 + (- 2e f x  - 2e f)%%CM0
+--R      *
+--R         log
+--R                           2 6               2   4               2   4
+--R                  (- 16384b e f %%CM0 + 2304a b e f)%%CM1 + 2304a b e f %%CM0
+--R                + 
+--R                        4 2        4 3
+--R                  - 648a e f + 256b e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CM1  - 16e f %%CM0 %%CM1 - 24e f %%CM0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                     2 6               2   4       2
+--R              (16384b e f %%CM0 - 2304a b e f)%%CM1
+--R            + 
+--R                     2 6       2       4 2        4 3              2   4       2
+--R              (16384b e f %%CM0  - 648a e f + 256b e )%%CM1 - 2304a b e f %%CM0
+--R            + 
+--R                     4 2        4 3              5          4         2 3
+--R              (- 648a e f + 256b e )%%CM0 + (243a f - 192a b e)x + 72a b e
+--R     + 
+--R              2 4     2
+--R         (4e f x  + 4e f)%%CM1
+--R      *
+--R         log
+--R                       2 6               2   4       2
+--R              (- 32768b e f %%CM0 + 4608a b e f)%%CM1
+--R            + 
+--R                       2 6       2        4 2        4 3
+--R              (- 32768b e f %%CM0  + 1296a e f - 512b e )%%CM1
+--R            + 
+--R                      2 6       3        4 3             5          4
+--R              - 32768b e f %%CM0  - 1024b e %%CM0 + (243a f - 192a b e)x
+--R            + 
+--R                  2 3
+--R              216a b e
+--R     + 
+--R              2 4     2
+--R         (4e f x  + 4e f)%%CM0
+--R      *
+--R         log
+--R                    2 6       3        2   4       2
+--R              32768b e f %%CM0  + 4608a b e f %%CM0
+--R            + 
+--R                    4 2        4 3              5          4          2 3
+--R              (1296a e f + 512b e )%%CM0 + (243a f - 192a b e)x - 360a b e
+--R     + 
+--R            2
+--R       b f x  + a f x - d e
+--R  /
+--R         2 4     2
+--R     4e f x  + 4e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 571
+
+--S 572 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+ +-+4+-+3 +-+4+-+
+--R             8e\|2 \|e \|e  \|f \|f
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CM1  - 16e f %%CM0 %%CM1 - 24e f %%CM0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+           +-+ +-+4+-+3 +-+4+-+
+--R           - 8e\|2 \|e \|e  \|f \|f %%CM1 - 8e\|2 \|e \|e  \|f \|f %%CM0
+--R      *
+--R         log
+--R                         2 6               2   4               2   4
+--R                  (16384b e f %%CM0 - 2304a b e f)%%CM1 - 2304a b e f %%CM0
+--R                + 
+--R                      4 2        4 3
+--R                  648a e f - 256b e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CM1  - 16e f %%CM0 %%CM1 - 24e f %%CM0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                     2 6               2   4       2
+--R              (16384b e f %%CM0 - 2304a b e f)%%CM1
+--R            + 
+--R                     2 6       2       4 2        4 3              2   4       2
+--R              (16384b e f %%CM0  - 648a e f + 256b e )%%CM1 - 2304a b e f %%CM0
+--R            + 
+--R                     4 2        4 3              5          4         2 3
+--R              (- 648a e f + 256b e )%%CM0 + (243a f - 192a b e)x + 72a b e
+--R     + 
+--R           -
+--R                   +-+ +-+4+-+3 +-+4+-+
+--R                8e\|2 \|e \|e  \|f \|f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CM1  - 16e f %%CM0 %%CM1 - 24e f %%CM0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+           +-+ +-+4+-+3 +-+4+-+
+--R           - 8e\|2 \|e \|e  \|f \|f %%CM1 - 8e\|2 \|e \|e  \|f \|f %%CM0
+--R      *
+--R         log
+--R                           2 6               2   4               2   4
+--R                  (- 16384b e f %%CM0 + 2304a b e f)%%CM1 + 2304a b e f %%CM0
+--R                + 
+--R                        4 2        4 3
+--R                  - 648a e f + 256b e
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CM1  - 16e f %%CM0 %%CM1 - 24e f %%CM0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                     2 6               2   4       2
+--R              (16384b e f %%CM0 - 2304a b e f)%%CM1
+--R            + 
+--R                     2 6       2       4 2        4 3              2   4       2
+--R              (16384b e f %%CM0  - 648a e f + 256b e )%%CM1 - 2304a b e f %%CM0
+--R            + 
+--R                     4 2        4 3              5          4         2 3
+--R              (- 648a e f + 256b e )%%CM0 + (243a f - 192a b e)x + 72a b e
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+
+--R         16e\|2 \|e \|e  \|f \|f %%CM1
+--R      *
+--R         log
+--R                       2 6               2   4       2
+--R              (- 32768b e f %%CM0 + 4608a b e f)%%CM1
+--R            + 
+--R                       2 6       2        4 2        4 3
+--R              (- 32768b e f %%CM0  + 1296a e f - 512b e )%%CM1
+--R            + 
+--R                      2 6       3        4 3             5          4
+--R              - 32768b e f %%CM0  - 1024b e %%CM0 + (243a f - 192a b e)x
+--R            + 
+--R                  2 3
+--R              216a b e
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+
+--R         16e\|2 \|e \|e  \|f \|f %%CM0
+--R      *
+--R         log
+--R                    2 6       3        2   4       2
+--R              32768b e f %%CM0  + 4608a b e f %%CM0
+--R            + 
+--R                    4 2        4 3              5          4          2 3
+--R              (1296a e f + 512b e )%%CM0 + (243a f - 192a b e)x - 360a b e
+--R     + 
+--R            +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       - 3a\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R          +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       3a\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                          +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|f  + \|e        +-+ +-+     x\|2 \|f  - \|e
+--R       - 6a\|e \|f atan(----------------) - 6a\|e \|f atan(----------------)
+--R                              4+-+                               4+-+
+--R                              \|e                                \|e
+--R     + 
+--R                               2 +-+
+--R            +-+4+-+3 4+-+     x \|f
+--R       - 4b\|2 \|e   \|f atan(------)
+--R                                +-+
+--R                               \|e
+--R  /
+--R         +-+ +-+4+-+3 +-+4+-+
+--R     16e\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                2 +-+4+-+2         6         2  +-+          4        4+-+2
+--R           (6a x \|e \|e   + 3a f x  + 3a e x )\|f  + (9a f x  + 3a e)\|e
+--R         + 
+--R                    4         +-+
+--R           (- 3a f x  - 3a e)\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R               4 +-+ +-+       2 6           2
+--R       - 6a f x \|e \|f  - 3a f x  - 9a e f x
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 573
+
+)clear all
+
+--S 574 of 953
+t0:=(c*x^2+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R               3      2
+--R            d x  + c x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 574
+
+--S 575 of 953
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*c*x^3/(e*(e+f*x^4))-1/8*c*atan(1-f^(1/4)*x*_
+   sqrt(2)/e^(1/4))/(e^(5/4)*f^(3/4)*sqrt(2))+1/8*c*atan(1+f^(1/4)*x*_
+   sqrt(2)/e^(1/4))/(e^(5/4)*f^(3/4)*sqrt(2))+1/16*c*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))-_
+   1/16*c*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/_
+   (e^(5/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2 4               +-+4+-+4+-+    2 +-+    +-+
+--R       (- c f x  - c e f)log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           2 4                 +-+4+-+4+-+    2 +-+    +-+
+--R       (c f x  + c e f)log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                +-+4+-+   4+-+
+--R            2 4               x\|2 \|f  + \|e
+--R       (2c f x  + 2c e f)atan(----------------)
+--R                                    4+-+
+--R                                    \|e
+--R     + 
+--R                                +-+4+-+   4+-+
+--R            2 4               x\|2 \|f  - \|e            3         +-+4+-+4+-+3
+--R       (2c f x  + 2c e f)atan(----------------) + (4c f x  - 4d e)\|2 \|e \|f
+--R                                    4+-+
+--R                                    \|e
+--R  /
+--R           2 4      2   +-+4+-+4+-+3
+--R     (16e f x  + 16e f)\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                         +-----------+              +-----------+3
+--R                         |       4                  |       4
+--R            2 4     2    |      c              4 2  |      c         3
+--R       (4e f x  + 4e f)  |- --------- log(4096e f   |- ---------  + c x)
+--R                        4|        5 3              4|        5 3
+--R                        \|  65536e f               \|  65536e f
+--R     + 
+--R                           +-----------+                +-----------+3
+--R                           |       4                    |       4
+--R              2 4     2    |      c                4 2  |      c         3
+--R       (- 4e f x  - 4e f)  |- --------- log(- 4096e f   |- ---------  + c x)
+--R                          4|        5 3                4|        5 3
+--R                          \|  65536e f                 \|  65536e f
+--R     + 
+--R                                                   +-----------+3
+--R                                                   |       4
+--R                                              4 2  |      c
+--R                       +-----------+     4096e f   |- ---------
+--R                       |       4                  4|        5 3
+--R          2 4     2    |      c                   \|  65536e f          3
+--R     (8e f x  + 8e f)  |- --------- atan(----------------------- + c f x  - d e
+--R                      4|        5 3                 3
+--R                      \|  65536e f                 c x
+--R  /
+--R         2 4     2
+--R     4e f x  + 4e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 576
+
+--S 577 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R       c log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                +-----------+                       +-----------+3
+--R                |       4                           |       4
+--R           +-+  |      c     4+-+4+-+3         4 2  |      c         3
+--R       16e\|2   |- --------- \|e \|f  log(4096e f   |- ---------  + c x)
+--R               4|        5 3                       4|        5 3
+--R               \|  65536e f                        \|  65536e f
+--R     + 
+--R                  +-----------+                         +-----------+3
+--R                  |       4                             |       4
+--R             +-+  |      c     4+-+4+-+3           4 2  |      c         3
+--R       - 16e\|2   |- --------- \|e \|f  log(- 4096e f   |- ---------  + c x)
+--R                 4|        5 3                         4|        5 3
+--R                 \|  65536e f                          \|  65536e f
+--R     + 
+--R                                                            +-+4+-+   4+-+
+--R                   +-+4+-+4+-+    2 +-+    +-+            x\|2 \|f  + \|e
+--R       - c log(- x\|2 \|e \|f  + x \|f  + \|e ) - 2c atan(----------------)
+--R                                                                4+-+
+--R                                                                \|e
+--R     + 
+--R                   +-+4+-+   4+-+
+--R                 x\|2 \|f  - \|e
+--R       - 2c atan(----------------)
+--R                       4+-+
+--R                       \|e
+--R     + 
+--R                                                     +-----------+3
+--R                                                     |       4
+--R                                                4 2  |      c
+--R                +-----------+              4096e f   |- ---------
+--R                |       4                           4|        5 3
+--R           +-+  |      c     4+-+4+-+3              \|  65536e f
+--R       32e\|2   |- --------- \|e \|f  atan(-----------------------)
+--R               4|        5 3                          3
+--R               \|  65536e f                          c x
+--R  /
+--R         +-+4+-+4+-+3
+--R     16e\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            4 +-+4+-+2 +-+         6         2 4+-+2 4+-+2
+--R       (2c x \|e \|e  \|f  + (c f x  + 3c e x )\|e  )\|f
+--R     + 
+--R                6        2 4+-+2         2 +-+  +-+         4        +-+4+-+2
+--R       ((- c f x  - c e x )\|e   - 2c e x \|e )\|f  + (c f x  + c e)\|e \|e
+--R     + 
+--R                 4      2
+--R       - 3c e f x  - c e
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 578
+
+)clear all
+
+--S 579 of 953
+t0:=(a+c*x^2+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R             3      2
+--R          d x  + c x  + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 579
+
+--S 580 of 953
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*x*(a+c*x^2)/(e*(e+f*x^4))+1/16*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/_
+   (e^(7/4)*f^(3/4)*sqrt(2))-1/16*log(e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/(e^(7/4)*f^(3/4)*_
+   sqrt(2))-1/8*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*_
+   sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))+1/8*atan(1+f^(1/4)*x*sqrt(2)/_
+   e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               2 4           +-+         2 4          +-+
+--R         ((3a f x  + 3a e f)\|f  + (- c f x  - c e f)\|e )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                 2 4           +-+       2 4          +-+
+--R         ((- 3a f x  - 3a e f)\|f  + (c f x  + c e f)\|e )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                               +-+4+-+   4+-+
+--R             2 4           +-+        2 4           +-+      x\|2 \|f  + \|e
+--R       ((6a f x  + 6a e f)\|f  + (2c f x  + 2c e f)\|e )atan(----------------)
+--R                                                                   4+-+
+--R                                                                   \|e
+--R     + 
+--R                                                               +-+4+-+   4+-+
+--R             2 4           +-+        2 4           +-+      x\|2 \|f  - \|e
+--R       ((6a f x  + 6a e f)\|f  + (2c f x  + 2c e f)\|e )atan(----------------)
+--R                                                                   4+-+
+--R                                                                   \|e
+--R     + 
+--R              3                  +-+4+-+3 4+-+3
+--R       (4c f x  + 4a f x - 4d e)\|2 \|e   \|f
+--R  /
+--R           2 4      2   +-+4+-+3 4+-+3
+--R     (16e f x  + 16e f)\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                            +------------------------------------------+
+--R                            |      +---------------------------+
+--R                            |      |     4 2      2 2       4 2
+--R                            |   3  |- 81a f  + 18a c e f - c e
+--R                            |64e f |---------------------------  - 3a c
+--R                            |      |               7 3
+--R                2 4     2   |     \|         16384e f
+--R         (- 2e f x  - 2e f) |------------------------------------------
+--R                            |                      3
+--R                           \|                   32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                    1024c e f  |---------------------------  - 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                  + 
+--R                         2 3
+--R                    24a c e f
+--R             *
+--R                 +------------------------------------------+
+--R                 |      +---------------------------+
+--R                 |      |     4 2      2 2       4 2
+--R                 |   3  |- 81a f  + 18a c e f - c e
+--R                 |64e f |---------------------------  - 3a c
+--R                 |      |               7 3
+--R                 |     \|         16384e f
+--R                 |------------------------------------------
+--R                 |                      3
+--R                \|                   32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R                          +--------------------------------------------+
+--R                          |        +---------------------------+
+--R                          |        |     4 2      2 2       4 2
+--R                          |     3  |- 81a f  + 18a c e f - c e
+--R                          |- 64e f |---------------------------  - 3a c
+--R                          |        |               7 3
+--R              2 4     2   |       \|         16384e f
+--R         (2e f x  + 2e f) |--------------------------------------------
+--R                          |                       3
+--R                         \|                    32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                    1024c e f  |---------------------------  + 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                  + 
+--R                           2 3
+--R                    - 24a c e f
+--R             *
+--R                 +--------------------------------------------+
+--R                 |        +---------------------------+
+--R                 |        |     4 2      2 2       4 2
+--R                 |     3  |- 81a f  + 18a c e f - c e
+--R                 |- 64e f |---------------------------  - 3a c
+--R                 |        |               7 3
+--R                 |       \|         16384e f
+--R                 |--------------------------------------------
+--R                 |                       3
+--R                \|                    32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R                            +--------------------------------------------+
+--R                            |        +---------------------------+
+--R                            |        |     4 2      2 2       4 2
+--R                            |     3  |- 81a f  + 18a c e f - c e
+--R                            |- 64e f |---------------------------  - 3a c
+--R                            |        |               7 3
+--R                2 4     2   |       \|         16384e f
+--R         (- 2e f x  - 2e f) |--------------------------------------------
+--R                            |                       3
+--R                           \|                    32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                  - 1024c e f  |---------------------------  - 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                + 
+--R                       2 3
+--R                  24a c e f
+--R             *
+--R                 +--------------------------------------------+
+--R                 |        +---------------------------+
+--R                 |        |     4 2      2 2       4 2
+--R                 |     3  |- 81a f  + 18a c e f - c e
+--R                 |- 64e f |---------------------------  - 3a c
+--R                 |        |               7 3
+--R                 |       \|         16384e f
+--R                 |--------------------------------------------
+--R                 |                       3
+--R                \|                    32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R                          +------------------------------------------+
+--R                          |      +---------------------------+
+--R                          |      |     4 2      2 2       4 2
+--R                          |   3  |- 81a f  + 18a c e f - c e
+--R                          |64e f |---------------------------  - 3a c
+--R                          |      |               7 3
+--R              2 4     2   |     \|         16384e f
+--R         (2e f x  + 2e f) |------------------------------------------
+--R                          |                      3
+--R                         \|                   32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                  - 1024c e f  |---------------------------  + 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                + 
+--R                         2 3
+--R                  - 24a c e f
+--R             *
+--R                 +------------------------------------------+
+--R                 |      +---------------------------+
+--R                 |      |     4 2      2 2       4 2
+--R                 |   3  |- 81a f  + 18a c e f - c e
+--R                 |64e f |---------------------------  - 3a c
+--R                 |      |               7 3
+--R                 |     \|         16384e f
+--R                 |------------------------------------------
+--R                 |                      3
+--R                \|                   32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R            3
+--R       c f x  + a f x - d e
+--R  /
+--R         2 4     2
+--R     4e f x  + 4e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 581
+
+--S 582 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       -
+--R                              +------------------------------------------+
+--R                              |      +---------------------------+
+--R                              |      |     4 2      2 2       4 2
+--R                              |   3  |- 81a f  + 18a c e f - c e
+--R                              |64e f |---------------------------  - 3a c
+--R                              |      |               7 3
+--R               +-+4+-+3 4+-+3 |     \|         16384e f
+--R            8e\|2 \|e   \|f   |------------------------------------------
+--R                              |                      3
+--R                             \|                   32e f
+--R         *
+--R            log
+--R                                +---------------------------+
+--R                                |     4 2      2 2       4 2
+--R                            6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                     1024c e f  |---------------------------  - 216a e f
+--R                                |               7 3
+--R                               \|         16384e f
+--R                   + 
+--R                          2 3
+--R                     24a c e f
+--R                *
+--R                    +------------------------------------------+
+--R                    |      +---------------------------+
+--R                    |      |     4 2      2 2       4 2
+--R                    |   3  |- 81a f  + 18a c e f - c e
+--R                    |64e f |---------------------------  - 3a c
+--R                    |      |               7 3
+--R                    |     \|         16384e f
+--R                    |------------------------------------------
+--R                    |                      3
+--R                   \|                   32e f
+--R               + 
+--R                     4 2    4 2
+--R                 (81a f  - c e )x
+--R     + 
+--R                           +--------------------------------------------+
+--R                           |        +---------------------------+
+--R                           |        |     4 2      2 2       4 2
+--R                           |     3  |- 81a f  + 18a c e f - c e
+--R                           |- 64e f |---------------------------  - 3a c
+--R                           |        |               7 3
+--R            +-+4+-+3 4+-+3 |       \|         16384e f
+--R         8e\|2 \|e   \|f   |--------------------------------------------
+--R                           |                       3
+--R                          \|                    32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                    1024c e f  |---------------------------  + 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                  + 
+--R                           2 3
+--R                    - 24a c e f
+--R             *
+--R                 +--------------------------------------------+
+--R                 |        +---------------------------+
+--R                 |        |     4 2      2 2       4 2
+--R                 |     3  |- 81a f  + 18a c e f - c e
+--R                 |- 64e f |---------------------------  - 3a c
+--R                 |        |               7 3
+--R                 |       \|         16384e f
+--R                 |--------------------------------------------
+--R                 |                       3
+--R                \|                    32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R       -
+--R                              +--------------------------------------------+
+--R                              |        +---------------------------+
+--R                              |        |     4 2      2 2       4 2
+--R                              |     3  |- 81a f  + 18a c e f - c e
+--R                              |- 64e f |---------------------------  - 3a c
+--R                              |        |               7 3
+--R               +-+4+-+3 4+-+3 |       \|         16384e f
+--R            8e\|2 \|e   \|f   |--------------------------------------------
+--R                              |                       3
+--R                             \|                    32e f
+--R         *
+--R            log
+--R                                  +---------------------------+
+--R                                  |     4 2      2 2       4 2
+--R                              6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                     - 1024c e f  |---------------------------  - 216a e f
+--R                                  |               7 3
+--R                                 \|         16384e f
+--R                   + 
+--R                          2 3
+--R                     24a c e f
+--R                *
+--R                    +--------------------------------------------+
+--R                    |        +---------------------------+
+--R                    |        |     4 2      2 2       4 2
+--R                    |     3  |- 81a f  + 18a c e f - c e
+--R                    |- 64e f |---------------------------  - 3a c
+--R                    |        |               7 3
+--R                    |       \|         16384e f
+--R                    |--------------------------------------------
+--R                    |                       3
+--R                   \|                    32e f
+--R               + 
+--R                     4 2    4 2
+--R                 (81a f  - c e )x
+--R     + 
+--R                           +------------------------------------------+
+--R                           |      +---------------------------+
+--R                           |      |     4 2      2 2       4 2
+--R                           |   3  |- 81a f  + 18a c e f - c e
+--R                           |64e f |---------------------------  - 3a c
+--R                           |      |               7 3
+--R            +-+4+-+3 4+-+3 |     \|         16384e f
+--R         8e\|2 \|e   \|f   |------------------------------------------
+--R                           |                      3
+--R                          \|                   32e f
+--R      *
+--R         log
+--R                               +---------------------------+
+--R                               |     4 2      2 2       4 2
+--R                           6 2 |- 81a f  + 18a c e f - c e         3 2 2
+--R                  - 1024c e f  |---------------------------  + 216a e f
+--R                               |               7 3
+--R                              \|         16384e f
+--R                + 
+--R                         2 3
+--R                  - 24a c e f
+--R             *
+--R                 +------------------------------------------+
+--R                 |      +---------------------------+
+--R                 |      |     4 2      2 2       4 2
+--R                 |   3  |- 81a f  + 18a c e f - c e
+--R                 |64e f |---------------------------  - 3a c
+--R                 |      |               7 3
+--R                 |     \|         16384e f
+--R                 |------------------------------------------
+--R                 |                      3
+--R                \|                   32e f
+--R            + 
+--R                  4 2    4 2
+--R              (81a f  - c e )x
+--R     + 
+--R             +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a\|f  + c\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (3a\|f  - c\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|f  + \|e
+--R       (- 6a\|f  - 2c\|e )atan(----------------)
+--R                                     4+-+
+--R                                     \|e
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R             +-+      +-+      x\|2 \|f  - \|e
+--R       (- 6a\|f  - 2c\|e )atan(----------------)
+--R                                     4+-+
+--R                                     \|e
+--R  /
+--R         +-+4+-+3 4+-+3
+--R     16e\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4        2  +-+4+-+2         6         4         2  +-+
+--R           ((4c x  + 12a x )\|e \|e   - 3a f x  - 2c e x  + 3a e x )\|f
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2c f x  + 6a f x  + 2c e x  + 6a e)\|e
+--R         + 
+--R                   6         4        2  +-+
+--R           (- c f x  - 6a f x  + c e x )\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R                  4         2        4+-+2
+--R           (3a f x  - 2c e x  - 3a e)\|e
+--R         + 
+--R                   6         4        2         +-+
+--R           (- c f x  - 3a f x  - c e x  - 3a e)\|e
+--R      *
+--R          +-+
+--R         \|f
+--R     + 
+--R           4         2        +-+4+-+2       2 6           4           2      2
+--R     (c f x  - 6a f x  - c e)\|e \|e   + 3a f x  - 3c e f x  - 9a e f x  + c e
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 583
+
+)clear all
+
+--S 584 of 953
+t0:=(b*x+c*x^2+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R            3      2
+--R         d x  + c x  + b x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 584
+
+--S 585 of 953
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*x^2*(b+c*x)/(e*(e+f*x^4))-1/8*c*atan(1-f^(1/4)*_
+   x*sqrt(2)/e^(1/4))/(e^(5/4)*f^(3/4)*sqrt(2))+1/8*c*atan(1+f^(1/4)*_
+   x*sqrt(2)/e^(1/4))/(e^(5/4)*f^(3/4)*sqrt(2))+1/16*c*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))-_
+   1/16*c*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(5/4)*_
+   f^(3/4)*sqrt(2))+1/4*b*atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R             2 4          +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       (- c f x  - c e f)\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           2 4          +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       (c f x  + c e f)\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R            2 4           +-+ +-+     x\|2 \|f  + \|e
+--R       (2c f x  + 2c e f)\|e \|f atan(----------------)
+--R                                            4+-+
+--R                                            \|e
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R            2 4           +-+ +-+     x\|2 \|f  - \|e
+--R       (2c f x  + 2c e f)\|e \|f atan(----------------)
+--R                                            4+-+
+--R                                            \|e
+--R     + 
+--R                                            2 +-+
+--R            2 4           +-+4+-+4+-+3     x \|f
+--R       (4b f x  + 4b e f)\|2 \|e \|f  atan(------)
+--R                                             +-+
+--R                                            \|e
+--R     + 
+--R              3         2         +-+ +-+4+-+ +-+4+-+3
+--R       (4c f x  + 4b f x  - 4d e)\|2 \|e \|e \|f \|f
+--R  /
+--R           2 4      2   +-+ +-+4+-+ +-+4+-+3
+--R     (16e f x  + 16e f)\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 585
+
+--S 586 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    2 4     2
+--R             (- 2e f x  - 2e f)
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CP1  - 16e f %%CP0 %%CP1 - 24e f %%CP0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                  2 4     2                 2 4     2
+--R           (- 2e f x  - 2e f)%%CP1 + (- 2e f x  - 2e f)%%CP0
+--R      *
+--R         log
+--R                        2 5 2             3 3 2              3 3 2
+--R                  (2048c e f %%CP0 + 2048b e f )%%CP1 + 2048b e f %%CP0
+--R                + 
+--R                     2 2 2
+--R                  32b c e f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CP1  - 16e f %%CP0 %%CP1 - 24e f %%CP0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                      2 5 2             3 3 2      2
+--R              (- 2048c e f %%CP0 - 2048b e f )%%CP1
+--R            + 
+--R                      2 5 2     2      2 2 2               3 3 2     2
+--R              (- 2048c e f %%CP0  + 32b c e f)%%CP1 - 2048b e f %%CP0
+--R            + 
+--R                 2 2 2              4       5         5        4
+--R              32b c e f %%CP0 + (64b c f - c e)x - 64b f + 2b c e
+--R     + 
+--R                  2 4     2
+--R             (2e f x  + 2e f)
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CP1  - 16e f %%CP0 %%CP1 - 24e f %%CP0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                  2 4     2                 2 4     2
+--R           (- 2e f x  - 2e f)%%CP1 + (- 2e f x  - 2e f)%%CP0
+--R      *
+--R         log
+--R                          2 5 2             3 3 2              3 3 2
+--R                  (- 2048c e f %%CP0 - 2048b e f )%%CP1 - 2048b e f %%CP0
+--R                + 
+--R                       2 2 2
+--R                  - 32b c e f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CP1  - 16e f %%CP0 %%CP1 - 24e f %%CP0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                      2 5 2             3 3 2      2
+--R              (- 2048c e f %%CP0 - 2048b e f )%%CP1
+--R            + 
+--R                      2 5 2     2      2 2 2               3 3 2     2
+--R              (- 2048c e f %%CP0  + 32b c e f)%%CP1 - 2048b e f %%CP0
+--R            + 
+--R                 2 2 2              4       5         5        4
+--R              32b c e f %%CP0 + (64b c f - c e)x - 64b f + 2b c e
+--R     + 
+--R              2 4     2
+--R         (4e f x  + 4e f)%%CP1
+--R      *
+--R         log
+--R                    2 5 2             3 3 2      2
+--R              (4096c e f %%CP0 + 4096b e f )%%CP1
+--R            + 
+--R                    2 5 2     2      2 2 2               2 5 2     3
+--R              (4096c e f %%CP0  - 64b c e f)%%CP1 + 4096c e f %%CP0
+--R            + 
+--R                  2 2 2              4       5         5        4
+--R              128b c e f %%CP0 + (64b c f - c e)x + 64b f + 2b c e
+--R     + 
+--R              2 4     2
+--R         (4e f x  + 4e f)%%CP0
+--R      *
+--R         log
+--R                     2 5 2     3        3 3 2     2       2 2 2
+--R              - 4096c e f %%CP0  + 4096b e f %%CP0  - 192b c e f %%CP0
+--R            + 
+--R                  4       5         5        4
+--R              (64b c f - c e)x + 64b f - 6b c e
+--R     + 
+--R            3        2
+--R       c f x  + b f x  - d e
+--R  /
+--R         2 4     2
+--R     4e f x  + 4e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 586
+
+--S 587 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                   +-+ +-+4+-+ +-+4+-+3
+--R                8e\|2 \|e \|e \|f \|f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CP1  - 16e f %%CP0 %%CP1 - 24e f %%CP0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R         + 
+--R                +-+ +-+4+-+ +-+4+-+3           +-+ +-+4+-+ +-+4+-+3
+--R           - 8e\|2 \|e \|e \|f \|f  %%CP1 - 8e\|2 \|e \|e \|f \|f  %%CP0
+--R      *
+--R         log
+--R                        2 5 2             3 3 2              3 3 2
+--R                  (2048c e f %%CP0 + 2048b e f )%%CP1 + 2048b e f %%CP0
+--R                + 
+--R                     2 2 2
+--R                  32b c e f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CP1  - 16e f %%CP0 %%CP1 - 24e f %%CP0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                      2 5 2             3 3 2      2
+--R              (- 2048c e f %%CP0 - 2048b e f )%%CP1
+--R            + 
+--R                      2 5 2     2      2 2 2               3 3 2     2
+--R              (- 2048c e f %%CP0  + 32b c e f)%%CP1 - 2048b e f %%CP0
+--R            + 
+--R                 2 2 2              4       5         5        4
+--R              32b c e f %%CP0 + (64b c f - c e)x - 64b f + 2b c e
+--R     + 
+--R                +-+ +-+4+-+ +-+4+-+3
+--R             8e\|2 \|e \|e \|f \|f
+--R          *
+--R              +------------------------------------------------------+
+--R              |     3       2      3                   3       2    2
+--R              |- 24e f %%CP1  - 16e f %%CP0 %%CP1 - 24e f %%CP0  - b
+--R              |------------------------------------------------------
+--R              |                           3
+--R             \|                         8e f
+--R         + 
+--R                +-+ +-+4+-+ +-+4+-+3           +-+ +-+4+-+ +-+4+-+3
+--R           - 8e\|2 \|e \|e \|f \|f  %%CP1 - 8e\|2 \|e \|e \|f \|f  %%CP0
+--R      *
+--R         log
+--R                          2 5 2             3 3 2              3 3 2
+--R                  (- 2048c e f %%CP0 - 2048b e f )%%CP1 - 2048b e f %%CP0
+--R                + 
+--R                       2 2 2
+--R                  - 32b c e f
+--R             *
+--R                 +------------------------------------------------------+
+--R                 |     3       2      3                   3       2    2
+--R                 |- 24e f %%CP1  - 16e f %%CP0 %%CP1 - 24e f %%CP0  - b
+--R                 |------------------------------------------------------
+--R                 |                           3
+--R                \|                         8e f
+--R            + 
+--R                      2 5 2             3 3 2      2
+--R              (- 2048c e f %%CP0 - 2048b e f )%%CP1
+--R            + 
+--R                      2 5 2     2      2 2 2               3 3 2     2
+--R              (- 2048c e f %%CP0  + 32b c e f)%%CP1 - 2048b e f %%CP0
+--R            + 
+--R                 2 2 2              4       5         5        4
+--R              32b c e f %%CP0 + (64b c f - c e)x - 64b f + 2b c e
+--R     + 
+--R             +-+ +-+4+-+ +-+4+-+3
+--R         16e\|2 \|e \|e \|f \|f  %%CP1
+--R      *
+--R         log
+--R                    2 5 2             3 3 2      2
+--R              (4096c e f %%CP0 + 4096b e f )%%CP1
+--R            + 
+--R                    2 5 2     2      2 2 2               2 5 2     3
+--R              (4096c e f %%CP0  - 64b c e f)%%CP1 + 4096c e f %%CP0
+--R            + 
+--R                  2 2 2              4       5         5        4
+--R              128b c e f %%CP0 + (64b c f - c e)x + 64b f + 2b c e
+--R     + 
+--R         +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       c\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       - c\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             +-+ +-+4+-+ +-+4+-+3
+--R         16e\|2 \|e \|e \|f \|f  %%CP0
+--R      *
+--R         log
+--R                     2 5 2     3        3 3 2     2       2 2 2
+--R              - 4096c e f %%CP0  + 4096b e f %%CP0  - 192b c e f %%CP0
+--R            + 
+--R                  4       5         5        4
+--R              (64b c f - c e)x + 64b f - 6b c e
+--R     + 
+--R                          +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|f  + \|e        +-+ +-+     x\|2 \|f  - \|e
+--R       - 2c\|e \|f atan(----------------) - 2c\|e \|f atan(----------------)
+--R                              4+-+                               4+-+
+--R                              \|e                                \|e
+--R     + 
+--R                              2 +-+
+--R            +-+4+-+4+-+3     x \|f
+--R       - 4b\|2 \|e \|f  atan(------)
+--R                               +-+
+--R                              \|e
+--R  /
+--R         +-+ +-+4+-+ +-+4+-+3
+--R     16e\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            4 +-+4+-+2 +-+         6         2 4+-+2 4+-+2
+--R       (2c x \|e \|e  \|f  + (c f x  + 3c e x )\|e  )\|f
+--R     + 
+--R                6        2 4+-+2         2 +-+  +-+         4        +-+4+-+2
+--R       ((- c f x  - c e x )\|e   - 2c e x \|e )\|f  + (c f x  + c e)\|e \|e
+--R     + 
+--R                 4      2
+--R       - 3c e f x  - c e
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 588
+
+)clear all
+
+--S 589 of 953
+t0:=(a+b*x+c*x^2+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + b x + a
+--R   (1)  ---------------------
+--R          2 8         4    2
+--R         f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 589
+
+--S 590 of 953
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*x*(a+b*x+c*x^2)/(e*(e+f*x^4))+1/4*b*_
+   atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))+1/16*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/_
+   (e^(7/4)*f^(3/4)*sqrt(2))-1/16*log(e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/(e^(7/4)*f^(3/4)*_
+   sqrt(2))-1/8*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*_
+   sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))+1/8*atan(1+f^(1/4)*x*sqrt(2)/_
+   e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  2 4      2   +-+        3 4         2  +-+
+--R         ((- c e f x  - c e f)\|f  + (3a f x  + 3a e f )\|e )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                2 4      2   +-+          3 4         2  +-+
+--R         ((c e f x  + c e f)\|f  + (- 3a f x  - 3a e f )\|e )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                 2 4       2   +-+        3 4         2  +-+
+--R         ((2c e f x  + 2c e f)\|f  + (6a f x  + 6a e f )\|e )
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|f  + \|e
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|e
+--R     + 
+--R                 2 4       2   +-+        3 4         2  +-+
+--R         ((2c e f x  + 2c e f)\|f  + (6a f x  + 6a e f )\|e )
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|f  - \|e
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|e
+--R     + 
+--R                                              2 +-+
+--R            2 4           +-+4+-+3 4+-+3     x \|f
+--R       (4b f x  + 4b e f)\|2 \|e   \|f  atan(------)
+--R                                               +-+
+--R                                              \|e
+--R     + 
+--R              3         2                  +-+ +-+4+-+3 +-+4+-+3
+--R       (4c f x  + 4b f x  + 4a f x - 4d e)\|2 \|e \|e  \|f \|f
+--R  /
+--R           2 4      2   +-+ +-+4+-+3 +-+4+-+3
+--R     (16e f x  + 16e f)\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    2 4     2
+--R             (- 2e f x  - 2e f)
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |     3       2      3                   3       2            2
+--R              |- 48e f %%CQ1  - 32e f %%CQ0 %%CQ1 - 48e f %%CQ0  - 3a c - 2b
+--R              |--------------------------------------------------------------
+--R              |                                3
+--R             \|                             16e f
+--R         + 
+--R                  2 4     2                 2 4     2
+--R           (- 2e f x  - 2e f)%%CQ1 + (- 2e f x  - 2e f)%%CQ0
+--R      *
+--R         log
+--R                              2            2  6 3        3 7 2
+--R                      ((18432a c - 49152a b )e f  - 2048c e f )%%CQ0
+--R                    + 
+--R                           3   4 3             2        3   5 2
+--R                      6912a b e f  + (2304a b c  - 2048b c)e f
+--R                 *
+--R                    %%CQ1
+--R                + 
+--R                        3   4 3             2        3   5 2              5 2 3
+--R                  (6912a b e f  + (2304a b c  - 2048b c)e f )%%CQ0 - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48e f %%CQ1  - 32e f %%CQ0 %%CQ1 - 48e f %%CQ0  - 3a c - 2b
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16e f
+--R            + 
+--R                            2            2  6 3        3 7 2
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CQ0
+--R                + 
+--R                         3   4 3               2        3   5 2
+--R                  - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R             *
+--R                     2
+--R                %%CQ1
+--R            + 
+--R                            2            2  6 3        3 7 2      2        5 2 3
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CQ0  - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R                %%CQ1
+--R            + 
+--R                      3   4 3               2        3   5 2      2
+--R              (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CQ0
+--R            + 
+--R                           5 2 3          2 2          4  3 2
+--R                    - 1944a e f  + (- 864a b c + 768a b )e f
+--R                  + 
+--R                          4      2 3  4
+--R                    (24a c  - 32b c )e f
+--R             *
+--R                %%CQ0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                     4          3 3    2         2   3        3 2      5   2
+--R              (- 486a b c + 216a b )e f  + (- 72a b c  - 24a b c  + 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R                  2 4     2
+--R             (2e f x  + 2e f)
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |     3       2      3                   3       2            2
+--R              |- 48e f %%CQ1  - 32e f %%CQ0 %%CQ1 - 48e f %%CQ0  - 3a c - 2b
+--R              |--------------------------------------------------------------
+--R              |                                3
+--R             \|                             16e f
+--R         + 
+--R                  2 4     2                 2 4     2
+--R           (- 2e f x  - 2e f)%%CQ1 + (- 2e f x  - 2e f)%%CQ0
+--R      *
+--R         log
+--R                                2            2  6 3        3 7 2
+--R                      ((- 18432a c + 49152a b )e f  + 2048c e f )%%CQ0
+--R                    + 
+--R                             3   4 3               2        3   5 2
+--R                      - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R                 *
+--R                    %%CQ1
+--R                + 
+--R                          3   4 3               2        3   5 2
+--R                  (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CQ0
+--R                + 
+--R                     5 2 3        2 2          4  3 2           4      2 3  4
+--R                1944a e f  + (864a b c - 768a b )e f  + (- 24a c  + 32b c )e f
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48e f %%CQ1  - 32e f %%CQ0 %%CQ1 - 48e f %%CQ0  - 3a c - 2b
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16e f
+--R            + 
+--R                            2            2  6 3        3 7 2
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CQ0
+--R                + 
+--R                         3   4 3               2        3   5 2
+--R                  - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R             *
+--R                     2
+--R                %%CQ1
+--R            + 
+--R                            2            2  6 3        3 7 2      2        5 2 3
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CQ0  - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R                %%CQ1
+--R            + 
+--R                      3   4 3               2        3   5 2      2
+--R              (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CQ0
+--R            + 
+--R                           5 2 3          2 2          4  3 2
+--R                    - 1944a e f  + (- 864a b c + 768a b )e f
+--R                  + 
+--R                          4      2 3  4
+--R                    (24a c  - 32b c )e f
+--R             *
+--R                %%CQ0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                     4          3 3    2         2   3        3 2      5   2
+--R              (- 486a b c + 216a b )e f  + (- 72a b c  - 24a b c  + 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R              2 4     2
+--R         (4e f x  + 4e f)%%CQ1
+--R      *
+--R         log
+--R                          2            2  6 3        3 7 2               3   4 3
+--R                  ((36864a c - 98304a b )e f  - 4096c e f )%%CQ0 + 13824a b e f
+--R                + 
+--R                            2        3   5 2
+--R                  (4608a b c  - 4096b c)e f
+--R             *
+--R                     2
+--R                %%CQ1
+--R            + 
+--R                          2            2  6 3        3 7 2      2        5 2 3
+--R                  ((36864a c - 98304a b )e f  - 4096c e f )%%CQ0  + 3888a e f
+--R                + 
+--R                        2 2           4  3 2           4      2 3  4
+--R                  (1728a b c - 1536a b )e f  + (- 48a c  + 64b c )e f
+--R             *
+--R                %%CQ1
+--R            + 
+--R                      2            2  6 3        3 7 2      3
+--R              ((36864a c - 98304a b )e f  - 4096c e f )%%CQ0
+--R            + 
+--R                          3 2        2 2           4  3 2
+--R                    (1728a c  - 3456a b c - 3072a b )e f
+--R                  + 
+--R                             4       2 3  4
+--R                    (- 192a c  - 128b c )e f
+--R             *
+--R                %%CQ0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4          3 3    2        2   3        3 2      5   2
+--R              (162a b c + 648a b )e f  + (144a b c  - 72a b c  - 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R              2 4     2
+--R         (4e f x  + 4e f)%%CQ0
+--R      *
+--R         log
+--R                        2            2  6 3        3 7 2      3
+--R              ((- 36864a c + 98304a b )e f  + 4096c e f )%%CQ0
+--R            + 
+--R                     3   4 3             2        3   5 2      2
+--R              (13824a b e f  + (4608a b c  - 4096b c)e f )%%CQ0
+--R            + 
+--R                       5 2 3           3 2        2 2           4  3 2
+--R                  3888a e f  + (- 1728a c  + 5184a b c + 1536a b )e f
+--R                + 
+--R                         4       2 3  4
+--R                  (144a c  + 192b c )e f
+--R             *
+--R                %%CQ0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4           3 3    2          3 2      5   2        5 3
+--R              (810a b c - 1080a b )e f  + (120a b c  - 64b c)e f + 6b c e
+--R     + 
+--R            3        2
+--R       c f x  + b f x  + a f x - d e
+--R  /
+--R         2 4     2
+--R     4e f x  + 4e f
+--R                                         Type: Union(Expression(Integer),...)
+--E 591
+
+--S 592 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                   +-+ +-+4+-+3 +-+4+-+3
+--R                8e\|2 \|e \|e  \|f \|f
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48e f %%CQ1  - 32e f %%CQ0 %%CQ1 - 48e f %%CQ0  - 3a c - 2b
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 8e\|2 \|e \|e  \|f \|f  %%CQ1 - 8e\|2 \|e \|e  \|f \|f  %%CQ0
+--R      *
+--R         log
+--R                              2            2  6 3        3 7 2
+--R                      ((18432a c - 49152a b )e f  - 2048c e f )%%CQ0
+--R                    + 
+--R                           3   4 3             2        3   5 2
+--R                      6912a b e f  + (2304a b c  - 2048b c)e f
+--R                 *
+--R                    %%CQ1
+--R                + 
+--R                        3   4 3             2        3   5 2              5 2 3
+--R                  (6912a b e f  + (2304a b c  - 2048b c)e f )%%CQ0 - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48e f %%CQ1  - 32e f %%CQ0 %%CQ1 - 48e f %%CQ0  - 3a c - 2b
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16e f
+--R            + 
+--R                            2            2  6 3        3 7 2
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CQ0
+--R                + 
+--R                         3   4 3               2        3   5 2
+--R                  - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R             *
+--R                     2
+--R                %%CQ1
+--R            + 
+--R                            2            2  6 3        3 7 2      2        5 2 3
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CQ0  - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R                %%CQ1
+--R            + 
+--R                      3   4 3               2        3   5 2      2
+--R              (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CQ0
+--R            + 
+--R                           5 2 3          2 2          4  3 2
+--R                    - 1944a e f  + (- 864a b c + 768a b )e f
+--R                  + 
+--R                          4      2 3  4
+--R                    (24a c  - 32b c )e f
+--R             *
+--R                %%CQ0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                     4          3 3    2         2   3        3 2      5   2
+--R              (- 486a b c + 216a b )e f  + (- 72a b c  - 24a b c  + 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R                +-+ +-+4+-+3 +-+4+-+3
+--R             8e\|2 \|e \|e  \|f \|f
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |     3       2      3                   3       2            2
+--R              |- 48e f %%CQ1  - 32e f %%CQ0 %%CQ1 - 48e f %%CQ0  - 3a c - 2b
+--R              |--------------------------------------------------------------
+--R              |                                3
+--R             \|                             16e f
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 8e\|2 \|e \|e  \|f \|f  %%CQ1 - 8e\|2 \|e \|e  \|f \|f  %%CQ0
+--R      *
+--R         log
+--R                                2            2  6 3        3 7 2
+--R                      ((- 18432a c + 49152a b )e f  + 2048c e f )%%CQ0
+--R                    + 
+--R                             3   4 3               2        3   5 2
+--R                      - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R                 *
+--R                    %%CQ1
+--R                + 
+--R                          3   4 3               2        3   5 2
+--R                  (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CQ0
+--R                + 
+--R                     5 2 3        2 2          4  3 2           4      2 3  4
+--R                1944a e f  + (864a b c - 768a b )e f  + (- 24a c  + 32b c )e f
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48e f %%CQ1  - 32e f %%CQ0 %%CQ1 - 48e f %%CQ0  - 3a c - 2b
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16e f
+--R            + 
+--R                            2            2  6 3        3 7 2
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CQ0
+--R                + 
+--R                         3   4 3               2        3   5 2
+--R                  - 6912a b e f  + (- 2304a b c  + 2048b c)e f
+--R             *
+--R                     2
+--R                %%CQ1
+--R            + 
+--R                            2            2  6 3        3 7 2      2        5 2 3
+--R                  ((- 18432a c + 49152a b )e f  + 2048c e f )%%CQ0  - 1944a e f
+--R                + 
+--R                         2 2          4  3 2         4      2 3  4
+--R                  (- 864a b c + 768a b )e f  + (24a c  - 32b c )e f
+--R             *
+--R                %%CQ1
+--R            + 
+--R                      3   4 3               2        3   5 2      2
+--R              (- 6912a b e f  + (- 2304a b c  + 2048b c)e f )%%CQ0
+--R            + 
+--R                           5 2 3          2 2          4  3 2
+--R                    - 1944a e f  + (- 864a b c + 768a b )e f
+--R                  + 
+--R                          4      2 3  4
+--R                    (24a c  - 32b c )e f
+--R             *
+--R                %%CQ0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                     4          3 3    2         2   3        3 2      5   2
+--R              (- 486a b c + 216a b )e f  + (- 72a b c  - 24a b c  + 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+3
+--R         16e\|2 \|e \|e  \|f \|f  %%CQ1
+--R      *
+--R         log
+--R                          2            2  6 3        3 7 2               3   4 3
+--R                  ((36864a c - 98304a b )e f  - 4096c e f )%%CQ0 + 13824a b e f
+--R                + 
+--R                            2        3   5 2
+--R                  (4608a b c  - 4096b c)e f
+--R             *
+--R                     2
+--R                %%CQ1
+--R            + 
+--R                          2            2  6 3        3 7 2      2        5 2 3
+--R                  ((36864a c - 98304a b )e f  - 4096c e f )%%CQ0  + 3888a e f
+--R                + 
+--R                        2 2           4  3 2           4      2 3  4
+--R                  (1728a b c - 1536a b )e f  + (- 48a c  + 64b c )e f
+--R             *
+--R                %%CQ1
+--R            + 
+--R                      2            2  6 3        3 7 2      3
+--R              ((36864a c - 98304a b )e f  - 4096c e f )%%CQ0
+--R            + 
+--R                          3 2        2 2           4  3 2
+--R                    (1728a c  - 3456a b c - 3072a b )e f
+--R                  + 
+--R                             4       2 3  4
+--R                    (- 192a c  - 128b c )e f
+--R             *
+--R                %%CQ0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4          3 3    2        2   3        3 2      5   2
+--R              (162a b c + 648a b )e f  + (144a b c  - 72a b c  - 64b c)e f
+--R            + 
+--R                    5 3
+--R              - 2b c e
+--R     + 
+--R            +-+        +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (c e\|f  - 3a f\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              +-+        +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- c e\|f  + 3a f\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+3
+--R         16e\|2 \|e \|e  \|f \|f  %%CQ0
+--R      *
+--R         log
+--R                        2            2  6 3        3 7 2      3
+--R              ((- 36864a c + 98304a b )e f  + 4096c e f )%%CQ0
+--R            + 
+--R                     3   4 3             2        3   5 2      2
+--R              (13824a b e f  + (4608a b c  - 4096b c)e f )%%CQ0
+--R            + 
+--R                       5 2 3           3 2        2 2           4  3 2
+--R                  3888a e f  + (- 1728a c  + 5184a b c + 1536a b )e f
+--R                + 
+--R                         4       2 3  4
+--R                  (144a c  + 192b c )e f
+--R             *
+--R                %%CQ0
+--R            + 
+--R                      6 3         4 2       3 2        2 4    2
+--R                  729a f  + (- 81a c  + 864a b c - 576a b )e f
+--R                + 
+--R                       2 4        2 3      4 2  2     6 3
+--R                  (- 9a c  + 96a b c  - 64b c )e f + c e
+--R             *
+--R                x
+--R            + 
+--R                   4           3 3    2          3 2      5   2        5 3
+--R              (810a b c - 1080a b )e f  + (120a b c  - 64b c)e f + 6b c e
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|f  + \|e
+--R       (- 2c e\|f  - 6a f\|e )atan(----------------)
+--R                                         4+-+
+--R                                         \|e
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|f  - \|e
+--R       (- 2c e\|f  - 6a f\|e )atan(----------------)
+--R                                         4+-+
+--R                                         \|e
+--R     + 
+--R                                2 +-+
+--R            +-+4+-+3 4+-+3     x \|f
+--R       - 4b\|2 \|e   \|f  atan(------)
+--R                                 +-+
+--R                                \|e
+--R  /
+--R         +-+ +-+4+-+3 +-+4+-+3
+--R     16e\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4        2  +-+4+-+2         6         4         2  +-+
+--R           ((4c x  + 12a x )\|e \|e   - 3a f x  - 2c e x  + 3a e x )\|f
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2c f x  + 6a f x  + 2c e x  + 6a e)\|e
+--R         + 
+--R                   6         4        2  +-+
+--R           (- c f x  - 6a f x  + c e x )\|e
+--R      *
+--R         4+-+2
+--R         \|f
+--R     + 
+--R                  4         2        4+-+2
+--R           (3a f x  - 2c e x  - 3a e)\|e
+--R         + 
+--R                   6         4        2         +-+
+--R           (- c f x  - 3a f x  - c e x  - 3a e)\|e
+--R      *
+--R          +-+
+--R         \|f
+--R     + 
+--R           4         2        +-+4+-+2       2 6           4           2      2
+--R     (c f x  - 6a f x  - c e)\|e \|e   + 3a f x  - 3c e f x  - 9a e f x  + c e
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16e f x  + 16e x )\|e \|e  \|f  + (8e f x  + 16e f x  + 8e )\|e  )\|f
+--R     + 
+--R            2 2 6      3   2
+--R       - 16e f x  - 16e f x
+--R                                                    Type: Expression(Integer)
+--E 593
+
+)clear all
+
+--S 594 of 953
+t0:=a/(2+3*x^4)
+--R 
+--R
+--R           a
+--R   (1)  -------
+--R          4
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 594
+
+--S 595 of 953
+r0:=-1/4*a*atan(1-6^(1/4)*x)/6^(1/4)+1/4*a*atan(1+6^(1/4)*x)/6^(1/4)-_
+   1/8*a*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)+1/8*a*_
+   log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)
+--R 
+--R
+--R   (2)
+--R               4+-+3 4+-+   2 +-+    +-+              4+-+3 4+-+   2 +-+    +-+
+--R       a log(x \|2   \|3 + x \|3  + \|2 ) - a log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R                4+-+                 4+-+
+--R       2a atan(x\|6  + 1) + 2a atan(x\|6  - 1)
+--R  /
+--R      4+-+
+--R     8\|6
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +--+      +--+2                 +--+
+--R        +-+4| 4      4| 4          +-+4+--+4| 4     2 2 4+--+2
+--R       \|2 \|a  log(4\|a    + 2a x\|2 \|24 \|a   + a x  \|24 )
+--R     + 
+--R              +--+      +--+2                 +--+
+--R          +-+4| 4      4| 4          +-+4+--+4| 4     2 2 4+--+2
+--R       - \|2 \|a  log(4\|a    - 2a x\|2 \|24 \|a   + a x  \|24 )
+--R     + 
+--R                                +--+
+--R             +--+              4| 4
+--R         +-+4| 4              2\|a
+--R       2\|2 \|a  atan(---------------------)
+--R                        +--+
+--R                       4| 4        +-+4+--+
+--R                      2\|a   - a x\|2 \|24
+--R     + 
+--R                                  +--+
+--R               +--+              4| 4
+--R           +-+4| 4              2\|a
+--R       - 2\|2 \|a  atan(---------------------)
+--R                          +--+
+--R                         4| 4        +-+4+--+
+--R                        2\|a   + a x\|2 \|24
+--R  /
+--R      4+--+
+--R     8\|24
+--R                                         Type: Union(Expression(Integer),...)
+--E 596
+
+--S 597 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +--+      +--+2                 +--+
+--R        +-+4+-+4| 4      4| 4          +-+4+--+4| 4     2 2 4+--+2
+--R       \|2 \|6 \|a  log(4\|a    + 2a x\|2 \|24 \|a   + a x  \|24 )
+--R     + 
+--R                  +--+      +--+2                 +--+
+--R          +-+4+-+4| 4      4| 4          +-+4+--+4| 4     2 2 4+--+2
+--R       - \|2 \|6 \|a  log(4\|a    - 2a x\|2 \|24 \|a   + a x  \|24 )
+--R     + 
+--R                                    +--+
+--R                 +--+              4| 4
+--R         +-+4+-+4| 4              2\|a
+--R       2\|2 \|6 \|a  atan(---------------------)
+--R                            +--+
+--R                           4| 4        +-+4+--+
+--R                          2\|a   - a x\|2 \|24
+--R     + 
+--R                                      +--+
+--R                   +--+              4| 4
+--R           +-+4+-+4| 4              2\|a
+--R       - 2\|2 \|6 \|a  atan(---------------------)
+--R                              +--+
+--R                             4| 4        +-+4+--+
+--R                            2\|a   + a x\|2 \|24
+--R     + 
+--R          4+--+      4+-+3 4+-+   2 +-+    +-+
+--R       - a\|24 log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R        4+--+        4+-+3 4+-+   2 +-+    +-+      4+--+      4+-+
+--R       a\|24 log(- x \|2   \|3 + x \|3  + \|2 ) - 2a\|24 atan(x\|6  + 1)
+--R     + 
+--R           4+--+      4+-+
+--R       - 2a\|24 atan(x\|6  - 1)
+--R  /
+--R      4+-+4+--+
+--R     8\|6 \|24
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R            2 4+-+2 4+-+2     2 +-+ +-+       4      4+-+2
+--R       (4a x  \|2   \|3 - 4a x \|2 \|3  - 6a x  - 4a)\|6
+--R     + 
+--R               6       2 4+-+3 +-+        4       +-+4+-+3 4+-+4+-+
+--R       ((- 3a x  - 2a x )\|2  \|3  + (3a x  + 2a)\|2 \|2  )\|3 \|6
+--R     + 
+--R              4 4+-+2 4+-+2      4 +-+ +-+        6        2
+--R       - 12a x  \|2   \|3 + 12a x \|2 \|3  + 18a x  + 12a x
+--R  /
+--R          6      2 4+-+2 4+-+2        6      2  +-+ +-+      8      4      4+-+2
+--R     ((24x  + 16x )\|2   \|3  + (- 24x  - 16x )\|2 \|3  - 36x  - 48x  - 16)\|6
+--R                                                    Type: Expression(Integer)
+--E 598
+
+)clear all
+
+--S 599 of 953
+t0:=b*x/(2+3*x^4)
+--R 
+--R
+--R          b x
+--R   (1)  -------
+--R          4
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 599
+
+--S 600 of 953
+r0:=1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R                2 +-+
+--R               x \|3
+--R        b atan(------)
+--R                 +-+
+--R                \|2
+--R   (2)  --------------
+--R               +-+
+--R             2\|6
+--R                                                    Type: Expression(Integer)
+--E 600
+
+--S 601 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2 +-+
+--R               x \|6
+--R        b atan(------)
+--R                  2
+--R   (3)  --------------
+--R               +-+
+--R             2\|6
+--R                                         Type: Union(Expression(Integer),...)
+--E 601
+
+--S 602 of 953
+m0:=a0-r0
+--R 
+--R
+--R                2 +-+            2 +-+
+--R               x \|6            x \|3
+--R        b atan(------) - b atan(------)
+--R                  2               +-+
+--R                                 \|2
+--R   (4)  -------------------------------
+--R                       +-+
+--R                     2\|6
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R              +-+ +-+ +-+
+--R        - b x\|2 \|3 \|6  + 6b x
+--R   (5)  ------------------------
+--R                   4
+--R                18x  + 12
+--R                                                    Type: Expression(Integer)
+--E 603
+
+)clear all
+
+--S 604 of 953
+t0:=(a+b*x)/(2+3*x^4)
+--R 
+--R
+--R        b x + a
+--R   (1)  -------
+--R          4
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 604
+
+--S 605 of 953
+r0:=-1/4*a*atan(1-6^(1/4)*x)/6^(1/4)+1/4*a*atan(1+6^(1/4)*x)/6^(1/4)-_
+   1/8*a*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)+1/8*a*_
+   log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)+1/2*b*atan(x^2*_
+   sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R         +-+      4+-+3 4+-+   2 +-+    +-+
+--R       a\|6 log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+        4+-+3 4+-+   2 +-+    +-+       +-+      4+-+
+--R       - a\|6 log(- x \|2   \|3 + x \|3  + \|2 ) + 2a\|6 atan(x\|6  + 1)
+--R     + 
+--R                                           2 +-+
+--R          +-+      4+-+          4+-+     x \|3
+--R       2a\|6 atan(x\|6  - 1) + 4b\|6 atan(------)
+--R                                            +-+
+--R                                           \|2
+--R  /
+--R       +-+4+-+
+--R     8\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +------------------------------------------+
+--R              |         2                          2    2      +-+
+--R           - \|- 36%%CS1  - 24%%CS0 %%CS1 - 36%%CS0  - b   - 2\|3 %%CS1
+--R         + 
+--R               +-+
+--R           - 2\|3 %%CS0
+--R      *
+--R         log
+--R                      2           2             2            4     4
+--R                ((768b %%CS0 - 48a b)%%CS1 - 48a b %%CS0 - 8b  + 6a )
+--R             *
+--R                 +------------------------------------------+
+--R                 |         2                          2    2
+--R                \|- 36%%CS1  - 24%%CS0 %%CS1 - 36%%CS0  - b
+--R            + 
+--R                      2 +-+           2  +-+      2
+--R              (- 1536b \|3 %%CS0 + 96a b\|3 )%%CS1
+--R            + 
+--R                      2 +-+     2         4      4  +-+            2  +-+     2
+--R              (- 1536b \|3 %%CS0  + (- 16b  + 12a )\|3 )%%CS1 + 96a b\|3 %%CS0
+--R            + 
+--R                    4      4  +-+              4     5       2 3  +-+
+--R              (- 16b  + 12a )\|3 %%CS0 + ((8a b  - 3a )x - 2a b )\|3
+--R     + 
+--R              +------------------------------------------+
+--R              |         2                          2    2      +-+
+--R             \|- 36%%CS1  - 24%%CS0 %%CS1 - 36%%CS0  - b   - 2\|3 %%CS1
+--R           + 
+--R                 +-+
+--R             - 2\|3 %%CS0
+--R      *
+--R         log
+--R                        2           2             2            4     4
+--R                ((- 768b %%CS0 + 48a b)%%CS1 + 48a b %%CS0 + 8b  - 6a )
+--R             *
+--R                 +------------------------------------------+
+--R                 |         2                          2    2
+--R                \|- 36%%CS1  - 24%%CS0 %%CS1 - 36%%CS0  - b
+--R            + 
+--R                      2 +-+           2  +-+      2
+--R              (- 1536b \|3 %%CS0 + 96a b\|3 )%%CS1
+--R            + 
+--R                      2 +-+     2         4      4  +-+            2  +-+     2
+--R              (- 1536b \|3 %%CS0  + (- 16b  + 12a )\|3 )%%CS1 + 96a b\|3 %%CS0
+--R            + 
+--R                    4      4  +-+              4     5       2 3  +-+
+--R              (- 16b  + 12a )\|3 %%CS0 + ((8a b  - 3a )x - 2a b )\|3
+--R     + 
+--R           +-+
+--R         4\|3 %%CS1
+--R      *
+--R         log
+--R                    2            2       2         2     2      4      4
+--R              (3072b %%CS0 - 192a b)%%CS1  + (3072b %%CS0  + 32b  - 24a )%%CS1
+--R            + 
+--R                   2     3      4             4     5       2 3
+--R              3072b %%CS0  + 64b %%CS0 + (8a b  - 3a )x - 6a b
+--R     + 
+--R           +-+
+--R         4\|3 %%CS0
+--R      *
+--R         log
+--R                     2     3       2       2         4      4
+--R              - 3072b %%CS0  - 192a b %%CS0  + (- 32b  - 24a )%%CS0
+--R            + 
+--R                   4     5        2 3
+--R              (8a b  - 3a )x + 10a b
+--R  /
+--R       +-+
+--R     4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 606
+
+--S 607 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       +------------------------------------------+
+--R               +-+4+-+ |         2                          2    2
+--R           - 2\|6 \|6 \|- 36%%CS1  - 24%%CS0 %%CS1 - 36%%CS0  - b
+--R         + 
+--R               +-+ +-+4+-+          +-+ +-+4+-+
+--R           - 4\|3 \|6 \|6 %%CS1 - 4\|3 \|6 \|6 %%CS0
+--R      *
+--R         log
+--R                      2           2             2            4     4
+--R                ((768b %%CS0 - 48a b)%%CS1 - 48a b %%CS0 - 8b  + 6a )
+--R             *
+--R                 +------------------------------------------+
+--R                 |         2                          2    2
+--R                \|- 36%%CS1  - 24%%CS0 %%CS1 - 36%%CS0  - b
+--R            + 
+--R                      2 +-+           2  +-+      2
+--R              (- 1536b \|3 %%CS0 + 96a b\|3 )%%CS1
+--R            + 
+--R                      2 +-+     2         4      4  +-+            2  +-+     2
+--R              (- 1536b \|3 %%CS0  + (- 16b  + 12a )\|3 )%%CS1 + 96a b\|3 %%CS0
+--R            + 
+--R                    4      4  +-+              4     5       2 3  +-+
+--R              (- 16b  + 12a )\|3 %%CS0 + ((8a b  - 3a )x - 2a b )\|3
+--R     + 
+--R                     +------------------------------------------+
+--R             +-+4+-+ |         2                          2    2
+--R           2\|6 \|6 \|- 36%%CS1  - 24%%CS0 %%CS1 - 36%%CS0  - b
+--R         + 
+--R               +-+ +-+4+-+          +-+ +-+4+-+
+--R           - 4\|3 \|6 \|6 %%CS1 - 4\|3 \|6 \|6 %%CS0
+--R      *
+--R         log
+--R                        2           2             2            4     4
+--R                ((- 768b %%CS0 + 48a b)%%CS1 + 48a b %%CS0 + 8b  - 6a )
+--R             *
+--R                 +------------------------------------------+
+--R                 |         2                          2    2
+--R                \|- 36%%CS1  - 24%%CS0 %%CS1 - 36%%CS0  - b
+--R            + 
+--R                      2 +-+           2  +-+      2
+--R              (- 1536b \|3 %%CS0 + 96a b\|3 )%%CS1
+--R            + 
+--R                      2 +-+     2         4      4  +-+            2  +-+     2
+--R              (- 1536b \|3 %%CS0  + (- 16b  + 12a )\|3 )%%CS1 + 96a b\|3 %%CS0
+--R            + 
+--R                    4      4  +-+              4     5       2 3  +-+
+--R              (- 16b  + 12a )\|3 %%CS0 + ((8a b  - 3a )x - 2a b )\|3
+--R     + 
+--R           +-+ +-+4+-+
+--R         8\|3 \|6 \|6 %%CS1
+--R      *
+--R         log
+--R                    2            2       2         2     2      4      4
+--R              (3072b %%CS0 - 192a b)%%CS1  + (3072b %%CS0  + 32b  - 24a )%%CS1
+--R            + 
+--R                   2     3      4             4     5       2 3
+--R              3072b %%CS0  + 64b %%CS0 + (8a b  - 3a )x - 6a b
+--R     + 
+--R           +-+ +-+4+-+
+--R         8\|3 \|6 \|6 %%CS0
+--R      *
+--R         log
+--R                     2     3       2       2         4      4
+--R              - 3072b %%CS0  - 192a b %%CS0  + (- 32b  - 24a )%%CS0
+--R            + 
+--R                   4     5        2 3
+--R              (8a b  - 3a )x + 10a b
+--R     + 
+--R           +-+ +-+      4+-+3 4+-+   2 +-+    +-+
+--R       - a\|3 \|6 log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R         +-+ +-+        4+-+3 4+-+   2 +-+    +-+       +-+ +-+      4+-+
+--R       a\|3 \|6 log(- x \|2   \|3 + x \|3  + \|2 ) - 2a\|3 \|6 atan(x\|6  + 1)
+--R     + 
+--R                                                     2 +-+
+--R            +-+ +-+      4+-+           +-+4+-+     x \|3
+--R       - 2a\|3 \|6 atan(x\|6  - 1) - 4b\|3 \|6 atan(------)
+--R                                                      +-+
+--R                                                     \|2
+--R  /
+--R       +-+ +-+4+-+
+--R     8\|3 \|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  3 +-+4+-+2 +-+4+-+2        5         +-+ +-+        3  +-+
+--R           (- 4b x \|2 \|2  \|3 \|3   + (6b x  + 4b x)\|2 \|3  + 24b x )\|6
+--R         + 
+--R                 3        2 4+-+2 4+-+2          3        2  +-+ +-+        5
+--R           (24b x  + 12a x )\|2   \|3  + (- 24b x  - 12a x )\|2 \|3  - 36b x
+--R         + 
+--R                  4
+--R           - 18a x  - 24b x - 12a
+--R      *
+--R         4+-+2
+--R         \|6
+--R     + 
+--R               6       2 4+-+3 +-+        4       +-+4+-+3 4+-+4+-+
+--R       ((- 9a x  - 6a x )\|2  \|3  + (9a x  + 6a)\|2 \|2  )\|3 \|6
+--R     + 
+--R              4 4+-+2 4+-+2      4 +-+ +-+        6        2
+--R       - 36a x  \|2   \|3 + 36a x \|2 \|3  + 54a x  + 36a x
+--R  /
+--R            6      2 4+-+2 4+-+2        6      2  +-+ +-+       8       4
+--R       ((72x  + 48x )\|2   \|3  + (- 72x  - 48x )\|2 \|3  - 108x  - 144x  - 48)
+--R    *
+--R       4+-+2
+--R       \|6
+--R                                                    Type: Expression(Integer)
+--E 608
+
+)clear all
+
+--S 609 of 953
+t0:=c*x^2/(2+3*x^4)
+--R 
+--R
+--R             2
+--R          c x
+--R   (1)  -------
+--R          4
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 609
+
+--S 610 of 953
+r0:=-1/2*c*atan(1-6^(1/4)*x)/6^(3/4)+1/2*c*atan(1+6^(1/4)*x)/6^(3/4)+_
+   1/4*c*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)-1/4*c*_
+   log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R                 4+-+3 4+-+   2 +-+    +-+
+--R       - c log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R                 4+-+3 4+-+   2 +-+    +-+             4+-+
+--R       c log(- x \|2   \|3 + x \|3  + \|2 ) + 2c atan(x\|6  + 1)
+--R     + 
+--R                4+-+
+--R       2c atan(x\|6  - 1)
+--R  /
+--R      4+-+3
+--R     4\|6
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +--+                 +--+3       +--+2
+--R          +-+4| 4       +-+4+--+3 4| 4        4| 4       3 2 4+--+2
+--R       - \|2 \|c  log(x\|2 \|54   \|c   + 18c \|c    + 3c x  \|54 )
+--R     + 
+--R            +--+                   +--+3       +--+2
+--R        +-+4| 4         +-+4+--+3 4| 4        4| 4       3 2 4+--+2
+--R       \|2 \|c  log(- x\|2 \|54   \|c   + 18c \|c    + 3c x  \|54 )
+--R     + 
+--R                                 +--+3
+--R             +--+               4| 4
+--R         +-+4| 4              18\|c
+--R       2\|2 \|c  atan(------------------------)
+--R                         +--+3
+--R                        4| 4      3  +-+4+--+3
+--R                      18\|c    - c x\|2 \|54
+--R     + 
+--R                                   +--+3
+--R               +--+               4| 4
+--R           +-+4| 4              18\|c
+--R       - 2\|2 \|c  atan(------------------------)
+--R                           +--+3
+--R                          4| 4      3  +-+4+--+3
+--R                        18\|c    + c x\|2 \|54
+--R  /
+--R      4+--+
+--R     8\|54
+--R                                         Type: Union(Expression(Integer),...)
+--E 611
+
+--S 612 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    +--+                 +--+3       +--+2
+--R          +-+4+-+3 4| 4       +-+4+--+3 4| 4        4| 4       3 2 4+--+2
+--R       - \|2 \|6   \|c  log(x\|2 \|54   \|c   + 18c \|c    + 3c x  \|54 )
+--R     + 
+--R                  +--+                   +--+3       +--+2
+--R        +-+4+-+3 4| 4         +-+4+--+3 4| 4        4| 4       3 2 4+--+2
+--R       \|2 \|6   \|c  log(- x\|2 \|54   \|c   + 18c \|c    + 3c x  \|54 )
+--R     + 
+--R                                       +--+3
+--R                   +--+               4| 4
+--R         +-+4+-+3 4| 4              18\|c
+--R       2\|2 \|6   \|c  atan(------------------------)
+--R                               +--+3
+--R                              4| 4      3  +-+4+--+3
+--R                            18\|c    - c x\|2 \|54
+--R     + 
+--R                                         +--+3
+--R                     +--+               4| 4
+--R           +-+4+-+3 4| 4              18\|c
+--R       - 2\|2 \|6   \|c  atan(------------------------)
+--R                                 +--+3
+--R                                4| 4      3  +-+4+--+3
+--R                              18\|c    + c x\|2 \|54
+--R     + 
+--R         4+--+      4+-+3 4+-+   2 +-+    +-+
+--R       2c\|54 log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           4+--+        4+-+3 4+-+   2 +-+    +-+      4+--+      4+-+
+--R       - 2c\|54 log(- x \|2   \|3 + x \|3  + \|2 ) - 4c\|54 atan(x\|6  + 1)
+--R     + 
+--R           4+--+      4+-+
+--R       - 4c\|54 atan(x\|6  - 1)
+--R  /
+--R      4+-+3 4+--+
+--R     8\|6   \|54
+--R                                                    Type: Expression(Integer)
+--E 612
+
+--S 613 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R             6       2 4+-+3 +-+          4       +-+4+-+3 4+-+4+-+3
+--R       ((3c x  + 2c x )\|2  \|3  + (- 3c x  - 2c)\|2 \|2  )\|3 \|6
+--R     + 
+--R             4 4+-+2 4+-+2      4 +-+ +-+        6        2 4+-+2
+--R       (12c x  \|2   \|3 - 12c x \|2 \|3  - 18c x  - 12c x )\|6
+--R     + 
+--R              2 4+-+2 4+-+2      2 +-+ +-+        4
+--R       - 24c x  \|2   \|3 + 24c x \|2 \|3  + 36c x  + 24c
+--R  /
+--R            6      2 4+-+2 4+-+2        6      2  +-+ +-+       8       4
+--R       ((72x  + 48x )\|2   \|3  + (- 72x  - 48x )\|2 \|3  - 108x  - 144x  - 48)
+--R    *
+--R       4+-+2
+--R       \|6
+--R                                                    Type: Expression(Integer)
+--E 613
+
+)clear all
+
+--S 614 of 953
+t0:=(a+c*x^2)/(2+3*x^4)
+--R 
+--R
+--R           2
+--R        c x  + a
+--R   (1)  --------
+--R           4
+--R         3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 614
+
+--S 615 of 953
+r0:=-1/8*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*(-2*c+a*_
+   sqrt(6))/6^(3/4)+1/8*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*_
+   (-2*c+a*sqrt(6))/6^(3/4)-1/4*atan(1-6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)+_
+   1/4*atan(1+6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R          +-+            4+-+3 4+-+   2 +-+    +-+
+--R       (a\|6  - 2c)log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R            +-+              4+-+3 4+-+   2 +-+    +-+
+--R       (- a\|6  + 2c)log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+            4+-+            +-+            4+-+
+--R       (2a\|6  + 4c)atan(x\|6  + 1) + (2a\|6  + 4c)atan(x\|6  - 1)
+--R  /
+--R      4+-+3
+--R     8\|6
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                        +------------------+
+--R                                        |  4      2 2     4
+--R                                       \|4c  - 12a c  + 9a
+--R                                  atan(---------------------)
+--R          +------------------+                     +-+
+--R         4|  4      2 2     4                 2a c\|6
+--R         \|4c  + 12a c  + 9a  cos(---------------------------)
+--R                                               2
+--R      *
+--R         log
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R                               +------------------+ +------------------+
+--R                     +-+4+---+ |  4      2 2     4 4|  4      2 2     4
+--R                4c x\|6 \|216 \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                                       +------------------+
+--R                      2      3  4+---+4|  4      2 2     4
+--R                (24a c  - 36a )x\|216 \|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                 4     4  2 4+---+2
+--R              (4c  - 9a )x  \|216
+--R     + 
+--R       -
+--R                                           +------------------+
+--R                                           |  4      2 2     4
+--R                                          \|4c  - 12a c  + 9a
+--R                                     atan(---------------------)
+--R             +------------------+                     +-+
+--R            4|  4      2 2     4                 2a c\|6
+--R            \|4c  + 12a c  + 9a  cos(---------------------------)
+--R                                                  2
+--R         *
+--R            log
+--R                                 +------------------+2
+--R                       2      2 4|  4      2 2     4
+--R                   (24c  - 36a )\|4c  + 12a c  + 9a
+--R                *
+--R                             +------------------+  2
+--R                             |  4      2 2     4
+--R                            \|4c  - 12a c  + 9a
+--R                       atan(---------------------)
+--R                                        +-+
+--R                                   2a c\|6
+--R                   sin(---------------------------)
+--R                                    2
+--R               + 
+--R                 -
+--R                                     +------------------+ +------------------+
+--R                           +-+4+---+ |  4      2 2     4 4|  4      2 2     4
+--R                      4c x\|6 \|216 \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                   *
+--R                                +------------------+
+--R                                |  4      2 2     4
+--R                               \|4c  - 12a c  + 9a
+--R                          atan(---------------------)
+--R                                           +-+
+--R                                      2a c\|6
+--R                      sin(---------------------------)
+--R                                       2
+--R               + 
+--R                                 +------------------+2
+--R                       2      2 4|  4      2 2     4
+--R                   (24c  - 36a )\|4c  + 12a c  + 9a
+--R                *
+--R                             +------------------+  2
+--R                             |  4      2 2     4
+--R                            \|4c  - 12a c  + 9a
+--R                       atan(---------------------)
+--R                                        +-+
+--R                                   2a c\|6
+--R                   cos(---------------------------)
+--R                                    2
+--R               + 
+--R                                            +------------------+
+--R                           2      3  4+---+4|  4      2 2     4
+--R                   (- 24a c  + 36a )x\|216 \|4c  + 12a c  + 9a
+--R                *
+--R                             +------------------+
+--R                             |  4      2 2     4
+--R                            \|4c  - 12a c  + 9a
+--R                       atan(---------------------)
+--R                                        +-+
+--R                                   2a c\|6
+--R                   cos(---------------------------)
+--R                                    2
+--R               + 
+--R                    4     4  2 4+---+2
+--R                 (4c  - 9a )x  \|216
+--R     + 
+--R                                         +------------------+
+--R                                         |  4      2 2     4
+--R                                        \|4c  - 12a c  + 9a
+--R                                   atan(---------------------)
+--R           +------------------+                     +-+
+--R          4|  4      2 2     4                 2a c\|6
+--R         2\|4c  + 12a c  + 9a  sin(---------------------------)
+--R                                                2
+--R      *
+--R         atan
+--R                                      +------------------+
+--R                        2      3  +-+4|  4      2 2     4
+--R                  (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  sin(---------------------------)
+--R                                   2
+--R              + 
+--R                -
+--R                         +------------------+ +------------------+
+--R                         |  4      2 2     4 4|  4      2 2     4
+--R                     12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     cos(---------------------------)
+--R                                      2
+--R           /
+--R                      +------------------+ +------------------+
+--R                      |  4      2 2     4 4|  4      2 2     4
+--R                  12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  sin(---------------------------)
+--R                                   2
+--R              + 
+--R                                      +------------------+
+--R                        2      3  +-+4|  4      2 2     4
+--R                  (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  cos(---------------------------)
+--R                                   2
+--R              + 
+--R                     4     4   +-+4+---+
+--R                (- 4c  + 9a )x\|6 \|216
+--R     + 
+--R       -
+--R                                            +------------------+
+--R                                            |  4      2 2     4
+--R                                           \|4c  - 12a c  + 9a
+--R                                      atan(---------------------)
+--R              +------------------+                     +-+
+--R             4|  4      2 2     4                 2a c\|6
+--R            2\|4c  + 12a c  + 9a  sin(---------------------------)
+--R                                                   2
+--R         *
+--R            atan
+--R                                         +------------------+
+--R                           2      3  +-+4|  4      2 2     4
+--R                     (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     sin(---------------------------)
+--R                                      2
+--R                 + 
+--R                   -
+--R                            +------------------+ +------------------+
+--R                            |  4      2 2     4 4|  4      2 2     4
+--R                        12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                     *
+--R                                  +------------------+
+--R                                  |  4      2 2     4
+--R                                 \|4c  - 12a c  + 9a
+--R                            atan(---------------------)
+--R                                             +-+
+--R                                        2a c\|6
+--R                        cos(---------------------------)
+--R                                         2
+--R              /
+--R                         +------------------+ +------------------+
+--R                         |  4      2 2     4 4|  4      2 2     4
+--R                     12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     sin(---------------------------)
+--R                                      2
+--R                 + 
+--R                                         +------------------+
+--R                           2      3  +-+4|  4      2 2     4
+--R                     (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     cos(---------------------------)
+--R                                      2
+--R                 + 
+--R                      4     4   +-+4+---+
+--R                   (4c  - 9a )x\|6 \|216
+--R  /
+--R      4+---+
+--R     4\|216
+--R                                         Type: Union(Expression(Integer),...)
+--E 616
+
+--S 617 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +------------------+
+--R                                               |  4      2 2     4
+--R                                              \|4c  - 12a c  + 9a
+--R                                         atan(---------------------)
+--R                 +------------------+                     +-+
+--R          4+-+3 4|  4      2 2     4                 2a c\|6
+--R         2\|6   \|4c  + 12a c  + 9a  cos(---------------------------)
+--R                                                      2
+--R      *
+--R         log
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R                               +------------------+ +------------------+
+--R                     +-+4+---+ |  4      2 2     4 4|  4      2 2     4
+--R                4c x\|6 \|216 \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                                       +------------------+
+--R                      2      3  4+---+4|  4      2 2     4
+--R                (24a c  - 36a )x\|216 \|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                 4     4  2 4+---+2
+--R              (4c  - 9a )x  \|216
+--R     + 
+--R       -
+--R                                                  +------------------+
+--R                                                  |  4      2 2     4
+--R                                                 \|4c  - 12a c  + 9a
+--R                                            atan(---------------------)
+--R                    +------------------+                     +-+
+--R             4+-+3 4|  4      2 2     4                 2a c\|6
+--R            2\|6   \|4c  + 12a c  + 9a  cos(---------------------------)
+--R                                                         2
+--R         *
+--R            log
+--R                                 +------------------+2
+--R                       2      2 4|  4      2 2     4
+--R                   (24c  - 36a )\|4c  + 12a c  + 9a
+--R                *
+--R                             +------------------+  2
+--R                             |  4      2 2     4
+--R                            \|4c  - 12a c  + 9a
+--R                       atan(---------------------)
+--R                                        +-+
+--R                                   2a c\|6
+--R                   sin(---------------------------)
+--R                                    2
+--R               + 
+--R                 -
+--R                                     +------------------+ +------------------+
+--R                           +-+4+---+ |  4      2 2     4 4|  4      2 2     4
+--R                      4c x\|6 \|216 \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                   *
+--R                                +------------------+
+--R                                |  4      2 2     4
+--R                               \|4c  - 12a c  + 9a
+--R                          atan(---------------------)
+--R                                           +-+
+--R                                      2a c\|6
+--R                      sin(---------------------------)
+--R                                       2
+--R               + 
+--R                                 +------------------+2
+--R                       2      2 4|  4      2 2     4
+--R                   (24c  - 36a )\|4c  + 12a c  + 9a
+--R                *
+--R                             +------------------+  2
+--R                             |  4      2 2     4
+--R                            \|4c  - 12a c  + 9a
+--R                       atan(---------------------)
+--R                                        +-+
+--R                                   2a c\|6
+--R                   cos(---------------------------)
+--R                                    2
+--R               + 
+--R                                            +------------------+
+--R                           2      3  4+---+4|  4      2 2     4
+--R                   (- 24a c  + 36a )x\|216 \|4c  + 12a c  + 9a
+--R                *
+--R                             +------------------+
+--R                             |  4      2 2     4
+--R                            \|4c  - 12a c  + 9a
+--R                       atan(---------------------)
+--R                                        +-+
+--R                                   2a c\|6
+--R                   cos(---------------------------)
+--R                                    2
+--R               + 
+--R                    4     4  2 4+---+2
+--R                 (4c  - 9a )x  \|216
+--R     + 
+--R                                               +------------------+
+--R                                               |  4      2 2     4
+--R                                              \|4c  - 12a c  + 9a
+--R                                         atan(---------------------)
+--R                 +------------------+                     +-+
+--R          4+-+3 4|  4      2 2     4                 2a c\|6
+--R         4\|6   \|4c  + 12a c  + 9a  sin(---------------------------)
+--R                                                      2
+--R      *
+--R         atan
+--R                                      +------------------+
+--R                        2      3  +-+4|  4      2 2     4
+--R                  (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  sin(---------------------------)
+--R                                   2
+--R              + 
+--R                -
+--R                         +------------------+ +------------------+
+--R                         |  4      2 2     4 4|  4      2 2     4
+--R                     12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     cos(---------------------------)
+--R                                      2
+--R           /
+--R                      +------------------+ +------------------+
+--R                      |  4      2 2     4 4|  4      2 2     4
+--R                  12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  sin(---------------------------)
+--R                                   2
+--R              + 
+--R                                      +------------------+
+--R                        2      3  +-+4|  4      2 2     4
+--R                  (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  cos(---------------------------)
+--R                                   2
+--R              + 
+--R                     4     4   +-+4+---+
+--R                (- 4c  + 9a )x\|6 \|216
+--R     + 
+--R       -
+--R                                                  +------------------+
+--R                                                  |  4      2 2     4
+--R                                                 \|4c  - 12a c  + 9a
+--R                                            atan(---------------------)
+--R                    +------------------+                     +-+
+--R             4+-+3 4|  4      2 2     4                 2a c\|6
+--R            4\|6   \|4c  + 12a c  + 9a  sin(---------------------------)
+--R                                                         2
+--R         *
+--R            atan
+--R                                         +------------------+
+--R                           2      3  +-+4|  4      2 2     4
+--R                     (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     sin(---------------------------)
+--R                                      2
+--R                 + 
+--R                   -
+--R                            +------------------+ +------------------+
+--R                            |  4      2 2     4 4|  4      2 2     4
+--R                        12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                     *
+--R                                  +------------------+
+--R                                  |  4      2 2     4
+--R                                 \|4c  - 12a c  + 9a
+--R                            atan(---------------------)
+--R                                             +-+
+--R                                        2a c\|6
+--R                        cos(---------------------------)
+--R                                         2
+--R              /
+--R                         +------------------+ +------------------+
+--R                         |  4      2 2     4 4|  4      2 2     4
+--R                     12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     sin(---------------------------)
+--R                                      2
+--R                 + 
+--R                                         +------------------+
+--R                           2      3  +-+4|  4      2 2     4
+--R                     (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     cos(---------------------------)
+--R                                      2
+--R                 + 
+--R                      4     4   +-+4+---+
+--R                   (4c  - 9a )x\|6 \|216
+--R     + 
+--R            +-+      4+---+      4+-+3 4+-+   2 +-+    +-+
+--R       (- a\|6  + 2c)\|216 log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R          +-+      4+---+        4+-+3 4+-+   2 +-+    +-+
+--R       (a\|6  - 2c)\|216 log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+      4+---+      4+-+              +-+      4+---+      4+-+
+--R     (- 2a\|6  - 4c)\|216 atan(x\|6  + 1) + (- 2a\|6  - 4c)\|216 atan(x\|6  - 1)
+--R  /
+--R      4+-+3 4+---+
+--R     8\|6   \|216
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                               6       3 4       5 2       7  6
+--R                       (- 96a c  - 144a c  + 216a c  + 324a )x
+--R                     + 
+--R                               6      3 4       5 2       7  2
+--R                       (- 64a c  - 96a c  + 144a c  + 216a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                             6       3 4       5 2       7  4        6      3 4
+--R                       (96a c  + 144a c  - 216a c  - 324a )x  + 64a c  + 96a c
+--R                     + 
+--R                             5 2       7
+--R                       - 144a c  - 216a
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                            7       2 5       4 3       6   6
+--R                       (192c  + 288a c  - 432a c  - 648a c)x
+--R                     + 
+--R                            7       2 5       4 3       6   2
+--R                       (128c  + 192a c  - 288a c  - 432a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                              7       2 5       4 3       6   4       7
+--R                       (- 192c  - 288a c  + 432a c  + 648a c)x  - 128c
+--R                     + 
+--R                             2 5       4 3       6
+--R                       - 192a c  + 288a c  + 432a c
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                            6       3 4       5 2        7  4 4+-+2 4+-+2
+--R                   (- 384a c  - 576a c  + 864a c  + 1296a )x  \|2   \|3
+--R                 + 
+--R                          6       3 4       5 2        7  4 +-+ +-+
+--R                   (384a c  + 576a c  - 864a c  - 1296a )x \|2 \|3
+--R                 + 
+--R                          6       3 4        5 2        7  6
+--R                   (576a c  + 864a c  - 1296a c  - 1944a )x
+--R                 + 
+--R                          6       3 4       5 2        7  2
+--R                   (384a c  + 576a c  - 864a c  - 1296a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                           6        3 4        5 2        7  6
+--R                   (2304a c  + 3456a c  - 5184a c  - 7776a )x
+--R                 + 
+--R                          7        2 5        4 3        6   4
+--R                   (- 768c  - 1152a c  + 1728a c  + 2592a c)x
+--R                 + 
+--R                           6        3 4        5 2        7  2
+--R                   (1536a c  + 2304a c  - 3456a c  - 5184a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                             6        3 4        5 2        7  6
+--R                   (- 2304a c  - 3456a c  + 5184a c  + 7776a )x
+--R                 + 
+--R                        7        2 5        4 3        6   4
+--R                   (768c  + 1152a c  - 1728a c  - 2592a c)x
+--R                 + 
+--R                             6        3 4        5 2        7  2
+--R                   (- 1536a c  - 2304a c  + 3456a c  + 5184a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                         6        3 4        5 2         7  8
+--R               (- 3456a c  - 5184a c  + 7776a c  + 11664a )x
+--R             + 
+--R                     7        2 5        4 3        6   6
+--R               (1152c  + 1728a c  - 2592a c  - 3888a c)x
+--R             + 
+--R                         6        3 4         5 2         7  4
+--R               (- 4608a c  - 6912a c  + 10368a c  + 15552a )x
+--R             + 
+--R                    7        2 5        4 3        6   2          6        3 4
+--R               (768c  + 1152a c  - 1728a c  - 2592a c)x  - 1536a c  - 2304a c
+--R             + 
+--R                    5 2        7
+--R               3456a c  + 5184a
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                        6        3 4        5 2        7  2 4+-+2 4+-+2
+--R               (- 768a c  - 1152a c  + 1728a c  + 2592a )x  \|2   \|3
+--R             + 
+--R                      6        3 4        5 2        7  2 +-+ +-+
+--R               (768a c  + 1152a c  - 1728a c  - 2592a )x \|2 \|3
+--R             + 
+--R                       6        3 4        5 2        7  4         6        3 4
+--R               (1152a c  + 1728a c  - 2592a c  - 3888a )x  + 768a c  + 1152a c
+--R             + 
+--R                      5 2        7
+--R               - 1728a c  - 2592a
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                   7        2 5        4 3        6   2 4+-+2 4+-+2
+--R           (- 1536c  - 2304a c  + 3456a c  + 5184a c)x  \|2   \|3
+--R         + 
+--R                 7        2 5        4 3        6   2 +-+ +-+
+--R           (1536c  + 2304a c  - 3456a c  - 5184a c)x \|2 \|3
+--R         + 
+--R                 7        2 5        4 3        6   4        7        2 5
+--R           (2304c  + 3456a c  - 5184a c  - 7776a c)x  + 1536c  + 2304a c
+--R         + 
+--R                  4 3        6
+--R           - 3456a c  - 5184a c
+--R      *
+--R                          +------------------+  8
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R         4+---+2                2a c\|6
+--R         \|216  sin(---------------------------)
+--R                                 2
+--R     + 
+--R                                    6       3 4       5 2        7  6
+--R                           (- 384a c  - 576a c  + 864a c  + 1296a )x
+--R                         + 
+--R                                    6       3 4       5 2       7  2
+--R                           (- 256a c  - 384a c  + 576a c  + 864a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  6       3 4       5 2        7  4         6
+--R                           (384a c  + 576a c  - 864a c  - 1296a )x  + 256a c
+--R                         + 
+--R                               3 4       5 2       7
+--R                           384a c  - 576a c  - 864a
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                7        2 5        4 3        6   6
+--R                           (768c  + 1152a c  - 1728a c  - 2592a c)x
+--R                         + 
+--R                                7       2 5        4 3        6   2
+--R                           (512c  + 768a c  - 1152a c  - 1728a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  7        2 5        4 3        6   4       7
+--R                           (- 768c  - 1152a c  + 1728a c  + 2592a c)x  - 512c
+--R                         + 
+--R                                 2 5        4 3        6
+--R                           - 768a c  + 1152a c  + 1728a c
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                 6        3 4        5 2        7  4 4+-+2 4+-+2
+--R                       (- 1536a c  - 2304a c  + 3456a c  + 5184a )x  \|2   \|3
+--R                     + 
+--R                               6        3 4        5 2        7  4 +-+ +-+
+--R                       (1536a c  + 2304a c  - 3456a c  - 5184a )x \|2 \|3
+--R                     + 
+--R                               6        3 4        5 2        7  6
+--R                       (2304a c  + 3456a c  - 5184a c  - 7776a )x
+--R                     + 
+--R                               6        3 4        5 2        7  2
+--R                       (1536a c  + 2304a c  - 3456a c  - 5184a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                               6         3 4         5 2         7  6
+--R                       (9216a c  + 13824a c  - 20736a c  - 31104a )x
+--R                     + 
+--R                               7        2 5        4 3         6   4
+--R                       (- 3072c  - 4608a c  + 6912a c  + 10368a c)x
+--R                     + 
+--R                               6        3 4         5 2         7  2
+--R                       (6144a c  + 9216a c  - 13824a c  - 20736a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                 6         3 4         5 2         7  6
+--R                       (- 9216a c  - 13824a c  + 20736a c  + 31104a )x
+--R                     + 
+--R                             7        2 5        4 3         6   4
+--R                       (3072c  + 4608a c  - 6912a c  - 10368a c)x
+--R                     + 
+--R                                 6        3 4         5 2         7  2
+--R                       (- 6144a c  - 9216a c  + 13824a c  + 20736a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                              6         3 4         5 2         7  8
+--R                   (- 13824a c  - 20736a c  + 31104a c  + 46656a )x
+--R                 + 
+--R                         7        2 5         4 3         6   6
+--R                   (4608c  + 6912a c  - 10368a c  - 15552a c)x
+--R                 + 
+--R                              6         3 4         5 2         7  4
+--R                   (- 18432a c  - 27648a c  + 41472a c  + 62208a )x
+--R                 + 
+--R                         7        2 5        4 3         6   2          6
+--R                   (3072c  + 4608a c  - 6912a c  - 10368a c)x  - 6144a c
+--R                 + 
+--R                          3 4         5 2         7
+--R                   - 9216a c  + 13824a c  + 20736a
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                             6        3 4        5 2         7  2 4+-+2 4+-+2
+--R                   (- 3072a c  - 4608a c  + 6912a c  + 10368a )x  \|2   \|3
+--R                 + 
+--R                           6        3 4        5 2         7  2 +-+ +-+
+--R                   (3072a c  + 4608a c  - 6912a c  - 10368a )x \|2 \|3
+--R                 + 
+--R                           6        3 4         5 2         7  4          6
+--R                   (4608a c  + 6912a c  - 10368a c  - 15552a )x  + 3072a c
+--R                 + 
+--R                        3 4        5 2         7
+--R                   4608a c  - 6912a c  - 10368a
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                       7        2 5         4 3         6   2 4+-+2 4+-+2
+--R               (- 6144c  - 9216a c  + 13824a c  + 20736a c)x  \|2   \|3
+--R             + 
+--R                     7        2 5         4 3         6   2 +-+ +-+
+--R               (6144c  + 9216a c  - 13824a c  - 20736a c)x \|2 \|3
+--R             + 
+--R                     7         2 5         4 3         6   4        7        2 5
+--R               (9216c  + 13824a c  - 20736a c  - 31104a c)x  + 6144c  + 9216a c
+--R             + 
+--R                       4 3         6
+--R               - 13824a c  - 20736a c
+--R          *
+--R                              +------------------+  2
+--R                              |  4      2 2     4
+--R                             \|4c  - 12a c  + 9a
+--R                        atan(---------------------)
+--R                                         +-+
+--R             4+---+2                2a c\|6
+--R             \|216  cos(---------------------------)
+--R                                     2
+--R         + 
+--R                                   4         3 2        5  8
+--R                           (3456a c  - 10368a c  + 7776a )x
+--R                         + 
+--R                                   4        3 2        5  4
+--R                           (2304a c  - 6912a c  + 5184a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                     4         3 2        5  6
+--R                           (- 3456a c  + 10368a c  - 7776a )x
+--R                         + 
+--R                                     4        3 2        5  2
+--R                           (- 2304a c  + 6912a c  - 5184a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                   5         2 3         4   8
+--R                           (- 6912c  + 20736a c  - 15552a c)x
+--R                         + 
+--R                                   5         2 3         4   4
+--R                           (- 4608c  + 13824a c  - 10368a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                 5         2 3         4   6
+--R                           (6912c  - 20736a c  + 15552a c)x
+--R                         + 
+--R                                 5         2 3         4   2
+--R                           (4608c  - 13824a c  + 10368a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                4         3 2         5  6 4+-+2 4+-+2
+--R                       (13824a c  - 41472a c  + 31104a )x  \|2   \|3
+--R                     + 
+--R                                  4         3 2         5  6 +-+ +-+
+--R                       (- 13824a c  + 41472a c  - 31104a )x \|2 \|3
+--R                     + 
+--R                                  4         3 2         5  8
+--R                       (- 20736a c  + 62208a c  - 46656a )x
+--R                     + 
+--R                                  4         3 2         5  4
+--R                       (- 13824a c  + 41472a c  - 31104a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                  4          3 2          5  8
+--R                       (- 20736a c  + 124416a c  - 139968a )x
+--R                     + 
+--R                              5         2 3         4   6
+--R                       (27648c  - 82944a c  + 62208a c)x
+--R                     + 
+--R                                  4         3 2         5  4
+--R                       (- 13824a c  + 82944a c  - 93312a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                4          3 2          5  8
+--R                       (20736a c  - 124416a c  + 139968a )x
+--R                     + 
+--R                                5         2 3         4   6
+--R                       (- 27648c  + 82944a c  - 62208a c)x
+--R                     + 
+--R                                4         3 2         5  4
+--R                       (13824a c  - 82944a c  + 93312a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                            4          3 2          5  10
+--R                   (31104a c  - 186624a c  + 209952a )x
+--R                 + 
+--R                            5          2 3         4   8
+--R                   (- 41472c  + 124416a c  - 93312a c)x
+--R                 + 
+--R                            4          3 2          5  6
+--R                   (41472a c  - 248832a c  + 279936a )x
+--R                 + 
+--R                            5         2 3         4   4
+--R                   (- 27648c  + 82944a c  - 62208a c)x
+--R                 + 
+--R                            4         3 2         5  2
+--R                   (13824a c  - 82944a c  + 93312a )x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                            4         3 2         5  4 4+-+2 4+-+2
+--R                   (27648a c  - 82944a c  + 62208a )x  \|2   \|3
+--R                 + 
+--R                              4         3 2         5  4 +-+ +-+
+--R                   (- 27648a c  + 82944a c  - 62208a )x \|2 \|3
+--R                 + 
+--R                              4          3 2         5  6
+--R                   (- 41472a c  + 124416a c  - 93312a )x
+--R                 + 
+--R                              4         3 2         5  2
+--R                   (- 27648a c  + 82944a c  - 62208a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      5          2 3          4   4 4+-+2 4+-+2
+--R               (55296c  - 165888a c  + 124416a c)x  \|2   \|3
+--R             + 
+--R                        5          2 3          4   4 +-+ +-+
+--R               (- 55296c  + 165888a c  - 124416a c)x \|2 \|3
+--R             + 
+--R                        5          2 3          4   6
+--R               (- 82944c  + 248832a c  - 186624a c)x
+--R             + 
+--R                        5          2 3          4   2
+--R               (- 55296c  + 165888a c  - 124416a c)x
+--R          *
+--R              +------------------+2
+--R             4|  4      2 2     4
+--R             \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+  6
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                             2 8          2 4 4+-+3 +-+
+--R                   (- 6912a c x  - 4608a c x )\|2  \|3
+--R                 + 
+--R                           2 6          2 2  +-+4+-+3
+--R                   (6912a c x  + 4608a c x )\|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                          2   8         2   4 4+-+3 +-+
+--R                   (20736a c x  + 13824a c x )\|2  \|3
+--R                 + 
+--R                            2   6         2   2  +-+4+-+3
+--R                   (- 20736a c x  - 13824a c x )\|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                               3         2   8           2 6
+--R                       (- 6912c  - 51840a c)x  + 27648a c x
+--R                     + 
+--R                               3         2   4
+--R                       (- 4608c  - 34560a c)x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                               3         2   8           2 6
+--R                         (6912c  + 51840a c)x  - 27648a c x
+--R                       + 
+--R                               3         2   4
+--R                         (4608c  + 34560a c)x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                          3         2   10           2 8
+--R                   (10368c  + 77760a c)x   - 41472a c x
+--R                 + 
+--R                        3          2   6           2 4         3         2   2
+--R                 (13824c  + 103680a c)x  - 27648a c x  + (4608c  + 34560a c)x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                     2   6 4+-+2 4+-+2       2   6 +-+ +-+          2   8
+--R               82944a c x  \|2   \|3 - 82944a c x \|2 \|3  - 124416a c x
+--R             + 
+--R                       2   4
+--R               - 82944a c x
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                       2 4 4+-+2 4+-+2         2 4 +-+ +-+           2 6
+--R               55296a c x  \|2   \|3 - 55296a c x \|2 \|3  - 82944a c x
+--R             + 
+--R                         2 2
+--R               - 55296a c x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                  2   4 4+-+2 4+-+2        2   4 +-+ +-+          2   6
+--R           165888a c x  \|2   \|3 - 165888a c x \|2 \|3  - 248832a c x
+--R         + 
+--R                    2   2
+--R           - 165888a c x
+--R      *
+--R          +------------------+ +------------------+2
+--R          |  4      2 2     4 4|  4      2 2     4
+--R         \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+            +------------------+  5
+--R                   |  4      2 2     4             |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a             \|4c  - 12a c  + 9a
+--R             atan(---------------------)     atan(---------------------)
+--R                              +-+                             +-+
+--R                         2a c\|6                         2a c\|6
+--R         cos(---------------------------)sin(---------------------------)
+--R                          2                               2
+--R     + 
+--R                                    6       3 4        5 2        7  6
+--R                           (- 576a c  - 864a c  + 1296a c  + 1944a )x
+--R                         + 
+--R                                    6       3 4       5 2        7  2
+--R                           (- 384a c  - 576a c  + 864a c  + 1296a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  6       3 4        5 2        7  4         6
+--R                           (576a c  + 864a c  - 1296a c  - 1944a )x  + 384a c
+--R                         + 
+--R                               3 4       5 2        7
+--R                           576a c  - 864a c  - 1296a
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                 7        2 5        4 3        6   6
+--R                           (1152c  + 1728a c  - 2592a c  - 3888a c)x
+--R                         + 
+--R                                7        2 5        4 3        6   2
+--R                           (768c  + 1152a c  - 1728a c  - 2592a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                   7        2 5        4 3        6   4       7
+--R                           (- 1152c  - 1728a c  + 2592a c  + 3888a c)x  - 768c
+--R                         + 
+--R                                  2 5        4 3        6
+--R                           - 1152a c  + 1728a c  + 2592a c
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                 6        3 4        5 2        7  4 4+-+2 4+-+2
+--R                       (- 2304a c  - 3456a c  + 5184a c  + 7776a )x  \|2   \|3
+--R                     + 
+--R                               6        3 4        5 2        7  4 +-+ +-+
+--R                       (2304a c  + 3456a c  - 5184a c  - 7776a )x \|2 \|3
+--R                     + 
+--R                               6        3 4        5 2         7  6
+--R                       (3456a c  + 5184a c  - 7776a c  - 11664a )x
+--R                     + 
+--R                               6        3 4        5 2        7  2
+--R                       (2304a c  + 3456a c  - 5184a c  - 7776a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                6         3 4         5 2         7  6
+--R                       (13824a c  + 20736a c  - 31104a c  - 46656a )x
+--R                     + 
+--R                               7        2 5         4 3         6   4
+--R                       (- 4608c  - 6912a c  + 10368a c  + 15552a c)x
+--R                     + 
+--R                               6         3 4         5 2         7  2
+--R                       (9216a c  + 13824a c  - 20736a c  - 31104a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                  6         3 4         5 2         7  6
+--R                       (- 13824a c  - 20736a c  + 31104a c  + 46656a )x
+--R                     + 
+--R                             7        2 5         4 3         6   4
+--R                       (4608c  + 6912a c  - 10368a c  - 15552a c)x
+--R                     + 
+--R                                 6         3 4         5 2         7  2
+--R                       (- 9216a c  - 13824a c  + 20736a c  + 31104a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                              6         3 4         5 2         7  8
+--R                   (- 20736a c  - 31104a c  + 46656a c  + 69984a )x
+--R                 + 
+--R                         7         2 5         4 3         6   6
+--R                   (6912c  + 10368a c  - 15552a c  - 23328a c)x
+--R                 + 
+--R                              6         3 4         5 2         7  4
+--R                   (- 27648a c  - 41472a c  + 62208a c  + 93312a )x
+--R                 + 
+--R                         7        2 5         4 3         6   2          6
+--R                   (4608c  + 6912a c  - 10368a c  - 15552a c)x  - 9216a c
+--R                 + 
+--R                           3 4         5 2         7
+--R                   - 13824a c  + 20736a c  + 31104a
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                             6        3 4         5 2         7  2 4+-+2 4+-+2
+--R                   (- 4608a c  - 6912a c  + 10368a c  + 15552a )x  \|2   \|3
+--R                 + 
+--R                           6        3 4         5 2         7  2 +-+ +-+
+--R                   (4608a c  + 6912a c  - 10368a c  - 15552a )x \|2 \|3
+--R                 + 
+--R                           6         3 4         5 2         7  4          6
+--R                   (6912a c  + 10368a c  - 15552a c  - 23328a )x  + 4608a c
+--R                 + 
+--R                        3 4         5 2         7
+--R                   6912a c  - 10368a c  - 15552a
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                       7         2 5         4 3         6   2 4+-+2 4+-+2
+--R               (- 9216c  - 13824a c  + 20736a c  + 31104a c)x  \|2   \|3
+--R             + 
+--R                     7         2 5         4 3         6   2 +-+ +-+
+--R               (9216c  + 13824a c  - 20736a c  - 31104a c)x \|2 \|3
+--R             + 
+--R                      7         2 5         4 3         6   4        7
+--R               (13824c  + 20736a c  - 31104a c  - 46656a c)x  + 9216c
+--R             + 
+--R                     2 5         4 3         6
+--R               13824a c  - 20736a c  - 31104a c
+--R          *
+--R                              +------------------+  4
+--R                              |  4      2 2     4
+--R                             \|4c  - 12a c  + 9a
+--R                        atan(---------------------)
+--R                                         +-+
+--R             4+---+2                2a c\|6
+--R             \|216  cos(---------------------------)
+--R                                     2
+--R         + 
+--R                                   4         3 2        5  8
+--R                           (3456a c  - 10368a c  + 7776a )x
+--R                         + 
+--R                                   4        3 2        5  4
+--R                           (2304a c  - 6912a c  + 5184a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                     4         3 2        5  6
+--R                           (- 3456a c  + 10368a c  - 7776a )x
+--R                         + 
+--R                                     4        3 2        5  2
+--R                           (- 2304a c  + 6912a c  - 5184a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                   5         2 3         4   8
+--R                           (- 6912c  + 20736a c  - 15552a c)x
+--R                         + 
+--R                                   5         2 3         4   4
+--R                           (- 4608c  + 13824a c  - 10368a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                 5         2 3         4   6
+--R                           (6912c  - 20736a c  + 15552a c)x
+--R                         + 
+--R                                 5         2 3         4   2
+--R                           (4608c  - 13824a c  + 10368a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                4         3 2         5  6 4+-+2 4+-+2
+--R                       (13824a c  - 41472a c  + 31104a )x  \|2   \|3
+--R                     + 
+--R                                  4         3 2         5  6 +-+ +-+
+--R                       (- 13824a c  + 41472a c  - 31104a )x \|2 \|3
+--R                     + 
+--R                                  4         3 2         5  8
+--R                       (- 20736a c  + 62208a c  - 46656a )x
+--R                     + 
+--R                                  4         3 2         5  4
+--R                       (- 13824a c  + 41472a c  - 31104a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                  4          3 2          5  8
+--R                       (- 20736a c  + 124416a c  - 139968a )x
+--R                     + 
+--R                              5         2 3         4   6
+--R                       (27648c  - 82944a c  + 62208a c)x
+--R                     + 
+--R                                  4         3 2         5  4
+--R                       (- 13824a c  + 82944a c  - 93312a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                4          3 2          5  8
+--R                       (20736a c  - 124416a c  + 139968a )x
+--R                     + 
+--R                                5         2 3         4   6
+--R                       (- 27648c  + 82944a c  - 62208a c)x
+--R                     + 
+--R                                4         3 2         5  4
+--R                       (13824a c  - 82944a c  + 93312a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                            4          3 2          5  10
+--R                   (31104a c  - 186624a c  + 209952a )x
+--R                 + 
+--R                            5          2 3         4   8
+--R                   (- 41472c  + 124416a c  - 93312a c)x
+--R                 + 
+--R                            4          3 2          5  6
+--R                   (41472a c  - 248832a c  + 279936a )x
+--R                 + 
+--R                            5         2 3         4   4
+--R                   (- 27648c  + 82944a c  - 62208a c)x
+--R                 + 
+--R                            4         3 2         5  2
+--R                   (13824a c  - 82944a c  + 93312a )x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                            4         3 2         5  4 4+-+2 4+-+2
+--R                   (27648a c  - 82944a c  + 62208a )x  \|2   \|3
+--R                 + 
+--R                              4         3 2         5  4 +-+ +-+
+--R                   (- 27648a c  + 82944a c  - 62208a )x \|2 \|3
+--R                 + 
+--R                              4          3 2         5  6
+--R                   (- 41472a c  + 124416a c  - 93312a )x
+--R                 + 
+--R                              4         3 2         5  2
+--R                   (- 27648a c  + 82944a c  - 62208a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      5          2 3          4   4 4+-+2 4+-+2
+--R               (55296c  - 165888a c  + 124416a c)x  \|2   \|3
+--R             + 
+--R                        5          2 3          4   4 +-+ +-+
+--R               (- 55296c  + 165888a c  - 124416a c)x \|2 \|3
+--R             + 
+--R                        5          2 3          4   6
+--R               (- 82944c  + 248832a c  - 186624a c)x
+--R             + 
+--R                        5          2 3          4   2
+--R               (- 55296c  + 165888a c  - 124416a c)x
+--R          *
+--R                                             +------------------+  2
+--R                                             |  4      2 2     4
+--R                                            \|4c  - 12a c  + 9a
+--R                                       atan(---------------------)
+--R              +------------------+2                     +-+
+--R             4|  4      2 2     4                  2a c\|6
+--R             \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                    2
+--R         + 
+--R                                    6        3 4        5 2        7  10
+--R                           (- 864a c  + 2160a c  - 3240a c  + 2916a )x
+--R                         + 
+--R                                    6        3 4        5 2        7  6
+--R                           (- 576a c  + 1440a c  - 2160a c  + 1944a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  6        3 4        5 2        7  8
+--R                           (864a c  - 2160a c  + 3240a c  - 2916a )x
+--R                         + 
+--R                                  6        3 4        5 2        7  4
+--R                           (576a c  - 1440a c  + 2160a c  - 1944a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                 7        2 5        4 3        6   10
+--R                           (1728c  - 4320a c  + 6480a c  - 5832a c)x
+--R                         + 
+--R                                 7        2 5        4 3        6   6
+--R                           (1152c  - 2880a c  + 4320a c  - 3888a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                   7        2 5        4 3        6   8
+--R                           (- 1728c  + 4320a c  - 6480a c  + 5832a c)x
+--R                         + 
+--R                                   7        2 5        4 3        6   4
+--R                           (- 1152c  + 2880a c  - 4320a c  + 3888a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                 6        3 4         5 2         7  8 4+-+2 4+-+2
+--R                       (- 3456a c  + 8640a c  - 12960a c  + 11664a )x  \|2   \|3
+--R                     + 
+--R                               6        3 4         5 2         7  8 +-+ +-+
+--R                       (3456a c  - 8640a c  + 12960a c  - 11664a )x \|2 \|3
+--R                     + 
+--R                               6         3 4         5 2         7  10
+--R                       (5184a c  - 12960a c  + 19440a c  - 17496a )x
+--R                     + 
+--R                               6        3 4         5 2         7  6
+--R                       (3456a c  - 8640a c  + 12960a c  - 11664a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                 6         3 4        5 2         7  10
+--R                       (- 3456a c  + 15552a c  + 7776a c  - 34992a )x
+--R                     + 
+--R                               7         2 5         4 3         6   8
+--R                       (- 6912c  + 17280a c  - 25920a c  + 23328a c)x
+--R                     + 
+--R                                 6         3 4        5 2         7  6
+--R                       (- 2304a c  + 10368a c  + 5184a c  - 23328a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                               6         3 4        5 2         7  10
+--R                       (3456a c  - 15552a c  - 7776a c  + 34992a )x
+--R                     + 
+--R                             7         2 5         4 3         6   8
+--R                       (6912c  - 17280a c  + 25920a c  - 23328a c)x
+--R                     + 
+--R                               6         3 4        5 2         7  6
+--R                       (2304a c  - 10368a c  - 5184a c  + 23328a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                           6         3 4         5 2         7  12
+--R                   (5184a c  - 23328a c  - 11664a c  + 52488a )x
+--R                 + 
+--R                          7         2 5         4 3         6   10
+--R                   (10368c  - 25920a c  + 38880a c  - 34992a c)x
+--R                 + 
+--R                           6         3 4         5 2         7  8
+--R                   (6912a c  - 31104a c  - 15552a c  + 69984a )x
+--R                 + 
+--R                         7         2 5         4 3         6   6
+--R                   (6912c  - 17280a c  + 25920a c  - 23328a c)x
+--R                 + 
+--R                           6         3 4        5 2         7  4
+--R                   (2304a c  - 10368a c  - 5184a c  + 23328a )x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                             6         3 4         5 2         7  6 4+-+2 4+-+2
+--R                   (- 6912a c  + 17280a c  - 25920a c  + 23328a )x  \|2   \|3
+--R                 + 
+--R                           6         3 4         5 2         7  6 +-+ +-+
+--R                   (6912a c  - 17280a c  + 25920a c  - 23328a )x \|2 \|3
+--R                 + 
+--R                            6         3 4         5 2         7  8
+--R                   (10368a c  - 25920a c  + 38880a c  - 34992a )x
+--R                 + 
+--R                           6         3 4         5 2         7  4
+--R                   (6912a c  - 17280a c  + 25920a c  - 23328a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                        7         2 5         4 3         6   6 4+-+2 4+-+2
+--R               (- 13824c  + 34560a c  - 51840a c  + 46656a c)x  \|2   \|3
+--R             + 
+--R                      7         2 5         4 3         6   6 +-+ +-+
+--R               (13824c  - 34560a c  + 51840a c  - 46656a c)x \|2 \|3
+--R             + 
+--R                      7         2 5         4 3         6   8
+--R               (20736c  - 51840a c  + 77760a c  - 69984a c)x
+--R             + 
+--R                      7         2 5         4 3         6   4
+--R               (13824c  - 34560a c  + 51840a c  - 46656a c)x
+--R          *
+--R             4+---+2
+--R             \|216
+--R      *
+--R                   +------------------+  4
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                  2 8          2 4 4+-+3 +-+
+--R                       (- 13824a c x  - 9216a c x )\|2  \|3
+--R                     + 
+--R                                2 6          2 2  +-+4+-+3
+--R                       (13824a c x  + 9216a c x )\|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                              2   8         2   4 4+-+3 +-+
+--R                       (41472a c x  + 27648a c x )\|2  \|3
+--R                     + 
+--R                                2   6         2   2  +-+4+-+3
+--R                       (- 41472a c x  - 27648a c x )\|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                    3          2   8           2 6
+--R                           (- 13824c  - 103680a c)x  + 55296a c x
+--R                         + 
+--R                                   3         2   4
+--R                           (- 9216c  - 69120a c)x
+--R                      *
+--R                         4+-+2 4+-+2
+--R                         \|2   \|3
+--R                     + 
+--R                                  3          2   8           2 6
+--R                           (13824c  + 103680a c)x  - 55296a c x
+--R                         + 
+--R                                 3         2   4
+--R                           (9216c  + 69120a c)x
+--R                      *
+--R                          +-+ +-+
+--R                         \|2 \|3
+--R                     + 
+--R                              3          2   10           2 8
+--R                       (20736c  + 155520a c)x   - 82944a c x
+--R                     + 
+--R                              3          2   6           2 4
+--R                       (27648c  + 207360a c)x  - 55296a c x
+--R                     + 
+--R                             3         2   2
+--R                       (9216c  + 69120a c)x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                          2   6 4+-+2 4+-+2        2   6 +-+ +-+          2   8
+--R                   165888a c x  \|2   \|3 - 165888a c x \|2 \|3  - 248832a c x
+--R                 + 
+--R                            2   4
+--R                   - 165888a c x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                            2 4 4+-+2 4+-+2          2 4 +-+ +-+            2 6
+--R                   110592a c x  \|2   \|3 - 110592a c x \|2 \|3  - 165888a c x
+--R                 + 
+--R                              2 2
+--R                   - 110592a c x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      2   4 4+-+2 4+-+2        2   4 +-+ +-+          2   6
+--R               331776a c x  \|2   \|3 - 331776a c x \|2 \|3  - 497664a c x
+--R             + 
+--R                        2   2
+--R               - 331776a c x
+--R          *
+--R              +------------------+ +------------------+2
+--R              |  4      2 2     4 4|  4      2 2     4
+--R             \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+  3
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                                  4        3 2  10           4        3 2  6
+--R                         ((2304a c  - 3456a c )x   + (1536a c  - 2304a c )x )
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                    4        3 2  8             4        3 2  4
+--R                         ((- 2304a c  + 3456a c )x  + (- 1536a c  + 2304a c )x )
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                  2 3         4   10           2 3        4   6
+--R                         ((- 6912a c  + 10368a c)x   + (- 4608a c  + 6912a c)x )
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                            2 3         4   8         2 3        4   4  +-+4+-+3
+--R                     ((6912a c  - 10368a c)x  + (4608a c  - 6912a c)x )\|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                 5        2 3         4   10
+--R                           (2304c  - 6912a c  - 15552a c)x
+--R                         + 
+--R                                     4         3 2  8
+--R                           (- 9216a c  + 13824a c )x
+--R                         + 
+--R                                 5        2 3         4   6
+--R                           (1536c  - 4608a c  - 10368a c)x
+--R                      *
+--R                         4+-+2 4+-+2
+--R                         \|2   \|3
+--R                     + 
+--R                                   5        2 3         4   10
+--R                           (- 2304c  + 6912a c  + 15552a c)x
+--R                         + 
+--R                                   4         3 2  8
+--R                           (9216a c  - 13824a c )x
+--R                         + 
+--R                                   5        2 3         4   6
+--R                           (- 1536c  + 4608a c  + 10368a c)x
+--R                      *
+--R                          +-+ +-+
+--R                         \|2 \|3
+--R                     + 
+--R                               5         2 3         4   12
+--R                       (- 3456c  + 10368a c  + 23328a c)x
+--R                     + 
+--R                                4         3 2  10
+--R                       (13824a c  - 20736a c )x
+--R                     + 
+--R                               5         2 3         4   8
+--R                       (- 4608c  + 13824a c  + 31104a c)x
+--R                     + 
+--R                               4         3 2  6
+--R                       (9216a c  - 13824a c )x
+--R                     + 
+--R                               5        2 3         4   4
+--R                       (- 1536c  + 4608a c  + 10368a c)x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                            2 3         4   8 4+-+2 4+-+2
+--R                   (- 27648a c  + 41472a c)x  \|2   \|3
+--R                 + 
+--R                          2 3         4   8 +-+ +-+          2 3         4   10
+--R                   (27648a c  - 41472a c)x \|2 \|3  + (41472a c  - 62208a c)x
+--R                 + 
+--R                          2 3         4   6
+--R                   (27648a c  - 41472a c)x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                              4         3 2  6 4+-+2 4+-+2
+--R                   (- 18432a c  + 27648a c )x  \|2   \|3
+--R                 + 
+--R                            4         3 2  6 +-+ +-+            4         3 2  8
+--R                   (18432a c  - 27648a c )x \|2 \|3  + (27648a c  - 41472a c )x
+--R                 + 
+--R                            4         3 2  4
+--R                   (18432a c  - 27648a c )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                        2 3         4   6 4+-+2 4+-+2
+--R               (- 55296a c  + 82944a c)x  \|2   \|3
+--R             + 
+--R                      2 3         4   6 +-+ +-+          2 3          4   8
+--R               (55296a c  - 82944a c)x \|2 \|3  + (82944a c  - 124416a c)x
+--R             + 
+--R                      2 3         4   4
+--R               (55296a c  - 82944a c)x
+--R          *
+--R                                                   +------------------+
+--R                                                   |  4      2 2     4
+--R                                                  \|4c  - 12a c  + 9a
+--R                                             atan(---------------------)
+--R                     +------------------+                     +-+
+--R             4+---+2 |  4      2 2     4                 2a c\|6
+--R             \|216  \|4c  - 12a c  + 9a  cos(---------------------------)
+--R                                                          2
+--R      *
+--R                   +------------------+  3
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                    6       3 4       5 2        7  6
+--R                           (- 384a c  - 576a c  + 864a c  + 1296a )x
+--R                         + 
+--R                                    6       3 4       5 2       7  2
+--R                           (- 256a c  - 384a c  + 576a c  + 864a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  6       3 4       5 2        7  4         6
+--R                           (384a c  + 576a c  - 864a c  - 1296a )x  + 256a c
+--R                         + 
+--R                               3 4       5 2       7
+--R                           384a c  - 576a c  - 864a
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                7        2 5        4 3        6   6
+--R                           (768c  + 1152a c  - 1728a c  - 2592a c)x
+--R                         + 
+--R                                7       2 5        4 3        6   2
+--R                           (512c  + 768a c  - 1152a c  - 1728a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  7        2 5        4 3        6   4       7
+--R                           (- 768c  - 1152a c  + 1728a c  + 2592a c)x  - 512c
+--R                         + 
+--R                                 2 5        4 3        6
+--R                           - 768a c  + 1152a c  + 1728a c
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                 6        3 4        5 2        7  4 4+-+2 4+-+2
+--R                       (- 1536a c  - 2304a c  + 3456a c  + 5184a )x  \|2   \|3
+--R                     + 
+--R                               6        3 4        5 2        7  4 +-+ +-+
+--R                       (1536a c  + 2304a c  - 3456a c  - 5184a )x \|2 \|3
+--R                     + 
+--R                               6        3 4        5 2        7  6
+--R                       (2304a c  + 3456a c  - 5184a c  - 7776a )x
+--R                     + 
+--R                               6        3 4        5 2        7  2
+--R                       (1536a c  + 2304a c  - 3456a c  - 5184a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                               6         3 4         5 2         7  6
+--R                       (9216a c  + 13824a c  - 20736a c  - 31104a )x
+--R                     + 
+--R                               7        2 5        4 3         6   4
+--R                       (- 3072c  - 4608a c  + 6912a c  + 10368a c)x
+--R                     + 
+--R                               6        3 4         5 2         7  2
+--R                       (6144a c  + 9216a c  - 13824a c  - 20736a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                 6         3 4         5 2         7  6
+--R                       (- 9216a c  - 13824a c  + 20736a c  + 31104a )x
+--R                     + 
+--R                             7        2 5        4 3         6   4
+--R                       (3072c  + 4608a c  - 6912a c  - 10368a c)x
+--R                     + 
+--R                                 6        3 4         5 2         7  2
+--R                       (- 6144a c  - 9216a c  + 13824a c  + 20736a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                              6         3 4         5 2         7  8
+--R                   (- 13824a c  - 20736a c  + 31104a c  + 46656a )x
+--R                 + 
+--R                         7        2 5         4 3         6   6
+--R                   (4608c  + 6912a c  - 10368a c  - 15552a c)x
+--R                 + 
+--R                              6         3 4         5 2         7  4
+--R                   (- 18432a c  - 27648a c  + 41472a c  + 62208a )x
+--R                 + 
+--R                         7        2 5        4 3         6   2          6
+--R                   (3072c  + 4608a c  - 6912a c  - 10368a c)x  - 6144a c
+--R                 + 
+--R                          3 4         5 2         7
+--R                   - 9216a c  + 13824a c  + 20736a
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                             6        3 4        5 2         7  2 4+-+2 4+-+2
+--R                   (- 3072a c  - 4608a c  + 6912a c  + 10368a )x  \|2   \|3
+--R                 + 
+--R                           6        3 4        5 2         7  2 +-+ +-+
+--R                   (3072a c  + 4608a c  - 6912a c  - 10368a )x \|2 \|3
+--R                 + 
+--R                           6        3 4         5 2         7  4          6
+--R                   (4608a c  + 6912a c  - 10368a c  - 15552a )x  + 3072a c
+--R                 + 
+--R                        3 4        5 2         7
+--R                   4608a c  - 6912a c  - 10368a
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                       7        2 5         4 3         6   2 4+-+2 4+-+2
+--R               (- 6144c  - 9216a c  + 13824a c  + 20736a c)x  \|2   \|3
+--R             + 
+--R                     7        2 5         4 3         6   2 +-+ +-+
+--R               (6144c  + 9216a c  - 13824a c  - 20736a c)x \|2 \|3
+--R             + 
+--R                     7         2 5         4 3         6   4        7        2 5
+--R               (9216c  + 13824a c  - 20736a c  - 31104a c)x  + 6144c  + 9216a c
+--R             + 
+--R                       4 3         6
+--R               - 13824a c  - 20736a c
+--R          *
+--R                              +------------------+  6
+--R                              |  4      2 2     4
+--R                             \|4c  - 12a c  + 9a
+--R                        atan(---------------------)
+--R                                         +-+
+--R             4+---+2                2a c\|6
+--R             \|216  cos(---------------------------)
+--R                                     2
+--R         + 
+--R                                     4         3 2        5  8
+--R                           (- 3456a c  + 10368a c  - 7776a )x
+--R                         + 
+--R                                     4        3 2        5  4
+--R                           (- 2304a c  + 6912a c  - 5184a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                   4         3 2        5  6
+--R                           (3456a c  - 10368a c  + 7776a )x
+--R                         + 
+--R                                   4        3 2        5  2
+--R                           (2304a c  - 6912a c  + 5184a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                 5         2 3         4   8
+--R                           (6912c  - 20736a c  + 15552a c)x
+--R                         + 
+--R                                 5         2 3         4   4
+--R                           (4608c  - 13824a c  + 10368a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                   5         2 3         4   6
+--R                           (- 6912c  + 20736a c  - 15552a c)x
+--R                         + 
+--R                                   5         2 3         4   2
+--R                           (- 4608c  + 13824a c  - 10368a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                  4         3 2         5  6 4+-+2 4+-+2
+--R                       (- 13824a c  + 41472a c  - 31104a )x  \|2   \|3
+--R                     + 
+--R                                4         3 2         5  6 +-+ +-+
+--R                       (13824a c  - 41472a c  + 31104a )x \|2 \|3
+--R                     + 
+--R                                4         3 2         5  8
+--R                       (20736a c  - 62208a c  + 46656a )x
+--R                     + 
+--R                                4         3 2         5  4
+--R                       (13824a c  - 41472a c  + 31104a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                4          3 2          5  8
+--R                       (20736a c  - 124416a c  + 139968a )x
+--R                     + 
+--R                                5         2 3         4   6
+--R                       (- 27648c  + 82944a c  - 62208a c)x
+--R                     + 
+--R                                4         3 2         5  4
+--R                       (13824a c  - 82944a c  + 93312a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                  4          3 2          5  8
+--R                       (- 20736a c  + 124416a c  - 139968a )x
+--R                     + 
+--R                              5         2 3         4   6
+--R                       (27648c  - 82944a c  + 62208a c)x
+--R                     + 
+--R                                  4         3 2         5  4
+--R                       (- 13824a c  + 82944a c  - 93312a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                              4          3 2          5  10
+--R                   (- 31104a c  + 186624a c  - 209952a )x
+--R                 + 
+--R                          5          2 3         4   8
+--R                   (41472c  - 124416a c  + 93312a c)x
+--R                 + 
+--R                              4          3 2          5  6
+--R                   (- 41472a c  + 248832a c  - 279936a )x
+--R                 + 
+--R                          5         2 3         4   4
+--R                   (27648c  - 82944a c  + 62208a c)x
+--R                 + 
+--R                              4         3 2         5  2
+--R                   (- 13824a c  + 82944a c  - 93312a )x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                              4         3 2         5  4 4+-+2 4+-+2
+--R                   (- 27648a c  + 82944a c  - 62208a )x  \|2   \|3
+--R                 + 
+--R                            4         3 2         5  4 +-+ +-+
+--R                   (27648a c  - 82944a c  + 62208a )x \|2 \|3
+--R                 + 
+--R                            4          3 2         5  6
+--R                   (41472a c  - 124416a c  + 93312a )x
+--R                 + 
+--R                            4         3 2         5  2
+--R                   (27648a c  - 82944a c  + 62208a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                        5          2 3          4   4 4+-+2 4+-+2
+--R               (- 55296c  + 165888a c  - 124416a c)x  \|2   \|3
+--R             + 
+--R                      5          2 3          4   4 +-+ +-+
+--R               (55296c  - 165888a c  + 124416a c)x \|2 \|3
+--R             + 
+--R                      5          2 3          4   6
+--R               (82944c  - 248832a c  + 186624a c)x
+--R             + 
+--R                      5          2 3          4   2
+--R               (55296c  - 165888a c  + 124416a c)x
+--R          *
+--R                                             +------------------+  4
+--R                                             |  4      2 2     4
+--R                                            \|4c  - 12a c  + 9a
+--R                                       atan(---------------------)
+--R              +------------------+2                     +-+
+--R             4|  4      2 2     4                  2a c\|6
+--R             \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                    2
+--R         + 
+--R                                  6         3 4         5 2        7  10
+--R                           (576a c  - 19872a c  + 29808a c  - 1944a )x
+--R                         + 
+--R                                  6         3 4         5 2        7  6
+--R                           (384a c  - 13248a c  + 19872a c  - 1296a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                    6         3 4         5 2        7  8
+--R                           (- 576a c  + 19872a c  - 29808a c  + 1944a )x
+--R                         + 
+--R                                    6         3 4         5 2        7  4
+--R                           (- 384a c  + 13248a c  - 19872a c  + 1296a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                   7         2 5         4 3        6   10
+--R                           (- 1152c  + 39744a c  - 59616a c  + 3888a c)x
+--R                         + 
+--R                                  7         2 5         4 3        6   6
+--R                           (- 768c  + 26496a c  - 39744a c  + 2592a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                 7         2 5         4 3        6   8
+--R                           (1152c  - 39744a c  + 59616a c  - 3888a c)x
+--R                         + 
+--R                                7         2 5         4 3        6   4
+--R                           (768c  - 26496a c  + 39744a c  - 2592a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                               6         3 4          5 2        7  8 4+-+2 4+-+2
+--R                       (2304a c  - 79488a c  + 119232a c  - 7776a )x  \|2   \|3
+--R                     + 
+--R                                 6         3 4          5 2        7  8 +-+ +-+
+--R                       (- 2304a c  + 79488a c  - 119232a c  + 7776a )x \|2 \|3
+--R                     + 
+--R                                 6          3 4          5 2         7  10
+--R                       (- 3456a c  + 119232a c  - 178848a c  + 11664a )x
+--R                     + 
+--R                                 6         3 4          5 2        7  6
+--R                       (- 2304a c  + 79488a c  - 119232a c  + 7776a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                6         3 4          5 2         7  10
+--R                       (76032a c  - 10368a c  - 171072a c  + 23328a )x
+--R                     + 
+--R                             7          2 5          4 3         6   8
+--R                       (4608c  - 158976a c  + 238464a c  - 15552a c)x
+--R                     + 
+--R                                6        3 4          5 2         7  6
+--R                       (50688a c  - 6912a c  - 114048a c  + 15552a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                  6         3 4          5 2         7  10
+--R                       (- 76032a c  + 10368a c  + 171072a c  - 23328a )x
+--R                     + 
+--R                               7          2 5          4 3         6   8
+--R                       (- 4608c  + 158976a c  - 238464a c  + 15552a c)x
+--R                     + 
+--R                                  6        3 4          5 2         7  6
+--R                       (- 50688a c  + 6912a c  + 114048a c  - 15552a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                               6         3 4          5 2         7  12
+--R                   (- 114048a c  + 15552a c  + 256608a c  - 34992a )x
+--R                 + 
+--R                           7          2 5          4 3         6   10
+--R                   (- 6912c  + 238464a c  - 357696a c  + 23328a c)x
+--R                 + 
+--R                               6         3 4          5 2         7  8
+--R                   (- 152064a c  + 20736a c  + 342144a c  - 46656a )x
+--R                 + 
+--R                           7          2 5          4 3         6   6
+--R                   (- 4608c  + 158976a c  - 238464a c  + 15552a c)x
+--R                 + 
+--R                              6        3 4          5 2         7  4
+--R                   (- 50688a c  + 6912a c  + 114048a c  - 15552a )x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                           6          3 4          5 2         7  6 4+-+2 4+-+2
+--R                   (4608a c  - 158976a c  + 238464a c  - 15552a )x  \|2   \|3
+--R                 + 
+--R                             6          3 4          5 2         7  6 +-+ +-+
+--R                   (- 4608a c  + 158976a c  - 238464a c  + 15552a )x \|2 \|3
+--R                 + 
+--R                             6          3 4          5 2         7  8
+--R                   (- 6912a c  + 238464a c  - 357696a c  + 23328a )x
+--R                 + 
+--R                             6          3 4          5 2         7  4
+--R                   (- 4608a c  + 158976a c  - 238464a c  + 15552a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                     7          2 5          4 3         6   6 4+-+2 4+-+2
+--R               (9216c  - 317952a c  + 476928a c  - 31104a c)x  \|2   \|3
+--R             + 
+--R                       7          2 5          4 3         6   6 +-+ +-+
+--R               (- 9216c  + 317952a c  - 476928a c  + 31104a c)x \|2 \|3
+--R             + 
+--R                        7          2 5          4 3         6   8
+--R               (- 13824c  + 476928a c  - 715392a c  + 46656a c)x
+--R             + 
+--R                       7          2 5          4 3         6   4
+--R               (- 9216c  + 317952a c  - 476928a c  + 31104a c)x
+--R          *
+--R                              +------------------+  2
+--R                              |  4      2 2     4
+--R                             \|4c  - 12a c  + 9a
+--R                        atan(---------------------)
+--R                                         +-+
+--R             4+---+2                2a c\|6
+--R             \|216  cos(---------------------------)
+--R                                     2
+--R         + 
+--R                                   4         3 2         5  12
+--R                           (5184a c  - 15552a c  + 11664a )x
+--R                         + 
+--R                                   4         3 2        5  8
+--R                           (3456a c  - 10368a c  + 7776a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                     4         3 2         5  10
+--R                           (- 5184a c  + 15552a c  - 11664a )x
+--R                         + 
+--R                                     4         3 2        5  6
+--R                           (- 3456a c  + 10368a c  - 7776a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                    5         2 3         4   12
+--R                           (- 10368c  + 31104a c  - 23328a c)x
+--R                         + 
+--R                                   5         2 3         4   8
+--R                           (- 6912c  + 20736a c  - 15552a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  5         2 3         4   10
+--R                           (10368c  - 31104a c  + 23328a c)x
+--R                         + 
+--R                                 5         2 3         4   6
+--R                           (6912c  - 20736a c  + 15552a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                4         3 2         5  10 4+-+2 4+-+2
+--R                       (20736a c  - 62208a c  + 46656a )x   \|2   \|3
+--R                     + 
+--R                                  4         3 2         5  10 +-+ +-+
+--R                       (- 20736a c  + 62208a c  - 46656a )x  \|2 \|3
+--R                     + 
+--R                                  4         3 2         5  12
+--R                       (- 31104a c  + 93312a c  - 69984a )x
+--R                     + 
+--R                                  4         3 2         5  8
+--R                       (- 20736a c  + 62208a c  - 46656a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                4         5  12
+--R                       (31104a c  - 69984a )x
+--R                     + 
+--R                              5          2 3         4   10
+--R                       (41472c  - 124416a c  + 93312a c)x
+--R                     + 
+--R                                4         5  8
+--R                       (20736a c  - 46656a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                  4         5  12
+--R                       (- 31104a c  + 69984a )x
+--R                     + 
+--R                                5          2 3         4   10
+--R                       (- 41472c  + 124416a c  - 93312a c)x
+--R                     + 
+--R                                  4         5  8
+--R                       (- 20736a c  + 46656a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                              4          5  14
+--R                   (- 46656a c  + 104976a )x
+--R                 + 
+--R                            5          2 3          4   12
+--R                   (- 62208c  + 186624a c  - 139968a c)x
+--R                 + 
+--R                              4          5  10
+--R                   (- 62208a c  + 139968a )x
+--R                 + 
+--R                            5          2 3         4   8
+--R                   (- 41472c  + 124416a c  - 93312a c)x
+--R                 + 
+--R                              4         5  6
+--R                   (- 20736a c  + 46656a )x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                            4          3 2         5  8 4+-+2 4+-+2
+--R                   (41472a c  - 124416a c  + 93312a )x  \|2   \|3
+--R                 + 
+--R                              4          3 2         5  8 +-+ +-+
+--R                   (- 41472a c  + 124416a c  - 93312a )x \|2 \|3
+--R                 + 
+--R                              4          3 2          5  10
+--R                   (- 62208a c  + 186624a c  - 139968a )x
+--R                 + 
+--R                              4          3 2         5  6
+--R                   (- 41472a c  + 124416a c  - 93312a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      5          2 3          4   8 4+-+2 4+-+2
+--R               (82944c  - 248832a c  + 186624a c)x  \|2   \|3
+--R             + 
+--R                        5          2 3          4   8 +-+ +-+
+--R               (- 82944c  + 248832a c  - 186624a c)x \|2 \|3
+--R             + 
+--R                         5          2 3          4   10
+--R               (- 124416c  + 373248a c  - 279936a c)x
+--R             + 
+--R                        5          2 3          4   6
+--R               (- 82944c  + 248832a c  - 186624a c)x
+--R          *
+--R              +------------------+2
+--R             4|  4      2 2     4
+--R             \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+  2
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                 2 8          2 4 4+-+3 +-+
+--R                       (- 6912a c x  - 4608a c x )\|2  \|3
+--R                     + 
+--R                               2 6          2 2  +-+4+-+3
+--R                       (6912a c x  + 4608a c x )\|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                              2   8         2   4 4+-+3 +-+
+--R                       (20736a c x  + 13824a c x )\|2  \|3
+--R                     + 
+--R                                2   6         2   2  +-+4+-+3
+--R                       (- 20736a c x  - 13824a c x )\|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                   3         2   8           2 6
+--R                           (- 6912c  - 51840a c)x  + 27648a c x
+--R                         + 
+--R                                   3         2   4
+--R                           (- 4608c  - 34560a c)x
+--R                      *
+--R                         4+-+2 4+-+2
+--R                         \|2   \|3
+--R                     + 
+--R                                 3         2   8           2 6
+--R                           (6912c  + 51840a c)x  - 27648a c x
+--R                         + 
+--R                                 3         2   4
+--R                           (4608c  + 34560a c)x
+--R                      *
+--R                          +-+ +-+
+--R                         \|2 \|3
+--R                     + 
+--R                              3         2   10           2 8
+--R                       (10368c  + 77760a c)x   - 41472a c x
+--R                     + 
+--R                              3          2   6           2 4
+--R                       (13824c  + 103680a c)x  - 27648a c x
+--R                     + 
+--R                             3         2   2
+--R                       (4608c  + 34560a c)x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                         2   6 4+-+2 4+-+2       2   6 +-+ +-+          2   8
+--R                   82944a c x  \|2   \|3 - 82944a c x \|2 \|3  - 124416a c x
+--R                 + 
+--R                           2   4
+--R                   - 82944a c x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                           2 4 4+-+2 4+-+2         2 4 +-+ +-+           2 6
+--R                   55296a c x  \|2   \|3 - 55296a c x \|2 \|3  - 82944a c x
+--R                 + 
+--R                             2 2
+--R                   - 55296a c x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      2   4 4+-+2 4+-+2        2   4 +-+ +-+          2   6
+--R               165888a c x  \|2   \|3 - 165888a c x \|2 \|3  - 248832a c x
+--R             + 
+--R                        2   2
+--R               - 165888a c x
+--R          *
+--R              +------------------+ +------------------+2
+--R              |  4      2 2     4 4|  4      2 2     4
+--R             \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+  5
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                                       4        3 2  10
+--R                             (- 2304a c  + 3456a c )x
+--R                           + 
+--R                                       4        3 2  6
+--R                             (- 1536a c  + 2304a c )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  4        3 2  8           4        3 2  4  +-+
+--R                         ((2304a c  - 3456a c )x  + (1536a c  - 2304a c )x )\|2
+--R                      *
+--R                         4+-+3
+--R                         \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                2 3         4   10         2 3        4   6
+--R                         ((6912a c  - 10368a c)x   + (4608a c  - 6912a c)x )
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  2 3         4   8           2 3        4   4
+--R                         ((- 6912a c  + 10368a c)x  + (- 4608a c  + 6912a c)x )
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                   5        2 3         4   10
+--R                           (- 2304c  + 6912a c  + 15552a c)x
+--R                         + 
+--R                                   4         3 2  8
+--R                           (9216a c  - 13824a c )x
+--R                         + 
+--R                                   5        2 3         4   6
+--R                           (- 1536c  + 4608a c  + 10368a c)x
+--R                      *
+--R                         4+-+2 4+-+2
+--R                         \|2   \|3
+--R                     + 
+--R                                 5        2 3         4   10
+--R                           (2304c  - 6912a c  - 15552a c)x
+--R                         + 
+--R                                     4         3 2  8
+--R                           (- 9216a c  + 13824a c )x
+--R                         + 
+--R                                 5        2 3         4   6
+--R                           (1536c  - 4608a c  - 10368a c)x
+--R                      *
+--R                          +-+ +-+
+--R                         \|2 \|3
+--R                     + 
+--R                             5         2 3         4   12
+--R                       (3456c  - 10368a c  - 23328a c)x
+--R                     + 
+--R                                  4         3 2  10
+--R                       (- 13824a c  + 20736a c )x
+--R                     + 
+--R                             5         2 3         4   8
+--R                       (4608c  - 13824a c  - 31104a c)x
+--R                     + 
+--R                                 4         3 2  6
+--R                       (- 9216a c  + 13824a c )x
+--R                     + 
+--R                             5        2 3         4   4
+--R                       (1536c  - 4608a c  - 10368a c)x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                          2 3         4   8 4+-+2 4+-+2
+--R                   (27648a c  - 41472a c)x  \|2   \|3
+--R                 + 
+--R                            2 3         4   8 +-+ +-+
+--R                   (- 27648a c  + 41472a c)x \|2 \|3
+--R                 + 
+--R                            2 3         4   10            2 3         4   6
+--R                   (- 41472a c  + 62208a c)x   + (- 27648a c  + 41472a c)x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                            4         3 2  6 4+-+2 4+-+2
+--R                   (18432a c  - 27648a c )x  \|2   \|3
+--R                 + 
+--R                              4         3 2  6 +-+ +-+
+--R                   (- 18432a c  + 27648a c )x \|2 \|3
+--R                 + 
+--R                              4         3 2  8              4         3 2  4
+--R                   (- 27648a c  + 41472a c )x  + (- 18432a c  + 27648a c )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      2 3         4   6 4+-+2 4+-+2
+--R               (55296a c  - 82944a c)x  \|2   \|3
+--R             + 
+--R                        2 3         4   6 +-+ +-+            2 3          4   8
+--R               (- 55296a c  + 82944a c)x \|2 \|3  + (- 82944a c  + 124416a c)x
+--R             + 
+--R                        2 3         4   4
+--R               (- 55296a c  + 82944a c)x
+--R          *
+--R                                                   +------------------+  3
+--R                                                   |  4      2 2     4
+--R                                                  \|4c  - 12a c  + 9a
+--R                                             atan(---------------------)
+--R                     +------------------+                     +-+
+--R             4+---+2 |  4      2 2     4                 2a c\|6
+--R             \|216  \|4c  - 12a c  + 9a  cos(---------------------------)
+--R                                                          2
+--R         + 
+--R                                  2 12          2 8 4+-+3 +-+
+--R                       (- 10368a c x   - 6912a c x )\|2  \|3
+--R                     + 
+--R                                2 10          2 6  +-+4+-+3
+--R                       (10368a c x   + 6912a c x )\|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                              2   12         2   8 4+-+3 +-+
+--R                       (31104a c x   + 20736a c x )\|2  \|3
+--R                     + 
+--R                                2   10         2   6  +-+4+-+3
+--R                       (- 31104a c x   - 20736a c x )\|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                    3         2   12           2 10
+--R                           (- 10368c  - 15552a c)x   + 41472a c x
+--R                         + 
+--R                                   3         2   8
+--R                           (- 6912c  - 10368a c)x
+--R                      *
+--R                         4+-+2 4+-+2
+--R                         \|2   \|3
+--R                     + 
+--R                                  3         2   12           2 10
+--R                           (10368c  + 15552a c)x   - 41472a c x
+--R                         + 
+--R                                 3         2   8
+--R                           (6912c  + 10368a c)x
+--R                      *
+--R                          +-+ +-+
+--R                         \|2 \|3
+--R                     + 
+--R                              3         2   14           2 12
+--R                       (15552c  + 23328a c)x   - 62208a c x
+--R                     + 
+--R                              3         2   10           2 8
+--R                       (20736c  + 31104a c)x   - 41472a c x
+--R                     + 
+--R                             3         2   6
+--R                       (6912c  + 10368a c)x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                          2   10 4+-+2 4+-+2        2   10 +-+ +-+
+--R                   124416a c x   \|2   \|3 - 124416a c x  \|2 \|3
+--R                 + 
+--R                            2   12          2   8
+--R                   - 186624a c x   - 124416a c x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                           2 8 4+-+2 4+-+2         2 8 +-+ +-+            2 10
+--R                   82944a c x  \|2   \|3 - 82944a c x \|2 \|3  - 124416a c x
+--R                 + 
+--R                             2 6
+--R                   - 82944a c x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      2   8 4+-+2 4+-+2        2   8 +-+ +-+          2   10
+--R               248832a c x  \|2   \|3 - 248832a c x \|2 \|3  - 373248a c x
+--R             + 
+--R                        2   6
+--R               - 248832a c x
+--R          *
+--R              +------------------+ +------------------+2
+--R              |  4      2 2     4 4|  4      2 2     4
+--R             \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R      *
+--R                   +------------------+
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                               6       3 4       5 2       7  6
+--R                       (- 96a c  - 144a c  + 216a c  + 324a )x
+--R                     + 
+--R                               6      3 4       5 2       7  2
+--R                       (- 64a c  - 96a c  + 144a c  + 216a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                             6       3 4       5 2       7  4        6      3 4
+--R                       (96a c  + 144a c  - 216a c  - 324a )x  + 64a c  + 96a c
+--R                     + 
+--R                             5 2       7
+--R                       - 144a c  - 216a
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                            7       2 5       4 3       6   6
+--R                       (192c  + 288a c  - 432a c  - 648a c)x
+--R                     + 
+--R                            7       2 5       4 3       6   2
+--R                       (128c  + 192a c  - 288a c  - 432a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                              7       2 5       4 3       6   4       7
+--R                       (- 192c  - 288a c  + 432a c  + 648a c)x  - 128c
+--R                     + 
+--R                             2 5       4 3       6
+--R                       - 192a c  + 288a c  + 432a c
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                            6       3 4       5 2        7  4 4+-+2 4+-+2
+--R                   (- 384a c  - 576a c  + 864a c  + 1296a )x  \|2   \|3
+--R                 + 
+--R                          6       3 4       5 2        7  4 +-+ +-+
+--R                   (384a c  + 576a c  - 864a c  - 1296a )x \|2 \|3
+--R                 + 
+--R                          6       3 4        5 2        7  6
+--R                   (576a c  + 864a c  - 1296a c  - 1944a )x
+--R                 + 
+--R                          6       3 4       5 2        7  2
+--R                   (384a c  + 576a c  - 864a c  - 1296a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                           6        3 4        5 2        7  6
+--R                   (2304a c  + 3456a c  - 5184a c  - 7776a )x
+--R                 + 
+--R                          7        2 5        4 3        6   4
+--R                   (- 768c  - 1152a c  + 1728a c  + 2592a c)x
+--R                 + 
+--R                           6        3 4        5 2        7  2
+--R                   (1536a c  + 2304a c  - 3456a c  - 5184a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                             6        3 4        5 2        7  6
+--R                   (- 2304a c  - 3456a c  + 5184a c  + 7776a )x
+--R                 + 
+--R                        7        2 5        4 3        6   4
+--R                   (768c  + 1152a c  - 1728a c  - 2592a c)x
+--R                 + 
+--R                             6        3 4        5 2        7  2
+--R                   (- 1536a c  - 2304a c  + 3456a c  + 5184a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                         6        3 4        5 2         7  8
+--R               (- 3456a c  - 5184a c  + 7776a c  + 11664a )x
+--R             + 
+--R                     7        2 5        4 3        6   6
+--R               (1152c  + 1728a c  - 2592a c  - 3888a c)x
+--R             + 
+--R                         6        3 4         5 2         7  4
+--R               (- 4608a c  - 6912a c  + 10368a c  + 15552a )x
+--R             + 
+--R                    7        2 5        4 3        6   2          6        3 4
+--R               (768c  + 1152a c  - 1728a c  - 2592a c)x  - 1536a c  - 2304a c
+--R             + 
+--R                    5 2        7
+--R               3456a c  + 5184a
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                        6        3 4        5 2        7  2 4+-+2 4+-+2
+--R               (- 768a c  - 1152a c  + 1728a c  + 2592a )x  \|2   \|3
+--R             + 
+--R                      6        3 4        5 2        7  2 +-+ +-+
+--R               (768a c  + 1152a c  - 1728a c  - 2592a )x \|2 \|3
+--R             + 
+--R                       6        3 4        5 2        7  4         6        3 4
+--R               (1152a c  + 1728a c  - 2592a c  - 3888a )x  + 768a c  + 1152a c
+--R             + 
+--R                      5 2        7
+--R               - 1728a c  - 2592a
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                   7        2 5        4 3        6   2 4+-+2 4+-+2
+--R           (- 1536c  - 2304a c  + 3456a c  + 5184a c)x  \|2   \|3
+--R         + 
+--R                 7        2 5        4 3        6   2 +-+ +-+
+--R           (1536c  + 2304a c  - 3456a c  - 5184a c)x \|2 \|3
+--R         + 
+--R                 7        2 5        4 3        6   4        7        2 5
+--R           (2304c  + 3456a c  - 5184a c  - 7776a c)x  + 1536c  + 2304a c
+--R         + 
+--R                  4 3        6
+--R           - 3456a c  - 5184a c
+--R      *
+--R                          +------------------+  8
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R         4+---+2                2a c\|6
+--R         \|216  cos(---------------------------)
+--R                                 2
+--R     + 
+--R                                 4         3 2        5  8
+--R                       (- 3456a c  + 10368a c  - 7776a )x
+--R                     + 
+--R                                 4        3 2        5  4
+--R                       (- 2304a c  + 6912a c  - 5184a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                               4         3 2        5  6
+--R                       (3456a c  - 10368a c  + 7776a )x
+--R                     + 
+--R                               4        3 2        5  2
+--R                       (2304a c  - 6912a c  + 5184a )x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                             5         2 3         4   8
+--R                       (6912c  - 20736a c  + 15552a c)x
+--R                     + 
+--R                             5         2 3         4   4
+--R                       (4608c  - 13824a c  + 10368a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                               5         2 3         4   6
+--R                       (- 6912c  + 20736a c  - 15552a c)x
+--R                     + 
+--R                               5         2 3         4   2
+--R                       (- 4608c  + 13824a c  - 10368a c)x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                              4         3 2         5  6 4+-+2 4+-+2
+--R                   (- 13824a c  + 41472a c  - 31104a )x  \|2   \|3
+--R                 + 
+--R                            4         3 2         5  6 +-+ +-+
+--R                   (13824a c  - 41472a c  + 31104a )x \|2 \|3
+--R                 + 
+--R                            4         3 2         5  8
+--R                   (20736a c  - 62208a c  + 46656a )x
+--R                 + 
+--R                            4         3 2         5  4
+--R                   (13824a c  - 41472a c  + 31104a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                            4          3 2          5  8
+--R                   (20736a c  - 124416a c  + 139968a )x
+--R                 + 
+--R                            5         2 3         4   6
+--R                   (- 27648c  + 82944a c  - 62208a c)x
+--R                 + 
+--R                            4         3 2         5  4
+--R                   (13824a c  - 82944a c  + 93312a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                              4          3 2          5  8
+--R                   (- 20736a c  + 124416a c  - 139968a )x
+--R                 + 
+--R                          5         2 3         4   6
+--R                   (27648c  - 82944a c  + 62208a c)x
+--R                 + 
+--R                              4         3 2         5  4
+--R                   (- 13824a c  + 82944a c  - 93312a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                          4          3 2          5  10
+--R               (- 31104a c  + 186624a c  - 209952a )x
+--R             + 
+--R                      5          2 3         4   8
+--R               (41472c  - 124416a c  + 93312a c)x
+--R             + 
+--R                          4          3 2          5  6
+--R               (- 41472a c  + 248832a c  - 279936a )x
+--R             + 
+--R                      5         2 3         4   4
+--R               (27648c  - 82944a c  + 62208a c)x
+--R             + 
+--R                          4         3 2         5  2
+--R               (- 13824a c  + 82944a c  - 93312a )x
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                          4         3 2         5  4 4+-+2 4+-+2
+--R               (- 27648a c  + 82944a c  - 62208a )x  \|2   \|3
+--R             + 
+--R                        4         3 2         5  4 +-+ +-+
+--R               (27648a c  - 82944a c  + 62208a )x \|2 \|3
+--R             + 
+--R                        4          3 2         5  6
+--R               (41472a c  - 124416a c  + 93312a )x
+--R             + 
+--R                        4         3 2         5  2
+--R               (27648a c  - 82944a c  + 62208a )x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                    5          2 3          4   4 4+-+2 4+-+2
+--R           (- 55296c  + 165888a c  - 124416a c)x  \|2   \|3
+--R         + 
+--R                  5          2 3          4   4 +-+ +-+
+--R           (55296c  - 165888a c  + 124416a c)x \|2 \|3
+--R         + 
+--R                  5          2 3          4   6
+--R           (82944c  - 248832a c  + 186624a c)x
+--R         + 
+--R                  5          2 3          4   2
+--R           (55296c  - 165888a c  + 124416a c)x
+--R      *
+--R                                         +------------------+  6
+--R                                         |  4      2 2     4
+--R                                        \|4c  - 12a c  + 9a
+--R                                   atan(---------------------)
+--R          +------------------+2                     +-+
+--R         4|  4      2 2     4                  2a c\|6
+--R         \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                2
+--R     + 
+--R                                6        3 4        5 2        7  10
+--R                       (- 864a c  + 2160a c  - 3240a c  + 2916a )x
+--R                     + 
+--R                                6        3 4        5 2        7  6
+--R                       (- 576a c  + 1440a c  - 2160a c  + 1944a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                              6        3 4        5 2        7  8
+--R                       (864a c  - 2160a c  + 3240a c  - 2916a )x
+--R                     + 
+--R                              6        3 4        5 2        7  4
+--R                       (576a c  - 1440a c  + 2160a c  - 1944a )x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                             7        2 5        4 3        6   10
+--R                       (1728c  - 4320a c  + 6480a c  - 5832a c)x
+--R                     + 
+--R                             7        2 5        4 3        6   6
+--R                       (1152c  - 2880a c  + 4320a c  - 3888a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                               7        2 5        4 3        6   8
+--R                       (- 1728c  + 4320a c  - 6480a c  + 5832a c)x
+--R                     + 
+--R                               7        2 5        4 3        6   4
+--R                       (- 1152c  + 2880a c  - 4320a c  + 3888a c)x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                             6        3 4         5 2         7  8 4+-+2 4+-+2
+--R                   (- 3456a c  + 8640a c  - 12960a c  + 11664a )x  \|2   \|3
+--R                 + 
+--R                           6        3 4         5 2         7  8 +-+ +-+
+--R                   (3456a c  - 8640a c  + 12960a c  - 11664a )x \|2 \|3
+--R                 + 
+--R                           6         3 4         5 2         7  10
+--R                   (5184a c  - 12960a c  + 19440a c  - 17496a )x
+--R                 + 
+--R                           6        3 4         5 2         7  6
+--R                   (3456a c  - 8640a c  + 12960a c  - 11664a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                             6         3 4        5 2         7  10
+--R                   (- 3456a c  + 15552a c  + 7776a c  - 34992a )x
+--R                 + 
+--R                           7         2 5         4 3         6   8
+--R                   (- 6912c  + 17280a c  - 25920a c  + 23328a c)x
+--R                 + 
+--R                             6         3 4        5 2         7  6
+--R                   (- 2304a c  + 10368a c  + 5184a c  - 23328a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                           6         3 4        5 2         7  10
+--R                   (3456a c  - 15552a c  - 7776a c  + 34992a )x
+--R                 + 
+--R                         7         2 5         4 3         6   8
+--R                   (6912c  - 17280a c  + 25920a c  - 23328a c)x
+--R                 + 
+--R                           6         3 4        5 2         7  6
+--R                   (2304a c  - 10368a c  - 5184a c  + 23328a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                       6         3 4         5 2         7  12
+--R               (5184a c  - 23328a c  - 11664a c  + 52488a )x
+--R             + 
+--R                      7         2 5         4 3         6   10
+--R               (10368c  - 25920a c  + 38880a c  - 34992a c)x
+--R             + 
+--R                       6         3 4         5 2         7  8
+--R               (6912a c  - 31104a c  - 15552a c  + 69984a )x
+--R             + 
+--R                     7         2 5         4 3         6   6
+--R               (6912c  - 17280a c  + 25920a c  - 23328a c)x
+--R             + 
+--R                       6         3 4        5 2         7  4
+--R               (2304a c  - 10368a c  - 5184a c  + 23328a )x
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                         6         3 4         5 2         7  6 4+-+2 4+-+2
+--R               (- 6912a c  + 17280a c  - 25920a c  + 23328a )x  \|2   \|3
+--R             + 
+--R                       6         3 4         5 2         7  6 +-+ +-+
+--R               (6912a c  - 17280a c  + 25920a c  - 23328a )x \|2 \|3
+--R             + 
+--R                        6         3 4         5 2         7  8
+--R               (10368a c  - 25920a c  + 38880a c  - 34992a )x
+--R             + 
+--R                       6         3 4         5 2         7  4
+--R               (6912a c  - 17280a c  + 25920a c  - 23328a )x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                    7         2 5         4 3         6   6 4+-+2 4+-+2
+--R           (- 13824c  + 34560a c  - 51840a c  + 46656a c)x  \|2   \|3
+--R         + 
+--R                  7         2 5         4 3         6   6 +-+ +-+
+--R           (13824c  - 34560a c  + 51840a c  - 46656a c)x \|2 \|3
+--R         + 
+--R                  7         2 5         4 3         6   8
+--R           (20736c  - 51840a c  + 77760a c  - 69984a c)x
+--R         + 
+--R                  7         2 5         4 3         6   4
+--R           (13824c  - 34560a c  + 51840a c  - 46656a c)x
+--R      *
+--R                          +------------------+  4
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R         4+---+2                2a c\|6
+--R         \|216  cos(---------------------------)
+--R                                 2
+--R     + 
+--R                                 4         3 2         5  12
+--R                       (- 5184a c  + 15552a c  - 11664a )x
+--R                     + 
+--R                                 4         3 2        5  8
+--R                       (- 3456a c  + 10368a c  - 7776a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                               4         3 2         5  10
+--R                       (5184a c  - 15552a c  + 11664a )x
+--R                     + 
+--R                               4         3 2        5  6
+--R                       (3456a c  - 10368a c  + 7776a )x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                              5         2 3         4   12
+--R                       (10368c  - 31104a c  + 23328a c)x
+--R                     + 
+--R                             5         2 3         4   8
+--R                       (6912c  - 20736a c  + 15552a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                                5         2 3         4   10
+--R                       (- 10368c  + 31104a c  - 23328a c)x
+--R                     + 
+--R                               5         2 3         4   6
+--R                       (- 6912c  + 20736a c  - 15552a c)x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                              4         3 2         5  10 4+-+2 4+-+2
+--R                   (- 20736a c  + 62208a c  - 46656a )x   \|2   \|3
+--R                 + 
+--R                            4         3 2         5  10 +-+ +-+
+--R                   (20736a c  - 62208a c  + 46656a )x  \|2 \|3
+--R                 + 
+--R                            4         3 2         5  12
+--R                   (31104a c  - 93312a c  + 69984a )x
+--R                 + 
+--R                            4         3 2         5  8
+--R                   (20736a c  - 62208a c  + 46656a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                              4         5  12
+--R                   (- 31104a c  + 69984a )x
+--R                 + 
+--R                            5          2 3         4   10
+--R                   (- 41472c  + 124416a c  - 93312a c)x
+--R                 + 
+--R                              4         5  8
+--R                   (- 20736a c  + 46656a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                            4         5  12
+--R                   (31104a c  - 69984a )x
+--R                 + 
+--R                        5          2 3         4   10            4         5  8
+--R                 (41472c  - 124416a c  + 93312a c)x   + (20736a c  - 46656a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                        4          5  14          5          2 3          4   12
+--R               (46656a c  - 104976a )x   + (62208c  - 186624a c  + 139968a c)x
+--R             + 
+--R                        4          5  10          5          2 3         4   8
+--R               (62208a c  - 139968a )x   + (41472c  - 124416a c  + 93312a c)x
+--R             + 
+--R                        4         5  6
+--R               (20736a c  - 46656a )x
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                          4          3 2         5  8 4+-+2 4+-+2
+--R               (- 41472a c  + 124416a c  - 93312a )x  \|2   \|3
+--R             + 
+--R                        4          3 2         5  8 +-+ +-+
+--R               (41472a c  - 124416a c  + 93312a )x \|2 \|3
+--R             + 
+--R                        4          3 2          5  10
+--R               (62208a c  - 186624a c  + 139968a )x
+--R             + 
+--R                        4          3 2         5  6
+--R               (41472a c  - 124416a c  + 93312a )x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                    5          2 3          4   8 4+-+2 4+-+2
+--R           (- 82944c  + 248832a c  - 186624a c)x  \|2   \|3
+--R         + 
+--R                  5          2 3          4   8 +-+ +-+
+--R           (82944c  - 248832a c  + 186624a c)x \|2 \|3
+--R         + 
+--R                   5          2 3          4   10
+--R           (124416c  - 373248a c  + 279936a c)x
+--R         + 
+--R                  5          2 3          4   6
+--R           (82944c  - 248832a c  + 186624a c)x
+--R      *
+--R                                         +------------------+  2
+--R                                         |  4      2 2     4
+--R                                        \|4c  - 12a c  + 9a
+--R                                   atan(---------------------)
+--R          +------------------+2                     +-+
+--R         4|  4      2 2     4                  2a c\|6
+--R         \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                2
+--R     + 
+--R                                6       3 4       5 2       7  14
+--R                       (- 216a c  - 324a c  + 486a c  + 729a )x
+--R                     + 
+--R                                6       3 4       5 2       7  10
+--R                       (- 144a c  - 216a c  + 324a c  + 486a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                              6       3 4       5 2       7  12
+--R                       (216a c  + 324a c  - 486a c  - 729a )x
+--R                     + 
+--R                              6       3 4       5 2       7  8
+--R                       (144a c  + 216a c  - 324a c  - 486a )x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                            7       2 5       4 3        6   14
+--R                       (432c  + 648a c  - 972a c  - 1458a c)x
+--R                     + 
+--R                            7       2 5       4 3       6   10
+--R                       (288c  + 432a c  - 648a c  - 972a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                              7       2 5       4 3        6   12
+--R                       (- 432c  - 648a c  + 972a c  + 1458a c)x
+--R                     + 
+--R                              7       2 5       4 3       6   8
+--R                       (- 288c  - 432a c  + 648a c  + 972a c)x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                            6        3 4        5 2        7  12 4+-+2 4+-+2
+--R                   (- 864a c  - 1296a c  + 1944a c  + 2916a )x   \|2   \|3
+--R                 + 
+--R                          6        3 4        5 2        7  12 +-+ +-+
+--R                   (864a c  + 1296a c  - 1944a c  - 2916a )x  \|2 \|3
+--R                 + 
+--R                           6        3 4        5 2        7  14
+--R                   (1296a c  + 1944a c  - 2916a c  - 4374a )x
+--R                 + 
+--R                          6        3 4        5 2        7  10
+--R                   (864a c  + 1296a c  - 1944a c  - 2916a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                       7        2 5        4 3        6   12 4+-+2 4+-+2
+--R               (- 1728c  - 2592a c  + 3888a c  + 5832a c)x   \|2   \|3
+--R             + 
+--R                     7        2 5        4 3        6   12 +-+ +-+
+--R               (1728c  + 2592a c  - 3888a c  - 5832a c)x  \|2 \|3
+--R             + 
+--R                     7        2 5        4 3        6   14
+--R               (2592c  + 3888a c  - 5832a c  - 8748a c)x
+--R             + 
+--R                     7        2 5        4 3        6   10
+--R               (1728c  + 2592a c  - 3888a c  - 5832a c)x
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                         6        3 4        5 2        7  10 4+-+2 4+-+2
+--R               (- 1728a c  - 2592a c  + 3888a c  + 5832a )x   \|2   \|3
+--R             + 
+--R                       6        3 4        5 2        7  10 +-+ +-+
+--R               (1728a c  + 2592a c  - 3888a c  - 5832a )x  \|2 \|3
+--R             + 
+--R                       6        3 4        5 2        7  12
+--R               (2592a c  + 3888a c  - 5832a c  - 8748a )x
+--R             + 
+--R                       6        3 4        5 2        7  8
+--R               (1728a c  + 2592a c  - 3888a c  - 5832a )x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                   7        2 5        4 3         6   10 4+-+2 4+-+2
+--R           (- 3456c  - 5184a c  + 7776a c  + 11664a c)x   \|2   \|3
+--R         + 
+--R                 7        2 5        4 3         6   10 +-+ +-+
+--R           (3456c  + 5184a c  - 7776a c  - 11664a c)x  \|2 \|3
+--R         + 
+--R                 7        2 5         4 3         6   12
+--R           (5184c  + 7776a c  - 11664a c  - 17496a c)x
+--R         + 
+--R                 7        2 5        4 3         6   8
+--R           (3456c  + 5184a c  - 7776a c  - 11664a c)x
+--R      *
+--R         4+---+2
+--R         \|216
+--R  /
+--R                     6        2 4         4 2         6  6
+--R               (4608c  + 6912a c  - 10368a c  - 15552a )x
+--R             + 
+--R                     6        2 4        4 2         6  2
+--R               (3072c  + 4608a c  - 6912a c  - 10368a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                       6        2 4         4 2         6  6
+--R               (- 4608c  - 6912a c  + 10368a c  + 15552a )x
+--R             + 
+--R                       6        2 4        4 2         6  2
+--R               (- 3072c  - 4608a c  + 6912a c  + 10368a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                   6         2 4         4 2         6  8
+--R           (- 6912c  - 10368a c  + 15552a c  + 23328a )x
+--R         + 
+--R                   6         2 4         4 2         6  4        6        2 4
+--R           (- 9216c  - 13824a c  + 20736a c  + 31104a )x  - 3072c  - 4608a c
+--R         + 
+--R                4 2         6
+--R           6912a c  + 10368a
+--R      *
+--R                                +------------------+  8
+--R                                |  4      2 2     4
+--R                               \|4c  - 12a c  + 9a
+--R                          atan(---------------------)
+--R                                           +-+
+--R         4+-+2 4+---+2                2a c\|6
+--R         \|6   \|216  sin(---------------------------)
+--R                                       2
+--R     + 
+--R                          6         2 4         4 2         6  6
+--R                   (18432c  + 27648a c  - 41472a c  - 62208a )x
+--R                 + 
+--R                          6         2 4         4 2         6  2
+--R                   (12288c  + 18432a c  - 27648a c  - 41472a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                            6         2 4         4 2         6  6
+--R                   (- 18432c  - 27648a c  + 41472a c  + 62208a )x
+--R                 + 
+--R                            6         2 4         4 2         6  2
+--R                   (- 12288c  - 18432a c  + 27648a c  + 41472a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                        6         2 4         4 2         6  8
+--R               (- 27648c  - 41472a c  + 62208a c  + 93312a )x
+--R             + 
+--R                        6         2 4         4 2          6  4         6
+--R               (- 36864c  - 55296a c  + 82944a c  + 124416a )x  - 12288c
+--R             + 
+--R                       2 4         4 2         6
+--R               - 18432a c  + 27648a c  + 41472a
+--R          *
+--R                                    +------------------+  2
+--R                                    |  4      2 2     4
+--R                                   \|4c  - 12a c  + 9a
+--R                              atan(---------------------)
+--R                                               +-+
+--R             4+-+2 4+---+2                2a c\|6
+--R             \|6   \|216  cos(---------------------------)
+--R                                           2
+--R         + 
+--R                             4          2 2          4  8
+--R                   (- 165888c  + 497664a c  - 373248a )x
+--R                 + 
+--R                             4          2 2          4  4
+--R                   (- 110592c  + 331776a c  - 248832a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                           4          2 2          4  8
+--R                   (165888c  - 497664a c  + 373248a )x
+--R                 + 
+--R                           4          2 2          4  4
+--R                   (110592c  - 331776a c  + 248832a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                       4          2 2          4  10
+--R               (248832c  - 746496a c  + 559872a )x
+--R             + 
+--R                       4          2 2          4  6
+--R               (331776c  - 995328a c  + 746496a )x
+--R             + 
+--R                       4          2 2          4  2
+--R               (110592c  - 331776a c  + 248832a )x
+--R          *
+--R                    +------------------+2
+--R             4+-+2 4|  4      2 2     4
+--R             \|6   \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+  6
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                         8              4 4+-+2 4+-+2
+--R           (- 165888a c x  - 110592a c x )\|2   \|3
+--R         + 
+--R                       8              4  +-+ +-+              10              6
+--R           (165888a c x  + 110592a c x )\|2 \|3  + 248832a c x   + 331776a c x
+--R         + 
+--R                      2
+--R           110592a c x
+--R      *
+--R                   +------------------+ +------------------+2
+--R          +-+4+-+2 |  4      2 2     4 4|  4      2 2     4
+--R         \|6 \|6  \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+            +------------------+  5
+--R                   |  4      2 2     4             |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a             \|4c  - 12a c  + 9a
+--R             atan(---------------------)     atan(---------------------)
+--R                              +-+                             +-+
+--R                         2a c\|6                         2a c\|6
+--R         cos(---------------------------)sin(---------------------------)
+--R                          2                               2
+--R     + 
+--R                          6         2 4         4 2         6  6
+--R                   (27648c  + 41472a c  - 62208a c  - 93312a )x
+--R                 + 
+--R                          6         2 4         4 2         6  2
+--R                   (18432c  + 27648a c  - 41472a c  - 62208a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                            6         2 4         4 2         6  6
+--R                   (- 27648c  - 41472a c  + 62208a c  + 93312a )x
+--R                 + 
+--R                            6         2 4         4 2         6  2
+--R                   (- 18432c  - 27648a c  + 41472a c  + 62208a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                        6         2 4         4 2          6  8
+--R               (- 41472c  - 62208a c  + 93312a c  + 139968a )x
+--R             + 
+--R                        6         2 4          4 2          6  4         6
+--R               (- 55296c  - 82944a c  + 124416a c  + 186624a )x  - 18432c
+--R             + 
+--R                       2 4         4 2         6
+--R               - 27648a c  + 41472a c  + 62208a
+--R          *
+--R                                    +------------------+  4
+--R                                    |  4      2 2     4
+--R                                   \|4c  - 12a c  + 9a
+--R                              atan(---------------------)
+--R                                               +-+
+--R             4+-+2 4+---+2                2a c\|6
+--R             \|6   \|216  cos(---------------------------)
+--R                                           2
+--R         + 
+--R                             4          2 2          4  8
+--R                   (- 165888c  + 497664a c  - 373248a )x
+--R                 + 
+--R                             4          2 2          4  4
+--R                   (- 110592c  + 331776a c  - 248832a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                           4          2 2          4  8
+--R                   (165888c  - 497664a c  + 373248a )x
+--R                 + 
+--R                           4          2 2          4  4
+--R                   (110592c  - 331776a c  + 248832a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                       4          2 2          4  10
+--R               (248832c  - 746496a c  + 559872a )x
+--R             + 
+--R                       4          2 2          4  6
+--R               (331776c  - 995328a c  + 746496a )x
+--R             + 
+--R                       4          2 2          4  2
+--R               (110592c  - 331776a c  + 248832a )x
+--R          *
+--R                                                   +------------------+  2
+--R                                                   |  4      2 2     4
+--R                                                  \|4c  - 12a c  + 9a
+--R                                             atan(---------------------)
+--R                    +------------------+2                     +-+
+--R             4+-+2 4|  4      2 2     4                  2a c\|6
+--R             \|6   \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                          2
+--R         + 
+--R                          6          2 4          4 2          6  10
+--R                   (41472c  - 103680a c  + 155520a c  - 139968a )x
+--R                 + 
+--R                          6         2 4          4 2         6  6
+--R                   (27648c  - 69120a c  + 103680a c  - 93312a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                            6          2 4          4 2          6  10
+--R                   (- 41472c  + 103680a c  - 155520a c  + 139968a )x
+--R                 + 
+--R                            6         2 4          4 2         6  6
+--R                   (- 27648c  + 69120a c  - 103680a c  + 93312a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                        6          2 4          4 2          6  12
+--R               (- 62208c  + 155520a c  - 233280a c  + 209952a )x
+--R             + 
+--R                        6          2 4          4 2          6  8
+--R               (- 82944c  + 207360a c  - 311040a c  + 279936a )x
+--R             + 
+--R                        6         2 4          4 2         6  4
+--R               (- 27648c  + 69120a c  - 103680a c  + 93312a )x
+--R          *
+--R             4+-+2 4+---+2
+--R             \|6   \|216
+--R      *
+--R                   +------------------+  4
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                             8              4 4+-+2 4+-+2
+--R               (- 331776a c x  - 221184a c x )\|2   \|3
+--R             + 
+--R                           8              4  +-+ +-+              10
+--R               (331776a c x  + 221184a c x )\|2 \|3  + 497664a c x
+--R             + 
+--R                          6              2
+--R               663552a c x  + 221184a c x
+--R          *
+--R                       +------------------+ +------------------+2
+--R              +-+4+-+2 |  4      2 2     4 4|  4      2 2     4
+--R             \|6 \|6  \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+  3
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                         3         3   10            3         3   6 4+-+2 4+-+2
+--R               ((55296a c  - 82944a c)x   + (36864a c  - 55296a c)x )\|2   \|3
+--R             + 
+--R                             3         3   10              3         3   6  +-+
+--R                 ((- 55296a c  + 82944a c)x   + (- 36864a c  + 55296a c)x )\|2
+--R              *
+--R                  +-+
+--R                 \|3
+--R             + 
+--R                          3          3   12               3          3   8
+--R               (- 82944a c  + 124416a c)x   + (- 110592a c  + 165888a c)x
+--R             + 
+--R                          3         3   4
+--R               (- 36864a c  + 55296a c)x
+--R          *
+--R                                                           +------------------+
+--R                                                           |  4      2 2     4
+--R                                                          \|4c  - 12a c  + 9a
+--R                                                     atan(---------------------)
+--R                             +------------------+                     +-+
+--R            +-+4+-+2 4+---+2 |  4      2 2     4                 2a c\|6
+--R           \|6 \|6   \|216  \|4c  - 12a c  + 9a  cos(---------------------------)
+--R                                                                  2
+--R      *
+--R                   +------------------+  3
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                          6         2 4         4 2         6  6
+--R                   (18432c  + 27648a c  - 41472a c  - 62208a )x
+--R                 + 
+--R                          6         2 4         4 2         6  2
+--R                   (12288c  + 18432a c  - 27648a c  - 41472a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                            6         2 4         4 2         6  6
+--R                   (- 18432c  - 27648a c  + 41472a c  + 62208a )x
+--R                 + 
+--R                            6         2 4         4 2         6  2
+--R                   (- 12288c  - 18432a c  + 27648a c  + 41472a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                        6         2 4         4 2         6  8
+--R               (- 27648c  - 41472a c  + 62208a c  + 93312a )x
+--R             + 
+--R                        6         2 4         4 2          6  4         6
+--R               (- 36864c  - 55296a c  + 82944a c  + 124416a )x  - 12288c
+--R             + 
+--R                       2 4         4 2         6
+--R               - 18432a c  + 27648a c  + 41472a
+--R          *
+--R                                    +------------------+  6
+--R                                    |  4      2 2     4
+--R                                   \|4c  - 12a c  + 9a
+--R                              atan(---------------------)
+--R                                               +-+
+--R             4+-+2 4+---+2                2a c\|6
+--R             \|6   \|216  cos(---------------------------)
+--R                                           2
+--R         + 
+--R                           4          2 2          4  8
+--R                   (165888c  - 497664a c  + 373248a )x
+--R                 + 
+--R                           4          2 2          4  4
+--R                   (110592c  - 331776a c  + 248832a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                             4          2 2          4  8
+--R                   (- 165888c  + 497664a c  - 373248a )x
+--R                 + 
+--R                             4          2 2          4  4
+--R                   (- 110592c  + 331776a c  - 248832a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                         4          2 2          4  10
+--R               (- 248832c  + 746496a c  - 559872a )x
+--R             + 
+--R                         4          2 2          4  6
+--R               (- 331776c  + 995328a c  - 746496a )x
+--R             + 
+--R                         4          2 2          4  2
+--R               (- 110592c  + 331776a c  - 248832a )x
+--R          *
+--R                                                   +------------------+  4
+--R                                                   |  4      2 2     4
+--R                                                  \|4c  - 12a c  + 9a
+--R                                             atan(---------------------)
+--R                    +------------------+2                     +-+
+--R             4+-+2 4|  4      2 2     4                  2a c\|6
+--R             \|6   \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                          2
+--R         + 
+--R                            6          2 4           4 2         6  10
+--R                   (- 27648c  + 953856a c  - 1430784a c  + 93312a )x
+--R                 + 
+--R                            6          2 4          4 2         6  6
+--R                   (- 18432c  + 635904a c  - 953856a c  + 62208a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                          6          2 4           4 2         6  10
+--R                   (27648c  - 953856a c  + 1430784a c  - 93312a )x
+--R                 + 
+--R                          6          2 4          4 2         6  6
+--R                   (18432c  - 635904a c  + 953856a c  - 62208a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                      6           2 4           4 2          6  12
+--R               (41472c  - 1430784a c  + 2146176a c  - 139968a )x
+--R             + 
+--R                      6           2 4           4 2          6  8
+--R               (55296c  - 1907712a c  + 2861568a c  - 186624a )x
+--R             + 
+--R                      6          2 4          4 2         6  4
+--R               (18432c  - 635904a c  + 953856a c  - 62208a )x
+--R          *
+--R                                    +------------------+  2
+--R                                    |  4      2 2     4
+--R                                   \|4c  - 12a c  + 9a
+--R                              atan(---------------------)
+--R                                               +-+
+--R             4+-+2 4+---+2                2a c\|6
+--R             \|6   \|216  cos(---------------------------)
+--R                                           2
+--R         + 
+--R                             4          2 2          4  12
+--R                   (- 248832c  + 746496a c  - 559872a )x
+--R                 + 
+--R                             4          2 2          4  8
+--R                   (- 165888c  + 497664a c  - 373248a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                           4          2 2          4  12
+--R                   (248832c  - 746496a c  + 559872a )x
+--R                 + 
+--R                           4          2 2          4  8
+--R                   (165888c  - 497664a c  + 373248a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                       4           2 2          4  14
+--R               (373248c  - 1119744a c  + 839808a )x
+--R             + 
+--R                       4           2 2           4  10
+--R               (497664c  - 1492992a c  + 1119744a )x
+--R             + 
+--R                       4          2 2          4  6
+--R               (165888c  - 497664a c  + 373248a )x
+--R          *
+--R                    +------------------+2
+--R             4+-+2 4|  4      2 2     4
+--R             \|6   \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+  2
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                             8              4 4+-+2 4+-+2
+--R               (- 165888a c x  - 110592a c x )\|2   \|3
+--R             + 
+--R                           8              4  +-+ +-+              10
+--R               (165888a c x  + 110592a c x )\|2 \|3  + 248832a c x
+--R             + 
+--R                          6              2
+--R               331776a c x  + 110592a c x
+--R          *
+--R                       +------------------+ +------------------+2
+--R              +-+4+-+2 |  4      2 2     4 4|  4      2 2     4
+--R             \|6 \|6  \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+  5
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                             3         3   10              3         3   6 4+-+2
+--R                 ((- 55296a c  + 82944a c)x   + (- 36864a c  + 55296a c)x )\|2
+--R              *
+--R                 4+-+2
+--R                 \|3
+--R             + 
+--R                         3         3   10            3         3   6  +-+ +-+
+--R               ((55296a c  - 82944a c)x   + (36864a c  - 55296a c)x )\|2 \|3
+--R             + 
+--R                        3          3   12             3          3   8
+--R               (82944a c  - 124416a c)x   + (110592a c  - 165888a c)x
+--R             + 
+--R                        3         3   4
+--R               (36864a c  - 55296a c)x
+--R          *
+--R                               +------------------+
+--R              +-+4+-+2 4+---+2 |  4      2 2     4
+--R             \|6 \|6   \|216  \|4c  - 12a c  + 9a
+--R          *
+--R                       +------------------+  3
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                             12              8 4+-+2 4+-+2
+--R               (- 248832a c x   - 165888a c x )\|2   \|3
+--R             + 
+--R                           12              8  +-+ +-+              14
+--R               (248832a c x   + 165888a c x )\|2 \|3  + 373248a c x
+--R             + 
+--R                          10              6
+--R               497664a c x   + 165888a c x
+--R          *
+--R                       +------------------+ +------------------+2
+--R              +-+4+-+2 |  4      2 2     4 4|  4      2 2     4
+--R             \|6 \|6  \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R      *
+--R                   +------------------+
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                     6        2 4         4 2         6  6
+--R               (4608c  + 6912a c  - 10368a c  - 15552a )x
+--R             + 
+--R                     6        2 4        4 2         6  2
+--R               (3072c  + 4608a c  - 6912a c  - 10368a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                       6        2 4         4 2         6  6
+--R               (- 4608c  - 6912a c  + 10368a c  + 15552a )x
+--R             + 
+--R                       6        2 4        4 2         6  2
+--R               (- 3072c  - 4608a c  + 6912a c  + 10368a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                   6         2 4         4 2         6  8
+--R           (- 6912c  - 10368a c  + 15552a c  + 23328a )x
+--R         + 
+--R                   6         2 4         4 2         6  4        6        2 4
+--R           (- 9216c  - 13824a c  + 20736a c  + 31104a )x  - 3072c  - 4608a c
+--R         + 
+--R                4 2         6
+--R           6912a c  + 10368a
+--R      *
+--R                                +------------------+  8
+--R                                |  4      2 2     4
+--R                               \|4c  - 12a c  + 9a
+--R                          atan(---------------------)
+--R                                           +-+
+--R         4+-+2 4+---+2                2a c\|6
+--R         \|6   \|216  cos(---------------------------)
+--R                                       2
+--R     + 
+--R                       4          2 2          4  8
+--R               (165888c  - 497664a c  + 373248a )x
+--R             + 
+--R                       4          2 2          4  4
+--R               (110592c  - 331776a c  + 248832a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                         4          2 2          4  8
+--R               (- 165888c  + 497664a c  - 373248a )x
+--R             + 
+--R                         4          2 2          4  4
+--R               (- 110592c  + 331776a c  - 248832a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                     4          2 2          4  10
+--R           (- 248832c  + 746496a c  - 559872a )x
+--R         + 
+--R                     4          2 2          4  6
+--R           (- 331776c  + 995328a c  - 746496a )x
+--R         + 
+--R                     4          2 2          4  2
+--R           (- 110592c  + 331776a c  - 248832a )x
+--R      *
+--R                                               +------------------+  6
+--R                                               |  4      2 2     4
+--R                                              \|4c  - 12a c  + 9a
+--R                                         atan(---------------------)
+--R                +------------------+2                     +-+
+--R         4+-+2 4|  4      2 2     4                  2a c\|6
+--R         \|6   \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                      2
+--R     + 
+--R                      6          2 4          4 2          6  10
+--R               (41472c  - 103680a c  + 155520a c  - 139968a )x
+--R             + 
+--R                      6         2 4          4 2         6  6
+--R               (27648c  - 69120a c  + 103680a c  - 93312a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                        6          2 4          4 2          6  10
+--R               (- 41472c  + 103680a c  - 155520a c  + 139968a )x
+--R             + 
+--R                        6         2 4          4 2         6  6
+--R               (- 27648c  + 69120a c  - 103680a c  + 93312a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                    6          2 4          4 2          6  12
+--R           (- 62208c  + 155520a c  - 233280a c  + 209952a )x
+--R         + 
+--R                    6          2 4          4 2          6  8
+--R           (- 82944c  + 207360a c  - 311040a c  + 279936a )x
+--R         + 
+--R                    6         2 4          4 2         6  4
+--R           (- 27648c  + 69120a c  - 103680a c  + 93312a )x
+--R      *
+--R                                +------------------+  4
+--R                                |  4      2 2     4
+--R                               \|4c  - 12a c  + 9a
+--R                          atan(---------------------)
+--R                                           +-+
+--R         4+-+2 4+---+2                2a c\|6
+--R         \|6   \|216  cos(---------------------------)
+--R                                       2
+--R     + 
+--R                       4          2 2          4  12
+--R               (248832c  - 746496a c  + 559872a )x
+--R             + 
+--R                       4          2 2          4  8
+--R               (165888c  - 497664a c  + 373248a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                         4          2 2          4  12
+--R               (- 248832c  + 746496a c  - 559872a )x
+--R             + 
+--R                         4          2 2          4  8
+--R               (- 165888c  + 497664a c  - 373248a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                     4           2 2          4  14
+--R           (- 373248c  + 1119744a c  - 839808a )x
+--R         + 
+--R                     4           2 2           4  10
+--R           (- 497664c  + 1492992a c  - 1119744a )x
+--R         + 
+--R                     4          2 2          4  6
+--R           (- 165888c  + 497664a c  - 373248a )x
+--R      *
+--R                                               +------------------+  2
+--R                                               |  4      2 2     4
+--R                                              \|4c  - 12a c  + 9a
+--R                                         atan(---------------------)
+--R                +------------------+2                     +-+
+--R         4+-+2 4|  4      2 2     4                  2a c\|6
+--R         \|6   \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                      2
+--R     + 
+--R                      6         2 4         4 2         6  14
+--R               (10368c  + 15552a c  - 23328a c  - 34992a )x
+--R             + 
+--R                     6         2 4         4 2         6  10
+--R               (6912c  + 10368a c  - 15552a c  - 23328a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                        6         2 4         4 2         6  14
+--R               (- 10368c  - 15552a c  + 23328a c  + 34992a )x
+--R             + 
+--R                       6         2 4         4 2         6  10
+--R               (- 6912c  - 10368a c  + 15552a c  + 23328a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                    6         2 4         4 2         6  16
+--R           (- 15552c  - 23328a c  + 34992a c  + 52488a )x
+--R         + 
+--R                    6         2 4         4 2         6  12
+--R           (- 20736c  - 31104a c  + 46656a c  + 69984a )x
+--R         + 
+--R                   6         2 4         4 2         6  8
+--R           (- 6912c  - 10368a c  + 15552a c  + 23328a )x
+--R      *
+--R         4+-+2 4+---+2
+--R         \|6   \|216
+--R                                                    Type: Expression(Integer)
+--E 618
+
+)clear all
+
+--S 619 of 953
+t0:=(b*x+c*x^2)/(2+3*x^4)
+--R 
+--R
+--R           2
+--R        c x  + b x
+--R   (1)  ----------
+--R            4
+--R          3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 619
+
+--S 620 of 953
+r0:=-1/2*c*atan(1-6^(1/4)*x)/6^(3/4)+1/2*c*atan(1+6^(1/4)*x)/6^(3/4)+_
+   1/4*c*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)-1/4*c*_
+   log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)+1/2*b*atan(x^2*_
+   sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R           +-+      4+-+3 4+-+   2 +-+    +-+
+--R       - c\|6 log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R         +-+        4+-+3 4+-+   2 +-+    +-+       +-+      4+-+
+--R       c\|6 log(- x \|2   \|3 + x \|3  + \|2 ) + 2c\|6 atan(x\|6  + 1)
+--R     + 
+--R                                             2 +-+
+--R          +-+      4+-+           4+-+3     x \|3
+--R       2c\|6 atan(x\|6  - 1) + 2b \|6  atan(------)
+--R                                              +-+
+--R                                             \|2
+--R  /
+--R       +-+4+-+3
+--R     4\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +------------------------------------------+
+--R              |         2                          2    2      +-+
+--R             \|- 36%%CV1  - 24%%CV0 %%CV1 - 36%%CV0  - b   - 2\|3 %%CV1
+--R           + 
+--R                 +-+
+--R             - 2\|3 %%CV0
+--R      *
+--R         log
+--R                      2           3            3          2 2
+--R                ((288c %%CV0 + 72b )%%CV1 + 72b %%CV0 + 3b c )
+--R             *
+--R                 +------------------------------------------+
+--R                 |         2                          2    2
+--R                \|- 36%%CV1  - 24%%CV0 %%CV1 - 36%%CV0  - b
+--R            + 
+--R                   2 +-+            3 +-+      2
+--R              (576c \|3 %%CV0 + 144b \|3 )%%CV1
+--R            + 
+--R                   2 +-+     2     2 2 +-+             3 +-+     2
+--R              (576c \|3 %%CV0  - 6b c \|3 )%%CV1 + 144b \|3 %%CV0
+--R            + 
+--R                  2 2 +-+           5     4         4     5  +-+
+--R              - 6b c \|3 %%CV0 + ((c  - 6b c)x - b c  + 3b )\|3
+--R     + 
+--R              +------------------------------------------+
+--R              |         2                          2    2      +-+
+--R           - \|- 36%%CV1  - 24%%CV0 %%CV1 - 36%%CV0  - b   - 2\|3 %%CV1
+--R         + 
+--R               +-+
+--R           - 2\|3 %%CV0
+--R      *
+--R         log
+--R                        2           3            3          2 2
+--R                ((- 288c %%CV0 - 72b )%%CV1 - 72b %%CV0 - 3b c )
+--R             *
+--R                 +------------------------------------------+
+--R                 |         2                          2    2
+--R                \|- 36%%CV1  - 24%%CV0 %%CV1 - 36%%CV0  - b
+--R            + 
+--R                   2 +-+            3 +-+      2
+--R              (576c \|3 %%CV0 + 144b \|3 )%%CV1
+--R            + 
+--R                   2 +-+     2     2 2 +-+             3 +-+     2
+--R              (576c \|3 %%CV0  - 6b c \|3 )%%CV1 + 144b \|3 %%CV0
+--R            + 
+--R                  2 2 +-+           5     4         4     5  +-+
+--R              - 6b c \|3 %%CV0 + ((c  - 6b c)x - b c  + 3b )\|3
+--R     + 
+--R           +-+
+--R         4\|3 %%CV1
+--R      *
+--R         log
+--R                      2            3      2           2     2      2 2
+--R              (- 1152c %%CV0 - 288b )%%CV1  + (- 1152c %%CV0  + 12b c )%%CV1
+--R            + 
+--R                     2     3      2 2          5     4         4     5
+--R              - 1152c %%CV0  - 24b c %%CV0 + (c  - 6b c)x - b c  - 3b
+--R     + 
+--R           +-+
+--R         4\|3 %%CV0
+--R      *
+--R         log
+--R                   2     3       3     2      2 2          5     4          4
+--R              1152c %%CV0  - 288b %%CV0  + 36b c %%CV0 + (c  - 6b c)x + 3b c
+--R            + 
+--R                  5
+--R              - 3b
+--R  /
+--R       +-+
+--R     4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 621
+
+--S 622 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +------------------------------------------+
+--R            +-+4+-+3 |         2                          2    2
+--R           \|6 \|6  \|- 36%%CV1  - 24%%CV0 %%CV1 - 36%%CV0  - b
+--R         + 
+--R               +-+ +-+4+-+3          +-+ +-+4+-+3
+--R           - 2\|3 \|6 \|6  %%CV1 - 2\|3 \|6 \|6  %%CV0
+--R      *
+--R         log
+--R                      2           3            3          2 2
+--R                ((288c %%CV0 + 72b )%%CV1 + 72b %%CV0 + 3b c )
+--R             *
+--R                 +------------------------------------------+
+--R                 |         2                          2    2
+--R                \|- 36%%CV1  - 24%%CV0 %%CV1 - 36%%CV0  - b
+--R            + 
+--R                   2 +-+            3 +-+      2
+--R              (576c \|3 %%CV0 + 144b \|3 )%%CV1
+--R            + 
+--R                   2 +-+     2     2 2 +-+             3 +-+     2
+--R              (576c \|3 %%CV0  - 6b c \|3 )%%CV1 + 144b \|3 %%CV0
+--R            + 
+--R                  2 2 +-+           5     4         4     5  +-+
+--R              - 6b c \|3 %%CV0 + ((c  - 6b c)x - b c  + 3b )\|3
+--R     + 
+--R                       +------------------------------------------+
+--R              +-+4+-+3 |         2                          2    2
+--R           - \|6 \|6  \|- 36%%CV1  - 24%%CV0 %%CV1 - 36%%CV0  - b
+--R         + 
+--R               +-+ +-+4+-+3          +-+ +-+4+-+3
+--R           - 2\|3 \|6 \|6  %%CV1 - 2\|3 \|6 \|6  %%CV0
+--R      *
+--R         log
+--R                        2           3            3          2 2
+--R                ((- 288c %%CV0 - 72b )%%CV1 - 72b %%CV0 - 3b c )
+--R             *
+--R                 +------------------------------------------+
+--R                 |         2                          2    2
+--R                \|- 36%%CV1  - 24%%CV0 %%CV1 - 36%%CV0  - b
+--R            + 
+--R                   2 +-+            3 +-+      2
+--R              (576c \|3 %%CV0 + 144b \|3 )%%CV1
+--R            + 
+--R                   2 +-+     2     2 2 +-+             3 +-+     2
+--R              (576c \|3 %%CV0  - 6b c \|3 )%%CV1 + 144b \|3 %%CV0
+--R            + 
+--R                  2 2 +-+           5     4         4     5  +-+
+--R              - 6b c \|3 %%CV0 + ((c  - 6b c)x - b c  + 3b )\|3
+--R     + 
+--R           +-+ +-+4+-+3
+--R         4\|3 \|6 \|6  %%CV1
+--R      *
+--R         log
+--R                      2            3      2           2     2      2 2
+--R              (- 1152c %%CV0 - 288b )%%CV1  + (- 1152c %%CV0  + 12b c )%%CV1
+--R            + 
+--R                     2     3      2 2          5     4         4     5
+--R              - 1152c %%CV0  - 24b c %%CV0 + (c  - 6b c)x - b c  - 3b
+--R     + 
+--R           +-+ +-+4+-+3
+--R         4\|3 \|6 \|6  %%CV0
+--R      *
+--R         log
+--R                   2     3       3     2      2 2          5     4          4
+--R              1152c %%CV0  - 288b %%CV0  + 36b c %%CV0 + (c  - 6b c)x + 3b c
+--R            + 
+--R                  5
+--R              - 3b
+--R     + 
+--R         +-+ +-+      4+-+3 4+-+   2 +-+    +-+
+--R       c\|3 \|6 log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+ +-+        4+-+3 4+-+   2 +-+    +-+       +-+ +-+      4+-+
+--R       - c\|3 \|6 log(- x \|2   \|3 + x \|3  + \|2 ) - 2c\|3 \|6 atan(x\|6  + 1)
+--R     + 
+--R                                                      2 +-+
+--R            +-+ +-+      4+-+           +-+4+-+3     x \|3
+--R       - 2c\|3 \|6 atan(x\|6  - 1) - 2b\|3 \|6  atan(------)
+--R                                                       +-+
+--R                                                      \|2
+--R  /
+--R       +-+ +-+4+-+3
+--R     4\|3 \|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R             6       2 4+-+3 +-+          4       +-+4+-+3 4+-+4+-+3
+--R       ((3c x  + 2c x )\|2  \|3  + (- 3c x  - 2c)\|2 \|2  )\|3 \|6
+--R     + 
+--R                  3 +-+4+-+2 +-+4+-+2        5         +-+ +-+        3  +-+
+--R           (- 4b x \|2 \|2  \|3 \|3   + (6b x  + 4b x)\|2 \|3  + 24b x )\|6
+--R         + 
+--R                 4        3 4+-+2 4+-+2          4        3  +-+ +-+        6
+--R           (12c x  + 24b x )\|2   \|3  + (- 12c x  - 24b x )\|2 \|3  - 18c x
+--R         + 
+--R                  5        2
+--R           - 36b x  - 12c x  - 24b x
+--R      *
+--R         4+-+2
+--R         \|6
+--R     + 
+--R              2 4+-+2 4+-+2      2 +-+ +-+        4
+--R       - 24c x  \|2   \|3 + 24c x \|2 \|3  + 36c x  + 24c
+--R  /
+--R            6      2 4+-+2 4+-+2        6      2  +-+ +-+       8       4
+--R       ((72x  + 48x )\|2   \|3  + (- 72x  - 48x )\|2 \|3  - 108x  - 144x  - 48)
+--R    *
+--R       4+-+2
+--R       \|6
+--R                                                    Type: Expression(Integer)
+--E 623
+
+)clear all
+
+--S 624 of 953
+t0:=(a+b*x+c*x^2)/(2+3*x^4)
+--R 
+--R
+--R           2
+--R        c x  + b x + a
+--R   (1)  --------------
+--R              4
+--R            3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 624
+
+--S 625 of 953
+r0:=1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)-1/8*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+_
+   x^2*sqrt(3))*(-2*c+a*sqrt(6))/6^(3/4)+1/8*log(2^(3/4)*3^(1/4)*x+_
+   sqrt(2)+x^2*sqrt(3))*(-2*c+a*sqrt(6))/6^(3/4)-1/4*atan(1-6^(1/4)*x)*_
+   (2*c+a*sqrt(6))/6^(3/4)+1/4*atan(1+6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R            +-+            4+-+3 4+-+   2 +-+    +-+
+--R       (- c\|6  + 3a)log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R          +-+              4+-+3 4+-+   2 +-+    +-+
+--R       (c\|6  - 3a)log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+            4+-+            +-+            4+-+
+--R       (2c\|6  + 6a)atan(x\|6  + 1) + (2c\|6  + 6a)atan(x\|6  - 1)
+--R     + 
+--R                     2 +-+
+--R          4+-+3     x \|3
+--R       2b \|6  atan(------)
+--R                      +-+
+--R                     \|2
+--R  /
+--R       +-+4+-+3
+--R     4\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +-------------------------------------------------+
+--R            |         2                          2           2      +-+
+--R           \|- 36%%CW1  - 24%%CW0 %%CW1 - 36%%CW0  - 2a c - b   - 2\|3 %%CW1
+--R         + 
+--R               +-+
+--R           - 2\|3 %%CW0
+--R      *
+--R         log
+--R                            3        2           2                 2       3
+--R                      (2304c  - 3456a c + 6912a b )%%CW0 - 864a b c  + 576b c
+--R                    + 
+--R                            3
+--R                      - 432a b
+--R                 *
+--R                    %%CW1
+--R                + 
+--R                             2       3        3               4      2 3
+--R                  (- 864a b c  + 576b c - 432a b)%%CW0 - 24a c  + 24b c
+--R                + 
+--R                      2 2         4      5
+--R                  108a b c - 72a b  + 54a
+--R             *
+--R                 +-------------------------------------------------+
+--R                 |         2                          2           2
+--R                \|- 36%%CW1  - 24%%CW0 %%CW1 - 36%%CW0  - 2a c - b
+--R            + 
+--R                        3        2            2  +-+
+--R                  (4608c  - 6912a c + 13824a b )\|3 %%CW0
+--R                + 
+--R                              2        3        3   +-+
+--R                  (- 1728a b c  + 1152b c - 864a b)\|3
+--R             *
+--R                     2
+--R                %%CW1
+--R            + 
+--R                        3        2            2  +-+     2
+--R                  (4608c  - 6912a c + 13824a b )\|3 %%CW0
+--R                + 
+--R                        4      2 3       2 2          4       5  +-+
+--R                  (48a c  - 48b c  - 216a b c + 144a b  - 108a )\|3
+--R             *
+--R                %%CW1
+--R            + 
+--R                          2        3        3   +-+     2
+--R              (- 1728a b c  + 1152b c - 864a b)\|3 %%CW0
+--R            + 
+--R                    4      2 3       2 2          4       5  +-+
+--R              (48a c  - 48b c  - 216a b c + 144a b  - 108a )\|3 %%CW0
+--R            + 
+--R                        6      2 4        2 3         4      4  2       3 2
+--R                      8c  - 12a c  + 96a b c  + (- 48b  - 18a )c  + 144a b c
+--R                    + 
+--R                           2 4      6
+--R                      - 72a b  + 27a
+--R                 *
+--R                    x
+--R                + 
+--R                        5      2   3        3 2       5      4         3 3
+--R                  - 8b c  - 48a b c  - 12a b c  + (24b  - 54a b)c + 18a b
+--R             *
+--R                 +-+
+--R                \|3
+--R     + 
+--R              +-------------------------------------------------+
+--R              |         2                          2           2      +-+
+--R           - \|- 36%%CW1  - 24%%CW0 %%CW1 - 36%%CW0  - 2a c - b   - 2\|3 %%CW1
+--R         + 
+--R               +-+
+--R           - 2\|3 %%CW0
+--R      *
+--R         log
+--R                              3        2           2                 2       3
+--R                      (- 2304c  + 3456a c - 6912a b )%%CW0 + 864a b c  - 576b c
+--R                    + 
+--R                          3
+--R                      432a b
+--R                 *
+--R                    %%CW1
+--R                + 
+--R                           2       3        3               4      2 3
+--R                  (864a b c  - 576b c + 432a b)%%CW0 + 24a c  - 24b c
+--R                + 
+--R                        2 2         4      5
+--R                  - 108a b c + 72a b  - 54a
+--R             *
+--R                 +-------------------------------------------------+
+--R                 |         2                          2           2
+--R                \|- 36%%CW1  - 24%%CW0 %%CW1 - 36%%CW0  - 2a c - b
+--R            + 
+--R                        3        2            2  +-+
+--R                  (4608c  - 6912a c + 13824a b )\|3 %%CW0
+--R                + 
+--R                              2        3        3   +-+
+--R                  (- 1728a b c  + 1152b c - 864a b)\|3
+--R             *
+--R                     2
+--R                %%CW1
+--R            + 
+--R                        3        2            2  +-+     2
+--R                  (4608c  - 6912a c + 13824a b )\|3 %%CW0
+--R                + 
+--R                        4      2 3       2 2          4       5  +-+
+--R                  (48a c  - 48b c  - 216a b c + 144a b  - 108a )\|3
+--R             *
+--R                %%CW1
+--R            + 
+--R                          2        3        3   +-+     2
+--R              (- 1728a b c  + 1152b c - 864a b)\|3 %%CW0
+--R            + 
+--R                    4      2 3       2 2          4       5  +-+
+--R              (48a c  - 48b c  - 216a b c + 144a b  - 108a )\|3 %%CW0
+--R            + 
+--R                        6      2 4        2 3         4      4  2       3 2
+--R                      8c  - 12a c  + 96a b c  + (- 48b  - 18a )c  + 144a b c
+--R                    + 
+--R                           2 4      6
+--R                      - 72a b  + 27a
+--R                 *
+--R                    x
+--R                + 
+--R                        5      2   3        3 2       5      4         3 3
+--R                  - 8b c  - 48a b c  - 12a b c  + (24b  - 54a b)c + 18a b
+--R             *
+--R                 +-+
+--R                \|3
+--R     + 
+--R           +-+
+--R         4\|3 %%CW1
+--R      *
+--R         log
+--R                          3         2            2                  2        3
+--R                  (- 9216c  + 13824a c - 27648a b )%%CW0 + 3456a b c  - 2304b c
+--R                + 
+--R                       3
+--R                  1728a b
+--R             *
+--R                     2
+--R                %%CW1
+--R            + 
+--R                          3         2            2      2        4      2 3
+--R                  (- 9216c  + 13824a c - 27648a b )%%CW0  - 96a c  + 96b c
+--R                + 
+--R                      2 2          4       5
+--R                  432a b c - 288a b  + 216a
+--R             *
+--R                %%CW1
+--R            + 
+--R                      3         2            2      3
+--R              (- 9216c  + 13824a c - 27648a b )%%CW0
+--R            + 
+--R                       4       2 3       3 2       2 2          4
+--R              (- 384a c  - 192b c  + 576a c  - 864a b c - 576a b )%%CW0
+--R            + 
+--R                    6      2 4        2 3         4      4  2       3 2
+--R                  8c  - 12a c  + 96a b c  + (- 48b  - 18a )c  + 144a b c
+--R                + 
+--R                       2 4      6
+--R                  - 72a b  + 27a
+--R             *
+--R                x
+--R            + 
+--R                    5      2   3        3 2         5      4         3 3
+--R              - 8b c  + 96a b c  - 36a b c  + (- 24b  + 18a b)c + 54a b
+--R     + 
+--R           +-+
+--R         4\|3 %%CW0
+--R      *
+--R         log
+--R                    3         2            2      3
+--R              (9216c  - 13824a c + 27648a b )%%CW0
+--R            + 
+--R                        2        3         3       2
+--R              (3456a b c  - 2304b c + 1728a b)%%CW0
+--R            + 
+--R                     4       2 3       3 2        2 2          4       5
+--R              (288a c  + 288b c  - 576a c  + 1296a b c + 288a b  + 216a )%%CW0
+--R            + 
+--R                    6      2 4        2 3         4      4  2       3 2
+--R                  8c  - 12a c  + 96a b c  + (- 48b  - 18a )c  + 144a b c
+--R                + 
+--R                       2 4      6
+--R                  - 72a b  + 27a
+--R             *
+--R                x
+--R            + 
+--R                   5        3 2         5      4         3 3
+--R              24b c  + 60a b c  + (- 24b  + 90a b)c - 90a b
+--R  /
+--R       +-+
+--R     4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 626
+
+--S 627 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +-------------------------------------------------+
+--R            +-+4+-+3 |         2                          2           2
+--R           \|6 \|6  \|- 36%%CW1  - 24%%CW0 %%CW1 - 36%%CW0  - 2a c - b
+--R         + 
+--R               +-+ +-+4+-+3          +-+ +-+4+-+3
+--R           - 2\|3 \|6 \|6  %%CW1 - 2\|3 \|6 \|6  %%CW0
+--R      *
+--R         log
+--R                            3        2           2                 2       3
+--R                      (2304c  - 3456a c + 6912a b )%%CW0 - 864a b c  + 576b c
+--R                    + 
+--R                            3
+--R                      - 432a b
+--R                 *
+--R                    %%CW1
+--R                + 
+--R                             2       3        3               4      2 3
+--R                  (- 864a b c  + 576b c - 432a b)%%CW0 - 24a c  + 24b c
+--R                + 
+--R                      2 2         4      5
+--R                  108a b c - 72a b  + 54a
+--R             *
+--R                 +-------------------------------------------------+
+--R                 |         2                          2           2
+--R                \|- 36%%CW1  - 24%%CW0 %%CW1 - 36%%CW0  - 2a c - b
+--R            + 
+--R                        3        2            2  +-+
+--R                  (4608c  - 6912a c + 13824a b )\|3 %%CW0
+--R                + 
+--R                              2        3        3   +-+
+--R                  (- 1728a b c  + 1152b c - 864a b)\|3
+--R             *
+--R                     2
+--R                %%CW1
+--R            + 
+--R                        3        2            2  +-+     2
+--R                  (4608c  - 6912a c + 13824a b )\|3 %%CW0
+--R                + 
+--R                        4      2 3       2 2          4       5  +-+
+--R                  (48a c  - 48b c  - 216a b c + 144a b  - 108a )\|3
+--R             *
+--R                %%CW1
+--R            + 
+--R                          2        3        3   +-+     2
+--R              (- 1728a b c  + 1152b c - 864a b)\|3 %%CW0
+--R            + 
+--R                    4      2 3       2 2          4       5  +-+
+--R              (48a c  - 48b c  - 216a b c + 144a b  - 108a )\|3 %%CW0
+--R            + 
+--R                        6      2 4        2 3         4      4  2       3 2
+--R                      8c  - 12a c  + 96a b c  + (- 48b  - 18a )c  + 144a b c
+--R                    + 
+--R                           2 4      6
+--R                      - 72a b  + 27a
+--R                 *
+--R                    x
+--R                + 
+--R                        5      2   3        3 2       5      4         3 3
+--R                  - 8b c  - 48a b c  - 12a b c  + (24b  - 54a b)c + 18a b
+--R             *
+--R                 +-+
+--R                \|3
+--R     + 
+--R                       +-------------------------------------------------+
+--R              +-+4+-+3 |         2                          2           2
+--R           - \|6 \|6  \|- 36%%CW1  - 24%%CW0 %%CW1 - 36%%CW0  - 2a c - b
+--R         + 
+--R               +-+ +-+4+-+3          +-+ +-+4+-+3
+--R           - 2\|3 \|6 \|6  %%CW1 - 2\|3 \|6 \|6  %%CW0
+--R      *
+--R         log
+--R                              3        2           2                 2       3
+--R                      (- 2304c  + 3456a c - 6912a b )%%CW0 + 864a b c  - 576b c
+--R                    + 
+--R                          3
+--R                      432a b
+--R                 *
+--R                    %%CW1
+--R                + 
+--R                           2       3        3               4      2 3
+--R                  (864a b c  - 576b c + 432a b)%%CW0 + 24a c  - 24b c
+--R                + 
+--R                        2 2         4      5
+--R                  - 108a b c + 72a b  - 54a
+--R             *
+--R                 +-------------------------------------------------+
+--R                 |         2                          2           2
+--R                \|- 36%%CW1  - 24%%CW0 %%CW1 - 36%%CW0  - 2a c - b
+--R            + 
+--R                        3        2            2  +-+
+--R                  (4608c  - 6912a c + 13824a b )\|3 %%CW0
+--R                + 
+--R                              2        3        3   +-+
+--R                  (- 1728a b c  + 1152b c - 864a b)\|3
+--R             *
+--R                     2
+--R                %%CW1
+--R            + 
+--R                        3        2            2  +-+     2
+--R                  (4608c  - 6912a c + 13824a b )\|3 %%CW0
+--R                + 
+--R                        4      2 3       2 2          4       5  +-+
+--R                  (48a c  - 48b c  - 216a b c + 144a b  - 108a )\|3
+--R             *
+--R                %%CW1
+--R            + 
+--R                          2        3        3   +-+     2
+--R              (- 1728a b c  + 1152b c - 864a b)\|3 %%CW0
+--R            + 
+--R                    4      2 3       2 2          4       5  +-+
+--R              (48a c  - 48b c  - 216a b c + 144a b  - 108a )\|3 %%CW0
+--R            + 
+--R                        6      2 4        2 3         4      4  2       3 2
+--R                      8c  - 12a c  + 96a b c  + (- 48b  - 18a )c  + 144a b c
+--R                    + 
+--R                           2 4      6
+--R                      - 72a b  + 27a
+--R                 *
+--R                    x
+--R                + 
+--R                        5      2   3        3 2       5      4         3 3
+--R                  - 8b c  - 48a b c  - 12a b c  + (24b  - 54a b)c + 18a b
+--R             *
+--R                 +-+
+--R                \|3
+--R     + 
+--R           +-+ +-+4+-+3
+--R         4\|3 \|6 \|6  %%CW1
+--R      *
+--R         log
+--R                          3         2            2                  2        3
+--R                  (- 9216c  + 13824a c - 27648a b )%%CW0 + 3456a b c  - 2304b c
+--R                + 
+--R                       3
+--R                  1728a b
+--R             *
+--R                     2
+--R                %%CW1
+--R            + 
+--R                          3         2            2      2        4      2 3
+--R                  (- 9216c  + 13824a c - 27648a b )%%CW0  - 96a c  + 96b c
+--R                + 
+--R                      2 2          4       5
+--R                  432a b c - 288a b  + 216a
+--R             *
+--R                %%CW1
+--R            + 
+--R                      3         2            2      3
+--R              (- 9216c  + 13824a c - 27648a b )%%CW0
+--R            + 
+--R                       4       2 3       3 2       2 2          4
+--R              (- 384a c  - 192b c  + 576a c  - 864a b c - 576a b )%%CW0
+--R            + 
+--R                    6      2 4        2 3         4      4  2       3 2
+--R                  8c  - 12a c  + 96a b c  + (- 48b  - 18a )c  + 144a b c
+--R                + 
+--R                       2 4      6
+--R                  - 72a b  + 27a
+--R             *
+--R                x
+--R            + 
+--R                    5      2   3        3 2         5      4         3 3
+--R              - 8b c  + 96a b c  - 36a b c  + (- 24b  + 18a b)c + 54a b
+--R     + 
+--R           +-+ +-+4+-+3
+--R         4\|3 \|6 \|6  %%CW0
+--R      *
+--R         log
+--R                    3         2            2      3
+--R              (9216c  - 13824a c + 27648a b )%%CW0
+--R            + 
+--R                        2        3         3       2
+--R              (3456a b c  - 2304b c + 1728a b)%%CW0
+--R            + 
+--R                     4       2 3       3 2        2 2          4       5
+--R              (288a c  + 288b c  - 576a c  + 1296a b c + 288a b  + 216a )%%CW0
+--R            + 
+--R                    6      2 4        2 3         4      4  2       3 2
+--R                  8c  - 12a c  + 96a b c  + (- 48b  - 18a )c  + 144a b c
+--R                + 
+--R                       2 4      6
+--R                  - 72a b  + 27a
+--R             *
+--R                x
+--R            + 
+--R                   5        3 2         5      4         3 3
+--R              24b c  + 60a b c  + (- 24b  + 90a b)c - 90a b
+--R     + 
+--R          +-+ +-+      +-+       4+-+3 4+-+   2 +-+    +-+
+--R       (c\|3 \|6  - 3a\|3 )log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R            +-+ +-+      +-+         4+-+3 4+-+   2 +-+    +-+
+--R       (- c\|3 \|6  + 3a\|3 )log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R             +-+ +-+      +-+       4+-+
+--R       (- 2c\|3 \|6  - 6a\|3 )atan(x\|6  + 1)
+--R     + 
+--R                                                                 2 +-+
+--R             +-+ +-+      +-+       4+-+           +-+4+-+3     x \|3
+--R       (- 2c\|3 \|6  - 6a\|3 )atan(x\|6  - 1) - 2b\|3 \|6  atan(------)
+--R                                                                  +-+
+--R                                                                 \|2
+--R  /
+--R       +-+ +-+4+-+3
+--R     4\|3 \|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                   6       2 4+-+3 +-+        4       +-+4+-+3 4+-+ +-+
+--R           ((- 3a x  - 2a x )\|2  \|3  + (3a x  + 2a)\|2 \|2  )\|3 \|6
+--R         + 
+--R                 6       2 4+-+3 +-+          4       +-+4+-+3 4+-+
+--R           ((6c x  + 4c x )\|2  \|3  + (- 6c x  - 4c)\|2 \|2  )\|3
+--R      *
+--R         4+-+3
+--R         \|6
+--R     + 
+--R                      3 +-+4+-+2 +-+        4 4+-+24+-+2
+--R               (- 8b x \|2 \|2  \|3  - 12a x  \|2 )\|3
+--R             + 
+--R                     5        4         +-+ +-+        6        3        2
+--R               (12b x  + 12a x  + 8b x)\|2 \|3  + 18a x  + 48b x  + 12a x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                 4        3        2 4+-+2 4+-+2
+--R           (24c x  + 48b x  + 48a x )\|2   \|3
+--R         + 
+--R                   4        3        2  +-+ +-+        6        5        4
+--R           (- 24c x  - 48b x  - 48a x )\|2 \|3  - 36c x  - 72b x  - 72a x
+--R         + 
+--R                  2
+--R           - 24c x  - 48b x - 48a
+--R      *
+--R         4+-+2
+--R         \|6
+--R     + 
+--R               2 4+-+2 4+-+2      2 +-+ +-+        4        +-+
+--R       (- 24a x  \|2   \|3 + 24a x \|2 \|3  + 36a x  + 24a)\|6
+--R     + 
+--R              2 4+-+2 4+-+2      2 +-+ +-+        4
+--R       - 48c x  \|2   \|3 + 48c x \|2 \|3  + 72c x  + 48c
+--R  /
+--R                6      2 4+-+2 4+-+2         6      2  +-+ +-+       8       4
+--R           (144x  + 96x )\|2   \|3  + (- 144x  - 96x )\|2 \|3  - 216x  - 288x
+--R         + 
+--R           - 96
+--R    *
+--R       4+-+2
+--R       \|6
+--R                                                    Type: Expression(Integer)
+--E 628
+
+)clear all
+
+--S 629 of 953
+t0:=d*x^3/(2+3*x^4)
+--R 
+--R
+--R             3
+--R          d x
+--R   (1)  -------
+--R          4
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 629
+
+--S 630 of 953
+r0:=1/12*d*log(2+3*x^4)
+--R 
+--R
+--R                4
+--R        d log(3x  + 2)
+--R   (2)  --------------
+--R              12
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                4
+--R        d log(3x  + 2)
+--R   (3)  --------------
+--R              12
+--R                                         Type: Union(Expression(Integer),...)
+--E 631
+
+--S 632 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 633
+
+)clear all
+
+--S 634 of 953
+t0:=(a+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3
+--R        d x  + a
+--R   (1)  --------
+--R           4
+--R         3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 634
+
+--S 635 of 953
+r0:=-1/4*a*atan(1-6^(1/4)*x)/6^(1/4)+1/4*a*atan(1+6^(1/4)*x)/6^(1/4)+_
+   1/12*d*log(2+3*x^4)-1/8*a*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*_
+   sqrt(3))/6^(1/4)+1/8*a*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)
+--R 
+--R
+--R   (2)
+--R                4+-+3 4+-+   2 +-+    +-+      4+-+      4
+--R       3a log(x \|2   \|3 + x \|3  + \|2 ) + 2d\|6 log(3x  + 2)
+--R     + 
+--R                    4+-+3 4+-+   2 +-+    +-+             4+-+
+--R       - 3a log(- x \|2   \|3 + x \|3  + \|2 ) + 6a atan(x\|6  + 1)
+--R     + 
+--R                4+-+
+--R       6a atan(x\|6  - 1)
+--R  /
+--R       4+-+
+--R     24\|6
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                              +-------+                           +-----+
+--R                              |   +--+                            | +--+
+--R                              |   | 4                             | | 4
+--R            +-------+         |  \|a              +-----+         |\|a
+--R            |   +--+        2 |- -----            | +--+        2 |-----
+--R            |   | 4           |    +-+            | | 4           |  +-+
+--R        +-+ |  \|a           \|  8\|6         +-+ |\|a           \|8\|6
+--R       \|2  |- ----- atan(---------------) + \|2  |----- atan(-------------)
+--R            |    +-+        +-------+             |  +-+        +-----+
+--R           \|  8\|6         |   +--+             \|8\|6         | +--+
+--R                            |   | 4                             | | 4
+--R                            |  \|a                              |\|a
+--R                          2 |- -----  - a                     2 |-----  - a
+--R                            |    +-+                            |  +-+
+--R                           \|  8\|6                            \|8\|6
+--R     + 
+--R                              +-----+                             +-------+
+--R                              | +--+                              |   +--+
+--R                              | | 4                               |   | 4
+--R              +-----+         |\|a              +-------+         |  \|a
+--R              | +--+        2 |-----            |   +--+        2 |- -----
+--R              | | 4           |  +-+            |   | 4           |    +-+
+--R          +-+ |\|a           \|8\|6         +-+ |  \|a           \|  8\|6
+--R       - \|2  |----- atan(-------------) - \|2  |- ----- atan(---------------)
+--R              |  +-+        +-----+             |    +-+        +-------+
+--R             \|8\|6         | +--+             \|  8\|6         |   +--+
+--R                            | | 4                               |   | 4
+--R                            |\|a                                |  \|a
+--R                          2 |-----  + a                       2 |- -----  + a
+--R                            |  +-+                              |    +-+
+--R                           \|8\|6                              \|  8\|6
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 636
+
+--S 637 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                   +-------+
+--R                                   |   +--+
+--R                                   |   | 4
+--R                 +-------+         |  \|a
+--R                 |   +--+        2 |- -----
+--R                 |   | 4           |    +-+
+--R         +-+4+-+ |  \|a           \|  8\|6
+--R       6\|2 \|6  |- ----- atan(---------------)
+--R                 |    +-+        +-------+
+--R                \|  8\|6         |   +--+
+--R                                 |   | 4
+--R                                 |  \|a
+--R                               2 |- -----  - a
+--R                                 |    +-+
+--R                                \|  8\|6
+--R     + 
+--R                                 +-----+
+--R                                 | +--+
+--R                                 | | 4
+--R                 +-----+         |\|a
+--R                 | +--+        2 |-----
+--R                 | | 4           |  +-+
+--R         +-+4+-+ |\|a           \|8\|6
+--R       6\|2 \|6  |----- atan(-------------)
+--R                 |  +-+        +-----+
+--R                \|8\|6         | +--+
+--R                               | | 4
+--R                               |\|a
+--R                             2 |-----  - a
+--R                               |  +-+
+--R                              \|8\|6
+--R     + 
+--R                                   +-----+
+--R                                   | +--+
+--R                                   | | 4
+--R                   +-----+         |\|a
+--R                   | +--+        2 |-----
+--R                   | | 4           |  +-+
+--R           +-+4+-+ |\|a           \|8\|6
+--R       - 6\|2 \|6  |----- atan(-------------)
+--R                   |  +-+        +-----+
+--R                  \|8\|6         | +--+
+--R                                 | | 4
+--R                                 |\|a
+--R                               2 |-----  + a
+--R                                 |  +-+
+--R                                \|8\|6
+--R     + 
+--R                                     +-------+
+--R                                     |   +--+
+--R                                     |   | 4
+--R                   +-------+         |  \|a
+--R                   |   +--+        2 |- -----
+--R                   |   | 4           |    +-+
+--R           +-+4+-+ |  \|a           \|  8\|6
+--R       - 6\|2 \|6  |- ----- atan(---------------)
+--R                   |    +-+        +-------+
+--R                  \|  8\|6         |   +--+
+--R                                   |   | 4
+--R                                   |  \|a
+--R                                 2 |- -----  + a
+--R                                   |    +-+
+--R                                  \|  8\|6
+--R     + 
+--R                  4+-+3 4+-+   2 +-+    +-+      4+-+      4
+--R       - 3a log(x \|2   \|3 + x \|3  + \|2 ) - 2d\|6 log(3x  + 2)
+--R     + 
+--R                  4+-+3 4+-+   2 +-+    +-+             4+-+
+--R       3a log(- x \|2   \|3 + x \|3  + \|2 ) - 6a atan(x\|6  + 1)
+--R     + 
+--R                  4+-+
+--R       - 6a atan(x\|6  - 1)
+--R  /
+--R       4+-+
+--R     24\|6
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  5       2 4+-+2 4+-+2       5       2  +-+ +-+        7
+--R           (- 8d x  - 4a x )\|2   \|3  + (8d x  + 4a x )\|2 \|3  + 12d x
+--R         + 
+--R               4       3
+--R           6a x  + 8d x  + 4a
+--R      *
+--R         4+-+2
+--R         \|6
+--R     + 
+--R               6       2 4+-+3 +-+        4       +-+4+-+3 4+-+4+-+
+--R       ((- 3a x  - 2a x )\|2  \|3  + (3a x  + 2a)\|2 \|2  )\|3 \|6
+--R     + 
+--R              4 4+-+2 4+-+2      4 +-+ +-+        6        2
+--R       - 12a x  \|2   \|3 + 12a x \|2 \|3  + 18a x  + 12a x
+--R  /
+--R          6      2 4+-+2 4+-+2        6      2  +-+ +-+      8      4      4+-+2
+--R     ((24x  + 16x )\|2   \|3  + (- 24x  - 16x )\|2 \|3  - 36x  - 48x  - 16)\|6
+--R                                                    Type: Expression(Integer)
+--E 638
+
+)clear all
+
+--S 639 of 953
+t0:=(b*x+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3
+--R        d x  + b x
+--R   (1)  ----------
+--R            4
+--R          3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 639
+
+--S 640 of 953
+r0:=1/12*d*log(2+3*x^4)+1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R                                     2 +-+
+--R          +-+      4                x \|3
+--R        d\|6 log(3x  + 2) + 6b atan(------)
+--R                                      +-+
+--R                                     \|2
+--R   (2)  -----------------------------------
+--R                          +-+
+--R                       12\|6
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                     2 +-+
+--R          +-+      4                x \|6
+--R        d\|6 log(3x  + 2) + 6b atan(------)
+--R                                       2
+--R   (3)  -----------------------------------
+--R                          +-+
+--R                       12\|6
+--R                                         Type: Union(Expression(Integer),...)
+--E 641
+
+--S 642 of 953
+m0:=a0-r0
+--R 
+--R
+--R                2 +-+            2 +-+
+--R               x \|6            x \|3
+--R        b atan(------) - b atan(------)
+--R                  2               +-+
+--R                                 \|2
+--R   (4)  -------------------------------
+--R                       +-+
+--R                     2\|6
+--R                                                    Type: Expression(Integer)
+--E 642
+
+--S 643 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R              +-+ +-+ +-+
+--R        - b x\|2 \|3 \|6  + 6b x
+--R   (5)  ------------------------
+--R                   4
+--R                18x  + 12
+--R                                                    Type: Expression(Integer)
+--E 643
+
+)clear all
+
+--S 644 of 953
+t0:=(a+b*x+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3
+--R        d x  + b x + a
+--R   (1)  --------------
+--R              4
+--R            3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 644
+
+--S 645 of 953
+r0:=-1/4*a*atan(1-6^(1/4)*x)/6^(1/4)+1/4*a*atan(1+6^(1/4)*x)/6^(1/4)+_
+   1/12*d*log(2+3*x^4)-1/8*a*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/_
+   6^(1/4)+1/8*a*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)+_
+   1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R          +-+      4+-+3 4+-+   2 +-+    +-+       +-+4+-+      4
+--R       3a\|6 log(x \|2   \|3 + x \|3  + \|2 ) + 2d\|6 \|6 log(3x  + 2)
+--R     + 
+--R            +-+        4+-+3 4+-+   2 +-+    +-+       +-+      4+-+
+--R       - 3a\|6 log(- x \|2   \|3 + x \|3  + \|2 ) + 6a\|6 atan(x\|6  + 1)
+--R     + 
+--R                                            2 +-+
+--R          +-+      4+-+           4+-+     x \|3
+--R       6a\|6 atan(x\|6  - 1) + 12b\|6 atan(------)
+--R                                             +-+
+--R                                            \|2
+--R  /
+--R        +-+4+-+
+--R     24\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 645
+
+--S 646 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R              ROOT
+--R                             2                                    2
+--R                   - 108%%CY1  + (- 72%%CY0 + 24d)%%CY1 - 108%%CY0  + 24d %%CY0
+--R                 + 
+--R                       2     2
+--R                   - 2d  - 3b
+--R         + 
+--R           - 6%%CY1 - 6%%CY0 + 2d
+--R      *
+--R         log
+--R                        2            2        2
+--R                  (2304b %%CY0 - 192b d - 144a b)%%CY1
+--R                + 
+--R                         2        2             2 2      2         4      4
+--R                  (- 192b d - 144a b)%%CY0 + 16b d  + 24a b d - 24b  + 18a
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%CY1  + (- 72%%CY0 + 24d)%%CY1 - 108%%CY0
+--R                   + 
+--R                                   2     2
+--R                     24d %%CY0 - 2d  - 3b
+--R            + 
+--R                       2             2        2       2
+--R              (- 13824b %%CY0 + 1152b d + 864a b)%%CY1
+--R            + 
+--R                          2     2        2              2 2       2          4
+--R                  - 13824b %%CY0  + 4608b d %%CY0 - 288b d  - 144a b d - 144b
+--R                + 
+--R                      4
+--R                  108a
+--R             *
+--R                %%CY1
+--R            + 
+--R                    2        2       2
+--R              (1152b d + 864a b)%%CY0
+--R            + 
+--R                     2 2       2          4       4               4      5
+--R              (- 288b d  - 144a b d - 144b  + 108a )%%CY0 + (72a b  - 27a )x
+--R            + 
+--R                 2 3      2   2       4      4        2 3
+--R              16b d  + 12a b d  + (24b  - 18a )d - 18a b
+--R     + 
+--R           ROOT
+--R                          2                                    2
+--R                - 108%%CY1  + (- 72%%CY0 + 24d)%%CY1 - 108%%CY0  + 24d %%CY0
+--R              + 
+--R                    2     2
+--R                - 2d  - 3b
+--R         + 
+--R           - 6%%CY1 - 6%%CY0 + 2d
+--R      *
+--R         log
+--R                          2            2        2
+--R                  (- 2304b %%CY0 + 192b d + 144a b)%%CY1
+--R                + 
+--R                       2        2             2 2      2         4      4
+--R                  (192b d + 144a b)%%CY0 - 16b d  - 24a b d + 24b  - 18a
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%CY1  + (- 72%%CY0 + 24d)%%CY1 - 108%%CY0
+--R                   + 
+--R                                   2     2
+--R                     24d %%CY0 - 2d  - 3b
+--R            + 
+--R                       2             2        2       2
+--R              (- 13824b %%CY0 + 1152b d + 864a b)%%CY1
+--R            + 
+--R                          2     2        2              2 2       2          4
+--R                  - 13824b %%CY0  + 4608b d %%CY0 - 288b d  - 144a b d - 144b
+--R                + 
+--R                      4
+--R                  108a
+--R             *
+--R                %%CY1
+--R            + 
+--R                    2        2       2
+--R              (1152b d + 864a b)%%CY0
+--R            + 
+--R                     2 2       2          4       4               4      5
+--R              (- 288b d  - 144a b d - 144b  + 108a )%%CY0 + (72a b  - 27a )x
+--R            + 
+--R                 2 3      2   2       4      4        2 3
+--R              16b d  + 12a b d  + (24b  - 18a )d - 18a b
+--R     + 
+--R         12%%CY1
+--R      *
+--R         log
+--R                    2            2        2       2
+--R              (9216b %%CY0 - 768b d - 576a b)%%CY1
+--R            + 
+--R                      2     2        2              2 2      2         4      4
+--R                (9216b %%CY0  - 3072b d %%CY0 + 192b d  + 96a b d + 96b  - 72a )
+--R             *
+--R                %%CY1
+--R            + 
+--R                   2     3        2       2        2 2       4
+--R              9216b %%CY0  - 3072b d %%CY0  + (384b d  + 192b )%%CY0
+--R            + 
+--R                    4     5        2 3     2   2         4     4        2 3
+--R              (24a b  - 9a )x - 16b d  - 4a b d  + (- 24b  + 6a )d - 18a b
+--R     + 
+--R         12%%CY0
+--R      *
+--R         log
+--R                      2     3         2         2       2
+--R              - 27648b %%CY0  + (6912b d - 1728a b)%%CY0
+--R            + 
+--R                     2 2       2          4       4               4      5
+--R              (- 576b d  + 288a b d - 288b  - 216a )%%CY0 + (72a b  - 27a )x
+--R            + 
+--R                 2 3      2   2       4      4        2 3
+--R              16b d  - 12a b d  + (24b  + 18a )d + 90a b
+--R  /
+--R     12
+--R                                         Type: Union(Expression(Integer),...)
+--E 646
+
+--S 647 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                  +-+4+-+
+--R                2\|6 \|6
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%CY1  + (- 72%%CY0 + 24d)%%CY1 - 108%%CY0
+--R                   + 
+--R                                   2     2
+--R                     24d %%CY0 - 2d  - 3b
+--R         + 
+--R                +-+4+-+           +-+4+-+           +-+4+-+
+--R           - 12\|6 \|6 %%CY1 - 12\|6 \|6 %%CY0 + 4d\|6 \|6
+--R      *
+--R         log
+--R                        2            2        2
+--R                  (2304b %%CY0 - 192b d - 144a b)%%CY1
+--R                + 
+--R                         2        2             2 2      2         4      4
+--R                  (- 192b d - 144a b)%%CY0 + 16b d  + 24a b d - 24b  + 18a
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%CY1  + (- 72%%CY0 + 24d)%%CY1 - 108%%CY0
+--R                   + 
+--R                                   2     2
+--R                     24d %%CY0 - 2d  - 3b
+--R            + 
+--R                       2             2        2       2
+--R              (- 13824b %%CY0 + 1152b d + 864a b)%%CY1
+--R            + 
+--R                          2     2        2              2 2       2          4
+--R                  - 13824b %%CY0  + 4608b d %%CY0 - 288b d  - 144a b d - 144b
+--R                + 
+--R                      4
+--R                  108a
+--R             *
+--R                %%CY1
+--R            + 
+--R                    2        2       2
+--R              (1152b d + 864a b)%%CY0
+--R            + 
+--R                     2 2       2          4       4               4      5
+--R              (- 288b d  - 144a b d - 144b  + 108a )%%CY0 + (72a b  - 27a )x
+--R            + 
+--R                 2 3      2   2       4      4        2 3
+--R              16b d  + 12a b d  + (24b  - 18a )d - 18a b
+--R     + 
+--R               +-+4+-+
+--R             2\|6 \|6
+--R          *
+--R             ROOT
+--R                            2                                    2
+--R                  - 108%%CY1  + (- 72%%CY0 + 24d)%%CY1 - 108%%CY0  + 24d %%CY0
+--R                + 
+--R                      2     2
+--R                  - 2d  - 3b
+--R         + 
+--R                +-+4+-+           +-+4+-+           +-+4+-+
+--R           - 12\|6 \|6 %%CY1 - 12\|6 \|6 %%CY0 + 4d\|6 \|6
+--R      *
+--R         log
+--R                          2            2        2
+--R                  (- 2304b %%CY0 + 192b d + 144a b)%%CY1
+--R                + 
+--R                       2        2             2 2      2         4      4
+--R                  (192b d + 144a b)%%CY0 - 16b d  - 24a b d + 24b  - 18a
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%CY1  + (- 72%%CY0 + 24d)%%CY1 - 108%%CY0
+--R                   + 
+--R                                   2     2
+--R                     24d %%CY0 - 2d  - 3b
+--R            + 
+--R                       2             2        2       2
+--R              (- 13824b %%CY0 + 1152b d + 864a b)%%CY1
+--R            + 
+--R                          2     2        2              2 2       2          4
+--R                  - 13824b %%CY0  + 4608b d %%CY0 - 288b d  - 144a b d - 144b
+--R                + 
+--R                      4
+--R                  108a
+--R             *
+--R                %%CY1
+--R            + 
+--R                    2        2       2
+--R              (1152b d + 864a b)%%CY0
+--R            + 
+--R                     2 2       2          4       4               4      5
+--R              (- 288b d  - 144a b d - 144b  + 108a )%%CY0 + (72a b  - 27a )x
+--R            + 
+--R                 2 3      2   2       4      4        2 3
+--R              16b d  + 12a b d  + (24b  - 18a )d - 18a b
+--R     + 
+--R            +-+4+-+
+--R         24\|6 \|6 %%CY1
+--R      *
+--R         log
+--R                    2            2        2       2
+--R              (9216b %%CY0 - 768b d - 576a b)%%CY1
+--R            + 
+--R                      2     2        2              2 2      2         4      4
+--R                (9216b %%CY0  - 3072b d %%CY0 + 192b d  + 96a b d + 96b  - 72a )
+--R             *
+--R                %%CY1
+--R            + 
+--R                   2     3        2       2        2 2       4
+--R              9216b %%CY0  - 3072b d %%CY0  + (384b d  + 192b )%%CY0
+--R            + 
+--R                    4     5        2 3     2   2         4     4        2 3
+--R              (24a b  - 9a )x - 16b d  - 4a b d  + (- 24b  + 6a )d - 18a b
+--R     + 
+--R            +-+4+-+
+--R         24\|6 \|6 %%CY0
+--R      *
+--R         log
+--R                      2     3         2         2       2
+--R              - 27648b %%CY0  + (6912b d - 1728a b)%%CY0
+--R            + 
+--R                     2 2       2          4       4               4      5
+--R              (- 576b d  + 288a b d - 288b  - 216a )%%CY0 + (72a b  - 27a )x
+--R            + 
+--R                 2 3      2   2       4      4        2 3
+--R              16b d  - 12a b d  + (24b  + 18a )d + 90a b
+--R     + 
+--R            +-+      4+-+3 4+-+   2 +-+    +-+       +-+4+-+      4
+--R       - 3a\|6 log(x \|2   \|3 + x \|3  + \|2 ) - 2d\|6 \|6 log(3x  + 2)
+--R     + 
+--R          +-+        4+-+3 4+-+   2 +-+    +-+       +-+      4+-+
+--R       3a\|6 log(- x \|2   \|3 + x \|3  + \|2 ) - 6a\|6 atan(x\|6  + 1)
+--R     + 
+--R                                              2 +-+
+--R            +-+      4+-+           4+-+     x \|3
+--R       - 6a\|6 atan(x\|6  - 1) - 12b\|6 atan(------)
+--R                                               +-+
+--R                                              \|2
+--R  /
+--R        +-+4+-+
+--R     24\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  3 +-+4+-+2 +-+4+-+2        5         +-+ +-+        3  +-+
+--R           (- 4b x \|2 \|2  \|3 \|3   + (6b x  + 4b x)\|2 \|3  + 24b x )\|6
+--R         + 
+--R                 3        2 4+-+2 4+-+2          3        2  +-+ +-+        5
+--R           (24b x  + 12a x )\|2   \|3  + (- 24b x  - 12a x )\|2 \|3  - 36b x
+--R         + 
+--R                  4
+--R           - 18a x  - 24b x - 12a
+--R      *
+--R         4+-+2
+--R         \|6
+--R     + 
+--R               6       2 4+-+3 +-+        4       +-+4+-+3 4+-+4+-+
+--R       ((- 9a x  - 6a x )\|2  \|3  + (9a x  + 6a)\|2 \|2  )\|3 \|6
+--R     + 
+--R              4 4+-+2 4+-+2      4 +-+ +-+        6        2
+--R       - 36a x  \|2   \|3 + 36a x \|2 \|3  + 54a x  + 36a x
+--R  /
+--R            6      2 4+-+2 4+-+2        6      2  +-+ +-+       8       4
+--R       ((72x  + 48x )\|2   \|3  + (- 72x  - 48x )\|2 \|3  - 108x  - 144x  - 48)
+--R    *
+--R       4+-+2
+--R       \|6
+--R                                                    Type: Expression(Integer)
+--E 648
+
+)clear all
+
+--S 649 of 953
+t0:=(c*x^2+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x
+--R   (1)  -----------
+--R            4
+--R          3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 649
+
+--S 650 of 953
+r0:=-1/2*c*atan(1-6^(1/4)*x)/6^(3/4)+1/2*c*atan(1+6^(1/4)*x)/6^(3/4)+_
+   1/12*d*log(2+3*x^4)+1/4*c*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/_
+   6^(3/4)-1/4*c*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R                  4+-+3 4+-+   2 +-+    +-+      4+-+3      4
+--R       - 3c log(x \|2   \|3 + x \|3  + \|2 ) + d \|6  log(3x  + 2)
+--R     + 
+--R                  4+-+3 4+-+   2 +-+    +-+             4+-+
+--R       3c log(- x \|2   \|3 + x \|3  + \|2 ) + 6c atan(x\|6  + 1)
+--R     + 
+--R                4+-+
+--R       6c atan(x\|6  - 1)
+--R  /
+--R       4+-+3
+--R     12\|6
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                         +--------+
+--R                                         |    +--+
+--R                                    +--+ |    | 4
+--R              +--------+            | 4  |   \|c
+--R              |    +--+           6\|c   |- ------
+--R              |    | 4                   |     +-+
+--R          +-+ |   \|c                   \|  12\|6
+--R       - \|2  |- ------ atan(--------------------------)
+--R              |     +-+             +--------+
+--R             \|  12\|6              |    +--+
+--R                               +--+ |    | 4
+--R                               | 4  |   \|c       3 +-+
+--R                             6\|c   |- ------  - c \|6
+--R                                    |     +-+
+--R                                   \|  12\|6
+--R     + 
+--R                                     +------+
+--R                                     |  +--+
+--R                                +--+ |  | 4
+--R            +------+            | 4  | \|c
+--R            |  +--+           6\|c   |------
+--R            |  | 4                   |   +-+
+--R        +-+ | \|c                   \|12\|6
+--R       \|2  |------ atan(------------------------)
+--R            |   +-+             +------+
+--R           \|12\|6              |  +--+
+--R                           +--+ |  | 4
+--R                           | 4  | \|c       3 +-+
+--R                         6\|c   |------  - c \|6
+--R                                |   +-+
+--R                               \|12\|6
+--R     + 
+--R                                       +------+
+--R                                       |  +--+
+--R                                  +--+ |  | 4
+--R              +------+            | 4  | \|c
+--R              |  +--+           6\|c   |------
+--R              |  | 4                   |   +-+
+--R          +-+ | \|c                   \|12\|6
+--R       - \|2  |------ atan(------------------------)
+--R              |   +-+             +------+
+--R             \|12\|6              |  +--+
+--R                             +--+ |  | 4
+--R                             | 4  | \|c       3 +-+
+--R                           6\|c   |------  + c \|6
+--R                                  |   +-+
+--R                                 \|12\|6
+--R     + 
+--R                                       +--------+
+--R                                       |    +--+
+--R                                  +--+ |    | 4
+--R            +--------+            | 4  |   \|c
+--R            |    +--+           6\|c   |- ------
+--R            |    | 4                   |     +-+
+--R        +-+ |   \|c                   \|  12\|6
+--R       \|2  |- ------ atan(--------------------------)
+--R            |     +-+             +--------+
+--R           \|  12\|6              |    +--+
+--R                             +--+ |    | 4
+--R                             | 4  |   \|c       3 +-+
+--R                           6\|c   |- ------  + c \|6
+--R                                  |     +-+
+--R                                 \|  12\|6
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 651
+
+--S 652 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +--------+
+--R                                               |    +--+
+--R                                          +--+ |    | 4
+--R                    +--------+            | 4  |   \|c
+--R                    |    +--+           6\|c   |- ------
+--R                    |    | 4                   |     +-+
+--R           +-+4+-+3 |   \|c                   \|  12\|6
+--R       - 3\|2 \|6   |- ------ atan(--------------------------)
+--R                    |     +-+             +--------+
+--R                   \|  12\|6              |    +--+
+--R                                     +--+ |    | 4
+--R                                     | 4  |   \|c       3 +-+
+--R                                   6\|c   |- ------  - c \|6
+--R                                          |     +-+
+--R                                         \|  12\|6
+--R     + 
+--R                                           +------+
+--R                                           |  +--+
+--R                                      +--+ |  | 4
+--R                  +------+            | 4  | \|c
+--R                  |  +--+           6\|c   |------
+--R                  |  | 4                   |   +-+
+--R         +-+4+-+3 | \|c                   \|12\|6
+--R       3\|2 \|6   |------ atan(------------------------)
+--R                  |   +-+             +------+
+--R                 \|12\|6              |  +--+
+--R                                 +--+ |  | 4
+--R                                 | 4  | \|c       3 +-+
+--R                               6\|c   |------  - c \|6
+--R                                      |   +-+
+--R                                     \|12\|6
+--R     + 
+--R                                             +------+
+--R                                             |  +--+
+--R                                        +--+ |  | 4
+--R                    +------+            | 4  | \|c
+--R                    |  +--+           6\|c   |------
+--R                    |  | 4                   |   +-+
+--R           +-+4+-+3 | \|c                   \|12\|6
+--R       - 3\|2 \|6   |------ atan(------------------------)
+--R                    |   +-+             +------+
+--R                   \|12\|6              |  +--+
+--R                                   +--+ |  | 4
+--R                                   | 4  | \|c       3 +-+
+--R                                 6\|c   |------  + c \|6
+--R                                        |   +-+
+--R                                       \|12\|6
+--R     + 
+--R                                             +--------+
+--R                                             |    +--+
+--R                                        +--+ |    | 4
+--R                  +--------+            | 4  |   \|c
+--R                  |    +--+           6\|c   |- ------
+--R                  |    | 4                   |     +-+
+--R         +-+4+-+3 |   \|c                   \|  12\|6
+--R       3\|2 \|6   |- ------ atan(--------------------------)
+--R                  |     +-+             +--------+
+--R                 \|  12\|6              |    +--+
+--R                                   +--+ |    | 4
+--R                                   | 4  |   \|c       3 +-+
+--R                                 6\|c   |- ------  + c \|6
+--R                                        |     +-+
+--R                                       \|  12\|6
+--R     + 
+--R                4+-+3 4+-+   2 +-+    +-+      4+-+3      4
+--R       3c log(x \|2   \|3 + x \|3  + \|2 ) - d \|6  log(3x  + 2)
+--R     + 
+--R                    4+-+3 4+-+   2 +-+    +-+             4+-+
+--R       - 3c log(- x \|2   \|3 + x \|3  + \|2 ) - 6c atan(x\|6  + 1)
+--R     + 
+--R                  4+-+
+--R       - 6c atan(x\|6  - 1)
+--R  /
+--R       4+-+3
+--R     12\|6
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R             6       2 4+-+3 +-+          4       +-+4+-+3 4+-+4+-+3
+--R       ((3c x  + 2c x )\|2  \|3  + (- 3c x  - 2c)\|2 \|2  )\|3 \|6
+--R     + 
+--R                   5        4 4+-+2 4+-+2        5        4  +-+ +-+        7
+--R           (- 24d x  - 12c x )\|2   \|3  + (24d x  + 12c x )\|2 \|3  + 36d x
+--R         + 
+--R                6        3        2
+--R           18c x  + 24d x  + 12c x
+--R      *
+--R         4+-+2
+--R         \|6
+--R     + 
+--R              2 4+-+2 4+-+2      2 +-+ +-+        4
+--R       - 24c x  \|2   \|3 + 24c x \|2 \|3  + 36c x  + 24c
+--R  /
+--R            6      2 4+-+2 4+-+2        6      2  +-+ +-+       8       4
+--R       ((72x  + 48x )\|2   \|3  + (- 72x  - 48x )\|2 \|3  - 108x  - 144x  - 48)
+--R    *
+--R       4+-+2
+--R       \|6
+--R                                                    Type: Expression(Integer)
+--E 653
+
+)clear all
+
+--S 654 of 953
+t0:=(a+c*x^2+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + a
+--R   (1)  ---------------
+--R              4
+--R            3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 654
+
+--S 655 of 953
+r0:=1/12*d*log(2+3*x^4)-1/8*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*_
+   (-2*c+a*sqrt(6))/6^(3/4)+1/8*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*_
+   (-2*c+a*sqrt(6))/6^(3/4)-1/4*atan(1-6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)+_
+   1/4*atan(1+6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R           +-+            4+-+3 4+-+   2 +-+    +-+       4+-+3      4
+--R       (3a\|6  - 6c)log(x \|2   \|3 + x \|3  + \|2 ) + 2d \|6  log(3x  + 2)
+--R     + 
+--R             +-+              4+-+3 4+-+   2 +-+    +-+
+--R       (- 3a\|6  + 6c)log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+             4+-+            +-+             4+-+
+--R       (6a\|6  + 12c)atan(x\|6  + 1) + (6a\|6  + 12c)atan(x\|6  - 1)
+--R  /
+--R       4+-+3
+--R     24\|6
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                          +------------------+
+--R                                          |  4      2 2     4
+--R                                         \|4c  - 12a c  + 9a
+--R                                    atan(---------------------)
+--R            +------------------+                     +-+
+--R           4|  4      2 2     4                 2a c\|6             4+---+
+--R         (3\|4c  + 12a c  + 9a  cos(---------------------------) + d\|216 )
+--R                                                 2
+--R      *
+--R         log
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R                               +------------------+ +------------------+
+--R                     +-+4+---+ |  4      2 2     4 4|  4      2 2     4
+--R                4c x\|6 \|216 \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                                       +------------------+
+--R                      2      3  4+---+4|  4      2 2     4
+--R                (24a c  - 36a )x\|216 \|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                 4     4  2 4+---+2
+--R              (4c  - 9a )x  \|216
+--R     + 
+--R                                            +------------------+
+--R                                            |  4      2 2     4
+--R                                           \|4c  - 12a c  + 9a
+--R                                      atan(---------------------)
+--R              +------------------+                     +-+
+--R             4|  4      2 2     4                 2a c\|6             4+---+
+--R         (- 3\|4c  + 12a c  + 9a  cos(---------------------------) + d\|216 )
+--R                                                   2
+--R      *
+--R         log
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R              -
+--R                                  +------------------+ +------------------+
+--R                        +-+4+---+ |  4      2 2     4 4|  4      2 2     4
+--R                   4c x\|6 \|216 \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                *
+--R                             +------------------+
+--R                             |  4      2 2     4
+--R                            \|4c  - 12a c  + 9a
+--R                       atan(---------------------)
+--R                                        +-+
+--R                                   2a c\|6
+--R                   sin(---------------------------)
+--R                                    2
+--R            + 
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                                         +------------------+
+--R                        2      3  4+---+4|  4      2 2     4
+--R                (- 24a c  + 36a )x\|216 \|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                 4     4  2 4+---+2
+--R              (4c  - 9a )x  \|216
+--R     + 
+--R                                         +------------------+
+--R                                         |  4      2 2     4
+--R                                        \|4c  - 12a c  + 9a
+--R                                   atan(---------------------)
+--R           +------------------+                     +-+
+--R          4|  4      2 2     4                 2a c\|6
+--R         6\|4c  + 12a c  + 9a  sin(---------------------------)
+--R                                                2
+--R      *
+--R         atan
+--R                                      +------------------+
+--R                        2      3  +-+4|  4      2 2     4
+--R                  (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  sin(---------------------------)
+--R                                   2
+--R              + 
+--R                -
+--R                         +------------------+ +------------------+
+--R                         |  4      2 2     4 4|  4      2 2     4
+--R                     12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     cos(---------------------------)
+--R                                      2
+--R           /
+--R                      +------------------+ +------------------+
+--R                      |  4      2 2     4 4|  4      2 2     4
+--R                  12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  sin(---------------------------)
+--R                                   2
+--R              + 
+--R                                      +------------------+
+--R                        2      3  +-+4|  4      2 2     4
+--R                  (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  cos(---------------------------)
+--R                                   2
+--R              + 
+--R                     4     4   +-+4+---+
+--R                (- 4c  + 9a )x\|6 \|216
+--R     + 
+--R       -
+--R                                            +------------------+
+--R                                            |  4      2 2     4
+--R                                           \|4c  - 12a c  + 9a
+--R                                      atan(---------------------)
+--R              +------------------+                     +-+
+--R             4|  4      2 2     4                 2a c\|6
+--R            6\|4c  + 12a c  + 9a  sin(---------------------------)
+--R                                                   2
+--R         *
+--R            atan
+--R                                         +------------------+
+--R                           2      3  +-+4|  4      2 2     4
+--R                     (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     sin(---------------------------)
+--R                                      2
+--R                 + 
+--R                   -
+--R                            +------------------+ +------------------+
+--R                            |  4      2 2     4 4|  4      2 2     4
+--R                        12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                     *
+--R                                  +------------------+
+--R                                  |  4      2 2     4
+--R                                 \|4c  - 12a c  + 9a
+--R                            atan(---------------------)
+--R                                             +-+
+--R                                        2a c\|6
+--R                        cos(---------------------------)
+--R                                         2
+--R              /
+--R                         +------------------+ +------------------+
+--R                         |  4      2 2     4 4|  4      2 2     4
+--R                     12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     sin(---------------------------)
+--R                                      2
+--R                 + 
+--R                                         +------------------+
+--R                           2      3  +-+4|  4      2 2     4
+--R                     (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     cos(---------------------------)
+--R                                      2
+--R                 + 
+--R                      4     4   +-+4+---+
+--R                   (4c  - 9a )x\|6 \|216
+--R  /
+--R       4+---+
+--R     12\|216
+--R                                         Type: Union(Expression(Integer),...)
+--E 656
+
+--S 657 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +------------------+
+--R                                                 |  4      2 2     4
+--R                                                \|4c  - 12a c  + 9a
+--R                                           atan(---------------------)
+--R                   +------------------+                     +-+
+--R            4+-+3 4|  4      2 2     4                 2a c\|6
+--R           6\|6   \|4c  + 12a c  + 9a  cos(---------------------------)
+--R                                                        2
+--R         + 
+--R              4+-+3 4+---+
+--R           2d \|6   \|216
+--R      *
+--R         log
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R                               +------------------+ +------------------+
+--R                     +-+4+---+ |  4      2 2     4 4|  4      2 2     4
+--R                4c x\|6 \|216 \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                                       +------------------+
+--R                      2      3  4+---+4|  4      2 2     4
+--R                (24a c  - 36a )x\|216 \|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                 4     4  2 4+---+2
+--R              (4c  - 9a )x  \|216
+--R     + 
+--R                                                   +------------------+
+--R                                                   |  4      2 2     4
+--R                                                  \|4c  - 12a c  + 9a
+--R                                             atan(---------------------)
+--R                     +------------------+                     +-+
+--R              4+-+3 4|  4      2 2     4                 2a c\|6
+--R           - 6\|6   \|4c  + 12a c  + 9a  cos(---------------------------)
+--R                                                          2
+--R         + 
+--R              4+-+3 4+---+
+--R           2d \|6   \|216
+--R      *
+--R         log
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                sin(---------------------------)
+--R                                 2
+--R            + 
+--R              -
+--R                                  +------------------+ +------------------+
+--R                        +-+4+---+ |  4      2 2     4 4|  4      2 2     4
+--R                   4c x\|6 \|216 \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                *
+--R                             +------------------+
+--R                             |  4      2 2     4
+--R                            \|4c  - 12a c  + 9a
+--R                       atan(---------------------)
+--R                                        +-+
+--R                                   2a c\|6
+--R                   sin(---------------------------)
+--R                                    2
+--R            + 
+--R                              +------------------+2
+--R                    2      2 4|  4      2 2     4
+--R                (24c  - 36a )\|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+  2
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                                         +------------------+
+--R                        2      3  4+---+4|  4      2 2     4
+--R                (- 24a c  + 36a )x\|216 \|4c  + 12a c  + 9a
+--R             *
+--R                          +------------------+
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R                                2a c\|6
+--R                cos(---------------------------)
+--R                                 2
+--R            + 
+--R                 4     4  2 4+---+2
+--R              (4c  - 9a )x  \|216
+--R     + 
+--R                                                +------------------+
+--R                                                |  4      2 2     4
+--R                                               \|4c  - 12a c  + 9a
+--R                                          atan(---------------------)
+--R                  +------------------+                     +-+
+--R           4+-+3 4|  4      2 2     4                 2a c\|6
+--R         12\|6   \|4c  + 12a c  + 9a  sin(---------------------------)
+--R                                                       2
+--R      *
+--R         atan
+--R                                      +------------------+
+--R                        2      3  +-+4|  4      2 2     4
+--R                  (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  sin(---------------------------)
+--R                                   2
+--R              + 
+--R                -
+--R                         +------------------+ +------------------+
+--R                         |  4      2 2     4 4|  4      2 2     4
+--R                     12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     cos(---------------------------)
+--R                                      2
+--R           /
+--R                      +------------------+ +------------------+
+--R                      |  4      2 2     4 4|  4      2 2     4
+--R                  12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  sin(---------------------------)
+--R                                   2
+--R              + 
+--R                                      +------------------+
+--R                        2      3  +-+4|  4      2 2     4
+--R                  (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R               *
+--R                            +------------------+
+--R                            |  4      2 2     4
+--R                           \|4c  - 12a c  + 9a
+--R                      atan(---------------------)
+--R                                       +-+
+--R                                  2a c\|6
+--R                  cos(---------------------------)
+--R                                   2
+--R              + 
+--R                     4     4   +-+4+---+
+--R                (- 4c  + 9a )x\|6 \|216
+--R     + 
+--R       -
+--R                                                   +------------------+
+--R                                                   |  4      2 2     4
+--R                                                  \|4c  - 12a c  + 9a
+--R                                             atan(---------------------)
+--R                     +------------------+                     +-+
+--R              4+-+3 4|  4      2 2     4                 2a c\|6
+--R            12\|6   \|4c  + 12a c  + 9a  sin(---------------------------)
+--R                                                          2
+--R         *
+--R            atan
+--R                                         +------------------+
+--R                           2      3  +-+4|  4      2 2     4
+--R                     (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     sin(---------------------------)
+--R                                      2
+--R                 + 
+--R                   -
+--R                            +------------------+ +------------------+
+--R                            |  4      2 2     4 4|  4      2 2     4
+--R                        12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                     *
+--R                                  +------------------+
+--R                                  |  4      2 2     4
+--R                                 \|4c  - 12a c  + 9a
+--R                            atan(---------------------)
+--R                                             +-+
+--R                                        2a c\|6
+--R                        cos(---------------------------)
+--R                                         2
+--R              /
+--R                         +------------------+ +------------------+
+--R                         |  4      2 2     4 4|  4      2 2     4
+--R                     12c\|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     sin(---------------------------)
+--R                                      2
+--R                 + 
+--R                                         +------------------+
+--R                           2      3  +-+4|  4      2 2     4
+--R                     (12a c  - 18a )\|6 \|4c  + 12a c  + 9a
+--R                  *
+--R                               +------------------+
+--R                               |  4      2 2     4
+--R                              \|4c  - 12a c  + 9a
+--R                         atan(---------------------)
+--R                                          +-+
+--R                                     2a c\|6
+--R                     cos(---------------------------)
+--R                                      2
+--R                 + 
+--R                      4     4   +-+4+---+
+--R                   (4c  - 9a )x\|6 \|216
+--R     + 
+--R             +-+      4+---+      4+-+3 4+-+   2 +-+    +-+
+--R       (- 3a\|6  + 6c)\|216 log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R            4+-+3 4+---+      4
+--R       - 2d \|6   \|216 log(3x  + 2)
+--R     + 
+--R           +-+      4+---+        4+-+3 4+-+   2 +-+    +-+
+--R       (3a\|6  - 6c)\|216 log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R             +-+       4+---+      4+-+
+--R       (- 6a\|6  - 12c)\|216 atan(x\|6  + 1)
+--R     + 
+--R             +-+       4+---+      4+-+
+--R       (- 6a\|6  - 12c)\|216 atan(x\|6  - 1)
+--R  /
+--R       4+-+3 4+---+
+--R     24\|6   \|216
+--R                                                    Type: Expression(Integer)
+--E 657
+
+--S 658 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                               6       3 4       5 2       7  6
+--R                       (- 96a c  - 144a c  + 216a c  + 324a )x
+--R                     + 
+--R                               6      3 4       5 2       7  2
+--R                       (- 64a c  - 96a c  + 144a c  + 216a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                             6       3 4       5 2       7  4        6      3 4
+--R                       (96a c  + 144a c  - 216a c  - 324a )x  + 64a c  + 96a c
+--R                     + 
+--R                             5 2       7
+--R                       - 144a c  - 216a
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                            7       2 5       4 3       6   6
+--R                       (192c  + 288a c  - 432a c  - 648a c)x
+--R                     + 
+--R                            7       2 5       4 3       6   2
+--R                       (128c  + 192a c  - 288a c  - 432a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                              7       2 5       4 3       6   4       7
+--R                       (- 192c  - 288a c  + 432a c  + 648a c)x  - 128c
+--R                     + 
+--R                             2 5       4 3       6
+--R                       - 192a c  + 288a c  + 432a c
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                            6       3 4       5 2        7  4 4+-+2 4+-+2
+--R                   (- 384a c  - 576a c  + 864a c  + 1296a )x  \|2   \|3
+--R                 + 
+--R                          6       3 4       5 2        7  4 +-+ +-+
+--R                   (384a c  + 576a c  - 864a c  - 1296a )x \|2 \|3
+--R                 + 
+--R                          6       3 4        5 2        7  6
+--R                   (576a c  + 864a c  - 1296a c  - 1944a )x
+--R                 + 
+--R                          6       3 4       5 2        7  2
+--R                   (384a c  + 576a c  - 864a c  - 1296a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                           6        3 4        5 2        7  6
+--R                   (2304a c  + 3456a c  - 5184a c  - 7776a )x
+--R                 + 
+--R                           6        2 4        4 2        6    5
+--R                   (- 1536c  - 2304a c  + 3456a c  + 5184a )d x
+--R                 + 
+--R                          7        2 5        4 3        6   4
+--R                   (- 768c  - 1152a c  + 1728a c  + 2592a c)x
+--R                 + 
+--R                           6        3 4        5 2        7  2
+--R                   (1536a c  + 2304a c  - 3456a c  - 5184a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                             6        3 4        5 2        7  6
+--R                   (- 2304a c  - 3456a c  + 5184a c  + 7776a )x
+--R                 + 
+--R                         6        2 4        4 2        6    5
+--R                   (1536c  + 2304a c  - 3456a c  - 5184a )d x
+--R                 + 
+--R                        7        2 5        4 3        6   4
+--R                   (768c  + 1152a c  - 1728a c  - 2592a c)x
+--R                 + 
+--R                             6        3 4        5 2        7  2
+--R                   (- 1536a c  - 2304a c  + 3456a c  + 5184a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                         6        3 4        5 2         7  8
+--R               (- 3456a c  - 5184a c  + 7776a c  + 11664a )x
+--R             + 
+--R                     6        2 4        4 2        6    7
+--R               (2304c  + 3456a c  - 5184a c  - 7776a )d x
+--R             + 
+--R                     7        2 5        4 3        6   6
+--R               (1152c  + 1728a c  - 2592a c  - 3888a c)x
+--R             + 
+--R                         6        3 4         5 2         7  4
+--R               (- 4608a c  - 6912a c  + 10368a c  + 15552a )x
+--R             + 
+--R                     6        2 4        4 2        6    3
+--R               (1536c  + 2304a c  - 3456a c  - 5184a )d x
+--R             + 
+--R                    7        2 5        4 3        6   2          6        3 4
+--R               (768c  + 1152a c  - 1728a c  - 2592a c)x  - 1536a c  - 2304a c
+--R             + 
+--R                    5 2        7
+--R               3456a c  + 5184a
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                        6        3 4        5 2        7  2 4+-+2 4+-+2
+--R               (- 768a c  - 1152a c  + 1728a c  + 2592a )x  \|2   \|3
+--R             + 
+--R                      6        3 4        5 2        7  2 +-+ +-+
+--R               (768a c  + 1152a c  - 1728a c  - 2592a )x \|2 \|3
+--R             + 
+--R                       6        3 4        5 2        7  4         6        3 4
+--R               (1152a c  + 1728a c  - 2592a c  - 3888a )x  + 768a c  + 1152a c
+--R             + 
+--R                      5 2        7
+--R               - 1728a c  - 2592a
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                   7        2 5        4 3        6   2 4+-+2 4+-+2
+--R           (- 1536c  - 2304a c  + 3456a c  + 5184a c)x  \|2   \|3
+--R         + 
+--R                 7        2 5        4 3        6   2 +-+ +-+
+--R           (1536c  + 2304a c  - 3456a c  - 5184a c)x \|2 \|3
+--R         + 
+--R                 7        2 5        4 3        6   4        7        2 5
+--R           (2304c  + 3456a c  - 5184a c  - 7776a c)x  + 1536c  + 2304a c
+--R         + 
+--R                  4 3        6
+--R           - 3456a c  - 5184a c
+--R      *
+--R                          +------------------+  8
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R         4+---+2                2a c\|6
+--R         \|216  sin(---------------------------)
+--R                                 2
+--R     + 
+--R                                    6       3 4       5 2        7  6
+--R                           (- 384a c  - 576a c  + 864a c  + 1296a )x
+--R                         + 
+--R                                    6       3 4       5 2       7  2
+--R                           (- 256a c  - 384a c  + 576a c  + 864a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  6       3 4       5 2        7  4         6
+--R                           (384a c  + 576a c  - 864a c  - 1296a )x  + 256a c
+--R                         + 
+--R                               3 4       5 2       7
+--R                           384a c  - 576a c  - 864a
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                7        2 5        4 3        6   6
+--R                           (768c  + 1152a c  - 1728a c  - 2592a c)x
+--R                         + 
+--R                                7       2 5        4 3        6   2
+--R                           (512c  + 768a c  - 1152a c  - 1728a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  7        2 5        4 3        6   4       7
+--R                           (- 768c  - 1152a c  + 1728a c  + 2592a c)x  - 512c
+--R                         + 
+--R                                 2 5        4 3        6
+--R                           - 768a c  + 1152a c  + 1728a c
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                 6        3 4        5 2        7  4 4+-+2 4+-+2
+--R                       (- 1536a c  - 2304a c  + 3456a c  + 5184a )x  \|2   \|3
+--R                     + 
+--R                               6        3 4        5 2        7  4 +-+ +-+
+--R                       (1536a c  + 2304a c  - 3456a c  - 5184a )x \|2 \|3
+--R                     + 
+--R                               6        3 4        5 2        7  6
+--R                       (2304a c  + 3456a c  - 5184a c  - 7776a )x
+--R                     + 
+--R                               6        3 4        5 2        7  2
+--R                       (1536a c  + 2304a c  - 3456a c  - 5184a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                               6         3 4         5 2         7  6
+--R                       (9216a c  + 13824a c  - 20736a c  - 31104a )x
+--R                     + 
+--R                               6        2 4         4 2         6    5
+--R                       (- 6144c  - 9216a c  + 13824a c  + 20736a )d x
+--R                     + 
+--R                               7        2 5        4 3         6   4
+--R                       (- 3072c  - 4608a c  + 6912a c  + 10368a c)x
+--R                     + 
+--R                               6        3 4         5 2         7  2
+--R                       (6144a c  + 9216a c  - 13824a c  - 20736a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                 6         3 4         5 2         7  6
+--R                       (- 9216a c  - 13824a c  + 20736a c  + 31104a )x
+--R                     + 
+--R                             6        2 4         4 2         6    5
+--R                       (6144c  + 9216a c  - 13824a c  - 20736a )d x
+--R                     + 
+--R                             7        2 5        4 3         6   4
+--R                       (3072c  + 4608a c  - 6912a c  - 10368a c)x
+--R                     + 
+--R                                 6        3 4         5 2         7  2
+--R                       (- 6144a c  - 9216a c  + 13824a c  + 20736a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                              6         3 4         5 2         7  8
+--R                   (- 13824a c  - 20736a c  + 31104a c  + 46656a )x
+--R                 + 
+--R                         6         2 4         4 2         6    7
+--R                   (9216c  + 13824a c  - 20736a c  - 31104a )d x
+--R                 + 
+--R                         7        2 5         4 3         6   6
+--R                   (4608c  + 6912a c  - 10368a c  - 15552a c)x
+--R                 + 
+--R                              6         3 4         5 2         7  4
+--R                   (- 18432a c  - 27648a c  + 41472a c  + 62208a )x
+--R                 + 
+--R                         6        2 4         4 2         6    3
+--R                   (6144c  + 9216a c  - 13824a c  - 20736a )d x
+--R                 + 
+--R                         7        2 5        4 3         6   2          6
+--R                   (3072c  + 4608a c  - 6912a c  - 10368a c)x  - 6144a c
+--R                 + 
+--R                          3 4         5 2         7
+--R                   - 9216a c  + 13824a c  + 20736a
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                             6        3 4        5 2         7  2 4+-+2 4+-+2
+--R                   (- 3072a c  - 4608a c  + 6912a c  + 10368a )x  \|2   \|3
+--R                 + 
+--R                           6        3 4        5 2         7  2 +-+ +-+
+--R                   (3072a c  + 4608a c  - 6912a c  - 10368a )x \|2 \|3
+--R                 + 
+--R                           6        3 4         5 2         7  4          6
+--R                   (4608a c  + 6912a c  - 10368a c  - 15552a )x  + 3072a c
+--R                 + 
+--R                        3 4        5 2         7
+--R                   4608a c  - 6912a c  - 10368a
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                       7        2 5         4 3         6   2 4+-+2 4+-+2
+--R               (- 6144c  - 9216a c  + 13824a c  + 20736a c)x  \|2   \|3
+--R             + 
+--R                     7        2 5         4 3         6   2 +-+ +-+
+--R               (6144c  + 9216a c  - 13824a c  - 20736a c)x \|2 \|3
+--R             + 
+--R                     7         2 5         4 3         6   4        7        2 5
+--R               (9216c  + 13824a c  - 20736a c  - 31104a c)x  + 6144c  + 9216a c
+--R             + 
+--R                       4 3         6
+--R               - 13824a c  - 20736a c
+--R          *
+--R                              +------------------+  2
+--R                              |  4      2 2     4
+--R                             \|4c  - 12a c  + 9a
+--R                        atan(---------------------)
+--R                                         +-+
+--R             4+---+2                2a c\|6
+--R             \|216  cos(---------------------------)
+--R                                     2
+--R         + 
+--R                                   4         3 2        5  8
+--R                           (3456a c  - 10368a c  + 7776a )x
+--R                         + 
+--R                                   4        3 2        5  4
+--R                           (2304a c  - 6912a c  + 5184a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                     4         3 2        5  6
+--R                           (- 3456a c  + 10368a c  - 7776a )x
+--R                         + 
+--R                                     4        3 2        5  2
+--R                           (- 2304a c  + 6912a c  - 5184a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                   5         2 3         4   8
+--R                           (- 6912c  + 20736a c  - 15552a c)x
+--R                         + 
+--R                                   5         2 3         4   4
+--R                           (- 4608c  + 13824a c  - 10368a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                 5         2 3         4   6
+--R                           (6912c  - 20736a c  + 15552a c)x
+--R                         + 
+--R                                 5         2 3         4   2
+--R                           (4608c  - 13824a c  + 10368a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                4         3 2         5  6 4+-+2 4+-+2
+--R                       (13824a c  - 41472a c  + 31104a )x  \|2   \|3
+--R                     + 
+--R                                  4         3 2         5  6 +-+ +-+
+--R                       (- 13824a c  + 41472a c  - 31104a )x \|2 \|3
+--R                     + 
+--R                                  4         3 2         5  8
+--R                       (- 20736a c  + 62208a c  - 46656a )x
+--R                     + 
+--R                                  4         3 2         5  4
+--R                       (- 13824a c  + 41472a c  - 31104a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                  4          3 2          5  8
+--R                       (- 20736a c  + 124416a c  - 139968a )x
+--R                     + 
+--R                              4          2 2         4    7
+--R                       (41472c  - 124416a c  + 93312a )d x
+--R                     + 
+--R                              5         2 3         4   6
+--R                       (27648c  - 82944a c  + 62208a c)x
+--R                     + 
+--R                                  4         3 2         5  4
+--R                       (- 13824a c  + 82944a c  - 93312a )x
+--R                     + 
+--R                               4         2 2         4    3
+--R                       (- 9216c  + 27648a c  - 20736a )d x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                4          3 2          5  8
+--R                       (20736a c  - 124416a c  + 139968a )x
+--R                     + 
+--R                                4          2 2         4    7
+--R                       (- 41472c  + 124416a c  - 93312a )d x
+--R                     + 
+--R                                5         2 3         4   6
+--R                       (- 27648c  + 82944a c  - 62208a c)x
+--R                     + 
+--R                                4         3 2         5  4
+--R                       (13824a c  - 82944a c  + 93312a )x
+--R                     + 
+--R                             4         2 2         4    3
+--R                       (9216c  - 27648a c  + 20736a )d x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                            4          3 2          5  10
+--R                   (31104a c  - 186624a c  + 209952a )x
+--R                 + 
+--R                            4          2 2          4    9
+--R                   (- 62208c  + 186624a c  - 139968a )d x
+--R                 + 
+--R                            5          2 3         4   8
+--R                   (- 41472c  + 124416a c  - 93312a c)x
+--R                 + 
+--R                            4          3 2          5  6
+--R                   (41472a c  - 248832a c  + 279936a )x
+--R                 + 
+--R                            4         2 2         4    5
+--R                   (- 27648c  + 82944a c  - 62208a )d x
+--R                 + 
+--R                            5         2 3         4   4
+--R                   (- 27648c  + 82944a c  - 62208a c)x
+--R                 + 
+--R                            4         3 2         5  2
+--R                   (13824a c  - 82944a c  + 93312a )x
+--R                 + 
+--R                         4         2 2         4
+--R                   (9216c  - 27648a c  + 20736a )d x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                            4         3 2         5  4 4+-+2 4+-+2
+--R                   (27648a c  - 82944a c  + 62208a )x  \|2   \|3
+--R                 + 
+--R                              4         3 2         5  4 +-+ +-+
+--R                   (- 27648a c  + 82944a c  - 62208a )x \|2 \|3
+--R                 + 
+--R                              4          3 2         5  6
+--R                   (- 41472a c  + 124416a c  - 93312a )x
+--R                 + 
+--R                              4         3 2         5  2
+--R                   (- 27648a c  + 82944a c  - 62208a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      5          2 3          4   4 4+-+2 4+-+2
+--R               (55296c  - 165888a c  + 124416a c)x  \|2   \|3
+--R             + 
+--R                        5          2 3          4   4 +-+ +-+
+--R               (- 55296c  + 165888a c  - 124416a c)x \|2 \|3
+--R             + 
+--R                        5          2 3          4   6
+--R               (- 82944c  + 248832a c  - 186624a c)x
+--R             + 
+--R                        5          2 3          4   2
+--R               (- 55296c  + 165888a c  - 124416a c)x
+--R          *
+--R              +------------------+2
+--R             4|  4      2 2     4
+--R             \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+  6
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                             2 8          2 4 4+-+3 +-+
+--R                   (- 6912a c x  - 4608a c x )\|2  \|3
+--R                 + 
+--R                           2 6          2 2  +-+4+-+3
+--R                   (6912a c x  + 4608a c x )\|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                          2   8         2   4 4+-+3 +-+
+--R                   (20736a c x  + 13824a c x )\|2  \|3
+--R                 + 
+--R                            2   6         2   2  +-+4+-+3
+--R                   (- 20736a c x  - 13824a c x )\|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                               3         2   8               7           2 6
+--R                       (- 6912c  - 51840a c)x  + 41472a c d x  + 27648a c x
+--R                     + 
+--R                               3         2   4              3
+--R                       (- 4608c  - 34560a c)x  - 9216a c d x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                             3         2   8               7           2 6
+--R                       (6912c  + 51840a c)x  - 41472a c d x  - 27648a c x
+--R                     + 
+--R                             3         2   4              3
+--R                       (4608c  + 34560a c)x  + 9216a c d x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                          3         2   10               9           2 8
+--R                   (10368c  + 77760a c)x   - 62208a c d x  - 41472a c x
+--R                 + 
+--R                          3          2   6               5           2 4
+--R                   (13824c  + 103680a c)x  - 27648a c d x  - 27648a c x
+--R                 + 
+--R                         3         2   2
+--R                   (4608c  + 34560a c)x  + 9216a c d x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                     2   6 4+-+2 4+-+2       2   6 +-+ +-+          2   8
+--R               82944a c x  \|2   \|3 - 82944a c x \|2 \|3  - 124416a c x
+--R             + 
+--R                       2   4
+--R               - 82944a c x
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                       2 4 4+-+2 4+-+2         2 4 +-+ +-+           2 6
+--R               55296a c x  \|2   \|3 - 55296a c x \|2 \|3  - 82944a c x
+--R             + 
+--R                         2 2
+--R               - 55296a c x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                  2   4 4+-+2 4+-+2        2   4 +-+ +-+          2   6
+--R           165888a c x  \|2   \|3 - 165888a c x \|2 \|3  - 248832a c x
+--R         + 
+--R                    2   2
+--R           - 165888a c x
+--R      *
+--R          +------------------+ +------------------+2
+--R          |  4      2 2     4 4|  4      2 2     4
+--R         \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+            +------------------+  5
+--R                   |  4      2 2     4             |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a             \|4c  - 12a c  + 9a
+--R             atan(---------------------)     atan(---------------------)
+--R                              +-+                             +-+
+--R                         2a c\|6                         2a c\|6
+--R         cos(---------------------------)sin(---------------------------)
+--R                          2                               2
+--R     + 
+--R                                    6       3 4        5 2        7  6
+--R                           (- 576a c  - 864a c  + 1296a c  + 1944a )x
+--R                         + 
+--R                                    6       3 4       5 2        7  2
+--R                           (- 384a c  - 576a c  + 864a c  + 1296a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  6       3 4        5 2        7  4         6
+--R                           (576a c  + 864a c  - 1296a c  - 1944a )x  + 384a c
+--R                         + 
+--R                               3 4       5 2        7
+--R                           576a c  - 864a c  - 1296a
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                 7        2 5        4 3        6   6
+--R                           (1152c  + 1728a c  - 2592a c  - 3888a c)x
+--R                         + 
+--R                                7        2 5        4 3        6   2
+--R                           (768c  + 1152a c  - 1728a c  - 2592a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                   7        2 5        4 3        6   4       7
+--R                           (- 1152c  - 1728a c  + 2592a c  + 3888a c)x  - 768c
+--R                         + 
+--R                                  2 5        4 3        6
+--R                           - 1152a c  + 1728a c  + 2592a c
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                 6        3 4        5 2        7  4 4+-+2 4+-+2
+--R                       (- 2304a c  - 3456a c  + 5184a c  + 7776a )x  \|2   \|3
+--R                     + 
+--R                               6        3 4        5 2        7  4 +-+ +-+
+--R                       (2304a c  + 3456a c  - 5184a c  - 7776a )x \|2 \|3
+--R                     + 
+--R                               6        3 4        5 2         7  6
+--R                       (3456a c  + 5184a c  - 7776a c  - 11664a )x
+--R                     + 
+--R                               6        3 4        5 2        7  2
+--R                       (2304a c  + 3456a c  - 5184a c  - 7776a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                6         3 4         5 2         7  6
+--R                       (13824a c  + 20736a c  - 31104a c  - 46656a )x
+--R                     + 
+--R                               6         2 4         4 2         6    5
+--R                       (- 9216c  - 13824a c  + 20736a c  + 31104a )d x
+--R                     + 
+--R                               7        2 5         4 3         6   4
+--R                       (- 4608c  - 6912a c  + 10368a c  + 15552a c)x
+--R                     + 
+--R                               6         3 4         5 2         7  2
+--R                       (9216a c  + 13824a c  - 20736a c  - 31104a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                  6         3 4         5 2         7  6
+--R                       (- 13824a c  - 20736a c  + 31104a c  + 46656a )x
+--R                     + 
+--R                             6         2 4         4 2         6    5
+--R                       (9216c  + 13824a c  - 20736a c  - 31104a )d x
+--R                     + 
+--R                             7        2 5         4 3         6   4
+--R                       (4608c  + 6912a c  - 10368a c  - 15552a c)x
+--R                     + 
+--R                                 6         3 4         5 2         7  2
+--R                       (- 9216a c  - 13824a c  + 20736a c  + 31104a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                              6         3 4         5 2         7  8
+--R                   (- 20736a c  - 31104a c  + 46656a c  + 69984a )x
+--R                 + 
+--R                          6         2 4         4 2         6    7
+--R                   (13824c  + 20736a c  - 31104a c  - 46656a )d x
+--R                 + 
+--R                         7         2 5         4 3         6   6
+--R                   (6912c  + 10368a c  - 15552a c  - 23328a c)x
+--R                 + 
+--R                              6         3 4         5 2         7  4
+--R                   (- 27648a c  - 41472a c  + 62208a c  + 93312a )x
+--R                 + 
+--R                         6         2 4         4 2         6    3
+--R                   (9216c  + 13824a c  - 20736a c  - 31104a )d x
+--R                 + 
+--R                         7        2 5         4 3         6   2          6
+--R                   (4608c  + 6912a c  - 10368a c  - 15552a c)x  - 9216a c
+--R                 + 
+--R                           3 4         5 2         7
+--R                   - 13824a c  + 20736a c  + 31104a
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                             6        3 4         5 2         7  2 4+-+2 4+-+2
+--R                   (- 4608a c  - 6912a c  + 10368a c  + 15552a )x  \|2   \|3
+--R                 + 
+--R                           6        3 4         5 2         7  2 +-+ +-+
+--R                   (4608a c  + 6912a c  - 10368a c  - 15552a )x \|2 \|3
+--R                 + 
+--R                           6         3 4         5 2         7  4          6
+--R                   (6912a c  + 10368a c  - 15552a c  - 23328a )x  + 4608a c
+--R                 + 
+--R                        3 4         5 2         7
+--R                   6912a c  - 10368a c  - 15552a
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                       7         2 5         4 3         6   2 4+-+2 4+-+2
+--R               (- 9216c  - 13824a c  + 20736a c  + 31104a c)x  \|2   \|3
+--R             + 
+--R                     7         2 5         4 3         6   2 +-+ +-+
+--R               (9216c  + 13824a c  - 20736a c  - 31104a c)x \|2 \|3
+--R             + 
+--R                      7         2 5         4 3         6   4        7
+--R               (13824c  + 20736a c  - 31104a c  - 46656a c)x  + 9216c
+--R             + 
+--R                     2 5         4 3         6
+--R               13824a c  - 20736a c  - 31104a c
+--R          *
+--R                              +------------------+  4
+--R                              |  4      2 2     4
+--R                             \|4c  - 12a c  + 9a
+--R                        atan(---------------------)
+--R                                         +-+
+--R             4+---+2                2a c\|6
+--R             \|216  cos(---------------------------)
+--R                                     2
+--R         + 
+--R                                   4         3 2        5  8
+--R                           (3456a c  - 10368a c  + 7776a )x
+--R                         + 
+--R                                   4        3 2        5  4
+--R                           (2304a c  - 6912a c  + 5184a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                     4         3 2        5  6
+--R                           (- 3456a c  + 10368a c  - 7776a )x
+--R                         + 
+--R                                     4        3 2        5  2
+--R                           (- 2304a c  + 6912a c  - 5184a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                   5         2 3         4   8
+--R                           (- 6912c  + 20736a c  - 15552a c)x
+--R                         + 
+--R                                   5         2 3         4   4
+--R                           (- 4608c  + 13824a c  - 10368a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                 5         2 3         4   6
+--R                           (6912c  - 20736a c  + 15552a c)x
+--R                         + 
+--R                                 5         2 3         4   2
+--R                           (4608c  - 13824a c  + 10368a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                4         3 2         5  6 4+-+2 4+-+2
+--R                       (13824a c  - 41472a c  + 31104a )x  \|2   \|3
+--R                     + 
+--R                                  4         3 2         5  6 +-+ +-+
+--R                       (- 13824a c  + 41472a c  - 31104a )x \|2 \|3
+--R                     + 
+--R                                  4         3 2         5  8
+--R                       (- 20736a c  + 62208a c  - 46656a )x
+--R                     + 
+--R                                  4         3 2         5  4
+--R                       (- 13824a c  + 41472a c  - 31104a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                  4          3 2          5  8
+--R                       (- 20736a c  + 124416a c  - 139968a )x
+--R                     + 
+--R                              4          2 2         4    7
+--R                       (41472c  - 124416a c  + 93312a )d x
+--R                     + 
+--R                              5         2 3         4   6
+--R                       (27648c  - 82944a c  + 62208a c)x
+--R                     + 
+--R                                  4         3 2         5  4
+--R                       (- 13824a c  + 82944a c  - 93312a )x
+--R                     + 
+--R                               4         2 2         4    3
+--R                       (- 9216c  + 27648a c  - 20736a )d x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                4          3 2          5  8
+--R                       (20736a c  - 124416a c  + 139968a )x
+--R                     + 
+--R                                4          2 2         4    7
+--R                       (- 41472c  + 124416a c  - 93312a )d x
+--R                     + 
+--R                                5         2 3         4   6
+--R                       (- 27648c  + 82944a c  - 62208a c)x
+--R                     + 
+--R                                4         3 2         5  4
+--R                       (13824a c  - 82944a c  + 93312a )x
+--R                     + 
+--R                             4         2 2         4    3
+--R                       (9216c  - 27648a c  + 20736a )d x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                            4          3 2          5  10
+--R                   (31104a c  - 186624a c  + 209952a )x
+--R                 + 
+--R                            4          2 2          4    9
+--R                   (- 62208c  + 186624a c  - 139968a )d x
+--R                 + 
+--R                            5          2 3         4   8
+--R                   (- 41472c  + 124416a c  - 93312a c)x
+--R                 + 
+--R                            4          3 2          5  6
+--R                   (41472a c  - 248832a c  + 279936a )x
+--R                 + 
+--R                            4         2 2         4    5
+--R                   (- 27648c  + 82944a c  - 62208a )d x
+--R                 + 
+--R                            5         2 3         4   4
+--R                   (- 27648c  + 82944a c  - 62208a c)x
+--R                 + 
+--R                            4         3 2         5  2
+--R                   (13824a c  - 82944a c  + 93312a )x
+--R                 + 
+--R                         4         2 2         4
+--R                   (9216c  - 27648a c  + 20736a )d x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                            4         3 2         5  4 4+-+2 4+-+2
+--R                   (27648a c  - 82944a c  + 62208a )x  \|2   \|3
+--R                 + 
+--R                              4         3 2         5  4 +-+ +-+
+--R                   (- 27648a c  + 82944a c  - 62208a )x \|2 \|3
+--R                 + 
+--R                              4          3 2         5  6
+--R                   (- 41472a c  + 124416a c  - 93312a )x
+--R                 + 
+--R                              4         3 2         5  2
+--R                   (- 27648a c  + 82944a c  - 62208a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      5          2 3          4   4 4+-+2 4+-+2
+--R               (55296c  - 165888a c  + 124416a c)x  \|2   \|3
+--R             + 
+--R                        5          2 3          4   4 +-+ +-+
+--R               (- 55296c  + 165888a c  - 124416a c)x \|2 \|3
+--R             + 
+--R                        5          2 3          4   6
+--R               (- 82944c  + 248832a c  - 186624a c)x
+--R             + 
+--R                        5          2 3          4   2
+--R               (- 55296c  + 165888a c  - 124416a c)x
+--R          *
+--R                                             +------------------+  2
+--R                                             |  4      2 2     4
+--R                                            \|4c  - 12a c  + 9a
+--R                                       atan(---------------------)
+--R              +------------------+2                     +-+
+--R             4|  4      2 2     4                  2a c\|6
+--R             \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                    2
+--R         + 
+--R                                    6        3 4        5 2        7  10
+--R                           (- 864a c  + 2160a c  - 3240a c  + 2916a )x
+--R                         + 
+--R                                    6        3 4        5 2        7  6
+--R                           (- 576a c  + 1440a c  - 2160a c  + 1944a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  6        3 4        5 2        7  8
+--R                           (864a c  - 2160a c  + 3240a c  - 2916a )x
+--R                         + 
+--R                                  6        3 4        5 2        7  4
+--R                           (576a c  - 1440a c  + 2160a c  - 1944a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                 7        2 5        4 3        6   10
+--R                           (1728c  - 4320a c  + 6480a c  - 5832a c)x
+--R                         + 
+--R                                 7        2 5        4 3        6   6
+--R                           (1152c  - 2880a c  + 4320a c  - 3888a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                   7        2 5        4 3        6   8
+--R                           (- 1728c  + 4320a c  - 6480a c  + 5832a c)x
+--R                         + 
+--R                                   7        2 5        4 3        6   4
+--R                           (- 1152c  + 2880a c  - 4320a c  + 3888a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                 6        3 4         5 2         7  8 4+-+2 4+-+2
+--R                       (- 3456a c  + 8640a c  - 12960a c  + 11664a )x  \|2   \|3
+--R                     + 
+--R                               6        3 4         5 2         7  8 +-+ +-+
+--R                       (3456a c  - 8640a c  + 12960a c  - 11664a )x \|2 \|3
+--R                     + 
+--R                               6         3 4         5 2         7  10
+--R                       (5184a c  - 12960a c  + 19440a c  - 17496a )x
+--R                     + 
+--R                               6        3 4         5 2         7  6
+--R                       (3456a c  - 8640a c  + 12960a c  - 11664a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                 6         3 4        5 2         7  10
+--R                       (- 3456a c  + 15552a c  + 7776a c  - 34992a )x
+--R                     + 
+--R                               6         2 4         4 2         6    9
+--R                       (- 6912c  + 17280a c  - 25920a c  + 23328a )d x
+--R                     + 
+--R                               7         2 5         4 3         6   8
+--R                       (- 6912c  + 17280a c  - 25920a c  + 23328a c)x
+--R                     + 
+--R                                 6         3 4        5 2         7  6
+--R                       (- 2304a c  + 10368a c  + 5184a c  - 23328a )x
+--R                     + 
+--R                             6         2 4         4 2         6    5
+--R                       (4608c  - 11520a c  + 17280a c  - 15552a )d x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                               6         3 4        5 2         7  10
+--R                       (3456a c  - 15552a c  - 7776a c  + 34992a )x
+--R                     + 
+--R                             6         2 4         4 2         6    9
+--R                       (6912c  - 17280a c  + 25920a c  - 23328a )d x
+--R                     + 
+--R                             7         2 5         4 3         6   8
+--R                       (6912c  - 17280a c  + 25920a c  - 23328a c)x
+--R                     + 
+--R                               6         3 4        5 2         7  6
+--R                       (2304a c  - 10368a c  - 5184a c  + 23328a )x
+--R                     + 
+--R                               6         2 4         4 2         6    5
+--R                       (- 4608c  + 11520a c  - 17280a c  + 15552a )d x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                           6         3 4         5 2         7  12
+--R                   (5184a c  - 23328a c  - 11664a c  + 52488a )x
+--R                 + 
+--R                          6         2 4         4 2         6    11
+--R                   (10368c  - 25920a c  + 38880a c  - 34992a )d x
+--R                 + 
+--R                          7         2 5         4 3         6   10
+--R                   (10368c  - 25920a c  + 38880a c  - 34992a c)x
+--R                 + 
+--R                           6         3 4         5 2         7  8
+--R                   (6912a c  - 31104a c  - 15552a c  + 69984a )x
+--R                 + 
+--R                         7         2 5         4 3         6   6
+--R                   (6912c  - 17280a c  + 25920a c  - 23328a c)x
+--R                 + 
+--R                           6         3 4        5 2         7  4
+--R                   (2304a c  - 10368a c  - 5184a c  + 23328a )x
+--R                 + 
+--R                           6         2 4         4 2         6    3
+--R                   (- 4608c  + 11520a c  - 17280a c  + 15552a )d x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                             6         3 4         5 2         7  6 4+-+2 4+-+2
+--R                   (- 6912a c  + 17280a c  - 25920a c  + 23328a )x  \|2   \|3
+--R                 + 
+--R                           6         3 4         5 2         7  6 +-+ +-+
+--R                   (6912a c  - 17280a c  + 25920a c  - 23328a )x \|2 \|3
+--R                 + 
+--R                            6         3 4         5 2         7  8
+--R                   (10368a c  - 25920a c  + 38880a c  - 34992a )x
+--R                 + 
+--R                           6         3 4         5 2         7  4
+--R                   (6912a c  - 17280a c  + 25920a c  - 23328a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                        7         2 5         4 3         6   6 4+-+2 4+-+2
+--R               (- 13824c  + 34560a c  - 51840a c  + 46656a c)x  \|2   \|3
+--R             + 
+--R                      7         2 5         4 3         6   6 +-+ +-+
+--R               (13824c  - 34560a c  + 51840a c  - 46656a c)x \|2 \|3
+--R             + 
+--R                      7         2 5         4 3         6   8
+--R               (20736c  - 51840a c  + 77760a c  - 69984a c)x
+--R             + 
+--R                      7         2 5         4 3         6   4
+--R               (13824c  - 34560a c  + 51840a c  - 46656a c)x
+--R          *
+--R             4+---+2
+--R             \|216
+--R      *
+--R                   +------------------+  4
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                  2 8          2 4 4+-+3 +-+
+--R                       (- 13824a c x  - 9216a c x )\|2  \|3
+--R                     + 
+--R                                2 6          2 2  +-+4+-+3
+--R                       (13824a c x  + 9216a c x )\|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                              2   8         2   4 4+-+3 +-+
+--R                       (41472a c x  + 27648a c x )\|2  \|3
+--R                     + 
+--R                                2   6         2   2  +-+4+-+3
+--R                       (- 41472a c x  - 27648a c x )\|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                    3          2   8               7
+--R                           (- 13824c  - 103680a c)x  + 82944a c d x
+--R                         + 
+--R                                 2 6           3         2   4               3
+--R                         55296a c x  + (- 9216c  - 69120a c)x  - 18432a c d x
+--R                      *
+--R                         4+-+2 4+-+2
+--R                         \|2   \|3
+--R                     + 
+--R                                  3          2   8               7           2 6
+--R                           (13824c  + 103680a c)x  - 82944a c d x  - 55296a c x
+--R                         + 
+--R                                 3         2   4               3
+--R                           (9216c  + 69120a c)x  + 18432a c d x
+--R                      *
+--R                          +-+ +-+
+--R                         \|2 \|3
+--R                     + 
+--R                              3          2   10                9           2 8
+--R                       (20736c  + 155520a c)x   - 124416a c d x  - 82944a c x
+--R                     + 
+--R                              3          2   6               5           2 4
+--R                       (27648c  + 207360a c)x  - 55296a c d x  - 55296a c x
+--R                     + 
+--R                             3         2   2
+--R                       (9216c  + 69120a c)x  + 18432a c d x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                          2   6 4+-+2 4+-+2        2   6 +-+ +-+          2   8
+--R                   165888a c x  \|2   \|3 - 165888a c x \|2 \|3  - 248832a c x
+--R                 + 
+--R                            2   4
+--R                   - 165888a c x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                            2 4 4+-+2 4+-+2          2 4 +-+ +-+            2 6
+--R                   110592a c x  \|2   \|3 - 110592a c x \|2 \|3  - 165888a c x
+--R                 + 
+--R                              2 2
+--R                   - 110592a c x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      2   4 4+-+2 4+-+2        2   4 +-+ +-+          2   6
+--R               331776a c x  \|2   \|3 - 331776a c x \|2 \|3  - 497664a c x
+--R             + 
+--R                        2   2
+--R               - 331776a c x
+--R          *
+--R              +------------------+ +------------------+2
+--R              |  4      2 2     4 4|  4      2 2     4
+--R             \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+  3
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                                  4        3 2  10           4        3 2  6
+--R                         ((2304a c  - 3456a c )x   + (1536a c  - 2304a c )x )
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                    4        3 2  8             4        3 2  4
+--R                         ((- 2304a c  + 3456a c )x  + (- 1536a c  + 2304a c )x )
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                  2 3         4   10           2 3        4   6
+--R                         ((- 6912a c  + 10368a c)x   + (- 4608a c  + 6912a c)x )
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                            2 3         4   8         2 3        4   4  +-+4+-+3
+--R                     ((6912a c  - 10368a c)x  + (4608a c  - 6912a c)x )\|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                 5        2 3         4   10
+--R                           (2304c  - 6912a c  - 15552a c)x
+--R                         + 
+--R                                     3         3     9
+--R                           (- 9216a c  + 13824a c)d x
+--R                         + 
+--R                                     4         3 2  8
+--R                           (- 9216a c  + 13824a c )x
+--R                         + 
+--R                                 5        2 3         4   6
+--R                           (1536c  - 4608a c  - 10368a c)x
+--R                         + 
+--R                                   3        3     5
+--R                           (6144a c  - 9216a c)d x
+--R                      *
+--R                         4+-+2 4+-+2
+--R                         \|2   \|3
+--R                     + 
+--R                                   5        2 3         4   10
+--R                           (- 2304c  + 6912a c  + 15552a c)x
+--R                         + 
+--R                                   3         3     9           4         3 2  8
+--R                           (9216a c  - 13824a c)d x  + (9216a c  - 13824a c )x
+--R                         + 
+--R                                   5        2 3         4   6
+--R                           (- 1536c  + 4608a c  + 10368a c)x
+--R                         + 
+--R                                     3        3     5
+--R                           (- 6144a c  + 9216a c)d x
+--R                      *
+--R                          +-+ +-+
+--R                         \|2 \|3
+--R                     + 
+--R                               5         2 3         4   12
+--R                       (- 3456c  + 10368a c  + 23328a c)x
+--R                     + 
+--R                                3         3     11            4         3 2  10
+--R                       (13824a c  - 20736a c)d x   + (13824a c  - 20736a c )x
+--R                     + 
+--R                               5         2 3         4   8
+--R                       (- 4608c  + 13824a c  + 31104a c)x
+--R                     + 
+--R                               4         3 2  6
+--R                       (9216a c  - 13824a c )x
+--R                     + 
+--R                               5        2 3         4   4
+--R                       (- 1536c  + 4608a c  + 10368a c)x
+--R                     + 
+--R                                 3        3     3
+--R                       (- 6144a c  + 9216a c)d x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                            2 3         4   8 4+-+2 4+-+2
+--R                   (- 27648a c  + 41472a c)x  \|2   \|3
+--R                 + 
+--R                          2 3         4   8 +-+ +-+          2 3         4   10
+--R                   (27648a c  - 41472a c)x \|2 \|3  + (41472a c  - 62208a c)x
+--R                 + 
+--R                          2 3         4   6
+--R                   (27648a c  - 41472a c)x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                              4         3 2  6 4+-+2 4+-+2
+--R                   (- 18432a c  + 27648a c )x  \|2   \|3
+--R                 + 
+--R                            4         3 2  6 +-+ +-+            4         3 2  8
+--R                   (18432a c  - 27648a c )x \|2 \|3  + (27648a c  - 41472a c )x
+--R                 + 
+--R                            4         3 2  4
+--R                   (18432a c  - 27648a c )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                        2 3         4   6 4+-+2 4+-+2
+--R               (- 55296a c  + 82944a c)x  \|2   \|3
+--R             + 
+--R                      2 3         4   6 +-+ +-+          2 3          4   8
+--R               (55296a c  - 82944a c)x \|2 \|3  + (82944a c  - 124416a c)x
+--R             + 
+--R                      2 3         4   4
+--R               (55296a c  - 82944a c)x
+--R          *
+--R                                                   +------------------+
+--R                                                   |  4      2 2     4
+--R                                                  \|4c  - 12a c  + 9a
+--R                                             atan(---------------------)
+--R                     +------------------+                     +-+
+--R             4+---+2 |  4      2 2     4                 2a c\|6
+--R             \|216  \|4c  - 12a c  + 9a  cos(---------------------------)
+--R                                                          2
+--R      *
+--R                   +------------------+  3
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                    6       3 4       5 2        7  6
+--R                           (- 384a c  - 576a c  + 864a c  + 1296a )x
+--R                         + 
+--R                                    6       3 4       5 2       7  2
+--R                           (- 256a c  - 384a c  + 576a c  + 864a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  6       3 4       5 2        7  4         6
+--R                           (384a c  + 576a c  - 864a c  - 1296a )x  + 256a c
+--R                         + 
+--R                               3 4       5 2       7
+--R                           384a c  - 576a c  - 864a
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                7        2 5        4 3        6   6
+--R                           (768c  + 1152a c  - 1728a c  - 2592a c)x
+--R                         + 
+--R                                7       2 5        4 3        6   2
+--R                           (512c  + 768a c  - 1152a c  - 1728a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  7        2 5        4 3        6   4       7
+--R                           (- 768c  - 1152a c  + 1728a c  + 2592a c)x  - 512c
+--R                         + 
+--R                                 2 5        4 3        6
+--R                           - 768a c  + 1152a c  + 1728a c
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                 6        3 4        5 2        7  4 4+-+2 4+-+2
+--R                       (- 1536a c  - 2304a c  + 3456a c  + 5184a )x  \|2   \|3
+--R                     + 
+--R                               6        3 4        5 2        7  4 +-+ +-+
+--R                       (1536a c  + 2304a c  - 3456a c  - 5184a )x \|2 \|3
+--R                     + 
+--R                               6        3 4        5 2        7  6
+--R                       (2304a c  + 3456a c  - 5184a c  - 7776a )x
+--R                     + 
+--R                               6        3 4        5 2        7  2
+--R                       (1536a c  + 2304a c  - 3456a c  - 5184a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                               6         3 4         5 2         7  6
+--R                       (9216a c  + 13824a c  - 20736a c  - 31104a )x
+--R                     + 
+--R                               6        2 4         4 2         6    5
+--R                       (- 6144c  - 9216a c  + 13824a c  + 20736a )d x
+--R                     + 
+--R                               7        2 5        4 3         6   4
+--R                       (- 3072c  - 4608a c  + 6912a c  + 10368a c)x
+--R                     + 
+--R                               6        3 4         5 2         7  2
+--R                       (6144a c  + 9216a c  - 13824a c  - 20736a )x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                 6         3 4         5 2         7  6
+--R                       (- 9216a c  - 13824a c  + 20736a c  + 31104a )x
+--R                     + 
+--R                             6        2 4         4 2         6    5
+--R                       (6144c  + 9216a c  - 13824a c  - 20736a )d x
+--R                     + 
+--R                             7        2 5        4 3         6   4
+--R                       (3072c  + 4608a c  - 6912a c  - 10368a c)x
+--R                     + 
+--R                                 6        3 4         5 2         7  2
+--R                       (- 6144a c  - 9216a c  + 13824a c  + 20736a )x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                              6         3 4         5 2         7  8
+--R                   (- 13824a c  - 20736a c  + 31104a c  + 46656a )x
+--R                 + 
+--R                         6         2 4         4 2         6    7
+--R                   (9216c  + 13824a c  - 20736a c  - 31104a )d x
+--R                 + 
+--R                         7        2 5         4 3         6   6
+--R                   (4608c  + 6912a c  - 10368a c  - 15552a c)x
+--R                 + 
+--R                              6         3 4         5 2         7  4
+--R                   (- 18432a c  - 27648a c  + 41472a c  + 62208a )x
+--R                 + 
+--R                         6        2 4         4 2         6    3
+--R                   (6144c  + 9216a c  - 13824a c  - 20736a )d x
+--R                 + 
+--R                         7        2 5        4 3         6   2          6
+--R                   (3072c  + 4608a c  - 6912a c  - 10368a c)x  - 6144a c
+--R                 + 
+--R                          3 4         5 2         7
+--R                   - 9216a c  + 13824a c  + 20736a
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                             6        3 4        5 2         7  2 4+-+2 4+-+2
+--R                   (- 3072a c  - 4608a c  + 6912a c  + 10368a )x  \|2   \|3
+--R                 + 
+--R                           6        3 4        5 2         7  2 +-+ +-+
+--R                   (3072a c  + 4608a c  - 6912a c  - 10368a )x \|2 \|3
+--R                 + 
+--R                           6        3 4         5 2         7  4          6
+--R                   (4608a c  + 6912a c  - 10368a c  - 15552a )x  + 3072a c
+--R                 + 
+--R                        3 4        5 2         7
+--R                   4608a c  - 6912a c  - 10368a
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                       7        2 5         4 3         6   2 4+-+2 4+-+2
+--R               (- 6144c  - 9216a c  + 13824a c  + 20736a c)x  \|2   \|3
+--R             + 
+--R                     7        2 5         4 3         6   2 +-+ +-+
+--R               (6144c  + 9216a c  - 13824a c  - 20736a c)x \|2 \|3
+--R             + 
+--R                     7         2 5         4 3         6   4        7        2 5
+--R               (9216c  + 13824a c  - 20736a c  - 31104a c)x  + 6144c  + 9216a c
+--R             + 
+--R                       4 3         6
+--R               - 13824a c  - 20736a c
+--R          *
+--R                              +------------------+  6
+--R                              |  4      2 2     4
+--R                             \|4c  - 12a c  + 9a
+--R                        atan(---------------------)
+--R                                         +-+
+--R             4+---+2                2a c\|6
+--R             \|216  cos(---------------------------)
+--R                                     2
+--R         + 
+--R                                     4         3 2        5  8
+--R                           (- 3456a c  + 10368a c  - 7776a )x
+--R                         + 
+--R                                     4        3 2        5  4
+--R                           (- 2304a c  + 6912a c  - 5184a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                   4         3 2        5  6
+--R                           (3456a c  - 10368a c  + 7776a )x
+--R                         + 
+--R                                   4        3 2        5  2
+--R                           (2304a c  - 6912a c  + 5184a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                 5         2 3         4   8
+--R                           (6912c  - 20736a c  + 15552a c)x
+--R                         + 
+--R                                 5         2 3         4   4
+--R                           (4608c  - 13824a c  + 10368a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                   5         2 3         4   6
+--R                           (- 6912c  + 20736a c  - 15552a c)x
+--R                         + 
+--R                                   5         2 3         4   2
+--R                           (- 4608c  + 13824a c  - 10368a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                  4         3 2         5  6 4+-+2 4+-+2
+--R                       (- 13824a c  + 41472a c  - 31104a )x  \|2   \|3
+--R                     + 
+--R                                4         3 2         5  6 +-+ +-+
+--R                       (13824a c  - 41472a c  + 31104a )x \|2 \|3
+--R                     + 
+--R                                4         3 2         5  8
+--R                       (20736a c  - 62208a c  + 46656a )x
+--R                     + 
+--R                                4         3 2         5  4
+--R                       (13824a c  - 41472a c  + 31104a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                4          3 2          5  8
+--R                       (20736a c  - 124416a c  + 139968a )x
+--R                     + 
+--R                                4          2 2         4    7
+--R                       (- 41472c  + 124416a c  - 93312a )d x
+--R                     + 
+--R                                5         2 3         4   6
+--R                       (- 27648c  + 82944a c  - 62208a c)x
+--R                     + 
+--R                                4         3 2         5  4
+--R                       (13824a c  - 82944a c  + 93312a )x
+--R                     + 
+--R                             4         2 2         4    3
+--R                       (9216c  - 27648a c  + 20736a )d x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                  4          3 2          5  8
+--R                       (- 20736a c  + 124416a c  - 139968a )x
+--R                     + 
+--R                              4          2 2         4    7
+--R                       (41472c  - 124416a c  + 93312a )d x
+--R                     + 
+--R                              5         2 3         4   6
+--R                       (27648c  - 82944a c  + 62208a c)x
+--R                     + 
+--R                                  4         3 2         5  4
+--R                       (- 13824a c  + 82944a c  - 93312a )x
+--R                     + 
+--R                               4         2 2         4    3
+--R                       (- 9216c  + 27648a c  - 20736a )d x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                              4          3 2          5  10
+--R                   (- 31104a c  + 186624a c  - 209952a )x
+--R                 + 
+--R                          4          2 2          4    9
+--R                   (62208c  - 186624a c  + 139968a )d x
+--R                 + 
+--R                          5          2 3         4   8
+--R                   (41472c  - 124416a c  + 93312a c)x
+--R                 + 
+--R                              4          3 2          5  6
+--R                   (- 41472a c  + 248832a c  - 279936a )x
+--R                 + 
+--R                          4         2 2         4    5
+--R                   (27648c  - 82944a c  + 62208a )d x
+--R                 + 
+--R                          5         2 3         4   4
+--R                   (27648c  - 82944a c  + 62208a c)x
+--R                 + 
+--R                              4         3 2         5  2
+--R                   (- 13824a c  + 82944a c  - 93312a )x
+--R                 + 
+--R                           4         2 2         4
+--R                   (- 9216c  + 27648a c  - 20736a )d x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                              4         3 2         5  4 4+-+2 4+-+2
+--R                   (- 27648a c  + 82944a c  - 62208a )x  \|2   \|3
+--R                 + 
+--R                            4         3 2         5  4 +-+ +-+
+--R                   (27648a c  - 82944a c  + 62208a )x \|2 \|3
+--R                 + 
+--R                            4          3 2         5  6
+--R                   (41472a c  - 124416a c  + 93312a )x
+--R                 + 
+--R                            4         3 2         5  2
+--R                   (27648a c  - 82944a c  + 62208a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                        5          2 3          4   4 4+-+2 4+-+2
+--R               (- 55296c  + 165888a c  - 124416a c)x  \|2   \|3
+--R             + 
+--R                      5          2 3          4   4 +-+ +-+
+--R               (55296c  - 165888a c  + 124416a c)x \|2 \|3
+--R             + 
+--R                      5          2 3          4   6
+--R               (82944c  - 248832a c  + 186624a c)x
+--R             + 
+--R                      5          2 3          4   2
+--R               (55296c  - 165888a c  + 124416a c)x
+--R          *
+--R                                             +------------------+  4
+--R                                             |  4      2 2     4
+--R                                            \|4c  - 12a c  + 9a
+--R                                       atan(---------------------)
+--R              +------------------+2                     +-+
+--R             4|  4      2 2     4                  2a c\|6
+--R             \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                    2
+--R         + 
+--R                                  6         3 4         5 2        7  10
+--R                           (576a c  - 19872a c  + 29808a c  - 1944a )x
+--R                         + 
+--R                                  6         3 4         5 2        7  6
+--R                           (384a c  - 13248a c  + 19872a c  - 1296a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                    6         3 4         5 2        7  8
+--R                           (- 576a c  + 19872a c  - 29808a c  + 1944a )x
+--R                         + 
+--R                                    6         3 4         5 2        7  4
+--R                           (- 384a c  + 13248a c  - 19872a c  + 1296a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                   7         2 5         4 3        6   10
+--R                           (- 1152c  + 39744a c  - 59616a c  + 3888a c)x
+--R                         + 
+--R                                  7         2 5         4 3        6   6
+--R                           (- 768c  + 26496a c  - 39744a c  + 2592a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                 7         2 5         4 3        6   8
+--R                           (1152c  - 39744a c  + 59616a c  - 3888a c)x
+--R                         + 
+--R                                7         2 5         4 3        6   4
+--R                           (768c  - 26496a c  + 39744a c  - 2592a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                               6         3 4          5 2        7  8 4+-+2 4+-+2
+--R                       (2304a c  - 79488a c  + 119232a c  - 7776a )x  \|2   \|3
+--R                     + 
+--R                                 6         3 4          5 2        7  8 +-+ +-+
+--R                       (- 2304a c  + 79488a c  - 119232a c  + 7776a )x \|2 \|3
+--R                     + 
+--R                                 6          3 4          5 2         7  10
+--R                       (- 3456a c  + 119232a c  - 178848a c  + 11664a )x
+--R                     + 
+--R                                 6         3 4          5 2        7  6
+--R                       (- 2304a c  + 79488a c  - 119232a c  + 7776a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                6         3 4          5 2         7  10
+--R                       (76032a c  - 10368a c  - 171072a c  + 23328a )x
+--R                     + 
+--R                             6          2 4          4 2         6    9
+--R                       (4608c  - 158976a c  + 238464a c  - 15552a )d x
+--R                     + 
+--R                             7          2 5          4 3         6   8
+--R                       (4608c  - 158976a c  + 238464a c  - 15552a c)x
+--R                     + 
+--R                                6        3 4          5 2         7  6
+--R                       (50688a c  - 6912a c  - 114048a c  + 15552a )x
+--R                     + 
+--R                               6          2 4          4 2         6    5
+--R                       (- 3072c  + 105984a c  - 158976a c  + 10368a )d x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                  6         3 4          5 2         7  10
+--R                       (- 76032a c  + 10368a c  + 171072a c  - 23328a )x
+--R                     + 
+--R                               6          2 4          4 2         6    9
+--R                       (- 4608c  + 158976a c  - 238464a c  + 15552a )d x
+--R                     + 
+--R                               7          2 5          4 3         6   8
+--R                       (- 4608c  + 158976a c  - 238464a c  + 15552a c)x
+--R                     + 
+--R                                  6        3 4          5 2         7  6
+--R                       (- 50688a c  + 6912a c  + 114048a c  - 15552a )x
+--R                     + 
+--R                             6          2 4          4 2         6    5
+--R                       (3072c  - 105984a c  + 158976a c  - 10368a )d x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                               6         3 4          5 2         7  12
+--R                   (- 114048a c  + 15552a c  + 256608a c  - 34992a )x
+--R                 + 
+--R                           6          2 4          4 2         6    11
+--R                   (- 6912c  + 238464a c  - 357696a c  + 23328a )d x
+--R                 + 
+--R                           7          2 5          4 3         6   10
+--R                   (- 6912c  + 238464a c  - 357696a c  + 23328a c)x
+--R                 + 
+--R                               6         3 4          5 2         7  8
+--R                   (- 152064a c  + 20736a c  + 342144a c  - 46656a )x
+--R                 + 
+--R                           7          2 5          4 3         6   6
+--R                   (- 4608c  + 158976a c  - 238464a c  + 15552a c)x
+--R                 + 
+--R                              6        3 4          5 2         7  4
+--R                   (- 50688a c  + 6912a c  + 114048a c  - 15552a )x
+--R                 + 
+--R                         6          2 4          4 2         6    3
+--R                   (3072c  - 105984a c  + 158976a c  - 10368a )d x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                           6          3 4          5 2         7  6 4+-+2 4+-+2
+--R                   (4608a c  - 158976a c  + 238464a c  - 15552a )x  \|2   \|3
+--R                 + 
+--R                             6          3 4          5 2         7  6 +-+ +-+
+--R                   (- 4608a c  + 158976a c  - 238464a c  + 15552a )x \|2 \|3
+--R                 + 
+--R                             6          3 4          5 2         7  8
+--R                   (- 6912a c  + 238464a c  - 357696a c  + 23328a )x
+--R                 + 
+--R                             6          3 4          5 2         7  4
+--R                   (- 4608a c  + 158976a c  - 238464a c  + 15552a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                     7          2 5          4 3         6   6 4+-+2 4+-+2
+--R               (9216c  - 317952a c  + 476928a c  - 31104a c)x  \|2   \|3
+--R             + 
+--R                       7          2 5          4 3         6   6 +-+ +-+
+--R               (- 9216c  + 317952a c  - 476928a c  + 31104a c)x \|2 \|3
+--R             + 
+--R                        7          2 5          4 3         6   8
+--R               (- 13824c  + 476928a c  - 715392a c  + 46656a c)x
+--R             + 
+--R                       7          2 5          4 3         6   4
+--R               (- 9216c  + 317952a c  - 476928a c  + 31104a c)x
+--R          *
+--R                              +------------------+  2
+--R                              |  4      2 2     4
+--R                             \|4c  - 12a c  + 9a
+--R                        atan(---------------------)
+--R                                         +-+
+--R             4+---+2                2a c\|6
+--R             \|216  cos(---------------------------)
+--R                                     2
+--R         + 
+--R                                   4         3 2         5  12
+--R                           (5184a c  - 15552a c  + 11664a )x
+--R                         + 
+--R                                   4         3 2        5  8
+--R                           (3456a c  - 10368a c  + 7776a )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                     4         3 2         5  10
+--R                           (- 5184a c  + 15552a c  - 11664a )x
+--R                         + 
+--R                                     4         3 2        5  6
+--R                           (- 3456a c  + 10368a c  - 7776a )x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                    5         2 3         4   12
+--R                           (- 10368c  + 31104a c  - 23328a c)x
+--R                         + 
+--R                                   5         2 3         4   8
+--R                           (- 6912c  + 20736a c  - 15552a c)x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  5         2 3         4   10
+--R                           (10368c  - 31104a c  + 23328a c)x
+--R                         + 
+--R                                 5         2 3         4   6
+--R                           (6912c  - 20736a c  + 15552a c)x
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                4         3 2         5  10 4+-+2 4+-+2
+--R                       (20736a c  - 62208a c  + 46656a )x   \|2   \|3
+--R                     + 
+--R                                  4         3 2         5  10 +-+ +-+
+--R                       (- 20736a c  + 62208a c  - 46656a )x  \|2 \|3
+--R                     + 
+--R                                  4         3 2         5  12
+--R                       (- 31104a c  + 93312a c  - 69984a )x
+--R                     + 
+--R                                  4         3 2         5  8
+--R                       (- 20736a c  + 62208a c  - 46656a )x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                                4         5  12
+--R                       (31104a c  - 69984a )x
+--R                     + 
+--R                              4         2 2         4    11
+--R                       (20736c  - 62208a c  + 46656a )d x
+--R                     + 
+--R                              5          2 3         4   10
+--R                       (41472c  - 124416a c  + 93312a c)x
+--R                     + 
+--R                                4         5  8
+--R                       (20736a c  - 46656a )x
+--R                     + 
+--R                                4          2 2         4    7
+--R                       (- 41472c  + 124416a c  - 93312a )d x
+--R                  *
+--R                     4+-+2 4+-+2
+--R                     \|2   \|3
+--R                 + 
+--R                                  4         5  12
+--R                       (- 31104a c  + 69984a )x
+--R                     + 
+--R                                4         2 2         4    11
+--R                       (- 20736c  + 62208a c  - 46656a )d x
+--R                     + 
+--R                                5          2 3         4   10
+--R                       (- 41472c  + 124416a c  - 93312a c)x
+--R                     + 
+--R                                  4         5  8
+--R                       (- 20736a c  + 46656a )x
+--R                     + 
+--R                              4          2 2         4    7
+--R                       (41472c  - 124416a c  + 93312a )d x
+--R                  *
+--R                      +-+ +-+
+--R                     \|2 \|3
+--R                 + 
+--R                              4          5  14
+--R                   (- 46656a c  + 104976a )x
+--R                 + 
+--R                            4         2 2         4    13
+--R                   (- 31104c  + 93312a c  - 69984a )d x
+--R                 + 
+--R                            5          2 3          4   12
+--R                   (- 62208c  + 186624a c  - 139968a c)x
+--R                 + 
+--R                              4          5  10
+--R                   (- 62208a c  + 139968a )x
+--R                 + 
+--R                          4          2 2         4    9
+--R                   (41472c  - 124416a c  + 93312a )d x
+--R                 + 
+--R                            5          2 3         4   8
+--R                   (- 41472c  + 124416a c  - 93312a c)x
+--R                 + 
+--R                              4         5  6
+--R                   (- 20736a c  + 46656a )x
+--R                 + 
+--R                          4          2 2         4    5
+--R                   (41472c  - 124416a c  + 93312a )d x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                            4          3 2         5  8 4+-+2 4+-+2
+--R                   (41472a c  - 124416a c  + 93312a )x  \|2   \|3
+--R                 + 
+--R                              4          3 2         5  8 +-+ +-+
+--R                   (- 41472a c  + 124416a c  - 93312a )x \|2 \|3
+--R                 + 
+--R                              4          3 2          5  10
+--R                   (- 62208a c  + 186624a c  - 139968a )x
+--R                 + 
+--R                              4          3 2         5  6
+--R                   (- 41472a c  + 124416a c  - 93312a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      5          2 3          4   8 4+-+2 4+-+2
+--R               (82944c  - 248832a c  + 186624a c)x  \|2   \|3
+--R             + 
+--R                        5          2 3          4   8 +-+ +-+
+--R               (- 82944c  + 248832a c  - 186624a c)x \|2 \|3
+--R             + 
+--R                         5          2 3          4   10
+--R               (- 124416c  + 373248a c  - 279936a c)x
+--R             + 
+--R                        5          2 3          4   6
+--R               (- 82944c  + 248832a c  - 186624a c)x
+--R          *
+--R              +------------------+2
+--R             4|  4      2 2     4
+--R             \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+  2
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                                 2 8          2 4 4+-+3 +-+
+--R                       (- 6912a c x  - 4608a c x )\|2  \|3
+--R                     + 
+--R                               2 6          2 2  +-+4+-+3
+--R                       (6912a c x  + 4608a c x )\|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                              2   8         2   4 4+-+3 +-+
+--R                       (20736a c x  + 13824a c x )\|2  \|3
+--R                     + 
+--R                                2   6         2   2  +-+4+-+3
+--R                       (- 20736a c x  - 13824a c x )\|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                   3         2   8               7           2 6
+--R                           (- 6912c  - 51840a c)x  + 41472a c d x  + 27648a c x
+--R                         + 
+--R                                   3         2   4              3
+--R                           (- 4608c  - 34560a c)x  - 9216a c d x
+--R                      *
+--R                         4+-+2 4+-+2
+--R                         \|2   \|3
+--R                     + 
+--R                                 3         2   8               7           2 6
+--R                           (6912c  + 51840a c)x  - 41472a c d x  - 27648a c x
+--R                         + 
+--R                                 3         2   4              3
+--R                           (4608c  + 34560a c)x  + 9216a c d x
+--R                      *
+--R                          +-+ +-+
+--R                         \|2 \|3
+--R                     + 
+--R                              3         2   10               9           2 8
+--R                       (10368c  + 77760a c)x   - 62208a c d x  - 41472a c x
+--R                     + 
+--R                              3          2   6               5           2 4
+--R                       (13824c  + 103680a c)x  - 27648a c d x  - 27648a c x
+--R                     + 
+--R                             3         2   2
+--R                       (4608c  + 34560a c)x  + 9216a c d x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                         2   6 4+-+2 4+-+2       2   6 +-+ +-+          2   8
+--R                   82944a c x  \|2   \|3 - 82944a c x \|2 \|3  - 124416a c x
+--R                 + 
+--R                           2   4
+--R                   - 82944a c x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                           2 4 4+-+2 4+-+2         2 4 +-+ +-+           2 6
+--R                   55296a c x  \|2   \|3 - 55296a c x \|2 \|3  - 82944a c x
+--R                 + 
+--R                             2 2
+--R                   - 55296a c x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      2   4 4+-+2 4+-+2        2   4 +-+ +-+          2   6
+--R               165888a c x  \|2   \|3 - 165888a c x \|2 \|3  - 248832a c x
+--R             + 
+--R                        2   2
+--R               - 165888a c x
+--R          *
+--R              +------------------+ +------------------+2
+--R              |  4      2 2     4 4|  4      2 2     4
+--R             \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+  5
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                                       4        3 2  10
+--R                             (- 2304a c  + 3456a c )x
+--R                           + 
+--R                                       4        3 2  6
+--R                             (- 1536a c  + 2304a c )x
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  4        3 2  8           4        3 2  4  +-+
+--R                         ((2304a c  - 3456a c )x  + (1536a c  - 2304a c )x )\|2
+--R                      *
+--R                         4+-+3
+--R                         \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                                2 3         4   10         2 3        4   6
+--R                         ((6912a c  - 10368a c)x   + (4608a c  - 6912a c)x )
+--R                      *
+--R                         4+-+3 +-+
+--R                         \|2  \|3
+--R                     + 
+--R                                  2 3         4   8           2 3        4   4
+--R                         ((- 6912a c  + 10368a c)x  + (- 4608a c  + 6912a c)x )
+--R                      *
+--R                          +-+4+-+3
+--R                         \|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                   5        2 3         4   10
+--R                           (- 2304c  + 6912a c  + 15552a c)x
+--R                         + 
+--R                                   3         3     9           4         3 2  8
+--R                           (9216a c  - 13824a c)d x  + (9216a c  - 13824a c )x
+--R                         + 
+--R                                   5        2 3         4   6
+--R                           (- 1536c  + 4608a c  + 10368a c)x
+--R                         + 
+--R                                     3        3     5
+--R                           (- 6144a c  + 9216a c)d x
+--R                      *
+--R                         4+-+2 4+-+2
+--R                         \|2   \|3
+--R                     + 
+--R                                 5        2 3         4   10
+--R                           (2304c  - 6912a c  - 15552a c)x
+--R                         + 
+--R                                     3         3     9
+--R                           (- 9216a c  + 13824a c)d x
+--R                         + 
+--R                                     4         3 2  8
+--R                           (- 9216a c  + 13824a c )x
+--R                         + 
+--R                                 5        2 3         4   6
+--R                           (1536c  - 4608a c  - 10368a c)x
+--R                         + 
+--R                                   3        3     5
+--R                           (6144a c  - 9216a c)d x
+--R                      *
+--R                          +-+ +-+
+--R                         \|2 \|3
+--R                     + 
+--R                             5         2 3         4   12
+--R                       (3456c  - 10368a c  - 23328a c)x
+--R                     + 
+--R                                  3         3     11
+--R                       (- 13824a c  + 20736a c)d x
+--R                     + 
+--R                                  4         3 2  10
+--R                       (- 13824a c  + 20736a c )x
+--R                     + 
+--R                             5         2 3         4   8
+--R                       (4608c  - 13824a c  - 31104a c)x
+--R                     + 
+--R                                 4         3 2  6
+--R                       (- 9216a c  + 13824a c )x
+--R                     + 
+--R                           5        2 3         4   4           3        3     3
+--R                     (1536c  - 4608a c  - 10368a c)x  + (6144a c  - 9216a c)d x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                          2 3         4   8 4+-+2 4+-+2
+--R                   (27648a c  - 41472a c)x  \|2   \|3
+--R                 + 
+--R                            2 3         4   8 +-+ +-+
+--R                   (- 27648a c  + 41472a c)x \|2 \|3
+--R                 + 
+--R                            2 3         4   10            2 3         4   6
+--R                   (- 41472a c  + 62208a c)x   + (- 27648a c  + 41472a c)x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                            4         3 2  6 4+-+2 4+-+2
+--R                   (18432a c  - 27648a c )x  \|2   \|3
+--R                 + 
+--R                              4         3 2  6 +-+ +-+
+--R                   (- 18432a c  + 27648a c )x \|2 \|3
+--R                 + 
+--R                              4         3 2  8              4         3 2  4
+--R                   (- 27648a c  + 41472a c )x  + (- 18432a c  + 27648a c )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      2 3         4   6 4+-+2 4+-+2
+--R               (55296a c  - 82944a c)x  \|2   \|3
+--R             + 
+--R                        2 3         4   6 +-+ +-+            2 3          4   8
+--R               (- 55296a c  + 82944a c)x \|2 \|3  + (- 82944a c  + 124416a c)x
+--R             + 
+--R                        2 3         4   4
+--R               (- 55296a c  + 82944a c)x
+--R          *
+--R                                                   +------------------+  3
+--R                                                   |  4      2 2     4
+--R                                                  \|4c  - 12a c  + 9a
+--R                                             atan(---------------------)
+--R                     +------------------+                     +-+
+--R             4+---+2 |  4      2 2     4                 2a c\|6
+--R             \|216  \|4c  - 12a c  + 9a  cos(---------------------------)
+--R                                                          2
+--R         + 
+--R                                  2 12          2 8 4+-+3 +-+
+--R                       (- 10368a c x   - 6912a c x )\|2  \|3
+--R                     + 
+--R                                2 10          2 6  +-+4+-+3
+--R                       (10368a c x   + 6912a c x )\|2 \|2
+--R                  *
+--R                     4+-+ +-+
+--R                     \|3 \|6
+--R                 + 
+--R                              2   12         2   8 4+-+3 +-+
+--R                       (31104a c x   + 20736a c x )\|2  \|3
+--R                     + 
+--R                                2   10         2   6  +-+4+-+3
+--R                       (- 31104a c x   - 20736a c x )\|2 \|2
+--R                  *
+--R                     4+-+
+--R                     \|3
+--R              *
+--R                 4+-+3
+--R                 \|6
+--R             + 
+--R                                    3         2   12               11
+--R                           (- 10368c  - 15552a c)x   + 20736a c d x
+--R                         + 
+--R                                 2 10           3         2   8               7
+--R                         41472a c x   + (- 6912c  - 10368a c)x  - 41472a c d x
+--R                      *
+--R                         4+-+2 4+-+2
+--R                         \|2   \|3
+--R                     + 
+--R                                  3         2   12               11
+--R                           (10368c  + 15552a c)x   - 20736a c d x
+--R                         + 
+--R                                   2 10         3         2   8               7
+--R                         - 41472a c x   + (6912c  + 10368a c)x  + 41472a c d x
+--R                      *
+--R                          +-+ +-+
+--R                         \|2 \|3
+--R                     + 
+--R                              3         2   14               13           2 12
+--R                       (15552c  + 23328a c)x   - 31104a c d x   - 62208a c x
+--R                     + 
+--R                              3         2   10               9           2 8
+--R                       (20736c  + 31104a c)x   + 41472a c d x  - 41472a c x
+--R                     + 
+--R                             3         2   6               5
+--R                       (6912c  + 10368a c)x  + 41472a c d x
+--R                  *
+--R                      +-+
+--R                     \|6
+--R                 + 
+--R                          2   10 4+-+2 4+-+2        2   10 +-+ +-+
+--R                   124416a c x   \|2   \|3 - 124416a c x  \|2 \|3
+--R                 + 
+--R                            2   12          2   8
+--R                   - 186624a c x   - 124416a c x
+--R              *
+--R                 4+-+2
+--R                 \|6
+--R             + 
+--R                           2 8 4+-+2 4+-+2         2 8 +-+ +-+            2 10
+--R                   82944a c x  \|2   \|3 - 82944a c x \|2 \|3  - 124416a c x
+--R                 + 
+--R                             2 6
+--R                   - 82944a c x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                      2   8 4+-+2 4+-+2        2   8 +-+ +-+          2   10
+--R               248832a c x  \|2   \|3 - 248832a c x \|2 \|3  - 373248a c x
+--R             + 
+--R                        2   6
+--R               - 248832a c x
+--R          *
+--R              +------------------+ +------------------+2
+--R              |  4      2 2     4 4|  4      2 2     4
+--R             \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R      *
+--R                   +------------------+
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                               6       3 4       5 2       7  6
+--R                       (- 96a c  - 144a c  + 216a c  + 324a )x
+--R                     + 
+--R                               6      3 4       5 2       7  2
+--R                       (- 64a c  - 96a c  + 144a c  + 216a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                             6       3 4       5 2       7  4        6      3 4
+--R                       (96a c  + 144a c  - 216a c  - 324a )x  + 64a c  + 96a c
+--R                     + 
+--R                             5 2       7
+--R                       - 144a c  - 216a
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                            7       2 5       4 3       6   6
+--R                       (192c  + 288a c  - 432a c  - 648a c)x
+--R                     + 
+--R                            7       2 5       4 3       6   2
+--R                       (128c  + 192a c  - 288a c  - 432a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                              7       2 5       4 3       6   4       7
+--R                       (- 192c  - 288a c  + 432a c  + 648a c)x  - 128c
+--R                     + 
+--R                             2 5       4 3       6
+--R                       - 192a c  + 288a c  + 432a c
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                            6       3 4       5 2        7  4 4+-+2 4+-+2
+--R                   (- 384a c  - 576a c  + 864a c  + 1296a )x  \|2   \|3
+--R                 + 
+--R                          6       3 4       5 2        7  4 +-+ +-+
+--R                   (384a c  + 576a c  - 864a c  - 1296a )x \|2 \|3
+--R                 + 
+--R                          6       3 4        5 2        7  6
+--R                   (576a c  + 864a c  - 1296a c  - 1944a )x
+--R                 + 
+--R                          6       3 4       5 2        7  2
+--R                   (384a c  + 576a c  - 864a c  - 1296a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                           6        3 4        5 2        7  6
+--R                   (2304a c  + 3456a c  - 5184a c  - 7776a )x
+--R                 + 
+--R                           6        2 4        4 2        6    5
+--R                   (- 1536c  - 2304a c  + 3456a c  + 5184a )d x
+--R                 + 
+--R                          7        2 5        4 3        6   4
+--R                   (- 768c  - 1152a c  + 1728a c  + 2592a c)x
+--R                 + 
+--R                           6        3 4        5 2        7  2
+--R                   (1536a c  + 2304a c  - 3456a c  - 5184a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                             6        3 4        5 2        7  6
+--R                   (- 2304a c  - 3456a c  + 5184a c  + 7776a )x
+--R                 + 
+--R                         6        2 4        4 2        6    5
+--R                   (1536c  + 2304a c  - 3456a c  - 5184a )d x
+--R                 + 
+--R                        7        2 5        4 3        6   4
+--R                   (768c  + 1152a c  - 1728a c  - 2592a c)x
+--R                 + 
+--R                             6        3 4        5 2        7  2
+--R                   (- 1536a c  - 2304a c  + 3456a c  + 5184a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                         6        3 4        5 2         7  8
+--R               (- 3456a c  - 5184a c  + 7776a c  + 11664a )x
+--R             + 
+--R                     6        2 4        4 2        6    7
+--R               (2304c  + 3456a c  - 5184a c  - 7776a )d x
+--R             + 
+--R                     7        2 5        4 3        6   6
+--R               (1152c  + 1728a c  - 2592a c  - 3888a c)x
+--R             + 
+--R                         6        3 4         5 2         7  4
+--R               (- 4608a c  - 6912a c  + 10368a c  + 15552a )x
+--R             + 
+--R                     6        2 4        4 2        6    3
+--R               (1536c  + 2304a c  - 3456a c  - 5184a )d x
+--R             + 
+--R                    7        2 5        4 3        6   2          6        3 4
+--R               (768c  + 1152a c  - 1728a c  - 2592a c)x  - 1536a c  - 2304a c
+--R             + 
+--R                    5 2        7
+--R               3456a c  + 5184a
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                        6        3 4        5 2        7  2 4+-+2 4+-+2
+--R               (- 768a c  - 1152a c  + 1728a c  + 2592a )x  \|2   \|3
+--R             + 
+--R                      6        3 4        5 2        7  2 +-+ +-+
+--R               (768a c  + 1152a c  - 1728a c  - 2592a )x \|2 \|3
+--R             + 
+--R                       6        3 4        5 2        7  4         6        3 4
+--R               (1152a c  + 1728a c  - 2592a c  - 3888a )x  + 768a c  + 1152a c
+--R             + 
+--R                      5 2        7
+--R               - 1728a c  - 2592a
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                   7        2 5        4 3        6   2 4+-+2 4+-+2
+--R           (- 1536c  - 2304a c  + 3456a c  + 5184a c)x  \|2   \|3
+--R         + 
+--R                 7        2 5        4 3        6   2 +-+ +-+
+--R           (1536c  + 2304a c  - 3456a c  - 5184a c)x \|2 \|3
+--R         + 
+--R                 7        2 5        4 3        6   4        7        2 5
+--R           (2304c  + 3456a c  - 5184a c  - 7776a c)x  + 1536c  + 2304a c
+--R         + 
+--R                  4 3        6
+--R           - 3456a c  - 5184a c
+--R      *
+--R                          +------------------+  8
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R         4+---+2                2a c\|6
+--R         \|216  cos(---------------------------)
+--R                                 2
+--R     + 
+--R                                 4         3 2        5  8
+--R                       (- 3456a c  + 10368a c  - 7776a )x
+--R                     + 
+--R                                 4        3 2        5  4
+--R                       (- 2304a c  + 6912a c  - 5184a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                               4         3 2        5  6
+--R                       (3456a c  - 10368a c  + 7776a )x
+--R                     + 
+--R                               4        3 2        5  2
+--R                       (2304a c  - 6912a c  + 5184a )x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                             5         2 3         4   8
+--R                       (6912c  - 20736a c  + 15552a c)x
+--R                     + 
+--R                             5         2 3         4   4
+--R                       (4608c  - 13824a c  + 10368a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                               5         2 3         4   6
+--R                       (- 6912c  + 20736a c  - 15552a c)x
+--R                     + 
+--R                               5         2 3         4   2
+--R                       (- 4608c  + 13824a c  - 10368a c)x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                              4         3 2         5  6 4+-+2 4+-+2
+--R                   (- 13824a c  + 41472a c  - 31104a )x  \|2   \|3
+--R                 + 
+--R                            4         3 2         5  6 +-+ +-+
+--R                   (13824a c  - 41472a c  + 31104a )x \|2 \|3
+--R                 + 
+--R                            4         3 2         5  8
+--R                   (20736a c  - 62208a c  + 46656a )x
+--R                 + 
+--R                            4         3 2         5  4
+--R                   (13824a c  - 41472a c  + 31104a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                            4          3 2          5  8
+--R                   (20736a c  - 124416a c  + 139968a )x
+--R                 + 
+--R                            4          2 2         4    7
+--R                   (- 41472c  + 124416a c  - 93312a )d x
+--R                 + 
+--R                            5         2 3         4   6
+--R                   (- 27648c  + 82944a c  - 62208a c)x
+--R                 + 
+--R                            4         3 2         5  4
+--R                   (13824a c  - 82944a c  + 93312a )x
+--R                 + 
+--R                         4         2 2         4    3
+--R                   (9216c  - 27648a c  + 20736a )d x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                              4          3 2          5  8
+--R                   (- 20736a c  + 124416a c  - 139968a )x
+--R                 + 
+--R                          4          2 2         4    7
+--R                   (41472c  - 124416a c  + 93312a )d x
+--R                 + 
+--R                          5         2 3         4   6
+--R                   (27648c  - 82944a c  + 62208a c)x
+--R                 + 
+--R                              4         3 2         5  4
+--R                   (- 13824a c  + 82944a c  - 93312a )x
+--R                 + 
+--R                           4         2 2         4    3
+--R                   (- 9216c  + 27648a c  - 20736a )d x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                          4          3 2          5  10
+--R               (- 31104a c  + 186624a c  - 209952a )x
+--R             + 
+--R                      4          2 2          4    9
+--R               (62208c  - 186624a c  + 139968a )d x
+--R             + 
+--R                      5          2 3         4   8
+--R               (41472c  - 124416a c  + 93312a c)x
+--R             + 
+--R                          4          3 2          5  6
+--R               (- 41472a c  + 248832a c  - 279936a )x
+--R             + 
+--R                      4         2 2         4    5
+--R               (27648c  - 82944a c  + 62208a )d x
+--R             + 
+--R                      5         2 3         4   4
+--R               (27648c  - 82944a c  + 62208a c)x
+--R             + 
+--R                          4         3 2         5  2
+--R               (- 13824a c  + 82944a c  - 93312a )x
+--R             + 
+--R                       4         2 2         4
+--R               (- 9216c  + 27648a c  - 20736a )d x
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                          4         3 2         5  4 4+-+2 4+-+2
+--R               (- 27648a c  + 82944a c  - 62208a )x  \|2   \|3
+--R             + 
+--R                        4         3 2         5  4 +-+ +-+
+--R               (27648a c  - 82944a c  + 62208a )x \|2 \|3
+--R             + 
+--R                        4          3 2         5  6
+--R               (41472a c  - 124416a c  + 93312a )x
+--R             + 
+--R                        4         3 2         5  2
+--R               (27648a c  - 82944a c  + 62208a )x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                    5          2 3          4   4 4+-+2 4+-+2
+--R           (- 55296c  + 165888a c  - 124416a c)x  \|2   \|3
+--R         + 
+--R                  5          2 3          4   4 +-+ +-+
+--R           (55296c  - 165888a c  + 124416a c)x \|2 \|3
+--R         + 
+--R                  5          2 3          4   6
+--R           (82944c  - 248832a c  + 186624a c)x
+--R         + 
+--R                  5          2 3          4   2
+--R           (55296c  - 165888a c  + 124416a c)x
+--R      *
+--R                                         +------------------+  6
+--R                                         |  4      2 2     4
+--R                                        \|4c  - 12a c  + 9a
+--R                                   atan(---------------------)
+--R          +------------------+2                     +-+
+--R         4|  4      2 2     4                  2a c\|6
+--R         \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                2
+--R     + 
+--R                                6        3 4        5 2        7  10
+--R                       (- 864a c  + 2160a c  - 3240a c  + 2916a )x
+--R                     + 
+--R                                6        3 4        5 2        7  6
+--R                       (- 576a c  + 1440a c  - 2160a c  + 1944a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                              6        3 4        5 2        7  8
+--R                       (864a c  - 2160a c  + 3240a c  - 2916a )x
+--R                     + 
+--R                              6        3 4        5 2        7  4
+--R                       (576a c  - 1440a c  + 2160a c  - 1944a )x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                             7        2 5        4 3        6   10
+--R                       (1728c  - 4320a c  + 6480a c  - 5832a c)x
+--R                     + 
+--R                             7        2 5        4 3        6   6
+--R                       (1152c  - 2880a c  + 4320a c  - 3888a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                               7        2 5        4 3        6   8
+--R                       (- 1728c  + 4320a c  - 6480a c  + 5832a c)x
+--R                     + 
+--R                               7        2 5        4 3        6   4
+--R                       (- 1152c  + 2880a c  - 4320a c  + 3888a c)x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                             6        3 4         5 2         7  8 4+-+2 4+-+2
+--R                   (- 3456a c  + 8640a c  - 12960a c  + 11664a )x  \|2   \|3
+--R                 + 
+--R                           6        3 4         5 2         7  8 +-+ +-+
+--R                   (3456a c  - 8640a c  + 12960a c  - 11664a )x \|2 \|3
+--R                 + 
+--R                           6         3 4         5 2         7  10
+--R                   (5184a c  - 12960a c  + 19440a c  - 17496a )x
+--R                 + 
+--R                           6        3 4         5 2         7  6
+--R                   (3456a c  - 8640a c  + 12960a c  - 11664a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                             6         3 4        5 2         7  10
+--R                   (- 3456a c  + 15552a c  + 7776a c  - 34992a )x
+--R                 + 
+--R                           6         2 4         4 2         6    9
+--R                   (- 6912c  + 17280a c  - 25920a c  + 23328a )d x
+--R                 + 
+--R                           7         2 5         4 3         6   8
+--R                   (- 6912c  + 17280a c  - 25920a c  + 23328a c)x
+--R                 + 
+--R                             6         3 4        5 2         7  6
+--R                   (- 2304a c  + 10368a c  + 5184a c  - 23328a )x
+--R                 + 
+--R                         6         2 4         4 2         6    5
+--R                   (4608c  - 11520a c  + 17280a c  - 15552a )d x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                           6         3 4        5 2         7  10
+--R                   (3456a c  - 15552a c  - 7776a c  + 34992a )x
+--R                 + 
+--R                         6         2 4         4 2         6    9
+--R                   (6912c  - 17280a c  + 25920a c  - 23328a )d x
+--R                 + 
+--R                         7         2 5         4 3         6   8
+--R                   (6912c  - 17280a c  + 25920a c  - 23328a c)x
+--R                 + 
+--R                           6         3 4        5 2         7  6
+--R                   (2304a c  - 10368a c  - 5184a c  + 23328a )x
+--R                 + 
+--R                           6         2 4         4 2         6    5
+--R                   (- 4608c  + 11520a c  - 17280a c  + 15552a )d x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                       6         3 4         5 2         7  12
+--R               (5184a c  - 23328a c  - 11664a c  + 52488a )x
+--R             + 
+--R                      6         2 4         4 2         6    11
+--R               (10368c  - 25920a c  + 38880a c  - 34992a )d x
+--R             + 
+--R                      7         2 5         4 3         6   10
+--R               (10368c  - 25920a c  + 38880a c  - 34992a c)x
+--R             + 
+--R                       6         3 4         5 2         7  8
+--R               (6912a c  - 31104a c  - 15552a c  + 69984a )x
+--R             + 
+--R                     7         2 5         4 3         6   6
+--R               (6912c  - 17280a c  + 25920a c  - 23328a c)x
+--R             + 
+--R                       6         3 4        5 2         7  4
+--R               (2304a c  - 10368a c  - 5184a c  + 23328a )x
+--R             + 
+--R                       6         2 4         4 2         6    3
+--R               (- 4608c  + 11520a c  - 17280a c  + 15552a )d x
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                         6         3 4         5 2         7  6 4+-+2 4+-+2
+--R               (- 6912a c  + 17280a c  - 25920a c  + 23328a )x  \|2   \|3
+--R             + 
+--R                       6         3 4         5 2         7  6 +-+ +-+
+--R               (6912a c  - 17280a c  + 25920a c  - 23328a )x \|2 \|3
+--R             + 
+--R                        6         3 4         5 2         7  8
+--R               (10368a c  - 25920a c  + 38880a c  - 34992a )x
+--R             + 
+--R                       6         3 4         5 2         7  4
+--R               (6912a c  - 17280a c  + 25920a c  - 23328a )x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                    7         2 5         4 3         6   6 4+-+2 4+-+2
+--R           (- 13824c  + 34560a c  - 51840a c  + 46656a c)x  \|2   \|3
+--R         + 
+--R                  7         2 5         4 3         6   6 +-+ +-+
+--R           (13824c  - 34560a c  + 51840a c  - 46656a c)x \|2 \|3
+--R         + 
+--R                  7         2 5         4 3         6   8
+--R           (20736c  - 51840a c  + 77760a c  - 69984a c)x
+--R         + 
+--R                  7         2 5         4 3         6   4
+--R           (13824c  - 34560a c  + 51840a c  - 46656a c)x
+--R      *
+--R                          +------------------+  4
+--R                          |  4      2 2     4
+--R                         \|4c  - 12a c  + 9a
+--R                    atan(---------------------)
+--R                                     +-+
+--R         4+---+2                2a c\|6
+--R         \|216  cos(---------------------------)
+--R                                 2
+--R     + 
+--R                                 4         3 2         5  12
+--R                       (- 5184a c  + 15552a c  - 11664a )x
+--R                     + 
+--R                                 4         3 2        5  8
+--R                       (- 3456a c  + 10368a c  - 7776a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                               4         3 2         5  10
+--R                       (5184a c  - 15552a c  + 11664a )x
+--R                     + 
+--R                               4         3 2        5  6
+--R                       (3456a c  - 10368a c  + 7776a )x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                              5         2 3         4   12
+--R                       (10368c  - 31104a c  + 23328a c)x
+--R                     + 
+--R                             5         2 3         4   8
+--R                       (6912c  - 20736a c  + 15552a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                                5         2 3         4   10
+--R                       (- 10368c  + 31104a c  - 23328a c)x
+--R                     + 
+--R                               5         2 3         4   6
+--R                       (- 6912c  + 20736a c  - 15552a c)x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                              4         3 2         5  10 4+-+2 4+-+2
+--R                   (- 20736a c  + 62208a c  - 46656a )x   \|2   \|3
+--R                 + 
+--R                            4         3 2         5  10 +-+ +-+
+--R                   (20736a c  - 62208a c  + 46656a )x  \|2 \|3
+--R                 + 
+--R                            4         3 2         5  12
+--R                   (31104a c  - 93312a c  + 69984a )x
+--R                 + 
+--R                            4         3 2         5  8
+--R                   (20736a c  - 62208a c  + 46656a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                              4         5  12
+--R                   (- 31104a c  + 69984a )x
+--R                 + 
+--R                            4         2 2         4    11
+--R                   (- 20736c  + 62208a c  - 46656a )d x
+--R                 + 
+--R                            5          2 3         4   10
+--R                   (- 41472c  + 124416a c  - 93312a c)x
+--R                 + 
+--R                              4         5  8
+--R                   (- 20736a c  + 46656a )x
+--R                 + 
+--R                          4          2 2         4    7
+--R                   (41472c  - 124416a c  + 93312a )d x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                            4         5  12
+--R                   (31104a c  - 69984a )x
+--R                 + 
+--R                          4         2 2         4    11
+--R                   (20736c  - 62208a c  + 46656a )d x
+--R                 + 
+--R                          5          2 3         4   10
+--R                   (41472c  - 124416a c  + 93312a c)x
+--R                 + 
+--R                            4         5  8
+--R                   (20736a c  - 46656a )x
+--R                 + 
+--R                            4          2 2         4    7
+--R                   (- 41472c  + 124416a c  - 93312a )d x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                        4          5  14          4         2 2         4    13
+--R               (46656a c  - 104976a )x   + (31104c  - 93312a c  + 69984a )d x
+--R             + 
+--R                      5          2 3          4   12            4          5  10
+--R               (62208c  - 186624a c  + 139968a c)x   + (62208a c  - 139968a )x
+--R             + 
+--R                        4          2 2         4    9
+--R               (- 41472c  + 124416a c  - 93312a )d x
+--R             + 
+--R                      5          2 3         4   8            4         5  6
+--R               (41472c  - 124416a c  + 93312a c)x  + (20736a c  - 46656a )x
+--R             + 
+--R                        4          2 2         4    5
+--R               (- 41472c  + 124416a c  - 93312a )d x
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                          4          3 2         5  8 4+-+2 4+-+2
+--R               (- 41472a c  + 124416a c  - 93312a )x  \|2   \|3
+--R             + 
+--R                        4          3 2         5  8 +-+ +-+
+--R               (41472a c  - 124416a c  + 93312a )x \|2 \|3
+--R             + 
+--R                        4          3 2          5  10
+--R               (62208a c  - 186624a c  + 139968a )x
+--R             + 
+--R                        4          3 2         5  6
+--R               (41472a c  - 124416a c  + 93312a )x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                    5          2 3          4   8 4+-+2 4+-+2
+--R           (- 82944c  + 248832a c  - 186624a c)x  \|2   \|3
+--R         + 
+--R                  5          2 3          4   8 +-+ +-+
+--R           (82944c  - 248832a c  + 186624a c)x \|2 \|3
+--R         + 
+--R                   5          2 3          4   10
+--R           (124416c  - 373248a c  + 279936a c)x
+--R         + 
+--R                  5          2 3          4   6
+--R           (82944c  - 248832a c  + 186624a c)x
+--R      *
+--R                                         +------------------+  2
+--R                                         |  4      2 2     4
+--R                                        \|4c  - 12a c  + 9a
+--R                                   atan(---------------------)
+--R          +------------------+2                     +-+
+--R         4|  4      2 2     4                  2a c\|6
+--R         \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                2
+--R     + 
+--R                                6       3 4       5 2       7  14
+--R                       (- 216a c  - 324a c  + 486a c  + 729a )x
+--R                     + 
+--R                                6       3 4       5 2       7  10
+--R                       (- 144a c  - 216a c  + 324a c  + 486a )x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                              6       3 4       5 2       7  12
+--R                       (216a c  + 324a c  - 486a c  - 729a )x
+--R                     + 
+--R                              6       3 4       5 2       7  8
+--R                       (144a c  + 216a c  - 324a c  - 486a )x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+ +-+
+--R                 \|3 \|6
+--R             + 
+--R                            7       2 5       4 3        6   14
+--R                       (432c  + 648a c  - 972a c  - 1458a c)x
+--R                     + 
+--R                            7       2 5       4 3       6   10
+--R                       (288c  + 432a c  - 648a c  - 972a c)x
+--R                  *
+--R                     4+-+3 +-+
+--R                     \|2  \|3
+--R                 + 
+--R                              7       2 5       4 3        6   12
+--R                       (- 432c  - 648a c  + 972a c  + 1458a c)x
+--R                     + 
+--R                              7       2 5       4 3       6   8
+--R                       (- 288c  - 432a c  + 648a c  + 972a c)x
+--R                  *
+--R                      +-+4+-+3
+--R                     \|2 \|2
+--R              *
+--R                 4+-+
+--R                 \|3
+--R          *
+--R             4+-+3
+--R             \|6
+--R         + 
+--R                            6        3 4        5 2        7  12 4+-+2 4+-+2
+--R                   (- 864a c  - 1296a c  + 1944a c  + 2916a )x   \|2   \|3
+--R                 + 
+--R                          6        3 4        5 2        7  12 +-+ +-+
+--R                   (864a c  + 1296a c  - 1944a c  - 2916a )x  \|2 \|3
+--R                 + 
+--R                           6        3 4        5 2        7  14
+--R                   (1296a c  + 1944a c  - 2916a c  - 4374a )x
+--R                 + 
+--R                          6        3 4        5 2        7  10
+--R                   (864a c  + 1296a c  - 1944a c  - 2916a )x
+--R              *
+--R                  +-+
+--R                 \|6
+--R             + 
+--R                           7        2 5        4 3        6   12
+--R                   (- 1728c  - 2592a c  + 3888a c  + 5832a c)x
+--R                 + 
+--R                         6        2 4        4 2        6    9
+--R                   (2304c  + 3456a c  - 5184a c  - 7776a )d x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                         7        2 5        4 3        6   12
+--R                   (1728c  + 2592a c  - 3888a c  - 5832a c)x
+--R                 + 
+--R                           6        2 4        4 2        6    9
+--R                   (- 2304c  - 3456a c  + 5184a c  + 7776a )d x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                     7        2 5        4 3        6   14
+--R               (2592c  + 3888a c  - 5832a c  - 8748a c)x
+--R             + 
+--R                       6        2 4        4 2         6    11
+--R               (- 3456c  - 5184a c  + 7776a c  + 11664a )d x
+--R             + 
+--R                     7        2 5        4 3        6   10
+--R               (1728c  + 2592a c  - 3888a c  - 5832a c)x
+--R             + 
+--R                       6        2 4        4 2        6    7
+--R               (- 2304c  - 3456a c  + 5184a c  + 7776a )d x
+--R          *
+--R             4+-+2
+--R             \|6
+--R         + 
+--R                         6        3 4        5 2        7  10 4+-+2 4+-+2
+--R               (- 1728a c  - 2592a c  + 3888a c  + 5832a )x   \|2   \|3
+--R             + 
+--R                       6        3 4        5 2        7  10 +-+ +-+
+--R               (1728a c  + 2592a c  - 3888a c  - 5832a )x  \|2 \|3
+--R             + 
+--R                       6        3 4        5 2        7  12
+--R               (2592a c  + 3888a c  - 5832a c  - 8748a )x
+--R             + 
+--R                       6        3 4        5 2        7  8
+--R               (1728a c  + 2592a c  - 3888a c  - 5832a )x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                   7        2 5        4 3         6   10 4+-+2 4+-+2
+--R           (- 3456c  - 5184a c  + 7776a c  + 11664a c)x   \|2   \|3
+--R         + 
+--R                 7        2 5        4 3         6   10 +-+ +-+
+--R           (3456c  + 5184a c  - 7776a c  - 11664a c)x  \|2 \|3
+--R         + 
+--R                 7        2 5         4 3         6   12
+--R           (5184c  + 7776a c  - 11664a c  - 17496a c)x
+--R         + 
+--R                 7        2 5        4 3         6   8
+--R           (3456c  + 5184a c  - 7776a c  - 11664a c)x
+--R      *
+--R         4+---+2
+--R         \|216
+--R  /
+--R                     6        2 4         4 2         6  6
+--R               (4608c  + 6912a c  - 10368a c  - 15552a )x
+--R             + 
+--R                     6        2 4        4 2         6  2
+--R               (3072c  + 4608a c  - 6912a c  - 10368a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                       6        2 4         4 2         6  6
+--R               (- 4608c  - 6912a c  + 10368a c  + 15552a )x
+--R             + 
+--R                       6        2 4        4 2         6  2
+--R               (- 3072c  - 4608a c  + 6912a c  + 10368a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                   6         2 4         4 2         6  8
+--R           (- 6912c  - 10368a c  + 15552a c  + 23328a )x
+--R         + 
+--R                   6         2 4         4 2         6  4        6        2 4
+--R           (- 9216c  - 13824a c  + 20736a c  + 31104a )x  - 3072c  - 4608a c
+--R         + 
+--R                4 2         6
+--R           6912a c  + 10368a
+--R      *
+--R                                +------------------+  8
+--R                                |  4      2 2     4
+--R                               \|4c  - 12a c  + 9a
+--R                          atan(---------------------)
+--R                                           +-+
+--R         4+-+2 4+---+2                2a c\|6
+--R         \|6   \|216  sin(---------------------------)
+--R                                       2
+--R     + 
+--R                          6         2 4         4 2         6  6
+--R                   (18432c  + 27648a c  - 41472a c  - 62208a )x
+--R                 + 
+--R                          6         2 4         4 2         6  2
+--R                   (12288c  + 18432a c  - 27648a c  - 41472a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                            6         2 4         4 2         6  6
+--R                   (- 18432c  - 27648a c  + 41472a c  + 62208a )x
+--R                 + 
+--R                            6         2 4         4 2         6  2
+--R                   (- 12288c  - 18432a c  + 27648a c  + 41472a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                        6         2 4         4 2         6  8
+--R               (- 27648c  - 41472a c  + 62208a c  + 93312a )x
+--R             + 
+--R                        6         2 4         4 2          6  4         6
+--R               (- 36864c  - 55296a c  + 82944a c  + 124416a )x  - 12288c
+--R             + 
+--R                       2 4         4 2         6
+--R               - 18432a c  + 27648a c  + 41472a
+--R          *
+--R                                    +------------------+  2
+--R                                    |  4      2 2     4
+--R                                   \|4c  - 12a c  + 9a
+--R                              atan(---------------------)
+--R                                               +-+
+--R             4+-+2 4+---+2                2a c\|6
+--R             \|6   \|216  cos(---------------------------)
+--R                                           2
+--R         + 
+--R                             4          2 2          4  8
+--R                   (- 165888c  + 497664a c  - 373248a )x
+--R                 + 
+--R                             4          2 2          4  4
+--R                   (- 110592c  + 331776a c  - 248832a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                           4          2 2          4  8
+--R                   (165888c  - 497664a c  + 373248a )x
+--R                 + 
+--R                           4          2 2          4  4
+--R                   (110592c  - 331776a c  + 248832a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                       4          2 2          4  10
+--R               (248832c  - 746496a c  + 559872a )x
+--R             + 
+--R                       4          2 2          4  6
+--R               (331776c  - 995328a c  + 746496a )x
+--R             + 
+--R                       4          2 2          4  2
+--R               (110592c  - 331776a c  + 248832a )x
+--R          *
+--R                    +------------------+2
+--R             4+-+2 4|  4      2 2     4
+--R             \|6   \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+  6
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                         8              4 4+-+2 4+-+2
+--R           (- 165888a c x  - 110592a c x )\|2   \|3
+--R         + 
+--R                       8              4  +-+ +-+              10              6
+--R           (165888a c x  + 110592a c x )\|2 \|3  + 248832a c x   + 331776a c x
+--R         + 
+--R                      2
+--R           110592a c x
+--R      *
+--R                   +------------------+ +------------------+2
+--R          +-+4+-+2 |  4      2 2     4 4|  4      2 2     4
+--R         \|6 \|6  \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+            +------------------+  5
+--R                   |  4      2 2     4             |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a             \|4c  - 12a c  + 9a
+--R             atan(---------------------)     atan(---------------------)
+--R                              +-+                             +-+
+--R                         2a c\|6                         2a c\|6
+--R         cos(---------------------------)sin(---------------------------)
+--R                          2                               2
+--R     + 
+--R                          6         2 4         4 2         6  6
+--R                   (27648c  + 41472a c  - 62208a c  - 93312a )x
+--R                 + 
+--R                          6         2 4         4 2         6  2
+--R                   (18432c  + 27648a c  - 41472a c  - 62208a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                            6         2 4         4 2         6  6
+--R                   (- 27648c  - 41472a c  + 62208a c  + 93312a )x
+--R                 + 
+--R                            6         2 4         4 2         6  2
+--R                   (- 18432c  - 27648a c  + 41472a c  + 62208a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                        6         2 4         4 2          6  8
+--R               (- 41472c  - 62208a c  + 93312a c  + 139968a )x
+--R             + 
+--R                        6         2 4          4 2          6  4         6
+--R               (- 55296c  - 82944a c  + 124416a c  + 186624a )x  - 18432c
+--R             + 
+--R                       2 4         4 2         6
+--R               - 27648a c  + 41472a c  + 62208a
+--R          *
+--R                                    +------------------+  4
+--R                                    |  4      2 2     4
+--R                                   \|4c  - 12a c  + 9a
+--R                              atan(---------------------)
+--R                                               +-+
+--R             4+-+2 4+---+2                2a c\|6
+--R             \|6   \|216  cos(---------------------------)
+--R                                           2
+--R         + 
+--R                             4          2 2          4  8
+--R                   (- 165888c  + 497664a c  - 373248a )x
+--R                 + 
+--R                             4          2 2          4  4
+--R                   (- 110592c  + 331776a c  - 248832a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                           4          2 2          4  8
+--R                   (165888c  - 497664a c  + 373248a )x
+--R                 + 
+--R                           4          2 2          4  4
+--R                   (110592c  - 331776a c  + 248832a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                       4          2 2          4  10
+--R               (248832c  - 746496a c  + 559872a )x
+--R             + 
+--R                       4          2 2          4  6
+--R               (331776c  - 995328a c  + 746496a )x
+--R             + 
+--R                       4          2 2          4  2
+--R               (110592c  - 331776a c  + 248832a )x
+--R          *
+--R                                                   +------------------+  2
+--R                                                   |  4      2 2     4
+--R                                                  \|4c  - 12a c  + 9a
+--R                                             atan(---------------------)
+--R                    +------------------+2                     +-+
+--R             4+-+2 4|  4      2 2     4                  2a c\|6
+--R             \|6   \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                          2
+--R         + 
+--R                          6          2 4          4 2          6  10
+--R                   (41472c  - 103680a c  + 155520a c  - 139968a )x
+--R                 + 
+--R                          6         2 4          4 2         6  6
+--R                   (27648c  - 69120a c  + 103680a c  - 93312a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                            6          2 4          4 2          6  10
+--R                   (- 41472c  + 103680a c  - 155520a c  + 139968a )x
+--R                 + 
+--R                            6         2 4          4 2         6  6
+--R                   (- 27648c  + 69120a c  - 103680a c  + 93312a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                        6          2 4          4 2          6  12
+--R               (- 62208c  + 155520a c  - 233280a c  + 209952a )x
+--R             + 
+--R                        6          2 4          4 2          6  8
+--R               (- 82944c  + 207360a c  - 311040a c  + 279936a )x
+--R             + 
+--R                        6         2 4          4 2         6  4
+--R               (- 27648c  + 69120a c  - 103680a c  + 93312a )x
+--R          *
+--R             4+-+2 4+---+2
+--R             \|6   \|216
+--R      *
+--R                   +------------------+  4
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                             8              4 4+-+2 4+-+2
+--R               (- 331776a c x  - 221184a c x )\|2   \|3
+--R             + 
+--R                           8              4  +-+ +-+              10
+--R               (331776a c x  + 221184a c x )\|2 \|3  + 497664a c x
+--R             + 
+--R                          6              2
+--R               663552a c x  + 221184a c x
+--R          *
+--R                       +------------------+ +------------------+2
+--R              +-+4+-+2 |  4      2 2     4 4|  4      2 2     4
+--R             \|6 \|6  \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+  3
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                         3         3   10            3         3   6 4+-+2 4+-+2
+--R               ((55296a c  - 82944a c)x   + (36864a c  - 55296a c)x )\|2   \|3
+--R             + 
+--R                             3         3   10              3         3   6  +-+
+--R                 ((- 55296a c  + 82944a c)x   + (- 36864a c  + 55296a c)x )\|2
+--R              *
+--R                  +-+
+--R                 \|3
+--R             + 
+--R                          3          3   12               3          3   8
+--R               (- 82944a c  + 124416a c)x   + (- 110592a c  + 165888a c)x
+--R             + 
+--R                          3         3   4
+--R               (- 36864a c  + 55296a c)x
+--R          *
+--R                                                           +------------------+
+--R                                                           |  4      2 2     4
+--R                                                          \|4c  - 12a c  + 9a
+--R                                                     atan(---------------------)
+--R                             +------------------+                     +-+
+--R            +-+4+-+2 4+---+2 |  4      2 2     4                 2a c\|6
+--R           \|6 \|6   \|216  \|4c  - 12a c  + 9a  cos(---------------------------)
+--R                                                                  2
+--R      *
+--R                   +------------------+  3
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                          6         2 4         4 2         6  6
+--R                   (18432c  + 27648a c  - 41472a c  - 62208a )x
+--R                 + 
+--R                          6         2 4         4 2         6  2
+--R                   (12288c  + 18432a c  - 27648a c  - 41472a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                            6         2 4         4 2         6  6
+--R                   (- 18432c  - 27648a c  + 41472a c  + 62208a )x
+--R                 + 
+--R                            6         2 4         4 2         6  2
+--R                   (- 12288c  - 18432a c  + 27648a c  + 41472a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                        6         2 4         4 2         6  8
+--R               (- 27648c  - 41472a c  + 62208a c  + 93312a )x
+--R             + 
+--R                        6         2 4         4 2          6  4         6
+--R               (- 36864c  - 55296a c  + 82944a c  + 124416a )x  - 12288c
+--R             + 
+--R                       2 4         4 2         6
+--R               - 18432a c  + 27648a c  + 41472a
+--R          *
+--R                                    +------------------+  6
+--R                                    |  4      2 2     4
+--R                                   \|4c  - 12a c  + 9a
+--R                              atan(---------------------)
+--R                                               +-+
+--R             4+-+2 4+---+2                2a c\|6
+--R             \|6   \|216  cos(---------------------------)
+--R                                           2
+--R         + 
+--R                           4          2 2          4  8
+--R                   (165888c  - 497664a c  + 373248a )x
+--R                 + 
+--R                           4          2 2          4  4
+--R                   (110592c  - 331776a c  + 248832a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                             4          2 2          4  8
+--R                   (- 165888c  + 497664a c  - 373248a )x
+--R                 + 
+--R                             4          2 2          4  4
+--R                   (- 110592c  + 331776a c  - 248832a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                         4          2 2          4  10
+--R               (- 248832c  + 746496a c  - 559872a )x
+--R             + 
+--R                         4          2 2          4  6
+--R               (- 331776c  + 995328a c  - 746496a )x
+--R             + 
+--R                         4          2 2          4  2
+--R               (- 110592c  + 331776a c  - 248832a )x
+--R          *
+--R                                                   +------------------+  4
+--R                                                   |  4      2 2     4
+--R                                                  \|4c  - 12a c  + 9a
+--R                                             atan(---------------------)
+--R                    +------------------+2                     +-+
+--R             4+-+2 4|  4      2 2     4                  2a c\|6
+--R             \|6   \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                          2
+--R         + 
+--R                            6          2 4           4 2         6  10
+--R                   (- 27648c  + 953856a c  - 1430784a c  + 93312a )x
+--R                 + 
+--R                            6          2 4          4 2         6  6
+--R                   (- 18432c  + 635904a c  - 953856a c  + 62208a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                          6          2 4           4 2         6  10
+--R                   (27648c  - 953856a c  + 1430784a c  - 93312a )x
+--R                 + 
+--R                          6          2 4          4 2         6  6
+--R                   (18432c  - 635904a c  + 953856a c  - 62208a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                      6           2 4           4 2          6  12
+--R               (41472c  - 1430784a c  + 2146176a c  - 139968a )x
+--R             + 
+--R                      6           2 4           4 2          6  8
+--R               (55296c  - 1907712a c  + 2861568a c  - 186624a )x
+--R             + 
+--R                      6          2 4          4 2         6  4
+--R               (18432c  - 635904a c  + 953856a c  - 62208a )x
+--R          *
+--R                                    +------------------+  2
+--R                                    |  4      2 2     4
+--R                                   \|4c  - 12a c  + 9a
+--R                              atan(---------------------)
+--R                                               +-+
+--R             4+-+2 4+---+2                2a c\|6
+--R             \|6   \|216  cos(---------------------------)
+--R                                           2
+--R         + 
+--R                             4          2 2          4  12
+--R                   (- 248832c  + 746496a c  - 559872a )x
+--R                 + 
+--R                             4          2 2          4  8
+--R                   (- 165888c  + 497664a c  - 373248a )x
+--R              *
+--R                 4+-+2 4+-+2
+--R                 \|2   \|3
+--R             + 
+--R                           4          2 2          4  12
+--R                   (248832c  - 746496a c  + 559872a )x
+--R                 + 
+--R                           4          2 2          4  8
+--R                   (165888c  - 497664a c  + 373248a )x
+--R              *
+--R                  +-+ +-+
+--R                 \|2 \|3
+--R             + 
+--R                       4           2 2          4  14
+--R               (373248c  - 1119744a c  + 839808a )x
+--R             + 
+--R                       4           2 2           4  10
+--R               (497664c  - 1492992a c  + 1119744a )x
+--R             + 
+--R                       4          2 2          4  6
+--R               (165888c  - 497664a c  + 373248a )x
+--R          *
+--R                    +------------------+2
+--R             4+-+2 4|  4      2 2     4
+--R             \|6   \|4c  + 12a c  + 9a
+--R      *
+--R                   +------------------+  2
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                             8              4 4+-+2 4+-+2
+--R               (- 165888a c x  - 110592a c x )\|2   \|3
+--R             + 
+--R                           8              4  +-+ +-+              10
+--R               (165888a c x  + 110592a c x )\|2 \|3  + 248832a c x
+--R             + 
+--R                          6              2
+--R               331776a c x  + 110592a c x
+--R          *
+--R                       +------------------+ +------------------+2
+--R              +-+4+-+2 |  4      2 2     4 4|  4      2 2     4
+--R             \|6 \|6  \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+  5
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                             3         3   10              3         3   6 4+-+2
+--R                 ((- 55296a c  + 82944a c)x   + (- 36864a c  + 55296a c)x )\|2
+--R              *
+--R                 4+-+2
+--R                 \|3
+--R             + 
+--R                         3         3   10            3         3   6  +-+ +-+
+--R               ((55296a c  - 82944a c)x   + (36864a c  - 55296a c)x )\|2 \|3
+--R             + 
+--R                        3          3   12             3          3   8
+--R               (82944a c  - 124416a c)x   + (110592a c  - 165888a c)x
+--R             + 
+--R                        3         3   4
+--R               (36864a c  - 55296a c)x
+--R          *
+--R                               +------------------+
+--R              +-+4+-+2 4+---+2 |  4      2 2     4
+--R             \|6 \|6   \|216  \|4c  - 12a c  + 9a
+--R          *
+--R                       +------------------+  3
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R         + 
+--R                             12              8 4+-+2 4+-+2
+--R               (- 248832a c x   - 165888a c x )\|2   \|3
+--R             + 
+--R                           12              8  +-+ +-+              14
+--R               (248832a c x   + 165888a c x )\|2 \|3  + 373248a c x
+--R             + 
+--R                          10              6
+--R               497664a c x   + 165888a c x
+--R          *
+--R                       +------------------+ +------------------+2
+--R              +-+4+-+2 |  4      2 2     4 4|  4      2 2     4
+--R             \|6 \|6  \|4c  - 12a c  + 9a  \|4c  + 12a c  + 9a
+--R          *
+--R                       +------------------+
+--R                       |  4      2 2     4
+--R                      \|4c  - 12a c  + 9a
+--R                 atan(---------------------)
+--R                                  +-+
+--R                             2a c\|6
+--R             cos(---------------------------)
+--R                              2
+--R      *
+--R                   +------------------+
+--R                   |  4      2 2     4
+--R                  \|4c  - 12a c  + 9a
+--R             atan(---------------------)
+--R                              +-+
+--R                         2a c\|6
+--R         sin(---------------------------)
+--R                          2
+--R     + 
+--R                     6        2 4         4 2         6  6
+--R               (4608c  + 6912a c  - 10368a c  - 15552a )x
+--R             + 
+--R                     6        2 4        4 2         6  2
+--R               (3072c  + 4608a c  - 6912a c  - 10368a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                       6        2 4         4 2         6  6
+--R               (- 4608c  - 6912a c  + 10368a c  + 15552a )x
+--R             + 
+--R                       6        2 4        4 2         6  2
+--R               (- 3072c  - 4608a c  + 6912a c  + 10368a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                   6         2 4         4 2         6  8
+--R           (- 6912c  - 10368a c  + 15552a c  + 23328a )x
+--R         + 
+--R                   6         2 4         4 2         6  4        6        2 4
+--R           (- 9216c  - 13824a c  + 20736a c  + 31104a )x  - 3072c  - 4608a c
+--R         + 
+--R                4 2         6
+--R           6912a c  + 10368a
+--R      *
+--R                                +------------------+  8
+--R                                |  4      2 2     4
+--R                               \|4c  - 12a c  + 9a
+--R                          atan(---------------------)
+--R                                           +-+
+--R         4+-+2 4+---+2                2a c\|6
+--R         \|6   \|216  cos(---------------------------)
+--R                                       2
+--R     + 
+--R                       4          2 2          4  8
+--R               (165888c  - 497664a c  + 373248a )x
+--R             + 
+--R                       4          2 2          4  4
+--R               (110592c  - 331776a c  + 248832a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                         4          2 2          4  8
+--R               (- 165888c  + 497664a c  - 373248a )x
+--R             + 
+--R                         4          2 2          4  4
+--R               (- 110592c  + 331776a c  - 248832a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                     4          2 2          4  10
+--R           (- 248832c  + 746496a c  - 559872a )x
+--R         + 
+--R                     4          2 2          4  6
+--R           (- 331776c  + 995328a c  - 746496a )x
+--R         + 
+--R                     4          2 2          4  2
+--R           (- 110592c  + 331776a c  - 248832a )x
+--R      *
+--R                                               +------------------+  6
+--R                                               |  4      2 2     4
+--R                                              \|4c  - 12a c  + 9a
+--R                                         atan(---------------------)
+--R                +------------------+2                     +-+
+--R         4+-+2 4|  4      2 2     4                  2a c\|6
+--R         \|6   \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                      2
+--R     + 
+--R                      6          2 4          4 2          6  10
+--R               (41472c  - 103680a c  + 155520a c  - 139968a )x
+--R             + 
+--R                      6         2 4          4 2         6  6
+--R               (27648c  - 69120a c  + 103680a c  - 93312a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                        6          2 4          4 2          6  10
+--R               (- 41472c  + 103680a c  - 155520a c  + 139968a )x
+--R             + 
+--R                        6         2 4          4 2         6  6
+--R               (- 27648c  + 69120a c  - 103680a c  + 93312a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                    6          2 4          4 2          6  12
+--R           (- 62208c  + 155520a c  - 233280a c  + 209952a )x
+--R         + 
+--R                    6          2 4          4 2          6  8
+--R           (- 82944c  + 207360a c  - 311040a c  + 279936a )x
+--R         + 
+--R                    6         2 4          4 2         6  4
+--R           (- 27648c  + 69120a c  - 103680a c  + 93312a )x
+--R      *
+--R                                +------------------+  4
+--R                                |  4      2 2     4
+--R                               \|4c  - 12a c  + 9a
+--R                          atan(---------------------)
+--R                                           +-+
+--R         4+-+2 4+---+2                2a c\|6
+--R         \|6   \|216  cos(---------------------------)
+--R                                       2
+--R     + 
+--R                       4          2 2          4  12
+--R               (248832c  - 746496a c  + 559872a )x
+--R             + 
+--R                       4          2 2          4  8
+--R               (165888c  - 497664a c  + 373248a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                         4          2 2          4  12
+--R               (- 248832c  + 746496a c  - 559872a )x
+--R             + 
+--R                         4          2 2          4  8
+--R               (- 165888c  + 497664a c  - 373248a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                     4           2 2          4  14
+--R           (- 373248c  + 1119744a c  - 839808a )x
+--R         + 
+--R                     4           2 2           4  10
+--R           (- 497664c  + 1492992a c  - 1119744a )x
+--R         + 
+--R                     4          2 2          4  6
+--R           (- 165888c  + 497664a c  - 373248a )x
+--R      *
+--R                                               +------------------+  2
+--R                                               |  4      2 2     4
+--R                                              \|4c  - 12a c  + 9a
+--R                                         atan(---------------------)
+--R                +------------------+2                     +-+
+--R         4+-+2 4|  4      2 2     4                  2a c\|6
+--R         \|6   \|4c  + 12a c  + 9a   cos(---------------------------)
+--R                                                      2
+--R     + 
+--R                      6         2 4         4 2         6  14
+--R               (10368c  + 15552a c  - 23328a c  - 34992a )x
+--R             + 
+--R                     6         2 4         4 2         6  10
+--R               (6912c  + 10368a c  - 15552a c  - 23328a )x
+--R          *
+--R             4+-+2 4+-+2
+--R             \|2   \|3
+--R         + 
+--R                        6         2 4         4 2         6  14
+--R               (- 10368c  - 15552a c  + 23328a c  + 34992a )x
+--R             + 
+--R                       6         2 4         4 2         6  10
+--R               (- 6912c  - 10368a c  + 15552a c  + 23328a )x
+--R          *
+--R              +-+ +-+
+--R             \|2 \|3
+--R         + 
+--R                    6         2 4         4 2         6  16
+--R           (- 15552c  - 23328a c  + 34992a c  + 52488a )x
+--R         + 
+--R                    6         2 4         4 2         6  12
+--R           (- 20736c  - 31104a c  + 46656a c  + 69984a )x
+--R         + 
+--R                   6         2 4         4 2         6  8
+--R           (- 6912c  - 10368a c  + 15552a c  + 23328a )x
+--R      *
+--R         4+-+2 4+---+2
+--R         \|6   \|216
+--R                                                    Type: Expression(Integer)
+--E 658
+
+)clear all
+
+--S 659 of 953
+t0:=(b*x+c*x^2+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + b x
+--R   (1)  -----------------
+--R               4
+--R             3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 659
+
+--S 660 of 953
+r0:=-1/2*c*atan(1-6^(1/4)*x)/6^(3/4)+1/2*c*atan(1+6^(1/4)*x)/6^(3/4)+_
+   1/12*d*log(2+3*x^4)+1/4*c*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/_
+   6^(3/4)-1/4*c*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)+_
+   1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R            +-+      4+-+3 4+-+   2 +-+    +-+      +-+4+-+3      4
+--R       - 3c\|6 log(x \|2   \|3 + x \|3  + \|2 ) + d\|6 \|6  log(3x  + 2)
+--R     + 
+--R          +-+        4+-+3 4+-+   2 +-+    +-+       +-+      4+-+
+--R       3c\|6 log(- x \|2   \|3 + x \|3  + \|2 ) + 6c\|6 atan(x\|6  + 1)
+--R     + 
+--R                                             2 +-+
+--R          +-+      4+-+           4+-+3     x \|3
+--R       6c\|6 atan(x\|6  - 1) + 6b \|6  atan(------)
+--R                                              +-+
+--R                                             \|2
+--R  /
+--R        +-+4+-+3
+--R     12\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           ROOT
+--R                          2                                    2
+--R                - 108%%DB1  + (- 72%%DB0 + 24d)%%DB1 - 108%%DB0  + 24d %%DB0
+--R              + 
+--R                    2     2
+--R                - 2d  - 3b
+--R         + 
+--R           - 6%%DB1 - 6%%DB0 + 2d
+--R      *
+--R         log
+--R                       2           2       3               2       3
+--R                  (288c %%DB0 - 24c d + 72b )%%DB1 + (- 24c d + 72b )%%DB0
+--R                + 
+--R                    2 2      3      2 2
+--R                  2c d  - 12b d + 3b c
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%DB1  + (- 72%%DB0 + 24d)%%DB1 - 108%%DB0
+--R                   + 
+--R                                   2     2
+--R                     24d %%DB0 - 2d  - 3b
+--R            + 
+--R                    2            2        3      2
+--R              (1728c %%DB0 - 144c d + 432b )%%DB1
+--R            + 
+--R                    2     2       2             2 2      3       2 2
+--R              (1728c %%DB0  - 576c d %%DB0 + 36c d  - 72b d - 18b c )%%DB1
+--R            + 
+--R                     2        3      2       2 2      3       2 2
+--R              (- 144c d + 432b )%%DB0  + (36c d  - 72b d - 18b c )%%DB0
+--R            + 
+--R                 5      4        2 3     3 2     2 2        4     5
+--R              (3c  - 18b c)x - 2c d  + 6b d  + 3b c d - 3b c  + 9b
+--R     + 
+--R           -
+--R              ROOT
+--R                             2                                    2
+--R                   - 108%%DB1  + (- 72%%DB0 + 24d)%%DB1 - 108%%DB0  + 24d %%DB0
+--R                 + 
+--R                       2     2
+--R                   - 2d  - 3b
+--R         + 
+--R           - 6%%DB1 - 6%%DB0 + 2d
+--R      *
+--R         log
+--R                         2           2       3             2       3
+--R                  (- 288c %%DB0 + 24c d - 72b )%%DB1 + (24c d - 72b )%%DB0
+--R                + 
+--R                      2 2      3      2 2
+--R                  - 2c d  + 12b d - 3b c
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%DB1  + (- 72%%DB0 + 24d)%%DB1 - 108%%DB0
+--R                   + 
+--R                                   2     2
+--R                     24d %%DB0 - 2d  - 3b
+--R            + 
+--R                    2            2        3      2
+--R              (1728c %%DB0 - 144c d + 432b )%%DB1
+--R            + 
+--R                    2     2       2             2 2      3       2 2
+--R              (1728c %%DB0  - 576c d %%DB0 + 36c d  - 72b d - 18b c )%%DB1
+--R            + 
+--R                     2        3      2       2 2      3       2 2
+--R              (- 144c d + 432b )%%DB0  + (36c d  - 72b d - 18b c )%%DB0
+--R            + 
+--R                 5      4        2 3     3 2     2 2        4     5
+--R              (3c  - 18b c)x - 2c d  + 6b d  + 3b c d - 3b c  + 9b
+--R     + 
+--R         12%%DB1
+--R      *
+--R         log
+--R                      2           2        3      2
+--R              (- 1152c %%DB0 + 96c d - 288b )%%DB1
+--R            + 
+--R                      2     2       2             2 2      3       2 2
+--R              (- 1152c %%DB0  + 384c d %%DB0 - 24c d  + 48b d + 12b c )%%DB1
+--R            + 
+--R                     2     3       2       2         2 2      2 2
+--R              - 1152c %%DB0  + 384c d %%DB0  + (- 48c d  - 24b c )%%DB0
+--R            + 
+--R                5     4        2 3     3 2    2 2       4     5
+--R              (c  - 6b c)x + 2c d  - 2b d  + b c d - b c  - 3b
+--R     + 
+--R         12%%DB0
+--R      *
+--R         log
+--R                   2     3          2        3      2
+--R              3456c %%DB0  + (- 864c d - 864b )%%DB0
+--R            + 
+--R                  2 2       3        2 2            5      4        2 3     3 2
+--R              (72c d  + 144b d + 108b c )%%DB0 + (3c  - 18b c)x - 2c d  - 6b d
+--R            + 
+--R                  2 2        4     5
+--R              - 9b c d + 9b c  - 9b
+--R  /
+--R     12
+--R                                         Type: Union(Expression(Integer),...)
+--E 661
+
+--S 662 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+4+-+3
+--R             \|6 \|6
+--R          *
+--R             ROOT
+--R                            2                                    2
+--R                  - 108%%DB1  + (- 72%%DB0 + 24d)%%DB1 - 108%%DB0  + 24d %%DB0
+--R                + 
+--R                      2     2
+--R                  - 2d  - 3b
+--R         + 
+--R               +-+4+-+3          +-+4+-+3           +-+4+-+3
+--R           - 6\|6 \|6  %%DB1 - 6\|6 \|6  %%DB0 + 2d\|6 \|6
+--R      *
+--R         log
+--R                       2           2       3               2       3
+--R                  (288c %%DB0 - 24c d + 72b )%%DB1 + (- 24c d + 72b )%%DB0
+--R                + 
+--R                    2 2      3      2 2
+--R                  2c d  - 12b d + 3b c
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%DB1  + (- 72%%DB0 + 24d)%%DB1 - 108%%DB0
+--R                   + 
+--R                                   2     2
+--R                     24d %%DB0 - 2d  - 3b
+--R            + 
+--R                    2            2        3      2
+--R              (1728c %%DB0 - 144c d + 432b )%%DB1
+--R            + 
+--R                    2     2       2             2 2      3       2 2
+--R              (1728c %%DB0  - 576c d %%DB0 + 36c d  - 72b d - 18b c )%%DB1
+--R            + 
+--R                     2        3      2       2 2      3       2 2
+--R              (- 144c d + 432b )%%DB0  + (36c d  - 72b d - 18b c )%%DB0
+--R            + 
+--R                 5      4        2 3     3 2     2 2        4     5
+--R              (3c  - 18b c)x - 2c d  + 6b d  + 3b c d - 3b c  + 9b
+--R     + 
+--R           -
+--R                 +-+4+-+3
+--R                \|6 \|6
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%DB1  + (- 72%%DB0 + 24d)%%DB1 - 108%%DB0
+--R                   + 
+--R                                   2     2
+--R                     24d %%DB0 - 2d  - 3b
+--R         + 
+--R               +-+4+-+3          +-+4+-+3           +-+4+-+3
+--R           - 6\|6 \|6  %%DB1 - 6\|6 \|6  %%DB0 + 2d\|6 \|6
+--R      *
+--R         log
+--R                         2           2       3             2       3
+--R                  (- 288c %%DB0 + 24c d - 72b )%%DB1 + (24c d - 72b )%%DB0
+--R                + 
+--R                      2 2      3      2 2
+--R                  - 2c d  + 12b d - 3b c
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%DB1  + (- 72%%DB0 + 24d)%%DB1 - 108%%DB0
+--R                   + 
+--R                                   2     2
+--R                     24d %%DB0 - 2d  - 3b
+--R            + 
+--R                    2            2        3      2
+--R              (1728c %%DB0 - 144c d + 432b )%%DB1
+--R            + 
+--R                    2     2       2             2 2      3       2 2
+--R              (1728c %%DB0  - 576c d %%DB0 + 36c d  - 72b d - 18b c )%%DB1
+--R            + 
+--R                     2        3      2       2 2      3       2 2
+--R              (- 144c d + 432b )%%DB0  + (36c d  - 72b d - 18b c )%%DB0
+--R            + 
+--R                 5      4        2 3     3 2     2 2        4     5
+--R              (3c  - 18b c)x - 2c d  + 6b d  + 3b c d - 3b c  + 9b
+--R     + 
+--R            +-+4+-+3
+--R         12\|6 \|6  %%DB1
+--R      *
+--R         log
+--R                      2           2        3      2
+--R              (- 1152c %%DB0 + 96c d - 288b )%%DB1
+--R            + 
+--R                      2     2       2             2 2      3       2 2
+--R              (- 1152c %%DB0  + 384c d %%DB0 - 24c d  + 48b d + 12b c )%%DB1
+--R            + 
+--R                     2     3       2       2         2 2      2 2
+--R              - 1152c %%DB0  + 384c d %%DB0  + (- 48c d  - 24b c )%%DB0
+--R            + 
+--R                5     4        2 3     3 2    2 2       4     5
+--R              (c  - 6b c)x + 2c d  - 2b d  + b c d - b c  - 3b
+--R     + 
+--R            +-+4+-+3
+--R         12\|6 \|6  %%DB0
+--R      *
+--R         log
+--R                   2     3          2        3      2
+--R              3456c %%DB0  + (- 864c d - 864b )%%DB0
+--R            + 
+--R                  2 2       3        2 2            5      4        2 3     3 2
+--R              (72c d  + 144b d + 108b c )%%DB0 + (3c  - 18b c)x - 2c d  - 6b d
+--R            + 
+--R                  2 2        4     5
+--R              - 9b c d + 9b c  - 9b
+--R     + 
+--R          +-+      4+-+3 4+-+   2 +-+    +-+      +-+4+-+3      4
+--R       3c\|6 log(x \|2   \|3 + x \|3  + \|2 ) - d\|6 \|6  log(3x  + 2)
+--R     + 
+--R            +-+        4+-+3 4+-+   2 +-+    +-+       +-+      4+-+
+--R       - 3c\|6 log(- x \|2   \|3 + x \|3  + \|2 ) - 6c\|6 atan(x\|6  + 1)
+--R     + 
+--R                                               2 +-+
+--R            +-+      4+-+           4+-+3     x \|3
+--R       - 6c\|6 atan(x\|6  - 1) - 6b \|6  atan(------)
+--R                                                +-+
+--R                                               \|2
+--R  /
+--R        +-+4+-+3
+--R     12\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R             6       2 4+-+3 +-+          4       +-+4+-+3 4+-+4+-+3
+--R       ((3c x  + 2c x )\|2  \|3  + (- 3c x  - 2c)\|2 \|2  )\|3 \|6
+--R     + 
+--R                  3 +-+4+-+2 +-+4+-+2        5         +-+ +-+        3  +-+
+--R           (- 4b x \|2 \|2  \|3 \|3   + (6b x  + 4b x)\|2 \|3  + 24b x )\|6
+--R         + 
+--R                 4        3 4+-+2 4+-+2          4        3  +-+ +-+        6
+--R           (12c x  + 24b x )\|2   \|3  + (- 12c x  - 24b x )\|2 \|3  - 18c x
+--R         + 
+--R                  5        2
+--R           - 36b x  - 12c x  - 24b x
+--R      *
+--R         4+-+2
+--R         \|6
+--R     + 
+--R              2 4+-+2 4+-+2      2 +-+ +-+        4
+--R       - 24c x  \|2   \|3 + 24c x \|2 \|3  + 36c x  + 24c
+--R  /
+--R            6      2 4+-+2 4+-+2        6      2  +-+ +-+       8       4
+--R       ((72x  + 48x )\|2   \|3  + (- 72x  - 48x )\|2 \|3  - 108x  - 144x  - 48)
+--R    *
+--R       4+-+2
+--R       \|6
+--R                                                    Type: Expression(Integer)
+--E 663
+
+)clear all
+
+--S 664 of 953
+t0:=(a+b*x+c*x^2+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + b x + a
+--R   (1)  ---------------------
+--R                 4
+--R               3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 664
+
+--S 665 of 953
+r0:=1/12*d*log(2+3*x^4)+1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)-1/8*log(-2^(3/4)*_
+   3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*(-2*c+a*sqrt(6))/6^(3/4)+_
+   1/8*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*(-2*c+a*sqrt(6))/_
+   6^(3/4)-1/4*atan(1-6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)+1/4*atan(1+_
+   6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R             +-+            4+-+3 4+-+   2 +-+    +-+      +-+4+-+3      4
+--R       (- 3c\|6  + 9a)log(x \|2   \|3 + x \|3  + \|2 ) + d\|6 \|6  log(3x  + 2)
+--R     + 
+--R           +-+              4+-+3 4+-+   2 +-+    +-+
+--R       (3c\|6  - 9a)log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+             4+-+            +-+             4+-+
+--R       (6c\|6  + 18a)atan(x\|6  + 1) + (6c\|6  + 18a)atan(x\|6  - 1)
+--R     + 
+--R                     2 +-+
+--R          4+-+3     x \|3
+--R       6b \|6  atan(------)
+--R                      +-+
+--R                     \|2
+--R  /
+--R        +-+4+-+3
+--R     12\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           ROOT
+--R                          2                                    2
+--R                - 108%%DC1  + (- 72%%DC0 + 24d)%%DC1 - 108%%DC0  + 24d %%DC0
+--R              + 
+--R                    2            2
+--R                - 2d  - 6a c - 3b
+--R         + 
+--R           - 6%%DC1 - 6%%DC0 + 2d
+--R      *
+--R         log
+--R                            3        2           2
+--R                      (2304c  - 3456a c + 6912a b )%%DC0
+--R                    + 
+--R                           3       2          2             2       3        3
+--R                    (- 192c  + 288a c - 576a b )d - 864a b c  + 576b c - 432a b
+--R                 *
+--R                    %%DC1
+--R                + 
+--R                               3       2          2             2       3
+--R                        (- 192c  + 288a c - 576a b )d - 864a b c  + 576b c
+--R                      + 
+--R                              3
+--R                        - 432a b
+--R                 *
+--R                    %%DC0
+--R                + 
+--R                      3      2         2  2            2      3       3
+--R                  (16c  - 24a c + 48a b )d  + (144a b c  - 96b c + 72a b)d
+--R                + 
+--R                         4      2 3       2 2         4      5
+--R                  - 24a c  + 24b c  + 108a b c - 72a b  + 54a
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%DC1  + (- 72%%DC0 + 24d)%%DC1 - 108%%DC0
+--R                   + 
+--R                                   2            2
+--R                     24d %%DC0 - 2d  - 6a c - 3b
+--R            + 
+--R                         3         2            2
+--R                  (13824c  - 20736a c + 41472a b )%%DC0
+--R                + 
+--R                          3        2           2              2        3
+--R                  (- 1152c  + 1728a c - 3456a b )d - 5184a b c  + 3456b c
+--R                + 
+--R                         3
+--R                  - 2592a b
+--R             *
+--R                     2
+--R                %%DC1
+--R            + 
+--R                         3         2            2      2
+--R                  (13824c  - 20736a c + 41472a b )%%DC0
+--R                + 
+--R                          3        2            2
+--R                  (- 4608c  + 6912a c - 13824a b )d %%DC0
+--R                + 
+--R                       3       2          2  2            2       3        3
+--R                  (288c  - 432a c + 864a b )d  + (864a b c  - 576b c + 432a b)d
+--R                + 
+--R                        4       2 3       2 2          4       5
+--R                  144a c  - 144b c  - 648a b c + 432a b  - 324a
+--R             *
+--R                %%DC1
+--R            + 
+--R                          3        2           2              2        3
+--R                  (- 1152c  + 1728a c - 3456a b )d - 5184a b c  + 3456b c
+--R                + 
+--R                         3
+--R                  - 2592a b
+--R             *
+--R                     2
+--R                %%DC0
+--R            + 
+--R                       3       2          2  2            2       3        3
+--R                  (288c  - 432a c + 864a b )d  + (864a b c  - 576b c + 432a b)d
+--R                + 
+--R                        4       2 3       2 2          4       5
+--R                  144a c  - 144b c  - 648a b c + 432a b  - 324a
+--R             *
+--R                %%DC0
+--R            + 
+--R                     6      2 4         2 3          4      4  2       3 2
+--R                  24c  - 36a c  + 288a b c  + (- 144b  - 54a )c  + 432a b c
+--R                + 
+--R                        2 4      6
+--R                  - 216a b  + 81a
+--R             *
+--R                x
+--R            + 
+--R                    3      2         2  3             2      3       3   2
+--R              (- 16c  + 24a c - 48a b )d  + (- 72a b c  + 48b c - 36a b)d
+--R            + 
+--R                      4      2 3       2 2         4      5          5
+--R              (- 24a c  + 24b c  + 108a b c - 72a b  + 54a )d - 24b c
+--R            + 
+--R                    2   3        3 2       5       4         3 3
+--R              - 144a b c  - 36a b c  + (72b  - 162a b)c + 54a b
+--R     + 
+--R           -
+--R              ROOT
+--R                             2                                    2
+--R                   - 108%%DC1  + (- 72%%DC0 + 24d)%%DC1 - 108%%DC0  + 24d %%DC0
+--R                 + 
+--R                       2            2
+--R                   - 2d  - 6a c - 3b
+--R         + 
+--R           - 6%%DC1 - 6%%DC0 + 2d
+--R      *
+--R         log
+--R                              3        2           2
+--R                      (- 2304c  + 3456a c - 6912a b )%%DC0
+--R                    + 
+--R                           3       2          2             2       3        3
+--R                      (192c  - 288a c + 576a b )d + 864a b c  - 576b c + 432a b
+--R                 *
+--R                    %%DC1
+--R                + 
+--R                          3       2          2             2       3        3
+--R                    ((192c  - 288a c + 576a b )d + 864a b c  - 576b c + 432a b)
+--R                 *
+--R                    %%DC0
+--R                + 
+--R                        3      2         2  2              2      3       3
+--R                  (- 16c  + 24a c - 48a b )d  + (- 144a b c  + 96b c - 72a b)d
+--R                + 
+--R                       4      2 3       2 2         4      5
+--R                  24a c  - 24b c  - 108a b c + 72a b  - 54a
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%DC1  + (- 72%%DC0 + 24d)%%DC1 - 108%%DC0
+--R                   + 
+--R                                   2            2
+--R                     24d %%DC0 - 2d  - 6a c - 3b
+--R            + 
+--R                         3         2            2
+--R                  (13824c  - 20736a c + 41472a b )%%DC0
+--R                + 
+--R                          3        2           2              2        3
+--R                  (- 1152c  + 1728a c - 3456a b )d - 5184a b c  + 3456b c
+--R                + 
+--R                         3
+--R                  - 2592a b
+--R             *
+--R                     2
+--R                %%DC1
+--R            + 
+--R                         3         2            2      2
+--R                  (13824c  - 20736a c + 41472a b )%%DC0
+--R                + 
+--R                          3        2            2
+--R                  (- 4608c  + 6912a c - 13824a b )d %%DC0
+--R                + 
+--R                       3       2          2  2            2       3        3
+--R                  (288c  - 432a c + 864a b )d  + (864a b c  - 576b c + 432a b)d
+--R                + 
+--R                        4       2 3       2 2          4       5
+--R                  144a c  - 144b c  - 648a b c + 432a b  - 324a
+--R             *
+--R                %%DC1
+--R            + 
+--R                          3        2           2              2        3
+--R                  (- 1152c  + 1728a c - 3456a b )d - 5184a b c  + 3456b c
+--R                + 
+--R                         3
+--R                  - 2592a b
+--R             *
+--R                     2
+--R                %%DC0
+--R            + 
+--R                       3       2          2  2            2       3        3
+--R                  (288c  - 432a c + 864a b )d  + (864a b c  - 576b c + 432a b)d
+--R                + 
+--R                        4       2 3       2 2          4       5
+--R                  144a c  - 144b c  - 648a b c + 432a b  - 324a
+--R             *
+--R                %%DC0
+--R            + 
+--R                     6      2 4         2 3          4      4  2       3 2
+--R                  24c  - 36a c  + 288a b c  + (- 144b  - 54a )c  + 432a b c
+--R                + 
+--R                        2 4      6
+--R                  - 216a b  + 81a
+--R             *
+--R                x
+--R            + 
+--R                    3      2         2  3             2      3       3   2
+--R              (- 16c  + 24a c - 48a b )d  + (- 72a b c  + 48b c - 36a b)d
+--R            + 
+--R                      4      2 3       2 2         4      5          5
+--R              (- 24a c  + 24b c  + 108a b c - 72a b  + 54a )d - 24b c
+--R            + 
+--R                    2   3        3 2       5       4         3 3
+--R              - 144a b c  - 36a b c  + (72b  - 162a b)c + 54a b
+--R     + 
+--R         12%%DC1
+--R      *
+--R         log
+--R                          3         2            2
+--R                  (- 9216c  + 13824a c - 27648a b )%%DC0
+--R                + 
+--R                     3        2           2              2        3         3
+--R                (768c  - 1152a c + 2304a b )d + 3456a b c  - 2304b c + 1728a b
+--R             *
+--R                     2
+--R                %%DC1
+--R            + 
+--R                          3         2            2      2
+--R                  (- 9216c  + 13824a c - 27648a b )%%DC0
+--R                + 
+--R                        3        2           2
+--R                  (3072c  - 4608a c + 9216a b )d %%DC0
+--R                + 
+--R                         3       2          2  2
+--R                  (- 192c  + 288a c - 576a b )d
+--R                + 
+--R                             2       3        3           4      2 3       2 2
+--R                  (- 576a b c  + 384b c - 288a b)d - 96a c  + 96b c  + 432a b c
+--R                + 
+--R                          4       5
+--R                  - 288a b  + 216a
+--R             *
+--R                %%DC1
+--R            + 
+--R                      3         2            2      3
+--R              (- 9216c  + 13824a c - 27648a b )%%DC0
+--R            + 
+--R                    3        2           2        2
+--R              (3072c  - 4608a c + 9216a b )d %%DC0
+--R            + 
+--R                         3       2           2  2         4       2 3       3 2
+--R                  (- 384c  + 576a c - 1152a b )d  - 384a c  - 192b c  + 576a c
+--R                + 
+--R                        2 2          4
+--R                  - 864a b c - 576a b
+--R             *
+--R                %%DC0
+--R            + 
+--R                    6      2 4        2 3         4      4  2       3 2
+--R                  8c  - 12a c  + 96a b c  + (- 48b  - 18a )c  + 144a b c
+--R                + 
+--R                       2 4      6
+--R                  - 72a b  + 27a
+--R             *
+--R                x
+--R            + 
+--R                  3      2         2  3           2      3       3   2
+--R              (16c  - 24a c + 48a b )d  + (24a b c  - 16b c + 12a b)d
+--R            + 
+--R                    4     2 3      3 2      2 2         4      5         5
+--R              (40a c  + 8b c  - 48a c  + 36a b c + 72a b  - 18a )d - 8b c
+--R            + 
+--R                 2   3        3 2         5      4         3 3
+--R              96a b c  - 36a b c  + (- 24b  + 18a b)c + 54a b
+--R     + 
+--R         12%%DC0
+--R      *
+--R         log
+--R                     3         2            2      3
+--R              (27648c  - 41472a c + 82944a b )%%DC0
+--R            + 
+--R                          3         2            2               2        3
+--R                  (- 6912c  + 10368a c - 20736a b )d + 10368a b c  - 6912b c
+--R                + 
+--R                       3
+--R                  5184a b
+--R             *
+--R                     2
+--R                %%DC0
+--R            + 
+--R                       3       2           2  2
+--R                  (576c  - 864a c + 1728a b )d
+--R                + 
+--R                              2        3        3            4       2 3
+--R                  (- 1728a b c  + 1152b c - 864a b)d + 864a c  + 864b c
+--R                + 
+--R                         3 2        2 2          4       5
+--R                  - 1728a c  + 3888a b c + 864a b  + 648a
+--R             *
+--R                %%DC0
+--R            + 
+--R                     6      2 4         2 3          4      4  2       3 2
+--R                  24c  - 36a c  + 288a b c  + (- 144b  - 54a )c  + 432a b c
+--R                + 
+--R                        2 4      6
+--R                  - 216a b  + 81a
+--R             *
+--R                x
+--R            + 
+--R                    3      2         2  3           2      3       3   2
+--R              (- 16c  + 24a c - 48a b )d  + (72a b c  - 48b c + 36a b)d
+--R            + 
+--R                      4      2 3       3 2       2 2         4      5          5
+--R              (- 72a c  - 72b c  + 144a c  - 324a b c - 72a b  - 54a )d + 72b c
+--R            + 
+--R                    3 2         5       4          3 3
+--R              180a b c  + (- 72b  + 270a b)c - 270a b
+--R  /
+--R     12
+--R                                         Type: Union(Expression(Integer),...)
+--E 666
+
+--S 667 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+4+-+3
+--R             \|6 \|6
+--R          *
+--R             ROOT
+--R                            2                                    2
+--R                  - 108%%DC1  + (- 72%%DC0 + 24d)%%DC1 - 108%%DC0  + 24d %%DC0
+--R                + 
+--R                      2            2
+--R                  - 2d  - 6a c - 3b
+--R         + 
+--R               +-+4+-+3          +-+4+-+3           +-+4+-+3
+--R           - 6\|6 \|6  %%DC1 - 6\|6 \|6  %%DC0 + 2d\|6 \|6
+--R      *
+--R         log
+--R                            3        2           2
+--R                      (2304c  - 3456a c + 6912a b )%%DC0
+--R                    + 
+--R                           3       2          2             2       3        3
+--R                    (- 192c  + 288a c - 576a b )d - 864a b c  + 576b c - 432a b
+--R                 *
+--R                    %%DC1
+--R                + 
+--R                               3       2          2             2       3
+--R                        (- 192c  + 288a c - 576a b )d - 864a b c  + 576b c
+--R                      + 
+--R                              3
+--R                        - 432a b
+--R                 *
+--R                    %%DC0
+--R                + 
+--R                      3      2         2  2            2      3       3
+--R                  (16c  - 24a c + 48a b )d  + (144a b c  - 96b c + 72a b)d
+--R                + 
+--R                         4      2 3       2 2         4      5
+--R                  - 24a c  + 24b c  + 108a b c - 72a b  + 54a
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%DC1  + (- 72%%DC0 + 24d)%%DC1 - 108%%DC0
+--R                   + 
+--R                                   2            2
+--R                     24d %%DC0 - 2d  - 6a c - 3b
+--R            + 
+--R                         3         2            2
+--R                  (13824c  - 20736a c + 41472a b )%%DC0
+--R                + 
+--R                          3        2           2              2        3
+--R                  (- 1152c  + 1728a c - 3456a b )d - 5184a b c  + 3456b c
+--R                + 
+--R                         3
+--R                  - 2592a b
+--R             *
+--R                     2
+--R                %%DC1
+--R            + 
+--R                         3         2            2      2
+--R                  (13824c  - 20736a c + 41472a b )%%DC0
+--R                + 
+--R                          3        2            2
+--R                  (- 4608c  + 6912a c - 13824a b )d %%DC0
+--R                + 
+--R                       3       2          2  2            2       3        3
+--R                  (288c  - 432a c + 864a b )d  + (864a b c  - 576b c + 432a b)d
+--R                + 
+--R                        4       2 3       2 2          4       5
+--R                  144a c  - 144b c  - 648a b c + 432a b  - 324a
+--R             *
+--R                %%DC1
+--R            + 
+--R                          3        2           2              2        3
+--R                  (- 1152c  + 1728a c - 3456a b )d - 5184a b c  + 3456b c
+--R                + 
+--R                         3
+--R                  - 2592a b
+--R             *
+--R                     2
+--R                %%DC0
+--R            + 
+--R                       3       2          2  2            2       3        3
+--R                  (288c  - 432a c + 864a b )d  + (864a b c  - 576b c + 432a b)d
+--R                + 
+--R                        4       2 3       2 2          4       5
+--R                  144a c  - 144b c  - 648a b c + 432a b  - 324a
+--R             *
+--R                %%DC0
+--R            + 
+--R                     6      2 4         2 3          4      4  2       3 2
+--R                  24c  - 36a c  + 288a b c  + (- 144b  - 54a )c  + 432a b c
+--R                + 
+--R                        2 4      6
+--R                  - 216a b  + 81a
+--R             *
+--R                x
+--R            + 
+--R                    3      2         2  3             2      3       3   2
+--R              (- 16c  + 24a c - 48a b )d  + (- 72a b c  + 48b c - 36a b)d
+--R            + 
+--R                      4      2 3       2 2         4      5          5
+--R              (- 24a c  + 24b c  + 108a b c - 72a b  + 54a )d - 24b c
+--R            + 
+--R                    2   3        3 2       5       4         3 3
+--R              - 144a b c  - 36a b c  + (72b  - 162a b)c + 54a b
+--R     + 
+--R           -
+--R                 +-+4+-+3
+--R                \|6 \|6
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%DC1  + (- 72%%DC0 + 24d)%%DC1 - 108%%DC0
+--R                   + 
+--R                                   2            2
+--R                     24d %%DC0 - 2d  - 6a c - 3b
+--R         + 
+--R               +-+4+-+3          +-+4+-+3           +-+4+-+3
+--R           - 6\|6 \|6  %%DC1 - 6\|6 \|6  %%DC0 + 2d\|6 \|6
+--R      *
+--R         log
+--R                              3        2           2
+--R                      (- 2304c  + 3456a c - 6912a b )%%DC0
+--R                    + 
+--R                           3       2          2             2       3        3
+--R                      (192c  - 288a c + 576a b )d + 864a b c  - 576b c + 432a b
+--R                 *
+--R                    %%DC1
+--R                + 
+--R                          3       2          2             2       3        3
+--R                    ((192c  - 288a c + 576a b )d + 864a b c  - 576b c + 432a b)
+--R                 *
+--R                    %%DC0
+--R                + 
+--R                        3      2         2  2              2      3       3
+--R                  (- 16c  + 24a c - 48a b )d  + (- 144a b c  + 96b c - 72a b)d
+--R                + 
+--R                       4      2 3       2 2         4      5
+--R                  24a c  - 24b c  - 108a b c + 72a b  - 54a
+--R             *
+--R                ROOT
+--R                               2                                    2
+--R                     - 108%%DC1  + (- 72%%DC0 + 24d)%%DC1 - 108%%DC0
+--R                   + 
+--R                                   2            2
+--R                     24d %%DC0 - 2d  - 6a c - 3b
+--R            + 
+--R                         3         2            2
+--R                  (13824c  - 20736a c + 41472a b )%%DC0
+--R                + 
+--R                          3        2           2              2        3
+--R                  (- 1152c  + 1728a c - 3456a b )d - 5184a b c  + 3456b c
+--R                + 
+--R                         3
+--R                  - 2592a b
+--R             *
+--R                     2
+--R                %%DC1
+--R            + 
+--R                         3         2            2      2
+--R                  (13824c  - 20736a c + 41472a b )%%DC0
+--R                + 
+--R                          3        2            2
+--R                  (- 4608c  + 6912a c - 13824a b )d %%DC0
+--R                + 
+--R                       3       2          2  2            2       3        3
+--R                  (288c  - 432a c + 864a b )d  + (864a b c  - 576b c + 432a b)d
+--R                + 
+--R                        4       2 3       2 2          4       5
+--R                  144a c  - 144b c  - 648a b c + 432a b  - 324a
+--R             *
+--R                %%DC1
+--R            + 
+--R                          3        2           2              2        3
+--R                  (- 1152c  + 1728a c - 3456a b )d - 5184a b c  + 3456b c
+--R                + 
+--R                         3
+--R                  - 2592a b
+--R             *
+--R                     2
+--R                %%DC0
+--R            + 
+--R                       3       2          2  2            2       3        3
+--R                  (288c  - 432a c + 864a b )d  + (864a b c  - 576b c + 432a b)d
+--R                + 
+--R                        4       2 3       2 2          4       5
+--R                  144a c  - 144b c  - 648a b c + 432a b  - 324a
+--R             *
+--R                %%DC0
+--R            + 
+--R                     6      2 4         2 3          4      4  2       3 2
+--R                  24c  - 36a c  + 288a b c  + (- 144b  - 54a )c  + 432a b c
+--R                + 
+--R                        2 4      6
+--R                  - 216a b  + 81a
+--R             *
+--R                x
+--R            + 
+--R                    3      2         2  3             2      3       3   2
+--R              (- 16c  + 24a c - 48a b )d  + (- 72a b c  + 48b c - 36a b)d
+--R            + 
+--R                      4      2 3       2 2         4      5          5
+--R              (- 24a c  + 24b c  + 108a b c - 72a b  + 54a )d - 24b c
+--R            + 
+--R                    2   3        3 2       5       4         3 3
+--R              - 144a b c  - 36a b c  + (72b  - 162a b)c + 54a b
+--R     + 
+--R            +-+4+-+3
+--R         12\|6 \|6  %%DC1
+--R      *
+--R         log
+--R                          3         2            2
+--R                  (- 9216c  + 13824a c - 27648a b )%%DC0
+--R                + 
+--R                     3        2           2              2        3         3
+--R                (768c  - 1152a c + 2304a b )d + 3456a b c  - 2304b c + 1728a b
+--R             *
+--R                     2
+--R                %%DC1
+--R            + 
+--R                          3         2            2      2
+--R                  (- 9216c  + 13824a c - 27648a b )%%DC0
+--R                + 
+--R                        3        2           2
+--R                  (3072c  - 4608a c + 9216a b )d %%DC0
+--R                + 
+--R                         3       2          2  2
+--R                  (- 192c  + 288a c - 576a b )d
+--R                + 
+--R                             2       3        3           4      2 3       2 2
+--R                  (- 576a b c  + 384b c - 288a b)d - 96a c  + 96b c  + 432a b c
+--R                + 
+--R                          4       5
+--R                  - 288a b  + 216a
+--R             *
+--R                %%DC1
+--R            + 
+--R                      3         2            2      3
+--R              (- 9216c  + 13824a c - 27648a b )%%DC0
+--R            + 
+--R                    3        2           2        2
+--R              (3072c  - 4608a c + 9216a b )d %%DC0
+--R            + 
+--R                         3       2           2  2         4       2 3       3 2
+--R                  (- 384c  + 576a c - 1152a b )d  - 384a c  - 192b c  + 576a c
+--R                + 
+--R                        2 2          4
+--R                  - 864a b c - 576a b
+--R             *
+--R                %%DC0
+--R            + 
+--R                    6      2 4        2 3         4      4  2       3 2
+--R                  8c  - 12a c  + 96a b c  + (- 48b  - 18a )c  + 144a b c
+--R                + 
+--R                       2 4      6
+--R                  - 72a b  + 27a
+--R             *
+--R                x
+--R            + 
+--R                  3      2         2  3           2      3       3   2
+--R              (16c  - 24a c + 48a b )d  + (24a b c  - 16b c + 12a b)d
+--R            + 
+--R                    4     2 3      3 2      2 2         4      5         5
+--R              (40a c  + 8b c  - 48a c  + 36a b c + 72a b  - 18a )d - 8b c
+--R            + 
+--R                 2   3        3 2         5      4         3 3
+--R              96a b c  - 36a b c  + (- 24b  + 18a b)c + 54a b
+--R     + 
+--R            +-+4+-+3
+--R         12\|6 \|6  %%DC0
+--R      *
+--R         log
+--R                     3         2            2      3
+--R              (27648c  - 41472a c + 82944a b )%%DC0
+--R            + 
+--R                          3         2            2               2        3
+--R                  (- 6912c  + 10368a c - 20736a b )d + 10368a b c  - 6912b c
+--R                + 
+--R                       3
+--R                  5184a b
+--R             *
+--R                     2
+--R                %%DC0
+--R            + 
+--R                       3       2           2  2
+--R                  (576c  - 864a c + 1728a b )d
+--R                + 
+--R                              2        3        3            4       2 3
+--R                  (- 1728a b c  + 1152b c - 864a b)d + 864a c  + 864b c
+--R                + 
+--R                         3 2        2 2          4       5
+--R                  - 1728a c  + 3888a b c + 864a b  + 648a
+--R             *
+--R                %%DC0
+--R            + 
+--R                     6      2 4         2 3          4      4  2       3 2
+--R                  24c  - 36a c  + 288a b c  + (- 144b  - 54a )c  + 432a b c
+--R                + 
+--R                        2 4      6
+--R                  - 216a b  + 81a
+--R             *
+--R                x
+--R            + 
+--R                    3      2         2  3           2      3       3   2
+--R              (- 16c  + 24a c - 48a b )d  + (72a b c  - 48b c + 36a b)d
+--R            + 
+--R                      4      2 3       3 2       2 2         4      5          5
+--R              (- 72a c  - 72b c  + 144a c  - 324a b c - 72a b  - 54a )d + 72b c
+--R            + 
+--R                    3 2         5       4          3 3
+--R              180a b c  + (- 72b  + 270a b)c - 270a b
+--R     + 
+--R           +-+            4+-+3 4+-+   2 +-+    +-+      +-+4+-+3      4
+--R       (3c\|6  - 9a)log(x \|2   \|3 + x \|3  + \|2 ) - d\|6 \|6  log(3x  + 2)
+--R     + 
+--R             +-+              4+-+3 4+-+   2 +-+    +-+
+--R       (- 3c\|6  + 9a)log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R             +-+             4+-+              +-+             4+-+
+--R       (- 6c\|6  - 18a)atan(x\|6  + 1) + (- 6c\|6  - 18a)atan(x\|6  - 1)
+--R     + 
+--R                       2 +-+
+--R            4+-+3     x \|3
+--R       - 6b \|6  atan(------)
+--R                        +-+
+--R                       \|2
+--R  /
+--R        +-+4+-+3
+--R     12\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                   6       2 4+-+3 +-+        4       +-+4+-+3 4+-+ +-+
+--R           ((- 3a x  - 2a x )\|2  \|3  + (3a x  + 2a)\|2 \|2  )\|3 \|6
+--R         + 
+--R                 6       2 4+-+3 +-+          4       +-+4+-+3 4+-+
+--R           ((6c x  + 4c x )\|2  \|3  + (- 6c x  - 4c)\|2 \|2  )\|3
+--R      *
+--R         4+-+3
+--R         \|6
+--R     + 
+--R                      3 +-+4+-+2 +-+        4 4+-+24+-+2
+--R               (- 8b x \|2 \|2  \|3  - 12a x  \|2 )\|3
+--R             + 
+--R                     5        4         +-+ +-+        6        3        2
+--R               (12b x  + 12a x  + 8b x)\|2 \|3  + 18a x  + 48b x  + 12a x
+--R          *
+--R              +-+
+--R             \|6
+--R         + 
+--R                 4        3        2 4+-+2 4+-+2
+--R           (24c x  + 48b x  + 48a x )\|2   \|3
+--R         + 
+--R                   4        3        2  +-+ +-+        6        5        4
+--R           (- 24c x  - 48b x  - 48a x )\|2 \|3  - 36c x  - 72b x  - 72a x
+--R         + 
+--R                  2
+--R           - 24c x  - 48b x - 48a
+--R      *
+--R         4+-+2
+--R         \|6
+--R     + 
+--R               2 4+-+2 4+-+2      2 +-+ +-+        4        +-+
+--R       (- 24a x  \|2   \|3 + 24a x \|2 \|3  + 36a x  + 24a)\|6
+--R     + 
+--R              2 4+-+2 4+-+2      2 +-+ +-+        4
+--R       - 48c x  \|2   \|3 + 48c x \|2 \|3  + 72c x  + 48c
+--R  /
+--R                6      2 4+-+2 4+-+2         6      2  +-+ +-+       8       4
+--R           (144x  + 96x )\|2   \|3  + (- 144x  - 96x )\|2 \|3  - 216x  - 288x
+--R         + 
+--R           - 96
+--R    *
+--R       4+-+2
+--R       \|6
+--R                                                    Type: Expression(Integer)
+--E 668
+
+)clear all
+
+--S 669 of 953
+t0:=(c+d*x)/(a+b*x^4)
+--R 
+--R
+--R         d x + c
+--R   (1)  --------
+--R           4
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 669
+
+--S 670 of 953
+r0:=-1/2*c*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*sqrt(2))+_
+   1/2*c*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*sqrt(2))-_
+   1/4*c*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))/_
+   (a^(3/4)*b^(1/4)*sqrt(2))+1/4*c*log(a^(1/4)*b^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(b))/(a^(3/4)*b^(1/4)*sqrt(2))+1/2*d*atan(x^2*_
+   sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R         +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       c\|a \|b log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       - c\|a \|b log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                        +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R          +-+ +-+     x\|2 \|b  + \|a        +-+ +-+     x\|2 \|b  - \|a
+--R       2c\|a \|b atan(----------------) + 2c\|a \|b atan(----------------)
+--R                            4+-+                               4+-+
+--R                            \|a                                \|a
+--R     + 
+--R                             2 +-+
+--R          +-+4+-+3 4+-+     x \|b
+--R       2d\|2 \|a   \|b atan(------)
+--R                              +-+
+--R                             \|a
+--R  /
+--R       +-+ +-+4+-+3 +-+4+-+
+--R     4\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6a b %%DD1  - 4a b %%DD0 %%DD1 - 6a b %%DD0  - d
+--R           -  |---------------------------------------------------  - %%DD1
+--R             \|                        2a b
+--R         + 
+--R           - %%DD0
+--R      *
+--R         log
+--R                      3   2          2   2            2   2            2 4
+--R                  (64a b d %%DD0 - 8a b c d)%%DD1 - 8a b c d %%DD0 - 4a d
+--R                + 
+--R                        4
+--R                  2a b c
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6a b %%DD1  - 4a b %%DD0 %%DD1 - 6a b %%DD0  - d
+--R                 |---------------------------------------------------
+--R                \|                        2a b
+--R            + 
+--R                    3   2          2   2       2
+--R              (- 64a b d %%DD0 + 8a b c d)%%DD1
+--R            + 
+--R                    3   2     2     2 4         4           2   2       2
+--R              (- 64a b d %%DD0  - 4a d  + 2a b c )%%DD1 + 8a b c d %%DD0
+--R            + 
+--R                   2 4         4                4      5        2 3
+--R              (- 4a d  + 2a b c )%%DD0 + (4a c d  - b c )x - a c d
+--R     + 
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6a b %%DD1  - 4a b %%DD0 %%DD1 - 6a b %%DD0  - d
+--R              |---------------------------------------------------  - %%DD1
+--R             \|                        2a b
+--R           + 
+--R             - %%DD0
+--R      *
+--R         log
+--R                        3   2          2   2            2   2            2 4
+--R                  (- 64a b d %%DD0 + 8a b c d)%%DD1 + 8a b c d %%DD0 + 4a d
+--R                + 
+--R                          4
+--R                  - 2a b c
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6a b %%DD1  - 4a b %%DD0 %%DD1 - 6a b %%DD0  - d
+--R                 |---------------------------------------------------
+--R                \|                        2a b
+--R            + 
+--R                    3   2          2   2       2
+--R              (- 64a b d %%DD0 + 8a b c d)%%DD1
+--R            + 
+--R                    3   2     2     2 4         4           2   2       2
+--R              (- 64a b d %%DD0  - 4a d  + 2a b c )%%DD1 + 8a b c d %%DD0
+--R            + 
+--R                   2 4         4                4      5        2 3
+--R              (- 4a d  + 2a b c )%%DD0 + (4a c d  - b c )x - a c d
+--R     + 
+--R         2%%DD1
+--R      *
+--R         log
+--R                   3   2           2   2       2
+--R              (128a b d %%DD0 - 16a b c d)%%DD1
+--R            + 
+--R                   3   2     2     2 4         4             3   2     3
+--R              (128a b d %%DD0  + 8a d  - 4a b c )%%DD1 + 128a b d %%DD0
+--R            + 
+--R                 2 4               4      5         2 3
+--R              16a d %%DD0 + (4a c d  - b c )x - 3a c d
+--R     + 
+--R         2%%DD0
+--R      *
+--R         log
+--R                    3   2     3      2   2       2        2 4         4
+--R              - 128a b d %%DD0  - 16a b c d %%DD0  + (- 8a d  - 4a b c )%%DD0
+--R            + 
+--R                     4      5         2 3
+--R              (4a c d  - b c )x + 5a c d
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 671
+
+--S 672 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                  +-+ +-+4+-+3 +-+4+-+
+--R                2\|2 \|a \|a  \|b \|b
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6a b %%DD1  - 4a b %%DD0 %%DD1 - 6a b %%DD0  - d
+--R                 |---------------------------------------------------
+--R                \|                        2a b
+--R         + 
+--R               +-+ +-+4+-+3 +-+4+-+          +-+ +-+4+-+3 +-+4+-+
+--R           - 2\|2 \|a \|a  \|b \|b %%DD1 - 2\|2 \|a \|a  \|b \|b %%DD0
+--R      *
+--R         log
+--R                      3   2          2   2            2   2            2 4
+--R                  (64a b d %%DD0 - 8a b c d)%%DD1 - 8a b c d %%DD0 - 4a d
+--R                + 
+--R                        4
+--R                  2a b c
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6a b %%DD1  - 4a b %%DD0 %%DD1 - 6a b %%DD0  - d
+--R                 |---------------------------------------------------
+--R                \|                        2a b
+--R            + 
+--R                    3   2          2   2       2
+--R              (- 64a b d %%DD0 + 8a b c d)%%DD1
+--R            + 
+--R                    3   2     2     2 4         4           2   2       2
+--R              (- 64a b d %%DD0  - 4a d  + 2a b c )%%DD1 + 8a b c d %%DD0
+--R            + 
+--R                   2 4         4                4      5        2 3
+--R              (- 4a d  + 2a b c )%%DD0 + (4a c d  - b c )x - a c d
+--R     + 
+--R               +-+ +-+4+-+3 +-+4+-+
+--R             2\|2 \|a \|a  \|b \|b
+--R          *
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6a b %%DD1  - 4a b %%DD0 %%DD1 - 6a b %%DD0  - d
+--R              |---------------------------------------------------
+--R             \|                        2a b
+--R         + 
+--R               +-+ +-+4+-+3 +-+4+-+          +-+ +-+4+-+3 +-+4+-+
+--R           - 2\|2 \|a \|a  \|b \|b %%DD1 - 2\|2 \|a \|a  \|b \|b %%DD0
+--R      *
+--R         log
+--R                        3   2          2   2            2   2            2 4
+--R                  (- 64a b d %%DD0 + 8a b c d)%%DD1 + 8a b c d %%DD0 + 4a d
+--R                + 
+--R                          4
+--R                  - 2a b c
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6a b %%DD1  - 4a b %%DD0 %%DD1 - 6a b %%DD0  - d
+--R                 |---------------------------------------------------
+--R                \|                        2a b
+--R            + 
+--R                    3   2          2   2       2
+--R              (- 64a b d %%DD0 + 8a b c d)%%DD1
+--R            + 
+--R                    3   2     2     2 4         4           2   2       2
+--R              (- 64a b d %%DD0  - 4a d  + 2a b c )%%DD1 + 8a b c d %%DD0
+--R            + 
+--R                   2 4         4                4      5        2 3
+--R              (- 4a d  + 2a b c )%%DD0 + (4a c d  - b c )x - a c d
+--R     + 
+--R           +-+ +-+4+-+3 +-+4+-+
+--R         4\|2 \|a \|a  \|b \|b %%DD1
+--R      *
+--R         log
+--R                   3   2           2   2       2
+--R              (128a b d %%DD0 - 16a b c d)%%DD1
+--R            + 
+--R                   3   2     2     2 4         4             3   2     3
+--R              (128a b d %%DD0  + 8a d  - 4a b c )%%DD1 + 128a b d %%DD0
+--R            + 
+--R                 2 4               4      5         2 3
+--R              16a d %%DD0 + (4a c d  - b c )x - 3a c d
+--R     + 
+--R           +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       - c\|a \|b log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R         +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       c\|a \|b log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R           +-+ +-+4+-+3 +-+4+-+
+--R         4\|2 \|a \|a  \|b \|b %%DD0
+--R      *
+--R         log
+--R                    3   2     3      2   2       2        2 4         4
+--R              - 128a b d %%DD0  - 16a b c d %%DD0  + (- 8a d  - 4a b c )%%DD0
+--R            + 
+--R                     4      5         2 3
+--R              (4a c d  - b c )x + 5a c d
+--R     + 
+--R                          +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|b  + \|a        +-+ +-+     x\|2 \|b  - \|a
+--R       - 2c\|a \|b atan(----------------) - 2c\|a \|b atan(----------------)
+--R                              4+-+                               4+-+
+--R                              \|a                                \|a
+--R     + 
+--R                               2 +-+
+--R            +-+4+-+3 4+-+     x \|b
+--R       - 2d\|2 \|a   \|b atan(------)
+--R                                +-+
+--R                               \|a
+--R  /
+--R       +-+ +-+4+-+3 +-+4+-+
+--R     4\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                2 +-+4+-+2        6        2  +-+          4       4+-+2
+--R           (2c x \|a \|a   + b c x  + a c x )\|b  + (3b c x  + a c)\|a
+--R         + 
+--R                   4        +-+
+--R           (- b c x  - a c)\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R               4 +-+ +-+    2   6           2
+--R       - 2b c x \|a \|b  - b c x  - 3a b c x
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4b x  + 4a x )\|a \|a  \|b  + (2b x  + 4a b x  + 2a )\|a  )\|b
+--R     + 
+--R             2 6     2   2
+--R       - 4a b x  - 4a b x
+--R                                                    Type: Expression(Integer)
+--E 673
+
+)clear all
+
+--S 674 of 953
+t0:=(c+d*x)/(1+x^4)
+--R 
+--R
+--R        d x + c
+--R   (1)  -------
+--R          4
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 674
+
+--S 675 of 953
+r0:=1/2*d*atan(x^2)-1/2*c*atan(1-x*sqrt(2))/sqrt(2)+1/2*c*atan(1+_
+   x*sqrt(2))/sqrt(2)-1/4*c*log(1+x^2-x*sqrt(2))/sqrt(2)+1/4*c*_
+   log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R               +-+    2                  +-+    2                  +-+
+--R       c log(x\|2  + x  + 1) - c log(- x\|2  + x  + 1) + 2c atan(x\|2  + 1)
+--R     + 
+--R                 +-+           +-+      2
+--R       2c atan(x\|2  - 1) + 2d\|2 atan(x )
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +---------------------------------------+
+--R             |        2                        2    2     +-+         +-+
+--R         (- \|- 6%%DE1  - 4%%DE0 %%DE1 - 6%%DE0  - d   - \|2 %%DE1 - \|2 %%DE0)
+--R      *
+--R         log
+--R                     2          2            2            4     4
+--R                ((64d %%DE0 - 8c d)%%DE1 - 8c d %%DE0 - 4d  + 2c )
+--R             *
+--R                 +---------------------------------------+
+--R                 |        2                        2    2
+--R                \|- 6%%DE1  - 4%%DE0 %%DE1 - 6%%DE0  - d
+--R            + 
+--R                    2 +-+          2  +-+      2
+--R              (- 64d \|2 %%DE0 + 8c d\|2 )%%DE1
+--R            + 
+--R                    2 +-+     2        4     4  +-+           2  +-+     2
+--R              (- 64d \|2 %%DE0  + (- 4d  + 2c )\|2 )%%DE1 + 8c d\|2 %%DE0
+--R            + 
+--R                   4     4  +-+              4    5      2 3  +-+
+--R              (- 4d  + 2c )\|2 %%DE0 + ((4c d  - c )x - c d )\|2
+--R     + 
+--R           +---------------------------------------+
+--R           |        2                        2    2     +-+         +-+
+--R         (\|- 6%%DE1  - 4%%DE0 %%DE1 - 6%%DE0  - d   - \|2 %%DE1 - \|2 %%DE0)
+--R      *
+--R         log
+--R                       2          2            2            4     4
+--R                ((- 64d %%DE0 + 8c d)%%DE1 + 8c d %%DE0 + 4d  - 2c )
+--R             *
+--R                 +---------------------------------------+
+--R                 |        2                        2    2
+--R                \|- 6%%DE1  - 4%%DE0 %%DE1 - 6%%DE0  - d
+--R            + 
+--R                    2 +-+          2  +-+      2
+--R              (- 64d \|2 %%DE0 + 8c d\|2 )%%DE1
+--R            + 
+--R                    2 +-+     2        4     4  +-+           2  +-+     2
+--R              (- 64d \|2 %%DE0  + (- 4d  + 2c )\|2 )%%DE1 + 8c d\|2 %%DE0
+--R            + 
+--R                   4     4  +-+              4    5      2 3  +-+
+--R              (- 4d  + 2c )\|2 %%DE0 + ((4c d  - c )x - c d )\|2
+--R     + 
+--R           +-+
+--R         2\|2 %%DE1
+--R      *
+--R         log
+--R                   2           2       2        2     2     4     4
+--R              (128d %%DE0 - 16c d)%%DE1  + (128d %%DE0  + 8d  - 4c )%%DE1
+--R            + 
+--R                  2     3      4             4    5       2 3
+--R              128d %%DE0  + 16d %%DE0 + (4c d  - c )x - 3c d
+--R     + 
+--R           +-+
+--R         2\|2 %%DE0
+--R      *
+--R         log
+--R                    2     3      2       2        4     4              4    5
+--R              - 128d %%DE0  - 16c d %%DE0  + (- 8d  - 4c )%%DE0 + (4c d  - c )x
+--R            + 
+--R                2 3
+--R              5c d
+--R  /
+--R       +-+
+--R     2\|2
+--R                                         Type: Union(Expression(Integer),...)
+--E 676
+
+--S 677 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 +---------------------------------------+
+--R                 |        2                        2    2      +-+
+--R             - 2\|- 6%%DE1  - 4%%DE0 %%DE1 - 6%%DE0  - d   - 2\|2 %%DE1
+--R           + 
+--R                 +-+
+--R             - 2\|2 %%DE0
+--R      *
+--R         log
+--R                     2          2            2            4     4
+--R                ((64d %%DE0 - 8c d)%%DE1 - 8c d %%DE0 - 4d  + 2c )
+--R             *
+--R                 +---------------------------------------+
+--R                 |        2                        2    2
+--R                \|- 6%%DE1  - 4%%DE0 %%DE1 - 6%%DE0  - d
+--R            + 
+--R                    2 +-+          2  +-+      2
+--R              (- 64d \|2 %%DE0 + 8c d\|2 )%%DE1
+--R            + 
+--R                    2 +-+     2        4     4  +-+           2  +-+     2
+--R              (- 64d \|2 %%DE0  + (- 4d  + 2c )\|2 )%%DE1 + 8c d\|2 %%DE0
+--R            + 
+--R                   4     4  +-+              4    5      2 3  +-+
+--R              (- 4d  + 2c )\|2 %%DE0 + ((4c d  - c )x - c d )\|2
+--R     + 
+--R            +---------------------------------------+
+--R            |        2                        2    2      +-+          +-+
+--R         (2\|- 6%%DE1  - 4%%DE0 %%DE1 - 6%%DE0  - d   - 2\|2 %%DE1 - 2\|2 %%DE0)
+--R      *
+--R         log
+--R                       2          2            2            4     4
+--R                ((- 64d %%DE0 + 8c d)%%DE1 + 8c d %%DE0 + 4d  - 2c )
+--R             *
+--R                 +---------------------------------------+
+--R                 |        2                        2    2
+--R                \|- 6%%DE1  - 4%%DE0 %%DE1 - 6%%DE0  - d
+--R            + 
+--R                    2 +-+          2  +-+      2
+--R              (- 64d \|2 %%DE0 + 8c d\|2 )%%DE1
+--R            + 
+--R                    2 +-+     2        4     4  +-+           2  +-+     2
+--R              (- 64d \|2 %%DE0  + (- 4d  + 2c )\|2 )%%DE1 + 8c d\|2 %%DE0
+--R            + 
+--R                   4     4  +-+              4    5      2 3  +-+
+--R              (- 4d  + 2c )\|2 %%DE0 + ((4c d  - c )x - c d )\|2
+--R     + 
+--R           +-+
+--R         4\|2 %%DE1
+--R      *
+--R         log
+--R                   2           2       2        2     2     4     4
+--R              (128d %%DE0 - 16c d)%%DE1  + (128d %%DE0  + 8d  - 4c )%%DE1
+--R            + 
+--R                  2     3      4             4    5       2 3
+--R              128d %%DE0  + 16d %%DE0 + (4c d  - c )x - 3c d
+--R     + 
+--R           +-+
+--R         4\|2 %%DE0
+--R      *
+--R         log
+--R                    2     3      2       2        4     4              4    5
+--R              - 128d %%DE0  - 16c d %%DE0  + (- 8d  - 4c )%%DE0 + (4c d  - c )x
+--R            + 
+--R                2 3
+--R              5c d
+--R     + 
+--R                 +-+    2                  +-+    2                  +-+
+--R       - c log(x\|2  + x  + 1) + c log(- x\|2  + x  + 1) - 2c atan(x\|2  + 1)
+--R     + 
+--R                   +-+           +-+      2
+--R       - 2c atan(x\|2  - 1) - 2d\|2 atan(x )
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 678
+
+)clear all
+
+--S 679 of 953
+t0:=(c+d*x)/(a-b*x^4)
+--R 
+--R
+--R        - d x - c
+--R   (1)  ---------
+--R            4
+--R         b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 679
+
+--S 680 of 953
+r0:=1/2*c*atan(b^(1/4)*x/a^(1/4))/(a^(3/4)*b^(1/4))+1/2*c*atanh(b^(1/4)*_
+   x/a^(1/4))/(a^(3/4)*b^(1/4))+1/2*d*atanh(x^2*sqrt(b)/sqrt(a))/_
+   (sqrt(a)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                   4+-+                       2 +-+                  4+-+
+--R     +-+ +-+      x\|b       4+-+3 4+-+      x \|b      +-+ +-+     x\|b
+--R   c\|a \|b atanh(-----) + d \|a   \|b atanh(------ + c\|a \|b atan(-----)
+--R                   4+-+                        +-+                   4+-+
+--R                   \|a                        \|a                    \|a
+--R   -----------------------------------------------------------------------
+--R                                +-+4+-+3 +-+4+-+
+--R                              2\|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6a b %%DF1  - 4a b %%DF0 %%DF1 - 6a b %%DF0  + d
+--R              |---------------------------------------------------  - %%DF1
+--R             \|                        2a b
+--R           + 
+--R             - %%DF0
+--R      *
+--R         log
+--R                      3   2          2   2            2   2            2 4
+--R                  (64a b d %%DF0 - 8a b c d)%%DF1 - 8a b c d %%DF0 + 4a d
+--R                + 
+--R                        4
+--R                  2a b c
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6a b %%DF1  - 4a b %%DF0 %%DF1 - 6a b %%DF0  + d
+--R                 |---------------------------------------------------
+--R                \|                        2a b
+--R            + 
+--R                  3   2          2   2       2
+--R              (64a b d %%DF0 - 8a b c d)%%DF1
+--R            + 
+--R                  3   2     2     2 4         4           2   2       2
+--R              (64a b d %%DF0  - 4a d  - 2a b c )%%DF1 - 8a b c d %%DF0
+--R            + 
+--R                   2 4         4                4      5        2 3
+--R              (- 4a d  - 2a b c )%%DF0 + (4a c d  + b c )x - a c d
+--R     + 
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6a b %%DF1  - 4a b %%DF0 %%DF1 - 6a b %%DF0  + d
+--R           -  |---------------------------------------------------  - %%DF1
+--R             \|                        2a b
+--R         + 
+--R           - %%DF0
+--R      *
+--R         log
+--R                        3   2          2   2            2   2            2 4
+--R                  (- 64a b d %%DF0 + 8a b c d)%%DF1 + 8a b c d %%DF0 - 4a d
+--R                + 
+--R                          4
+--R                  - 2a b c
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6a b %%DF1  - 4a b %%DF0 %%DF1 - 6a b %%DF0  + d
+--R                 |---------------------------------------------------
+--R                \|                        2a b
+--R            + 
+--R                  3   2          2   2       2
+--R              (64a b d %%DF0 - 8a b c d)%%DF1
+--R            + 
+--R                  3   2     2     2 4         4           2   2       2
+--R              (64a b d %%DF0  - 4a d  - 2a b c )%%DF1 - 8a b c d %%DF0
+--R            + 
+--R                   2 4         4                4      5        2 3
+--R              (- 4a d  - 2a b c )%%DF0 + (4a c d  + b c )x - a c d
+--R     + 
+--R         2%%DF1
+--R      *
+--R         log
+--R                     3   2           2   2       2
+--R              (- 128a b d %%DF0 + 16a b c d)%%DF1
+--R            + 
+--R                     3   2     2     2 4         4             3   2     3
+--R              (- 128a b d %%DF0  + 8a d  + 4a b c )%%DF1 - 128a b d %%DF0
+--R            + 
+--R                 2 4               4      5         2 3
+--R              16a d %%DF0 + (4a c d  + b c )x - 3a c d
+--R     + 
+--R         2%%DF0
+--R      *
+--R         log
+--R                  3   2     3      2   2       2        2 4         4
+--R              128a b d %%DF0  + 16a b c d %%DF0  + (- 8a d  + 4a b c )%%DF0
+--R            + 
+--R                     4      5         2 3
+--R              (4a c d  + b c )x + 5a c d
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 681
+
+--S 682 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+4+-+3 +-+4+-+
+--R             \|a \|a  \|b \|b
+--R          *
+--R              +---------------------------------------------------+
+--R              |            2                                2    2
+--R              |- 6a b %%DF1  - 4a b %%DF0 %%DF1 - 6a b %%DF0  + d
+--R              |---------------------------------------------------
+--R             \|                        2a b
+--R         + 
+--R              +-+4+-+3 +-+4+-+         +-+4+-+3 +-+4+-+
+--R           - \|a \|a  \|b \|b %%DF1 - \|a \|a  \|b \|b %%DF0
+--R      *
+--R         log
+--R                      3   2          2   2            2   2            2 4
+--R                  (64a b d %%DF0 - 8a b c d)%%DF1 - 8a b c d %%DF0 + 4a d
+--R                + 
+--R                        4
+--R                  2a b c
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6a b %%DF1  - 4a b %%DF0 %%DF1 - 6a b %%DF0  + d
+--R                 |---------------------------------------------------
+--R                \|                        2a b
+--R            + 
+--R                  3   2          2   2       2
+--R              (64a b d %%DF0 - 8a b c d)%%DF1
+--R            + 
+--R                  3   2     2     2 4         4           2   2       2
+--R              (64a b d %%DF0  - 4a d  - 2a b c )%%DF1 - 8a b c d %%DF0
+--R            + 
+--R                   2 4         4                4      5        2 3
+--R              (- 4a d  - 2a b c )%%DF0 + (4a c d  + b c )x - a c d
+--R     + 
+--R           -
+--R                 +-+4+-+3 +-+4+-+
+--R                \|a \|a  \|b \|b
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6a b %%DF1  - 4a b %%DF0 %%DF1 - 6a b %%DF0  + d
+--R                 |---------------------------------------------------
+--R                \|                        2a b
+--R         + 
+--R              +-+4+-+3 +-+4+-+         +-+4+-+3 +-+4+-+
+--R           - \|a \|a  \|b \|b %%DF1 - \|a \|a  \|b \|b %%DF0
+--R      *
+--R         log
+--R                        3   2          2   2            2   2            2 4
+--R                  (- 64a b d %%DF0 + 8a b c d)%%DF1 + 8a b c d %%DF0 - 4a d
+--R                + 
+--R                          4
+--R                  - 2a b c
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |            2                                2    2
+--R                 |- 6a b %%DF1  - 4a b %%DF0 %%DF1 - 6a b %%DF0  + d
+--R                 |---------------------------------------------------
+--R                \|                        2a b
+--R            + 
+--R                  3   2          2   2       2
+--R              (64a b d %%DF0 - 8a b c d)%%DF1
+--R            + 
+--R                  3   2     2     2 4         4           2   2       2
+--R              (64a b d %%DF0  - 4a d  - 2a b c )%%DF1 - 8a b c d %%DF0
+--R            + 
+--R                   2 4         4                4      5        2 3
+--R              (- 4a d  - 2a b c )%%DF0 + (4a c d  + b c )x - a c d
+--R     + 
+--R           +-+4+-+3 +-+4+-+
+--R         2\|a \|a  \|b \|b %%DF1
+--R      *
+--R         log
+--R                     3   2           2   2       2
+--R              (- 128a b d %%DF0 + 16a b c d)%%DF1
+--R            + 
+--R                     3   2     2     2 4         4             3   2     3
+--R              (- 128a b d %%DF0  + 8a d  + 4a b c )%%DF1 - 128a b d %%DF0
+--R            + 
+--R                 2 4               4      5         2 3
+--R              16a d %%DF0 + (4a c d  + b c )x - 3a c d
+--R     + 
+--R           +-+4+-+3 +-+4+-+
+--R         2\|a \|a  \|b \|b %%DF0
+--R      *
+--R         log
+--R                  3   2     3      2   2       2        2 4         4
+--R              128a b d %%DF0  + 16a b c d %%DF0  + (- 8a d  + 4a b c )%%DF0
+--R            + 
+--R                     4      5         2 3
+--R              (4a c d  + b c )x + 5a c d
+--R     + 
+--R                       4+-+                       2 +-+                  4+-+
+--R         +-+ +-+      x\|b       4+-+3 4+-+      x \|b      +-+ +-+     x\|b
+--R     - c\|a \|b atanh(-----) - d \|a   \|b atanh(------ - c\|a \|b atan(-----)
+--R                       4+-+                        +-+                   4+-+
+--R                       \|a                        \|a                    \|a
+--R  /
+--R       +-+4+-+3 +-+4+-+
+--R     2\|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 683
+
+)clear all
+
+--S 684 of 953
+t0:=(c+d*x)/(1-x^4)
+--R 
+--R
+--R        - d x - c
+--R   (1)  ---------
+--R           4
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 684
+
+--S 685 of 953
+r0:=1/2*c*atan(x)+1/2*c*atanh(x)+1/2*d*atanh(x^2)
+--R 
+--R
+--R                 2
+--R        d atanh(x ) + c atanh(x) + c atan(x)
+--R   (2)  ------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 685
+
+--S 686 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R        d log(x  + 1) + (- d + c)log(x + 1) + (- d - c)log(x - 1) + 2c atan(x)
+--R   (3)  ----------------------------------------------------------------------
+--R                                           4
+--R                                         Type: Union(Expression(Integer),...)
+--E 686
+
+--S 687 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2                                                              2
+--R       d log(x  + 1) + (- d + c)log(x + 1) + (- d - c)log(x - 1) - 2d atanh(x )
+--R     + 
+--R       - 2c atanh(x)
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 688
+
+)clear all
+
+--S 689 of 953
+t0:=(1+x+x^2+x^3)/(1-x^4)
+--R 
+--R
+--R            1
+--R   (1)  - -----
+--R          x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 689
+
+--S 690 of 953
+r0:=-log(1-x)
+--R 
+--R
+--R   (2)  - log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 690
+
+--S 691 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  - log(x - 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 691
+
+--S 692 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  - log(x - 1) + log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 693
+
+)clear all
+
+--S 694 of 953
+t0:=(1+x+x^2+x^3)/(1+x^4)
+--R 
+--R
+--R         3    2
+--R        x  + x  + x + 1
+--R   (1)  ---------------
+--R              4
+--R             x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 694
+
+--S 695 of 953
+r0:=1/2*atan(x^2)+1/4*log(1+x^4)-atan(1-x*sqrt(2))/sqrt(2)+_
+   atan(1+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R         +-+     4                +-+                +-+          +-+      2
+--R        \|2 log(x  + 1) + 4atan(x\|2  + 1) + 4atan(x\|2  - 1) + 2\|2 atan(x )
+--R   (2)  ---------------------------------------------------------------------
+--R                                          +-+
+--R                                        4\|2
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                       +---------+
+--R                                       |  +-+
+--R                              +-+      |3\|2  + 4
+--R           +---------+     (2\|2  - 2) |---------
+--R           |  +-+                      |    +-+
+--R           |3\|2  + 4                 \|  4\|2
+--R       - 4 |--------- atan(-----------------------)
+--R           |    +-+                 +-+
+--R          \|  4\|2                x\|2  - 1
+--R     + 
+--R                                       +---------+
+--R                                       |  +-+
+--R                              +-+      |3\|2  - 4
+--R           +---------+     (2\|2  + 2) |---------
+--R           |  +-+                      |    +-+
+--R           |3\|2  - 4                 \|  4\|2              +-+    2
+--R       - 4 |--------- atan(-----------------------) + log(x\|2  + x  + 1)
+--R           |    +-+                 +-+
+--R          \|  4\|2                x\|2  + 1
+--R     + 
+--R               +-+    2
+--R       log(- x\|2  + x  + 1)
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 696
+
+--S 697 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           +---------+
+--R                                           |  +-+
+--R                                  +-+      |3\|2  + 4
+--R               +---------+     (2\|2  - 2) |---------
+--R               |  +-+                      |    +-+
+--R           +-+ |3\|2  + 4                 \|  4\|2
+--R       - 4\|2  |--------- atan(-----------------------)
+--R               |    +-+                 +-+
+--R              \|  4\|2                x\|2  - 1
+--R     + 
+--R                                           +---------+
+--R                                           |  +-+
+--R                                  +-+      |3\|2  - 4
+--R               +---------+     (2\|2  + 2) |---------
+--R               |  +-+                      |    +-+
+--R           +-+ |3\|2  - 4                 \|  4\|2
+--R       - 4\|2  |--------- atan(-----------------------)
+--R               |    +-+                 +-+
+--R              \|  4\|2                x\|2  + 1
+--R     + 
+--R        +-+      +-+    2         +-+     4         +-+        +-+    2
+--R       \|2 log(x\|2  + x  + 1) - \|2 log(x  + 1) + \|2 log(- x\|2  + x  + 1)
+--R     + 
+--R                 +-+                +-+          +-+      2
+--R       - 4atan(x\|2  + 1) - 4atan(x\|2  - 1) - 2\|2 atan(x )
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 698
+
+)clear all
+
+--S 699 of 953
+t0:=(1+x+x^2+x^3)/(a-b*x^4)
+--R 
+--R
+--R           3    2
+--R        - x  - x  - x - 1
+--R   (1)  -----------------
+--R                4
+--R             b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 699
+
+--S 700 of 953
+r0:=-1/4*log(a-b*x^4)/b-1/2*atan(b^(1/4)*x/a^(1/4))*(sqrt(a)-_
+   sqrt(b))/(a^(3/4)*b^(3/4))+1/2*atanh(x^2*sqrt(b)/sqrt(a))/_
+   (sqrt(a)*sqrt(b))+1/2*atanh(b^(1/4)*x/a^(1/4))*(sqrt(a)+sqrt(b))/_
+   (a^(3/4)*b^(3/4))
+--R 
+--R
+--R   (2)
+--R                                  4+-+                         2 +-+
+--R             +-+     2 +-+       x\|b        4+-+3 4+-+3      x \|b
+--R       (2a b\|b  + 2b \|a )atanh(-----) + 2b \|a   \|b  atanh(------)
+--R                                  4+-+                          +-+
+--R                                  \|a                          \|a
+--R     + 
+--R                                   4+-+
+--R               +-+     2 +-+      x\|b              4      +-+4+-+3 +-+4+-+3
+--R       (- 2a b\|b  + 2b \|a )atan(-----) - log(- b x  + a)\|a \|a  \|b \|b
+--R                                   4+-+
+--R                                   \|a
+--R  /
+--R        +-+4+-+3 +-+4+-+3
+--R     4b\|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 700
+
+--S 701 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             b
+--R          *
+--R             ROOT
+--R                          2     2          2                         2     2
+--R                    - 6a b %%DH1  + (- 4a b %%DH0 - 4a b)%%DH1 - 6a b %%DH0
+--R                  + 
+--R                    - 4a b %%DH0 + 3b - a
+--R               /
+--R                      2
+--R                  2a b
+--R         + 
+--R           - b %%DH1 - b %%DH0 - 1
+--R      *
+--R         log
+--R                      3 3          2 3     3 2              2 3     3 2
+--R                  (32a b %%DH0 - 8a b  + 8a b )%%DH1 + (- 8a b  + 8a b )%%DH0
+--R                + 
+--R                      3     2 2     3
+--R                  2a b  - 4a b  + 2a b
+--R             *
+--R                ROOT
+--R                             2     2          2                         2     2
+--R                       - 6a b %%DH1  + (- 4a b %%DH0 - 4a b)%%DH1 - 6a b %%DH0
+--R                     + 
+--R                       - 4a b %%DH0 + 3b - a
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                  3 3          2 3     3 2      2
+--R              (32a b %%DH0 - 8a b  + 8a b )%%DH1
+--R            + 
+--R                  3 3     2      3 2            3     2 2     3
+--R              (32a b %%DH0  + 32a b %%DH0 - 2a b  - 4a b  + 6a b)%%DH1
+--R            + 
+--R                   2 3     3 2      2          3     2 2     3
+--R              (- 8a b  + 8a b )%%DH0  + (- 2a b  - 4a b  + 6a b)%%DH0
+--R            + 
+--R                3       2    2         2     2     3
+--R              (b  - 2a b  + a b)x + a b  - 2a b + a
+--R     + 
+--R           -
+--R                b
+--R             *
+--R                ROOT
+--R                             2     2          2                         2     2
+--R                       - 6a b %%DH1  + (- 4a b %%DH0 - 4a b)%%DH1 - 6a b %%DH0
+--R                     + 
+--R                       - 4a b %%DH0 + 3b - a
+--R                  /
+--R                         2
+--R                     2a b
+--R         + 
+--R           - b %%DH1 - b %%DH0 - 1
+--R      *
+--R         log
+--R                        3 3          2 3     3 2            2 3     3 2
+--R                  (- 32a b %%DH0 + 8a b  - 8a b )%%DH1 + (8a b  - 8a b )%%DH0
+--R                + 
+--R                        3     2 2     3
+--R                  - 2a b  + 4a b  - 2a b
+--R             *
+--R                ROOT
+--R                             2     2          2                         2     2
+--R                       - 6a b %%DH1  + (- 4a b %%DH0 - 4a b)%%DH1 - 6a b %%DH0
+--R                     + 
+--R                       - 4a b %%DH0 + 3b - a
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                  3 3          2 3     3 2      2
+--R              (32a b %%DH0 - 8a b  + 8a b )%%DH1
+--R            + 
+--R                  3 3     2      3 2            3     2 2     3
+--R              (32a b %%DH0  + 32a b %%DH0 - 2a b  - 4a b  + 6a b)%%DH1
+--R            + 
+--R                   2 3     3 2      2          3     2 2     3
+--R              (- 8a b  + 8a b )%%DH0  + (- 2a b  - 4a b  + 6a b)%%DH0
+--R            + 
+--R                3       2    2         2     2     3
+--R              (b  - 2a b  + a b)x + a b  - 2a b + a
+--R     + 
+--R         2b %%DH1
+--R      *
+--R         log
+--R                    3 3           2 3      3 2      2
+--R              (- 64a b %%DH0 + 16a b  - 16a b )%%DH1
+--R            + 
+--R                    3 3     2      3 2            3     2 2      3
+--R              (- 64a b %%DH0  - 64a b %%DH0 + 4a b  + 8a b  - 12a b)%%DH1
+--R            + 
+--R                   3 3     3      3 2     2       2 2      3
+--R              - 64a b %%DH0  - 64a b %%DH0  + (24a b  - 24a b)%%DH0
+--R            + 
+--R                3       2    2          2     2      3
+--R              (b  - 2a b  + a b)x - 3a b  + 6a b - 3a
+--R     + 
+--R         2b %%DH0
+--R      *
+--R         log
+--R                 3 3     3       2 3      3 2      2
+--R              64a b %%DH0  + (16a b  + 48a b )%%DH0
+--R            + 
+--R                   3      2 2      3            3       2    2         2     2
+--R              (4a b  - 16a b  + 12a b)%%DH0 + (b  - 2a b  + a b)x + a b  - 2a b
+--R            + 
+--R               3
+--R              a
+--R  /
+--R     2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 701
+
+--S 702 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+4+-+3 +-+4+-+3
+--R             2b\|a \|a  \|b \|b
+--R          *
+--R             ROOT
+--R                          2     2          2                         2     2
+--R                    - 6a b %%DH1  + (- 4a b %%DH0 - 4a b)%%DH1 - 6a b %%DH0
+--R                  + 
+--R                    - 4a b %%DH0 + 3b - a
+--R               /
+--R                      2
+--R                  2a b
+--R         + 
+--R                +-+4+-+3 +-+4+-+3           +-+4+-+3 +-+4+-+3
+--R           - 2b\|a \|a  \|b \|b  %%DH1 - 2b\|a \|a  \|b \|b  %%DH0
+--R         + 
+--R               +-+4+-+3 +-+4+-+3
+--R           - 2\|a \|a  \|b \|b
+--R      *
+--R         log
+--R                      3 3          2 3     3 2              2 3     3 2
+--R                  (32a b %%DH0 - 8a b  + 8a b )%%DH1 + (- 8a b  + 8a b )%%DH0
+--R                + 
+--R                      3     2 2     3
+--R                  2a b  - 4a b  + 2a b
+--R             *
+--R                ROOT
+--R                             2     2          2                         2     2
+--R                       - 6a b %%DH1  + (- 4a b %%DH0 - 4a b)%%DH1 - 6a b %%DH0
+--R                     + 
+--R                       - 4a b %%DH0 + 3b - a
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                  3 3          2 3     3 2      2
+--R              (32a b %%DH0 - 8a b  + 8a b )%%DH1
+--R            + 
+--R                  3 3     2      3 2            3     2 2     3
+--R              (32a b %%DH0  + 32a b %%DH0 - 2a b  - 4a b  + 6a b)%%DH1
+--R            + 
+--R                   2 3     3 2      2          3     2 2     3
+--R              (- 8a b  + 8a b )%%DH0  + (- 2a b  - 4a b  + 6a b)%%DH0
+--R            + 
+--R                3       2    2         2     2     3
+--R              (b  - 2a b  + a b)x + a b  - 2a b + a
+--R     + 
+--R           -
+--R                   +-+4+-+3 +-+4+-+3
+--R                2b\|a \|a  \|b \|b
+--R             *
+--R                ROOT
+--R                             2     2          2                         2     2
+--R                       - 6a b %%DH1  + (- 4a b %%DH0 - 4a b)%%DH1 - 6a b %%DH0
+--R                     + 
+--R                       - 4a b %%DH0 + 3b - a
+--R                  /
+--R                         2
+--R                     2a b
+--R         + 
+--R                +-+4+-+3 +-+4+-+3           +-+4+-+3 +-+4+-+3
+--R           - 2b\|a \|a  \|b \|b  %%DH1 - 2b\|a \|a  \|b \|b  %%DH0
+--R         + 
+--R               +-+4+-+3 +-+4+-+3
+--R           - 2\|a \|a  \|b \|b
+--R      *
+--R         log
+--R                        3 3          2 3     3 2            2 3     3 2
+--R                  (- 32a b %%DH0 + 8a b  - 8a b )%%DH1 + (8a b  - 8a b )%%DH0
+--R                + 
+--R                        3     2 2     3
+--R                  - 2a b  + 4a b  - 2a b
+--R             *
+--R                ROOT
+--R                             2     2          2                         2     2
+--R                       - 6a b %%DH1  + (- 4a b %%DH0 - 4a b)%%DH1 - 6a b %%DH0
+--R                     + 
+--R                       - 4a b %%DH0 + 3b - a
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                  3 3          2 3     3 2      2
+--R              (32a b %%DH0 - 8a b  + 8a b )%%DH1
+--R            + 
+--R                  3 3     2      3 2            3     2 2     3
+--R              (32a b %%DH0  + 32a b %%DH0 - 2a b  - 4a b  + 6a b)%%DH1
+--R            + 
+--R                   2 3     3 2      2          3     2 2     3
+--R              (- 8a b  + 8a b )%%DH0  + (- 2a b  - 4a b  + 6a b)%%DH0
+--R            + 
+--R                3       2    2         2     2     3
+--R              (b  - 2a b  + a b)x + a b  - 2a b + a
+--R     + 
+--R            +-+4+-+3 +-+4+-+3
+--R         4b\|a \|a  \|b \|b  %%DH1
+--R      *
+--R         log
+--R                    3 3           2 3      3 2      2
+--R              (- 64a b %%DH0 + 16a b  - 16a b )%%DH1
+--R            + 
+--R                    3 3     2      3 2            3     2 2      3
+--R              (- 64a b %%DH0  - 64a b %%DH0 + 4a b  + 8a b  - 12a b)%%DH1
+--R            + 
+--R                   3 3     3      3 2     2       2 2      3
+--R              - 64a b %%DH0  - 64a b %%DH0  + (24a b  - 24a b)%%DH0
+--R            + 
+--R                3       2    2          2     2      3
+--R              (b  - 2a b  + a b)x - 3a b  + 6a b - 3a
+--R     + 
+--R            +-+4+-+3 +-+4+-+3
+--R         4b\|a \|a  \|b \|b  %%DH0
+--R      *
+--R         log
+--R                 3 3     3       2 3      3 2      2
+--R              64a b %%DH0  + (16a b  + 48a b )%%DH0
+--R            + 
+--R                   3      2 2      3            3       2    2         2     2
+--R              (4a b  - 16a b  + 12a b)%%DH0 + (b  - 2a b  + a b)x + a b  - 2a b
+--R            + 
+--R               3
+--R              a
+--R     + 
+--R                                    4+-+                         2 +-+
+--R               +-+     2 +-+       x\|b        4+-+3 4+-+3      x \|b
+--R       (- 2a b\|b  - 2b \|a )atanh(-----) - 2b \|a   \|b  atanh(------)
+--R                                    4+-+                          +-+
+--R                                    \|a                          \|a
+--R     + 
+--R                                 4+-+
+--R             +-+     2 +-+      x\|b              4      +-+4+-+3 +-+4+-+3
+--R       (2a b\|b  - 2b \|a )atan(-----) + log(- b x  + a)\|a \|a  \|b \|b
+--R                                 4+-+
+--R                                 \|a
+--R  /
+--R        +-+4+-+3 +-+4+-+3
+--R     4b\|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R             2     4+-+2    2 +-+ 4+-+2   4+-+2 +-+
+--R        ((- x  - 1)\|a   + x \|a )\|b   + \|a  \|b
+--R   (5)  -------------------------------------------
+--R                        4     4+-+2 4+-+2
+--R                    (b x  - a)\|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 703
+
+)clear all
+
+--S 704 of 953
+t0:=(c+d*x+e*x^2+f*x^3)/(a-b*x^4)
+--R 
+--R
+--R             3      2
+--R        - f x  - e x  - d x - c
+--R   (1)  -----------------------
+--R                   4
+--R                b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 704
+
+--S 705 of 953
+r0:=-1/4*f*log(a-b*x^4)/b+1/2*d*atanh(x^2*sqrt(b)/sqrt(a))/(sqrt(a)*_
+   sqrt(b))+1/2*atan(b^(1/4)*x/a^(1/4))*(-e*sqrt(a)+c*sqrt(b))/(a^(3/4)*_
+   b^(3/4))+1/2*atanh(b^(1/4)*x/a^(1/4))*(e*sqrt(a)+c*sqrt(b))/_
+   (a^(3/4)*b^(3/4))
+--R 
+--R
+--R   (2)
+--R                                     4+-+                           2 +-+
+--R               +-+     2  +-+       x\|b          4+-+3 4+-+3      x \|b
+--R       (2a b e\|b  + 2b c\|a )atanh(-----) + 2b d \|a   \|b  atanh(------)
+--R                                     4+-+                            +-+
+--R                                     \|a                            \|a
+--R     + 
+--R                                    4+-+
+--R               +-+     2  +-+      x\|b                4      +-+4+-+3 +-+4+-+3
+--R     (- 2a b e\|b  + 2b c\|a )atan(-----) - f log(- b x  + a)\|a \|a  \|b \|b
+--R                                    4+-+
+--R                                    \|a
+--R  /
+--R        +-+4+-+3 +-+4+-+3
+--R     4b\|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 705
+
+--S 706 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             b
+--R          *
+--R             ROOT
+--R                          2     2          2                           2     2
+--R                    - 6a b %%DI1  + (- 4a b %%DI0 - 4a b f)%%DI1 - 6a b %%DI0
+--R                  + 
+--R                                        2               2
+--R                    - 4a b f %%DI0 - a f  + 2b c e + b d
+--R               /
+--R                      2
+--R                  2a b
+--R         + 
+--R           - b %%DI1 - b %%DI0 - f
+--R      *
+--R         log
+--R                          4 3 3      3 4 2       3 4   2
+--R                      (32a b e  + 32a b c e - 64a b c d )%%DI0
+--R                    + 
+--R                         4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                    + 
+--R                         3 3 3      2 4 3
+--R                      16a b d e + 8a b c d
+--R                 *
+--R                    %%DI1
+--R                + 
+--R                         4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                    + 
+--R                         3 3 3      2 4 3
+--R                      16a b d e + 8a b c d
+--R                 *
+--R                    %%DI0
+--R                + 
+--R                     4   3     3 2 2      3 2   2  2
+--R                  (2a b e  + 2a b c e - 4a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e + 4a b c d)f + 2a b c e
+--R                + 
+--R                      3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  - 2a b d e  + 6a b c d e - 4a b c d  - 2a b c
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DI1  + (- 4a b %%DI0 - 4a b f)%%DI1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DI0  - 4a b f %%DI0 - a f  + 2b c e + b d
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2
+--R                  (32a b e  + 32a b c e - 64a b c d )%%DI0
+--R                + 
+--R                     4 2 3     3 3 2       3 3   2        3 3     2      3 3 3
+--R                  (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e  + 16a b d e
+--R                + 
+--R                    2 4 3
+--R                  8a b c d
+--R             *
+--R                     2
+--R                %%DI1
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2      2
+--R                  (32a b e  + 32a b c e - 64a b c d )%%DI0
+--R                + 
+--R                      4 2 3      3 3 2       3 3   2
+--R                  (32a b e  + 32a b c e - 64a b c d )f %%DI0
+--R                + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  + 6a b c e - 12a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e + 4a b c d)f - 2a b c e
+--R                + 
+--R                    3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  2a b d e  - 6a b c d e + 4a b c d  + 2a b c
+--R             *
+--R                %%DI1
+--R            + 
+--R                     4 2 3     3 3 2       3 3   2        3 3     2      3 3 3
+--R                  (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e  + 16a b d e
+--R                + 
+--R                    2 4 3
+--R                  8a b c d
+--R             *
+--R                     2
+--R                %%DI0
+--R            + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  + 6a b c e - 12a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e + 4a b c d)f - 2a b c e
+--R                + 
+--R                    3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  2a b d e  - 6a b c d e + 4a b c d  + 2a b c
+--R             *
+--R                %%DI0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3      2 2 4      3 4  2
+--R                  a b e  + a b c e  - 8a b c d e  + (4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  - b c
+--R             *
+--R                x
+--R            + 
+--R                4 3    3   2      3     2  3
+--R              (a e  + a b c e - 2a b c d )f
+--R            + 
+--R                   3       2     3   3     2 2 3   2
+--R              (- 3a b c d e  + 2a b d e + a b c d)f
+--R            + 
+--R                  3     4    3   2 3     2 2 2 2      2 2   4      3 5
+--R              (- a b c e  + a b d e  - 3a b c d e + 2a b c d  + a b c )f
+--R            + 
+--R                 3     5     2 2 2   3    2 2   3 2        2 2 5       3 4
+--R              - a b d e  + 4a b c d e  + a b c d e  + (- 2a b d  - 3a b c d)e
+--R            + 
+--R                 3 3 3
+--R              a b c d
+--R     + 
+--R           -
+--R                b
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DI1  + (- 4a b %%DI0 - 4a b f)%%DI1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DI0  - 4a b f %%DI0 - a f  + 2b c e + b d
+--R                  /
+--R                         2
+--R                     2a b
+--R         + 
+--R           - b %%DI1 - b %%DI0 - f
+--R      *
+--R         log
+--R                            4 3 3      3 4 2       3 4   2
+--R                      (- 32a b e  - 32a b c e + 64a b c d )%%DI0
+--R                    + 
+--R                           4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (- 8a b e  - 8a b c e + 16a b c d )f + 24a b c d e
+--R                    + 
+--R                           3 3 3      2 4 3
+--R                      - 16a b d e - 8a b c d
+--R                 *
+--R                    %%DI1
+--R                + 
+--R                           4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (- 8a b e  - 8a b c e + 16a b c d )f + 24a b c d e
+--R                    + 
+--R                           3 3 3      2 4 3
+--R                      - 16a b d e - 8a b c d
+--R                 *
+--R                    %%DI0
+--R                + 
+--R                       4   3     3 2 2      3 2   2  2
+--R                  (- 2a b e  - 2a b c e + 4a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e - 4a b c d)f - 2a b c e  + 2a b d e
+--R                + 
+--R                      2 3 2 2      2 3   4       4 5
+--R                  - 6a b c d e + 4a b c d  + 2a b c
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DI1  + (- 4a b %%DI0 - 4a b f)%%DI1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DI0  - 4a b f %%DI0 - a f  + 2b c e + b d
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2
+--R                  (32a b e  + 32a b c e - 64a b c d )%%DI0
+--R                + 
+--R                     4 2 3     3 3 2       3 3   2        3 3     2      3 3 3
+--R                  (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e  + 16a b d e
+--R                + 
+--R                    2 4 3
+--R                  8a b c d
+--R             *
+--R                     2
+--R                %%DI1
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2      2
+--R                  (32a b e  + 32a b c e - 64a b c d )%%DI0
+--R                + 
+--R                      4 2 3      3 3 2       3 3   2
+--R                  (32a b e  + 32a b c e - 64a b c d )f %%DI0
+--R                + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  + 6a b c e - 12a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e + 4a b c d)f - 2a b c e
+--R                + 
+--R                    3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  2a b d e  - 6a b c d e + 4a b c d  + 2a b c
+--R             *
+--R                %%DI1
+--R            + 
+--R                     4 2 3     3 3 2       3 3   2        3 3     2      3 3 3
+--R                  (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e  + 16a b d e
+--R                + 
+--R                    2 4 3
+--R                  8a b c d
+--R             *
+--R                     2
+--R                %%DI0
+--R            + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  + 6a b c e - 12a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e + 4a b c d)f - 2a b c e
+--R                + 
+--R                    3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  2a b d e  - 6a b c d e + 4a b c d  + 2a b c
+--R             *
+--R                %%DI0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3      2 2 4      3 4  2
+--R                  a b e  + a b c e  - 8a b c d e  + (4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  - b c
+--R             *
+--R                x
+--R            + 
+--R                4 3    3   2      3     2  3
+--R              (a e  + a b c e - 2a b c d )f
+--R            + 
+--R                   3       2     3   3     2 2 3   2
+--R              (- 3a b c d e  + 2a b d e + a b c d)f
+--R            + 
+--R                  3     4    3   2 3     2 2 2 2      2 2   4      3 5
+--R              (- a b c e  + a b d e  - 3a b c d e + 2a b c d  + a b c )f
+--R            + 
+--R                 3     5     2 2 2   3    2 2   3 2        2 2 5       3 4
+--R              - a b d e  + 4a b c d e  + a b c d e  + (- 2a b d  - 3a b c d)e
+--R            + 
+--R                 3 3 3
+--R              a b c d
+--R     + 
+--R         2b %%DI1
+--R      *
+--R         log
+--R                        4 3 3      3 4 2        3 4   2
+--R                  (- 64a b e  - 64a b c e + 128a b c d )%%DI0
+--R                + 
+--R                        4 2 3      3 3 2       3 3   2        3 3     2
+--R                  (- 16a b e  - 16a b c e + 32a b c d )f + 48a b c d e
+--R                + 
+--R                       3 3 3       2 4 3
+--R                  - 32a b d e - 16a b c d
+--R             *
+--R                     2
+--R                %%DI1
+--R            + 
+--R                        4 3 3      3 4 2        3 4   2      2
+--R                  (- 64a b e  - 64a b c e + 128a b c d )%%DI0
+--R                + 
+--R                        4 2 3      3 3 2        3 3   2
+--R                  (- 64a b e  - 64a b c e + 128a b c d )f %%DI0
+--R                + 
+--R                        4   3      3 2 2       3 2   2  2
+--R                  (- 12a b e  - 12a b c e + 24a b c d )f
+--R                + 
+--R                      3 2     2      3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (24a b c d e  - 16a b d e - 8a b c d)f + 4a b c e  - 4a b d e
+--R                + 
+--R                     2 3 2 2      2 3   4       4 5
+--R                  12a b c d e - 8a b c d  - 4a b c
+--R             *
+--R                %%DI1
+--R            + 
+--R                    4 3 3      3 4 2        3 4   2      3
+--R              (- 64a b e  - 64a b c e + 128a b c d )%%DI0
+--R            + 
+--R                    4 2 3      3 3 2        3 3   2        2
+--R              (- 64a b e  - 64a b c e + 128a b c d )f %%DI0
+--R            + 
+--R                        4   3      3 2 2       3 2   2  2      3 2   4
+--R                  (- 24a b e  - 24a b c e + 48a b c d )f  + 16a b c e
+--R                + 
+--R                    3 2 2 3      2 3 3 2      2 3 2 2       2 3   4
+--R                  8a b d e  + 16a b c e  - 24a b c d e - 16a b c d
+--R             *
+--R                %%DI0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3      2 2 4      3 4  2
+--R                  a b e  + a b c e  - 8a b c d e  + (4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  - b c
+--R             *
+--R                x
+--R            + 
+--R                   4 3     3   2      3     2  3
+--R              (- 3a e  - 3a b c e + 6a b c d )f
+--R            + 
+--R                 3       2     3   3     2 2 3   2
+--R              (3a b c d e  - 2a b d e - a b c d)f
+--R            + 
+--R                    3     4    3   2 3     2 2 3 2     2 2 2 2      2 2   4
+--R                  5a b c e  + a b d e  + 4a b c e  - 3a b c d e - 6a b c d
+--R                + 
+--R                       3 5
+--R                  - a b c
+--R             *
+--R                f
+--R            + 
+--R                 3     5     2 2 2   3     2 2   3 2      2 2 5      3 4
+--R              - a b d e  - 8a b c d e  + 3a b c d e  + (2a b d  + a b c d)e
+--R            + 
+--R                  3 3 3
+--R              3a b c d
+--R     + 
+--R         2b %%DI0
+--R      *
+--R         log
+--R                  4 3 3      3 4 2        3 4   2      3
+--R              (64a b e  + 64a b c e - 128a b c d )%%DI0
+--R            + 
+--R                      4 2 3      3 3 2       3 3   2        3 3     2
+--R                  (48a b e  + 48a b c e - 96a b c d )f + 48a b c d e
+--R                + 
+--R                       3 3 3       2 4 3
+--R                  - 32a b d e - 16a b c d
+--R             *
+--R                     2
+--R                %%DI0
+--R            + 
+--R                      4   3      3 2 2       3 2   2  2
+--R                  (12a b e  + 12a b c e - 24a b c d )f
+--R                + 
+--R                      3 2     2      3 2 3      2 3 3         3 2   4
+--R                  (24a b c d e  - 16a b d e - 8a b c d)f - 12a b c e
+--R                + 
+--R                       3 2 2 3      2 3 3 2      2 3 2 2      2 3   4       4 5
+--R                  - 12a b d e  - 16a b c e  + 36a b c d e + 8a b c d  - 4a b c
+--R             *
+--R                %%DI0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3      2 2 4      3 4  2
+--R                  a b e  + a b c e  - 8a b c d e  + (4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  - b c
+--R             *
+--R                x
+--R            + 
+--R                4 3    3   2      3     2  3
+--R              (a e  + a b c e - 2a b c d )f
+--R            + 
+--R                 3       2     3   3     2 2 3   2
+--R              (3a b c d e  - 2a b d e - a b c d)f
+--R            + 
+--R                      3     4     3   2 3     2 2 3 2     2 2 2 2      2 2   4
+--R                  - 3a b c e  - 3a b d e  - 4a b c e  + 9a b c d e + 2a b c d
+--R                + 
+--R                       3 5
+--R                  - a b c
+--R             *
+--R                f
+--R            + 
+--R                3     5     2 2   3 2      2 2 5       3 4          3 3 3
+--R              3a b d e  - 5a b c d e  + (2a b d  + 5a b c d)e - 5a b c d
+--R  /
+--R     2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 706
+
+--S 707 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+4+-+3 +-+4+-+3
+--R             2b\|a \|a  \|b \|b
+--R          *
+--R             ROOT
+--R                          2     2          2                           2     2
+--R                    - 6a b %%DI1  + (- 4a b %%DI0 - 4a b f)%%DI1 - 6a b %%DI0
+--R                  + 
+--R                                        2               2
+--R                    - 4a b f %%DI0 - a f  + 2b c e + b d
+--R               /
+--R                      2
+--R                  2a b
+--R         + 
+--R                +-+4+-+3 +-+4+-+3           +-+4+-+3 +-+4+-+3
+--R           - 2b\|a \|a  \|b \|b  %%DI1 - 2b\|a \|a  \|b \|b  %%DI0
+--R         + 
+--R                +-+4+-+3 +-+4+-+3
+--R           - 2f\|a \|a  \|b \|b
+--R      *
+--R         log
+--R                          4 3 3      3 4 2       3 4   2
+--R                      (32a b e  + 32a b c e - 64a b c d )%%DI0
+--R                    + 
+--R                         4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                    + 
+--R                         3 3 3      2 4 3
+--R                      16a b d e + 8a b c d
+--R                 *
+--R                    %%DI1
+--R                + 
+--R                         4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                    + 
+--R                         3 3 3      2 4 3
+--R                      16a b d e + 8a b c d
+--R                 *
+--R                    %%DI0
+--R                + 
+--R                     4   3     3 2 2      3 2   2  2
+--R                  (2a b e  + 2a b c e - 4a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e + 4a b c d)f + 2a b c e
+--R                + 
+--R                      3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  - 2a b d e  + 6a b c d e - 4a b c d  - 2a b c
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DI1  + (- 4a b %%DI0 - 4a b f)%%DI1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DI0  - 4a b f %%DI0 - a f  + 2b c e + b d
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2
+--R                  (32a b e  + 32a b c e - 64a b c d )%%DI0
+--R                + 
+--R                     4 2 3     3 3 2       3 3   2        3 3     2      3 3 3
+--R                  (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e  + 16a b d e
+--R                + 
+--R                    2 4 3
+--R                  8a b c d
+--R             *
+--R                     2
+--R                %%DI1
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2      2
+--R                  (32a b e  + 32a b c e - 64a b c d )%%DI0
+--R                + 
+--R                      4 2 3      3 3 2       3 3   2
+--R                  (32a b e  + 32a b c e - 64a b c d )f %%DI0
+--R                + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  + 6a b c e - 12a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e + 4a b c d)f - 2a b c e
+--R                + 
+--R                    3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  2a b d e  - 6a b c d e + 4a b c d  + 2a b c
+--R             *
+--R                %%DI1
+--R            + 
+--R                     4 2 3     3 3 2       3 3   2        3 3     2      3 3 3
+--R                  (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e  + 16a b d e
+--R                + 
+--R                    2 4 3
+--R                  8a b c d
+--R             *
+--R                     2
+--R                %%DI0
+--R            + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  + 6a b c e - 12a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e + 4a b c d)f - 2a b c e
+--R                + 
+--R                    3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  2a b d e  - 6a b c d e + 4a b c d  + 2a b c
+--R             *
+--R                %%DI0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3      2 2 4      3 4  2
+--R                  a b e  + a b c e  - 8a b c d e  + (4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  - b c
+--R             *
+--R                x
+--R            + 
+--R                4 3    3   2      3     2  3
+--R              (a e  + a b c e - 2a b c d )f
+--R            + 
+--R                   3       2     3   3     2 2 3   2
+--R              (- 3a b c d e  + 2a b d e + a b c d)f
+--R            + 
+--R                  3     4    3   2 3     2 2 2 2      2 2   4      3 5
+--R              (- a b c e  + a b d e  - 3a b c d e + 2a b c d  + a b c )f
+--R            + 
+--R                 3     5     2 2 2   3    2 2   3 2        2 2 5       3 4
+--R              - a b d e  + 4a b c d e  + a b c d e  + (- 2a b d  - 3a b c d)e
+--R            + 
+--R                 3 3 3
+--R              a b c d
+--R     + 
+--R           -
+--R                   +-+4+-+3 +-+4+-+3
+--R                2b\|a \|a  \|b \|b
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DI1  + (- 4a b %%DI0 - 4a b f)%%DI1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DI0  - 4a b f %%DI0 - a f  + 2b c e + b d
+--R                  /
+--R                         2
+--R                     2a b
+--R         + 
+--R                +-+4+-+3 +-+4+-+3           +-+4+-+3 +-+4+-+3
+--R           - 2b\|a \|a  \|b \|b  %%DI1 - 2b\|a \|a  \|b \|b  %%DI0
+--R         + 
+--R                +-+4+-+3 +-+4+-+3
+--R           - 2f\|a \|a  \|b \|b
+--R      *
+--R         log
+--R                            4 3 3      3 4 2       3 4   2
+--R                      (- 32a b e  - 32a b c e + 64a b c d )%%DI0
+--R                    + 
+--R                           4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (- 8a b e  - 8a b c e + 16a b c d )f + 24a b c d e
+--R                    + 
+--R                           3 3 3      2 4 3
+--R                      - 16a b d e - 8a b c d
+--R                 *
+--R                    %%DI1
+--R                + 
+--R                           4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (- 8a b e  - 8a b c e + 16a b c d )f + 24a b c d e
+--R                    + 
+--R                           3 3 3      2 4 3
+--R                      - 16a b d e - 8a b c d
+--R                 *
+--R                    %%DI0
+--R                + 
+--R                       4   3     3 2 2      3 2   2  2
+--R                  (- 2a b e  - 2a b c e + 4a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e - 4a b c d)f - 2a b c e  + 2a b d e
+--R                + 
+--R                      2 3 2 2      2 3   4       4 5
+--R                  - 6a b c d e + 4a b c d  + 2a b c
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DI1  + (- 4a b %%DI0 - 4a b f)%%DI1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DI0  - 4a b f %%DI0 - a f  + 2b c e + b d
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2
+--R                  (32a b e  + 32a b c e - 64a b c d )%%DI0
+--R                + 
+--R                     4 2 3     3 3 2       3 3   2        3 3     2      3 3 3
+--R                  (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e  + 16a b d e
+--R                + 
+--R                    2 4 3
+--R                  8a b c d
+--R             *
+--R                     2
+--R                %%DI1
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2      2
+--R                  (32a b e  + 32a b c e - 64a b c d )%%DI0
+--R                + 
+--R                      4 2 3      3 3 2       3 3   2
+--R                  (32a b e  + 32a b c e - 64a b c d )f %%DI0
+--R                + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  + 6a b c e - 12a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e + 4a b c d)f - 2a b c e
+--R                + 
+--R                    3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  2a b d e  - 6a b c d e + 4a b c d  + 2a b c
+--R             *
+--R                %%DI1
+--R            + 
+--R                     4 2 3     3 3 2       3 3   2        3 3     2      3 3 3
+--R                  (8a b e  + 8a b c e - 16a b c d )f - 24a b c d e  + 16a b d e
+--R                + 
+--R                    2 4 3
+--R                  8a b c d
+--R             *
+--R                     2
+--R                %%DI0
+--R            + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  + 6a b c e - 12a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e + 4a b c d)f - 2a b c e
+--R                + 
+--R                    3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  2a b d e  - 6a b c d e + 4a b c d  + 2a b c
+--R             *
+--R                %%DI0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3      2 2 4      3 4  2
+--R                  a b e  + a b c e  - 8a b c d e  + (4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  - b c
+--R             *
+--R                x
+--R            + 
+--R                4 3    3   2      3     2  3
+--R              (a e  + a b c e - 2a b c d )f
+--R            + 
+--R                   3       2     3   3     2 2 3   2
+--R              (- 3a b c d e  + 2a b d e + a b c d)f
+--R            + 
+--R                  3     4    3   2 3     2 2 2 2      2 2   4      3 5
+--R              (- a b c e  + a b d e  - 3a b c d e + 2a b c d  + a b c )f
+--R            + 
+--R                 3     5     2 2 2   3    2 2   3 2        2 2 5       3 4
+--R              - a b d e  + 4a b c d e  + a b c d e  + (- 2a b d  - 3a b c d)e
+--R            + 
+--R                 3 3 3
+--R              a b c d
+--R     + 
+--R            +-+4+-+3 +-+4+-+3
+--R         4b\|a \|a  \|b \|b  %%DI1
+--R      *
+--R         log
+--R                        4 3 3      3 4 2        3 4   2
+--R                  (- 64a b e  - 64a b c e + 128a b c d )%%DI0
+--R                + 
+--R                        4 2 3      3 3 2       3 3   2        3 3     2
+--R                  (- 16a b e  - 16a b c e + 32a b c d )f + 48a b c d e
+--R                + 
+--R                       3 3 3       2 4 3
+--R                  - 32a b d e - 16a b c d
+--R             *
+--R                     2
+--R                %%DI1
+--R            + 
+--R                        4 3 3      3 4 2        3 4   2      2
+--R                  (- 64a b e  - 64a b c e + 128a b c d )%%DI0
+--R                + 
+--R                        4 2 3      3 3 2        3 3   2
+--R                  (- 64a b e  - 64a b c e + 128a b c d )f %%DI0
+--R                + 
+--R                        4   3      3 2 2       3 2   2  2
+--R                  (- 12a b e  - 12a b c e + 24a b c d )f
+--R                + 
+--R                      3 2     2      3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (24a b c d e  - 16a b d e - 8a b c d)f + 4a b c e  - 4a b d e
+--R                + 
+--R                     2 3 2 2      2 3   4       4 5
+--R                  12a b c d e - 8a b c d  - 4a b c
+--R             *
+--R                %%DI1
+--R            + 
+--R                    4 3 3      3 4 2        3 4   2      3
+--R              (- 64a b e  - 64a b c e + 128a b c d )%%DI0
+--R            + 
+--R                    4 2 3      3 3 2        3 3   2        2
+--R              (- 64a b e  - 64a b c e + 128a b c d )f %%DI0
+--R            + 
+--R                        4   3      3 2 2       3 2   2  2      3 2   4
+--R                  (- 24a b e  - 24a b c e + 48a b c d )f  + 16a b c e
+--R                + 
+--R                    3 2 2 3      2 3 3 2      2 3 2 2       2 3   4
+--R                  8a b d e  + 16a b c e  - 24a b c d e - 16a b c d
+--R             *
+--R                %%DI0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3      2 2 4      3 4  2
+--R                  a b e  + a b c e  - 8a b c d e  + (4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  - b c
+--R             *
+--R                x
+--R            + 
+--R                   4 3     3   2      3     2  3
+--R              (- 3a e  - 3a b c e + 6a b c d )f
+--R            + 
+--R                 3       2     3   3     2 2 3   2
+--R              (3a b c d e  - 2a b d e - a b c d)f
+--R            + 
+--R                    3     4    3   2 3     2 2 3 2     2 2 2 2      2 2   4
+--R                  5a b c e  + a b d e  + 4a b c e  - 3a b c d e - 6a b c d
+--R                + 
+--R                       3 5
+--R                  - a b c
+--R             *
+--R                f
+--R            + 
+--R                 3     5     2 2 2   3     2 2   3 2      2 2 5      3 4
+--R              - a b d e  - 8a b c d e  + 3a b c d e  + (2a b d  + a b c d)e
+--R            + 
+--R                  3 3 3
+--R              3a b c d
+--R     + 
+--R            +-+4+-+3 +-+4+-+3
+--R         4b\|a \|a  \|b \|b  %%DI0
+--R      *
+--R         log
+--R                  4 3 3      3 4 2        3 4   2      3
+--R              (64a b e  + 64a b c e - 128a b c d )%%DI0
+--R            + 
+--R                      4 2 3      3 3 2       3 3   2        3 3     2
+--R                  (48a b e  + 48a b c e - 96a b c d )f + 48a b c d e
+--R                + 
+--R                       3 3 3       2 4 3
+--R                  - 32a b d e - 16a b c d
+--R             *
+--R                     2
+--R                %%DI0
+--R            + 
+--R                      4   3      3 2 2       3 2   2  2
+--R                  (12a b e  + 12a b c e - 24a b c d )f
+--R                + 
+--R                      3 2     2      3 2 3      2 3 3         3 2   4
+--R                  (24a b c d e  - 16a b d e - 8a b c d)f - 12a b c e
+--R                + 
+--R                       3 2 2 3      2 3 3 2      2 3 2 2      2 3   4       4 5
+--R                  - 12a b d e  - 16a b c e  + 36a b c d e + 8a b c d  - 4a b c
+--R             *
+--R                %%DI0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3      2 2 4      3 4  2
+--R                  a b e  + a b c e  - 8a b c d e  + (4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  - b c
+--R             *
+--R                x
+--R            + 
+--R                4 3    3   2      3     2  3
+--R              (a e  + a b c e - 2a b c d )f
+--R            + 
+--R                 3       2     3   3     2 2 3   2
+--R              (3a b c d e  - 2a b d e - a b c d)f
+--R            + 
+--R                      3     4     3   2 3     2 2 3 2     2 2 2 2      2 2   4
+--R                  - 3a b c e  - 3a b d e  - 4a b c e  + 9a b c d e + 2a b c d
+--R                + 
+--R                       3 5
+--R                  - a b c
+--R             *
+--R                f
+--R            + 
+--R                3     5     2 2   3 2      2 2 5       3 4          3 3 3
+--R              3a b d e  - 5a b c d e  + (2a b d  + 5a b c d)e - 5a b c d
+--R     + 
+--R                                       4+-+                           2 +-+
+--R                 +-+     2  +-+       x\|b          4+-+3 4+-+3      x \|b
+--R       (- 2a b e\|b  - 2b c\|a )atanh(-----) - 2b d \|a   \|b  atanh(------)
+--R                                       4+-+                            +-+
+--R                                       \|a                            \|a
+--R     + 
+--R                                    4+-+
+--R               +-+     2  +-+      x\|b                4      +-+4+-+3 +-+4+-+3
+--R       (2a b e\|b  - 2b c\|a )atan(-----) + f log(- b x  + a)\|a \|a  \|b \|b
+--R                                    4+-+
+--R                                    \|a
+--R  /
+--R        +-+4+-+3 +-+4+-+3
+--R     4b\|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R               2     4+-+2      2 +-+ 4+-+2     4+-+2 +-+
+--R        ((- e x  - c)\|a   + e x \|a )\|b   + c \|a  \|b
+--R   (5)  -------------------------------------------------
+--R                           4     4+-+2 4+-+2
+--R                       (b x  - a)\|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 708
+
+)clear all
+
+--S 709 of 953
+t0:=(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^p
+--R 
+--R
+--R            3      2               4     p
+--R   (1)  (f x  + e x  + d x + c)(b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 953
+--r0:=1/4*f*(a+b*x^4)^(1+p)/(b*(1+p))+c*x*(a+b*x^4)^p*_
+--   hypergeometric(1/4,-p,5/4,-b*x^4/a)/((a+b*x^4)/a)^p+1/2*d*x^2*_
+--   (a+b*x^4)^p*hypergeometric(1/2,-p,3/2,-b*x^4/a)/((a+b*x^4)/a)^p+_
+--   1/3*e*x^3*(a+b*x^4)^p*hypergeometric(3/4,-p,7/4,-b*x^4/a)/((a+b*x^4)/a)^p
+--E 710
+
+--S 711 of 953
+--a0:=integrate(t0,x)
+--E 711
+
+--S 712 of 953
+--m0:=a0-r0
+--E 712
+
+--S 713 of 953
+--d0:=D(m0,x)
+--E 713
+
+)clear all
+
+--S 714 of 953
+t0:=(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^4
+--R 
+--R
+--R   (1)
+--R      4   19    4   18    4   17    4   16       3   15       3   14
+--R     b f x   + b e x   + b d x   + b c x   + 4a b f x   + 4a b e x
+--R   + 
+--R         3   13       3   12     2 2   11     2 2   10     2 2   9     2 2   8
+--R     4a b d x   + 4a b c x   + 6a b f x   + 6a b e x   + 6a b d x  + 6a b c x
+--R   + 
+--R     3     7     3     6     3     5     3     4    4   3    4   2    4       4
+--R   4a b f x  + 4a b e x  + 4a b d x  + 4a b c x  + a f x  + a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 714
+
+--S 715 of 953
+r0:=a^4*c*x+1/2*a^4*d*x^2+1/3*a^4*e*x^3+4/5*a^3*b*c*x^5+2/3*a^3*b*d*x^6+_
+   4/7*a^3*b*e*x^7+2/3*a^2*b^2*c*x^9+3/5*a^2*b^2*d*x^10+6/11*a^2*b^2*_
+   e*x^11+4/13*a*b^3*c*x^13+2/7*a*b^3*d*x^14+4/15*a*b^3*e*x^15+_
+   1/17*b^4*c*x^17+1/18*b^4*d*x^18+1/19*b^4*e*x^19+1/20*f*(a+b*x^4)^5/b
+--R 
+--R
+--R   (2)
+--R        1  5   20    1  5   19    1  5   18    1  5   17   1    4   16
+--R       -- b f x   + -- b e x   + -- b d x   + -- b c x   + - a b f x
+--R       20           19           18           17           4
+--R     + 
+--R        4    4   15   2    4   14    4    4   13   1  2 3   12    6  2 3   11
+--R       -- a b e x   + - a b d x   + -- a b c x   + - a b f x   + -- a b e x
+--R       15             7             13             2             11
+--R     + 
+--R       3  2 3   10   2  2 3   9   1  3 2   8   4  3 2   7   2  3 2   6
+--R       - a b d x   + - a b c x  + - a b f x  + - a b e x  + - a b d x
+--R       5             3            2            7            3
+--R     + 
+--R       4  3 2   5   1  4     4   1  4     3   1  4     2    4         1  5
+--R       - a b c x  + - a b f x  + - a b e x  + - a b d x  + a b c x + -- a f
+--R       5            4            3            2                      20
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 715
+
+--S 716 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  4   20    1  4   19    1  4   18    1  4   17   1    3   16
+--R     -- b f x   + -- b e x   + -- b d x   + -- b c x   + - a b f x
+--R     20           19           18           17           4
+--R   + 
+--R      4    3   15   2    3   14    4    3   13   1  2 2   12    6  2 2   11
+--R     -- a b e x   + - a b d x   + -- a b c x   + - a b f x   + -- a b e x
+--R     15             7             13             2             11
+--R   + 
+--R     3  2 2   10   2  2 2   9   1  3     8   4  3     7   2  3     6
+--R     - a b d x   + - a b c x  + - a b f x  + - a b e x  + - a b d x
+--R     5             3            2            7            3
+--R   + 
+--R     4  3     5   1  4   4   1  4   3   1  4   2    4
+--R     - a b c x  + - a f x  + - a e x  + - a d x  + a c x
+--R     5            4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 716
+
+--S 717 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1  5
+--R          -- a f
+--R          20
+--R   (4)  - ------
+--R             b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 717
+
+--S 718 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 718
+
+)clear all
+
+--S 719 of 953
+t0:=(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3   15    3   14    3   13    3   12       2   11       2   10       2   9
+--R     b f x   + b e x   + b d x   + b c x   + 3a b f x   + 3a b e x   + 3a b d x
+--R   + 
+--R         2   8     2     7     2     6     2     5     2     4    3   3    3   2
+--R     3a b c x  + 3a b f x  + 3a b e x  + 3a b d x  + 3a b c x  + a f x  + a e x
+--R   + 
+--R      3       3
+--R     a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 719
+
+--S 720 of 953
+r0:=a^3*c*x+1/2*a^3*d*x^2+1/3*a^3*e*x^3+3/5*a^2*b*c*x^5+1/2*a^2*b*d*x^6+_
+   3/7*a^2*b*e*x^7+1/3*a*b^2*c*x^9+3/10*a*b^2*d*x^10+3/11*a*b^2*e*x^11+_
+   1/13*b^3*c*x^13+1/14*b^3*d*x^14+1/15*b^3*e*x^15+1/16*f*(a+b*x^4)^4/b
+--R 
+--R
+--R   (2)
+--R        1  4   16    1  4   15    1  4   14    1  4   13   1    3   12
+--R       -- b f x   + -- b e x   + -- b d x   + -- b c x   + - a b f x
+--R       16           15           14           13           4
+--R     + 
+--R        3    3   11    3    3   10   1    3   9   3  2 2   8   3  2 2   7
+--R       -- a b e x   + -- a b d x   + - a b c x  + - a b f x  + - a b e x
+--R       11             10             3            8            7
+--R     + 
+--R       1  2 2   6   3  2 2   5   1  3     4   1  3     3   1  3     2    3
+--R       - a b d x  + - a b c x  + - a b f x  + - a b e x  + - a b d x  + a b c x
+--R       2            5            4            3            2
+--R     + 
+--R        1  4
+--R       -- a f
+--R       16
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 720
+
+--S 721 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3   16    1  3   15    1  3   14    1  3   13   1    2   12
+--R     -- b f x   + -- b e x   + -- b d x   + -- b c x   + - a b f x
+--R     16           15           14           13           4
+--R   + 
+--R      3    2   11    3    2   10   1    2   9   3  2     8   3  2     7
+--R     -- a b e x   + -- a b d x   + - a b c x  + - a b f x  + - a b e x
+--R     11             10             3            8            7
+--R   + 
+--R     1  2     6   3  2     5   1  3   4   1  3   3   1  3   2    3
+--R     - a b d x  + - a b c x  + - a f x  + - a e x  + - a d x  + a c x
+--R     2            5            4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 721
+
+--S 722 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1  4
+--R          -- a f
+--R          16
+--R   (4)  - ------
+--R             b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 722
+
+--S 723 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 723
+
+)clear all
+
+--S 724 of 953
+t0:=(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^2
+--R 
+--R
+--R   (1)
+--R      2   11    2   10    2   9    2   8           7           6           5
+--R     b f x   + b e x   + b d x  + b c x  + 2a b f x  + 2a b e x  + 2a b d x
+--R   + 
+--R             4    2   3    2   2    2       2
+--R     2a b c x  + a f x  + a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 724
+
+--S 725 of 953
+r0:=a^2*c*x+1/2*a^2*d*x^2+1/3*a^2*e*x^3+2/5*a*b*c*x^5+1/3*a*b*d*x^6+_
+   2/7*a*b*e*x^7+1/9*b^2*c*x^9+1/10*b^2*d*x^10+1/11*b^2*e*x^11+_
+   1/12*f*(a+b*x^4)^3/b
+--R 
+--R
+--R   (2)
+--R        1  3   12    1  3   11    1  3   10   1  3   9   1    2   8   2    2   7
+--R       -- b f x   + -- b e x   + -- b d x   + - b c x  + - a b f x  + - a b e x
+--R       12           11           10           9          4            7
+--R     + 
+--R       1    2   6   2    2   5   1  2     4   1  2     3   1  2     2    2
+--R       - a b d x  + - a b c x  + - a b f x  + - a b e x  + - a b d x  + a b c x
+--R       3            5            4            3            2
+--R     + 
+--R        1  3
+--R       -- a f
+--R       12
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 725
+
+--S 726 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  2   12    1  2   11    1  2   10   1  2   9   1        8   2        7
+--R     -- b f x   + -- b e x   + -- b d x   + - b c x  + - a b f x  + - a b e x
+--R     12           11           10           9          4            7
+--R   + 
+--R     1        6   2        5   1  2   4   1  2   3   1  2   2    2
+--R     - a b d x  + - a b c x  + - a f x  + - a e x  + - a d x  + a c x
+--R     3            5            4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 726
+
+--S 727 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1  3
+--R          -- a f
+--R          12
+--R   (4)  - ------
+--R             b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 727
+
+--S 728 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 728
+
+)clear all
+
+--S 729 of 953
+t0:=(c+d*x+e*x^2+f*x^3)*(a+b*x^4)
+--R 
+--R
+--R             7        6        5        4        3        2
+--R   (1)  b f x  + b e x  + b d x  + b c x  + a f x  + a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 729
+
+--S 730 of 953
+r0:=a*c*x+1/2*a*d*x^2+1/3*a*e*x^3+1/4*a*f*x^4+1/5*b*c*x^5+1/6*b*d*x^6+_
+   1/7*b*e*x^7+1/8*b*f*x^8
+--R 
+--R
+--R   (2)
+--R     1      8   1      7   1      6   1      5   1      4   1      3   1      2
+--R     - b f x  + - b e x  + - b d x  + - b c x  + - a f x  + - a e x  + - a d x
+--R     8          7          6          5          4          3          2
+--R   + 
+--R     a c x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 730
+
+--S 731 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     1      8   1      7   1      6   1      5   1      4   1      3   1      2
+--R     - b f x  + - b e x  + - b d x  + - b c x  + - a f x  + - a e x  + - a d x
+--R     8          7          6          5          4          3          2
+--R   + 
+--R     a c x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 731
+
+--S 732 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 732
+
+--S 733 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 733
+
+)clear all
+
+--S 734 of 953
+t0:=(c+d*x+e*x^2+f*x^3)/(a+b*x^4)
+--R 
+--R
+--R           3      2
+--R        f x  + e x  + d x + c
+--R   (1)  ---------------------
+--R                  4
+--R               b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 734
+
+--S 735 of 953
+r0:=1/4*f*log(a+b*x^4)/b+1/2*d*atan(x^2*sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b))-_
+   1/4*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-e*sqrt(a)+_
+   c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))+1/4*log(a^(1/4)*b^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(b))*(-e*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))-_
+   1/2*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(e*sqrt(a)+c*sqrt(b))/(a^(3/4)*_
+   b^(3/4)*sqrt(2))+1/2*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(e*sqrt(a)+c*_
+   sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                +-+    2  +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- a b e\|b  + b c\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R              +-+    2  +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (a b e\|b  - b c\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+     2  +-+      x\|2 \|b  + \|a
+--R       (2a b e\|b  + 2b c\|a )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+     2  +-+      x\|2 \|b  - \|a
+--R       (2a b e\|b  + 2b c\|a )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                2 +-+
+--R            +-+4+-+3 4+-+3     x \|b      +-+       4      +-+4+-+3 +-+4+-+3
+--R       2b d\|2 \|a   \|b  atan(------ + f\|2 log(b x  + a)\|a \|a  \|b \|b
+--R                                 +-+
+--R                                \|a
+--R  /
+--R        +-+ +-+4+-+3 +-+4+-+3
+--R     4b\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 735
+
+--S 736 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             b
+--R          *
+--R             ROOT
+--R                          2     2          2                           2     2
+--R                    - 6a b %%DJ1  + (- 4a b %%DJ0 + 4a b f)%%DJ1 - 6a b %%DJ0
+--R                  + 
+--R                                      2               2
+--R                    4a b f %%DJ0 - a f  - 2b c e - b d
+--R               /
+--R                      2
+--R                  2a b
+--R         + 
+--R           - b %%DJ1 - b %%DJ0 + f
+--R      *
+--R         log
+--R                          4 3 3      3 4 2       3 4   2
+--R                      (32a b e  - 32a b c e + 64a b c d )%%DJ0
+--R                    + 
+--R                           4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                    + 
+--R                         3 3 3      2 4 3
+--R                      16a b d e - 8a b c d
+--R                 *
+--R                    %%DJ1
+--R                + 
+--R                           4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                    + 
+--R                         3 3 3      2 4 3
+--R                      16a b d e - 8a b c d
+--R                 *
+--R                    %%DJ0
+--R                + 
+--R                     4   3     3 2 2      3 2   2  2
+--R                  (2a b e  - 2a b c e + 4a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e + 4a b c d)f - 2a b c e  + 2a b d e
+--R                + 
+--R                    2 3 2 2      2 3   4       4 5
+--R                  6a b c d e - 4a b c d  + 2a b c
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DJ1  + (- 4a b %%DJ0 + 4a b f)%%DJ1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DJ0  + 4a b f %%DJ0 - a f  - 2b c e - b d
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2
+--R                  (32a b e  - 32a b c e + 64a b c d )%%DJ0
+--R                + 
+--R                       4 2 3     3 3 2       3 3   2        3 3     2
+--R                  (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                + 
+--R                     3 3 3      2 4 3
+--R                  16a b d e - 8a b c d
+--R             *
+--R                     2
+--R                %%DJ1
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2      2
+--R                  (32a b e  - 32a b c e + 64a b c d )%%DJ0
+--R                + 
+--R                        4 2 3      3 3 2       3 3   2
+--R                  (- 32a b e  + 32a b c e - 64a b c d )f %%DJ0
+--R                + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  - 6a b c e + 12a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e + 4a b c d)f + 2a b c e  - 2a b d e
+--R                + 
+--R                      2 3 2 2      2 3   4       4 5
+--R                  - 6a b c d e + 4a b c d  - 2a b c
+--R             *
+--R                %%DJ1
+--R            + 
+--R                       4 2 3     3 3 2       3 3   2        3 3     2
+--R                  (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                + 
+--R                     3 3 3      2 4 3
+--R                  16a b d e - 8a b c d
+--R             *
+--R                     2
+--R                %%DJ0
+--R            + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  - 6a b c e + 12a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e + 4a b c d)f + 2a b c e  - 2a b d e
+--R                + 
+--R                      2 3 2 2      2 3   4       4 5
+--R                  - 6a b c d e + 4a b c d  - 2a b c
+--R             *
+--R                %%DJ0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3        2 2 4      3 4  2
+--R                  a b e  - a b c e  + 8a b c d e  + (- 4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  + b c
+--R             *
+--R                x
+--R            + 
+--R                  4 3    3   2      3     2  3
+--R              (- a e  + a b c e - 2a b c d )f
+--R            + 
+--R                   3       2     3   3     2 2 3   2
+--R              (- 3a b c d e  + 2a b d e - a b c d)f
+--R            + 
+--R                  3     4    3   2 3     2 2 2 2      2 2   4      3 5
+--R              (- a b c e  + a b d e  + 3a b c d e - 2a b c d  + a b c )f
+--R            + 
+--R                 3     5     2 2 2   3    2 2   3 2      2 2 5       3 4
+--R              - a b d e  - 4a b c d e  - a b c d e  + (2a b d  - 3a b c d)e
+--R            + 
+--R                 3 3 3
+--R              a b c d
+--R     + 
+--R           -
+--R                b
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DJ1  + (- 4a b %%DJ0 + 4a b f)%%DJ1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DJ0  + 4a b f %%DJ0 - a f  - 2b c e - b d
+--R                  /
+--R                         2
+--R                     2a b
+--R         + 
+--R           - b %%DJ1 - b %%DJ0 + f
+--R      *
+--R         log
+--R                            4 3 3      3 4 2       3 4   2
+--R                      (- 32a b e  + 32a b c e - 64a b c d )%%DJ0
+--R                    + 
+--R                         4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (8a b e  - 8a b c e + 16a b c d )f + 24a b c d e
+--R                    + 
+--R                           3 3 3      2 4 3
+--R                      - 16a b d e + 8a b c d
+--R                 *
+--R                    %%DJ1
+--R                + 
+--R                         4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (8a b e  - 8a b c e + 16a b c d )f + 24a b c d e
+--R                    + 
+--R                           3 3 3      2 4 3
+--R                      - 16a b d e + 8a b c d
+--R                 *
+--R                    %%DJ0
+--R                + 
+--R                       4   3     3 2 2      3 2   2  2
+--R                  (- 2a b e  + 2a b c e - 4a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e - 4a b c d)f + 2a b c e
+--R                + 
+--R                      3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  - 2a b d e  - 6a b c d e + 4a b c d  - 2a b c
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DJ1  + (- 4a b %%DJ0 + 4a b f)%%DJ1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DJ0  + 4a b f %%DJ0 - a f  - 2b c e - b d
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2
+--R                  (32a b e  - 32a b c e + 64a b c d )%%DJ0
+--R                + 
+--R                       4 2 3     3 3 2       3 3   2        3 3     2
+--R                  (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                + 
+--R                     3 3 3      2 4 3
+--R                  16a b d e - 8a b c d
+--R             *
+--R                     2
+--R                %%DJ1
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2      2
+--R                  (32a b e  - 32a b c e + 64a b c d )%%DJ0
+--R                + 
+--R                        4 2 3      3 3 2       3 3   2
+--R                  (- 32a b e  + 32a b c e - 64a b c d )f %%DJ0
+--R                + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  - 6a b c e + 12a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e + 4a b c d)f + 2a b c e  - 2a b d e
+--R                + 
+--R                      2 3 2 2      2 3   4       4 5
+--R                  - 6a b c d e + 4a b c d  - 2a b c
+--R             *
+--R                %%DJ1
+--R            + 
+--R                       4 2 3     3 3 2       3 3   2        3 3     2
+--R                  (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                + 
+--R                     3 3 3      2 4 3
+--R                  16a b d e - 8a b c d
+--R             *
+--R                     2
+--R                %%DJ0
+--R            + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  - 6a b c e + 12a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e + 4a b c d)f + 2a b c e  - 2a b d e
+--R                + 
+--R                      2 3 2 2      2 3   4       4 5
+--R                  - 6a b c d e + 4a b c d  - 2a b c
+--R             *
+--R                %%DJ0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3        2 2 4      3 4  2
+--R                  a b e  - a b c e  + 8a b c d e  + (- 4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  + b c
+--R             *
+--R                x
+--R            + 
+--R                  4 3    3   2      3     2  3
+--R              (- a e  + a b c e - 2a b c d )f
+--R            + 
+--R                   3       2     3   3     2 2 3   2
+--R              (- 3a b c d e  + 2a b d e - a b c d)f
+--R            + 
+--R                  3     4    3   2 3     2 2 2 2      2 2   4      3 5
+--R              (- a b c e  + a b d e  + 3a b c d e - 2a b c d  + a b c )f
+--R            + 
+--R                 3     5     2 2 2   3    2 2   3 2      2 2 5       3 4
+--R              - a b d e  - 4a b c d e  - a b c d e  + (2a b d  - 3a b c d)e
+--R            + 
+--R                 3 3 3
+--R              a b c d
+--R     + 
+--R         2b %%DJ1
+--R      *
+--R         log
+--R                        4 3 3      3 4 2        3 4   2
+--R                  (- 64a b e  + 64a b c e - 128a b c d )%%DJ0
+--R                + 
+--R                      4 2 3      3 3 2       3 3   2        3 3     2
+--R                  (16a b e  - 16a b c e + 32a b c d )f + 48a b c d e
+--R                + 
+--R                       3 3 3       2 4 3
+--R                  - 32a b d e + 16a b c d
+--R             *
+--R                     2
+--R                %%DJ1
+--R            + 
+--R                        4 3 3      3 4 2        3 4   2      2
+--R                  (- 64a b e  + 64a b c e - 128a b c d )%%DJ0
+--R                + 
+--R                      4 2 3      3 3 2        3 3   2
+--R                  (64a b e  - 64a b c e + 128a b c d )f %%DJ0
+--R                + 
+--R                        4   3      3 2 2       3 2   2  2
+--R                  (- 12a b e  + 12a b c e - 24a b c d )f
+--R                + 
+--R                        3 2     2      3 2 3      2 3 3        3 2   4
+--R                  (- 24a b c d e  + 16a b d e - 8a b c d)f - 4a b c e
+--R                + 
+--R                    3 2 2 3      2 3 2 2      2 3   4       4 5
+--R                  4a b d e  + 12a b c d e - 8a b c d  + 4a b c
+--R             *
+--R                %%DJ1
+--R            + 
+--R                    4 3 3      3 4 2        3 4   2      3
+--R              (- 64a b e  + 64a b c e - 128a b c d )%%DJ0
+--R            + 
+--R                  4 2 3      3 3 2        3 3   2        2
+--R              (64a b e  - 64a b c e + 128a b c d )f %%DJ0
+--R            + 
+--R                        4   3      3 2 2       3 2   2  2      3 2   4
+--R                  (- 24a b e  + 24a b c e - 48a b c d )f  - 16a b c e
+--R                + 
+--R                      3 2 2 3      2 3 3 2      2 3 2 2       2 3   4
+--R                  - 8a b d e  + 16a b c e  - 24a b c d e - 16a b c d
+--R             *
+--R                %%DJ0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3        2 2 4      3 4  2
+--R                  a b e  - a b c e  + 8a b c d e  + (- 4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  + b c
+--R             *
+--R                x
+--R            + 
+--R                 4 3     3   2      3     2  3
+--R              (3a e  - 3a b c e + 6a b c d )f
+--R            + 
+--R                 3       2     3   3     2 2 3   2
+--R              (3a b c d e  - 2a b d e + a b c d)f
+--R            + 
+--R                    3     4    3   2 3     2 2 3 2     2 2 2 2      2 2   4
+--R                  5a b c e  + a b d e  - 4a b c e  + 3a b c d e + 6a b c d
+--R                + 
+--R                       3 5
+--R                  - a b c
+--R             *
+--R                f
+--R            + 
+--R                 3     5     2 2 2   3     2 2   3 2        2 2 5      3 4
+--R              - a b d e  + 8a b c d e  - 3a b c d e  + (- 2a b d  + a b c d)e
+--R            + 
+--R                  3 3 3
+--R              3a b c d
+--R     + 
+--R         2b %%DJ0
+--R      *
+--R         log
+--R                  4 3 3      3 4 2        3 4   2      3
+--R              (64a b e  - 64a b c e + 128a b c d )%%DJ0
+--R            + 
+--R                        4 2 3      3 3 2       3 3   2        3 3     2
+--R                  (- 48a b e  + 48a b c e - 96a b c d )f + 48a b c d e
+--R                + 
+--R                       3 3 3       2 4 3
+--R                  - 32a b d e + 16a b c d
+--R             *
+--R                     2
+--R                %%DJ0
+--R            + 
+--R                      4   3      3 2 2       3 2   2  2
+--R                  (12a b e  - 12a b c e + 24a b c d )f
+--R                + 
+--R                        3 2     2      3 2 3      2 3 3         3 2   4
+--R                  (- 24a b c d e  + 16a b d e - 8a b c d)f + 12a b c e
+--R                + 
+--R                     3 2 2 3      2 3 3 2      2 3 2 2      2 3   4       4 5
+--R                  12a b d e  - 16a b c e  + 36a b c d e + 8a b c d  + 4a b c
+--R             *
+--R                %%DJ0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3        2 2 4      3 4  2
+--R                  a b e  - a b c e  + 8a b c d e  + (- 4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  + b c
+--R             *
+--R                x
+--R            + 
+--R                  4 3    3   2      3     2  3
+--R              (- a e  + a b c e - 2a b c d )f
+--R            + 
+--R                 3       2     3   3     2 2 3   2
+--R              (3a b c d e  - 2a b d e + a b c d)f
+--R            + 
+--R                      3     4     3   2 3     2 2 3 2     2 2 2 2      2 2   4
+--R                  - 3a b c e  - 3a b d e  + 4a b c e  - 9a b c d e - 2a b c d
+--R                + 
+--R                       3 5
+--R                  - a b c
+--R             *
+--R                f
+--R            + 
+--R                3     5     2 2   3 2        2 2 5       3 4          3 3 3
+--R              3a b d e  + 5a b c d e  + (- 2a b d  + 5a b c d)e - 5a b c d
+--R  /
+--R     2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 736
+
+--S 737 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+ +-+4+-+3 +-+4+-+3
+--R             2b\|2 \|a \|a  \|b \|b
+--R          *
+--R             ROOT
+--R                          2     2          2                           2     2
+--R                    - 6a b %%DJ1  + (- 4a b %%DJ0 + 4a b f)%%DJ1 - 6a b %%DJ0
+--R                  + 
+--R                                      2               2
+--R                    4a b f %%DJ0 - a f  - 2b c e - b d
+--R               /
+--R                      2
+--R                  2a b
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 2b\|2 \|a \|a  \|b \|b  %%DJ1 - 2b\|2 \|a \|a  \|b \|b  %%DJ0
+--R         + 
+--R              +-+ +-+4+-+3 +-+4+-+3
+--R           2f\|2 \|a \|a  \|b \|b
+--R      *
+--R         log
+--R                          4 3 3      3 4 2       3 4   2
+--R                      (32a b e  - 32a b c e + 64a b c d )%%DJ0
+--R                    + 
+--R                           4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                    + 
+--R                         3 3 3      2 4 3
+--R                      16a b d e - 8a b c d
+--R                 *
+--R                    %%DJ1
+--R                + 
+--R                           4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                    + 
+--R                         3 3 3      2 4 3
+--R                      16a b d e - 8a b c d
+--R                 *
+--R                    %%DJ0
+--R                + 
+--R                     4   3     3 2 2      3 2   2  2
+--R                  (2a b e  - 2a b c e + 4a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e + 4a b c d)f - 2a b c e  + 2a b d e
+--R                + 
+--R                    2 3 2 2      2 3   4       4 5
+--R                  6a b c d e - 4a b c d  + 2a b c
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DJ1  + (- 4a b %%DJ0 + 4a b f)%%DJ1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DJ0  + 4a b f %%DJ0 - a f  - 2b c e - b d
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2
+--R                  (32a b e  - 32a b c e + 64a b c d )%%DJ0
+--R                + 
+--R                       4 2 3     3 3 2       3 3   2        3 3     2
+--R                  (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                + 
+--R                     3 3 3      2 4 3
+--R                  16a b d e - 8a b c d
+--R             *
+--R                     2
+--R                %%DJ1
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2      2
+--R                  (32a b e  - 32a b c e + 64a b c d )%%DJ0
+--R                + 
+--R                        4 2 3      3 3 2       3 3   2
+--R                  (- 32a b e  + 32a b c e - 64a b c d )f %%DJ0
+--R                + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  - 6a b c e + 12a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e + 4a b c d)f + 2a b c e  - 2a b d e
+--R                + 
+--R                      2 3 2 2      2 3   4       4 5
+--R                  - 6a b c d e + 4a b c d  - 2a b c
+--R             *
+--R                %%DJ1
+--R            + 
+--R                       4 2 3     3 3 2       3 3   2        3 3     2
+--R                  (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                + 
+--R                     3 3 3      2 4 3
+--R                  16a b d e - 8a b c d
+--R             *
+--R                     2
+--R                %%DJ0
+--R            + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  - 6a b c e + 12a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e + 4a b c d)f + 2a b c e  - 2a b d e
+--R                + 
+--R                      2 3 2 2      2 3   4       4 5
+--R                  - 6a b c d e + 4a b c d  - 2a b c
+--R             *
+--R                %%DJ0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3        2 2 4      3 4  2
+--R                  a b e  - a b c e  + 8a b c d e  + (- 4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  + b c
+--R             *
+--R                x
+--R            + 
+--R                  4 3    3   2      3     2  3
+--R              (- a e  + a b c e - 2a b c d )f
+--R            + 
+--R                   3       2     3   3     2 2 3   2
+--R              (- 3a b c d e  + 2a b d e - a b c d)f
+--R            + 
+--R                  3     4    3   2 3     2 2 2 2      2 2   4      3 5
+--R              (- a b c e  + a b d e  + 3a b c d e - 2a b c d  + a b c )f
+--R            + 
+--R                 3     5     2 2 2   3    2 2   3 2      2 2 5       3 4
+--R              - a b d e  - 4a b c d e  - a b c d e  + (2a b d  - 3a b c d)e
+--R            + 
+--R                 3 3 3
+--R              a b c d
+--R     + 
+--R           -
+--R                   +-+ +-+4+-+3 +-+4+-+3
+--R                2b\|2 \|a \|a  \|b \|b
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DJ1  + (- 4a b %%DJ0 + 4a b f)%%DJ1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DJ0  + 4a b f %%DJ0 - a f  - 2b c e - b d
+--R                  /
+--R                         2
+--R                     2a b
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 2b\|2 \|a \|a  \|b \|b  %%DJ1 - 2b\|2 \|a \|a  \|b \|b  %%DJ0
+--R         + 
+--R              +-+ +-+4+-+3 +-+4+-+3
+--R           2f\|2 \|a \|a  \|b \|b
+--R      *
+--R         log
+--R                            4 3 3      3 4 2       3 4   2
+--R                      (- 32a b e  + 32a b c e - 64a b c d )%%DJ0
+--R                    + 
+--R                         4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (8a b e  - 8a b c e + 16a b c d )f + 24a b c d e
+--R                    + 
+--R                           3 3 3      2 4 3
+--R                      - 16a b d e + 8a b c d
+--R                 *
+--R                    %%DJ1
+--R                + 
+--R                         4 2 3     3 3 2       3 3   2        3 3     2
+--R                      (8a b e  - 8a b c e + 16a b c d )f + 24a b c d e
+--R                    + 
+--R                           3 3 3      2 4 3
+--R                      - 16a b d e + 8a b c d
+--R                 *
+--R                    %%DJ0
+--R                + 
+--R                       4   3     3 2 2      3 2   2  2
+--R                  (- 2a b e  + 2a b c e - 4a b c d )f
+--R                + 
+--R                        3 2     2     3 2 3      2 3 3        3 2   4
+--R                  (- 12a b c d e  + 8a b d e - 4a b c d)f + 2a b c e
+--R                + 
+--R                      3 2 2 3     2 3 2 2      2 3   4       4 5
+--R                  - 2a b d e  - 6a b c d e + 4a b c d  - 2a b c
+--R             *
+--R                ROOT
+--R                             2     2          2
+--R                       - 6a b %%DJ1  + (- 4a b %%DJ0 + 4a b f)%%DJ1
+--R                     + 
+--R                             2     2                     2               2
+--R                       - 6a b %%DJ0  + 4a b f %%DJ0 - a f  - 2b c e - b d
+--R                  /
+--R                         2
+--R                     2a b
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2
+--R                  (32a b e  - 32a b c e + 64a b c d )%%DJ0
+--R                + 
+--R                       4 2 3     3 3 2       3 3   2        3 3     2
+--R                  (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                + 
+--R                     3 3 3      2 4 3
+--R                  16a b d e - 8a b c d
+--R             *
+--R                     2
+--R                %%DJ1
+--R            + 
+--R                      4 3 3      3 4 2       3 4   2      2
+--R                  (32a b e  - 32a b c e + 64a b c d )%%DJ0
+--R                + 
+--R                        4 2 3      3 3 2       3 3   2
+--R                  (- 32a b e  + 32a b c e - 64a b c d )f %%DJ0
+--R                + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  - 6a b c e + 12a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e + 4a b c d)f + 2a b c e  - 2a b d e
+--R                + 
+--R                      2 3 2 2      2 3   4       4 5
+--R                  - 6a b c d e + 4a b c d  - 2a b c
+--R             *
+--R                %%DJ1
+--R            + 
+--R                       4 2 3     3 3 2       3 3   2        3 3     2
+--R                  (- 8a b e  + 8a b c e - 16a b c d )f - 24a b c d e
+--R                + 
+--R                     3 3 3      2 4 3
+--R                  16a b d e - 8a b c d
+--R             *
+--R                     2
+--R                %%DJ0
+--R            + 
+--R                     4   3     3 2 2       3 2   2  2
+--R                  (6a b e  - 6a b c e + 12a b c d )f
+--R                + 
+--R                      3 2     2     3 2 3      2 3 3        3 2   4     3 2 2 3
+--R                  (12a b c d e  - 8a b d e + 4a b c d)f + 2a b c e  - 2a b d e
+--R                + 
+--R                      2 3 2 2      2 3   4       4 5
+--R                  - 6a b c d e + 4a b c d  - 2a b c
+--R             *
+--R                %%DJ0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3        2 2 4      3 4  2
+--R                  a b e  - a b c e  + 8a b c d e  + (- 4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  + b c
+--R             *
+--R                x
+--R            + 
+--R                  4 3    3   2      3     2  3
+--R              (- a e  + a b c e - 2a b c d )f
+--R            + 
+--R                   3       2     3   3     2 2 3   2
+--R              (- 3a b c d e  + 2a b d e - a b c d)f
+--R            + 
+--R                  3     4    3   2 3     2 2 2 2      2 2   4      3 5
+--R              (- a b c e  + a b d e  + 3a b c d e - 2a b c d  + a b c )f
+--R            + 
+--R                 3     5     2 2 2   3    2 2   3 2      2 2 5       3 4
+--R              - a b d e  - 4a b c d e  - a b c d e  + (2a b d  - 3a b c d)e
+--R            + 
+--R                 3 3 3
+--R              a b c d
+--R     + 
+--R            +-+ +-+4+-+3 +-+4+-+3
+--R         4b\|2 \|a \|a  \|b \|b  %%DJ1
+--R      *
+--R         log
+--R                        4 3 3      3 4 2        3 4   2
+--R                  (- 64a b e  + 64a b c e - 128a b c d )%%DJ0
+--R                + 
+--R                      4 2 3      3 3 2       3 3   2        3 3     2
+--R                  (16a b e  - 16a b c e + 32a b c d )f + 48a b c d e
+--R                + 
+--R                       3 3 3       2 4 3
+--R                  - 32a b d e + 16a b c d
+--R             *
+--R                     2
+--R                %%DJ1
+--R            + 
+--R                        4 3 3      3 4 2        3 4   2      2
+--R                  (- 64a b e  + 64a b c e - 128a b c d )%%DJ0
+--R                + 
+--R                      4 2 3      3 3 2        3 3   2
+--R                  (64a b e  - 64a b c e + 128a b c d )f %%DJ0
+--R                + 
+--R                        4   3      3 2 2       3 2   2  2
+--R                  (- 12a b e  + 12a b c e - 24a b c d )f
+--R                + 
+--R                        3 2     2      3 2 3      2 3 3        3 2   4
+--R                  (- 24a b c d e  + 16a b d e - 8a b c d)f - 4a b c e
+--R                + 
+--R                    3 2 2 3      2 3 2 2      2 3   4       4 5
+--R                  4a b d e  + 12a b c d e - 8a b c d  + 4a b c
+--R             *
+--R                %%DJ1
+--R            + 
+--R                    4 3 3      3 4 2        3 4   2      3
+--R              (- 64a b e  + 64a b c e - 128a b c d )%%DJ0
+--R            + 
+--R                  4 2 3      3 3 2        3 3   2        2
+--R              (64a b e  - 64a b c e + 128a b c d )f %%DJ0
+--R            + 
+--R                        4   3      3 2 2       3 2   2  2      3 2   4
+--R                  (- 24a b e  + 24a b c e - 48a b c d )f  - 16a b c e
+--R                + 
+--R                      3 2 2 3      2 3 3 2      2 3 2 2       2 3   4
+--R                  - 8a b d e  + 16a b c e  - 24a b c d e - 16a b c d
+--R             *
+--R                %%DJ0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3        2 2 4      3 4  2
+--R                  a b e  - a b c e  + 8a b c d e  + (- 4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  + b c
+--R             *
+--R                x
+--R            + 
+--R                 4 3     3   2      3     2  3
+--R              (3a e  - 3a b c e + 6a b c d )f
+--R            + 
+--R                 3       2     3   3     2 2 3   2
+--R              (3a b c d e  - 2a b d e + a b c d)f
+--R            + 
+--R                    3     4    3   2 3     2 2 3 2     2 2 2 2      2 2   4
+--R                  5a b c e  + a b d e  - 4a b c e  + 3a b c d e + 6a b c d
+--R                + 
+--R                       3 5
+--R                  - a b c
+--R             *
+--R                f
+--R            + 
+--R                 3     5     2 2 2   3     2 2   3 2        2 2 5      3 4
+--R              - a b d e  + 8a b c d e  - 3a b c d e  + (- 2a b d  + a b c d)e
+--R            + 
+--R                  3 3 3
+--R              3a b c d
+--R     + 
+--R            +-+ +-+4+-+3 +-+4+-+3
+--R         4b\|2 \|a \|a  \|b \|b  %%DJ0
+--R      *
+--R         log
+--R                  4 3 3      3 4 2        3 4   2      3
+--R              (64a b e  - 64a b c e + 128a b c d )%%DJ0
+--R            + 
+--R                        4 2 3      3 3 2       3 3   2        3 3     2
+--R                  (- 48a b e  + 48a b c e - 96a b c d )f + 48a b c d e
+--R                + 
+--R                       3 3 3       2 4 3
+--R                  - 32a b d e + 16a b c d
+--R             *
+--R                     2
+--R                %%DJ0
+--R            + 
+--R                      4   3      3 2 2       3 2   2  2
+--R                  (12a b e  - 12a b c e + 24a b c d )f
+--R                + 
+--R                        3 2     2      3 2 3      2 3 3         3 2   4
+--R                  (- 24a b c d e  + 16a b d e - 8a b c d)f + 12a b c e
+--R                + 
+--R                     3 2 2 3      2 3 3 2      2 3 2 2      2 3   4       4 5
+--R                  12a b d e  - 16a b c e  + 36a b c d e + 8a b c d  + 4a b c
+--R             *
+--R                %%DJ0
+--R            + 
+--R                   3   6    2 2 2 4     2 2   2 3        2 2 4      3 4  2
+--R                  a b e  - a b c e  + 8a b c d e  + (- 4a b d  - a b c )e
+--R                + 
+--R                      3 3 2        3 2 4    4 6
+--R                  8a b c d e - 4a b c d  + b c
+--R             *
+--R                x
+--R            + 
+--R                  4 3    3   2      3     2  3
+--R              (- a e  + a b c e - 2a b c d )f
+--R            + 
+--R                 3       2     3   3     2 2 3   2
+--R              (3a b c d e  - 2a b d e + a b c d)f
+--R            + 
+--R                      3     4     3   2 3     2 2 3 2     2 2 2 2      2 2   4
+--R                  - 3a b c e  - 3a b d e  + 4a b c e  - 9a b c d e - 2a b c d
+--R                + 
+--R                       3 5
+--R                  - a b c
+--R             *
+--R                f
+--R            + 
+--R                3     5     2 2   3 2        2 2 5       3 4          3 3 3
+--R              3a b d e  + 5a b c d e  + (- 2a b d  + 5a b c d)e - 5a b c d
+--R     + 
+--R              +-+    2  +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (a b e\|b  - b c\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                +-+    2  +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- a b e\|b  + b c\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                       +-+4+-+   4+-+
+--R                 +-+     2  +-+      x\|2 \|b  + \|a
+--R       (- 2a b e\|b  - 2b c\|a )atan(----------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                       +-+4+-+   4+-+
+--R                 +-+     2  +-+      x\|2 \|b  - \|a
+--R       (- 2a b e\|b  - 2b c\|a )atan(----------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                  2 +-+
+--R              +-+4+-+3 4+-+3     x \|b      +-+       4      +-+4+-+3 +-+4+-+3
+--R       - 2b d\|2 \|a   \|b  atan(------ - f\|2 log(b x  + a)\|a \|a  \|b \|b
+--R                                   +-+
+--R                                  \|a
+--R  /
+--R        +-+ +-+4+-+3 +-+4+-+3
+--R     4b\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4       2  +-+4+-+2        6         4        2  +-+
+--R           ((4e x  + 4c x )\|a \|a   - b c x  - 2a e x  + a c x )\|b
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2b e x  + 2b c x  + 2a e x  + 2a c)\|a
+--R         + 
+--R                   6         4        2  +-+
+--R           (- b e x  - 2b c x  + a e x )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                   4         2       4+-+2
+--R             (b c x  - 2a e x  - a c)\|a
+--R           + 
+--R                     6        4        2        +-+
+--R             (- b e x  - b c x  - a e x  - a c)\|a
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R             4         2        +-+4+-+2    2   6           4           2    2
+--R       (b e x  - 2b c x  - a e)\|a \|a   + b c x  - 3a b e x  - 3a b c x  + a e
+--R  /
+--R             6       2  +-+4+-+2 +-+      2 8         4     2 4+-+2 4+-+2
+--R       ((4b x  + 4a x )\|a \|a  \|b  + (2b x  + 4a b x  + 2a )\|a  )\|b
+--R     + 
+--R             2 6     2   2
+--R       - 4a b x  - 4a b x
+--R                                                    Type: Expression(Integer)
+--E 738
+
+)clear all
+
+--S 739 of 953
+t0:=(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^2
+--R 
+--R
+--R           3      2
+--R        f x  + e x  + d x + c
+--R   (1)  ---------------------
+--R          2 8         4    2
+--R         b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 739
+
+--S 740 of 953
+r0:=-1/4*f/(b*(a+b*x^4))+1/4*x*(c+d*x+e*x^2)/(a*(a+b*x^4))+1/4*d*_
+   atan(x^2*sqrt(b)/sqrt(a))/(a^(3/2)*sqrt(b))-1/16*log(-a^(1/4)*b^(1/4)*_
+   x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-e*sqrt(a)+3*c*sqrt(b))/(a^(7/4)*_
+   b^(3/4)*sqrt(2))+1/16*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*_
+   sqrt(b))*(-e*sqrt(a)+3*c*sqrt(b))/(a^(7/4)*b^(3/4)*sqrt(2))-_
+   1/8*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(e*sqrt(a)+3*c*sqrt(b))/_
+   (a^(7/4)*b^(3/4)*sqrt(2))+1/8*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*_
+   (e*sqrt(a)+3*c*sqrt(b))/(a^(7/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                2   4    2     +-+      3   4       2   +-+
+--R         ((- a b e x  - a b e)\|b  + (3b c x  + 3a b c)\|a )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R              2   4    2     +-+        3   4       2   +-+
+--R         ((a b e x  + a b e)\|b  + (- 3b c x  - 3a b c)\|a )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                                                 +-+4+-+   4+-+
+--R             2   4     2     +-+      3   4       2   +-+      x\|2 \|b  + \|a
+--R       ((2a b e x  + 2a b e)\|b  + (6b c x  + 6a b c)\|a )atan(----------------)
+--R                                                                     4+-+
+--R                                                                     \|a
+--R     + 
+--R                                                                 +-+4+-+   4+-+
+--R             2   4     2     +-+      3   4       2   +-+      x\|2 \|b  - \|a
+--R       ((2a b e x  + 2a b e)\|b  + (6b c x  + 6a b c)\|a )atan(----------------)
+--R                                                                     4+-+
+--R                                                                     \|a
+--R     + 
+--R                                              2 +-+
+--R          2   4           +-+4+-+3 4+-+3     x \|b
+--R       (4b d x  + 4a b d)\|2 \|a   \|b  atan(------)
+--R                                               +-+
+--R                                              \|a
+--R     + 
+--R              3         2                  +-+ +-+4+-+3 +-+4+-+3
+--R       (4b e x  + 4b d x  + 4b c x - 4a f)\|2 \|a \|a  \|b \|b
+--R  /
+--R           2 4      2   +-+ +-+4+-+3 +-+4+-+3
+--R     (16a b x  + 16a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2 4     2
+--R             (2a b x  + 2a b)
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |     3       2      3                   3       2            2
+--R              |- 48a b %%DK1  - 32a b %%DK0 %%DK1 - 48a b %%DK0  - 3c e - 2d
+--R              |--------------------------------------------------------------
+--R              |                                3
+--R             \|                             16a b
+--R         + 
+--R                  2 4     2                 2 4     2
+--R           (- 2a b x  - 2a b)%%DK1 + (- 2a b x  - 2a b)%%DK0
+--R      *
+--R         log
+--R                            7 2 3         6 3 2          6 3   2
+--R                      (2048a b e  - 18432a b c e + 49152a b c d )%%DK0
+--R                    + 
+--R                             5 2     2        5 2 3         4 3 3
+--R                      - 2304a b c d e  + 2048a b d e - 6912a b c d
+--R                 *
+--R                    %%DK1
+--R                + 
+--R                          5 2     2        5 2 3         4 3 3
+--R                  (- 2304a b c d e  + 2048a b d e - 6912a b c d)%%DK0
+--R                + 
+--R                       4     4      4   2 3       3 2 2 2        3 2   4
+--R                  - 24a b c e  + 32a b d e  + 864a b c d e - 768a b c d
+--R                + 
+--R                       2 3 5
+--R                  1944a b c
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48a b %%DK1  - 32a b %%DK0 %%DK1 - 48a b %%DK0  - 3c e - 2d
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16a b
+--R            + 
+--R                        7 2 3         6 3 2          6 3   2
+--R                  (2048a b e  - 18432a b c e + 49152a b c d )%%DK0
+--R                + 
+--R                         5 2     2        5 2 3         4 3 3
+--R                  - 2304a b c d e  + 2048a b d e - 6912a b c d
+--R             *
+--R                     2
+--R                %%DK1
+--R            + 
+--R                        7 2 3         6 3 2          6 3   2      2      4     4
+--R                  (2048a b e  - 18432a b c e + 49152a b c d )%%DK0  + 24a b c e
+--R                + 
+--R                       4   2 3       3 2 2 2        3 2   4        2 3 5
+--R                  - 32a b d e  - 864a b c d e + 768a b c d  - 1944a b c
+--R             *
+--R                %%DK1
+--R            + 
+--R                      5 2     2        5 2 3         4 3 3       2
+--R              (- 2304a b c d e  + 2048a b d e - 6912a b c d)%%DK0
+--R            + 
+--R                     4     4      4   2 3       3 2 2 2        3 2   4
+--R                  24a b c e  - 32a b d e  - 864a b c d e + 768a b c d
+--R                + 
+--R                         2 3 5
+--R                  - 1944a b c
+--R             *
+--R                %%DK0
+--R            + 
+--R                   3 6     2   2 4      2     2 3         2   4        2 4  2
+--R                  a e  - 9a b c e  + 96a b c d e  + (- 64a b d  - 81a b c )e
+--R                + 
+--R                        2 3 2          2 2 4       3 6
+--R                  864a b c d e - 576a b c d  + 729b c
+--R             *
+--R                x
+--R            + 
+--R                  3   5      2   2   3      2     3 2       2   5         2 4
+--R              - 2a d e  - 72a b c d e  - 24a b c d e  + (64a b d  - 486a b c d)e
+--R            + 
+--R                    2 3 3
+--R              216a b c d
+--R     + 
+--R                    2 4     2
+--R             (- 2a b x  - 2a b)
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |     3       2      3                   3       2            2
+--R              |- 48a b %%DK1  - 32a b %%DK0 %%DK1 - 48a b %%DK0  - 3c e - 2d
+--R              |--------------------------------------------------------------
+--R              |                                3
+--R             \|                             16a b
+--R         + 
+--R                  2 4     2                 2 4     2
+--R           (- 2a b x  - 2a b)%%DK1 + (- 2a b x  - 2a b)%%DK0
+--R      *
+--R         log
+--R                              7 2 3         6 3 2          6 3   2
+--R                      (- 2048a b e  + 18432a b c e - 49152a b c d )%%DK0
+--R                    + 
+--R                           5 2     2        5 2 3         4 3 3
+--R                      2304a b c d e  - 2048a b d e + 6912a b c d
+--R                 *
+--R                    %%DK1
+--R                + 
+--R                        5 2     2        5 2 3         4 3 3             4     4
+--R                  (2304a b c d e  - 2048a b d e + 6912a b c d)%%DK0 + 24a b c e
+--R                + 
+--R                       4   2 3       3 2 2 2        3 2   4        2 3 5
+--R                  - 32a b d e  - 864a b c d e + 768a b c d  - 1944a b c
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48a b %%DK1  - 32a b %%DK0 %%DK1 - 48a b %%DK0  - 3c e - 2d
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16a b
+--R            + 
+--R                        7 2 3         6 3 2          6 3   2
+--R                  (2048a b e  - 18432a b c e + 49152a b c d )%%DK0
+--R                + 
+--R                         5 2     2        5 2 3         4 3 3
+--R                  - 2304a b c d e  + 2048a b d e - 6912a b c d
+--R             *
+--R                     2
+--R                %%DK1
+--R            + 
+--R                        7 2 3         6 3 2          6 3   2      2      4     4
+--R                  (2048a b e  - 18432a b c e + 49152a b c d )%%DK0  + 24a b c e
+--R                + 
+--R                       4   2 3       3 2 2 2        3 2   4        2 3 5
+--R                  - 32a b d e  - 864a b c d e + 768a b c d  - 1944a b c
+--R             *
+--R                %%DK1
+--R            + 
+--R                      5 2     2        5 2 3         4 3 3       2
+--R              (- 2304a b c d e  + 2048a b d e - 6912a b c d)%%DK0
+--R            + 
+--R                     4     4      4   2 3       3 2 2 2        3 2   4
+--R                  24a b c e  - 32a b d e  - 864a b c d e + 768a b c d
+--R                + 
+--R                         2 3 5
+--R                  - 1944a b c
+--R             *
+--R                %%DK0
+--R            + 
+--R                   3 6     2   2 4      2     2 3         2   4        2 4  2
+--R                  a e  - 9a b c e  + 96a b c d e  + (- 64a b d  - 81a b c )e
+--R                + 
+--R                        2 3 2          2 2 4       3 6
+--R                  864a b c d e - 576a b c d  + 729b c
+--R             *
+--R                x
+--R            + 
+--R                  3   5      2   2   3      2     3 2       2   5         2 4
+--R              - 2a d e  - 72a b c d e  - 24a b c d e  + (64a b d  - 486a b c d)e
+--R            + 
+--R                    2 3 3
+--R              216a b c d
+--R     + 
+--R              2 4     2
+--R         (4a b x  + 4a b)%%DK1
+--R      *
+--R         log
+--R                          7 2 3         6 3 2          6 3   2
+--R                  (- 4096a b e  + 36864a b c e - 98304a b c d )%%DK0
+--R                + 
+--R                       5 2     2        5 2 3          4 3 3
+--R                  4608a b c d e  - 4096a b d e + 13824a b c d
+--R             *
+--R                     2
+--R                %%DK1
+--R            + 
+--R                          7 2 3         6 3 2          6 3   2      2
+--R                  (- 4096a b e  + 36864a b c e - 98304a b c d )%%DK0
+--R                + 
+--R                       4     4      4   2 3        3 2 2 2         3 2   4
+--R                  - 48a b c e  + 64a b d e  + 1728a b c d e - 1536a b c d
+--R                + 
+--R                       2 3 5
+--R                  3888a b c
+--R             *
+--R                %%DK1
+--R            + 
+--R                      7 2 3         6 3 2          6 3   2      3
+--R              (- 4096a b e  + 36864a b c e - 98304a b c d )%%DK0
+--R            + 
+--R                        4     4       4   2 3        3 2 3 2        3 2 2 2
+--R                  - 192a b c e  - 128a b d e  + 1728a b c e  - 3456a b c d e
+--R                + 
+--R                         3 2   4
+--R                  - 3072a b c d
+--R             *
+--R                %%DK0
+--R            + 
+--R                   3 6     2   2 4      2     2 3         2   4        2 4  2
+--R                  a e  - 9a b c e  + 96a b c d e  + (- 64a b d  - 81a b c )e
+--R                + 
+--R                        2 3 2          2 2 4       3 6
+--R                  864a b c d e - 576a b c d  + 729b c
+--R             *
+--R                x
+--R            + 
+--R                  3   5       2   2   3      2     3 2
+--R              - 2a d e  + 144a b c d e  - 72a b c d e
+--R            + 
+--R                    2   5         2 4            2 3 3
+--R              (- 64a b d  + 162a b c d)e + 648a b c d
+--R     + 
+--R              2 4     2
+--R         (4a b x  + 4a b)%%DK0
+--R      *
+--R         log
+--R                    7 2 3         6 3 2          6 3   2      3
+--R              (4096a b e  - 36864a b c e + 98304a b c d )%%DK0
+--R            + 
+--R                    5 2     2        5 2 3          4 3 3       2
+--R              (4608a b c d e  - 4096a b d e + 13824a b c d)%%DK0
+--R            + 
+--R                      4     4       4   2 3        3 2 3 2        3 2 2 2
+--R                  144a b c e  + 192a b d e  - 1728a b c e  + 5184a b c d e
+--R                + 
+--R                       3 2   4        2 3 5
+--R                  1536a b c d  + 3888a b c
+--R             *
+--R                %%DK0
+--R            + 
+--R                   3 6     2   2 4      2     2 3         2   4        2 4  2
+--R                  a e  - 9a b c e  + 96a b c d e  + (- 64a b d  - 81a b c )e
+--R                + 
+--R                        2 3 2          2 2 4       3 6
+--R                  864a b c d e - 576a b c d  + 729b c
+--R             *
+--R                x
+--R            + 
+--R              3   5       2     3 2         2   5         2 4             2 3 3
+--R            6a d e  + 120a b c d e  + (- 64a b d  + 810a b c d)e - 1080a b c d
+--R     + 
+--R            3        2
+--R       b e x  + b d x  + b c x - a f
+--R  /
+--R         2 4     2
+--R     4a b x  + 4a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 741
+
+--S 742 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+ +-+4+-+3 +-+4+-+3
+--R             8a\|2 \|a \|a  \|b \|b
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |     3       2      3                   3       2            2
+--R              |- 48a b %%DK1  - 32a b %%DK0 %%DK1 - 48a b %%DK0  - 3c e - 2d
+--R              |--------------------------------------------------------------
+--R              |                                3
+--R             \|                             16a b
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 8a\|2 \|a \|a  \|b \|b  %%DK1 - 8a\|2 \|a \|a  \|b \|b  %%DK0
+--R      *
+--R         log
+--R                            7 2 3         6 3 2          6 3   2
+--R                      (2048a b e  - 18432a b c e + 49152a b c d )%%DK0
+--R                    + 
+--R                             5 2     2        5 2 3         4 3 3
+--R                      - 2304a b c d e  + 2048a b d e - 6912a b c d
+--R                 *
+--R                    %%DK1
+--R                + 
+--R                          5 2     2        5 2 3         4 3 3
+--R                  (- 2304a b c d e  + 2048a b d e - 6912a b c d)%%DK0
+--R                + 
+--R                       4     4      4   2 3       3 2 2 2        3 2   4
+--R                  - 24a b c e  + 32a b d e  + 864a b c d e - 768a b c d
+--R                + 
+--R                       2 3 5
+--R                  1944a b c
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48a b %%DK1  - 32a b %%DK0 %%DK1 - 48a b %%DK0  - 3c e - 2d
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16a b
+--R            + 
+--R                        7 2 3         6 3 2          6 3   2
+--R                  (2048a b e  - 18432a b c e + 49152a b c d )%%DK0
+--R                + 
+--R                         5 2     2        5 2 3         4 3 3
+--R                  - 2304a b c d e  + 2048a b d e - 6912a b c d
+--R             *
+--R                     2
+--R                %%DK1
+--R            + 
+--R                        7 2 3         6 3 2          6 3   2      2      4     4
+--R                  (2048a b e  - 18432a b c e + 49152a b c d )%%DK0  + 24a b c e
+--R                + 
+--R                       4   2 3       3 2 2 2        3 2   4        2 3 5
+--R                  - 32a b d e  - 864a b c d e + 768a b c d  - 1944a b c
+--R             *
+--R                %%DK1
+--R            + 
+--R                      5 2     2        5 2 3         4 3 3       2
+--R              (- 2304a b c d e  + 2048a b d e - 6912a b c d)%%DK0
+--R            + 
+--R                     4     4      4   2 3       3 2 2 2        3 2   4
+--R                  24a b c e  - 32a b d e  - 864a b c d e + 768a b c d
+--R                + 
+--R                         2 3 5
+--R                  - 1944a b c
+--R             *
+--R                %%DK0
+--R            + 
+--R                   3 6     2   2 4      2     2 3         2   4        2 4  2
+--R                  a e  - 9a b c e  + 96a b c d e  + (- 64a b d  - 81a b c )e
+--R                + 
+--R                        2 3 2          2 2 4       3 6
+--R                  864a b c d e - 576a b c d  + 729b c
+--R             *
+--R                x
+--R            + 
+--R                  3   5      2   2   3      2     3 2       2   5         2 4
+--R              - 2a d e  - 72a b c d e  - 24a b c d e  + (64a b d  - 486a b c d)e
+--R            + 
+--R                    2 3 3
+--R              216a b c d
+--R     + 
+--R           -
+--R                   +-+ +-+4+-+3 +-+4+-+3
+--R                8a\|2 \|a \|a  \|b \|b
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48a b %%DK1  - 32a b %%DK0 %%DK1 - 48a b %%DK0  - 3c e - 2d
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16a b
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 8a\|2 \|a \|a  \|b \|b  %%DK1 - 8a\|2 \|a \|a  \|b \|b  %%DK0
+--R      *
+--R         log
+--R                              7 2 3         6 3 2          6 3   2
+--R                      (- 2048a b e  + 18432a b c e - 49152a b c d )%%DK0
+--R                    + 
+--R                           5 2     2        5 2 3         4 3 3
+--R                      2304a b c d e  - 2048a b d e + 6912a b c d
+--R                 *
+--R                    %%DK1
+--R                + 
+--R                        5 2     2        5 2 3         4 3 3             4     4
+--R                  (2304a b c d e  - 2048a b d e + 6912a b c d)%%DK0 + 24a b c e
+--R                + 
+--R                       4   2 3       3 2 2 2        3 2   4        2 3 5
+--R                  - 32a b d e  - 864a b c d e + 768a b c d  - 1944a b c
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |     3       2      3                   3       2            2
+--R               |- 48a b %%DK1  - 32a b %%DK0 %%DK1 - 48a b %%DK0  - 3c e - 2d
+--R               |--------------------------------------------------------------
+--R               |                                3
+--R              \|                             16a b
+--R            + 
+--R                        7 2 3         6 3 2          6 3   2
+--R                  (2048a b e  - 18432a b c e + 49152a b c d )%%DK0
+--R                + 
+--R                         5 2     2        5 2 3         4 3 3
+--R                  - 2304a b c d e  + 2048a b d e - 6912a b c d
+--R             *
+--R                     2
+--R                %%DK1
+--R            + 
+--R                        7 2 3         6 3 2          6 3   2      2      4     4
+--R                  (2048a b e  - 18432a b c e + 49152a b c d )%%DK0  + 24a b c e
+--R                + 
+--R                       4   2 3       3 2 2 2        3 2   4        2 3 5
+--R                  - 32a b d e  - 864a b c d e + 768a b c d  - 1944a b c
+--R             *
+--R                %%DK1
+--R            + 
+--R                      5 2     2        5 2 3         4 3 3       2
+--R              (- 2304a b c d e  + 2048a b d e - 6912a b c d)%%DK0
+--R            + 
+--R                     4     4      4   2 3       3 2 2 2        3 2   4
+--R                  24a b c e  - 32a b d e  - 864a b c d e + 768a b c d
+--R                + 
+--R                         2 3 5
+--R                  - 1944a b c
+--R             *
+--R                %%DK0
+--R            + 
+--R                   3 6     2   2 4      2     2 3         2   4        2 4  2
+--R                  a e  - 9a b c e  + 96a b c d e  + (- 64a b d  - 81a b c )e
+--R                + 
+--R                        2 3 2          2 2 4       3 6
+--R                  864a b c d e - 576a b c d  + 729b c
+--R             *
+--R                x
+--R            + 
+--R                  3   5      2   2   3      2     3 2       2   5         2 4
+--R              - 2a d e  - 72a b c d e  - 24a b c d e  + (64a b d  - 486a b c d)e
+--R            + 
+--R                    2 3 3
+--R              216a b c d
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+3
+--R         16a\|2 \|a \|a  \|b \|b  %%DK1
+--R      *
+--R         log
+--R                          7 2 3         6 3 2          6 3   2
+--R                  (- 4096a b e  + 36864a b c e - 98304a b c d )%%DK0
+--R                + 
+--R                       5 2     2        5 2 3          4 3 3
+--R                  4608a b c d e  - 4096a b d e + 13824a b c d
+--R             *
+--R                     2
+--R                %%DK1
+--R            + 
+--R                          7 2 3         6 3 2          6 3   2      2
+--R                  (- 4096a b e  + 36864a b c e - 98304a b c d )%%DK0
+--R                + 
+--R                       4     4      4   2 3        3 2 2 2         3 2   4
+--R                  - 48a b c e  + 64a b d e  + 1728a b c d e - 1536a b c d
+--R                + 
+--R                       2 3 5
+--R                  3888a b c
+--R             *
+--R                %%DK1
+--R            + 
+--R                      7 2 3         6 3 2          6 3   2      3
+--R              (- 4096a b e  + 36864a b c e - 98304a b c d )%%DK0
+--R            + 
+--R                        4     4       4   2 3        3 2 3 2        3 2 2 2
+--R                  - 192a b c e  - 128a b d e  + 1728a b c e  - 3456a b c d e
+--R                + 
+--R                         3 2   4
+--R                  - 3072a b c d
+--R             *
+--R                %%DK0
+--R            + 
+--R                   3 6     2   2 4      2     2 3         2   4        2 4  2
+--R                  a e  - 9a b c e  + 96a b c d e  + (- 64a b d  - 81a b c )e
+--R                + 
+--R                        2 3 2          2 2 4       3 6
+--R                  864a b c d e - 576a b c d  + 729b c
+--R             *
+--R                x
+--R            + 
+--R                  3   5       2   2   3      2     3 2
+--R              - 2a d e  + 144a b c d e  - 72a b c d e
+--R            + 
+--R                    2   5         2 4            2 3 3
+--R              (- 64a b d  + 162a b c d)e + 648a b c d
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+3
+--R         16a\|2 \|a \|a  \|b \|b  %%DK0
+--R      *
+--R         log
+--R                    7 2 3         6 3 2          6 3   2      3
+--R              (4096a b e  - 36864a b c e + 98304a b c d )%%DK0
+--R            + 
+--R                    5 2     2        5 2 3          4 3 3       2
+--R              (4608a b c d e  - 4096a b d e + 13824a b c d)%%DK0
+--R            + 
+--R                      4     4       4   2 3        3 2 3 2        3 2 2 2
+--R                  144a b c e  + 192a b d e  - 1728a b c e  + 5184a b c d e
+--R                + 
+--R                       3 2   4        2 3 5
+--R                  1536a b c d  + 3888a b c
+--R             *
+--R                %%DK0
+--R            + 
+--R                   3 6     2   2 4      2     2 3         2   4        2 4  2
+--R                  a e  - 9a b c e  + 96a b c d e  + (- 64a b d  - 81a b c )e
+--R                + 
+--R                        2 3 2          2 2 4       3 6
+--R                  864a b c d e - 576a b c d  + 729b c
+--R             *
+--R                x
+--R            + 
+--R              3   5       2     3 2         2   5         2 4             2 3 3
+--R            6a d e  + 120a b c d e  + (- 64a b d  + 810a b c d)e - 1080a b c d
+--R     + 
+--R            +-+        +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (a e\|b  - 3b c\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R              +-+        +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- a e\|b  + 3b c\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|b  + \|a
+--R       (- 2a e\|b  - 6b c\|a )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|b  - \|a
+--R       (- 2a e\|b  - 6b c\|a )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                2 +-+
+--R            +-+4+-+3 4+-+3     x \|b
+--R       - 4d\|2 \|a   \|b  atan(------)
+--R                                 +-+
+--R                                \|a
+--R  /
+--R         +-+ +-+4+-+3 +-+4+-+3
+--R     16a\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                 4        2  +-+4+-+2         6         4         2  +-+
+--R           ((4e x  + 12c x )\|a \|a   - 3b c x  - 2a e x  + 3a c x )\|b
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (2b e x  + 6b c x  + 2a e x  + 6a c)\|a
+--R         + 
+--R                   6         4        2  +-+
+--R           (- b e x  - 6b c x  + a e x )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                  4         2        4+-+2
+--R           (3b c x  - 2a e x  - 3a c)\|a
+--R         + 
+--R                   6         4        2         +-+
+--R           (- b e x  - 3b c x  - a e x  - 3a c)\|a
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R           4         2        +-+4+-+2     2   6           4           2    2
+--R     (b e x  - 6b c x  - a e)\|a \|a   + 3b c x  - 3a b e x  - 9a b c x  + a e
+--R  /
+--R                6      2 2  +-+4+-+2 +-+        2 8      2   4     3 4+-+2 4+-+2
+--R       ((16a b x  + 16a x )\|a \|a  \|b  + (8a b x  + 16a b x  + 8a )\|a  )\|b
+--R     + 
+--R            2 2 6      3   2
+--R       - 16a b x  - 16a b x
+--R                                                    Type: Expression(Integer)
+--E 743
+
+)clear all
+
+--S 744 of 953
+t0:=(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^3
+--R 
+--R
+--R                3      2
+--R             f x  + e x  + d x + c
+--R   (1)  ------------------------------
+--R         3 12       2 8     2   4    3
+--R        b x   + 3a b x  + 3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 744
+
+--S 745 of 953
+r0:=-1/8*f/(b*(a+b*x^4)^2)+1/8*x*(c+d*x+e*x^2)/(a*(a+b*x^4)^2)+1/32*x*_
+   (7*c+6*d*x+5*e*x^2)/(a^2*(a+b*x^4))+3/16*d*atan(x^2*sqrt(b)/sqrt(a))/_
+   (a^(5/2)*sqrt(b))-1/128*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+_
+   x^2*sqrt(b))*(-5*e*sqrt(a)+21*c*sqrt(b))/(a^(11/4)*b^(3/4)*sqrt(2))+_
+   1/128*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-5*e*_
+   sqrt(a)+21*c*sqrt(b))/(a^(11/4)*b^(3/4)*sqrt(2))-1/64*atan(1-b^(1/4)*_
+   x*sqrt(2)/a^(1/4))*(5*e*sqrt(a)+21*c*sqrt(b))/(a^(11/4)*b^(3/4)*_
+   sqrt(2))+1/64*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(5*e*sqrt(a)+21*c*_
+   sqrt(b))/(a^(11/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  3   8      2 2   4     3     +-+
+--R           (- 5a b e x  - 10a b e x  - 5a b e)\|b
+--R         + 
+--R               4   8        3   4      2 2   +-+
+--R           (21b c x  + 42a b c x  + 21a b c)\|a
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                3   8      2 2   4     3     +-+
+--R           (5a b e x  + 10a b e x  + 5a b e)\|b
+--R         + 
+--R                 4   8        3   4      2 2   +-+
+--R           (- 21b c x  - 42a b c x  - 21a b c)\|a
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                 3   8      2 2   4      3     +-+
+--R           (10a b e x  + 20a b e x  + 10a b e)\|b
+--R         + 
+--R               4   8        3   4      2 2   +-+
+--R           (42b c x  + 84a b c x  + 42a b c)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  + \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                 3   8      2 2   4      3     +-+
+--R           (10a b e x  + 20a b e x  + 10a b e)\|b
+--R         + 
+--R               4   8        3   4      2 2   +-+
+--R           (42b c x  + 84a b c x  + 42a b c)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  - \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                                                             2 +-+
+--R           3   8        2   4      2     +-+4+-+3 4+-+3     x \|b
+--R       (24b d x  + 48a b d x  + 24a b d)\|2 \|a   \|b  atan(------)
+--R                                                              +-+
+--R                                                             \|a
+--R     + 
+--R              2   7      2   6      2   5            3            2
+--R           20b e x  + 24b d x  + 28b c x  + 36a b e x  + 40a b d x  + 44a b c x
+--R         + 
+--R                2
+--R           - 16a f
+--R      *
+--R          +-+ +-+4+-+3 +-+4+-+3
+--R         \|2 \|a \|a  \|b \|b
+--R  /
+--R          2 3 8       3 2 4       4   +-+ +-+4+-+3 +-+4+-+3
+--R     (128a b x  + 256a b x  + 128a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 745
+
+--S 746 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 2 3 8      3 2 4      4
+--R             (16a b x  + 32a b x  + 16a b)
+--R          *
+--R             ROOT
+--R                           5       2        5                     5       2
+--R                    - 3072a b %%DL1  - 2048a b %%DL0 %%DL1 - 3072a b %%DL0
+--R                  + 
+--R                                  2
+--R                    - 105c e - 72d
+--R               /
+--R                       5
+--R                  1024a b
+--R         + 
+--R                 2 3 8      3 2 4      4
+--R           (- 16a b x  - 32a b x  - 16a b)%%DL1
+--R         + 
+--R                 2 3 8      3 2 4      4
+--R           (- 16a b x  - 32a b x  - 16a b)%%DL0
+--R      *
+--R         log
+--R                                    10 2 3              9 3 2
+--R                          131072000a  b e  - 2312110080a b c e
+--R                        + 
+--R                                     9 3   2
+--R                          6341787648a b c d
+--R                     *
+--R                        %%DL0
+--R                    + 
+--R                                7 2     2             7 2 3              6 3 3
+--R                    - 154828800a b c d e  + 141557760a b d e - 910393344a b c d
+--R                 *
+--R                    %%DL1
+--R                + 
+--R                                    7 2     2             7 2 3
+--R                        - 154828800a b c d e  + 141557760a b d e
+--R                      + 
+--R                                    6 3 3
+--R                        - 910393344a b c d
+--R                 *
+--R                    %%DL0
+--R                + 
+--R                           5     4           5   2 3            4 2 2 2
+--R                  - 840000a b c e  + 1152000a b d e  + 60963840a b c d e
+--R                + 
+--R                             4 2   4             3 3 5
+--R                  - 55738368a b c d  + 261382464a b c
+--R             *
+--R                ROOT
+--R                              5       2        5                     5       2
+--R                       - 3072a b %%DL1  - 2048a b %%DL0 %%DL1 - 3072a b %%DL0
+--R                     + 
+--R                                     2
+--R                       - 105c e - 72d
+--R                  /
+--R                          5
+--R                     1024a b
+--R            + 
+--R                               10 2 3              9 3 2               9 3   2
+--R                    (131072000a  b e  - 2312110080a b c e + 6341787648a b c d )
+--R                 *
+--R                    %%DL0
+--R                + 
+--R                              7 2     2             7 2 3              6 3 3
+--R                  - 154828800a b c d e  + 141557760a b d e - 910393344a b c d
+--R             *
+--R                     2
+--R                %%DL1
+--R            + 
+--R                               10 2 3              9 3 2               9 3   2
+--R                    (131072000a  b e  - 2312110080a b c e + 6341787648a b c d )
+--R                 *
+--R                         2
+--R                    %%DL0
+--R                + 
+--R                         5     4           5   2 3            4 2 2 2
+--R                  840000a b c e  - 1152000a b d e  - 60963840a b c d e
+--R                + 
+--R                           4 2   4             3 3 5
+--R                  55738368a b c d  - 261382464a b c
+--R             *
+--R                %%DL1
+--R            + 
+--R                             7 2     2             7 2 3              6 3 3
+--R                (- 154828800a b c d e  + 141557760a b d e - 910393344a b c d)
+--R             *
+--R                     2
+--R                %%DL0
+--R            + 
+--R                         5     4           5   2 3            4 2 2 2
+--R                  840000a b c e  - 1152000a b d e  - 60963840a b c d e
+--R                + 
+--R                           4 2   4             3 3 5
+--R                  55738368a b c d  - 261382464a b c
+--R             *
+--R                %%DL0
+--R            + 
+--R                        3 6          2   2 4           2     2 3
+--R                  15625a e  - 275625a b c e  + 3024000a b c d e
+--R                + 
+--R                             2   4             2 4  2              2 3 2
+--R                  (- 2073600a b d  - 4862025a b c )e  + 53343360a b c d e
+--R                + 
+--R                               2 2 4            3 6
+--R                  - 36578304a b c d  + 85766121b c
+--R             *
+--R                x
+--R            + 
+--R                      3   5           2   2   3          2     3 2
+--R              - 37500a d e  - 2646000a b c d e  - 907200a b c d e
+--R            + 
+--R                       2   5              2 4                 2 3 3
+--R              (2488320a b d  - 35006580a b c d)e + 16003008a b c d
+--R     + 
+--R                   2 3 8      3 2 4      4
+--R             (- 16a b x  - 32a b x  - 16a b)
+--R          *
+--R             ROOT
+--R                           5       2        5                     5       2
+--R                    - 3072a b %%DL1  - 2048a b %%DL0 %%DL1 - 3072a b %%DL0
+--R                  + 
+--R                                  2
+--R                    - 105c e - 72d
+--R               /
+--R                       5
+--R                  1024a b
+--R         + 
+--R                 2 3 8      3 2 4      4
+--R           (- 16a b x  - 32a b x  - 16a b)%%DL1
+--R         + 
+--R                 2 3 8      3 2 4      4
+--R           (- 16a b x  - 32a b x  - 16a b)%%DL0
+--R      *
+--R         log
+--R                                      10 2 3              9 3 2
+--R                          - 131072000a  b e  + 2312110080a b c e
+--R                        + 
+--R                                       9 3   2
+--R                          - 6341787648a b c d
+--R                     *
+--R                        %%DL0
+--R                    + 
+--R                                7 2     2             7 2 3              6 3 3
+--R                      154828800a b c d e  - 141557760a b d e + 910393344a b c d
+--R                 *
+--R                    %%DL1
+--R                + 
+--R                               7 2     2             7 2 3              6 3 3
+--R                    (154828800a b c d e  - 141557760a b d e + 910393344a b c d)
+--R                 *
+--R                    %%DL0
+--R                + 
+--R                         5     4           5   2 3            4 2 2 2
+--R                  840000a b c e  - 1152000a b d e  - 60963840a b c d e
+--R                + 
+--R                           4 2   4             3 3 5
+--R                  55738368a b c d  - 261382464a b c
+--R             *
+--R                ROOT
+--R                              5       2        5                     5       2
+--R                       - 3072a b %%DL1  - 2048a b %%DL0 %%DL1 - 3072a b %%DL0
+--R                     + 
+--R                                     2
+--R                       - 105c e - 72d
+--R                  /
+--R                          5
+--R                     1024a b
+--R            + 
+--R                               10 2 3              9 3 2               9 3   2
+--R                    (131072000a  b e  - 2312110080a b c e + 6341787648a b c d )
+--R                 *
+--R                    %%DL0
+--R                + 
+--R                              7 2     2             7 2 3              6 3 3
+--R                  - 154828800a b c d e  + 141557760a b d e - 910393344a b c d
+--R             *
+--R                     2
+--R                %%DL1
+--R            + 
+--R                               10 2 3              9 3 2               9 3   2
+--R                    (131072000a  b e  - 2312110080a b c e + 6341787648a b c d )
+--R                 *
+--R                         2
+--R                    %%DL0
+--R                + 
+--R                         5     4           5   2 3            4 2 2 2
+--R                  840000a b c e  - 1152000a b d e  - 60963840a b c d e
+--R                + 
+--R                           4 2   4             3 3 5
+--R                  55738368a b c d  - 261382464a b c
+--R             *
+--R                %%DL1
+--R            + 
+--R                             7 2     2             7 2 3              6 3 3
+--R                (- 154828800a b c d e  + 141557760a b d e - 910393344a b c d)
+--R             *
+--R                     2
+--R                %%DL0
+--R            + 
+--R                         5     4           5   2 3            4 2 2 2
+--R                  840000a b c e  - 1152000a b d e  - 60963840a b c d e
+--R                + 
+--R                           4 2   4             3 3 5
+--R                  55738368a b c d  - 261382464a b c
+--R             *
+--R                %%DL0
+--R            + 
+--R                        3 6          2   2 4           2     2 3
+--R                  15625a e  - 275625a b c e  + 3024000a b c d e
+--R                + 
+--R                             2   4             2 4  2              2 3 2
+--R                  (- 2073600a b d  - 4862025a b c )e  + 53343360a b c d e
+--R                + 
+--R                               2 2 4            3 6
+--R                  - 36578304a b c d  + 85766121b c
+--R             *
+--R                x
+--R            + 
+--R                      3   5           2   2   3          2     3 2
+--R              - 37500a d e  - 2646000a b c d e  - 907200a b c d e
+--R            + 
+--R                       2   5              2 4                 2 3 3
+--R              (2488320a b d  - 35006580a b c d)e + 16003008a b c d
+--R     + 
+--R             2 3 8      3 2 4      4
+--R         (32a b x  + 64a b x  + 32a b)%%DL1
+--R      *
+--R         log
+--R                                    10 2 3              9 3 2
+--R                        - 262144000a  b e  + 4624220160a b c e
+--R                      + 
+--R                                      9 3   2
+--R                        - 12683575296a b c d
+--R                 *
+--R                    %%DL0
+--R                + 
+--R                            7 2     2             7 2 3               6 3 3
+--R                  309657600a b c d e  - 283115520a b d e + 1820786688a b c d
+--R             *
+--R                     2
+--R                %%DL1
+--R            + 
+--R                                    10 2 3              9 3 2
+--R                        - 262144000a  b e  + 4624220160a b c e
+--R                      + 
+--R                                      9 3   2
+--R                        - 12683575296a b c d
+--R                 *
+--R                         2
+--R                    %%DL0
+--R                + 
+--R                            5     4           5   2 3             4 2 2 2
+--R                  - 1680000a b c e  + 2304000a b d e  + 121927680a b c d e
+--R                + 
+--R                              4 2   4             3 3 5
+--R                  - 111476736a b c d  + 522764928a b c
+--R             *
+--R                %%DL1
+--R            + 
+--R                             10 2 3              9 3 2                9 3   2
+--R                (- 262144000a  b e  + 4624220160a b c e - 12683575296a b c d )
+--R             *
+--R                     3
+--R                %%DL0
+--R            + 
+--R                            5     4           5   2 3             4 2 3 2
+--R                  - 6720000a b c e  - 4608000a b d e  + 118540800a b c e
+--R                + 
+--R                              4 2 2 2              4 2   4
+--R                  - 243855360a b c d e - 222953472a b c d
+--R             *
+--R                %%DL0
+--R            + 
+--R                        3 6          2   2 4           2     2 3
+--R                  15625a e  - 275625a b c e  + 3024000a b c d e
+--R                + 
+--R                             2   4             2 4  2              2 3 2
+--R                  (- 2073600a b d  - 4862025a b c )e  + 53343360a b c d e
+--R                + 
+--R                               2 2 4            3 6
+--R                  - 36578304a b c d  + 85766121b c
+--R             *
+--R                x
+--R            + 
+--R                      3   5           2   2   3           2     3 2
+--R              - 37500a d e  + 5292000a b c d e  - 2721600a b c d e
+--R            + 
+--R                         2   5              2 4                 2 3 3
+--R              (- 2488320a b d  + 11668860a b c d)e + 48009024a b c d
+--R     + 
+--R             2 3 8      3 2 4      4
+--R         (32a b x  + 64a b x  + 32a b)%%DL0
+--R      *
+--R         log
+--R                         10 2 3              9 3 2                9 3   2      3
+--R              (262144000a  b e  - 4624220160a b c e + 12683575296a b c d )%%DL0
+--R            + 
+--R                         7 2     2             7 2 3               6 3 3       2
+--R              (309657600a b c d e  - 283115520a b d e + 1820786688a b c d)%%DL0
+--R            + 
+--R                          5     4           5   2 3             4 2 3 2
+--R                  5040000a b c e  + 6912000a b d e  - 118540800a b c e
+--R                + 
+--R                            4 2 2 2              4 2   4             3 3 5
+--R                  365783040a b c d e + 111476736a b c d  + 522764928a b c
+--R             *
+--R                %%DL0
+--R            + 
+--R                        3 6          2   2 4           2     2 3
+--R                  15625a e  - 275625a b c e  + 3024000a b c d e
+--R                + 
+--R                             2   4             2 4  2              2 3 2
+--R                  (- 2073600a b d  - 4862025a b c )e  + 53343360a b c d e
+--R                + 
+--R                               2 2 4            3 6
+--R                  - 36578304a b c d  + 85766121b c
+--R             *
+--R                x
+--R            + 
+--R                     3   5           2     3 2
+--R              112500a d e  + 4536000a b c d e
+--R            + 
+--R                         2   5              2 4                 2 3 3
+--R              (- 2488320a b d  + 58344300a b c d)e - 80015040a b c d
+--R     + 
+--R         2   7     2   6     2   5           3            2                 2
+--R       5b e x  + 6b d x  + 7b c x  + 9a b e x  + 10a b d x  + 11a b c x - 4a f
+--R  /
+--R        2 3 8      3 2 4      4
+--R     32a b x  + 64a b x  + 32a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 746
+
+--S 747 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2 +-+ +-+4+-+3 +-+4+-+3
+--R             64a \|2 \|a \|a  \|b \|b
+--R          *
+--R             ROOT
+--R                           5       2        5                     5       2
+--R                    - 3072a b %%DL1  - 2048a b %%DL0 %%DL1 - 3072a b %%DL0
+--R                  + 
+--R                                  2
+--R                    - 105c e - 72d
+--R               /
+--R                       5
+--R                  1024a b
+--R         + 
+--R                2 +-+ +-+4+-+3 +-+4+-+3           2 +-+ +-+4+-+3 +-+4+-+3
+--R           - 64a \|2 \|a \|a  \|b \|b  %%DL1 - 64a \|2 \|a \|a  \|b \|b  %%DL0
+--R      *
+--R         log
+--R                                    10 2 3              9 3 2
+--R                          131072000a  b e  - 2312110080a b c e
+--R                        + 
+--R                                     9 3   2
+--R                          6341787648a b c d
+--R                     *
+--R                        %%DL0
+--R                    + 
+--R                                7 2     2             7 2 3              6 3 3
+--R                    - 154828800a b c d e  + 141557760a b d e - 910393344a b c d
+--R                 *
+--R                    %%DL1
+--R                + 
+--R                                    7 2     2             7 2 3
+--R                        - 154828800a b c d e  + 141557760a b d e
+--R                      + 
+--R                                    6 3 3
+--R                        - 910393344a b c d
+--R                 *
+--R                    %%DL0
+--R                + 
+--R                           5     4           5   2 3            4 2 2 2
+--R                  - 840000a b c e  + 1152000a b d e  + 60963840a b c d e
+--R                + 
+--R                             4 2   4             3 3 5
+--R                  - 55738368a b c d  + 261382464a b c
+--R             *
+--R                ROOT
+--R                              5       2        5                     5       2
+--R                       - 3072a b %%DL1  - 2048a b %%DL0 %%DL1 - 3072a b %%DL0
+--R                     + 
+--R                                     2
+--R                       - 105c e - 72d
+--R                  /
+--R                          5
+--R                     1024a b
+--R            + 
+--R                               10 2 3              9 3 2               9 3   2
+--R                    (131072000a  b e  - 2312110080a b c e + 6341787648a b c d )
+--R                 *
+--R                    %%DL0
+--R                + 
+--R                              7 2     2             7 2 3              6 3 3
+--R                  - 154828800a b c d e  + 141557760a b d e - 910393344a b c d
+--R             *
+--R                     2
+--R                %%DL1
+--R            + 
+--R                               10 2 3              9 3 2               9 3   2
+--R                    (131072000a  b e  - 2312110080a b c e + 6341787648a b c d )
+--R                 *
+--R                         2
+--R                    %%DL0
+--R                + 
+--R                         5     4           5   2 3            4 2 2 2
+--R                  840000a b c e  - 1152000a b d e  - 60963840a b c d e
+--R                + 
+--R                           4 2   4             3 3 5
+--R                  55738368a b c d  - 261382464a b c
+--R             *
+--R                %%DL1
+--R            + 
+--R                             7 2     2             7 2 3              6 3 3
+--R                (- 154828800a b c d e  + 141557760a b d e - 910393344a b c d)
+--R             *
+--R                     2
+--R                %%DL0
+--R            + 
+--R                         5     4           5   2 3            4 2 2 2
+--R                  840000a b c e  - 1152000a b d e  - 60963840a b c d e
+--R                + 
+--R                           4 2   4             3 3 5
+--R                  55738368a b c d  - 261382464a b c
+--R             *
+--R                %%DL0
+--R            + 
+--R                        3 6          2   2 4           2     2 3
+--R                  15625a e  - 275625a b c e  + 3024000a b c d e
+--R                + 
+--R                             2   4             2 4  2              2 3 2
+--R                  (- 2073600a b d  - 4862025a b c )e  + 53343360a b c d e
+--R                + 
+--R                               2 2 4            3 6
+--R                  - 36578304a b c d  + 85766121b c
+--R             *
+--R                x
+--R            + 
+--R                      3   5           2   2   3          2     3 2
+--R              - 37500a d e  - 2646000a b c d e  - 907200a b c d e
+--R            + 
+--R                       2   5              2 4                 2 3 3
+--R              (2488320a b d  - 35006580a b c d)e + 16003008a b c d
+--R     + 
+--R           -
+--R                   2 +-+ +-+4+-+3 +-+4+-+3
+--R                64a \|2 \|a \|a  \|b \|b
+--R             *
+--R                ROOT
+--R                              5       2        5                     5       2
+--R                       - 3072a b %%DL1  - 2048a b %%DL0 %%DL1 - 3072a b %%DL0
+--R                     + 
+--R                                     2
+--R                       - 105c e - 72d
+--R                  /
+--R                          5
+--R                     1024a b
+--R         + 
+--R                2 +-+ +-+4+-+3 +-+4+-+3           2 +-+ +-+4+-+3 +-+4+-+3
+--R           - 64a \|2 \|a \|a  \|b \|b  %%DL1 - 64a \|2 \|a \|a  \|b \|b  %%DL0
+--R      *
+--R         log
+--R                                      10 2 3              9 3 2
+--R                          - 131072000a  b e  + 2312110080a b c e
+--R                        + 
+--R                                       9 3   2
+--R                          - 6341787648a b c d
+--R                     *
+--R                        %%DL0
+--R                    + 
+--R                                7 2     2             7 2 3              6 3 3
+--R                      154828800a b c d e  - 141557760a b d e + 910393344a b c d
+--R                 *
+--R                    %%DL1
+--R                + 
+--R                               7 2     2             7 2 3              6 3 3
+--R                    (154828800a b c d e  - 141557760a b d e + 910393344a b c d)
+--R                 *
+--R                    %%DL0
+--R                + 
+--R                         5     4           5   2 3            4 2 2 2
+--R                  840000a b c e  - 1152000a b d e  - 60963840a b c d e
+--R                + 
+--R                           4 2   4             3 3 5
+--R                  55738368a b c d  - 261382464a b c
+--R             *
+--R                ROOT
+--R                              5       2        5                     5       2
+--R                       - 3072a b %%DL1  - 2048a b %%DL0 %%DL1 - 3072a b %%DL0
+--R                     + 
+--R                                     2
+--R                       - 105c e - 72d
+--R                  /
+--R                          5
+--R                     1024a b
+--R            + 
+--R                               10 2 3              9 3 2               9 3   2
+--R                    (131072000a  b e  - 2312110080a b c e + 6341787648a b c d )
+--R                 *
+--R                    %%DL0
+--R                + 
+--R                              7 2     2             7 2 3              6 3 3
+--R                  - 154828800a b c d e  + 141557760a b d e - 910393344a b c d
+--R             *
+--R                     2
+--R                %%DL1
+--R            + 
+--R                               10 2 3              9 3 2               9 3   2
+--R                    (131072000a  b e  - 2312110080a b c e + 6341787648a b c d )
+--R                 *
+--R                         2
+--R                    %%DL0
+--R                + 
+--R                         5     4           5   2 3            4 2 2 2
+--R                  840000a b c e  - 1152000a b d e  - 60963840a b c d e
+--R                + 
+--R                           4 2   4             3 3 5
+--R                  55738368a b c d  - 261382464a b c
+--R             *
+--R                %%DL1
+--R            + 
+--R                             7 2     2             7 2 3              6 3 3
+--R                (- 154828800a b c d e  + 141557760a b d e - 910393344a b c d)
+--R             *
+--R                     2
+--R                %%DL0
+--R            + 
+--R                         5     4           5   2 3            4 2 2 2
+--R                  840000a b c e  - 1152000a b d e  - 60963840a b c d e
+--R                + 
+--R                           4 2   4             3 3 5
+--R                  55738368a b c d  - 261382464a b c
+--R             *
+--R                %%DL0
+--R            + 
+--R                        3 6          2   2 4           2     2 3
+--R                  15625a e  - 275625a b c e  + 3024000a b c d e
+--R                + 
+--R                             2   4             2 4  2              2 3 2
+--R                  (- 2073600a b d  - 4862025a b c )e  + 53343360a b c d e
+--R                + 
+--R                               2 2 4            3 6
+--R                  - 36578304a b c d  + 85766121b c
+--R             *
+--R                x
+--R            + 
+--R                      3   5           2   2   3          2     3 2
+--R              - 37500a d e  - 2646000a b c d e  - 907200a b c d e
+--R            + 
+--R                       2   5              2 4                 2 3 3
+--R              (2488320a b d  - 35006580a b c d)e + 16003008a b c d
+--R     + 
+--R             2 +-+ +-+4+-+3 +-+4+-+3
+--R         128a \|2 \|a \|a  \|b \|b  %%DL1
+--R      *
+--R         log
+--R                                    10 2 3              9 3 2
+--R                        - 262144000a  b e  + 4624220160a b c e
+--R                      + 
+--R                                      9 3   2
+--R                        - 12683575296a b c d
+--R                 *
+--R                    %%DL0
+--R                + 
+--R                            7 2     2             7 2 3               6 3 3
+--R                  309657600a b c d e  - 283115520a b d e + 1820786688a b c d
+--R             *
+--R                     2
+--R                %%DL1
+--R            + 
+--R                                    10 2 3              9 3 2
+--R                        - 262144000a  b e  + 4624220160a b c e
+--R                      + 
+--R                                      9 3   2
+--R                        - 12683575296a b c d
+--R                 *
+--R                         2
+--R                    %%DL0
+--R                + 
+--R                            5     4           5   2 3             4 2 2 2
+--R                  - 1680000a b c e  + 2304000a b d e  + 121927680a b c d e
+--R                + 
+--R                              4 2   4             3 3 5
+--R                  - 111476736a b c d  + 522764928a b c
+--R             *
+--R                %%DL1
+--R            + 
+--R                             10 2 3              9 3 2                9 3   2
+--R                (- 262144000a  b e  + 4624220160a b c e - 12683575296a b c d )
+--R             *
+--R                     3
+--R                %%DL0
+--R            + 
+--R                            5     4           5   2 3             4 2 3 2
+--R                  - 6720000a b c e  - 4608000a b d e  + 118540800a b c e
+--R                + 
+--R                              4 2 2 2              4 2   4
+--R                  - 243855360a b c d e - 222953472a b c d
+--R             *
+--R                %%DL0
+--R            + 
+--R                        3 6          2   2 4           2     2 3
+--R                  15625a e  - 275625a b c e  + 3024000a b c d e
+--R                + 
+--R                             2   4             2 4  2              2 3 2
+--R                  (- 2073600a b d  - 4862025a b c )e  + 53343360a b c d e
+--R                + 
+--R                               2 2 4            3 6
+--R                  - 36578304a b c d  + 85766121b c
+--R             *
+--R                x
+--R            + 
+--R                      3   5           2   2   3           2     3 2
+--R              - 37500a d e  + 5292000a b c d e  - 2721600a b c d e
+--R            + 
+--R                         2   5              2 4                 2 3 3
+--R              (- 2488320a b d  + 11668860a b c d)e + 48009024a b c d
+--R     + 
+--R             2 +-+ +-+4+-+3 +-+4+-+3
+--R         128a \|2 \|a \|a  \|b \|b  %%DL0
+--R      *
+--R         log
+--R                         10 2 3              9 3 2                9 3   2      3
+--R              (262144000a  b e  - 4624220160a b c e + 12683575296a b c d )%%DL0
+--R            + 
+--R                         7 2     2             7 2 3               6 3 3       2
+--R              (309657600a b c d e  - 283115520a b d e + 1820786688a b c d)%%DL0
+--R            + 
+--R                          5     4           5   2 3             4 2 3 2
+--R                  5040000a b c e  + 6912000a b d e  - 118540800a b c e
+--R                + 
+--R                            4 2 2 2              4 2   4             3 3 5
+--R                  365783040a b c d e + 111476736a b c d  + 522764928a b c
+--R             *
+--R                %%DL0
+--R            + 
+--R                        3 6          2   2 4           2     2 3
+--R                  15625a e  - 275625a b c e  + 3024000a b c d e
+--R                + 
+--R                             2   4             2 4  2              2 3 2
+--R                  (- 2073600a b d  - 4862025a b c )e  + 53343360a b c d e
+--R                + 
+--R                               2 2 4            3 6
+--R                  - 36578304a b c d  + 85766121b c
+--R             *
+--R                x
+--R            + 
+--R                     3   5           2     3 2
+--R              112500a d e  + 4536000a b c d e
+--R            + 
+--R                         2   5              2 4                 2 3 3
+--R              (- 2488320a b d  + 58344300a b c d)e - 80015040a b c d
+--R     + 
+--R             +-+         +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (5a e\|b  - 21b c\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R               +-+         +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- 5a e\|b  + 21b c\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                       +-+4+-+   4+-+
+--R                +-+         +-+      x\|2 \|b  + \|a
+--R       (- 10a e\|b  - 42b c\|a )atan(----------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                       +-+4+-+   4+-+
+--R                +-+         +-+      x\|2 \|b  - \|a
+--R       (- 10a e\|b  - 42b c\|a )atan(----------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                 2 +-+
+--R             +-+4+-+3 4+-+3     x \|b
+--R       - 24d\|2 \|a   \|b  atan(------)
+--R                                  +-+
+--R                                 \|a
+--R  /
+--R         2 +-+ +-+4+-+3 +-+4+-+3
+--R     128a \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 747
+
+--S 748 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  4        2  +-+4+-+2          6          4          2  +-+
+--R           ((20e x  + 84c x )\|a \|a   - 21b c x  - 10a e x  + 21a c x )\|b
+--R         + 
+--R                   6          4          2         4+-+2
+--R           (10b e x  + 42b c x  + 10a e x  + 42a c)\|a
+--R         + 
+--R                    6          4         2  +-+
+--R           (- 5b e x  - 42b c x  + 5a e x )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                   4          2         4+-+2
+--R           (21b c x  - 10a e x  - 21a c)\|a
+--R         + 
+--R                    6          4         2          +-+
+--R           (- 5b e x  - 21b c x  - 5a e x  - 21a c)\|a
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R              4          2         +-+4+-+2      2   6            4            2
+--R       (5b e x  - 42b c x  - 5a e)\|a \|a   + 21b c x  - 15a b e x  - 63a b c x
+--R     + 
+--R         2
+--R       5a e
+--R  /
+--R                  2   6       3 2  +-+4+-+2 +-+
+--R             (128a b x  + 128a x )\|a \|a  \|b
+--R           + 
+--R                 2 2 8       3   4      4 4+-+2
+--R             (64a b x  + 128a b x  + 64a )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R             3 2 6       4   2
+--R       - 128a b x  - 128a b x
+--R                                                    Type: Expression(Integer)
+--E 748
+
+)clear all
+
+--S 749 of 953
+t0:=(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^4
+--R 
+--R
+--R                     3      2
+--R                  f x  + e x  + d x + c
+--R   (1)  -----------------------------------------
+--R         4 16       3 12     2 2 8     3   4    4
+--R        b x   + 4a b x   + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 749
+
+--S 750 of 953
+r0:=-1/12*f/(b*(a+b*x^4)^3)+1/12*x*(c+d*x+e*x^2)/(a*(a+b*x^4)^3)+1/96*x*_
+   (11*c+10*d*x+9*e*x^2)/(a^2*(a+b*x^4)^2)+1/384*x*(77*c+60*d*x+45*e*x^2)/_
+   (a^3*(a+b*x^4))+5/32*d*atan(x^2*sqrt(b)/sqrt(a))/(a^(7/2)*sqrt(b))-_
+   1/512*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-15*e*_
+   sqrt(a)+77*c*sqrt(b))/(a^(15/4)*b^(3/4)*sqrt(2))+1/512*log(a^(1/4)*_
+   b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-15*e*sqrt(a)+77*c*sqrt(b))/_
+   (a^(15/4)*b^(3/4)*sqrt(2))-1/256*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*_
+   (15*e*sqrt(a)+77*c*sqrt(b))/(a^(15/4)*b^(3/4)*sqrt(2))+1/256*_
+   atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(15*e*sqrt(a)+77*c*sqrt(b))/_
+   (a^(15/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   4   12       2 3   8       3 2   4      4     +-+
+--R           (- 45a b e x   - 135a b e x  - 135a b e x  - 45a b e)\|b
+--R         + 
+--R                5   12         4   8       2 3   4       3 2   +-+
+--R           (231b c x   + 693a b c x  + 693a b c x  + 231a b c)\|a
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                 4   12       2 3   8       3 2   4      4     +-+
+--R           (45a b e x   + 135a b e x  + 135a b e x  + 45a b e)\|b
+--R         + 
+--R                  5   12         4   8       2 3   4       3 2   +-+
+--R           (- 231b c x   - 693a b c x  - 693a b c x  - 231a b c)\|a
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                 4   12       2 3   8       3 2   4      4     +-+
+--R           (90a b e x   + 270a b e x  + 270a b e x  + 90a b e)\|b
+--R         + 
+--R                5   12          4   8        2 3   4       3 2   +-+
+--R           (462b c x   + 1386a b c x  + 1386a b c x  + 462a b c)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  + \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                 4   12       2 3   8       3 2   4      4     +-+
+--R           (90a b e x   + 270a b e x  + 270a b e x  + 90a b e)\|b
+--R         + 
+--R                5   12          4   8        2 3   4       3 2   +-+
+--R           (462b c x   + 1386a b c x  + 1386a b c x  + 462a b c)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  - \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R              4   12         3   8       2 2   4       3     +-+4+-+3 4+-+3
+--R         (240b d x   + 720a b d x  + 720a b d x  + 240a b d)\|2 \|a   \|b
+--R      *
+--R               2 +-+
+--R              x \|b
+--R         atan(------)
+--R                +-+
+--R               \|a
+--R     + 
+--R               3   11       3   10       3   9         2   7         2   6
+--R           180b e x   + 240b d x   + 308b c x  + 504a b e x  + 640a b d x
+--R         + 
+--R                 2   5       2     3       2     2       2            3
+--R           792a b c x  + 452a b e x  + 528a b d x  + 612a b c x - 128a f
+--R      *
+--R          +-+ +-+4+-+3 +-+4+-+3
+--R         \|2 \|a \|a  \|b \|b
+--R  /
+--R           3 4 12        4 3 8        5 2 4        6   +-+ +-+4+-+3 +-+4+-+3
+--R     (1536a b x   + 4608a b x  + 4608a b x  + 1536a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 750
+
+--S 751 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  3 4 12       4 3 8       5 2 4       6
+--R             (192a b x   + 576a b x  + 576a b x  + 192a b)
+--R          *
+--R             ROOT
+--R                            7       2         7                      7       2
+--R                    - 49152a b %%DM1  - 32768a b %%DM0 %%DM1 - 49152a b %%DM0
+--R                  + 
+--R                                    2
+--R                    - 1155c e - 800d
+--R               /
+--R                        7
+--R                  16384a b
+--R         + 
+--R                  3 4 12       4 3 8       5 2 4       6
+--R           (- 192a b x   - 576a b x  - 576a b x  - 192a b)%%DM1
+--R         + 
+--R                  3 4 12       4 3 8       5 2 4       6
+--R           (- 192a b x   - 576a b x  - 576a b x  - 192a b)%%DM0
+--R      *
+--R         log
+--R                                       13 2 3                 12 3 2
+--R                          226492416000a  b e  - 5968326819840a  b c e
+--R                        + 
+--R                                         12 3   2
+--R                          16535624089600a  b c d
+--R                     *
+--R                        %%DM0
+--R                    + 
+--R                                     9 2     2                9 2 3
+--R                      - 272498688000a b c d e  + 251658240000a b d e
+--R                    + 
+--R                                      8 3 3
+--R                      - 2393547735040a b c d
+--R                 *
+--R                    %%DM1
+--R                + 
+--R                                     9 2     2                9 2 3
+--R                      - 272498688000a b c d e  + 251658240000a b d e
+--R                    + 
+--R                                      8 3 3
+--R                      - 2393547735040a b c d
+--R                 *
+--R                    %%DM0
+--R                + 
+--R                              6     4              6   2 3
+--R                  - 997920000a b c e  + 1382400000a b d e
+--R                + 
+--R                               5 2 2 2                 5 2   4
+--R                  109283328000a b c d e - 100925440000a b c d
+--R                + 
+--R                               4 3 5
+--R                  692936744192a b c
+--R             *
+--R                ROOT
+--R                               7       2         7
+--R                       - 49152a b %%DM1  - 32768a b %%DM0 %%DM1
+--R                     + 
+--R                               7       2                 2
+--R                       - 49152a b %%DM0  - 1155c e - 800d
+--R                  /
+--R                           7
+--R                     16384a b
+--R            + 
+--R                                   13 2 3                 12 3 2
+--R                      226492416000a  b e  - 5968326819840a  b c e
+--R                    + 
+--R                                     12 3   2
+--R                      16535624089600a  b c d
+--R                 *
+--R                    %%DM0
+--R                + 
+--R                                 9 2     2                9 2 3
+--R                  - 272498688000a b c d e  + 251658240000a b d e
+--R                + 
+--R                                  8 3 3
+--R                  - 2393547735040a b c d
+--R             *
+--R                     2
+--R                %%DM1
+--R            + 
+--R                                   13 2 3                 12 3 2
+--R                      226492416000a  b e  - 5968326819840a  b c e
+--R                    + 
+--R                                     12 3   2
+--R                      16535624089600a  b c d
+--R                 *
+--R                         2
+--R                    %%DM0
+--R                + 
+--R                            6     4              6   2 3                5 2 2 2
+--R                  997920000a b c e  - 1382400000a b d e  - 109283328000a b c d e
+--R                + 
+--R                               5 2   4                4 3 5
+--R                  100925440000a b c d  - 692936744192a b c
+--R             *
+--R                %%DM1
+--R            + 
+--R                                 9 2     2                9 2 3
+--R                  - 272498688000a b c d e  + 251658240000a b d e
+--R                + 
+--R                                  8 3 3
+--R                  - 2393547735040a b c d
+--R             *
+--R                     2
+--R                %%DM0
+--R            + 
+--R                            6     4              6   2 3                5 2 2 2
+--R                  997920000a b c e  - 1382400000a b d e  - 109283328000a b c d e
+--R                + 
+--R                               5 2   4                4 3 5
+--R                  100925440000a b c d  - 692936744192a b c
+--R             *
+--R                %%DM0
+--R            + 
+--R                           3 6             2   2 4              2     2 3
+--R                  11390625a e  - 300155625a b c e  + 3326400000a b c d e
+--R                + 
+--R                                2   4                2 4  2
+--R                  (- 2304000000a b d  - 7909434225a b c )e
+--R                + 
+--R                                2 3 2                  2 2 4                3 6
+--R                  87654336000a b c d e - 60712960000a b c d  + 208422380089b c
+--R             *
+--R                x
+--R            + 
+--R                         3   5              2   2   3              2     3 2
+--R              - 30375000a d e  - 3201660000a b c d e  - 1108800000a b c d e
+--R            + 
+--R                          2   5                 2 4                    2 3 3
+--R              (3072000000a b d  - 63275473800a b c d)e + 29218112000a b c d
+--R     + 
+--R                    3 4 12       4 3 8       5 2 4       6
+--R             (- 192a b x   - 576a b x  - 576a b x  - 192a b)
+--R          *
+--R             ROOT
+--R                            7       2         7                      7       2
+--R                    - 49152a b %%DM1  - 32768a b %%DM0 %%DM1 - 49152a b %%DM0
+--R                  + 
+--R                                    2
+--R                    - 1155c e - 800d
+--R               /
+--R                        7
+--R                  16384a b
+--R         + 
+--R                  3 4 12       4 3 8       5 2 4       6
+--R           (- 192a b x   - 576a b x  - 576a b x  - 192a b)%%DM1
+--R         + 
+--R                  3 4 12       4 3 8       5 2 4       6
+--R           (- 192a b x   - 576a b x  - 576a b x  - 192a b)%%DM0
+--R      *
+--R         log
+--R                                         13 2 3                 12 3 2
+--R                          - 226492416000a  b e  + 5968326819840a  b c e
+--R                        + 
+--R                                           12 3   2
+--R                          - 16535624089600a  b c d
+--R                     *
+--R                        %%DM0
+--R                    + 
+--R                                   9 2     2                9 2 3
+--R                      272498688000a b c d e  - 251658240000a b d e
+--R                    + 
+--R                                    8 3 3
+--R                      2393547735040a b c d
+--R                 *
+--R                    %%DM1
+--R                + 
+--R                                   9 2     2                9 2 3
+--R                      272498688000a b c d e  - 251658240000a b d e
+--R                    + 
+--R                                    8 3 3
+--R                      2393547735040a b c d
+--R                 *
+--R                    %%DM0
+--R                + 
+--R                            6     4              6   2 3                5 2 2 2
+--R                  997920000a b c e  - 1382400000a b d e  - 109283328000a b c d e
+--R                + 
+--R                               5 2   4                4 3 5
+--R                  100925440000a b c d  - 692936744192a b c
+--R             *
+--R                ROOT
+--R                               7       2         7
+--R                       - 49152a b %%DM1  - 32768a b %%DM0 %%DM1
+--R                     + 
+--R                               7       2                 2
+--R                       - 49152a b %%DM0  - 1155c e - 800d
+--R                  /
+--R                           7
+--R                     16384a b
+--R            + 
+--R                                   13 2 3                 12 3 2
+--R                      226492416000a  b e  - 5968326819840a  b c e
+--R                    + 
+--R                                     12 3   2
+--R                      16535624089600a  b c d
+--R                 *
+--R                    %%DM0
+--R                + 
+--R                                 9 2     2                9 2 3
+--R                  - 272498688000a b c d e  + 251658240000a b d e
+--R                + 
+--R                                  8 3 3
+--R                  - 2393547735040a b c d
+--R             *
+--R                     2
+--R                %%DM1
+--R            + 
+--R                                   13 2 3                 12 3 2
+--R                      226492416000a  b e  - 5968326819840a  b c e
+--R                    + 
+--R                                     12 3   2
+--R                      16535624089600a  b c d
+--R                 *
+--R                         2
+--R                    %%DM0
+--R                + 
+--R                            6     4              6   2 3                5 2 2 2
+--R                  997920000a b c e  - 1382400000a b d e  - 109283328000a b c d e
+--R                + 
+--R                               5 2   4                4 3 5
+--R                  100925440000a b c d  - 692936744192a b c
+--R             *
+--R                %%DM1
+--R            + 
+--R                                 9 2     2                9 2 3
+--R                  - 272498688000a b c d e  + 251658240000a b d e
+--R                + 
+--R                                  8 3 3
+--R                  - 2393547735040a b c d
+--R             *
+--R                     2
+--R                %%DM0
+--R            + 
+--R                            6     4              6   2 3                5 2 2 2
+--R                  997920000a b c e  - 1382400000a b d e  - 109283328000a b c d e
+--R                + 
+--R                               5 2   4                4 3 5
+--R                  100925440000a b c d  - 692936744192a b c
+--R             *
+--R                %%DM0
+--R            + 
+--R                           3 6             2   2 4              2     2 3
+--R                  11390625a e  - 300155625a b c e  + 3326400000a b c d e
+--R                + 
+--R                                2   4                2 4  2
+--R                  (- 2304000000a b d  - 7909434225a b c )e
+--R                + 
+--R                                2 3 2                  2 2 4                3 6
+--R                  87654336000a b c d e - 60712960000a b c d  + 208422380089b c
+--R             *
+--R                x
+--R            + 
+--R                         3   5              2   2   3              2     3 2
+--R              - 30375000a d e  - 3201660000a b c d e  - 1108800000a b c d e
+--R            + 
+--R                          2   5                 2 4                    2 3 3
+--R              (3072000000a b d  - 63275473800a b c d)e + 29218112000a b c d
+--R     + 
+--R              3 4 12        4 3 8        5 2 4       6
+--R         (384a b x   + 1152a b x  + 1152a b x  + 384a b)%%DM1
+--R      *
+--R         log
+--R                                     13 2 3                  12 3 2
+--R                      - 452984832000a  b e  + 11936653639680a  b c e
+--R                    + 
+--R                                       12 3   2
+--R                      - 33071248179200a  b c d
+--R                 *
+--R                    %%DM0
+--R                + 
+--R                               9 2     2                9 2 3
+--R                  544997376000a b c d e  - 503316480000a b d e
+--R                + 
+--R                                8 3 3
+--R                  4787095470080a b c d
+--R             *
+--R                     2
+--R                %%DM1
+--R            + 
+--R                                     13 2 3                  12 3 2
+--R                      - 452984832000a  b e  + 11936653639680a  b c e
+--R                    + 
+--R                                       12 3   2
+--R                      - 33071248179200a  b c d
+--R                 *
+--R                         2
+--R                    %%DM0
+--R                + 
+--R                               6     4              6   2 3
+--R                  - 1995840000a b c e  + 2764800000a b d e
+--R                + 
+--R                               5 2 2 2                 5 2   4
+--R                  218566656000a b c d e - 201850880000a b c d
+--R                + 
+--R                                4 3 5
+--R                  1385873488384a b c
+--R             *
+--R                %%DM1
+--R            + 
+--R                                 13 2 3                  12 3 2
+--R                  - 452984832000a  b e  + 11936653639680a  b c e
+--R                + 
+--R                                   12 3   2
+--R                  - 33071248179200a  b c d
+--R             *
+--R                     3
+--R                %%DM0
+--R            + 
+--R                               6     4              6   2 3
+--R                  - 7983360000a b c e  - 5529600000a b d e
+--R                + 
+--R                               5 2 3 2                5 2 2 2
+--R                  210370406400a b c e  - 437133312000a b c d e
+--R                + 
+--R                                 5 2   4
+--R                  - 403701760000a b c d
+--R             *
+--R                %%DM0
+--R            + 
+--R                           3 6             2   2 4              2     2 3
+--R                  11390625a e  - 300155625a b c e  + 3326400000a b c d e
+--R                + 
+--R                                2   4                2 4  2
+--R                  (- 2304000000a b d  - 7909434225a b c )e
+--R                + 
+--R                                2 3 2                  2 2 4                3 6
+--R                  87654336000a b c d e - 60712960000a b c d  + 208422380089b c
+--R             *
+--R                x
+--R            + 
+--R                         3   5              2   2   3              2     3 2
+--R              - 30375000a d e  + 6403320000a b c d e  - 3326400000a b c d e
+--R            + 
+--R                            2   5                 2 4                    2 3 3
+--R              (- 3072000000a b d  + 21091824600a b c d)e + 87654336000a b c d
+--R     + 
+--R              3 4 12        4 3 8        5 2 4       6
+--R         (384a b x   + 1152a b x  + 1152a b x  + 384a b)%%DM0
+--R      *
+--R         log
+--R                               13 2 3                  12 3 2
+--R                  452984832000a  b e  - 11936653639680a  b c e
+--R                + 
+--R                                 12 3   2
+--R                  33071248179200a  b c d
+--R             *
+--R                     3
+--R                %%DM0
+--R            + 
+--R                               9 2     2                9 2 3
+--R                  544997376000a b c d e  - 503316480000a b d e
+--R                + 
+--R                                8 3 3
+--R                  4787095470080a b c d
+--R             *
+--R                     2
+--R                %%DM0
+--R            + 
+--R                             6     4              6   2 3                5 2 3 2
+--R                  5987520000a b c e  + 8294400000a b d e  - 210370406400a b c e
+--R                + 
+--R                               5 2 2 2                 5 2   4
+--R                  655699968000a b c d e + 201850880000a b c d
+--R                + 
+--R                                4 3 5
+--R                  1385873488384a b c
+--R             *
+--R                %%DM0
+--R            + 
+--R                           3 6             2   2 4              2     2 3
+--R                  11390625a e  - 300155625a b c e  + 3326400000a b c d e
+--R                + 
+--R                                2   4                2 4  2
+--R                  (- 2304000000a b d  - 7909434225a b c )e
+--R                + 
+--R                                2 3 2                  2 2 4                3 6
+--R                  87654336000a b c d e - 60712960000a b c d  + 208422380089b c
+--R             *
+--R                x
+--R            + 
+--R                       3   5              2     3 2
+--R              91125000a d e  + 5544000000a b c d e
+--R            + 
+--R                          2   5                  2 4                     2 3 3
+--R            (- 3072000000a b d  + 105459123000a b c d)e - 146090560000a b c d
+--R     + 
+--R          3   11      3   10      3   9         2   7         2   6
+--R       45b e x   + 60b d x   + 77b c x  + 126a b e x  + 160a b d x
+--R     + 
+--R             2   5       2     3       2     2       2           3
+--R       198a b c x  + 113a b e x  + 132a b d x  + 153a b c x - 32a f
+--R  /
+--R         3 4 12        4 3 8        5 2 4       6
+--R     384a b x   + 1152a b x  + 1152a b x  + 384a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 751
+
+--S 752 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3 +-+ +-+4+-+3 +-+4+-+3
+--R             256a \|2 \|a \|a  \|b \|b
+--R          *
+--R             ROOT
+--R                            7       2         7                      7       2
+--R                    - 49152a b %%DM1  - 32768a b %%DM0 %%DM1 - 49152a b %%DM0
+--R                  + 
+--R                                    2
+--R                    - 1155c e - 800d
+--R               /
+--R                        7
+--R                  16384a b
+--R         + 
+--R               3 +-+ +-+4+-+3 +-+4+-+3            3 +-+ +-+4+-+3 +-+4+-+3
+--R         - 256a \|2 \|a \|a  \|b \|b  %%DM1 - 256a \|2 \|a \|a  \|b \|b  %%DM0
+--R      *
+--R         log
+--R                                       13 2 3                 12 3 2
+--R                          226492416000a  b e  - 5968326819840a  b c e
+--R                        + 
+--R                                         12 3   2
+--R                          16535624089600a  b c d
+--R                     *
+--R                        %%DM0
+--R                    + 
+--R                                     9 2     2                9 2 3
+--R                      - 272498688000a b c d e  + 251658240000a b d e
+--R                    + 
+--R                                      8 3 3
+--R                      - 2393547735040a b c d
+--R                 *
+--R                    %%DM1
+--R                + 
+--R                                     9 2     2                9 2 3
+--R                      - 272498688000a b c d e  + 251658240000a b d e
+--R                    + 
+--R                                      8 3 3
+--R                      - 2393547735040a b c d
+--R                 *
+--R                    %%DM0
+--R                + 
+--R                              6     4              6   2 3
+--R                  - 997920000a b c e  + 1382400000a b d e
+--R                + 
+--R                               5 2 2 2                 5 2   4
+--R                  109283328000a b c d e - 100925440000a b c d
+--R                + 
+--R                               4 3 5
+--R                  692936744192a b c
+--R             *
+--R                ROOT
+--R                               7       2         7
+--R                       - 49152a b %%DM1  - 32768a b %%DM0 %%DM1
+--R                     + 
+--R                               7       2                 2
+--R                       - 49152a b %%DM0  - 1155c e - 800d
+--R                  /
+--R                           7
+--R                     16384a b
+--R            + 
+--R                                   13 2 3                 12 3 2
+--R                      226492416000a  b e  - 5968326819840a  b c e
+--R                    + 
+--R                                     12 3   2
+--R                      16535624089600a  b c d
+--R                 *
+--R                    %%DM0
+--R                + 
+--R                                 9 2     2                9 2 3
+--R                  - 272498688000a b c d e  + 251658240000a b d e
+--R                + 
+--R                                  8 3 3
+--R                  - 2393547735040a b c d
+--R             *
+--R                     2
+--R                %%DM1
+--R            + 
+--R                                   13 2 3                 12 3 2
+--R                      226492416000a  b e  - 5968326819840a  b c e
+--R                    + 
+--R                                     12 3   2
+--R                      16535624089600a  b c d
+--R                 *
+--R                         2
+--R                    %%DM0
+--R                + 
+--R                            6     4              6   2 3                5 2 2 2
+--R                  997920000a b c e  - 1382400000a b d e  - 109283328000a b c d e
+--R                + 
+--R                               5 2   4                4 3 5
+--R                  100925440000a b c d  - 692936744192a b c
+--R             *
+--R                %%DM1
+--R            + 
+--R                                 9 2     2                9 2 3
+--R                  - 272498688000a b c d e  + 251658240000a b d e
+--R                + 
+--R                                  8 3 3
+--R                  - 2393547735040a b c d
+--R             *
+--R                     2
+--R                %%DM0
+--R            + 
+--R                            6     4              6   2 3                5 2 2 2
+--R                  997920000a b c e  - 1382400000a b d e  - 109283328000a b c d e
+--R                + 
+--R                               5 2   4                4 3 5
+--R                  100925440000a b c d  - 692936744192a b c
+--R             *
+--R                %%DM0
+--R            + 
+--R                           3 6             2   2 4              2     2 3
+--R                  11390625a e  - 300155625a b c e  + 3326400000a b c d e
+--R                + 
+--R                                2   4                2 4  2
+--R                  (- 2304000000a b d  - 7909434225a b c )e
+--R                + 
+--R                                2 3 2                  2 2 4                3 6
+--R                  87654336000a b c d e - 60712960000a b c d  + 208422380089b c
+--R             *
+--R                x
+--R            + 
+--R                         3   5              2   2   3              2     3 2
+--R              - 30375000a d e  - 3201660000a b c d e  - 1108800000a b c d e
+--R            + 
+--R                          2   5                 2 4                    2 3 3
+--R              (3072000000a b d  - 63275473800a b c d)e + 29218112000a b c d
+--R     + 
+--R           -
+--R                    3 +-+ +-+4+-+3 +-+4+-+3
+--R                256a \|2 \|a \|a  \|b \|b
+--R             *
+--R                ROOT
+--R                               7       2         7
+--R                       - 49152a b %%DM1  - 32768a b %%DM0 %%DM1
+--R                     + 
+--R                               7       2                 2
+--R                       - 49152a b %%DM0  - 1155c e - 800d
+--R                  /
+--R                           7
+--R                     16384a b
+--R         + 
+--R               3 +-+ +-+4+-+3 +-+4+-+3            3 +-+ +-+4+-+3 +-+4+-+3
+--R         - 256a \|2 \|a \|a  \|b \|b  %%DM1 - 256a \|2 \|a \|a  \|b \|b  %%DM0
+--R      *
+--R         log
+--R                                         13 2 3                 12 3 2
+--R                          - 226492416000a  b e  + 5968326819840a  b c e
+--R                        + 
+--R                                           12 3   2
+--R                          - 16535624089600a  b c d
+--R                     *
+--R                        %%DM0
+--R                    + 
+--R                                   9 2     2                9 2 3
+--R                      272498688000a b c d e  - 251658240000a b d e
+--R                    + 
+--R                                    8 3 3
+--R                      2393547735040a b c d
+--R                 *
+--R                    %%DM1
+--R                + 
+--R                                   9 2     2                9 2 3
+--R                      272498688000a b c d e  - 251658240000a b d e
+--R                    + 
+--R                                    8 3 3
+--R                      2393547735040a b c d
+--R                 *
+--R                    %%DM0
+--R                + 
+--R                            6     4              6   2 3                5 2 2 2
+--R                  997920000a b c e  - 1382400000a b d e  - 109283328000a b c d e
+--R                + 
+--R                               5 2   4                4 3 5
+--R                  100925440000a b c d  - 692936744192a b c
+--R             *
+--R                ROOT
+--R                               7       2         7
+--R                       - 49152a b %%DM1  - 32768a b %%DM0 %%DM1
+--R                     + 
+--R                               7       2                 2
+--R                       - 49152a b %%DM0  - 1155c e - 800d
+--R                  /
+--R                           7
+--R                     16384a b
+--R            + 
+--R                                   13 2 3                 12 3 2
+--R                      226492416000a  b e  - 5968326819840a  b c e
+--R                    + 
+--R                                     12 3   2
+--R                      16535624089600a  b c d
+--R                 *
+--R                    %%DM0
+--R                + 
+--R                                 9 2     2                9 2 3
+--R                  - 272498688000a b c d e  + 251658240000a b d e
+--R                + 
+--R                                  8 3 3
+--R                  - 2393547735040a b c d
+--R             *
+--R                     2
+--R                %%DM1
+--R            + 
+--R                                   13 2 3                 12 3 2
+--R                      226492416000a  b e  - 5968326819840a  b c e
+--R                    + 
+--R                                     12 3   2
+--R                      16535624089600a  b c d
+--R                 *
+--R                         2
+--R                    %%DM0
+--R                + 
+--R                            6     4              6   2 3                5 2 2 2
+--R                  997920000a b c e  - 1382400000a b d e  - 109283328000a b c d e
+--R                + 
+--R                               5 2   4                4 3 5
+--R                  100925440000a b c d  - 692936744192a b c
+--R             *
+--R                %%DM1
+--R            + 
+--R                                 9 2     2                9 2 3
+--R                  - 272498688000a b c d e  + 251658240000a b d e
+--R                + 
+--R                                  8 3 3
+--R                  - 2393547735040a b c d
+--R             *
+--R                     2
+--R                %%DM0
+--R            + 
+--R                            6     4              6   2 3                5 2 2 2
+--R                  997920000a b c e  - 1382400000a b d e  - 109283328000a b c d e
+--R                + 
+--R                               5 2   4                4 3 5
+--R                  100925440000a b c d  - 692936744192a b c
+--R             *
+--R                %%DM0
+--R            + 
+--R                           3 6             2   2 4              2     2 3
+--R                  11390625a e  - 300155625a b c e  + 3326400000a b c d e
+--R                + 
+--R                                2   4                2 4  2
+--R                  (- 2304000000a b d  - 7909434225a b c )e
+--R                + 
+--R                                2 3 2                  2 2 4                3 6
+--R                  87654336000a b c d e - 60712960000a b c d  + 208422380089b c
+--R             *
+--R                x
+--R            + 
+--R                         3   5              2   2   3              2     3 2
+--R              - 30375000a d e  - 3201660000a b c d e  - 1108800000a b c d e
+--R            + 
+--R                          2   5                 2 4                    2 3 3
+--R              (3072000000a b d  - 63275473800a b c d)e + 29218112000a b c d
+--R     + 
+--R             3 +-+ +-+4+-+3 +-+4+-+3
+--R         512a \|2 \|a \|a  \|b \|b  %%DM1
+--R      *
+--R         log
+--R                                     13 2 3                  12 3 2
+--R                      - 452984832000a  b e  + 11936653639680a  b c e
+--R                    + 
+--R                                       12 3   2
+--R                      - 33071248179200a  b c d
+--R                 *
+--R                    %%DM0
+--R                + 
+--R                               9 2     2                9 2 3
+--R                  544997376000a b c d e  - 503316480000a b d e
+--R                + 
+--R                                8 3 3
+--R                  4787095470080a b c d
+--R             *
+--R                     2
+--R                %%DM1
+--R            + 
+--R                                     13 2 3                  12 3 2
+--R                      - 452984832000a  b e  + 11936653639680a  b c e
+--R                    + 
+--R                                       12 3   2
+--R                      - 33071248179200a  b c d
+--R                 *
+--R                         2
+--R                    %%DM0
+--R                + 
+--R                               6     4              6   2 3
+--R                  - 1995840000a b c e  + 2764800000a b d e
+--R                + 
+--R                               5 2 2 2                 5 2   4
+--R                  218566656000a b c d e - 201850880000a b c d
+--R                + 
+--R                                4 3 5
+--R                  1385873488384a b c
+--R             *
+--R                %%DM1
+--R            + 
+--R                                 13 2 3                  12 3 2
+--R                  - 452984832000a  b e  + 11936653639680a  b c e
+--R                + 
+--R                                   12 3   2
+--R                  - 33071248179200a  b c d
+--R             *
+--R                     3
+--R                %%DM0
+--R            + 
+--R                               6     4              6   2 3
+--R                  - 7983360000a b c e  - 5529600000a b d e
+--R                + 
+--R                               5 2 3 2                5 2 2 2
+--R                  210370406400a b c e  - 437133312000a b c d e
+--R                + 
+--R                                 5 2   4
+--R                  - 403701760000a b c d
+--R             *
+--R                %%DM0
+--R            + 
+--R                           3 6             2   2 4              2     2 3
+--R                  11390625a e  - 300155625a b c e  + 3326400000a b c d e
+--R                + 
+--R                                2   4                2 4  2
+--R                  (- 2304000000a b d  - 7909434225a b c )e
+--R                + 
+--R                                2 3 2                  2 2 4                3 6
+--R                  87654336000a b c d e - 60712960000a b c d  + 208422380089b c
+--R             *
+--R                x
+--R            + 
+--R                         3   5              2   2   3              2     3 2
+--R              - 30375000a d e  + 6403320000a b c d e  - 3326400000a b c d e
+--R            + 
+--R                            2   5                 2 4                    2 3 3
+--R              (- 3072000000a b d  + 21091824600a b c d)e + 87654336000a b c d
+--R     + 
+--R             3 +-+ +-+4+-+3 +-+4+-+3
+--R         512a \|2 \|a \|a  \|b \|b  %%DM0
+--R      *
+--R         log
+--R                               13 2 3                  12 3 2
+--R                  452984832000a  b e  - 11936653639680a  b c e
+--R                + 
+--R                                 12 3   2
+--R                  33071248179200a  b c d
+--R             *
+--R                     3
+--R                %%DM0
+--R            + 
+--R                               9 2     2                9 2 3
+--R                  544997376000a b c d e  - 503316480000a b d e
+--R                + 
+--R                                8 3 3
+--R                  4787095470080a b c d
+--R             *
+--R                     2
+--R                %%DM0
+--R            + 
+--R                             6     4              6   2 3                5 2 3 2
+--R                  5987520000a b c e  + 8294400000a b d e  - 210370406400a b c e
+--R                + 
+--R                               5 2 2 2                 5 2   4
+--R                  655699968000a b c d e + 201850880000a b c d
+--R                + 
+--R                                4 3 5
+--R                  1385873488384a b c
+--R             *
+--R                %%DM0
+--R            + 
+--R                           3 6             2   2 4              2     2 3
+--R                  11390625a e  - 300155625a b c e  + 3326400000a b c d e
+--R                + 
+--R                                2   4                2 4  2
+--R                  (- 2304000000a b d  - 7909434225a b c )e
+--R                + 
+--R                                2 3 2                  2 2 4                3 6
+--R                  87654336000a b c d e - 60712960000a b c d  + 208422380089b c
+--R             *
+--R                x
+--R            + 
+--R                       3   5              2     3 2
+--R              91125000a d e  + 5544000000a b c d e
+--R            + 
+--R                          2   5                  2 4                     2 3 3
+--R            (- 3072000000a b d  + 105459123000a b c d)e - 146090560000a b c d
+--R     + 
+--R              +-+         +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (15a e\|b  - 77b c\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                +-+         +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- 15a e\|b  + 77b c\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R                +-+          +-+      x\|2 \|b  + \|a
+--R       (- 30a e\|b  - 154b c\|a )atan(----------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R                +-+          +-+      x\|2 \|b  - \|a
+--R       (- 30a e\|b  - 154b c\|a )atan(----------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R                                 2 +-+
+--R             +-+4+-+3 4+-+3     x \|b
+--R       - 80d\|2 \|a   \|b  atan(------)
+--R                                  +-+
+--R                                 \|a
+--R  /
+--R         3 +-+ +-+4+-+3 +-+4+-+3
+--R     512a \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  4         2  +-+4+-+2          6          4          2  +-+
+--R           ((60e x  + 308c x )\|a \|a   - 77b c x  - 30a e x  + 77a c x )\|b
+--R         + 
+--R                   6           4          2          4+-+2
+--R           (30b e x  + 154b c x  + 30a e x  + 154a c)\|a
+--R         + 
+--R                     6           4          2  +-+
+--R           (- 15b e x  - 154b c x  + 15a e x )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                   4          2         4+-+2
+--R           (77b c x  - 30a e x  - 77a c)\|a
+--R         + 
+--R                     6          4          2          +-+
+--R           (- 15b e x  - 77b c x  - 15a e x  - 77a c)\|a
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R               4           2          +-+4+-+2      2   6            4
+--R       (15b e x  - 154b c x  - 15a e)\|a \|a   + 77b c x  - 45a b e x
+--R     + 
+--R                   2      2
+--R       - 231a b c x  + 15a e
+--R  /
+--R                3   6       4 2  +-+4+-+2 +-+
+--R           (512a b x  + 512a x )\|a \|a  \|b
+--R         + 
+--R                3 2 8       4   4       5 4+-+2
+--R           (256a b x  + 512a b x  + 256a )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R             4 2 6       5   2
+--R       - 512a b x  - 512a b x
+--R                                                    Type: Expression(Integer)
+--E 753
+
+)clear all
+
+--S 754 of 953
+t0:=x^3*(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^p
+--R 
+--R
+--R            6      5      4      3     4     p
+--R   (1)  (f x  + e x  + d x  + c x )(b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 953
+--r0:=1/4*c*(a+b*x^4)^(1+p)/(b*(1+p))+d*x*(a+b*x^4)^(1+p)/(b*(5+4*p))+_
+--   1/2*e*x^2*(a+b*x^4)^(1+p)/(b*(3+2*p))+f*x^3*(a+b*x^4)^(1+p)/_
+--   (b*(7+4*p))-a*d*x*(a+b*x^4)^p*hypergeometric(1/4,-p,5/4,-b*x^4/a)/_
+--   (b*(5+4*p)*((a+b*x^4)/a)^p)-1/2*a*e*x^2*(a+b*x^4)^p*_
+--   hypergeometric(1/2,-p,3/2,-b*x^4/a)/(b*(3+2*p)*((a+b*x^4)/a)^p)-_
+--   a*f*x^3*(a+b*x^4)^p*hypergeometric(3/4,-p,7/4,-b*x^4/a)/(b*(7+4*p)*_
+--   ((a+b*x^4)/a)^p)
+--E 755
+
+--S 756 of 953
+--a0:=integrate(t0,x)
+--E 756
+
+--S 757 of 953
+--m0:=a0-r0
+--E 757
+
+--S 758 of 953
+--d0:=D(m0,x)
+--E 758
+
+)clear all
+
+--S 759 of 953
+t0:=x^3*(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^4
+--R 
+--R
+--R   (1)
+--R      4   22    4   21    4   20    4   19       3   18       3   17
+--R     b f x   + b e x   + b d x   + b c x   + 4a b f x   + 4a b e x
+--R   + 
+--R         3   16       3   15     2 2   14     2 2   13     2 2   12     2 2   11
+--R     4a b d x   + 4a b c x   + 6a b f x   + 6a b e x   + 6a b d x   + 6a b c x
+--R   + 
+--R       3     10     3     9     3     8     3     7    4   6    4   5    4   4
+--R     4a b f x   + 4a b e x  + 4a b d x  + 4a b c x  + a f x  + a e x  + a d x
+--R   + 
+--R      4   3
+--R     a c x
+--R                                                    Type: Polynomial(Integer)
+--E 759
+
+--S 760 of 953
+r0:=1/5*a^4*d*x^5+1/6*a^4*e*x^6+1/7*a^4*f*x^7+4/9*a^3*b*d*x^9+2/5*a^3*_
+   b*e*x^10+4/11*a^3*b*f*x^11+6/13*a^2*b^2*d*x^13+3/7*a^2*b^2*e*x^14+_
+   2/5*a^2*b^2*f*x^15+4/17*a*b^3*d*x^17+2/9*a*b^3*e*x^18+4/19*a*b^3*_
+   f*x^19+1/21*b^4*d*x^21+1/22*b^4*e*x^22+1/23*b^4*f*x^23+1/20*c*(a+b*x^4)^5/b
+--R 
+--R
+--R   (2)
+--R        1  5   23    1  5   22    1  5   21    1  5   20    4    4   19
+--R       -- b f x   + -- b e x   + -- b d x   + -- b c x   + -- a b f x
+--R       23           22           21           20           19
+--R     + 
+--R       2    4   18    4    4   17   1    4   16   2  2 3   15   3  2 3   14
+--R       - a b e x   + -- a b d x   + - a b c x   + - a b f x   + - a b e x
+--R       9             17             4             5             7
+--R     + 
+--R        6  2 3   13   1  2 3   12    4  3 2   11   2  3 2   10   4  3 2   9
+--R       -- a b d x   + - a b c x   + -- a b f x   + - a b e x   + - a b d x
+--R       13             2             11             5             9
+--R     + 
+--R       1  3 2   8   1  4     7   1  4     6   1  4     5   1  4     4    1  5
+--R       - a b c x  + - a b f x  + - a b e x  + - a b d x  + - a b c x  + -- a c
+--R       2            7            6            5            4            20
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 760
+
+--S 761 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  4   23    1  4   22    1  4   21    1  4   20    4    3   19
+--R     -- b f x   + -- b e x   + -- b d x   + -- b c x   + -- a b f x
+--R     23           22           21           20           19
+--R   + 
+--R     2    3   18    4    3   17   1    3   16   2  2 2   15   3  2 2   14
+--R     - a b e x   + -- a b d x   + - a b c x   + - a b f x   + - a b e x
+--R     9             17             4             5             7
+--R   + 
+--R      6  2 2   13   1  2 2   12    4  3     11   2  3     10   4  3     9
+--R     -- a b d x   + - a b c x   + -- a b f x   + - a b e x   + - a b d x
+--R     13             2             11             5             9
+--R   + 
+--R     1  3     8   1  4   7   1  4   6   1  4   5   1  4   4
+--R     - a b c x  + - a f x  + - a e x  + - a d x  + - a c x
+--R     2            7          6          5          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 761
+
+--S 762 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1  5
+--R          -- a c
+--R          20
+--R   (4)  - ------
+--R             b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 762
+
+--S 763 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 763
+
+)clear all
+
+--S 764 of 953
+t0:=x^3*(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3   18    3   17    3   16    3   15       2   14       2   13
+--R     b f x   + b e x   + b d x   + b c x   + 3a b f x   + 3a b e x
+--R   + 
+--R         2   12       2   11     2     10     2     9     2     8     2     7
+--R     3a b d x   + 3a b c x   + 3a b f x   + 3a b e x  + 3a b d x  + 3a b c x
+--R   + 
+--R      3   6    3   5    3   4    3   3
+--R     a f x  + a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 764
+
+--S 765 of 953
+r0:=1/5*a^3*d*x^5+1/6*a^3*e*x^6+1/7*a^3*f*x^7+1/3*a^2*b*d*x^9+3/10*a^2*b*_
+   e*x^10+3/11*a^2*b*f*x^11+3/13*a*b^2*d*x^13+3/14*a*b^2*e*x^14+_
+   1/5*a*b^2*f*x^15+1/17*b^3*d*x^17+1/18*b^3*e*x^18+1/19*b^3*f*x^19+_
+   1/16*c*(a+b*x^4)^4/b
+--R 
+--R
+--R   (2)
+--R        1  4   19    1  4   18    1  4   17    1  4   16   1    3   15
+--R       -- b f x   + -- b e x   + -- b d x   + -- b c x   + - a b f x
+--R       19           18           17           16           5
+--R     + 
+--R        3    3   14    3    3   13   1    3   12    3  2 2   11    3  2 2   10
+--R       -- a b e x   + -- a b d x   + - a b c x   + -- a b f x   + -- a b e x
+--R       14             13             4             11             10
+--R     + 
+--R       1  2 2   9   3  2 2   8   1  3     7   1  3     6   1  3     5
+--R       - a b d x  + - a b c x  + - a b f x  + - a b e x  + - a b d x
+--R       3            8            7            6            5
+--R     + 
+--R       1  3     4    1  4
+--R       - a b c x  + -- a c
+--R       4            16
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 765
+
+--S 766 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  3   19    1  3   18    1  3   17    1  3   16   1    2   15
+--R     -- b f x   + -- b e x   + -- b d x   + -- b c x   + - a b f x
+--R     19           18           17           16           5
+--R   + 
+--R      3    2   14    3    2   13   1    2   12    3  2     11    3  2     10
+--R     -- a b e x   + -- a b d x   + - a b c x   + -- a b f x   + -- a b e x
+--R     14             13             4             11             10
+--R   + 
+--R     1  2     9   3  2     8   1  3   7   1  3   6   1  3   5   1  3   4
+--R     - a b d x  + - a b c x  + - a f x  + - a e x  + - a d x  + - a c x
+--R     3            8            7          6          5          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 766
+
+--S 767 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1  4
+--R          -- a c
+--R          16
+--R   (4)  - ------
+--R             b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 767
+
+--S 768 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 768
+
+)clear all
+
+--S 769 of 953
+t0:=x^3*(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^2
+--R 
+--R
+--R   (1)
+--R      2   14    2   13    2   12    2   11           10           9           8
+--R     b f x   + b e x   + b d x   + b c x   + 2a b f x   + 2a b e x  + 2a b d x
+--R   + 
+--R             7    2   6    2   5    2   4    2   3
+--R     2a b c x  + a f x  + a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 769
+
+--S 770 of 953
+r0:=1/5*a^2*d*x^5+1/6*a^2*e*x^6+1/7*a^2*f*x^7+2/9*a*b*d*x^9+1/5*a*b*_
+   e*x^10+2/11*a*b*f*x^11+1/13*b^2*d*x^13+1/14*b^2*e*x^14+1/15*b^2*_
+   f*x^15+1/12*c*(a+b*x^4)^3/b
+--R 
+--R
+--R   (2)
+--R        1  3   15    1  3   14    1  3   13    1  3   12    2    2   11
+--R       -- b f x   + -- b e x   + -- b d x   + -- b c x   + -- a b f x
+--R       15           14           13           12           11
+--R     + 
+--R       1    2   10   2    2   9   1    2   8   1  2     7   1  2     6
+--R       - a b e x   + - a b d x  + - a b c x  + - a b f x  + - a b e x
+--R       5             9            4            7            6
+--R     + 
+--R       1  2     5   1  2     4    1  3
+--R       - a b d x  + - a b c x  + -- a c
+--R       5            4            12
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 770
+
+--S 771 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1  2   15    1  2   14    1  2   13    1  2   12    2        11
+--R     -- b f x   + -- b e x   + -- b d x   + -- b c x   + -- a b f x
+--R     15           14           13           12           11
+--R   + 
+--R     1        10   2        9   1        8   1  2   7   1  2   6   1  2   5
+--R     - a b e x   + - a b d x  + - a b c x  + - a f x  + - a e x  + - a d x
+--R     5             9            4            7          6          5
+--R   + 
+--R     1  2   4
+--R     - a c x
+--R     4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 771
+
+--S 772 of 953
+m0:=a0-r0
+--R 
+--R
+--R           1  3
+--R          -- a c
+--R          12
+--R   (4)  - ------
+--R             b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 772
+
+--S 773 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 773
+
+)clear all
+
+--S 774 of 953
+t0:=x^3*(c+d*x+e*x^2+f*x^3)*(a+b*x^4)
+--R 
+--R
+--R             10        9        8        7        6        5        4        3
+--R   (1)  b f x   + b e x  + b d x  + b c x  + a f x  + a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 774
+
+--S 775 of 953
+r0:=1/4*a*c*x^4+1/5*a*d*x^5+1/6*a*e*x^6+1/7*a*f*x^7+1/8*b*c*x^8+1/9*b*_
+   d*x^9+1/10*b*e*x^10+1/11*b*f*x^11
+--R 
+--R
+--R   (2)
+--R      1      11    1      10   1      9   1      8   1      7   1      6
+--R     -- b f x   + -- b e x   + - b d x  + - b c x  + - a f x  + - a e x
+--R     11           10           9          8          7          6
+--R   + 
+--R     1      5   1      4
+--R     - a d x  + - a c x
+--R     5          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 775
+
+--S 776 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      1      11    1      10   1      9   1      8   1      7   1      6
+--R     -- b f x   + -- b e x   + - b d x  + - b c x  + - a f x  + - a e x
+--R     11           10           9          8          7          6
+--R   + 
+--R     1      5   1      4
+--R     - a d x  + - a c x
+--R     5          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 776
+
+--S 777 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 777
+
+--S 778 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 778
+
+)clear all
+
+--S 779 of 953
+t0:=x^3*(c+d*x+e*x^2+f*x^3)/(a+b*x^4)
+--R 
+--R
+--R           6      5      4      3
+--R        f x  + e x  + d x  + c x
+--R   (1)  -------------------------
+--R                    4
+--R                 b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 779
+
+--S 780 of 953
+r0:=d*x/b+1/2*e*x^2/b+1/3*f*x^3/b+1/4*c*log(a+b*x^4)/b-1/2*e*atan(x^2*_
+   sqrt(b)/sqrt(a))*sqrt(a)/b^(3/2)+1/4*a^(1/4)*log(-a^(1/4)*b^(1/4)*_
+   x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-f*sqrt(a)+d*sqrt(b))/(b^(7/4)*_
+   sqrt(2))-1/4*a^(1/4)*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*_
+   sqrt(b))*(-f*sqrt(a)+d*sqrt(b))/(b^(7/4)*sqrt(2))+1/2*a^(1/4)*_
+   atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(f*sqrt(a)+d*sqrt(b))/(b^(7/4)*_
+   sqrt(2))-1/2*a^(1/4)*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(f*sqrt(a)+_
+   d*sqrt(b))/(b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R           +-+4+-+ +-+       4+-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (3f\|a \|a \|b  - 3b d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R             +-+4+-+ +-+       4+-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3f\|a \|a \|b  + 3b d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                           +-+4+-+   4+-+
+--R             +-+4+-+ +-+       4+-+      x\|2 \|b  + \|a
+--R       (- 6f\|a \|a \|b  - 6b d\|a )atan(----------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R                                           +-+4+-+   4+-+
+--R             +-+4+-+ +-+       4+-+      x\|2 \|b  - \|a
+--R       (- 6f\|a \|a \|b  - 6b d\|a )atan(----------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R                              2 +-+
+--R            +-+ +-+4+-+3     x \|b
+--R       - 6e\|2 \|a \|b  atan(------)
+--R                               +-+
+--R                              \|a
+--R     + 
+--R           +-+       4             3       2          +-+  +-+4+-+3
+--R       (3c\|2 log(b x  + a) + (4f x  + 6e x  + 12d x)\|2 )\|b \|b
+--R  /
+--R         +-+ +-+4+-+3
+--R     12b\|2 \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 780
+
+--S 781 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           -
+--R                3b
+--R             *
+--R                ROOT
+--R                           3     2        3          2            3     2
+--R                       - 6b %%DN1  + (- 4b %%DN0 + 4b c)%%DN1 - 6b %%DN0
+--R                     + 
+--R                         2                      2      2
+--R                       4b c %%DN0 - 2a d f - a e  - b c
+--R                  /
+--R                       3
+--R                     2b
+--R         + 
+--R           - 3b %%DN1 - 3b %%DN0 + 3c
+--R      *
+--R         log
+--R                            5 3      6 2       6   2             4   3
+--R                      (32a b f  - 32b d f + 64b d e )%%DN0 - 8a b c f
+--R                    + 
+--R                         4     2           4 3     5   2        5     2     5 3
+--R                    24a b d e f  + (- 16a b e  + 8b c d )f - 16b c d e  + 8b d e
+--R                 *
+--R                    %%DN1
+--R                + 
+--R                            4   3        4     2           4 3     5   2
+--R                      - 8a b c f  + 24a b d e f  + (- 16a b e  + 8b c d )f
+--R                    + 
+--R                           5     2     5 3
+--R                      - 16b c d e  + 8b d e
+--R                 *
+--R                    %%DN0
+--R                + 
+--R                      2 2   4      2 2 2       3 2  3        3       2
+--R                  - 2a b d f  + (2a b e  + 2a b c )f  - 12a b c d e f
+--R                + 
+--R                       3   3       3 2 2     4 2 2         3   4     4 2   2
+--R                  (8a b c e  + 6a b d e  - 2b c d )f - 4a b d e  + 4b c d e
+--R                + 
+--R                      4   3      4 5
+--R                  - 4b c d e + 2b d
+--R             *
+--R                ROOT
+--R                           3     2        3          2            3     2
+--R                       - 6b %%DN1  + (- 4b %%DN0 + 4b c)%%DN1 - 6b %%DN0
+--R                     + 
+--R                         2                      2      2
+--R                       4b c %%DN0 - 2a d f - a e  - b c
+--R                  /
+--R                       3
+--R                     2b
+--R            + 
+--R                          5 3      6 2       6   2             4   3
+--R                  (- 32a b f  + 32b d f - 64b d e )%%DN0 + 8a b c f
+--R                + 
+--R                         4     2         4 3     5   2        5     2     5 3
+--R                  - 24a b d e f  + (16a b e  - 8b c d )f + 16b c d e  - 8b d e
+--R             *
+--R                     2
+--R                %%DN1
+--R            + 
+--R                          5 3      6 2       6   2      2
+--R                  (- 32a b f  + 32b d f - 64b d e )%%DN0
+--R                + 
+--R                        4   3      5   2       5     2           2 2   4
+--R                  (32a b c f  - 32b c d f + 64b c d e )%%DN0 - 2a b d f
+--R                + 
+--R                     2 2 2       3 2  3        3       2
+--R                  (2a b e  - 6a b c )f  + 12a b c d e f
+--R                + 
+--R                         3   3       3 2 2     4 2 2         3   4      4 2   2
+--R                  (- 8a b c e  + 6a b d e  + 6b c d )f - 4a b d e  - 12b c d e
+--R                + 
+--R                    4   3      4 5
+--R                  4b c d e + 2b d
+--R             *
+--R                %%DN1
+--R            + 
+--R                      4   3        4     2         4 3     5   2        5     2
+--R                  8a b c f  - 24a b d e f  + (16a b e  - 8b c d )f + 16b c d e
+--R                + 
+--R                      5 3
+--R                  - 8b d e
+--R             *
+--R                     2
+--R                %%DN0
+--R            + 
+--R                      2 2   4      2 2 2       3 2  3        3       2
+--R                  - 2a b d f  + (2a b e  - 6a b c )f  + 12a b c d e f
+--R                + 
+--R                         3   3       3 2 2     4 2 2         3   4      4 2   2
+--R                  (- 8a b c e  + 6a b d e  + 6b c d )f - 4a b d e  - 12b c d e
+--R                + 
+--R                    4   3      4 5
+--R                  4b c d e + 2b d
+--R             *
+--R                %%DN0
+--R            + 
+--R                   3 6    2   2 4     2     2 3        2   4      2 4  2
+--R                  a f  - a b d f  + 8a b d e f  + (- 4a b e  - a b d )f
+--R                + 
+--R                      2 3 2        2 2 4    3 6
+--R                  8a b d e f - 4a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                 3   5    2       4       2     2     2   2       2 3  3
+--R              - a e f  + a b c d f  + (- a b c e  - 4a b d e + a b c )f
+--R            + 
+--R                  2     3       2 2     2
+--R              (- a b d e  - 3a b c d e)f
+--R            + 
+--R                 2   5       2 2 3       2   2 2       2 4     3 3 2
+--R              (2a b e  + 2a b c e  - 3a b c d e  - 3a b d e - b c d )f
+--R            + 
+--R                  2     4      2 3 3     3 3   2    3 2 3     3   5
+--R              2a b c d e  + a b d e  + 2b c d e  - b c d e - b c d
+--R     + 
+--R             3b
+--R          *
+--R             ROOT
+--R                        3     2        3          2            3     2
+--R                    - 6b %%DN1  + (- 4b %%DN0 + 4b c)%%DN1 - 6b %%DN0
+--R                  + 
+--R                      2                      2      2
+--R                    4b c %%DN0 - 2a d f - a e  - b c
+--R               /
+--R                    3
+--R                  2b
+--R         + 
+--R           - 3b %%DN1 - 3b %%DN0 + 3c
+--R      *
+--R         log
+--R                              5 3      6 2       6   2             4   3
+--R                      (- 32a b f  + 32b d f - 64b d e )%%DN0 + 8a b c f
+--R                    + 
+--R                           4     2         4 3     5   2        5     2     5 3
+--R                    - 24a b d e f  + (16a b e  - 8b c d )f + 16b c d e  - 8b d e
+--R                 *
+--R                    %%DN1
+--R                + 
+--R                          4   3        4     2         4 3     5   2
+--R                      8a b c f  - 24a b d e f  + (16a b e  - 8b c d )f
+--R                    + 
+--R                         5     2     5 3
+--R                      16b c d e  - 8b d e
+--R                 *
+--R                    %%DN0
+--R                + 
+--R                    2 2   4        2 2 2       3 2  3        3       2
+--R                  2a b d f  + (- 2a b e  - 2a b c )f  + 12a b c d e f
+--R                + 
+--R                         3   3       3 2 2     4 2 2         3   4     4 2   2
+--R                  (- 8a b c e  - 6a b d e  + 2b c d )f + 4a b d e  - 4b c d e
+--R                + 
+--R                    4   3      4 5
+--R                  4b c d e - 2b d
+--R             *
+--R                ROOT
+--R                           3     2        3          2            3     2
+--R                       - 6b %%DN1  + (- 4b %%DN0 + 4b c)%%DN1 - 6b %%DN0
+--R                     + 
+--R                         2                      2      2
+--R                       4b c %%DN0 - 2a d f - a e  - b c
+--R                  /
+--R                       3
+--R                     2b
+--R            + 
+--R                          5 3      6 2       6   2             4   3
+--R                  (- 32a b f  + 32b d f - 64b d e )%%DN0 + 8a b c f
+--R                + 
+--R                         4     2         4 3     5   2        5     2     5 3
+--R                  - 24a b d e f  + (16a b e  - 8b c d )f + 16b c d e  - 8b d e
+--R             *
+--R                     2
+--R                %%DN1
+--R            + 
+--R                          5 3      6 2       6   2      2
+--R                  (- 32a b f  + 32b d f - 64b d e )%%DN0
+--R                + 
+--R                        4   3      5   2       5     2           2 2   4
+--R                  (32a b c f  - 32b c d f + 64b c d e )%%DN0 - 2a b d f
+--R                + 
+--R                     2 2 2       3 2  3        3       2
+--R                  (2a b e  - 6a b c )f  + 12a b c d e f
+--R                + 
+--R                         3   3       3 2 2     4 2 2         3   4      4 2   2
+--R                  (- 8a b c e  + 6a b d e  + 6b c d )f - 4a b d e  - 12b c d e
+--R                + 
+--R                    4   3      4 5
+--R                  4b c d e + 2b d
+--R             *
+--R                %%DN1
+--R            + 
+--R                      4   3        4     2         4 3     5   2        5     2
+--R                  8a b c f  - 24a b d e f  + (16a b e  - 8b c d )f + 16b c d e
+--R                + 
+--R                      5 3
+--R                  - 8b d e
+--R             *
+--R                     2
+--R                %%DN0
+--R            + 
+--R                      2 2   4      2 2 2       3 2  3        3       2
+--R                  - 2a b d f  + (2a b e  - 6a b c )f  + 12a b c d e f
+--R                + 
+--R                         3   3       3 2 2     4 2 2         3   4      4 2   2
+--R                  (- 8a b c e  + 6a b d e  + 6b c d )f - 4a b d e  - 12b c d e
+--R                + 
+--R                    4   3      4 5
+--R                  4b c d e + 2b d
+--R             *
+--R                %%DN0
+--R            + 
+--R                   3 6    2   2 4     2     2 3        2   4      2 4  2
+--R                  a f  - a b d f  + 8a b d e f  + (- 4a b e  - a b d )f
+--R                + 
+--R                      2 3 2        2 2 4    3 6
+--R                  8a b d e f - 4a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                 3   5    2       4       2     2     2   2       2 3  3
+--R              - a e f  + a b c d f  + (- a b c e  - 4a b d e + a b c )f
+--R            + 
+--R                  2     3       2 2     2
+--R              (- a b d e  - 3a b c d e)f
+--R            + 
+--R                 2   5       2 2 3       2   2 2       2 4     3 3 2
+--R              (2a b e  + 2a b c e  - 3a b c d e  - 3a b d e - b c d )f
+--R            + 
+--R                  2     4      2 3 3     3 3   2    3 2 3     3   5
+--R              2a b c d e  + a b d e  + 2b c d e  - b c d e - b c d
+--R     + 
+--R         6b %%DN1
+--R      *
+--R         log
+--R                        5 3      6 2        6   2              4   3
+--R                  (64a b f  - 64b d f + 128b d e )%%DN0 - 16a b c f
+--R                + 
+--R                     4     2           4 3      5   2        5     2      5 3
+--R                48a b d e f  + (- 32a b e  + 16b c d )f - 32b c d e  + 16b d e
+--R             *
+--R                     2
+--R                %%DN1
+--R            + 
+--R                        5 3      6 2        6   2      2
+--R                  (64a b f  - 64b d f + 128b d e )%%DN0
+--R                + 
+--R                          4   3      5   2        5     2           2 2   4
+--R                  (- 64a b c f  + 64b c d f - 128b c d e )%%DN0 + 4a b d f
+--R                + 
+--R                       2 2 2        3 2  3        3       2
+--R                  (- 4a b e  + 12a b c )f  - 24a b c d e f
+--R                + 
+--R                        3   3        3 2 2      4 2 2         3   4      4 2   2
+--R                  (16a b c e  - 12a b d e  - 12b c d )f + 8a b d e  + 24b c d e
+--R                + 
+--R                      4   3      4 5
+--R                  - 8b c d e - 4b d
+--R             *
+--R                %%DN1
+--R            + 
+--R                    5 3      6 2        6   2      3
+--R              (64a b f  - 64b d f + 128b d e )%%DN0
+--R            + 
+--R                      4   3      5   2        5     2      2
+--R              (- 64a b c f  + 64b c d f - 128b c d e )%%DN0
+--R            + 
+--R                     2 2   4      2 2 2        3 2  3        3 3 2
+--R                  16a b d f  + (8a b e  + 24a b c )f  - 16a b d f
+--R                + 
+--R                        3 2 2      4 2 2          3   4      4 2   2
+--R                  (24a b d e  - 24b c d )f + 16a b d e  + 48b c d e
+--R             *
+--R                %%DN0
+--R            + 
+--R                   3 6    2   2 4     2     2 3        2   4      2 4  2
+--R                  a f  - a b d f  + 8a b d e f  + (- 4a b e  - a b d )f
+--R                + 
+--R                      2 3 2        2 2 4    3 6
+--R                  8a b d e f - 4a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                 3   5     2       4       2     2     2   2        2 3  3
+--R              - a e f  - 5a b c d f  + (- a b c e  + 8a b d e - 3a b c )f
+--R            + 
+--R                   2     3       2 2          2   3  2
+--R              (- 3a b d e  + 3a b c d e + 4a b c d )f
+--R            + 
+--R                   2   5       2 2 3       2   2 2      2 4      3 3 2
+--R              (- 2a b e  - 2a b c e  - 3a b c d e  + a b d e + 3b c d )f
+--R            + 
+--R                    2     4       2 3 3     3 3   2    3 2 3     3   5
+--R              - 6a b c d e  + 3a b d e  - 6b c d e  + b c d e + b c d
+--R     + 
+--R         6b %%DN0
+--R      *
+--R         log
+--R                      5 3      6 2        6   2      3
+--R              (- 64a b f  + 64b d f - 128b d e )%%DN0
+--R            + 
+--R                       4   3        4     2           4 3      5   2
+--R                  48a b c f  + 48a b d e f  + (- 32a b e  - 48b c d )f
+--R                + 
+--R                     5     2      5 3
+--R                  96b c d e  + 16b d e
+--R             *
+--R                     2
+--R                %%DN0
+--R            + 
+--R                       2 2   4         2 2 2        3 2  3
+--R                  - 12a b d f  + (- 12a b e  - 12a b c )f
+--R                + 
+--R                          3             3 3  2
+--R                  (- 24a b c d e + 16a b d )f
+--R                + 
+--R                        3   3        3 2 2      4 2 2         3   4      4 2   2
+--R                  (16a b c e  - 36a b d e  + 12b c d )f - 8a b d e  - 24b c d e
+--R                + 
+--R                      4   3      4 5
+--R                  - 8b c d e - 4b d
+--R             *
+--R                %%DN0
+--R            + 
+--R                   3 6    2   2 4     2     2 3        2   4      2 4  2
+--R                  a f  - a b d f  + 8a b d e f  + (- 4a b e  - a b d )f
+--R                + 
+--R                      2 3 2        2 2 4    3 6
+--R                  8a b d e f - 4a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                3   5     2       4      2     2      2 3  3
+--R              3a e f  + 3a b c d f  + (3a b c e  + a b c )f
+--R            + 
+--R                 2     3       2 2          2   3  2
+--R              (5a b d e  + 3a b c d e - 4a b c d )f
+--R            + 
+--R                   2   5       2 2 3       2   2 2       2 4     3 3 2
+--R              (- 2a b e  - 2a b c e  + 9a b c d e  + 5a b d e - b c d )f
+--R            + 
+--R                  2     4       2 3 3     3 3   2    3 2 3     3   5
+--R              2a b c d e  - 5a b d e  + 2b c d e  + b c d e + b c d
+--R     + 
+--R           3       2
+--R       2f x  + 3e x  + 6d x
+--R  /
+--R     6b
+--R                                         Type: Union(Expression(Integer),...)
+--E 781
+
+--S 782 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           -
+--R                   +-+ +-+4+-+3
+--R                2b\|2 \|b \|b
+--R             *
+--R                ROOT
+--R                           3     2        3          2            3     2
+--R                       - 6b %%DN1  + (- 4b %%DN0 + 4b c)%%DN1 - 6b %%DN0
+--R                     + 
+--R                         2                      2      2
+--R                       4b c %%DN0 - 2a d f - a e  - b c
+--R                  /
+--R                       3
+--R                     2b
+--R         + 
+--R                +-+ +-+4+-+3           +-+ +-+4+-+3           +-+ +-+4+-+3
+--R           - 2b\|2 \|b \|b  %%DN1 - 2b\|2 \|b \|b  %%DN0 + 2c\|2 \|b \|b
+--R      *
+--R         log
+--R                            5 3      6 2       6   2             4   3
+--R                      (32a b f  - 32b d f + 64b d e )%%DN0 - 8a b c f
+--R                    + 
+--R                         4     2           4 3     5   2        5     2     5 3
+--R                    24a b d e f  + (- 16a b e  + 8b c d )f - 16b c d e  + 8b d e
+--R                 *
+--R                    %%DN1
+--R                + 
+--R                            4   3        4     2           4 3     5   2
+--R                      - 8a b c f  + 24a b d e f  + (- 16a b e  + 8b c d )f
+--R                    + 
+--R                           5     2     5 3
+--R                      - 16b c d e  + 8b d e
+--R                 *
+--R                    %%DN0
+--R                + 
+--R                      2 2   4      2 2 2       3 2  3        3       2
+--R                  - 2a b d f  + (2a b e  + 2a b c )f  - 12a b c d e f
+--R                + 
+--R                       3   3       3 2 2     4 2 2         3   4     4 2   2
+--R                  (8a b c e  + 6a b d e  - 2b c d )f - 4a b d e  + 4b c d e
+--R                + 
+--R                      4   3      4 5
+--R                  - 4b c d e + 2b d
+--R             *
+--R                ROOT
+--R                           3     2        3          2            3     2
+--R                       - 6b %%DN1  + (- 4b %%DN0 + 4b c)%%DN1 - 6b %%DN0
+--R                     + 
+--R                         2                      2      2
+--R                       4b c %%DN0 - 2a d f - a e  - b c
+--R                  /
+--R                       3
+--R                     2b
+--R            + 
+--R                          5 3      6 2       6   2             4   3
+--R                  (- 32a b f  + 32b d f - 64b d e )%%DN0 + 8a b c f
+--R                + 
+--R                         4     2         4 3     5   2        5     2     5 3
+--R                  - 24a b d e f  + (16a b e  - 8b c d )f + 16b c d e  - 8b d e
+--R             *
+--R                     2
+--R                %%DN1
+--R            + 
+--R                          5 3      6 2       6   2      2
+--R                  (- 32a b f  + 32b d f - 64b d e )%%DN0
+--R                + 
+--R                        4   3      5   2       5     2           2 2   4
+--R                  (32a b c f  - 32b c d f + 64b c d e )%%DN0 - 2a b d f
+--R                + 
+--R                     2 2 2       3 2  3        3       2
+--R                  (2a b e  - 6a b c )f  + 12a b c d e f
+--R                + 
+--R                         3   3       3 2 2     4 2 2         3   4      4 2   2
+--R                  (- 8a b c e  + 6a b d e  + 6b c d )f - 4a b d e  - 12b c d e
+--R                + 
+--R                    4   3      4 5
+--R                  4b c d e + 2b d
+--R             *
+--R                %%DN1
+--R            + 
+--R                      4   3        4     2         4 3     5   2        5     2
+--R                  8a b c f  - 24a b d e f  + (16a b e  - 8b c d )f + 16b c d e
+--R                + 
+--R                      5 3
+--R                  - 8b d e
+--R             *
+--R                     2
+--R                %%DN0
+--R            + 
+--R                      2 2   4      2 2 2       3 2  3        3       2
+--R                  - 2a b d f  + (2a b e  - 6a b c )f  + 12a b c d e f
+--R                + 
+--R                         3   3       3 2 2     4 2 2         3   4      4 2   2
+--R                  (- 8a b c e  + 6a b d e  + 6b c d )f - 4a b d e  - 12b c d e
+--R                + 
+--R                    4   3      4 5
+--R                  4b c d e + 2b d
+--R             *
+--R                %%DN0
+--R            + 
+--R                   3 6    2   2 4     2     2 3        2   4      2 4  2
+--R                  a f  - a b d f  + 8a b d e f  + (- 4a b e  - a b d )f
+--R                + 
+--R                      2 3 2        2 2 4    3 6
+--R                  8a b d e f - 4a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                 3   5    2       4       2     2     2   2       2 3  3
+--R              - a e f  + a b c d f  + (- a b c e  - 4a b d e + a b c )f
+--R            + 
+--R                  2     3       2 2     2
+--R              (- a b d e  - 3a b c d e)f
+--R            + 
+--R                 2   5       2 2 3       2   2 2       2 4     3 3 2
+--R              (2a b e  + 2a b c e  - 3a b c d e  - 3a b d e - b c d )f
+--R            + 
+--R                  2     4      2 3 3     3 3   2    3 2 3     3   5
+--R              2a b c d e  + a b d e  + 2b c d e  - b c d e - b c d
+--R     + 
+--R                +-+ +-+4+-+3
+--R             2b\|2 \|b \|b
+--R          *
+--R             ROOT
+--R                        3     2        3          2            3     2
+--R                    - 6b %%DN1  + (- 4b %%DN0 + 4b c)%%DN1 - 6b %%DN0
+--R                  + 
+--R                      2                      2      2
+--R                    4b c %%DN0 - 2a d f - a e  - b c
+--R               /
+--R                    3
+--R                  2b
+--R         + 
+--R                +-+ +-+4+-+3           +-+ +-+4+-+3           +-+ +-+4+-+3
+--R           - 2b\|2 \|b \|b  %%DN1 - 2b\|2 \|b \|b  %%DN0 + 2c\|2 \|b \|b
+--R      *
+--R         log
+--R                              5 3      6 2       6   2             4   3
+--R                      (- 32a b f  + 32b d f - 64b d e )%%DN0 + 8a b c f
+--R                    + 
+--R                           4     2         4 3     5   2        5     2     5 3
+--R                    - 24a b d e f  + (16a b e  - 8b c d )f + 16b c d e  - 8b d e
+--R                 *
+--R                    %%DN1
+--R                + 
+--R                          4   3        4     2         4 3     5   2
+--R                      8a b c f  - 24a b d e f  + (16a b e  - 8b c d )f
+--R                    + 
+--R                         5     2     5 3
+--R                      16b c d e  - 8b d e
+--R                 *
+--R                    %%DN0
+--R                + 
+--R                    2 2   4        2 2 2       3 2  3        3       2
+--R                  2a b d f  + (- 2a b e  - 2a b c )f  + 12a b c d e f
+--R                + 
+--R                         3   3       3 2 2     4 2 2         3   4     4 2   2
+--R                  (- 8a b c e  - 6a b d e  + 2b c d )f + 4a b d e  - 4b c d e
+--R                + 
+--R                    4   3      4 5
+--R                  4b c d e - 2b d
+--R             *
+--R                ROOT
+--R                           3     2        3          2            3     2
+--R                       - 6b %%DN1  + (- 4b %%DN0 + 4b c)%%DN1 - 6b %%DN0
+--R                     + 
+--R                         2                      2      2
+--R                       4b c %%DN0 - 2a d f - a e  - b c
+--R                  /
+--R                       3
+--R                     2b
+--R            + 
+--R                          5 3      6 2       6   2             4   3
+--R                  (- 32a b f  + 32b d f - 64b d e )%%DN0 + 8a b c f
+--R                + 
+--R                         4     2         4 3     5   2        5     2     5 3
+--R                  - 24a b d e f  + (16a b e  - 8b c d )f + 16b c d e  - 8b d e
+--R             *
+--R                     2
+--R                %%DN1
+--R            + 
+--R                          5 3      6 2       6   2      2
+--R                  (- 32a b f  + 32b d f - 64b d e )%%DN0
+--R                + 
+--R                        4   3      5   2       5     2           2 2   4
+--R                  (32a b c f  - 32b c d f + 64b c d e )%%DN0 - 2a b d f
+--R                + 
+--R                     2 2 2       3 2  3        3       2
+--R                  (2a b e  - 6a b c )f  + 12a b c d e f
+--R                + 
+--R                         3   3       3 2 2     4 2 2         3   4      4 2   2
+--R                  (- 8a b c e  + 6a b d e  + 6b c d )f - 4a b d e  - 12b c d e
+--R                + 
+--R                    4   3      4 5
+--R                  4b c d e + 2b d
+--R             *
+--R                %%DN1
+--R            + 
+--R                      4   3        4     2         4 3     5   2        5     2
+--R                  8a b c f  - 24a b d e f  + (16a b e  - 8b c d )f + 16b c d e
+--R                + 
+--R                      5 3
+--R                  - 8b d e
+--R             *
+--R                     2
+--R                %%DN0
+--R            + 
+--R                      2 2   4      2 2 2       3 2  3        3       2
+--R                  - 2a b d f  + (2a b e  - 6a b c )f  + 12a b c d e f
+--R                + 
+--R                         3   3       3 2 2     4 2 2         3   4      4 2   2
+--R                  (- 8a b c e  + 6a b d e  + 6b c d )f - 4a b d e  - 12b c d e
+--R                + 
+--R                    4   3      4 5
+--R                  4b c d e + 2b d
+--R             *
+--R                %%DN0
+--R            + 
+--R                   3 6    2   2 4     2     2 3        2   4      2 4  2
+--R                  a f  - a b d f  + 8a b d e f  + (- 4a b e  - a b d )f
+--R                + 
+--R                      2 3 2        2 2 4    3 6
+--R                  8a b d e f - 4a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                 3   5    2       4       2     2     2   2       2 3  3
+--R              - a e f  + a b c d f  + (- a b c e  - 4a b d e + a b c )f
+--R            + 
+--R                  2     3       2 2     2
+--R              (- a b d e  - 3a b c d e)f
+--R            + 
+--R                 2   5       2 2 3       2   2 2       2 4     3 3 2
+--R              (2a b e  + 2a b c e  - 3a b c d e  - 3a b d e - b c d )f
+--R            + 
+--R                  2     4      2 3 3     3 3   2    3 2 3     3   5
+--R              2a b c d e  + a b d e  + 2b c d e  - b c d e - b c d
+--R     + 
+--R            +-+ +-+4+-+3
+--R         4b\|2 \|b \|b  %%DN1
+--R      *
+--R         log
+--R                        5 3      6 2        6   2              4   3
+--R                  (64a b f  - 64b d f + 128b d e )%%DN0 - 16a b c f
+--R                + 
+--R                     4     2           4 3      5   2        5     2      5 3
+--R                48a b d e f  + (- 32a b e  + 16b c d )f - 32b c d e  + 16b d e
+--R             *
+--R                     2
+--R                %%DN1
+--R            + 
+--R                        5 3      6 2        6   2      2
+--R                  (64a b f  - 64b d f + 128b d e )%%DN0
+--R                + 
+--R                          4   3      5   2        5     2           2 2   4
+--R                  (- 64a b c f  + 64b c d f - 128b c d e )%%DN0 + 4a b d f
+--R                + 
+--R                       2 2 2        3 2  3        3       2
+--R                  (- 4a b e  + 12a b c )f  - 24a b c d e f
+--R                + 
+--R                        3   3        3 2 2      4 2 2         3   4      4 2   2
+--R                  (16a b c e  - 12a b d e  - 12b c d )f + 8a b d e  + 24b c d e
+--R                + 
+--R                      4   3      4 5
+--R                  - 8b c d e - 4b d
+--R             *
+--R                %%DN1
+--R            + 
+--R                    5 3      6 2        6   2      3
+--R              (64a b f  - 64b d f + 128b d e )%%DN0
+--R            + 
+--R                      4   3      5   2        5     2      2
+--R              (- 64a b c f  + 64b c d f - 128b c d e )%%DN0
+--R            + 
+--R                     2 2   4      2 2 2        3 2  3        3 3 2
+--R                  16a b d f  + (8a b e  + 24a b c )f  - 16a b d f
+--R                + 
+--R                        3 2 2      4 2 2          3   4      4 2   2
+--R                  (24a b d e  - 24b c d )f + 16a b d e  + 48b c d e
+--R             *
+--R                %%DN0
+--R            + 
+--R                   3 6    2   2 4     2     2 3        2   4      2 4  2
+--R                  a f  - a b d f  + 8a b d e f  + (- 4a b e  - a b d )f
+--R                + 
+--R                      2 3 2        2 2 4    3 6
+--R                  8a b d e f - 4a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                 3   5     2       4       2     2     2   2        2 3  3
+--R              - a e f  - 5a b c d f  + (- a b c e  + 8a b d e - 3a b c )f
+--R            + 
+--R                   2     3       2 2          2   3  2
+--R              (- 3a b d e  + 3a b c d e + 4a b c d )f
+--R            + 
+--R                   2   5       2 2 3       2   2 2      2 4      3 3 2
+--R              (- 2a b e  - 2a b c e  - 3a b c d e  + a b d e + 3b c d )f
+--R            + 
+--R                    2     4       2 3 3     3 3   2    3 2 3     3   5
+--R              - 6a b c d e  + 3a b d e  - 6b c d e  + b c d e + b c d
+--R     + 
+--R            +-+4+-+ +-+      4+-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- f\|a \|a \|b  + b d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R          +-+4+-+ +-+      4+-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (f\|a \|a \|b  - b d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R            +-+ +-+4+-+3
+--R         4b\|2 \|b \|b  %%DN0
+--R      *
+--R         log
+--R                      5 3      6 2        6   2      3
+--R              (- 64a b f  + 64b d f - 128b d e )%%DN0
+--R            + 
+--R                       4   3        4     2           4 3      5   2
+--R                  48a b c f  + 48a b d e f  + (- 32a b e  - 48b c d )f
+--R                + 
+--R                     5     2      5 3
+--R                  96b c d e  + 16b d e
+--R             *
+--R                     2
+--R                %%DN0
+--R            + 
+--R                       2 2   4         2 2 2        3 2  3
+--R                  - 12a b d f  + (- 12a b e  - 12a b c )f
+--R                + 
+--R                          3             3 3  2
+--R                  (- 24a b c d e + 16a b d )f
+--R                + 
+--R                        3   3        3 2 2      4 2 2         3   4      4 2   2
+--R                  (16a b c e  - 36a b d e  + 12b c d )f - 8a b d e  - 24b c d e
+--R                + 
+--R                      4   3      4 5
+--R                  - 8b c d e - 4b d
+--R             *
+--R                %%DN0
+--R            + 
+--R                   3 6    2   2 4     2     2 3        2   4      2 4  2
+--R                  a f  - a b d f  + 8a b d e f  + (- 4a b e  - a b d )f
+--R                + 
+--R                      2 3 2        2 2 4    3 6
+--R                  8a b d e f - 4a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                3   5     2       4      2     2      2 3  3
+--R              3a e f  + 3a b c d f  + (3a b c e  + a b c )f
+--R            + 
+--R                 2     3       2 2          2   3  2
+--R              (5a b d e  + 3a b c d e - 4a b c d )f
+--R            + 
+--R                   2   5       2 2 3       2   2 2       2 4     3 3 2
+--R              (- 2a b e  - 2a b c e  + 9a b c d e  + 5a b d e - b c d )f
+--R            + 
+--R                  2     4       2 3 3     3 3   2    3 2 3     3   5
+--R              2a b c d e  - 5a b d e  + 2b c d e  + b c d e + b c d
+--R     + 
+--R                                         +-+4+-+   4+-+
+--R           +-+4+-+ +-+       4+-+      x\|2 \|b  + \|a
+--R       (2f\|a \|a \|b  + 2b d\|a )atan(----------------)
+--R                                             4+-+
+--R                                             \|a
+--R     + 
+--R                                         +-+4+-+   4+-+
+--R           +-+4+-+ +-+       4+-+      x\|2 \|b  - \|a
+--R       (2f\|a \|a \|b  + 2b d\|a )atan(----------------)
+--R                                             4+-+
+--R                                             \|a
+--R     + 
+--R                            2 +-+
+--R          +-+ +-+4+-+3     x \|b       +-+       4      +-+4+-+3
+--R       2e\|2 \|a \|b  atan(------) - c\|2 log(b x  + a)\|b \|b
+--R                             +-+
+--R                            \|a
+--R  /
+--R        +-+ +-+4+-+3
+--R     4b\|2 \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  6         4        2 4+-+2            4         2  +-+  +-+
+--R           ((b d x  + 2a f x  - a d x )\|a   + (- 4a f x  - 4a d x )\|a )\|b
+--R         + 
+--R                 6         4        2  +-+4+-+2           6           4
+--R           (b f x  + 2b d x  - a f x )\|a \|a   - 2a b f x  - 2a b d x
+--R         + 
+--R               2   2     2
+--R           - 2a f x  - 2a d
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                6        4        2        +-+4+-+2          4     2   2    2
+--R         ((b f x  + b d x  + a f x  + a d)\|a \|a   - a b d x  + 2a f x  + a d)
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R           2   6           4           2    2  4+-+2
+--R       (- b d x  + 3a b f x  + 3a b d x  - a f)\|a
+--R     + 
+--R                 4           2    2   +-+
+--R       (- a b f x  + 2a b d x  + a f)\|a
+--R  /
+--R           2 6         2  +-+ +-+     3 8       2 4     2  4+-+2
+--R       ((4b x  + 4a b x )\|a \|b  + 2b x  + 4a b x  + 2a b)\|b
+--R     + 
+--R            3 6       2 2 4+-+2
+--R       (- 4b x  - 4a b x )\|a
+--R                                                    Type: Expression(Integer)
+--E 783
+
+)clear all
+
+--S 784 of 953
+t0:=x^3*(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^2
+--R 
+--R
+--R           6      5      4      3
+--R        f x  + e x  + d x  + c x
+--R   (1)  -------------------------
+--R            2 8         4    2
+--R           b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 784
+
+--S 785 of 953
+r0:=1/4*(-c-d*x-e*x^2-f*x^3)/(b*(a+b*x^4))+1/4*e*atan(x^2*sqrt(b)/_
+   sqrt(a))/(b^(3/2)*sqrt(a))-1/16*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(b))*(-3*f*sqrt(a)+d*sqrt(b))/(a^(3/4)*b^(7/4)*_
+   sqrt(2))+1/16*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*_
+   (-3*f*sqrt(a)+d*sqrt(b))/(a^(3/4)*b^(7/4)*sqrt(2))-1/8*atan(1-b^(1/4)*_
+   x*sqrt(2)/a^(1/4))*(3*f*sqrt(a)+d*sqrt(b))/(a^(3/4)*b^(7/4)*_
+   sqrt(2))+1/8*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(3*f*sqrt(a)+d*_
+   sqrt(b))/(a^(3/4)*b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                     4     2   +-+     2   4          +-+
+--R         ((- 3a b f x  - 3a f)\|b  + (b d x  + a b d)\|a )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                   4     2   +-+       2   4          +-+
+--R         ((3a b f x  + 3a f)\|b  + (- b d x  - a b d)\|a )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                                               +-+4+-+   4+-+
+--R                 4     2   +-+      2   4           +-+      x\|2 \|b  + \|a
+--R       ((6a b f x  + 6a f)\|b  + (2b d x  + 2a b d)\|a )atan(----------------)
+--R                                                                   4+-+
+--R                                                                   \|a
+--R     + 
+--R                                                               +-+4+-+   4+-+
+--R                 4     2   +-+      2   4           +-+      x\|2 \|b  - \|a
+--R       ((6a b f x  + 6a f)\|b  + (2b d x  + 2a b d)\|a )atan(----------------)
+--R                                                                   4+-+
+--R                                                                   \|a
+--R     + 
+--R                                            2 +-+
+--R              4         +-+4+-+3 4+-+3     x \|b
+--R       (4b e x  + 4a e)\|2 \|a   \|b  atan(------)
+--R                                             +-+
+--R                                            \|a
+--R     + 
+--R              3       2              +-+ +-+4+-+3 +-+4+-+3
+--R       (- 4f x  - 4e x  - 4d x - 4c)\|2 \|a \|a  \|b \|b
+--R  /
+--R         2 4          +-+ +-+4+-+3 +-+4+-+3
+--R     (16b x  + 16a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 785
+
+--S 786 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2 4
+--R             (2b x  + 2a b)
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |       3     2        3                   3     2            2
+--R              |- 48a b %%DO1  - 32a b %%DO0 %%DO1 - 48a b %%DO0  - 3d f - 2e
+--R              |--------------------------------------------------------------
+--R              |                                 3
+--R             \|                            16a b
+--R         + 
+--R                2 4                     2 4
+--R           (- 2b x  - 2a b)%%DO1 + (- 2b x  - 2a b)%%DO0
+--R      *
+--R         log
+--R                             4 5 3        3 6 2          3 6   2
+--R                      (55296a b f  - 6144a b d f + 16384a b d e )%%DO0
+--R                    + 
+--R                             3 4     2        3 4 3        2 5 3
+--R                      - 6912a b d e f  + 6144a b e f - 256a b d e
+--R                 *
+--R                    %%DO1
+--R                + 
+--R                          3 4     2        3 4 3        2 5 3
+--R                  (- 6912a b d e f  + 6144a b e f - 256a b d e)%%DO0
+--R                + 
+--R                        3 2   4       3 2 2 3       2 3 2 2        2 3   4
+--R                  - 648a b d f  + 864a b e f  + 288a b d e f - 256a b d e
+--R                + 
+--R                      4 5
+--R                  8a b d
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |       3     2        3                   3     2            2
+--R               |- 48a b %%DO1  - 32a b %%DO0 %%DO1 - 48a b %%DO0  - 3d f - 2e
+--R               |--------------------------------------------------------------
+--R               |                                 3
+--R              \|                            16a b
+--R            + 
+--R                         4 5 3        3 6 2          3 6   2
+--R                  (55296a b f  - 6144a b d f + 16384a b d e )%%DO0
+--R                + 
+--R                         3 4     2        3 4 3        2 5 3
+--R                  - 6912a b d e f  + 6144a b e f - 256a b d e
+--R             *
+--R                     2
+--R                %%DO1
+--R            + 
+--R                         4 5 3        3 6 2          3 6   2      2
+--R                  (55296a b f  - 6144a b d f + 16384a b d e )%%DO0
+--R                + 
+--R                    3 2   4       3 2 2 3       2 3 2 2        2 3   4       4 5
+--R                648a b d f  - 864a b e f  - 288a b d e f + 256a b d e  - 8a b d
+--R             *
+--R                %%DO1
+--R            + 
+--R                      3 4     2        3 4 3        2 5 3       2
+--R              (- 6912a b d e f  + 6144a b e f - 256a b d e)%%DO0
+--R            + 
+--R                        3 2   4       3 2 2 3       2 3 2 2        2 3   4
+--R                    648a b d f  - 864a b e f  - 288a b d e f + 256a b d e
+--R                  + 
+--R                          4 5
+--R                    - 8a b d
+--R             *
+--R                %%DO0
+--R            + 
+--R                      3 6      2   2 4       2     2 3
+--R                  729a f  - 81a b d f  + 864a b d e f
+--R                + 
+--R                         2   4       2 4  2        2 3 2         2 2 4    3 6
+--R                  (- 576a b e  - 9a b d )f  + 96a b d e f - 64a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5       2   2   3      2     3 2
+--R              - 486a e f  - 216a b d e f  - 72a b d e f
+--R            + 
+--R                   2   5        2 4          2 3 3
+--R              (192a b e  - 18a b d e)f + 8a b d e
+--R     + 
+--R                  2 4
+--R             (- 2b x  - 2a b)
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |       3     2        3                   3     2            2
+--R              |- 48a b %%DO1  - 32a b %%DO0 %%DO1 - 48a b %%DO0  - 3d f - 2e
+--R              |--------------------------------------------------------------
+--R              |                                 3
+--R             \|                            16a b
+--R         + 
+--R                2 4                     2 4
+--R           (- 2b x  - 2a b)%%DO1 + (- 2b x  - 2a b)%%DO0
+--R      *
+--R         log
+--R                               4 5 3        3 6 2          3 6   2
+--R                      (- 55296a b f  + 6144a b d f - 16384a b d e )%%DO0
+--R                    + 
+--R                           3 4     2        3 4 3        2 5 3
+--R                      6912a b d e f  - 6144a b e f + 256a b d e
+--R                 *
+--R                    %%DO1
+--R                + 
+--R                        3 4     2        3 4 3        2 5 3              3 2   4
+--R                  (6912a b d e f  - 6144a b e f + 256a b d e)%%DO0 + 648a b d f
+--R                + 
+--R                        3 2 2 3       2 3 2 2        2 3   4       4 5
+--R                  - 864a b e f  - 288a b d e f + 256a b d e  - 8a b d
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |       3     2        3                   3     2            2
+--R               |- 48a b %%DO1  - 32a b %%DO0 %%DO1 - 48a b %%DO0  - 3d f - 2e
+--R               |--------------------------------------------------------------
+--R               |                                 3
+--R              \|                            16a b
+--R            + 
+--R                         4 5 3        3 6 2          3 6   2
+--R                  (55296a b f  - 6144a b d f + 16384a b d e )%%DO0
+--R                + 
+--R                         3 4     2        3 4 3        2 5 3
+--R                  - 6912a b d e f  + 6144a b e f - 256a b d e
+--R             *
+--R                     2
+--R                %%DO1
+--R            + 
+--R                         4 5 3        3 6 2          3 6   2      2
+--R                  (55296a b f  - 6144a b d f + 16384a b d e )%%DO0
+--R                + 
+--R                    3 2   4       3 2 2 3       2 3 2 2        2 3   4       4 5
+--R                648a b d f  - 864a b e f  - 288a b d e f + 256a b d e  - 8a b d
+--R             *
+--R                %%DO1
+--R            + 
+--R                      3 4     2        3 4 3        2 5 3       2
+--R              (- 6912a b d e f  + 6144a b e f - 256a b d e)%%DO0
+--R            + 
+--R                        3 2   4       3 2 2 3       2 3 2 2        2 3   4
+--R                    648a b d f  - 864a b e f  - 288a b d e f + 256a b d e
+--R                  + 
+--R                          4 5
+--R                    - 8a b d
+--R             *
+--R                %%DO0
+--R            + 
+--R                      3 6      2   2 4       2     2 3
+--R                  729a f  - 81a b d f  + 864a b d e f
+--R                + 
+--R                         2   4       2 4  2        2 3 2         2 2 4    3 6
+--R                  (- 576a b e  - 9a b d )f  + 96a b d e f - 64a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5       2   2   3      2     3 2
+--R              - 486a e f  - 216a b d e f  - 72a b d e f
+--R            + 
+--R                   2   5        2 4          2 3 3
+--R              (192a b e  - 18a b d e)f + 8a b d e
+--R     + 
+--R            2 4
+--R         (4b x  + 4a b)%%DO1
+--R      *
+--R         log
+--R                            4 5 3         3 6 2          3 6   2
+--R                  (- 110592a b f  + 12288a b d f - 32768a b d e )%%DO0
+--R                + 
+--R                        3 4     2         3 4 3        2 5 3
+--R                  13824a b d e f  - 12288a b e f + 512a b d e
+--R             *
+--R                     2
+--R                %%DO1
+--R            + 
+--R                            4 5 3         3 6 2          3 6   2      2
+--R                  (- 110592a b f  + 12288a b d f - 32768a b d e )%%DO0
+--R                + 
+--R                         3 2   4        3 2 2 3       2 3 2 2        2 3   4
+--R                  - 1296a b d f  + 1728a b e f  + 576a b d e f - 512a b d e
+--R                + 
+--R                       4 5
+--R                  16a b d
+--R             *
+--R                %%DO1
+--R            + 
+--R                        4 5 3         3 6 2          3 6   2      3
+--R              (- 110592a b f  + 12288a b d f - 32768a b d e )%%DO0
+--R            + 
+--R                         3 2   4        3 2 2 3       2 3 3 2        2 3 2 2
+--R                  - 5184a b d f  - 3456a b e f  + 576a b d f  - 1152a b d e f
+--R                + 
+--R                         2 3   4
+--R                  - 1024a b d e
+--R             *
+--R                %%DO0
+--R            + 
+--R                      3 6      2   2 4       2     2 3
+--R                  729a f  - 81a b d f  + 864a b d e f
+--R                + 
+--R                         2   4       2 4  2        2 3 2         2 2 4    3 6
+--R                  (- 576a b e  - 9a b d )f  + 96a b d e f - 64a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5       2   2   3       2     3 2
+--R              - 486a e f  + 432a b d e f  - 216a b d e f
+--R            + 
+--R                     2   5       2 4           2 3 3
+--R              (- 192a b e  + 6a b d e)f + 24a b d e
+--R     + 
+--R            2 4
+--R         (4b x  + 4a b)%%DO0
+--R      *
+--R         log
+--R                      4 5 3         3 6 2          3 6   2      3
+--R              (110592a b f  - 12288a b d f + 32768a b d e )%%DO0
+--R            + 
+--R                     3 4     2         3 4 3        2 5 3       2
+--R              (13824a b d e f  - 12288a b e f + 512a b d e)%%DO0
+--R            + 
+--R                       3 2   4        3 2 2 3       2 3 3 2        2 3 2 2
+--R                  3888a b d f  + 5184a b e f  - 576a b d f  + 1728a b d e f
+--R                + 
+--R                      2 3   4        4 5
+--R                  512a b d e  + 16a b d
+--R             *
+--R                %%DO0
+--R            + 
+--R                      3 6      2   2 4       2     2 3
+--R                  729a f  - 81a b d f  + 864a b d e f
+--R                + 
+--R                         2   4       2 4  2        2 3 2         2 2 4    3 6
+--R                  (- 576a b e  - 9a b d )f  + 96a b d e f - 64a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                 3   5       2     3 2          2   5        2 4           2 3 3
+--R            1458a e f  + 360a b d e f  + (- 192a b e  + 30a b d e)f - 40a b d e
+--R     + 
+--R            3      2
+--R       - f x  - e x  - d x - c
+--R  /
+--R       2 4
+--R     4b x  + 4a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 786
+
+--S 787 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +-+ +-+4+-+3 +-+4+-+3
+--R             8b\|2 \|a \|a  \|b \|b
+--R          *
+--R              +--------------------------------------------------------------+
+--R              |       3     2        3                   3     2            2
+--R              |- 48a b %%DO1  - 32a b %%DO0 %%DO1 - 48a b %%DO0  - 3d f - 2e
+--R              |--------------------------------------------------------------
+--R              |                                 3
+--R             \|                            16a b
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 8b\|2 \|a \|a  \|b \|b  %%DO1 - 8b\|2 \|a \|a  \|b \|b  %%DO0
+--R      *
+--R         log
+--R                             4 5 3        3 6 2          3 6   2
+--R                      (55296a b f  - 6144a b d f + 16384a b d e )%%DO0
+--R                    + 
+--R                             3 4     2        3 4 3        2 5 3
+--R                      - 6912a b d e f  + 6144a b e f - 256a b d e
+--R                 *
+--R                    %%DO1
+--R                + 
+--R                          3 4     2        3 4 3        2 5 3
+--R                  (- 6912a b d e f  + 6144a b e f - 256a b d e)%%DO0
+--R                + 
+--R                        3 2   4       3 2 2 3       2 3 2 2        2 3   4
+--R                  - 648a b d f  + 864a b e f  + 288a b d e f - 256a b d e
+--R                + 
+--R                      4 5
+--R                  8a b d
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |       3     2        3                   3     2            2
+--R               |- 48a b %%DO1  - 32a b %%DO0 %%DO1 - 48a b %%DO0  - 3d f - 2e
+--R               |--------------------------------------------------------------
+--R               |                                 3
+--R              \|                            16a b
+--R            + 
+--R                         4 5 3        3 6 2          3 6   2
+--R                  (55296a b f  - 6144a b d f + 16384a b d e )%%DO0
+--R                + 
+--R                         3 4     2        3 4 3        2 5 3
+--R                  - 6912a b d e f  + 6144a b e f - 256a b d e
+--R             *
+--R                     2
+--R                %%DO1
+--R            + 
+--R                         4 5 3        3 6 2          3 6   2      2
+--R                  (55296a b f  - 6144a b d f + 16384a b d e )%%DO0
+--R                + 
+--R                    3 2   4       3 2 2 3       2 3 2 2        2 3   4       4 5
+--R                648a b d f  - 864a b e f  - 288a b d e f + 256a b d e  - 8a b d
+--R             *
+--R                %%DO1
+--R            + 
+--R                      3 4     2        3 4 3        2 5 3       2
+--R              (- 6912a b d e f  + 6144a b e f - 256a b d e)%%DO0
+--R            + 
+--R                        3 2   4       3 2 2 3       2 3 2 2        2 3   4
+--R                    648a b d f  - 864a b e f  - 288a b d e f + 256a b d e
+--R                  + 
+--R                          4 5
+--R                    - 8a b d
+--R             *
+--R                %%DO0
+--R            + 
+--R                      3 6      2   2 4       2     2 3
+--R                  729a f  - 81a b d f  + 864a b d e f
+--R                + 
+--R                         2   4       2 4  2        2 3 2         2 2 4    3 6
+--R                  (- 576a b e  - 9a b d )f  + 96a b d e f - 64a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5       2   2   3      2     3 2
+--R              - 486a e f  - 216a b d e f  - 72a b d e f
+--R            + 
+--R                   2   5        2 4          2 3 3
+--R              (192a b e  - 18a b d e)f + 8a b d e
+--R     + 
+--R           -
+--R                   +-+ +-+4+-+3 +-+4+-+3
+--R                8b\|2 \|a \|a  \|b \|b
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |       3     2        3                   3     2            2
+--R               |- 48a b %%DO1  - 32a b %%DO0 %%DO1 - 48a b %%DO0  - 3d f - 2e
+--R               |--------------------------------------------------------------
+--R               |                                 3
+--R              \|                            16a b
+--R         + 
+--R                +-+ +-+4+-+3 +-+4+-+3           +-+ +-+4+-+3 +-+4+-+3
+--R           - 8b\|2 \|a \|a  \|b \|b  %%DO1 - 8b\|2 \|a \|a  \|b \|b  %%DO0
+--R      *
+--R         log
+--R                               4 5 3        3 6 2          3 6   2
+--R                      (- 55296a b f  + 6144a b d f - 16384a b d e )%%DO0
+--R                    + 
+--R                           3 4     2        3 4 3        2 5 3
+--R                      6912a b d e f  - 6144a b e f + 256a b d e
+--R                 *
+--R                    %%DO1
+--R                + 
+--R                        3 4     2        3 4 3        2 5 3              3 2   4
+--R                  (6912a b d e f  - 6144a b e f + 256a b d e)%%DO0 + 648a b d f
+--R                + 
+--R                        3 2 2 3       2 3 2 2        2 3   4       4 5
+--R                  - 864a b e f  - 288a b d e f + 256a b d e  - 8a b d
+--R             *
+--R               +--------------------------------------------------------------+
+--R               |       3     2        3                   3     2            2
+--R               |- 48a b %%DO1  - 32a b %%DO0 %%DO1 - 48a b %%DO0  - 3d f - 2e
+--R               |--------------------------------------------------------------
+--R               |                                 3
+--R              \|                            16a b
+--R            + 
+--R                         4 5 3        3 6 2          3 6   2
+--R                  (55296a b f  - 6144a b d f + 16384a b d e )%%DO0
+--R                + 
+--R                         3 4     2        3 4 3        2 5 3
+--R                  - 6912a b d e f  + 6144a b e f - 256a b d e
+--R             *
+--R                     2
+--R                %%DO1
+--R            + 
+--R                         4 5 3        3 6 2          3 6   2      2
+--R                  (55296a b f  - 6144a b d f + 16384a b d e )%%DO0
+--R                + 
+--R                    3 2   4       3 2 2 3       2 3 2 2        2 3   4       4 5
+--R                648a b d f  - 864a b e f  - 288a b d e f + 256a b d e  - 8a b d
+--R             *
+--R                %%DO1
+--R            + 
+--R                      3 4     2        3 4 3        2 5 3       2
+--R              (- 6912a b d e f  + 6144a b e f - 256a b d e)%%DO0
+--R            + 
+--R                        3 2   4       3 2 2 3       2 3 2 2        2 3   4
+--R                    648a b d f  - 864a b e f  - 288a b d e f + 256a b d e
+--R                  + 
+--R                          4 5
+--R                    - 8a b d
+--R             *
+--R                %%DO0
+--R            + 
+--R                      3 6      2   2 4       2     2 3
+--R                  729a f  - 81a b d f  + 864a b d e f
+--R                + 
+--R                         2   4       2 4  2        2 3 2         2 2 4    3 6
+--R                  (- 576a b e  - 9a b d )f  + 96a b d e f - 64a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5       2   2   3      2     3 2
+--R              - 486a e f  - 216a b d e f  - 72a b d e f
+--R            + 
+--R                   2   5        2 4          2 3 3
+--R              (192a b e  - 18a b d e)f + 8a b d e
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+3
+--R         16b\|2 \|a \|a  \|b \|b  %%DO1
+--R      *
+--R         log
+--R                            4 5 3         3 6 2          3 6   2
+--R                  (- 110592a b f  + 12288a b d f - 32768a b d e )%%DO0
+--R                + 
+--R                        3 4     2         3 4 3        2 5 3
+--R                  13824a b d e f  - 12288a b e f + 512a b d e
+--R             *
+--R                     2
+--R                %%DO1
+--R            + 
+--R                            4 5 3         3 6 2          3 6   2      2
+--R                  (- 110592a b f  + 12288a b d f - 32768a b d e )%%DO0
+--R                + 
+--R                         3 2   4        3 2 2 3       2 3 2 2        2 3   4
+--R                  - 1296a b d f  + 1728a b e f  + 576a b d e f - 512a b d e
+--R                + 
+--R                       4 5
+--R                  16a b d
+--R             *
+--R                %%DO1
+--R            + 
+--R                        4 5 3         3 6 2          3 6   2      3
+--R              (- 110592a b f  + 12288a b d f - 32768a b d e )%%DO0
+--R            + 
+--R                         3 2   4        3 2 2 3       2 3 3 2        2 3 2 2
+--R                  - 5184a b d f  - 3456a b e f  + 576a b d f  - 1152a b d e f
+--R                + 
+--R                         2 3   4
+--R                  - 1024a b d e
+--R             *
+--R                %%DO0
+--R            + 
+--R                      3 6      2   2 4       2     2 3
+--R                  729a f  - 81a b d f  + 864a b d e f
+--R                + 
+--R                         2   4       2 4  2        2 3 2         2 2 4    3 6
+--R                  (- 576a b e  - 9a b d )f  + 96a b d e f - 64a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5       2   2   3       2     3 2
+--R              - 486a e f  + 432a b d e f  - 216a b d e f
+--R            + 
+--R                     2   5       2 4           2 3 3
+--R              (- 192a b e  + 6a b d e)f + 24a b d e
+--R     + 
+--R             +-+ +-+4+-+3 +-+4+-+3
+--R         16b\|2 \|a \|a  \|b \|b  %%DO0
+--R      *
+--R         log
+--R                      4 5 3         3 6 2          3 6   2      3
+--R              (110592a b f  - 12288a b d f + 32768a b d e )%%DO0
+--R            + 
+--R                     3 4     2         3 4 3        2 5 3       2
+--R              (13824a b d e f  - 12288a b e f + 512a b d e)%%DO0
+--R            + 
+--R                       3 2   4        3 2 2 3       2 3 3 2        2 3 2 2
+--R                  3888a b d f  + 5184a b e f  - 576a b d f  + 1728a b d e f
+--R                + 
+--R                      2 3   4        4 5
+--R                  512a b d e  + 16a b d
+--R             *
+--R                %%DO0
+--R            + 
+--R                      3 6      2   2 4       2     2 3
+--R                  729a f  - 81a b d f  + 864a b d e f
+--R                + 
+--R                         2   4       2 4  2        2 3 2         2 2 4    3 6
+--R                  (- 576a b e  - 9a b d )f  + 96a b d e f - 64a b d e  + b d
+--R             *
+--R                x
+--R            + 
+--R                 3   5       2     3 2          2   5        2 4           2 3 3
+--R            1458a e f  + 360a b d e f  + (- 192a b e  + 30a b d e)f - 40a b d e
+--R     + 
+--R             +-+       +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (3a f\|b  - b d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R               +-+       +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a f\|b  + b d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|b  + \|a
+--R       (- 6a f\|b  - 2b d\|a )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|b  - \|a
+--R       (- 6a f\|b  - 2b d\|a )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                2 +-+
+--R            +-+4+-+3 4+-+3     x \|b
+--R       - 4e\|2 \|a   \|b  atan(------)
+--R                                 +-+
+--R                                \|a
+--R  /
+--R         +-+ +-+4+-+3 +-+4+-+3
+--R     16b\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  4       2  +-+4+-+2        6         4        2  +-+
+--R           ((12f x  + 4d x )\|a \|a   - b d x  - 6a f x  + a d x )\|b
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (6b f x  + 2b d x  + 6a f x  + 2a d)\|a
+--R         + 
+--R                    6         4         2  +-+
+--R           (- 3b f x  - 2b d x  + 3a f x )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                 4         2       4+-+2
+--R           (b d x  - 6a f x  - a d)\|a
+--R         + 
+--R                    6        4         2        +-+
+--R           (- 3b f x  - b d x  - 3a f x  - a d)\|a
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R            4         2         +-+4+-+2    2   6           4           2     2
+--R     (3b f x  - 2b d x  - 3a f)\|a \|a   + b d x  - 9a b f x  - 3a b d x  + 3a f
+--R  /
+--R            2 6          2  +-+4+-+2 +-+      3 8        2 4     2  4+-+2 4+-+2
+--R       ((16b x  + 16a b x )\|a \|a  \|b  + (8b x  + 16a b x  + 8a b)\|a  )\|b
+--R     + 
+--R              3 6      2 2 2
+--R       - 16a b x  - 16a b x
+--R                                                    Type: Expression(Integer)
+--E 788
+
+)clear all
+
+--S 789 of 953
+t0:=x^3*(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^3
+--R 
+--R
+--R              6      5      4      3
+--R           f x  + e x  + d x  + c x
+--R   (1)  ------------------------------
+--R         3 12       2 8     2   4    3
+--R        b x   + 3a b x  + 3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 789
+
+--S 790 of 953
+r0:=1/8*(-c-d*x-e*x^2-f*x^3)/(b*(a+b*x^4)^2)+1/32*x*(d+2*e*x+3*f*x^2)/_
+   (a*b*(a+b*x^4))+1/16*e*atan(x^2*sqrt(b)/sqrt(a))/(a^(3/2)*b^(3/2))-_
+   3/128*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-f*_
+   sqrt(a)+d*sqrt(b))/(a^(7/4)*b^(7/4)*sqrt(2))+3/128*log(a^(1/4)*_
+   b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-f*sqrt(a)+d*sqrt(b))/_
+   (a^(7/4)*b^(7/4)*sqrt(2))-3/64*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*_
+   (f*sqrt(a)+d*sqrt(b))/(a^(7/4)*b^(7/4)*sqrt(2))+3/64*atan(1+b^(1/4)*_
+   x*sqrt(2)/a^(1/4))*(f*sqrt(a)+d*sqrt(b))/(a^(7/4)*b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  2   8     2     4     3   +-+
+--R           (- 3a b f x  - 6a b f x  - 3a f)\|b
+--R         + 
+--R              3   8       2   4     2     +-+
+--R           (3b d x  + 6a b d x  + 3a b d)\|a
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                2   8     2     4     3   +-+
+--R           (3a b f x  + 6a b f x  + 3a f)\|b
+--R         + 
+--R                3   8       2   4     2     +-+
+--R           (- 3b d x  - 6a b d x  - 3a b d)\|a
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                2   8      2     4     3   +-+
+--R           (6a b f x  + 12a b f x  + 6a f)\|b
+--R         + 
+--R              3   8        2   4     2     +-+
+--R           (6b d x  + 12a b d x  + 6a b d)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  + \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                2   8      2     4     3   +-+
+--R           (6a b f x  + 12a b f x  + 6a f)\|b
+--R         + 
+--R              3   8        2   4     2     +-+
+--R           (6b d x  + 12a b d x  + 6a b d)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  - \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                                                         2 +-+
+--R          2   8            4     2   +-+4+-+3 4+-+3     x \|b
+--R       (8b e x  + 16a b e x  + 8a e)\|2 \|a   \|b  atan(------)
+--R                                                          +-+
+--R                                                         \|a
+--R     + 
+--R                 7         6         5         3         2
+--R         (12b f x  + 8b e x  + 4b d x  - 4a f x  - 8a e x  - 12a d x - 16a c)
+--R      *
+--R          +-+ +-+4+-+3 +-+4+-+3
+--R         \|2 \|a \|a  \|b \|b
+--R  /
+--R            3 8       2 2 4       3   +-+ +-+4+-+3 +-+4+-+3
+--R     (128a b x  + 256a b x  + 128a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 790
+
+--S 791 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   3 8      2 2 4      3
+--R             (16a b x  + 32a b x  + 16a b)
+--R          *
+--R             ROOT
+--R                           3 3     2        3 3                   3 3     2
+--R                    - 3072a b %%DP1  - 2048a b %%DP0 %%DP1 - 3072a b %%DP0
+--R                  + 
+--R                               2
+--R                    - 9d f - 8e
+--R               /
+--R                       3 3
+--R                  1024a b
+--R         + 
+--R                   3 8      2 2 4      3
+--R           (- 16a b x  - 32a b x  - 16a b)%%DP1
+--R         + 
+--R                   3 8      2 2 4      3
+--R           (- 16a b x  - 32a b x  - 16a b)%%DP0
+--R      *
+--R         log
+--R                               7 5 3           6 6 2             6 6   2
+--R                      (9437184a b f  - 9437184a b d f + 33554432a b d e )%%DP0
+--R                    + 
+--R                               5 4     2           5 4 3           4 5 3
+--R                      - 884736a b d e f  + 1048576a b e f - 294912a b d e
+--R                 *
+--R                    %%DP1
+--R                + 
+--R                            5 4     2           5 4 3           4 5 3
+--R                  (- 884736a b d e f  + 1048576a b e f - 294912a b d e)%%DP0
+--R                + 
+--R                         4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  - 5184a b d f  + 9216a b e f  + 27648a b d e f - 32768a b d e
+--R                + 
+--R                       2 4 5
+--R                  5184a b d
+--R             *
+--R                ROOT
+--R                              3 3     2        3 3                   3 3     2
+--R                       - 3072a b %%DP1  - 2048a b %%DP0 %%DP1 - 3072a b %%DP0
+--R                     + 
+--R                                  2
+--R                       - 9d f - 8e
+--R                  /
+--R                          3 3
+--R                     1024a b
+--R            + 
+--R                           7 5 3           6 6 2             6 6   2
+--R                  (9437184a b f  - 9437184a b d f + 33554432a b d e )%%DP0
+--R                + 
+--R                           5 4     2           5 4 3           4 5 3
+--R                  - 884736a b d e f  + 1048576a b e f - 294912a b d e
+--R             *
+--R                     2
+--R                %%DP1
+--R            + 
+--R                           7 5 3           6 6 2             6 6   2      2
+--R                  (9437184a b f  - 9437184a b d f + 33554432a b d e )%%DP0
+--R                + 
+--R                       4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  5184a b d f  - 9216a b e f  - 27648a b d e f + 32768a b d e
+--R                + 
+--R                         2 4 5
+--R                  - 5184a b d
+--R             *
+--R                %%DP1
+--R            + 
+--R                        5 4     2           5 4 3           4 5 3       2
+--R              (- 884736a b d e f  + 1048576a b e f - 294912a b d e)%%DP0
+--R            + 
+--R                       4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  5184a b d f  - 9216a b e f  - 27648a b d e f + 32768a b d e
+--R                + 
+--R                         2 4 5
+--R                  - 5184a b d
+--R             *
+--R                %%DP0
+--R            + 
+--R                      3 6       2   2 4        2     2 3
+--R                  243a f  - 243a b d f  + 3456a b d e f
+--R                + 
+--R                          2   4         2 4  2          2 3 2           2 2 4
+--R                  (- 3072a b e  - 243a b d )f  + 3456a b d e f - 3072a b d e
+--R                + 
+--R                      3 6
+--R                  243b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5        2   2   3       2     3 2
+--R              - 324a e f  - 1296a b d e f  - 576a b d e f
+--R            + 
+--R                    2   5         2 4            2 3 3
+--R              (2048a b e  - 972a b d e)f + 576a b d e
+--R     + 
+--R                     3 8      2 2 4      3
+--R             (- 16a b x  - 32a b x  - 16a b)
+--R          *
+--R             ROOT
+--R                           3 3     2        3 3                   3 3     2
+--R                    - 3072a b %%DP1  - 2048a b %%DP0 %%DP1 - 3072a b %%DP0
+--R                  + 
+--R                               2
+--R                    - 9d f - 8e
+--R               /
+--R                       3 3
+--R                  1024a b
+--R         + 
+--R                   3 8      2 2 4      3
+--R           (- 16a b x  - 32a b x  - 16a b)%%DP1
+--R         + 
+--R                   3 8      2 2 4      3
+--R           (- 16a b x  - 32a b x  - 16a b)%%DP0
+--R      *
+--R         log
+--R                                 7 5 3           6 6 2             6 6   2
+--R                      (- 9437184a b f  + 9437184a b d f - 33554432a b d e )%%DP0
+--R                    + 
+--R                             5 4     2           5 4 3           4 5 3
+--R                      884736a b d e f  - 1048576a b e f + 294912a b d e
+--R                 *
+--R                    %%DP1
+--R                + 
+--R                          5 4     2           5 4 3           4 5 3
+--R                  (884736a b d e f  - 1048576a b e f + 294912a b d e)%%DP0
+--R                + 
+--R                       4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  5184a b d f  - 9216a b e f  - 27648a b d e f + 32768a b d e
+--R                + 
+--R                         2 4 5
+--R                  - 5184a b d
+--R             *
+--R                ROOT
+--R                              3 3     2        3 3                   3 3     2
+--R                       - 3072a b %%DP1  - 2048a b %%DP0 %%DP1 - 3072a b %%DP0
+--R                     + 
+--R                                  2
+--R                       - 9d f - 8e
+--R                  /
+--R                          3 3
+--R                     1024a b
+--R            + 
+--R                           7 5 3           6 6 2             6 6   2
+--R                  (9437184a b f  - 9437184a b d f + 33554432a b d e )%%DP0
+--R                + 
+--R                           5 4     2           5 4 3           4 5 3
+--R                  - 884736a b d e f  + 1048576a b e f - 294912a b d e
+--R             *
+--R                     2
+--R                %%DP1
+--R            + 
+--R                           7 5 3           6 6 2             6 6   2      2
+--R                  (9437184a b f  - 9437184a b d f + 33554432a b d e )%%DP0
+--R                + 
+--R                       4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  5184a b d f  - 9216a b e f  - 27648a b d e f + 32768a b d e
+--R                + 
+--R                         2 4 5
+--R                  - 5184a b d
+--R             *
+--R                %%DP1
+--R            + 
+--R                        5 4     2           5 4 3           4 5 3       2
+--R              (- 884736a b d e f  + 1048576a b e f - 294912a b d e)%%DP0
+--R            + 
+--R                       4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  5184a b d f  - 9216a b e f  - 27648a b d e f + 32768a b d e
+--R                + 
+--R                         2 4 5
+--R                  - 5184a b d
+--R             *
+--R                %%DP0
+--R            + 
+--R                      3 6       2   2 4        2     2 3
+--R                  243a f  - 243a b d f  + 3456a b d e f
+--R                + 
+--R                          2   4         2 4  2          2 3 2           2 2 4
+--R                  (- 3072a b e  - 243a b d )f  + 3456a b d e f - 3072a b d e
+--R                + 
+--R                      3 6
+--R                  243b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5        2   2   3       2     3 2
+--R              - 324a e f  - 1296a b d e f  - 576a b d e f
+--R            + 
+--R                    2   5         2 4            2 3 3
+--R              (2048a b e  - 972a b d e)f + 576a b d e
+--R     + 
+--R               3 8      2 2 4      3
+--R         (32a b x  + 64a b x  + 32a b)%%DP1
+--R      *
+--R         log
+--R                              7 5 3            6 6 2             6 6   2
+--R                  (- 18874368a b f  + 18874368a b d f - 67108864a b d e )%%DP0
+--R                + 
+--R                          5 4     2           5 4 3           4 5 3
+--R                  1769472a b d e f  - 2097152a b e f + 589824a b d e
+--R             *
+--R                     2
+--R                %%DP1
+--R            + 
+--R                              7 5 3            6 6 2             6 6   2      2
+--R                  (- 18874368a b f  + 18874368a b d f - 67108864a b d e )%%DP0
+--R                + 
+--R                          4 2   4         4 2 2 3         3 3 2 2
+--R                  - 10368a b d f  + 18432a b e f  + 55296a b d e f
+--R                + 
+--R                          3 3   4         2 4 5
+--R                  - 65536a b d e  + 10368a b d
+--R             *
+--R                %%DP1
+--R            + 
+--R                          7 5 3            6 6 2             6 6   2      3
+--R              (- 18874368a b f  + 18874368a b d f - 67108864a b d e )%%DP0
+--R            + 
+--R                          4 2   4         4 2 2 3         3 3 3 2
+--R                  - 41472a b d f  - 36864a b e f  + 41472a b d f
+--R                + 
+--R                           3 3 2 2           3 3   4
+--R                  - 110592a b d e f - 131072a b d e
+--R             *
+--R                %%DP0
+--R            + 
+--R                      3 6       2   2 4        2     2 3
+--R                  243a f  - 243a b d f  + 3456a b d e f
+--R                + 
+--R                          2   4         2 4  2          2 3 2           2 2 4
+--R                  (- 3072a b e  - 243a b d )f  + 3456a b d e f - 3072a b d e
+--R                + 
+--R                      3 6
+--R                  243b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5        2   2   3        2     3 2
+--R              - 324a e f  + 2592a b d e f  - 1728a b d e f
+--R            + 
+--R                      2   5         2 4             2 3 3
+--R              (- 2048a b e  + 324a b d e)f + 1728a b d e
+--R     + 
+--R               3 8      2 2 4      3
+--R         (32a b x  + 64a b x  + 32a b)%%DP0
+--R      *
+--R         log
+--R                        7 5 3            6 6 2             6 6   2      3
+--R              (18874368a b f  - 18874368a b d f + 67108864a b d e )%%DP0
+--R            + 
+--R                       5 4     2           5 4 3           4 5 3       2
+--R              (1769472a b d e f  - 2097152a b e f + 589824a b d e)%%DP0
+--R            + 
+--R                        4 2   4         4 2 2 3         3 3 3 2
+--R                  31104a b d f  + 55296a b e f  - 41472a b d f
+--R                + 
+--R                         3 3 2 2          3 3   4         2 4 5
+--R                  165888a b d e f + 65536a b d e  + 10368a b d
+--R             *
+--R                %%DP0
+--R            + 
+--R                      3 6       2   2 4        2     2 3
+--R                  243a f  - 243a b d f  + 3456a b d e f
+--R                + 
+--R                          2   4         2 4  2          2 3 2           2 2 4
+--R                  (- 3072a b e  - 243a b d )f  + 3456a b d e f - 3072a b d e
+--R                + 
+--R                      3 6
+--R                  243b d
+--R             *
+--R                x
+--R            + 
+--R                  3   5        2     3 2           2   5          2 4
+--R              972a e f  + 2880a b d e f  + (- 2048a b e  + 1620a b d e)f
+--R            + 
+--R                       2 3 3
+--R              - 2880a b d e
+--R     + 
+--R             7         6        5        3         2
+--R       3b f x  + 2b e x  + b d x  - a f x  - 2a e x  - 3a d x - 4a c
+--R  /
+--R          3 8      2 2 4      3
+--R     32a b x  + 64a b x  + 32a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 791
+
+--S 792 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   +-+ +-+4+-+3 +-+4+-+3
+--R             64a b\|2 \|a \|a  \|b \|b
+--R          *
+--R             ROOT
+--R                           3 3     2        3 3                   3 3     2
+--R                    - 3072a b %%DP1  - 2048a b %%DP0 %%DP1 - 3072a b %%DP0
+--R                  + 
+--R                               2
+--R                    - 9d f - 8e
+--R               /
+--R                       3 3
+--R                  1024a b
+--R         + 
+--R                 +-+ +-+4+-+3 +-+4+-+3              +-+ +-+4+-+3 +-+4+-+3
+--R         - 64a b\|2 \|a \|a  \|b \|b  %%DP1 - 64a b\|2 \|a \|a  \|b \|b  %%DP0
+--R      *
+--R         log
+--R                               7 5 3           6 6 2             6 6   2
+--R                      (9437184a b f  - 9437184a b d f + 33554432a b d e )%%DP0
+--R                    + 
+--R                               5 4     2           5 4 3           4 5 3
+--R                      - 884736a b d e f  + 1048576a b e f - 294912a b d e
+--R                 *
+--R                    %%DP1
+--R                + 
+--R                            5 4     2           5 4 3           4 5 3
+--R                  (- 884736a b d e f  + 1048576a b e f - 294912a b d e)%%DP0
+--R                + 
+--R                         4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  - 5184a b d f  + 9216a b e f  + 27648a b d e f - 32768a b d e
+--R                + 
+--R                       2 4 5
+--R                  5184a b d
+--R             *
+--R                ROOT
+--R                              3 3     2        3 3                   3 3     2
+--R                       - 3072a b %%DP1  - 2048a b %%DP0 %%DP1 - 3072a b %%DP0
+--R                     + 
+--R                                  2
+--R                       - 9d f - 8e
+--R                  /
+--R                          3 3
+--R                     1024a b
+--R            + 
+--R                           7 5 3           6 6 2             6 6   2
+--R                  (9437184a b f  - 9437184a b d f + 33554432a b d e )%%DP0
+--R                + 
+--R                           5 4     2           5 4 3           4 5 3
+--R                  - 884736a b d e f  + 1048576a b e f - 294912a b d e
+--R             *
+--R                     2
+--R                %%DP1
+--R            + 
+--R                           7 5 3           6 6 2             6 6   2      2
+--R                  (9437184a b f  - 9437184a b d f + 33554432a b d e )%%DP0
+--R                + 
+--R                       4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  5184a b d f  - 9216a b e f  - 27648a b d e f + 32768a b d e
+--R                + 
+--R                         2 4 5
+--R                  - 5184a b d
+--R             *
+--R                %%DP1
+--R            + 
+--R                        5 4     2           5 4 3           4 5 3       2
+--R              (- 884736a b d e f  + 1048576a b e f - 294912a b d e)%%DP0
+--R            + 
+--R                       4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  5184a b d f  - 9216a b e f  - 27648a b d e f + 32768a b d e
+--R                + 
+--R                         2 4 5
+--R                  - 5184a b d
+--R             *
+--R                %%DP0
+--R            + 
+--R                      3 6       2   2 4        2     2 3
+--R                  243a f  - 243a b d f  + 3456a b d e f
+--R                + 
+--R                          2   4         2 4  2          2 3 2           2 2 4
+--R                  (- 3072a b e  - 243a b d )f  + 3456a b d e f - 3072a b d e
+--R                + 
+--R                      3 6
+--R                  243b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5        2   2   3       2     3 2
+--R              - 324a e f  - 1296a b d e f  - 576a b d e f
+--R            + 
+--R                    2   5         2 4            2 3 3
+--R              (2048a b e  - 972a b d e)f + 576a b d e
+--R     + 
+--R           -
+--R                      +-+ +-+4+-+3 +-+4+-+3
+--R                64a b\|2 \|a \|a  \|b \|b
+--R             *
+--R                ROOT
+--R                              3 3     2        3 3                   3 3     2
+--R                       - 3072a b %%DP1  - 2048a b %%DP0 %%DP1 - 3072a b %%DP0
+--R                     + 
+--R                                  2
+--R                       - 9d f - 8e
+--R                  /
+--R                          3 3
+--R                     1024a b
+--R         + 
+--R                 +-+ +-+4+-+3 +-+4+-+3              +-+ +-+4+-+3 +-+4+-+3
+--R         - 64a b\|2 \|a \|a  \|b \|b  %%DP1 - 64a b\|2 \|a \|a  \|b \|b  %%DP0
+--R      *
+--R         log
+--R                                 7 5 3           6 6 2             6 6   2
+--R                      (- 9437184a b f  + 9437184a b d f - 33554432a b d e )%%DP0
+--R                    + 
+--R                             5 4     2           5 4 3           4 5 3
+--R                      884736a b d e f  - 1048576a b e f + 294912a b d e
+--R                 *
+--R                    %%DP1
+--R                + 
+--R                          5 4     2           5 4 3           4 5 3
+--R                  (884736a b d e f  - 1048576a b e f + 294912a b d e)%%DP0
+--R                + 
+--R                       4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  5184a b d f  - 9216a b e f  - 27648a b d e f + 32768a b d e
+--R                + 
+--R                         2 4 5
+--R                  - 5184a b d
+--R             *
+--R                ROOT
+--R                              3 3     2        3 3                   3 3     2
+--R                       - 3072a b %%DP1  - 2048a b %%DP0 %%DP1 - 3072a b %%DP0
+--R                     + 
+--R                                  2
+--R                       - 9d f - 8e
+--R                  /
+--R                          3 3
+--R                     1024a b
+--R            + 
+--R                           7 5 3           6 6 2             6 6   2
+--R                  (9437184a b f  - 9437184a b d f + 33554432a b d e )%%DP0
+--R                + 
+--R                           5 4     2           5 4 3           4 5 3
+--R                  - 884736a b d e f  + 1048576a b e f - 294912a b d e
+--R             *
+--R                     2
+--R                %%DP1
+--R            + 
+--R                           7 5 3           6 6 2             6 6   2      2
+--R                  (9437184a b f  - 9437184a b d f + 33554432a b d e )%%DP0
+--R                + 
+--R                       4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  5184a b d f  - 9216a b e f  - 27648a b d e f + 32768a b d e
+--R                + 
+--R                         2 4 5
+--R                  - 5184a b d
+--R             *
+--R                %%DP1
+--R            + 
+--R                        5 4     2           5 4 3           4 5 3       2
+--R              (- 884736a b d e f  + 1048576a b e f - 294912a b d e)%%DP0
+--R            + 
+--R                       4 2   4        4 2 2 3         3 3 2 2          3 3   4
+--R                  5184a b d f  - 9216a b e f  - 27648a b d e f + 32768a b d e
+--R                + 
+--R                         2 4 5
+--R                  - 5184a b d
+--R             *
+--R                %%DP0
+--R            + 
+--R                      3 6       2   2 4        2     2 3
+--R                  243a f  - 243a b d f  + 3456a b d e f
+--R                + 
+--R                          2   4         2 4  2          2 3 2           2 2 4
+--R                  (- 3072a b e  - 243a b d )f  + 3456a b d e f - 3072a b d e
+--R                + 
+--R                      3 6
+--R                  243b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5        2   2   3       2     3 2
+--R              - 324a e f  - 1296a b d e f  - 576a b d e f
+--R            + 
+--R                    2   5         2 4            2 3 3
+--R              (2048a b e  - 972a b d e)f + 576a b d e
+--R     + 
+--R                +-+ +-+4+-+3 +-+4+-+3
+--R         128a b\|2 \|a \|a  \|b \|b  %%DP1
+--R      *
+--R         log
+--R                              7 5 3            6 6 2             6 6   2
+--R                  (- 18874368a b f  + 18874368a b d f - 67108864a b d e )%%DP0
+--R                + 
+--R                          5 4     2           5 4 3           4 5 3
+--R                  1769472a b d e f  - 2097152a b e f + 589824a b d e
+--R             *
+--R                     2
+--R                %%DP1
+--R            + 
+--R                              7 5 3            6 6 2             6 6   2      2
+--R                  (- 18874368a b f  + 18874368a b d f - 67108864a b d e )%%DP0
+--R                + 
+--R                          4 2   4         4 2 2 3         3 3 2 2
+--R                  - 10368a b d f  + 18432a b e f  + 55296a b d e f
+--R                + 
+--R                          3 3   4         2 4 5
+--R                  - 65536a b d e  + 10368a b d
+--R             *
+--R                %%DP1
+--R            + 
+--R                          7 5 3            6 6 2             6 6   2      3
+--R              (- 18874368a b f  + 18874368a b d f - 67108864a b d e )%%DP0
+--R            + 
+--R                          4 2   4         4 2 2 3         3 3 3 2
+--R                  - 41472a b d f  - 36864a b e f  + 41472a b d f
+--R                + 
+--R                           3 3 2 2           3 3   4
+--R                  - 110592a b d e f - 131072a b d e
+--R             *
+--R                %%DP0
+--R            + 
+--R                      3 6       2   2 4        2     2 3
+--R                  243a f  - 243a b d f  + 3456a b d e f
+--R                + 
+--R                          2   4         2 4  2          2 3 2           2 2 4
+--R                  (- 3072a b e  - 243a b d )f  + 3456a b d e f - 3072a b d e
+--R                + 
+--R                      3 6
+--R                  243b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5        2   2   3        2     3 2
+--R              - 324a e f  + 2592a b d e f  - 1728a b d e f
+--R            + 
+--R                      2   5         2 4             2 3 3
+--R              (- 2048a b e  + 324a b d e)f + 1728a b d e
+--R     + 
+--R                +-+ +-+4+-+3 +-+4+-+3
+--R         128a b\|2 \|a \|a  \|b \|b  %%DP0
+--R      *
+--R         log
+--R                        7 5 3            6 6 2             6 6   2      3
+--R              (18874368a b f  - 18874368a b d f + 67108864a b d e )%%DP0
+--R            + 
+--R                       5 4     2           5 4 3           4 5 3       2
+--R              (1769472a b d e f  - 2097152a b e f + 589824a b d e)%%DP0
+--R            + 
+--R                        4 2   4         4 2 2 3         3 3 3 2
+--R                  31104a b d f  + 55296a b e f  - 41472a b d f
+--R                + 
+--R                         3 3 2 2          3 3   4         2 4 5
+--R                  165888a b d e f + 65536a b d e  + 10368a b d
+--R             *
+--R                %%DP0
+--R            + 
+--R                      3 6       2   2 4        2     2 3
+--R                  243a f  - 243a b d f  + 3456a b d e f
+--R                + 
+--R                          2   4         2 4  2          2 3 2           2 2 4
+--R                  (- 3072a b e  - 243a b d )f  + 3456a b d e f - 3072a b d e
+--R                + 
+--R                      3 6
+--R                  243b d
+--R             *
+--R                x
+--R            + 
+--R                  3   5        2     3 2           2   5          2 4
+--R              972a e f  + 2880a b d e f  + (- 2048a b e  + 1620a b d e)f
+--R            + 
+--R                       2 3 3
+--R              - 2880a b d e
+--R     + 
+--R             +-+        +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (3a f\|b  - 3b d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R               +-+        +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a f\|b  + 3b d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|b  + \|a
+--R       (- 6a f\|b  - 6b d\|a )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+        +-+      x\|2 \|b  - \|a
+--R       (- 6a f\|b  - 6b d\|a )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                2 +-+
+--R            +-+4+-+3 4+-+3     x \|b
+--R       - 8e\|2 \|a   \|b  atan(------)
+--R                                 +-+
+--R                                \|a
+--R  /
+--R            +-+ +-+4+-+3 +-+4+-+3
+--R     128a b\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 792
+
+--S 793 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  4        2  +-+4+-+2         6         4         2  +-+
+--R           ((12f x  + 12d x )\|a \|a   - 3b d x  - 6a f x  + 3a d x )\|b
+--R         + 
+--R                  6         4         2        4+-+2
+--R           (6b f x  + 6b d x  + 6a f x  + 6a d)\|a
+--R         + 
+--R                    6         4         2  +-+
+--R           (- 3b f x  - 6b d x  + 3a f x )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                  4         2        4+-+2
+--R           (3b d x  - 6a f x  - 3a d)\|a
+--R         + 
+--R                    6         4         2         +-+
+--R           (- 3b f x  - 3b d x  - 3a f x  - 3a d)\|a
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R              4         2         +-+4+-+2     2   6           4           2
+--R       (3b f x  - 6b d x  - 3a f)\|a \|a   + 3b d x  - 9a b f x  - 9a b d x
+--R     + 
+--R         2
+--R       3a f
+--R  /
+--R                  2 6       2   2  +-+4+-+2 +-+
+--R           (128a b x  + 128a b x )\|a \|a  \|b
+--R         + 
+--R                 3 8       2 2 4      3  4+-+2
+--R           (64a b x  + 128a b x  + 64a b)\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R             2 3 6       3 2 2
+--R       - 128a b x  - 128a b x
+--R                                                    Type: Expression(Integer)
+--E 793
+
+)clear all
+
+--S 794 of 953
+t0:=x^3*(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^4
+--R 
+--R
+--R                   6      5      4      3
+--R                f x  + e x  + d x  + c x
+--R   (1)  -----------------------------------------
+--R         4 16       3 12     2 2 8     3   4    4
+--R        b x   + 4a b x   + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 794
+
+--S 795 of 953
+r0:=1/12*(-c-d*x-e*x^2-f*x^3)/(b*(a+b*x^4)^3)+1/96*x*(d+2*e*x+3*f*x^2)/_
+   (a*b*(a+b*x^4)^2)+1/384*x*(7*d+12*e*x+15*f*x^2)/(a^2*b*(a+b*x^4))+_
+   1/32*e*atan(x^2*sqrt(b)/sqrt(a))/(a^(5/2)*b^(3/2))-1/512*log(-a^(1/4)*_
+   b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-5*f*sqrt(a)+7*d*sqrt(b))/_
+   (a^(11/4)*b^(7/4)*sqrt(2))+1/512*log(a^(1/4)*b^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(b))*(-5*f*sqrt(a)+7*d*sqrt(b))/(a^(11/4)*b^(7/4)*_
+   sqrt(2))-1/256*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(5*f*sqrt(a)+7*_
+   d*sqrt(b))/(a^(11/4)*b^(7/4)*sqrt(2))+1/256*atan(1+b^(1/4)*x*_
+   sqrt(2)/a^(1/4))*(5*f*sqrt(a)+7*d*sqrt(b))/(a^(11/4)*b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   3   12      2 2   8      3     4      4   +-+
+--R           (- 15a b f x   - 45a b f x  - 45a b f x  - 15a f)\|b
+--R         + 
+--R               4   12        3   8      2 2   4      3     +-+
+--R           (21b d x   + 63a b d x  + 63a b d x  + 21a b d)\|a
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                 3   12      2 2   8      3     4      4   +-+
+--R           (15a b f x   + 45a b f x  + 45a b f x  + 15a f)\|b
+--R         + 
+--R                 4   12        3   8      2 2   4      3     +-+
+--R           (- 21b d x   - 63a b d x  - 63a b d x  - 21a b d)\|a
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                 3   12      2 2   8      3     4      4   +-+
+--R           (30a b f x   + 90a b f x  + 90a b f x  + 30a f)\|b
+--R         + 
+--R               4   12         3   8       2 2   4      3     +-+
+--R           (42b d x   + 126a b d x  + 126a b d x  + 42a b d)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  + \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                 3   12      2 2   8      3     4      4   +-+
+--R           (30a b f x   + 90a b f x  + 90a b f x  + 30a f)\|b
+--R         + 
+--R               4   12         3   8       2 2   4      3     +-+
+--R           (42b d x   + 126a b d x  + 126a b d x  + 42a b d)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  - \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                                                                           2 +-+
+--R           3   12         2   8       2     4      3   +-+4+-+3 4+-+3     x \|b
+--R       (48b e x   + 144a b e x  + 144a b e x  + 48a e)\|2 \|a   \|b  atan(------)
+--R                                                                            +-+
+--R                                                                           \|a
+--R     + 
+--R              2   11      2   10      2   9             7             6
+--R           60b f x   + 48b e x   + 28b d x  + 168a b f x  + 128a b e x
+--R         + 
+--R                    5      2   3      2   2      2          2
+--R           72a b d x  - 20a f x  - 48a e x  - 84a d x - 128a c
+--R      *
+--R          +-+ +-+4+-+3 +-+4+-+3
+--R         \|2 \|a \|a  \|b \|b
+--R  /
+--R           2 4 12        3 3 8        4 2 4        5   +-+ +-+4+-+3 +-+4+-+3
+--R     (1536a b x   + 4608a b x  + 4608a b x  + 1536a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 795
+
+--S 796 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2 4 12       3 3 8       4 2 4       5
+--R             (192a b x   + 576a b x  + 576a b x  + 192a b)
+--R          *
+--R             ROOT
+--R                            5 3     2         5 3                    5 3     2
+--R                    - 49152a b %%DQ1  - 32768a b %%DQ0 %%DQ1 - 49152a b %%DQ0
+--R                  + 
+--R                                 2
+--R                    - 35d f - 32e
+--R               /
+--R                        5 3
+--R                  16384a b
+--R         + 
+--R                  2 4 12       3 3 8       4 2 4       5
+--R           (- 192a b x   - 576a b x  - 576a b x  - 192a b)%%DQ1
+--R         + 
+--R                  2 4 12       3 3 8       4 2 4       5
+--R           (- 192a b x   - 576a b x  - 576a b x  - 192a b)%%DQ0
+--R      *
+--R         log
+--R                                     10 5 3               9 6 2
+--R                          8388608000a  b f  - 16441671680a b d f
+--R                        + 
+--R                                      9 6   2
+--R                          60129542144a b d e
+--R                     *
+--R                        %%DQ0
+--R                    + 
+--R                                7 4     2             7 4 3              6 5 3
+--R                    - 550502400a b d e f  + 671088640a b e f - 359661568a b d e
+--R                 *
+--R                    %%DQ1
+--R                + 
+--R                                    7 4     2             7 4 3
+--R                        - 550502400a b d e f  + 671088640a b e f
+--R                      + 
+--R                                    6 5 3
+--R                        - 359661568a b d e
+--R                 *
+--R                    %%DQ0
+--R                + 
+--R                            5 2   4           5 2 2 3            4 3 2 2
+--R                  - 1120000a b d f  + 2048000a b e f  + 12042240a b d e f
+--R                + 
+--R                             4 3   4           3 4 5
+--R                  - 14680064a b d e  + 4302592a b d
+--R             *
+--R                ROOT
+--R                               5 3     2         5 3
+--R                       - 49152a b %%DQ1  - 32768a b %%DQ0 %%DQ1
+--R                     + 
+--R                               5 3     2              2
+--R                       - 49152a b %%DQ0  - 35d f - 32e
+--R                  /
+--R                           5 3
+--R                     16384a b
+--R            + 
+--R                                   10 5 3               9 6 2
+--R                        8388608000a  b f  - 16441671680a b d f
+--R                      + 
+--R                                    9 6   2
+--R                        60129542144a b d e
+--R                 *
+--R                    %%DQ0
+--R                + 
+--R                              7 4     2             7 4 3              6 5 3
+--R                  - 550502400a b d e f  + 671088640a b e f - 359661568a b d e
+--R             *
+--R                     2
+--R                %%DQ1
+--R            + 
+--R                                   10 5 3               9 6 2
+--R                        8388608000a  b f  - 16441671680a b d f
+--R                      + 
+--R                                    9 6   2
+--R                        60129542144a b d e
+--R                 *
+--R                         2
+--R                    %%DQ0
+--R                + 
+--R                          5 2   4           5 2 2 3            4 3 2 2
+--R                  1120000a b d f  - 2048000a b e f  - 12042240a b d e f
+--R                + 
+--R                           4 3   4           3 4 5
+--R                  14680064a b d e  - 4302592a b d
+--R             *
+--R                %%DQ1
+--R            + 
+--R                             7 4     2             7 4 3              6 5 3
+--R                (- 550502400a b d e f  + 671088640a b e f - 359661568a b d e)
+--R             *
+--R                     2
+--R                %%DQ0
+--R            + 
+--R                          5 2   4           5 2 2 3            4 3 2 2
+--R                  1120000a b d f  - 2048000a b e f  - 12042240a b d e f
+--R                + 
+--R                           4 3   4           3 4 5
+--R                  14680064a b d e  - 4302592a b d
+--R             *
+--R                %%DQ0
+--R            + 
+--R                        3 6         2   2 4          2     2 3
+--R                  15625a f  - 30625a b d f  + 448000a b d e f
+--R                + 
+--R                            2   4           2 4  2            2 3 2
+--R                  (- 409600a b e  - 60025a b d )f  + 878080a b d e f
+--R                + 
+--R                             2 2 4          3 6
+--R                  - 802816a b d e  + 117649b d
+--R             *
+--R                x
+--R            + 
+--R                      3   5          2   2   3         2     3 2
+--R              - 25000a e f  - 196000a b d e f  - 89600a b d e f
+--R            + 
+--R                      2   5            2 4               2 3 3
+--R              (327680a b e  - 288120a b d e)f + 175616a b d e
+--R     + 
+--R                    2 4 12       3 3 8       4 2 4       5
+--R             (- 192a b x   - 576a b x  - 576a b x  - 192a b)
+--R          *
+--R             ROOT
+--R                            5 3     2         5 3                    5 3     2
+--R                    - 49152a b %%DQ1  - 32768a b %%DQ0 %%DQ1 - 49152a b %%DQ0
+--R                  + 
+--R                                 2
+--R                    - 35d f - 32e
+--R               /
+--R                        5 3
+--R                  16384a b
+--R         + 
+--R                  2 4 12       3 3 8       4 2 4       5
+--R           (- 192a b x   - 576a b x  - 576a b x  - 192a b)%%DQ1
+--R         + 
+--R                  2 4 12       3 3 8       4 2 4       5
+--R           (- 192a b x   - 576a b x  - 576a b x  - 192a b)%%DQ0
+--R      *
+--R         log
+--R                                       10 5 3               9 6 2
+--R                          - 8388608000a  b f  + 16441671680a b d f
+--R                        + 
+--R                                        9 6   2
+--R                          - 60129542144a b d e
+--R                     *
+--R                        %%DQ0
+--R                    + 
+--R                                7 4     2             7 4 3              6 5 3
+--R                      550502400a b d e f  - 671088640a b e f + 359661568a b d e
+--R                 *
+--R                    %%DQ1
+--R                + 
+--R                               7 4     2             7 4 3              6 5 3
+--R                    (550502400a b d e f  - 671088640a b e f + 359661568a b d e)
+--R                 *
+--R                    %%DQ0
+--R                + 
+--R                          5 2   4           5 2 2 3            4 3 2 2
+--R                  1120000a b d f  - 2048000a b e f  - 12042240a b d e f
+--R                + 
+--R                           4 3   4           3 4 5
+--R                  14680064a b d e  - 4302592a b d
+--R             *
+--R                ROOT
+--R                               5 3     2         5 3
+--R                       - 49152a b %%DQ1  - 32768a b %%DQ0 %%DQ1
+--R                     + 
+--R                               5 3     2              2
+--R                       - 49152a b %%DQ0  - 35d f - 32e
+--R                  /
+--R                           5 3
+--R                     16384a b
+--R            + 
+--R                                   10 5 3               9 6 2
+--R                        8388608000a  b f  - 16441671680a b d f
+--R                      + 
+--R                                    9 6   2
+--R                        60129542144a b d e
+--R                 *
+--R                    %%DQ0
+--R                + 
+--R                              7 4     2             7 4 3              6 5 3
+--R                  - 550502400a b d e f  + 671088640a b e f - 359661568a b d e
+--R             *
+--R                     2
+--R                %%DQ1
+--R            + 
+--R                                   10 5 3               9 6 2
+--R                        8388608000a  b f  - 16441671680a b d f
+--R                      + 
+--R                                    9 6   2
+--R                        60129542144a b d e
+--R                 *
+--R                         2
+--R                    %%DQ0
+--R                + 
+--R                          5 2   4           5 2 2 3            4 3 2 2
+--R                  1120000a b d f  - 2048000a b e f  - 12042240a b d e f
+--R                + 
+--R                           4 3   4           3 4 5
+--R                  14680064a b d e  - 4302592a b d
+--R             *
+--R                %%DQ1
+--R            + 
+--R                             7 4     2             7 4 3              6 5 3
+--R                (- 550502400a b d e f  + 671088640a b e f - 359661568a b d e)
+--R             *
+--R                     2
+--R                %%DQ0
+--R            + 
+--R                          5 2   4           5 2 2 3            4 3 2 2
+--R                  1120000a b d f  - 2048000a b e f  - 12042240a b d e f
+--R                + 
+--R                           4 3   4           3 4 5
+--R                  14680064a b d e  - 4302592a b d
+--R             *
+--R                %%DQ0
+--R            + 
+--R                        3 6         2   2 4          2     2 3
+--R                  15625a f  - 30625a b d f  + 448000a b d e f
+--R                + 
+--R                            2   4           2 4  2            2 3 2
+--R                  (- 409600a b e  - 60025a b d )f  + 878080a b d e f
+--R                + 
+--R                             2 2 4          3 6
+--R                  - 802816a b d e  + 117649b d
+--R             *
+--R                x
+--R            + 
+--R                      3   5          2   2   3         2     3 2
+--R              - 25000a e f  - 196000a b d e f  - 89600a b d e f
+--R            + 
+--R                      2   5            2 4               2 3 3
+--R              (327680a b e  - 288120a b d e)f + 175616a b d e
+--R     + 
+--R              2 4 12        3 3 8        4 2 4       5
+--R         (384a b x   + 1152a b x  + 1152a b x  + 384a b)%%DQ1
+--R      *
+--R         log
+--R                                    10 5 3               9 6 2
+--R                      - 16777216000a  b f  + 32883343360a b d f
+--R                    + 
+--R                                     9 6   2
+--R                      - 120259084288a b d e
+--R                 *
+--R                    %%DQ0
+--R                + 
+--R                             7 4     2              7 4 3              6 5 3
+--R                  1101004800a b d e f  - 1342177280a b e f + 719323136a b d e
+--R             *
+--R                     2
+--R                %%DQ1
+--R            + 
+--R                                    10 5 3               9 6 2
+--R                      - 16777216000a  b f  + 32883343360a b d f
+--R                    + 
+--R                                     9 6   2
+--R                      - 120259084288a b d e
+--R                 *
+--R                         2
+--R                    %%DQ0
+--R                + 
+--R                            5 2   4           5 2 2 3            4 3 2 2
+--R                  - 2240000a b d f  + 4096000a b e f  + 24084480a b d e f
+--R                + 
+--R                             4 3   4           3 4 5
+--R                  - 29360128a b d e  + 8605184a b d
+--R             *
+--R                %%DQ1
+--R            + 
+--R                                  10 5 3               9 6 2
+--R                    - 16777216000a  b f  + 32883343360a b d f
+--R                  + 
+--R                                   9 6   2
+--R                    - 120259084288a b d e
+--R             *
+--R                     3
+--R                %%DQ0
+--R            + 
+--R                            5 2   4           5 2 2 3            4 3 3 2
+--R                  - 8960000a b d f  - 8192000a b e f  + 17561600a b d f
+--R                + 
+--R                             4 3 2 2             4 3   4
+--R                  - 48168960a b d e f - 58720256a b d e
+--R             *
+--R                %%DQ0
+--R            + 
+--R                        3 6         2   2 4          2     2 3
+--R                  15625a f  - 30625a b d f  + 448000a b d e f
+--R                + 
+--R                            2   4           2 4  2            2 3 2
+--R                  (- 409600a b e  - 60025a b d )f  + 878080a b d e f
+--R                + 
+--R                             2 2 4          3 6
+--R                  - 802816a b d e  + 117649b d
+--R             *
+--R                x
+--R            + 
+--R                      3   5          2   2   3          2     3 2
+--R              - 25000a e f  + 392000a b d e f  - 268800a b d e f
+--R            + 
+--R                        2   5           2 4               2 3 3
+--R              (- 327680a b e  + 96040a b d e)f + 526848a b d e
+--R     + 
+--R              2 4 12        3 3 8        4 2 4       5
+--R         (384a b x   + 1152a b x  + 1152a b x  + 384a b)%%DQ0
+--R      *
+--R         log
+--R                             10 5 3               9 6 2                 9 6   2
+--R                (16777216000a  b f  - 32883343360a b d f + 120259084288a b d e )
+--R             *
+--R                     3
+--R                %%DQ0
+--R            + 
+--R                            7 4     2              7 4 3              6 5 3
+--R                (1101004800a b d e f  - 1342177280a b e f + 719323136a b d e)
+--R             *
+--R                     2
+--R                %%DQ0
+--R            + 
+--R                          5 2   4            5 2 2 3            4 3 3 2
+--R                  6720000a b d f  + 12288000a b e f  - 17561600a b d f
+--R                + 
+--R                           4 3 2 2             4 3   4           3 4 5
+--R                  72253440a b d e f + 29360128a b d e  + 8605184a b d
+--R             *
+--R                %%DQ0
+--R            + 
+--R                        3 6         2   2 4          2     2 3
+--R                  15625a f  - 30625a b d f  + 448000a b d e f
+--R                + 
+--R                            2   4           2 4  2            2 3 2
+--R                  (- 409600a b e  - 60025a b d )f  + 878080a b d e f
+--R                + 
+--R                             2 2 4          3 6
+--R                  - 802816a b d e  + 117649b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5          2     3 2             2   5            2 4
+--R              75000a e f  + 448000a b d e f  + (- 327680a b e  + 480200a b d e)f
+--R            + 
+--R                         2 3 3
+--R              - 878080a b d e
+--R     + 
+--R          2   11      2   10     2   9            7            6            5
+--R       15b f x   + 12b e x   + 7b d x  + 42a b f x  + 32a b e x  + 18a b d x
+--R     + 
+--R           2   3      2   2      2         2
+--R       - 5a f x  - 12a e x  - 21a d x - 32a c
+--R  /
+--R         2 4 12        3 3 8        4 2 4       5
+--R     384a b x   + 1152a b x  + 1152a b x  + 384a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 796
+
+--S 797 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 2  +-+ +-+4+-+3 +-+4+-+3
+--R             256a b\|2 \|a \|a  \|b \|b
+--R          *
+--R             ROOT
+--R                            5 3     2         5 3                    5 3     2
+--R                    - 49152a b %%DQ1  - 32768a b %%DQ0 %%DQ1 - 49152a b %%DQ0
+--R                  + 
+--R                                 2
+--R                    - 35d f - 32e
+--R               /
+--R                        5 3
+--R                  16384a b
+--R         + 
+--R               2  +-+ +-+4+-+3 +-+4+-+3            2  +-+ +-+4+-+3 +-+4+-+3
+--R         - 256a b\|2 \|a \|a  \|b \|b  %%DQ1 - 256a b\|2 \|a \|a  \|b \|b  %%DQ0
+--R      *
+--R         log
+--R                                     10 5 3               9 6 2
+--R                          8388608000a  b f  - 16441671680a b d f
+--R                        + 
+--R                                      9 6   2
+--R                          60129542144a b d e
+--R                     *
+--R                        %%DQ0
+--R                    + 
+--R                                7 4     2             7 4 3              6 5 3
+--R                    - 550502400a b d e f  + 671088640a b e f - 359661568a b d e
+--R                 *
+--R                    %%DQ1
+--R                + 
+--R                                    7 4     2             7 4 3
+--R                        - 550502400a b d e f  + 671088640a b e f
+--R                      + 
+--R                                    6 5 3
+--R                        - 359661568a b d e
+--R                 *
+--R                    %%DQ0
+--R                + 
+--R                            5 2   4           5 2 2 3            4 3 2 2
+--R                  - 1120000a b d f  + 2048000a b e f  + 12042240a b d e f
+--R                + 
+--R                             4 3   4           3 4 5
+--R                  - 14680064a b d e  + 4302592a b d
+--R             *
+--R                ROOT
+--R                               5 3     2         5 3
+--R                       - 49152a b %%DQ1  - 32768a b %%DQ0 %%DQ1
+--R                     + 
+--R                               5 3     2              2
+--R                       - 49152a b %%DQ0  - 35d f - 32e
+--R                  /
+--R                           5 3
+--R                     16384a b
+--R            + 
+--R                                   10 5 3               9 6 2
+--R                        8388608000a  b f  - 16441671680a b d f
+--R                      + 
+--R                                    9 6   2
+--R                        60129542144a b d e
+--R                 *
+--R                    %%DQ0
+--R                + 
+--R                              7 4     2             7 4 3              6 5 3
+--R                  - 550502400a b d e f  + 671088640a b e f - 359661568a b d e
+--R             *
+--R                     2
+--R                %%DQ1
+--R            + 
+--R                                   10 5 3               9 6 2
+--R                        8388608000a  b f  - 16441671680a b d f
+--R                      + 
+--R                                    9 6   2
+--R                        60129542144a b d e
+--R                 *
+--R                         2
+--R                    %%DQ0
+--R                + 
+--R                          5 2   4           5 2 2 3            4 3 2 2
+--R                  1120000a b d f  - 2048000a b e f  - 12042240a b d e f
+--R                + 
+--R                           4 3   4           3 4 5
+--R                  14680064a b d e  - 4302592a b d
+--R             *
+--R                %%DQ1
+--R            + 
+--R                             7 4     2             7 4 3              6 5 3
+--R                (- 550502400a b d e f  + 671088640a b e f - 359661568a b d e)
+--R             *
+--R                     2
+--R                %%DQ0
+--R            + 
+--R                          5 2   4           5 2 2 3            4 3 2 2
+--R                  1120000a b d f  - 2048000a b e f  - 12042240a b d e f
+--R                + 
+--R                           4 3   4           3 4 5
+--R                  14680064a b d e  - 4302592a b d
+--R             *
+--R                %%DQ0
+--R            + 
+--R                        3 6         2   2 4          2     2 3
+--R                  15625a f  - 30625a b d f  + 448000a b d e f
+--R                + 
+--R                            2   4           2 4  2            2 3 2
+--R                  (- 409600a b e  - 60025a b d )f  + 878080a b d e f
+--R                + 
+--R                             2 2 4          3 6
+--R                  - 802816a b d e  + 117649b d
+--R             *
+--R                x
+--R            + 
+--R                      3   5          2   2   3         2     3 2
+--R              - 25000a e f  - 196000a b d e f  - 89600a b d e f
+--R            + 
+--R                      2   5            2 4               2 3 3
+--R              (327680a b e  - 288120a b d e)f + 175616a b d e
+--R     + 
+--R           -
+--R                    2  +-+ +-+4+-+3 +-+4+-+3
+--R                256a b\|2 \|a \|a  \|b \|b
+--R             *
+--R                ROOT
+--R                               5 3     2         5 3
+--R                       - 49152a b %%DQ1  - 32768a b %%DQ0 %%DQ1
+--R                     + 
+--R                               5 3     2              2
+--R                       - 49152a b %%DQ0  - 35d f - 32e
+--R                  /
+--R                           5 3
+--R                     16384a b
+--R         + 
+--R               2  +-+ +-+4+-+3 +-+4+-+3            2  +-+ +-+4+-+3 +-+4+-+3
+--R         - 256a b\|2 \|a \|a  \|b \|b  %%DQ1 - 256a b\|2 \|a \|a  \|b \|b  %%DQ0
+--R      *
+--R         log
+--R                                       10 5 3               9 6 2
+--R                          - 8388608000a  b f  + 16441671680a b d f
+--R                        + 
+--R                                        9 6   2
+--R                          - 60129542144a b d e
+--R                     *
+--R                        %%DQ0
+--R                    + 
+--R                                7 4     2             7 4 3              6 5 3
+--R                      550502400a b d e f  - 671088640a b e f + 359661568a b d e
+--R                 *
+--R                    %%DQ1
+--R                + 
+--R                               7 4     2             7 4 3              6 5 3
+--R                    (550502400a b d e f  - 671088640a b e f + 359661568a b d e)
+--R                 *
+--R                    %%DQ0
+--R                + 
+--R                          5 2   4           5 2 2 3            4 3 2 2
+--R                  1120000a b d f  - 2048000a b e f  - 12042240a b d e f
+--R                + 
+--R                           4 3   4           3 4 5
+--R                  14680064a b d e  - 4302592a b d
+--R             *
+--R                ROOT
+--R                               5 3     2         5 3
+--R                       - 49152a b %%DQ1  - 32768a b %%DQ0 %%DQ1
+--R                     + 
+--R                               5 3     2              2
+--R                       - 49152a b %%DQ0  - 35d f - 32e
+--R                  /
+--R                           5 3
+--R                     16384a b
+--R            + 
+--R                                   10 5 3               9 6 2
+--R                        8388608000a  b f  - 16441671680a b d f
+--R                      + 
+--R                                    9 6   2
+--R                        60129542144a b d e
+--R                 *
+--R                    %%DQ0
+--R                + 
+--R                              7 4     2             7 4 3              6 5 3
+--R                  - 550502400a b d e f  + 671088640a b e f - 359661568a b d e
+--R             *
+--R                     2
+--R                %%DQ1
+--R            + 
+--R                                   10 5 3               9 6 2
+--R                        8388608000a  b f  - 16441671680a b d f
+--R                      + 
+--R                                    9 6   2
+--R                        60129542144a b d e
+--R                 *
+--R                         2
+--R                    %%DQ0
+--R                + 
+--R                          5 2   4           5 2 2 3            4 3 2 2
+--R                  1120000a b d f  - 2048000a b e f  - 12042240a b d e f
+--R                + 
+--R                           4 3   4           3 4 5
+--R                  14680064a b d e  - 4302592a b d
+--R             *
+--R                %%DQ1
+--R            + 
+--R                             7 4     2             7 4 3              6 5 3
+--R                (- 550502400a b d e f  + 671088640a b e f - 359661568a b d e)
+--R             *
+--R                     2
+--R                %%DQ0
+--R            + 
+--R                          5 2   4           5 2 2 3            4 3 2 2
+--R                  1120000a b d f  - 2048000a b e f  - 12042240a b d e f
+--R                + 
+--R                           4 3   4           3 4 5
+--R                  14680064a b d e  - 4302592a b d
+--R             *
+--R                %%DQ0
+--R            + 
+--R                        3 6         2   2 4          2     2 3
+--R                  15625a f  - 30625a b d f  + 448000a b d e f
+--R                + 
+--R                            2   4           2 4  2            2 3 2
+--R                  (- 409600a b e  - 60025a b d )f  + 878080a b d e f
+--R                + 
+--R                             2 2 4          3 6
+--R                  - 802816a b d e  + 117649b d
+--R             *
+--R                x
+--R            + 
+--R                      3   5          2   2   3         2     3 2
+--R              - 25000a e f  - 196000a b d e f  - 89600a b d e f
+--R            + 
+--R                      2   5            2 4               2 3 3
+--R              (327680a b e  - 288120a b d e)f + 175616a b d e
+--R     + 
+--R             2  +-+ +-+4+-+3 +-+4+-+3
+--R         512a b\|2 \|a \|a  \|b \|b  %%DQ1
+--R      *
+--R         log
+--R                                    10 5 3               9 6 2
+--R                      - 16777216000a  b f  + 32883343360a b d f
+--R                    + 
+--R                                     9 6   2
+--R                      - 120259084288a b d e
+--R                 *
+--R                    %%DQ0
+--R                + 
+--R                             7 4     2              7 4 3              6 5 3
+--R                  1101004800a b d e f  - 1342177280a b e f + 719323136a b d e
+--R             *
+--R                     2
+--R                %%DQ1
+--R            + 
+--R                                    10 5 3               9 6 2
+--R                      - 16777216000a  b f  + 32883343360a b d f
+--R                    + 
+--R                                     9 6   2
+--R                      - 120259084288a b d e
+--R                 *
+--R                         2
+--R                    %%DQ0
+--R                + 
+--R                            5 2   4           5 2 2 3            4 3 2 2
+--R                  - 2240000a b d f  + 4096000a b e f  + 24084480a b d e f
+--R                + 
+--R                             4 3   4           3 4 5
+--R                  - 29360128a b d e  + 8605184a b d
+--R             *
+--R                %%DQ1
+--R            + 
+--R                                  10 5 3               9 6 2
+--R                    - 16777216000a  b f  + 32883343360a b d f
+--R                  + 
+--R                                   9 6   2
+--R                    - 120259084288a b d e
+--R             *
+--R                     3
+--R                %%DQ0
+--R            + 
+--R                            5 2   4           5 2 2 3            4 3 3 2
+--R                  - 8960000a b d f  - 8192000a b e f  + 17561600a b d f
+--R                + 
+--R                             4 3 2 2             4 3   4
+--R                  - 48168960a b d e f - 58720256a b d e
+--R             *
+--R                %%DQ0
+--R            + 
+--R                        3 6         2   2 4          2     2 3
+--R                  15625a f  - 30625a b d f  + 448000a b d e f
+--R                + 
+--R                            2   4           2 4  2            2 3 2
+--R                  (- 409600a b e  - 60025a b d )f  + 878080a b d e f
+--R                + 
+--R                             2 2 4          3 6
+--R                  - 802816a b d e  + 117649b d
+--R             *
+--R                x
+--R            + 
+--R                      3   5          2   2   3          2     3 2
+--R              - 25000a e f  + 392000a b d e f  - 268800a b d e f
+--R            + 
+--R                        2   5           2 4               2 3 3
+--R              (- 327680a b e  + 96040a b d e)f + 526848a b d e
+--R     + 
+--R             2  +-+ +-+4+-+3 +-+4+-+3
+--R         512a b\|2 \|a \|a  \|b \|b  %%DQ0
+--R      *
+--R         log
+--R                             10 5 3               9 6 2                 9 6   2
+--R                (16777216000a  b f  - 32883343360a b d f + 120259084288a b d e )
+--R             *
+--R                     3
+--R                %%DQ0
+--R            + 
+--R                            7 4     2              7 4 3              6 5 3
+--R                (1101004800a b d e f  - 1342177280a b e f + 719323136a b d e)
+--R             *
+--R                     2
+--R                %%DQ0
+--R            + 
+--R                          5 2   4            5 2 2 3            4 3 3 2
+--R                  6720000a b d f  + 12288000a b e f  - 17561600a b d f
+--R                + 
+--R                           4 3 2 2             4 3   4           3 4 5
+--R                  72253440a b d e f + 29360128a b d e  + 8605184a b d
+--R             *
+--R                %%DQ0
+--R            + 
+--R                        3 6         2   2 4          2     2 3
+--R                  15625a f  - 30625a b d f  + 448000a b d e f
+--R                + 
+--R                            2   4           2 4  2            2 3 2
+--R                  (- 409600a b e  - 60025a b d )f  + 878080a b d e f
+--R                + 
+--R                             2 2 4          3 6
+--R                  - 802816a b d e  + 117649b d
+--R             *
+--R                x
+--R            + 
+--R                    3   5          2     3 2             2   5            2 4
+--R              75000a e f  + 448000a b d e f  + (- 327680a b e  + 480200a b d e)f
+--R            + 
+--R                         2 3 3
+--R              - 878080a b d e
+--R     + 
+--R             +-+        +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (5a f\|b  - 7b d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R               +-+        +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- 5a f\|b  + 7b d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                       +-+4+-+   4+-+
+--R                +-+         +-+      x\|2 \|b  + \|a
+--R       (- 10a f\|b  - 14b d\|a )atan(----------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                       +-+4+-+   4+-+
+--R                +-+         +-+      x\|2 \|b  - \|a
+--R       (- 10a f\|b  - 14b d\|a )atan(----------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                 2 +-+
+--R             +-+4+-+3 4+-+3     x \|b
+--R       - 16e\|2 \|a   \|b  atan(------)
+--R                                  +-+
+--R                                 \|a
+--R  /
+--R         2  +-+ +-+4+-+3 +-+4+-+3
+--R     512a b\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 797
+
+--S 798 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R                  4        2  +-+4+-+2         6          4         2  +-+
+--R           ((20f x  + 28d x )\|a \|a   - 7b d x  - 10a f x  + 7a d x )\|b
+--R         + 
+--R                   6          4          2         4+-+2
+--R           (10b f x  + 14b d x  + 10a f x  + 14a d)\|a
+--R         + 
+--R                    6          4         2  +-+
+--R           (- 5b f x  - 14b d x  + 5a f x )\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R                  4          2        4+-+2
+--R           (7b d x  - 10a f x  - 7a d)\|a
+--R         + 
+--R                    6         4         2         +-+
+--R           (- 5b f x  - 7b d x  - 5a f x  - 7a d)\|a
+--R      *
+--R          +-+
+--R         \|b
+--R     + 
+--R              4          2         +-+4+-+2     2   6            4            2
+--R       (5b f x  - 14b d x  - 5a f)\|a \|a   + 7b d x  - 15a b f x  - 21a b d x
+--R     + 
+--R         2
+--R       5a f
+--R  /
+--R                2 2 6       3   2  +-+4+-+2 +-+
+--R           (512a b x  + 512a b x )\|a \|a  \|b
+--R         + 
+--R                2 3 8       3 2 4       4  4+-+2
+--R           (256a b x  + 512a b x  + 256a b)\|a
+--R      *
+--R         4+-+2
+--R         \|b
+--R     + 
+--R             3 3 6       4 2 2
+--R       - 512a b x  - 512a b x
+--R                                                    Type: Expression(Integer)
+--E 798
+
+)clear all
+
+--S 799 of 953
+t0:=(c+d*x^(-1+n))*(a+b*x^n)^3
+--R 
+--R
+--R   (1)
+--R       3   n - 1    3    n 3        2   n - 1       2    n 2
+--R     (b d x      + b c)(x )  + (3a b d x      + 3a b c)(x )
+--R   + 
+--R        2     n - 1     2     n    3   n - 1    3
+--R     (3a b d x      + 3a b c)x  + a d x      + a c
+--R                                                    Type: Expression(Integer)
+--E 799
+
+--S 800 of 953
+r0:=a^3*c*x+3*a^2*b*c*x^(1+n)/(1+n)+3*a*b^2*c*x^(1+2*n)/(1+2*n)+_
+   b^3*c*x^(1+3*n)/(1+3*n)+1/4*d*(a+b*x^n)^4/(b*n)
+--R 
+--R
+--R   (2)
+--R          4   3      4   2     4     3n + 1
+--R       (8b c n  + 12b c n  + 4b c n)x
+--R     + 
+--R             3   3        3   2        3     2n + 1
+--R       (36a b c n  + 48a b c n  + 12a b c n)x
+--R     + 
+--R           2 2   3      2 2   2      2 2     n + 1
+--R       (72a b c n  + 60a b c n  + 12a b c n)x
+--R     + 
+--R          4   3      4   2     4       4    n 4
+--R       (6b d n  + 11b d n  + 6b d n + b d)(x )
+--R     + 
+--R             3   3        3   2        3          3    n 3
+--R       (24a b d n  + 44a b d n  + 24a b d n + 4a b d)(x )
+--R     + 
+--R           2 2   3      2 2   2      2 2        2 2    n 2
+--R       (36a b d n  + 66a b d n  + 36a b d n + 6a b d)(x )
+--R     + 
+--R           3     3      3     2      3          3     n
+--R       (24a b d n  + 44a b d n  + 24a b d n + 4a b d)x
+--R     + 
+--R           3     4      3     3      3     2     3            4   3      4   2
+--R       (24a b c n  + 44a b c n  + 24a b c n  + 4a b c n)x + 6a d n  + 11a d n
+--R     + 
+--R         4       4
+--R       6a d n + a d
+--R  /
+--R          4        3        2
+--R     24b n  + 44b n  + 24b n  + 4b n
+--R                                                    Type: Expression(Integer)
+--E 800
+
+--S 801 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3   3      3   2     3       3     n log(x) 4
+--R       (6b d n  + 11b d n  + 6b d n + b d)(%e        )
+--R     + 
+--R              3   3      3   2     3             2   3        2   2        2
+--R           (8b c n  + 12b c n  + 4b c n)x + 24a b d n  + 44a b d n  + 24a b d n
+--R         + 
+--R               2
+--R           4a b d
+--R      *
+--R            n log(x) 3
+--R         (%e        )
+--R     + 
+--R                 2   3        2   2        2           2     3      2     2
+--R           (36a b c n  + 48a b c n  + 12a b c n)x + 36a b d n  + 66a b d n
+--R         + 
+--R              2          2
+--R           36a b d n + 6a b d
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R               2     3      2     2      2             3   3      3   2
+--R           (72a b c n  + 60a b c n  + 12a b c n)x + 24a d n  + 44a d n
+--R         + 
+--R              3        3
+--R           24a d n + 4a d
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R           3   4      3   3      3   2     3
+--R       (24a c n  + 44a c n  + 24a c n  + 4a c n)x
+--R  /
+--R        4      3      2
+--R     24n  + 44n  + 24n  + 4n
+--R                                         Type: Union(Expression(Integer),...)
+--E 801
+
+--S 802 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          4   3      4   2     4       4     n log(x) 4
+--R       (6b d n  + 11b d n  + 6b d n + b d)(%e        )
+--R     + 
+--R              4   3      4   2     4             3   3        3   2        3
+--R           (8b c n  + 12b c n  + 4b c n)x + 24a b d n  + 44a b d n  + 24a b d n
+--R         + 
+--R               3
+--R           4a b d
+--R      *
+--R            n log(x) 3
+--R         (%e        )
+--R     + 
+--R                 3   3        3   2        3           2 2   3      2 2   2
+--R           (36a b c n  + 48a b c n  + 12a b c n)x + 36a b d n  + 66a b d n
+--R         + 
+--R              2 2        2 2
+--R           36a b d n + 6a b d
+--R      *
+--R            n log(x) 2
+--R         (%e        )
+--R     + 
+--R               2 2   3      2 2   2      2 2           3     3      3     2
+--R           (72a b c n  + 60a b c n  + 12a b c n)x + 24a b d n  + 44a b d n
+--R         + 
+--R              3          3
+--R           24a b d n + 4a b d
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R            4   3      4   2     4     3n + 1
+--R       (- 8b c n  - 12b c n  - 4b c n)x
+--R     + 
+--R               3   3        3   2        3     2n + 1
+--R       (- 36a b c n  - 48a b c n  - 12a b c n)x
+--R     + 
+--R             2 2   3      2 2   2      2 2     n + 1
+--R       (- 72a b c n  - 60a b c n  - 12a b c n)x
+--R     + 
+--R            4   3      4   2     4       4    n 4
+--R       (- 6b d n  - 11b d n  - 6b d n - b d)(x )
+--R     + 
+--R               3   3        3   2        3          3    n 3
+--R       (- 24a b d n  - 44a b d n  - 24a b d n - 4a b d)(x )
+--R     + 
+--R             2 2   3      2 2   2      2 2        2 2    n 2
+--R       (- 36a b d n  - 66a b d n  - 36a b d n - 6a b d)(x )
+--R     + 
+--R             3     3      3     2      3          3     n     4   3      4   2
+--R       (- 24a b d n  - 44a b d n  - 24a b d n - 4a b d)x  - 6a d n  - 11a d n
+--R     + 
+--R           4       4
+--R       - 6a d n - a d
+--R  /
+--R          4        3        2
+--R     24b n  + 44b n  + 24b n  + 4b n
+--R                                                    Type: Expression(Integer)
+--E 802
+
+--S 803 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R        3     n log(x) 4     3          2     n log(x) 3
+--R       b d (%e        )  + (b c x + 3a b d)(%e        )
+--R     + 
+--R            2        2       n log(x) 2      2         3    n log(x)    3     3n
+--R       (3a b c x + 3a b d)(%e        )  + (3a b c x + a d)%e         - b c x x
+--R     + 
+--R             2     2n    3     n - 1  n 3       2     n - 1  n 2
+--R       - 3a b c x x   - b d x x     (x )  - 3a b d x x     (x )
+--R     + 
+--R            2       n - 1     2       n    3     n - 1
+--R       (- 3a b d x x      - 3a b c x)x  - a d x x
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 803
+
+)clear all
+
+--S 804 of 953
+t0:=(c+d*x^(-1+n))*(a+b*x^n)^2
+--R 
+--R
+--R   (1)
+--R     2   n - 1    2    n 2            n - 1           n    2   n - 1    2
+--R   (b d x      + b c)(x )  + (2a b d x      + 2a b c)x  + a d x      + a c
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 953
+r0:=a^2*c*x+2*a*b*c*x^(1+n)/(1+n)+b^2*c*x^(1+2*n)/(1+2*n)+_
+   1/3*d*(a+b*x^n)^3/(b*n)
+--R 
+--R
+--R   (2)
+--R          3   2     3     2n + 1         2   2       2     n + 1
+--R       (3b c n  + 3b c n)x       + (12a b c n  + 6a b c n)x
+--R     + 
+--R          3   2     3       3    n 3        2   2       2          2    n 2
+--R       (2b d n  + 3b d n + b d)(x )  + (6a b d n  + 9a b d n + 3a b d)(x )
+--R     + 
+--R          2     2     2          2     n      2     3     2     2     2
+--R       (6a b d n  + 9a b d n + 3a b d)x  + (6a b c n  + 9a b c n  + 3a b c n)x
+--R     + 
+--R         3   2     3       3
+--R       2a d n  + 3a d n + a d
+--R  /
+--R         3       2
+--R     6b n  + 9b n  + 3b n
+--R                                                    Type: Expression(Integer)
+--E 805
+
+--S 806 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2   2     2       2     n log(x) 3
+--R       (2b d n  + 3b d n + b d)(%e        )
+--R     + 
+--R           2   2     2                2                        n log(x) 2
+--R       ((3b c n  + 3b c n)x + 6a b d n  + 9a b d n + 3a b d)(%e        )
+--R     + 
+--R                  2                  2   2     2        2    n log(x)
+--R       ((12a b c n  + 6a b c n)x + 6a d n  + 9a d n + 3a d)%e
+--R     + 
+--R          2   3     2   2     2
+--R       (6a c n  + 9a c n  + 3a c n)x
+--R  /
+--R       3     2
+--R     6n  + 9n  + 3n
+--R                                         Type: Union(Expression(Integer),...)
+--E 806
+
+--S 807 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          3   2     3       3     n log(x) 3
+--R       (2b d n  + 3b d n + b d)(%e        )
+--R     + 
+--R           3   2     3            2   2       2          2     n log(x) 2
+--R       ((3b c n  + 3b c n)x + 6a b d n  + 9a b d n + 3a b d)(%e        )
+--R     + 
+--R              2   2       2          2     2     2          2      n log(x)
+--R       ((12a b c n  + 6a b c n)x + 6a b d n  + 9a b d n + 3a b d)%e
+--R     + 
+--R            3   2     3     2n + 1           2   2       2     n + 1
+--R       (- 3b c n  - 3b c n)x       + (- 12a b c n  - 6a b c n)x
+--R     + 
+--R            3   2     3       3    n 3          2   2       2          2    n 2
+--R       (- 2b d n  - 3b d n - b d)(x )  + (- 6a b d n  - 9a b d n - 3a b d)(x )
+--R     + 
+--R            2     2     2          2     n     3   2     3       3
+--R       (- 6a b d n  - 9a b d n - 3a b d)x  - 2a d n  - 3a d n - a d
+--R  /
+--R         3       2
+--R     6b n  + 9b n  + 3b n
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R        2     n log(x) 3     2                n log(x) 2
+--R       b d (%e        )  + (b c x + 2a b d)(%e        )
+--R     + 
+--R                    2    n log(x)    2     2n    2     n - 1  n 2
+--R       (2a b c x + a d)%e         - b c x x   - b d x x     (x )
+--R     + 
+--R                    n - 1             n    2     n - 1
+--R       (- 2a b d x x      - 2a b c x)x  - a d x x
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 808
+
+)clear all
+
+--S 809 of 953
+t0:=(c+d*x^(-1+n))*(a+b*x^n)
+--R 
+--R
+--R              n - 1        n        n - 1
+--R   (1)  (b d x      + b c)x  + a d x      + a c
+--R                                                    Type: Expression(Integer)
+--E 809
+
+--S 810 of 953
+r0:=a*c*x+a*d*x^n/n+1/2*b*d*x^(2*n)/n+b*c*x^(1+n)/(1+n)
+--R 
+--R
+--R   (2)
+--R                 2n           n + 1                   n          2
+--R   (b d n + b d)x   + 2b c n x      + (2a d n + 2a d)x  + (2a c n  + 2a c n)x
+--R   --------------------------------------------------------------------------
+--R                                      2
+--R                                    2n  + 2n
+--R                                                    Type: Expression(Integer)
+--E 810
+
+--S 811 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                       n log(x) 2                               n log(x)
+--R       (b d n + b d)(%e        )  + (2b c n x + 2a d n + 2a d)%e
+--R     + 
+--R              2
+--R       (2a c n  + 2a c n)x
+--R  /
+--R       2
+--R     2n  + 2n
+--R                                         Type: Union(Expression(Integer),...)
+--E 811
+
+--S 812 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       n log(x) 2                               n log(x)
+--R       (b d n + b d)(%e        )  + (2b c n x + 2a d n + 2a d)%e
+--R     + 
+--R                       2n           n + 1                     n
+--R       (- b d n - b d)x   - 2b c n x      + (- 2a d n - 2a d)x
+--R  /
+--R       2
+--R     2n  + 2n
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R              n log(x) 2                  n log(x)          2n - 1          n
+--R       b d (%e        )  + (b c x + a d)%e         - b d x x       - b c x x
+--R     + 
+--R                n - 1
+--R       - a d x x
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 813
+
+)clear all
+
+--S 814 of 953
+t0:=c+d*x^(-1+n)
+--R 
+--R
+--R           n - 1
+--R   (1)  d x      + c
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 953
+r0:=c*x+d*x^n/n
+--R 
+--R
+--R           n
+--R        d x  + c n x
+--R   (2)  ------------
+--R              n
+--R                                                    Type: Expression(Integer)
+--E 815
+
+--S 816 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R              (n - 1)log(x)
+--R        d x %e              + c n x
+--R   (3)  ---------------------------
+--R                     n
+--R                                         Type: Union(Expression(Integer),...)
+--E 816
+
+--S 817 of 953
+m0:=a0-r0
+--R 
+--R
+--R              (n - 1)log(x)      n
+--R        d x %e              - d x
+--R   (4)  --------------------------
+--R                     n
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R            (n - 1)log(x)      n - 1
+--R   (5)  d %e              - d x
+--R                                                    Type: Expression(Integer)
+--E 818
+
+)clear all
+
+--S 819 of 953
+t0:=(c+d*x^(-1+n))/(a+b*x^n)
+--R 
+--R
+--R           n - 1
+--R        d x      + c
+--R   (1)  ------------
+--R             n
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 953
+--r0:=c*x*hypergeometric(1,1/n,1+1/n,-b*x^n/a)/a+d*log(a+b*x^n)/(b*n)
+--E 820
+
+--S 821 of 953
+--a0:=integrate(t0,x)
+--E 821
+
+--S 822 of 953
+--m0:=a0-r0
+--E 822
+
+--S 823 of 953
+--d0:=D(m0,x)
+--E 823
+
+)clear all
+
+--S 824 of 953
+t0:=(c+d*x^(-1+n))/(a+b*x^n)^2
+--R 
+--R
+--R                n - 1
+--R             d x      + c
+--R   (1)  ----------------------
+--R         2  n 2         n    2
+--R        b (x )  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 824
+
+--S 825 of 953
+--r0:=-d/(b*n*(a+b*x^n))+c*x/(a*n*(a+b*x^n))-c*(1-n)*x*_
+--   hypergeometric(1,1/n,1+1/n,-b*x^n/a)/(a^2*n)
+--E 825
+
+--S 826 of 953
+--a0:=integrate(t0,x)
+--E 826
+
+--S 827 of 953
+--m0:=a0-r0
+--E 827
+
+--S 828 of 953
+--d0:=D(m0,x)
+--E 828
+
+)clear all
+
+--S 829 of 953
+t0:=(c+d*x^(-1+n))/(a+b*x^n)^3
+--R 
+--R
+--R                       n - 1
+--R                    d x      + c
+--R   (1)  -----------------------------------
+--R         3  n 3       2  n 2     2   n    3
+--R        b (x )  + 3a b (x )  + 3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 953
+--r0:=-1/2*d/(b*n*(a+b*x^n)^2)+1/2*c*x/(a*n*(a+b*x^n)^2)-1/2*c*(1-2*n)*_
+--   x/(a^2*n^2*(a+b*x^n))+1/2*c*(1-2*n)*(1-n)*x*hypergeometric(1,1/n,_
+--   1+1/n,-b*x^n/a)/(a^3*n^2)
+--E 830
+
+--S 831 of 953
+--a0:=integrate(t0,x)
+--E 831
+
+--S 832 of 953
+--m0:=a0-r0
+--E 832
+
+--S 833 of 953
+--d0:=D(m0,x)
+--E 833
+
+)clear all
+
+--S 834 of 953
+t0:=x^2*(a+b*x)^n*(c+d*x^3)
+--R 
+--R
+--R            5      2          n
+--R   (1)  (d x  + c x )(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 834
+
+--S 835 of 953
+r0:=a^2*(b^3*c-a^3*d)*(a+b*x)^(1+n)/(b^6*(1+n))-a*(2*b^3*c-5*a^3*d)*_
+   (a+b*x)^(2+n)/(b^6*(2+n))+(b^3*c-10*a^3*d)*(a+b*x)^(3+n)/(b^6*(3+n))+_
+   10*a^2*d*(a+b*x)^(4+n)/(b^6*(4+n))-5*a*d*(a+b*x)^(5+n)/(b^6*(5+n))+_
+   d*(a+b*x)^(6+n)/(b^6*(6+n))
+--R 
+--R
+--R   (2)
+--R           5        4        3         2                          n + 6
+--R       (d n  + 15d n  + 85d n  + 225d n  + 274d n + 120d)(b x + a)
+--R     + 
+--R                  5          4           3            2
+--R         (- 5a d n  - 80a d n  - 475a d n  - 1300a d n  - 1620a d n - 720a d)
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R             2   5       2   4        2   3        2   2        2           2
+--R         (10a d n  + 170a d n  + 1070a d n  + 3070a d n  + 3960a d n + 1800a d)
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 3     3   5          3       3   4           3        3   3
+--R           (- 10a d + b c)n  + (- 180a d + 18b c)n  + (- 1210a d + 121b c)n
+--R         + 
+--R                   3        3   2           3        3           3        3
+--R           (- 3720a d + 372b c)n  + (- 5080a d + 508b c)n - 2400a d + 240b c
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R              4        3   5       4         3   4        4          3   3
+--R           (5a d - 2a b c)n  + (95a d - 38a b c)n  + (685a d - 274a b c)n
+--R         + 
+--R                 4          3   2         4           3           4          3
+--R           (2305a d - 922a b c)n  + (3510a d - 1404a b c)n + 1800a d - 720a b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               5     2 3   5         5       2 3   4          5        2 3   3
+--R           (- a d + a b c)n  + (- 20a d + 20a b c)n  + (- 155a d + 155a b c)n
+--R         + 
+--R                5        2 3   2           5         2 3          5        2 3
+--R         (- 580a d + 580a b c)n  + (- 1044a d + 1044a b c)n - 720a d + 720a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     b n  + 21b n  + 175b n  + 735b n  + 1624b n  + 1764b n + 720b
+--R                                                    Type: Expression(Integer)
+--E 835
+
+--S 836 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           6   5      6   4      6   3       6   2       6          6   6
+--R         (b d n  + 15b d n  + 85b d n  + 225b d n  + 274b d n + 120b d)x
+--R       + 
+--R             5   5        5   4        5   3        5   2        5     5
+--R         (a b d n  + 10a b d n  + 35a b d n  + 50a b d n  + 24a b d n)x
+--R       + 
+--R              2 4   4      2 4   3      2 4   2      2 4     4
+--R         (- 5a b d n  - 30a b d n  - 55a b d n  - 30a b d n)x
+--R       + 
+--R              6   5      6   4       3 3        6   3       3 3        6   2
+--R             b c n  + 18b c n  + (20a b d + 121b c)n  + (60a b d + 372b c)n
+--R           + 
+--R                 3 3        6          6
+--R             (40a b d + 508b c)n + 240b c
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                5   5        5   4        5   3         4 2          5   2
+--R             a b c n  + 16a b c n  + 89a b c n  + (- 60a b d + 194a b c)n
+--R           + 
+--R                   4 2          5
+--R             (- 60a b d + 120a b c)n
+--R        *
+--R            2
+--R           x
+--R       + 
+--R              2 4   4      2 4   3       2 4   2        5          2 4
+--R         (- 2a b c n  - 30a b c n  - 148a b c n  + (120a b d - 240a b c)n)x
+--R       + 
+--R           3 3   3      3 3   2       3 3          6        3 3
+--R         2a b c n  + 30a b c n  + 148a b c n - 120a d + 240a b c
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     b n  + 21b n  + 175b n  + 735b n  + 1624b n  + 1764b n + 720b
+--R                                         Type: Union(Expression(Integer),...)
+--E 836
+
+--S 837 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             6   5      6   4      6   3       6   2       6          6   6
+--R           (b d n  + 15b d n  + 85b d n  + 225b d n  + 274b d n + 120b d)x
+--R         + 
+--R               5   5        5   4        5   3        5   2        5     5
+--R           (a b d n  + 10a b d n  + 35a b d n  + 50a b d n  + 24a b d n)x
+--R         + 
+--R                2 4   4      2 4   3      2 4   2      2 4     4
+--R           (- 5a b d n  - 30a b d n  - 55a b d n  - 30a b d n)x
+--R         + 
+--R                6   5      6   4       3 3        6   3       3 3        6   2
+--R               b c n  + 18b c n  + (20a b d + 121b c)n  + (60a b d + 372b c)n
+--R             + 
+--R                   3 3        6          6
+--R               (40a b d + 508b c)n + 240b c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  5   5        5   4        5   3         4 2          5   2
+--R               a b c n  + 16a b c n  + 89a b c n  + (- 60a b d + 194a b c)n
+--R             + 
+--R                     4 2          5
+--R               (- 60a b d + 120a b c)n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                2 4   4      2 4   3       2 4   2        5          2 4
+--R           (- 2a b c n  - 30a b c n  - 148a b c n  + (120a b d - 240a b c)n)x
+--R         + 
+--R             3 3   3      3 3   2       3 3          6        3 3
+--R           2a b c n  + 30a b c n  + 148a b c n - 120a d + 240a b c
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R             5        4        3         2                          n + 6
+--R       (- d n  - 15d n  - 85d n  - 225d n  - 274d n - 120d)(b x + a)
+--R     + 
+--R                5          4           3            2
+--R         (5a d n  + 80a d n  + 475a d n  + 1300a d n  + 1620a d n + 720a d)
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                  2   5       2   4        2   3        2   2        2
+--R             - 10a d n  - 170a d n  - 1070a d n  - 3070a d n  - 3960a d n
+--R           + 
+--R                    2
+--R             - 1800a d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R               3     3   5        3       3   4         3        3   3
+--R           (10a d - b c)n  + (180a d - 18b c)n  + (1210a d - 121b c)n
+--R         + 
+--R                 3        3   2         3        3           3        3
+--R           (3720a d - 372b c)n  + (5080a d - 508b c)n + 2400a d - 240b c
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R                4        3   5         4         3   4          4          3   3
+--R           (- 5a d + 2a b c)n  + (- 95a d + 38a b c)n  + (- 685a d + 274a b c)n
+--R         + 
+--R                   4          3   2           4           3           4
+--R           (- 2305a d + 922a b c)n  + (- 3510a d + 1404a b c)n - 1800a d
+--R         + 
+--R                 3
+--R           720a b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             5     2 3   5       5       2 3   4        5        2 3   3
+--R           (a d - a b c)n  + (20a d - 20a b c)n  + (155a d - 155a b c)n
+--R         + 
+--R                5        2 3   2         5         2 3          5        2 3
+--R           (580a d - 580a b c)n  + (1044a d - 1044a b c)n + 720a d - 720a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     b n  + 21b n  + 175b n  + 735b n  + 1624b n  + 1764b n + 720b
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         5   5    5   2   n log(b x + a)              n + 5
+--R       (b d x  + b c x )%e               - d (b x + a)
+--R     + 
+--R                     n + 4      2           n + 3       3     3           n + 2
+--R       5a d (b x + a)      - 10a d (b x + a)      + (10a d - b c)(b x + a)
+--R     + 
+--R            4        3           n + 1     5     2 3           n
+--R       (- 5a d + 2a b c)(b x + a)      + (a d - a b c)(b x + a)
+--R  /
+--R      5
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 838
+
+)clear all
+
+--S 839 of 953
+t0:=x*(a+b*x)^n*(c+d*x^3)
+--R 
+--R
+--R            4                n
+--R   (1)  (d x  + c x)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 839
+
+--S 840 of 953
+r0:=-a*(b^3*c-a^3*d)*(a+b*x)^(1+n)/(b^5*(1+n))+(b^3*c-4*a^3*d)*_
+   (a+b*x)^(2+n)/(b^5*(2+n))+6*a^2*d*(a+b*x)^(3+n)/(b^5*(3+n))-_
+   4*a*d*(a+b*x)^(4+n)/(b^5*(4+n))+d*(a+b*x)^(5+n)/(b^5*(5+n))
+--R 
+--R
+--R   (2)
+--R           4        3        2                        n + 5
+--R       (d n  + 10d n  + 35d n  + 50d n + 24d)(b x + a)
+--R     + 
+--R                4          3           2                              n + 4
+--R       (- 4a d n  - 44a d n  - 164a d n  - 244a d n - 120a d)(b x + a)
+--R     + 
+--R          2   4      2   3       2   2       2          2           n + 3
+--R       (6a d n  + 72a d n  + 294a d n  + 468a d n + 240a d)(b x + a)
+--R     + 
+--R                3     3   4         3       3   3          3       3   2
+--R           (- 4a d + b c)n  + (- 52a d + 13b c)n  + (- 236a d + 59b c)n
+--R         + 
+--R                  3        3          3       3
+--R           (- 428a d + 107b c)n - 240a d + 60b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             4       3   4       4         3   3       4         3   2
+--R           (a d - a b c)n  + (14a d - 14a b c)n  + (71a d - 71a b c)n
+--R         + 
+--R                4          3          4          3
+--R           (154a d - 154a b c)n + 120a d - 120a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R      5 5      5 4      5 3       5 2       5        5
+--R     b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b
+--R                                                    Type: Expression(Integer)
+--E 840
+
+--S 841 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           5   4      5   3      5   2      5         5   5
+--R         (b d n  + 10b d n  + 35b d n  + 50b d n + 24b d)x
+--R       + 
+--R             4   4       4   3        4   2       4     4
+--R         (a b d n  + 6a b d n  + 11a b d n  + 6a b d n)x
+--R       + 
+--R              2 3   3      2 3   2     2 3     3
+--R         (- 4a b d n  - 12a b d n  - 8a b d n)x
+--R       + 
+--R                5   4      5   3       3 2       5   2       3 2        5
+--R               b c n  + 13b c n  + (12a b d + 59b c)n  + (12a b d + 107b c)n
+--R             + 
+--R                  5
+--R               60b c
+--R        *
+--R            2
+--R           x
+--R       + 
+--R             4   4        4   3        4   2         4           4
+--R         (a b c n  + 12a b c n  + 47a b c n  + (- 24a b d + 60a b c)n)x
+--R       + 
+--R            2 3   3      2 3   2      2 3         5       2 3
+--R         - a b c n  - 12a b c n  - 47a b c n + 24a d - 60a b c
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R      5 5      5 4      5 3       5 2       5        5
+--R     b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b
+--R                                         Type: Union(Expression(Integer),...)
+--E 841
+
+--S 842 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             5   4      5   3      5   2      5         5   5
+--R           (b d n  + 10b d n  + 35b d n  + 50b d n + 24b d)x
+--R         + 
+--R               4   4       4   3        4   2       4     4
+--R           (a b d n  + 6a b d n  + 11a b d n  + 6a b d n)x
+--R         + 
+--R                2 3   3      2 3   2     2 3     3
+--R           (- 4a b d n  - 12a b d n  - 8a b d n)x
+--R         + 
+--R                5   4      5   3       3 2       5   2       3 2        5
+--R               b c n  + 13b c n  + (12a b d + 59b c)n  + (12a b d + 107b c)n
+--R             + 
+--R                  5
+--R               60b c
+--R          *
+--R              2
+--R             x
+--R         + 
+--R               4   4        4   3        4   2         4           4
+--R           (a b c n  + 12a b c n  + 47a b c n  + (- 24a b d + 60a b c)n)x
+--R         + 
+--R              2 3   3      2 3   2      2 3         5       2 3
+--R           - a b c n  - 12a b c n  - 47a b c n + 24a d - 60a b c
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R             4        3        2                        n + 5
+--R       (- d n  - 10d n  - 35d n  - 50d n - 24d)(b x + a)
+--R     + 
+--R              4          3           2                              n + 4
+--R       (4a d n  + 44a d n  + 164a d n  + 244a d n + 120a d)(b x + a)
+--R     + 
+--R            2   4      2   3       2   2       2          2           n + 3
+--R       (- 6a d n  - 72a d n  - 294a d n  - 468a d n - 240a d)(b x + a)
+--R     + 
+--R              3     3   4       3       3   3        3       3   2
+--R           (4a d - b c)n  + (52a d - 13b c)n  + (236a d - 59b c)n
+--R         + 
+--R                3        3          3       3
+--R           (428a d - 107b c)n + 240a d - 60b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               4       3   4         4         3   3         4         3   2
+--R           (- a d + a b c)n  + (- 14a d + 14a b c)n  + (- 71a d + 71a b c)n
+--R         + 
+--R                  4          3          4          3
+--R           (- 154a d + 154a b c)n - 120a d + 120a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R      5 5      5 4      5 3       5 2       5        5
+--R     b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         4   4    4      n log(b x + a)              n + 4                 n + 3
+--R       (b d x  + b c x)%e               - d (b x + a)      + 4a d (b x + a)
+--R     + 
+--R           2           n + 2      3     3           n + 1
+--R       - 6a d (b x + a)      + (4a d - b c)(b x + a)
+--R     + 
+--R           4       3           n
+--R       (- a d + a b c)(b x + a)
+--R  /
+--R      4
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 843
+
+)clear all
+
+--S 844 of 953
+t0:=(a+b*x)^n*(c+d*x^3)
+--R 
+--R
+--R            3              n
+--R   (1)  (d x  + c)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 844
+
+--S 845 of 953
+r0:=(b^3*c-a^3*d)*(a+b*x)^(1+n)/(b^4*(1+n))+3*a^2*d*(a+b*x)^(2+n)/(b^4*_
+   (2+n))-3*a*d*(a+b*x)^(3+n)/(b^4*(3+n))+d*(a+b*x)^(4+n)/(b^4*(4+n))
+--R 
+--R
+--R   (2)
+--R           3       2                       n + 4
+--R       (d n  + 6d n  + 11d n + 6d)(b x + a)
+--R     + 
+--R                3          2                            n + 3
+--R       (- 3a d n  - 21a d n  - 42a d n - 24a d)(b x + a)
+--R     + 
+--R          2   3      2   2      2         2           n + 2
+--R       (3a d n  + 24a d n  + 57a d n + 36a d)(b x + a)
+--R     + 
+--R               3     3   3        3      3   2         3       3         3
+--R           (- a d + b c)n  + (- 9a d + 9b c)n  + (- 26a d + 26b c)n - 24a d
+--R         + 
+--R              3
+--R           24b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     b n  + 10b n  + 35b n  + 50b n + 24b
+--R                                                    Type: Expression(Integer)
+--E 845
+
+--S 846 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4   3     4   2      4        4   4
+--R         (b d n  + 6b d n  + 11b d n + 6b d)x
+--R       + 
+--R             3   3       3   2       3     3        2 2   2     2 2     2
+--R         (a b d n  + 3a b d n  + 2a b d n)x  + (- 3a b d n  - 3a b d n)x
+--R       + 
+--R           4   3     4   2      3         4         4         3   3       3   2
+--R         (b c n  + 9b c n  + (6a b d + 26b c)n + 24b c)x + a b c n  + 9a b c n
+--R       + 
+--R              3        4         3
+--R         26a b c n - 6a d + 24a b c
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     b n  + 10b n  + 35b n  + 50b n + 24b
+--R                                         Type: Union(Expression(Integer),...)
+--E 846
+
+--S 847 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             4   3     4   2      4        4   4
+--R           (b d n  + 6b d n  + 11b d n + 6b d)x
+--R         + 
+--R               3   3       3   2       3     3        2 2   2     2 2     2
+--R           (a b d n  + 3a b d n  + 2a b d n)x  + (- 3a b d n  - 3a b d n)x
+--R         + 
+--R             4   3     4   2      3         4         4         3   3
+--R           (b c n  + 9b c n  + (6a b d + 26b c)n + 24b c)x + a b c n
+--R         + 
+--R               3   2        3        4         3
+--R           9a b c n  + 26a b c n - 6a d + 24a b c
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R             3       2                       n + 4
+--R       (- d n  - 6d n  - 11d n - 6d)(b x + a)
+--R     + 
+--R              3          2                            n + 3
+--R       (3a d n  + 21a d n  + 42a d n + 24a d)(b x + a)
+--R     + 
+--R            2   3      2   2      2         2           n + 2
+--R       (- 3a d n  - 24a d n  - 57a d n - 36a d)(b x + a)
+--R     + 
+--R            3     3   3      3      3   2       3       3         3       3
+--R         ((a d - b c)n  + (9a d - 9b c)n  + (26a d - 26b c)n + 24a d - 24b c)
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     b n  + 10b n  + 35b n  + 50b n + 24b
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         3   3    3    n log(b x + a)              n + 3                 n + 2
+--R       (b d x  + b c)%e               - d (b x + a)      + 3a d (b x + a)
+--R     + 
+--R           2           n + 1     3     3           n
+--R       - 3a d (b x + a)      + (a d - b c)(b x + a)
+--R  /
+--R      3
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 848
+
+)clear all
+
+--S 849 of 953
+t0:=(a+b*x)^n*(c+d*x^3)/x
+--R 
+--R
+--R            3              n
+--R        (d x  + c)(b x + a)
+--R   (1)  --------------------
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 849
+
+--S 850 of 953
+--r0:=a^2*d*(a+b*x)^(1+n)/(b^3*(1+n))-2*a*d*(a+b*x)^(2+n)/(b^3*(2+n))+_
+--   d*(a+b*x)^(3+n)/(b^3*(3+n))-c*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*(1+n))
+--E 850
+
+--S 851 of 953
+--a0:=integrate(t0,x)
+--E 851
+
+--S 852 of 953
+--m0:=a0-r0
+--E 852
+
+--S 853 of 953
+--d0:=D(m0,x)
+--E 853
+
+)clear all
+
+--S 854 of 953
+t0:=x^2*(a+b*x)^n*(c+d*x^3)^2
+--R 
+--R
+--R          2 8         5    2 2          n
+--R   (1)  (d x  + 2c d x  + c x )(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 854
+
+--S 855 of 953
+r0:=a^2*(b^3*c-a^3*d)^2*(a+b*x)^(1+n)/(b^9*(1+n))-2*a*(b^3*c-4*a^3*d)*_
+   (b^3*c-a^3*d)*(a+b*x)^(2+n)/(b^9*(2+n))+(b^6*c^2-20*a^3*b^3*c*d+_
+   28*a^6*d^2)*(a+b*x)^(3+n)/(b^9*(3+n))+4*a^2*d*(5*b^3*c-14*a^3*d)*_
+   (a+b*x)^(4+n)/(b^9*(4+n))-10*a*d*(b^3*c-7*a^3*d)*(a+b*x)^(5+n)/_
+   (b^9*(5+n))+2*d*(b^3*c-28*a^3*d)*(a+b*x)^(6+n)/(b^9*(6+n))+28*a^2*_
+   d^2*(a+b*x)^(7+n)/(b^9*(7+n))-8*a*d^2*(a+b*x)^(8+n)/(b^9*(8+n))+_
+   d^2*(a+b*x)^(9+n)/(b^9*(9+n))
+--R 
+--R
+--R   (2)
+--R            2 8      2 7       2 6        2 5         2 4         2 3
+--R           d n  + 36d n  + 546d n  + 4536d n  + 22449d n  + 67284d n
+--R         + 
+--R                  2 2          2          2
+--R           118124d n  + 109584d n + 40320d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R                 2 8         2 7          2 6           2 5            2 4
+--R           - 8a d n  - 296a d n  - 4592a d n  - 38864a d n  - 195272a d n
+--R         + 
+--R                      2 3             2 2            2             2
+--R           - 592424a d n  - 1050048a d n  - 981216a d n - 362880a d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R              2 2 8        2 2 7         2 2 6          2 2 5          2 2 4
+--R           28a d n  + 1064a d n  + 16912a d n  + 146216a d n  + 748132a d n
+--R         + 
+--R                   2 2 3           2 2 2           2 2            2 2
+--R           2304176a d n  + 4133808a d n  + 3898944a d n + 1451520a d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                 3 2     3     8           3 2      3     7
+--R           (- 56a d  + 2b c d)n  + (- 2184a d  + 78b c d)n
+--R         + 
+--R                    3 2        3     6             3 2         3     5
+--R           (- 35616a d  + 1272b c d)n  + (- 315504a d  + 11268b c d)n
+--R         + 
+--R                      3 2         3     4              3 2          3     3
+--R           (- 1650264a d  + 58938b c d)n  + (- 5180616a d  + 185022b c d)n
+--R         + 
+--R                      3 2          3     2              3 2          3
+--R           (- 9442384a d  + 337228b c d)n  + (- 9016896a d  + 322032b c d)n
+--R         + 
+--R                     3 2          3
+--R           - 3386880a d  + 120960b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R               4 2        3     8         4 2         3     7
+--R           (70a d  - 10a b c d)n  + (2800a d  - 400a b c d)n
+--R         + 
+--R                  4 2          3     6           4 2           3     5
+--R           (46900a d  - 6700a b c d)n  + (427000a d  - 61000a b c d)n
+--R         + 
+--R                    4 2            3     4            4 2             3     3
+--R           (2294110a d  - 327730a b c d)n  + (7382200a d  - 1054600a b c d)n
+--R         + 
+--R                     4 2             3     2             4 2             3
+--R           (13746600a d  - 1963800a b c d)n  + (13356000a d  - 1908000a b c d)n
+--R         + 
+--R                   4 2            3
+--R           5080320a d  - 725760a b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                 5 2      2 3     8           5 2       2 3     7
+--R           (- 56a d  + 20a b c d)n  + (- 2296a d  + 820a b c d)n
+--R         + 
+--R                    5 2         2 3     6             5 2          2 3     5
+--R           (- 39536a d  + 14120a b c d)n  + (- 371056a d  + 132520a b c d)n
+--R         + 
+--R                      5 2          2 3     4
+--R           (- 2059064a d  + 735380a b c d)n
+--R         + 
+--R                      5 2           2 3     3
+--R           (- 6845944a d  + 2444980a b c d)n
+--R         + 
+--R                       5 2           2 3     2
+--R           (- 13142304a d  + 4693680a b c d)n
+--R         + 
+--R                       5 2           2 3                5 2           2 3
+--R           (- 13101984a d  + 4679280a b c d)n - 5080320a d  + 1814400a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R               6 2      3 3       6 2  8         6 2       3 3         6 2  7
+--R           (28a d  - 20a b c d + b c )n  + (1176a d  - 840a b c d + 42b c )n
+--R         + 
+--R                  6 2         3 3          6 2  6
+--R           (20832a d  - 14880a b c d + 744b c )n
+--R         + 
+--R                   6 2          3 3           6 2  5
+--R           (202104a d  - 144360a b c d + 7218b c )n
+--R         + 
+--R                    6 2          3 3            6 2  4
+--R           (1165332a d  - 832380a b c d + 41619b c )n
+--R         + 
+--R                    6 2           3 3             6 2  3
+--R           (4045104a d  - 2889360a b c d + 144468b c )n
+--R         + 
+--R                    6 2           3 3             6 2  2
+--R           (8127728a d  - 5805520a b c d + 290276b c )n
+--R         + 
+--R                    6 2           3 3             6 2             6 2
+--R           (8452416a d  - 6037440a b c d + 301872b c )n + 3386880a d
+--R         + 
+--R                     3 3             6 2
+--R           - 2419200a b c d + 120960b c
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R                7 2      4 3          6 2  8
+--R           (- 8a d  + 10a b c d - 2a b c )n
+--R         + 
+--R                  7 2       4 3           6 2  7
+--R           (- 344a d  + 430a b c d - 86a b c )n
+--R         + 
+--R                   7 2        4 3             6 2  6
+--R           (- 6272a d  + 7840a b c d - 1568a b c )n
+--R         + 
+--R                    7 2         4 3              6 2  5
+--R           (- 63056a d  + 78820a b c d - 15764a b c )n
+--R         + 
+--R                     7 2          4 3              6 2  4
+--R           (- 380072a d  + 475090a b c d - 95018a b c )n
+--R         + 
+--R                      7 2           4 3               6 2  3
+--R           (- 1394456a d  + 1743070a b c d - 348614a b c )n
+--R         + 
+--R                      7 2           4 3               6 2  2
+--R           (- 3000528a d  + 3750660a b c d - 750132a b c )n
+--R         + 
+--R                      7 2           4 3               6 2             7 2
+--R           (- 3380544a d  + 4225680a b c d - 845136a b c )n - 1451520a d
+--R         + 
+--R                   4 3               6 2
+--R           1814400a b c d - 362880a b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             8 2     5 3       2 6 2  8       8 2      5 3         2 6 2  7
+--R           (a d  - 2a b c d + a b c )n  + (44a d  - 88a b c d + 44a b c )n
+--R         + 
+--R                8 2        5 3          2 6 2  6
+--R           (826a d  - 1652a b c d + 826a b c )n
+--R         + 
+--R                 8 2         5 3           2 6 2  5
+--R           (8624a d  - 17248a b c d + 8624a b c )n
+--R         + 
+--R                  8 2          5 3            2 6 2  4
+--R           (54649a d  - 109298a b c d + 54649a b c )n
+--R         + 
+--R                   8 2          5 3             2 6 2  3
+--R           (214676a d  - 429352a b c d + 214676a b c )n
+--R         + 
+--R                   8 2           5 3             2 6 2  2
+--R           (509004a d  - 1018008a b c d + 509004a b c )n
+--R         + 
+--R                   8 2           5 3             2 6 2            8 2
+--R           (663696a d  - 1327392a b c d + 663696a b c )n + 362880a d
+--R         + 
+--R                    5 3             2 6 2
+--R           - 725760a b c d + 362880a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        9 9      9 8       9 7        9 6         9 5          9 4          9 3
+--R       b n  + 45b n  + 870b n  + 9450b n  + 63273b n  + 269325b n  + 723680b n
+--R     + 
+--R               9 2           9           9
+--R       1172700b n  + 1026576b n + 362880b
+--R                                                    Type: Expression(Integer)
+--E 855
+
+--S 856 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              9 2 8      9 2 7       9 2 6        9 2 5         9 2 4
+--R             b d n  + 36b d n  + 546b d n  + 4536b d n  + 22449b d n
+--R           + 
+--R                   9 2 3          9 2 2          9 2          9 2
+--R             67284b d n  + 118124b d n  + 109584b d n + 40320b d
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                8 2 8        8 2 7         8 2 6          8 2 5          8 2 4
+--R             a b d n  + 28a b d n  + 322a b d n  + 1960a b d n  + 6769a b d n
+--R           + 
+--R                     8 2 3           8 2 2          8 2
+--R             13132a b d n  + 13068a b d n  + 5040a b d n
+--R        *
+--R            8
+--R           x
+--R       + 
+--R                 2 7 2 7       2 7 2 6        2 7 2 5        2 7 2 4
+--R             - 8a b d n  - 168a b d n  - 1400a b d n  - 5880a b d n
+--R           + 
+--R                     2 7 2 3         2 7 2 2        2 7 2
+--R             - 12992a b d n  - 14112a b d n  - 5760a b d n
+--R        *
+--R            7
+--R           x
+--R       + 
+--R               9     8      9     7       3 6 2        9     6
+--R             2b c d n  + 78b c d n  + (56a b d  + 1272b c d)n
+--R           + 
+--R                  3 6 2         9     5         3 6 2         9     4
+--R             (840a b d  + 11268b c d)n  + (4760a b d  + 58938b c d)n
+--R           + 
+--R                    3 6 2          9     3          3 6 2          9     2
+--R             (12600a b d  + 185022b c d)n  + (15344a b d  + 337228b c d)n
+--R           + 
+--R                   3 6 2          9               9
+--R             (6720a b d  + 322032b c d)n + 120960b c d
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                 8     8        8     7         8     6
+--R             2a b c d n  + 68a b c d n  + 932a b c d n
+--R           + 
+--R                    4 5 2          8     5           4 5 2           8     4
+--R             (- 336a b d  + 6608a b c d)n  + (- 3360a b d  + 25898a b c d)n
+--R           + 
+--R                      4 5 2           8     3            4 5 2           8     2
+--R             (- 11760a b d  + 55532a b c d)n  + (- 16800a b d  + 59568a b c d)n
+--R           + 
+--R                     4 5 2           8
+--R             (- 8064a b d  + 24192a b c d)n
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                  2 7     7       2 7     6        2 7     5
+--R             - 10a b c d n  - 300a b c d n  - 3460a b c d n
+--R           + 
+--R                   5 4 2         2 7     4          5 4 2         2 7     3
+--R             (1680a b d  - 19200a b c d)n  + (10080a b d  - 52690a b c d)n
+--R           + 
+--R                    5 4 2         2 7     2          5 4 2         2 7
+--R             (18480a b d  - 66900a b c d)n  + (10080a b d  - 30240a b c d)n
+--R        *
+--R            4
+--R           x
+--R       + 
+--R              9 2 8      9 2 7       3 6          9 2  6
+--R             b c n  + 42b c n  + (40a b c d + 744b c )n
+--R           + 
+--R                   3 6           9 2  5          3 6            9 2  4
+--R             (1080a b c d + 7218b c )n  + (10600a b c d + 41619b c )n
+--R           + 
+--R                     6 3 2         3 6             9 2  3
+--R             (- 6720a b d  + 45000a b c d + 144468b c )n
+--R           + 
+--R                      6 3 2         3 6             9 2  2
+--R             (- 20160a b d  + 75760a b c d + 290276b c )n
+--R           + 
+--R                      6 3 2         3 6             9 2            9 2
+--R             (- 13440a b d  + 40320a b c d + 301872b c )n + 120960b c
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                8 2 8        8 2 7         8 2 6          4 5             8 2  5
+--R             a b c n  + 40a b c n  + 664a b c n  + (- 120a b c d + 5890a b c )n
+--R           + 
+--R                     4 5              8 2  4            4 5              8 2  3
+--R             (- 3000a b c d + 29839a b c )n  + (- 25800a b c d + 84790a b c )n
+--R           + 
+--R                    7 2 2         4 5               8 2  2
+--R             (20160a b d  - 83400a b c d + 120696a b c )n
+--R           + 
+--R                    7 2 2         4 5              8 2
+--R             (20160a b d  - 60480a b c d + 60480a b c )n
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                 2 7 2 7      2 7 2 6        2 7 2 5
+--R             - 2a b c n  - 78a b c n  - 1250a b c n
+--R           + 
+--R                  5 4            2 7 2  4         5 4            2 7 2  3
+--R             (240a b c d - 10530a b c )n  + (5760a b c d - 49148a b c )n
+--R           + 
+--R                    5 4             2 7 2  2
+--R             (45840a b c d - 120432a b c )n
+--R           + 
+--R                      8   2          5 4             2 7 2
+--R             (- 40320a b d  + 120960a b c d - 120960a b c )n
+--R        *
+--R           x
+--R       + 
+--R           3 6 2 6      3 6 2 5        3 6 2 4          6 3            3 6 2  3
+--R         2a b c n  + 78a b c n  + 1250a b c n  + (- 240a b c d + 10530a b c )n
+--R       + 
+--R                 6 3            3 6 2  2            6 3             3 6 2
+--R         (- 5760a b c d + 49148a b c )n  + (- 45840a b c d + 120432a b c )n
+--R       + 
+--R               9 2          6 3             3 6 2
+--R         40320a d  - 120960a b c d + 120960a b c
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R        9 9      9 8       9 7        9 6         9 5          9 4          9 3
+--R       b n  + 45b n  + 870b n  + 9450b n  + 63273b n  + 269325b n  + 723680b n
+--R     + 
+--R               9 2           9           9
+--R       1172700b n  + 1026576b n + 362880b
+--R                                         Type: Union(Expression(Integer),...)
+--E 856
+
+--S 857 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                9 2 8      9 2 7       9 2 6        9 2 5         9 2 4
+--R               b d n  + 36b d n  + 546b d n  + 4536b d n  + 22449b d n
+--R             + 
+--R                     9 2 3          9 2 2          9 2          9 2
+--R               67284b d n  + 118124b d n  + 109584b d n + 40320b d
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                  8 2 8        8 2 7         8 2 6          8 2 5          8 2 4
+--R               a b d n  + 28a b d n  + 322a b d n  + 1960a b d n  + 6769a b d n
+--R             + 
+--R                       8 2 3           8 2 2          8 2
+--R               13132a b d n  + 13068a b d n  + 5040a b d n
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                   2 7 2 7       2 7 2 6        2 7 2 5        2 7 2 4
+--R               - 8a b d n  - 168a b d n  - 1400a b d n  - 5880a b d n
+--R             + 
+--R                       2 7 2 3         2 7 2 2        2 7 2
+--R               - 12992a b d n  - 14112a b d n  - 5760a b d n
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                 9     8      9     7       3 6 2        9     6
+--R               2b c d n  + 78b c d n  + (56a b d  + 1272b c d)n
+--R             + 
+--R                    3 6 2         9     5         3 6 2         9     4
+--R               (840a b d  + 11268b c d)n  + (4760a b d  + 58938b c d)n
+--R             + 
+--R                      3 6 2          9     3          3 6 2          9     2
+--R               (12600a b d  + 185022b c d)n  + (15344a b d  + 337228b c d)n
+--R             + 
+--R                     3 6 2          9               9
+--R               (6720a b d  + 322032b c d)n + 120960b c d
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                   8     8        8     7         8     6
+--R               2a b c d n  + 68a b c d n  + 932a b c d n
+--R             + 
+--R                      4 5 2          8     5           4 5 2           8     4
+--R               (- 336a b d  + 6608a b c d)n  + (- 3360a b d  + 25898a b c d)n
+--R             + 
+--R                        4 5 2           8     3
+--R               (- 11760a b d  + 55532a b c d)n
+--R             + 
+--R                      4 5 2           8     2           4 5 2           8
+--R             (- 16800a b d  + 59568a b c d)n  + (- 8064a b d  + 24192a b c d)n
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    2 7     7       2 7     6        2 7     5
+--R               - 10a b c d n  - 300a b c d n  - 3460a b c d n
+--R             + 
+--R                     5 4 2         2 7     4          5 4 2         2 7     3
+--R               (1680a b d  - 19200a b c d)n  + (10080a b d  - 52690a b c d)n
+--R             + 
+--R                      5 4 2         2 7     2          5 4 2         2 7
+--R               (18480a b d  - 66900a b c d)n  + (10080a b d  - 30240a b c d)n
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                9 2 8      9 2 7       3 6          9 2  6
+--R               b c n  + 42b c n  + (40a b c d + 744b c )n
+--R             + 
+--R                     3 6           9 2  5          3 6            9 2  4
+--R               (1080a b c d + 7218b c )n  + (10600a b c d + 41619b c )n
+--R             + 
+--R                       6 3 2         3 6             9 2  3
+--R               (- 6720a b d  + 45000a b c d + 144468b c )n
+--R             + 
+--R                        6 3 2         3 6             9 2  2
+--R               (- 20160a b d  + 75760a b c d + 290276b c )n
+--R             + 
+--R                        6 3 2         3 6             9 2            9 2
+--R               (- 13440a b d  + 40320a b c d + 301872b c )n + 120960b c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  8 2 8        8 2 7         8 2 6
+--R               a b c n  + 40a b c n  + 664a b c n
+--R             + 
+--R                      4 5             8 2  5           4 5              8 2  4
+--R               (- 120a b c d + 5890a b c )n  + (- 3000a b c d + 29839a b c )n
+--R             + 
+--R                        4 5              8 2  3
+--R               (- 25800a b c d + 84790a b c )n
+--R             + 
+--R                      7 2 2         4 5               8 2  2
+--R               (20160a b d  - 83400a b c d + 120696a b c )n
+--R             + 
+--R                      7 2 2         4 5              8 2
+--R               (20160a b d  - 60480a b c d + 60480a b c )n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   2 7 2 7      2 7 2 6        2 7 2 5
+--R               - 2a b c n  - 78a b c n  - 1250a b c n
+--R             + 
+--R                    5 4            2 7 2  4         5 4            2 7 2  3
+--R               (240a b c d - 10530a b c )n  + (5760a b c d - 49148a b c )n
+--R             + 
+--R                      5 4             2 7 2  2
+--R               (45840a b c d - 120432a b c )n
+--R             + 
+--R                        8   2          5 4             2 7 2
+--R               (- 40320a b d  + 120960a b c d - 120960a b c )n
+--R          *
+--R             x
+--R         + 
+--R             3 6 2 6      3 6 2 5        3 6 2 4
+--R           2a b c n  + 78a b c n  + 1250a b c n
+--R         + 
+--R                  6 3            3 6 2  3           6 3            3 6 2  2
+--R           (- 240a b c d + 10530a b c )n  + (- 5760a b c d + 49148a b c )n
+--R         + 
+--R                    6 3             3 6 2           9 2          6 3
+--R           (- 45840a b c d + 120432a b c )n + 40320a d  - 120960a b c d
+--R         + 
+--R                  3 6 2
+--R           120960a b c
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R              2 8      2 7       2 6        2 5         2 4         2 3
+--R           - d n  - 36d n  - 546d n  - 4536d n  - 22449d n  - 67284d n
+--R         + 
+--R                    2 2          2          2
+--R           - 118124d n  - 109584d n - 40320d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R               2 8         2 7          2 6           2 5            2 4
+--R           8a d n  + 296a d n  + 4592a d n  + 38864a d n  + 195272a d n
+--R         + 
+--R                    2 3             2 2            2             2
+--R           592424a d n  + 1050048a d n  + 981216a d n + 362880a d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                2 2 8        2 2 7         2 2 6          2 2 5          2 2 4
+--R           - 28a d n  - 1064a d n  - 16912a d n  - 146216a d n  - 748132a d n
+--R         + 
+--R                     2 2 3           2 2 2           2 2            2 2
+--R           - 2304176a d n  - 4133808a d n  - 3898944a d n - 1451520a d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R               3 2     3     8         3 2      3     7
+--R           (56a d  - 2b c d)n  + (2184a d  - 78b c d)n
+--R         + 
+--R                  3 2        3     6           3 2         3     5
+--R           (35616a d  - 1272b c d)n  + (315504a d  - 11268b c d)n
+--R         + 
+--R                    3 2         3     4            3 2          3     3
+--R           (1650264a d  - 58938b c d)n  + (5180616a d  - 185022b c d)n
+--R         + 
+--R                    3 2          3     2            3 2          3
+--R           (9442384a d  - 337228b c d)n  + (9016896a d  - 322032b c d)n
+--R         + 
+--R                   3 2          3
+--R           3386880a d  - 120960b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                 4 2        3     8           4 2         3     7
+--R           (- 70a d  + 10a b c d)n  + (- 2800a d  + 400a b c d)n
+--R         + 
+--R                    4 2          3     6             4 2           3     5
+--R           (- 46900a d  + 6700a b c d)n  + (- 427000a d  + 61000a b c d)n
+--R         + 
+--R                      4 2            3     4
+--R           (- 2294110a d  + 327730a b c d)n
+--R         + 
+--R                      4 2             3     3
+--R           (- 7382200a d  + 1054600a b c d)n
+--R         + 
+--R                       4 2             3     2
+--R           (- 13746600a d  + 1963800a b c d)n
+--R         + 
+--R                       4 2             3                4 2            3
+--R           (- 13356000a d  + 1908000a b c d)n - 5080320a d  + 725760a b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R               5 2      2 3     8         5 2       2 3     7
+--R           (56a d  - 20a b c d)n  + (2296a d  - 820a b c d)n
+--R         + 
+--R                  5 2         2 3     6           5 2          2 3     5
+--R           (39536a d  - 14120a b c d)n  + (371056a d  - 132520a b c d)n
+--R         + 
+--R                    5 2          2 3     4            5 2           2 3     3
+--R           (2059064a d  - 735380a b c d)n  + (6845944a d  - 2444980a b c d)n
+--R         + 
+--R                     5 2           2 3     2             5 2           2 3
+--R           (13142304a d  - 4693680a b c d)n  + (13101984a d  - 4679280a b c d)n
+--R         + 
+--R                   5 2           2 3
+--R           5080320a d  - 1814400a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 6 2      3 3       6 2  8
+--R           (- 28a d  + 20a b c d - b c )n
+--R         + 
+--R                   6 2       3 3         6 2  7
+--R           (- 1176a d  + 840a b c d - 42b c )n
+--R         + 
+--R                    6 2         3 3          6 2  6
+--R           (- 20832a d  + 14880a b c d - 744b c )n
+--R         + 
+--R                     6 2          3 3           6 2  5
+--R           (- 202104a d  + 144360a b c d - 7218b c )n
+--R         + 
+--R                      6 2          3 3            6 2  4
+--R           (- 1165332a d  + 832380a b c d - 41619b c )n
+--R         + 
+--R                      6 2           3 3             6 2  3
+--R           (- 4045104a d  + 2889360a b c d - 144468b c )n
+--R         + 
+--R                      6 2           3 3             6 2  2
+--R           (- 8127728a d  + 5805520a b c d - 290276b c )n
+--R         + 
+--R                      6 2           3 3             6 2             6 2
+--R           (- 8452416a d  + 6037440a b c d - 301872b c )n - 3386880a d
+--R         + 
+--R                   3 3             6 2
+--R           2419200a b c d - 120960b c
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R              7 2      4 3          6 2  8        7 2       4 3           6 2  7
+--R           (8a d  - 10a b c d + 2a b c )n  + (344a d  - 430a b c d + 86a b c )n
+--R         + 
+--R                 7 2        4 3             6 2  6
+--R           (6272a d  - 7840a b c d + 1568a b c )n
+--R         + 
+--R                  7 2         4 3              6 2  5
+--R           (63056a d  - 78820a b c d + 15764a b c )n
+--R         + 
+--R                   7 2          4 3              6 2  4
+--R           (380072a d  - 475090a b c d + 95018a b c )n
+--R         + 
+--R                    7 2           4 3               6 2  3
+--R           (1394456a d  - 1743070a b c d + 348614a b c )n
+--R         + 
+--R                    7 2           4 3               6 2  2
+--R           (3000528a d  - 3750660a b c d + 750132a b c )n
+--R         + 
+--R                    7 2           4 3               6 2             7 2
+--R           (3380544a d  - 4225680a b c d + 845136a b c )n + 1451520a d
+--R         + 
+--R                     4 3               6 2
+--R           - 1814400a b c d + 362880a b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               8 2     5 3       2 6 2  8         8 2      5 3         2 6 2  7
+--R           (- a d  + 2a b c d - a b c )n  + (- 44a d  + 88a b c d - 44a b c )n
+--R         + 
+--R                  8 2        5 3          2 6 2  6
+--R           (- 826a d  + 1652a b c d - 826a b c )n
+--R         + 
+--R                   8 2         5 3           2 6 2  5
+--R           (- 8624a d  + 17248a b c d - 8624a b c )n
+--R         + 
+--R                    8 2          5 3            2 6 2  4
+--R           (- 54649a d  + 109298a b c d - 54649a b c )n
+--R         + 
+--R                     8 2          5 3             2 6 2  3
+--R           (- 214676a d  + 429352a b c d - 214676a b c )n
+--R         + 
+--R                     8 2           5 3             2 6 2  2
+--R           (- 509004a d  + 1018008a b c d - 509004a b c )n
+--R         + 
+--R                     8 2           5 3             2 6 2            8 2
+--R           (- 663696a d  + 1327392a b c d - 663696a b c )n - 362880a d
+--R         + 
+--R                  5 3             2 6 2
+--R           725760a b c d - 362880a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        9 9      9 8       9 7        9 6         9 5          9 4          9 3
+--R       b n  + 45b n  + 870b n  + 9450b n  + 63273b n  + 269325b n  + 723680b n
+--R     + 
+--R               9 2           9           9
+--R       1172700b n  + 1026576b n + 362880b
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         8 2 8     8     5    8 2 2   n log(b x + a)    2         n + 8
+--R       (b d x  + 2b c d x  + b c x )%e               - d (b x + a)
+--R     + 
+--R           2         n + 7      2 2         n + 6
+--R       8a d (b x + a)      - 28a d (b x + a)
+--R     + 
+--R           3 2     3             n + 5         4 2        3             n + 4
+--R       (56a d  - 2b c d)(b x + a)      + (- 70a d  + 10a b c d)(b x + a)
+--R     + 
+--R           5 2      2 3             n + 3
+--R       (56a d  - 20a b c d)(b x + a)
+--R     + 
+--R             6 2      3 3       6 2          n + 2
+--R       (- 28a d  + 20a b c d - b c )(b x + a)
+--R     + 
+--R          7 2      4 3          6 2          n + 1
+--R       (8a d  - 10a b c d + 2a b c )(b x + a)
+--R     + 
+--R           8 2     5 3       2 6 2          n
+--R       (- a d  + 2a b c d - a b c )(b x + a)
+--R  /
+--R      8
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 858
+
+)clear all
+
+--S 859 of 953
+t0:=x*(a+b*x)^n*(c+d*x^3)^2
+--R 
+--R
+--R          2 7         4    2           n
+--R   (1)  (d x  + 2c d x  + c x)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 859
+
+--S 860 of 953
+r0:=-a*(b^3*c-a^3*d)^2*(a+b*x)^(1+n)/(b^8*(1+n))+(b^3*c-7*a^3*d)*_
+   (b^3*c-a^3*d)*(a+b*x)^(2+n)/(b^8*(2+n))+3*a^2*d*(4*b^3*c-7*a^3*d)*_
+   (a+b*x)^(3+n)/(b^8*(3+n))-a*d*(8*b^3*c-35*a^3*d)*(a+b*x)^(4+n)/_
+   (b^8*(4+n))+d*(2*b^3*c-35*a^3*d)*(a+b*x)^(5+n)/(b^8*(5+n))+21*a^2*_
+   d^2*(a+b*x)^(6+n)/(b^8*(6+n))-7*a*d^2*(a+b*x)^(7+n)/(b^8*(7+n))+_
+   d^2*(a+b*x)^(8+n)/(b^8*(8+n))
+--R 
+--R
+--R   (2)
+--R            2 7      2 6       2 5        2 4        2 3         2 2         2
+--R           d n  + 28d n  + 322d n  + 1960d n  + 6769d n  + 13132d n  + 13068d n
+--R         + 
+--R                2
+--R           5040d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                 2 7         2 6          2 5           2 4           2 3
+--R           - 7a d n  - 203a d n  - 2401a d n  - 14945a d n  - 52528a d n
+--R         + 
+--R                      2 2            2            2
+--R           - 103292a d n  - 103824a d n - 40320a d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R              2 2 7       2 2 6        2 2 5         2 2 4          2 2 3
+--R           21a d n  + 630a d n  + 7686a d n  + 49140a d n  + 176589a d n
+--R         + 
+--R                  2 2 2          2 2           2 2
+--R           353430a d n  + 360024a d n + 141120a d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                 3 2     3     7           3 2      3     6
+--R           (- 35a d  + 2b c d)n  + (- 1085a d  + 62b c d)n
+--R         + 
+--R                    3 2       3     5            3 2        3     4
+--R           (- 13685a d  + 782b c d)n  + (- 90335a d  + 5162b c d)n
+--R         + 
+--R                     3 2         3     3             3 2         3     2
+--R           (- 334040a d  + 19088b c d)n  + (- 684740a d  + 39128b c d)n
+--R         + 
+--R                     3 2         3               3 2         3
+--R           (- 710640a d  + 40608b c d)n - 282240a d  + 16128b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R               4 2       3     7         4 2         3     6
+--R           (35a d  - 8a b c d)n  + (1120a d  - 256a b c d)n
+--R         + 
+--R                  4 2          3     5           4 2           3     4
+--R           (14630a d  - 3344a b c d)n  + (100240a d  - 22912a b c d)n
+--R         + 
+--R                   4 2           3     3           4 2            3     2
+--R           (384755a d  - 87944a b c d)n  + (815920a d  - 186496a b c d)n
+--R         + 
+--R                   4 2            3               4 2           3
+--R           (870660a d  - 199008a b c d)n + 352800a d  - 80640a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 5 2      2 3     7          5 2       2 3     6
+--R           (- 21a d  + 12a b c d)n  + (- 693a d  + 396a b c d)n
+--R         + 
+--R                   5 2        2 3     5            5 2         2 3     4
+--R           (- 9387a d  + 5364a b c d)n  + (- 67095a d  + 38340a b c d)n
+--R         + 
+--R                     5 2          2 3     3             5 2          2 3     2
+--R           (- 270144a d  + 154368a b c d)n  + (- 602532a d  + 344304a b c d)n
+--R         + 
+--R                     5 2          2 3               5 2          2 3
+--R           (- 673008a d  + 384576a b c d)n - 282240a d  + 161280a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R              6 2     3 3       6 2  7        6 2       3 3         6 2  6
+--R           (7a d  - 8a b c d + b c )n  + (238a d  - 272a b c d + 34b c )n
+--R         + 
+--R                 6 2        3 3          6 2  5
+--R           (3346a d  - 3824a b c d + 478b c )n
+--R         + 
+--R                  6 2         3 3           6 2  4
+--R           (25060a d  - 28640a b c d + 3580b c )n
+--R         + 
+--R                   6 2          3 3            6 2  3
+--R           (107023a d  - 122312a b c d + 15289b c )n
+--R         + 
+--R                   6 2          3 3            6 2  2
+--R           (256942a d  - 293648a b c d + 36706b c )n
+--R         + 
+--R                   6 2          3 3            6 2            6 2
+--R           (312984a d  - 357696a b c d + 44712b c )n + 141120a d
+--R         + 
+--R                    3 3            6 2
+--R           - 161280a b c d + 20160b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               7 2     4 3         6 2  7         7 2      4 3           6 2  6
+--R           (- a d  + 2a b c d - a b c )n  + (- 35a d  + 70a b c d - 35a b c )n
+--R         + 
+--R                  7 2        4 3            6 2  5
+--R           (- 511a d  + 1022a b c d - 511a b c )n
+--R         + 
+--R                   7 2        4 3             6 2  4
+--R           (- 4025a d  + 8050a b c d - 4025a b c )n
+--R         + 
+--R                    7 2         4 3              6 2  3
+--R           (- 18424a d  + 36848a b c d - 18424a b c )n
+--R         + 
+--R                    7 2         4 3              6 2  2
+--R           (- 48860a d  + 97720a b c d - 48860a b c )n
+--R         + 
+--R                    7 2          4 3              6 2           7 2
+--R           (- 69264a d  + 138528a b c d - 69264a b c )n - 40320a d
+--R         + 
+--R                 4 3              6 2
+--R           80640a b c d - 40320a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        8 8      8 7       8 6        8 5         8 4         8 3          8 2
+--R       b n  + 36b n  + 546b n  + 4536b n  + 22449b n  + 67284b n  + 118124b n
+--R     + 
+--R              8          8
+--R       109584b n + 40320b
+--R                                                    Type: Expression(Integer)
+--E 860
+
+--S 861 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              8 2 7      8 2 6       8 2 5        8 2 4        8 2 3
+--R             b d n  + 28b d n  + 322b d n  + 1960b d n  + 6769b d n
+--R           + 
+--R                   8 2 2         8 2         8 2
+--R             13132b d n  + 13068b d n + 5040b d
+--R        *
+--R            8
+--R           x
+--R       + 
+--R                7 2 7        7 2 6         7 2 5         7 2 4          7 2 3
+--R             a b d n  + 21a b d n  + 175a b d n  + 735a b d n  + 1624a b d n
+--R           + 
+--R                    7 2 2         7 2
+--R             1764a b d n  + 720a b d n
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                 2 6 2 6       2 6 2 5       2 6 2 4        2 6 2 3
+--R             - 7a b d n  - 105a b d n  - 595a b d n  - 1575a b d n
+--R           + 
+--R                    2 6 2 2       2 6 2
+--R             - 1918a b d n  - 840a b d n
+--R        *
+--R            6
+--R           x
+--R       + 
+--R               8     7      8     6       3 5 2       8     5
+--R             2b c d n  + 62b c d n  + (42a b d  + 782b c d)n
+--R           + 
+--R                  3 5 2        8     4         3 5 2         8     3
+--R             (420a b d  + 5162b c d)n  + (1470a b d  + 19088b c d)n
+--R           + 
+--R                 3 5 2         8     2         3 5 2         8              8
+--R           (2100a b d  + 39128b c d)n  + (1008a b d  + 40608b c d)n + 16128b c d
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                 7     7        7     6         7     5
+--R             2a b c d n  + 54a b c d n  + 566a b c d n
+--R           + 
+--R                    4 4 2          7     4           4 4 2          7     3
+--R             (- 210a b d  + 2898a b c d)n  + (- 1260a b d  + 7496a b c d)n
+--R           + 
+--R                     4 4 2          7     2           4 4 2          7
+--R             (- 2310a b d  + 9144a b c d)n  + (- 1260a b d  + 4032a b c d)n
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                 2 6     6       2 6     5        2 6     4
+--R             - 8a b c d n  - 192a b c d n  - 1688a b c d n
+--R           + 
+--R                  5 3 2        2 6     3         5 3 2         2 6     2
+--R             (840a b d  - 6528a b c d)n  + (2520a b d  - 10400a b c d)n
+--R           + 
+--R                   5 3 2        2 6
+--R             (1680a b d  - 5376a b c d)n
+--R        *
+--R            3
+--R           x
+--R       + 
+--R              8 2 7      8 2 6       3 5          8 2  5
+--R             b c n  + 34b c n  + (24a b c d + 478b c )n
+--R           + 
+--R                  3 5           8 2  4         3 5            8 2  3
+--R             (528a b c d + 3580b c )n  + (4008a b c d + 15289b c )n
+--R           + 
+--R                     6 2 2         3 5            8 2  2
+--R             (- 2520a b d  + 11568a b c d + 36706b c )n
+--R           + 
+--R                     6 2 2        3 5            8 2           8 2
+--R             (- 2520a b d  + 8064a b c d + 44712b c )n + 20160b c
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                7 2 7        7 2 6         7 2 5         4 4             7 2  4
+--R             a b c n  + 33a b c n  + 445a b c n  + (- 48a b c d + 3135a b c )n
+--R           + 
+--R                     4 4              7 2  3           4 4              7 2  2
+--R             (- 1008a b c d + 12154a b c )n  + (- 7008a b c d + 24552a b c )n
+--R           + 
+--R                   7   2         4 4              7 2
+--R             (5040a b d  - 16128a b c d + 20160a b c )n
+--R        *
+--R           x
+--R       + 
+--R            2 6 2 6      2 6 2 5       2 6 2 4       5 3           2 6 2  3
+--R         - a b c n  - 33a b c n  - 445a b c n  + (48a b c d - 3135a b c )n
+--R       + 
+--R               5 3            2 6 2  2         5 3            2 6 2          8 2
+--R         (1008a b c d - 12154a b c )n  + (7008a b c d - 24552a b c )n - 5040a d
+--R       + 
+--R               5 3            2 6 2
+--R         16128a b c d - 20160a b c
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R        8 8      8 7       8 6        8 5         8 4         8 3          8 2
+--R       b n  + 36b n  + 546b n  + 4536b n  + 22449b n  + 67284b n  + 118124b n
+--R     + 
+--R              8          8
+--R       109584b n + 40320b
+--R                                         Type: Union(Expression(Integer),...)
+--E 861
+
+--S 862 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                8 2 7      8 2 6       8 2 5        8 2 4        8 2 3
+--R               b d n  + 28b d n  + 322b d n  + 1960b d n  + 6769b d n
+--R             + 
+--R                     8 2 2         8 2         8 2
+--R               13132b d n  + 13068b d n + 5040b d
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                  7 2 7        7 2 6         7 2 5         7 2 4          7 2 3
+--R               a b d n  + 21a b d n  + 175a b d n  + 735a b d n  + 1624a b d n
+--R             + 
+--R                      7 2 2         7 2
+--R               1764a b d n  + 720a b d n
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                   2 6 2 6       2 6 2 5       2 6 2 4        2 6 2 3
+--R               - 7a b d n  - 105a b d n  - 595a b d n  - 1575a b d n
+--R             + 
+--R                      2 6 2 2       2 6 2
+--R               - 1918a b d n  - 840a b d n
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                 8     7      8     6       3 5 2       8     5
+--R               2b c d n  + 62b c d n  + (42a b d  + 782b c d)n
+--R             + 
+--R                    3 5 2        8     4         3 5 2         8     3
+--R               (420a b d  + 5162b c d)n  + (1470a b d  + 19088b c d)n
+--R             + 
+--R                     3 5 2         8     2         3 5 2         8
+--R               (2100a b d  + 39128b c d)n  + (1008a b d  + 40608b c d)n
+--R             + 
+--R                     8
+--R               16128b c d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                   7     7        7     6         7     5
+--R               2a b c d n  + 54a b c d n  + 566a b c d n
+--R             + 
+--R                      4 4 2          7     4           4 4 2          7     3
+--R               (- 210a b d  + 2898a b c d)n  + (- 1260a b d  + 7496a b c d)n
+--R             + 
+--R                       4 4 2          7     2           4 4 2          7
+--R               (- 2310a b d  + 9144a b c d)n  + (- 1260a b d  + 4032a b c d)n
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   2 6     6       2 6     5        2 6     4
+--R               - 8a b c d n  - 192a b c d n  - 1688a b c d n
+--R             + 
+--R                    5 3 2        2 6     3         5 3 2         2 6     2
+--R               (840a b d  - 6528a b c d)n  + (2520a b d  - 10400a b c d)n
+--R             + 
+--R                     5 3 2        2 6
+--R               (1680a b d  - 5376a b c d)n
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                8 2 7      8 2 6       3 5          8 2  5
+--R               b c n  + 34b c n  + (24a b c d + 478b c )n
+--R             + 
+--R                    3 5           8 2  4         3 5            8 2  3
+--R               (528a b c d + 3580b c )n  + (4008a b c d + 15289b c )n
+--R             + 
+--R                       6 2 2         3 5            8 2  2
+--R               (- 2520a b d  + 11568a b c d + 36706b c )n
+--R             + 
+--R                       6 2 2        3 5            8 2           8 2
+--R               (- 2520a b d  + 8064a b c d + 44712b c )n + 20160b c
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                  7 2 7        7 2 6         7 2 5
+--R               a b c n  + 33a b c n  + 445a b c n
+--R             + 
+--R                     4 4             7 2  4           4 4              7 2  3
+--R               (- 48a b c d + 3135a b c )n  + (- 1008a b c d + 12154a b c )n
+--R             + 
+--R                       4 4              7 2  2
+--R               (- 7008a b c d + 24552a b c )n
+--R             + 
+--R                     7   2         4 4              7 2
+--R               (5040a b d  - 16128a b c d + 20160a b c )n
+--R          *
+--R             x
+--R         + 
+--R              2 6 2 6      2 6 2 5       2 6 2 4       5 3           2 6 2  3
+--R           - a b c n  - 33a b c n  - 445a b c n  + (48a b c d - 3135a b c )n
+--R         + 
+--R                 5 3            2 6 2  2         5 3            2 6 2
+--R           (1008a b c d - 12154a b c )n  + (7008a b c d - 24552a b c )n
+--R         + 
+--R                  8 2         5 3            2 6 2
+--R           - 5040a d  + 16128a b c d - 20160a b c
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R              2 7      2 6       2 5        2 4        2 3         2 2
+--R           - d n  - 28d n  - 322d n  - 1960d n  - 6769d n  - 13132d n
+--R         + 
+--R                   2         2
+--R           - 13068d n - 5040d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R               2 7         2 6          2 5           2 4           2 3
+--R           7a d n  + 203a d n  + 2401a d n  + 14945a d n  + 52528a d n
+--R         + 
+--R                    2 2            2            2
+--R           103292a d n  + 103824a d n + 40320a d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                2 2 7       2 2 6        2 2 5         2 2 4          2 2 3
+--R           - 21a d n  - 630a d n  - 7686a d n  - 49140a d n  - 176589a d n
+--R         + 
+--R                    2 2 2          2 2           2 2
+--R           - 353430a d n  - 360024a d n - 141120a d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R               3 2     3     7         3 2      3     6
+--R           (35a d  - 2b c d)n  + (1085a d  - 62b c d)n
+--R         + 
+--R                  3 2       3     5          3 2        3     4
+--R           (13685a d  - 782b c d)n  + (90335a d  - 5162b c d)n
+--R         + 
+--R                   3 2         3     3           3 2         3     2
+--R           (334040a d  - 19088b c d)n  + (684740a d  - 39128b c d)n
+--R         + 
+--R                   3 2         3               3 2         3
+--R           (710640a d  - 40608b c d)n + 282240a d  - 16128b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                 4 2       3     7           4 2         3     6
+--R           (- 35a d  + 8a b c d)n  + (- 1120a d  + 256a b c d)n
+--R         + 
+--R                    4 2          3     5             4 2           3     4
+--R           (- 14630a d  + 3344a b c d)n  + (- 100240a d  + 22912a b c d)n
+--R         + 
+--R                     4 2           3     3             4 2            3     2
+--R           (- 384755a d  + 87944a b c d)n  + (- 815920a d  + 186496a b c d)n
+--R         + 
+--R                     4 2            3               4 2           3
+--R           (- 870660a d  + 199008a b c d)n - 352800a d  + 80640a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R               5 2      2 3     7        5 2       2 3     6
+--R           (21a d  - 12a b c d)n  + (693a d  - 396a b c d)n
+--R         + 
+--R                 5 2        2 3     5          5 2         2 3     4
+--R           (9387a d  - 5364a b c d)n  + (67095a d  - 38340a b c d)n
+--R         + 
+--R                   5 2          2 3     3           5 2          2 3     2
+--R           (270144a d  - 154368a b c d)n  + (602532a d  - 344304a b c d)n
+--R         + 
+--R                   5 2          2 3               5 2          2 3
+--R           (673008a d  - 384576a b c d)n + 282240a d  - 161280a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R                6 2     3 3       6 2  7          6 2       3 3         6 2  6
+--R           (- 7a d  + 8a b c d - b c )n  + (- 238a d  + 272a b c d - 34b c )n
+--R         + 
+--R                   6 2        3 3          6 2  5
+--R           (- 3346a d  + 3824a b c d - 478b c )n
+--R         + 
+--R                    6 2         3 3           6 2  4
+--R           (- 25060a d  + 28640a b c d - 3580b c )n
+--R         + 
+--R                     6 2          3 3            6 2  3
+--R           (- 107023a d  + 122312a b c d - 15289b c )n
+--R         + 
+--R                     6 2          3 3            6 2  2
+--R           (- 256942a d  + 293648a b c d - 36706b c )n
+--R         + 
+--R                     6 2          3 3            6 2            6 2
+--R           (- 312984a d  + 357696a b c d - 44712b c )n - 141120a d
+--R         + 
+--R                  3 3            6 2
+--R           161280a b c d - 20160b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             7 2     4 3         6 2  7       7 2      4 3           6 2  6
+--R           (a d  - 2a b c d + a b c )n  + (35a d  - 70a b c d + 35a b c )n
+--R         + 
+--R                7 2        4 3            6 2  5
+--R           (511a d  - 1022a b c d + 511a b c )n
+--R         + 
+--R                 7 2        4 3             6 2  4
+--R           (4025a d  - 8050a b c d + 4025a b c )n
+--R         + 
+--R                  7 2         4 3              6 2  3
+--R           (18424a d  - 36848a b c d + 18424a b c )n
+--R         + 
+--R                  7 2         4 3              6 2  2
+--R           (48860a d  - 97720a b c d + 48860a b c )n
+--R         + 
+--R                  7 2          4 3              6 2           7 2         4 3
+--R           (69264a d  - 138528a b c d + 69264a b c )n + 40320a d  - 80640a b c d
+--R         + 
+--R                   6 2
+--R           40320a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        8 8      8 7       8 6        8 5         8 4         8 3          8 2
+--R       b n  + 36b n  + 546b n  + 4536b n  + 22449b n  + 67284b n  + 118124b n
+--R     + 
+--R              8          8
+--R       109584b n + 40320b
+--R                                                    Type: Expression(Integer)
+--E 862
+
+--S 863 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         7 2 7     7     4    7 2    n log(b x + a)    2         n + 7
+--R       (b d x  + 2b c d x  + b c x)%e               - d (b x + a)
+--R     + 
+--R           2         n + 6      2 2         n + 5
+--R       7a d (b x + a)      - 21a d (b x + a)
+--R     + 
+--R           3 2     3             n + 4         4 2       3             n + 3
+--R       (35a d  - 2b c d)(b x + a)      + (- 35a d  + 8a b c d)(b x + a)
+--R     + 
+--R           5 2      2 3             n + 2
+--R       (21a d  - 12a b c d)(b x + a)
+--R     + 
+--R            6 2     3 3       6 2          n + 1
+--R       (- 7a d  + 8a b c d - b c )(b x + a)
+--R     + 
+--R         7 2     4 3         6 2          n
+--R       (a d  - 2a b c d + a b c )(b x + a)
+--R  /
+--R      7
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 863
+
+)clear all
+
+--S 864 of 953
+t0:=(a+b*x)^n*(c+d*x^3)^2
+--R 
+--R
+--R          2 6         3    2          n
+--R   (1)  (d x  + 2c d x  + c )(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 864
+
+--S 865 of 953
+r0:=(b^3*c-a^3*d)^2*(a+b*x)^(1+n)/(b^7*(1+n))+6*a^2*d*(b^3*c-a^3*d)*_
+   (a+b*x)^(2+n)/(b^7*(2+n))-3*a*d*(2*b^3*c-5*a^3*d)*(a+b*x)^(3+n)/_
+   (b^7*(3+n))+2*d*(b^3*c-10*a^3*d)*(a+b*x)^(4+n)/(b^7*(4+n))+15*a^2*_
+   d^2*(a+b*x)^(5+n)/(b^7*(5+n))-6*a*d^2*(a+b*x)^(6+n)/(b^7*(6+n))+_
+   d^2*(a+b*x)^(7+n)/(b^7*(7+n))
+--R 
+--R
+--R   (2)
+--R           2 6      2 5       2 4       2 3        2 2        2        2
+--R         (d n  + 21d n  + 175d n  + 735d n  + 1624d n  + 1764d n + 720d )
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                 2 6         2 5          2 4          2 3           2 2
+--R           - 6a d n  - 132a d n  - 1140a d n  - 4920a d n  - 11094a d n
+--R         + 
+--R                     2           2
+--R           - 12228a d n - 5040a d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R              2 2 6       2 2 5        2 2 4         2 2 3         2 2 2
+--R           15a d n  + 345a d n  + 3105a d n  + 13875a d n  + 32160a d n
+--R         + 
+--R                 2 2          2 2
+--R           36180a d n + 15120a d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                 3 2     3     6          3 2      3     5
+--R           (- 20a d  + 2b c d)n  + (- 480a d  + 48b c d)n
+--R         + 
+--R                   3 2       3     4            3 2        3     3
+--R           (- 4520a d  + 452b c d)n  + (- 21120a d  + 2112b c d)n
+--R         + 
+--R                    3 2        3     2            3 2        3              3 2
+--R           (- 50900a d  + 5090b c d)n  + (- 59040a d  + 5904b c d)n - 25200a d
+--R         + 
+--R                3
+--R           2520b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R               4 2       3     6        4 2         3     5
+--R           (15a d  - 6a b c d)n  + (375a d  - 150a b c d)n
+--R         + 
+--R                 4 2          3     4          4 2          3     3
+--R           (3705a d  - 1482a b c d)n  + (18285a d  - 7314a b c d)n
+--R         + 
+--R                  4 2           3     2          4 2           3
+--R           (46680a d  - 18672a b c d)n  + (56940a d  - 22776a b c d)n
+--R         + 
+--R                 4 2           3
+--R           25200a d  - 10080a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R                5 2     2 3     6          5 2       2 3     5
+--R           (- 6a d  + 6a b c d)n  + (- 156a d  + 156a b c d)n
+--R         + 
+--R                   5 2        2 3     4           5 2        2 3     3
+--R           (- 1620a d  + 1620a b c d)n  + (- 8520a d  + 8520a b c d)n
+--R         + 
+--R                    5 2         2 3     2            5 2         2 3
+--R           (- 23574a d  + 23574a b c d)n  + (- 31644a d  + 31644a b c d)n
+--R         + 
+--R                   5 2         2 3
+--R           - 15120a d  + 15120a b c d
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             6 2     3 3       6 2  6       6 2      3 3         6 2  5
+--R           (a d  - 2a b c d + b c )n  + (27a d  - 54a b c d + 27b c )n
+--R         + 
+--R                6 2       3 3          6 2  4
+--R           (295a d  - 590a b c d + 295b c )n
+--R         + 
+--R                 6 2        3 3           6 2  3
+--R           (1665a d  - 3330a b c d + 1665b c )n
+--R         + 
+--R                 6 2         3 3           6 2  2
+--R           (5104a d  - 10208a b c d + 5104b c )n
+--R         + 
+--R                 6 2         3 3           6 2          6 2         3 3
+--R           (8028a d  - 16056a b c d + 8028b c )n + 5040a d  - 10080a b c d
+--R         + 
+--R                6 2
+--R           5040b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        7 7      7 6       7 5        7 4        7 3         7 2         7
+--R       b n  + 28b n  + 322b n  + 1960b n  + 6769b n  + 13132b n  + 13068b n
+--R     + 
+--R            7
+--R       5040b
+--R                                                    Type: Expression(Integer)
+--E 865
+
+--S 866 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              7 2 6      7 2 5       7 2 4       7 2 3        7 2 2        7 2
+--R             b d n  + 21b d n  + 175b d n  + 735b d n  + 1624b d n  + 1764b d n
+--R           + 
+--R                 7 2
+--R             720b d
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                6 2 6        6 2 5        6 2 4         6 2 3         6 2 2
+--R             a b d n  + 15a b d n  + 85a b d n  + 225a b d n  + 274a b d n
+--R           + 
+--R                   6 2
+--R             120a b d n
+--R        *
+--R            6
+--R           x
+--R       + 
+--R              2 5 2 5      2 5 2 4       2 5 2 3       2 5 2 2       2 5 2   5
+--R         (- 6a b d n  - 60a b d n  - 210a b d n  - 300a b d n  - 144a b d n)x
+--R       + 
+--R               7     6      7     5       3 4 2       7     4
+--R             2b c d n  + 48b c d n  + (30a b d  + 452b c d)n
+--R           + 
+--R                  3 4 2        7     3        3 4 2        7     2
+--R             (180a b d  + 2112b c d)n  + (330a b d  + 5090b c d)n
+--R           + 
+--R                  3 4 2        7             7
+--R             (180a b d  + 5904b c d)n + 2520b c d
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                 6     6        6     5         6     4
+--R             2a b c d n  + 42a b c d n  + 326a b c d n
+--R           + 
+--R                    4 3 2          6     3          4 3 2          6     2
+--R             (- 120a b d  + 1134a b c d)n  + (- 360a b d  + 1688a b c d)n
+--R           + 
+--R                    4 3 2         6
+--R             (- 240a b d  + 840a b c d)n
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                 2 5     5       2 5     4       2 5     3
+--R             - 6a b c d n  - 114a b c d n  - 750a b c d n
+--R           + 
+--R                  5 2 2        2 5     2        5 2 2        2 5
+--R             (360a b d  - 1902a b c d)n  + (360a b d  - 1260a b c d)n
+--R        *
+--R            2
+--R           x
+--R       + 
+--R              7 2 6      7 2 5       3 4          7 2  4
+--R             b c n  + 27b c n  + (12a b c d + 295b c )n
+--R           + 
+--R                  3 4           7 2  3         3 4           7 2  2
+--R             (216a b c d + 1665b c )n  + (1284a b c d + 5104b c )n
+--R           + 
+--R                    6   2        3 4           7 2          7 2
+--R             (- 720a b d  + 2520a b c d + 8028b c )n + 5040b c
+--R        *
+--R           x
+--R       + 
+--R            6 2 6        6 2 5         6 2 4         4 3             6 2  3
+--R         a b c n  + 27a b c n  + 295a b c n  + (- 12a b c d + 1665a b c )n
+--R       + 
+--R                4 3             6 2  2           4 3             6 2         7 2
+--R         (- 216a b c d + 5104a b c )n  + (- 1284a b c d + 8028a b c )n + 720a d
+--R       + 
+--R                4 3             6 2
+--R         - 2520a b c d + 5040a b c
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R        7 7      7 6       7 5        7 4        7 3         7 2         7
+--R       b n  + 28b n  + 322b n  + 1960b n  + 6769b n  + 13132b n  + 13068b n
+--R     + 
+--R            7
+--R       5040b
+--R                                         Type: Union(Expression(Integer),...)
+--E 866
+
+--S 867 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                7 2 6      7 2 5       7 2 4       7 2 3        7 2 2
+--R               b d n  + 21b d n  + 175b d n  + 735b d n  + 1624b d n
+--R             + 
+--R                    7 2        7 2
+--R               1764b d n + 720b d
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                  6 2 6        6 2 5        6 2 4         6 2 3         6 2 2
+--R               a b d n  + 15a b d n  + 85a b d n  + 225a b d n  + 274a b d n
+--R             + 
+--R                     6 2
+--R               120a b d n
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                2 5 2 5      2 5 2 4       2 5 2 3       2 5 2 2       2 5 2   5
+--R           (- 6a b d n  - 60a b d n  - 210a b d n  - 300a b d n  - 144a b d n)x
+--R         + 
+--R                 7     6      7     5       3 4 2       7     4
+--R               2b c d n  + 48b c d n  + (30a b d  + 452b c d)n
+--R             + 
+--R                    3 4 2        7     3        3 4 2        7     2
+--R               (180a b d  + 2112b c d)n  + (330a b d  + 5090b c d)n
+--R             + 
+--R                    3 4 2        7             7
+--R               (180a b d  + 5904b c d)n + 2520b c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   6     6        6     5         6     4
+--R               2a b c d n  + 42a b c d n  + 326a b c d n
+--R             + 
+--R                      4 3 2          6     3          4 3 2          6     2
+--R               (- 120a b d  + 1134a b c d)n  + (- 360a b d  + 1688a b c d)n
+--R             + 
+--R                      4 3 2         6
+--R               (- 240a b d  + 840a b c d)n
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   2 5     5       2 5     4       2 5     3
+--R               - 6a b c d n  - 114a b c d n  - 750a b c d n
+--R             + 
+--R                    5 2 2        2 5     2        5 2 2        2 5
+--R               (360a b d  - 1902a b c d)n  + (360a b d  - 1260a b c d)n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                7 2 6      7 2 5       3 4          7 2  4
+--R               b c n  + 27b c n  + (12a b c d + 295b c )n
+--R             + 
+--R                    3 4           7 2  3         3 4           7 2  2
+--R               (216a b c d + 1665b c )n  + (1284a b c d + 5104b c )n
+--R             + 
+--R                      6   2        3 4           7 2          7 2
+--R               (- 720a b d  + 2520a b c d + 8028b c )n + 5040b c
+--R          *
+--R             x
+--R         + 
+--R              6 2 6        6 2 5         6 2 4         4 3             6 2  3
+--R           a b c n  + 27a b c n  + 295a b c n  + (- 12a b c d + 1665a b c )n
+--R         + 
+--R                  4 3             6 2  2           4 3             6 2
+--R           (- 216a b c d + 5104a b c )n  + (- 1284a b c d + 8028a b c )n
+--R         + 
+--R               7 2        4 3             6 2
+--R           720a d  - 2520a b c d + 5040a b c
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R             2 6      2 5       2 4       2 3        2 2        2        2
+--R         (- d n  - 21d n  - 175d n  - 735d n  - 1624d n  - 1764d n - 720d )
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R               2 6         2 5          2 4          2 3           2 2
+--R           6a d n  + 132a d n  + 1140a d n  + 4920a d n  + 11094a d n
+--R         + 
+--R                   2           2
+--R           12228a d n + 5040a d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                2 2 6       2 2 5        2 2 4         2 2 3         2 2 2
+--R           - 15a d n  - 345a d n  - 3105a d n  - 13875a d n  - 32160a d n
+--R         + 
+--R                   2 2          2 2
+--R           - 36180a d n - 15120a d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R               3 2     3     6        3 2      3     5         3 2       3     4
+--R           (20a d  - 2b c d)n  + (480a d  - 48b c d)n  + (4520a d  - 452b c d)n
+--R         + 
+--R                  3 2        3     3          3 2        3     2
+--R           (21120a d  - 2112b c d)n  + (50900a d  - 5090b c d)n
+--R         + 
+--R                  3 2        3              3 2        3
+--R           (59040a d  - 5904b c d)n + 25200a d  - 2520b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 4 2       3     6          4 2         3     5
+--R           (- 15a d  + 6a b c d)n  + (- 375a d  + 150a b c d)n
+--R         + 
+--R                   4 2          3     4            4 2          3     3
+--R           (- 3705a d  + 1482a b c d)n  + (- 18285a d  + 7314a b c d)n
+--R         + 
+--R                    4 2           3     2            4 2           3
+--R           (- 46680a d  + 18672a b c d)n  + (- 56940a d  + 22776a b c d)n
+--R         + 
+--R                   4 2           3
+--R           - 25200a d  + 10080a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R              5 2     2 3     6        5 2       2 3     5
+--R           (6a d  - 6a b c d)n  + (156a d  - 156a b c d)n
+--R         + 
+--R                 5 2        2 3     4         5 2        2 3     3
+--R           (1620a d  - 1620a b c d)n  + (8520a d  - 8520a b c d)n
+--R         + 
+--R                  5 2         2 3     2          5 2         2 3
+--R           (23574a d  - 23574a b c d)n  + (31644a d  - 31644a b c d)n
+--R         + 
+--R                 5 2         2 3
+--R           15120a d  - 15120a b c d
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               6 2     3 3       6 2  6         6 2      3 3         6 2  5
+--R           (- a d  + 2a b c d - b c )n  + (- 27a d  + 54a b c d - 27b c )n
+--R         + 
+--R                  6 2       3 3          6 2  4
+--R           (- 295a d  + 590a b c d - 295b c )n
+--R         + 
+--R                   6 2        3 3           6 2  3
+--R           (- 1665a d  + 3330a b c d - 1665b c )n
+--R         + 
+--R                   6 2         3 3           6 2  2
+--R           (- 5104a d  + 10208a b c d - 5104b c )n
+--R         + 
+--R                   6 2         3 3           6 2          6 2         3 3
+--R           (- 8028a d  + 16056a b c d - 8028b c )n - 5040a d  + 10080a b c d
+--R         + 
+--R                  6 2
+--R           - 5040b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        7 7      7 6       7 5        7 4        7 3         7 2         7
+--R       b n  + 28b n  + 322b n  + 1960b n  + 6769b n  + 13132b n  + 13068b n
+--R     + 
+--R            7
+--R       5040b
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         6 2 6     6     3    6 2   n log(b x + a)    2         n + 6
+--R       (b d x  + 2b c d x  + b c )%e               - d (b x + a)
+--R     + 
+--R           2         n + 5      2 2         n + 4
+--R       6a d (b x + a)      - 15a d (b x + a)
+--R     + 
+--R           3 2     3             n + 3         4 2       3             n + 2
+--R       (20a d  - 2b c d)(b x + a)      + (- 15a d  + 6a b c d)(b x + a)
+--R     + 
+--R          5 2     2 3             n + 1       6 2     3 3       6 2          n
+--R       (6a d  - 6a b c d)(b x + a)      + (- a d  + 2a b c d - b c )(b x + a)
+--R  /
+--R      6
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 868
+
+)clear all
+
+--S 869 of 953
+t0:=(a+b*x)^n*(c+d*x^3)^2/x
+--R 
+--R
+--R          2 6         3    2          n
+--R        (d x  + 2c d x  + c )(b x + a)
+--R   (1)  -------------------------------
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 869
+
+--S 870 of 953
+--r0:=2*a^2*c*d*(a+b*x)^(1+n)/(b^3*(1+n))-a^5*d^2*(a+b*x)^(1+n)/(b^6*(1+n))-_
+--   4*a*c*d*(a+b*x)^(2+n)/(b^3*(2+n))+5*a^4*d^2*(a+b*x)^(2+n)/(b^6*(2+n))+_
+--   2*c*d*(a+b*x)^(3+n)/(b^3*(3+n))-10*a^3*d^2*(a+b*x)^(3+n)/(b^6*(3+n))+_
+--   10*a^2*d^2*(a+b*x)^(4+n)/(b^6*(4+n))-5*a*d^2*(a+b*x)^(5+n)/(b^6*_
+--   (5+n))+d^2*(a+b*x)^(6+n)/(b^6*(6+n))-c^2*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*(1+n))
+--E 870
+
+--S 871 of 953
+--a0:=integrate(t0,x)
+--E 871
+
+--S 872 of 953
+--m0:=a0-r0
+--E 872
+
+--S 873 of 953
+--d0:=D(m0,x)
+--E 873
+
+)clear all
+
+--S 874 of 953
+t0:=x^2*(a+b*x)^n*(c+d*x^3)^3
+--R 
+--R
+--R          3 11       2 8     2   5    3 2          n
+--R   (1)  (d x   + 3c d x  + 3c d x  + c x )(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 874
+
+--S 875 of 953
+r0:=a^2*(b^3*c-a^3*d)^3*(a+b*x)^(1+n)/(b^12*(1+n))-a*(2*b^3*c-11*a^3*d)*_
+   (b^3*c-a^3*d)^2*(a+b*x)^(2+n)/(b^12*(2+n))+(b^3*c-a^3*d)*(b^6*c^2-29*_
+   a^3*b^3*c*d+55*a^6*d^2)*(a+b*x)^(3+n)/(b^12*(3+n))+3*a^2*d*(10*b^6*_
+   c^2-56*a^3*b^3*c*d+55*a^6*d^2)*(a+b*x)^(4+n)/(b^12*(4+n))-15*a*d*_
+   (b^6*c^2-14*a^3*b^3*c*d+22*a^6*d^2)*(a+b*x)^(5+n)/(b^12*(5+n))+_
+   3*d*(b^6*c^2-56*a^3*b^3*c*d+154*a^6*d^2)*(a+b*x)^(6+n)/(b^12*(6+n))+_
+   42*a^2*d^2*(2*b^3*c-11*a^3*d)*(a+b*x)^(7+n)/(b^12*(7+n))-6*a*d^2*_
+   (4*b^3*c-55*a^3*d)*(a+b*x)^(8+n)/(b^12*(8+n))+3*d^2*(b^3*c-55*a^3*d)*_
+   (a+b*x)^(9+n)/(b^12*(9+n))+55*a^2*d^3*(a+b*x)^(10+n)/(b^12*(10+n))-_
+   11*a*d^3*(a+b*x)^(11+n)/(b^12*(11+n))+d^3*(a+b*x)^(12+n)/(b^12*(12+n))
+--R 
+--R
+--R   (2)
+--R            3 11      3 10        3 9         3 8          3 7           3 6
+--R           d n   + 66d n   + 1925d n  + 32670d n  + 357423d n  + 2637558d n
+--R         + 
+--R                    3 5            3 4             3 3             3 2
+--R           13339535d n  + 45995730d n  + 105258076d n  + 150917976d n
+--R         + 
+--R                     3             3
+--R           120543840d n + 39916800d
+--R      *
+--R                  n + 12
+--R         (b x + a)
+--R     + 
+--R                  3 11         3 10           3 9            3 8             3 7
+--R           - 11a d n   - 737a d n   - 21780a d n  - 373890a d n  - 4131303a d n
+--R         + 
+--R                        3 6               3 5               3 4
+--R           - 30748641a d n  - 156657490a d n  - 543539260a d n
+--R         + 
+--R                        3 3                3 2                3                3
+--R         - 1250343336a d n  - 1800387072a d n  - 1442897280a d n - 479001600a d
+--R      *
+--R                  n + 11
+--R         (b x + a)
+--R     + 
+--R              2 3 11        2 3 10          2 3 9           2 3 8
+--R           55a d n   + 3740a d n   + 112035a d n  + 1947000a d n
+--R         + 
+--R                    2 3 7             2 3 6             2 3 5              2 3 4
+--R           21750465a d n  + 163460220a d n  + 839860505a d n  + 2935253200a d n
+--R         + 
+--R                    2 3 3              2 3 2              2 3               2 3
+--R         6793843980a d n  + 9832379040a d n  + 7911984960a d n + 2634508800a d
+--R      *
+--R                  n + 10
+--R         (b x + a)
+--R     + 
+--R                  3 3     3   2  11            3 3       3   2  10
+--R           (- 165a d  + 3b c d )n   + (- 11385a d  + 207b c d )n
+--R         + 
+--R                     3 3        3   2  9              3 3          3   2  8
+--R           (- 345840a d  + 6288b c d )n  + (- 6089490a d  + 110718b c d )n
+--R         + 
+--R                       3 3           3   2  7
+--R           (- 68855985a d  + 1251927b c d )n
+--R         + 
+--R                        3 3           3   2  6
+--R           (- 523190745a d  + 9512559b c d )n
+--R         + 
+--R                         3 3            3   2  5
+--R           (- 2714671410a d  + 49357662b c d )n
+--R         + 
+--R                         3 3             3   2  4
+--R           (- 9569532060a d  + 173991492b c d )n
+--R         + 
+--R                          3 3             3   2  3
+--R           (- 22313339400a d  + 405697080b c d )n
+--R         + 
+--R                          3 3             3   2  2
+--R           (- 32492401920a d  + 590770944b c d )n
+--R         + 
+--R                          3 3             3   2                3 3
+--R           (- 26275708800a d  + 477740160b c d )n - 8781696000a d
+--R         + 
+--R                     3   2
+--R           159667200b c d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R                4 3        3   2  11          4 3          3   2  10
+--R           (330a d  - 24a b c d )n   + (23100a d  - 1680a b c d )n
+--R         + 
+--R                   4 3           3   2  9             4 3            3   2  8
+--R           (711810a d  - 51768a b c d )n  + (12709620a d  - 924336a b c d )n
+--R         + 
+--R                      4 3              3   2  7
+--R           (145645830a d  - 10592424a b c d )n
+--R         + 
+--R                       4 3              3   2  6
+--R           (1120622580a d  - 81499824a b c d )n
+--R         + 
+--R                       4 3               3   2  5
+--R           (5881795590a d  - 427766952a b c d )n
+--R         + 
+--R                        4 3                3   2  4
+--R           (20948784780a d  - 1523547984a b c d )n
+--R         + 
+--R                        4 3                3   2  3
+--R           (49287977640a d  - 3584580192a b c d )n
+--R         + 
+--R                        4 3                3   2  2
+--R           (72321091920a d  - 5259715776a b c d )n
+--R         + 
+--R                        4 3                3   2                 4 3
+--R           (58845916800a d  - 4279703040a b c d )n + 19758816000a d
+--R         + 
+--R                          3   2
+--R           - 1437004800a b c d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                  5 3      2 3   2  11            5 3        2 3   2  10
+--R           (- 462a d  + 84a b c d )n   + (- 32802a d  + 5964a b c d )n
+--R         + 
+--R                      5 3          2 3   2  9
+--R           (- 1025640a d  + 186480a b c d )n
+--R         + 
+--R                       5 3           2 3   2  8
+--R           (- 18586260a d  + 3379320a b c d )n
+--R         + 
+--R                        5 3            2 3   2  7
+--R           (- 216148086a d  + 39299652a b c d )n
+--R         + 
+--R                         5 3             2 3   2  6
+--R           (- 1687068306a d  + 306739692a b c d )n
+--R         + 
+--R                         5 3              2 3   2  5
+--R           (- 8976008580a d  + 1632001560a b c d )n
+--R         + 
+--R                          5 3              2 3   2  4
+--R           (- 32372349240a d  + 5885881680a b c d )n
+--R         + 
+--R                          5 3               2 3   2  3
+--R           (- 77023113552a d  + 14004202464a b c d )n
+--R         + 
+--R                           5 3               2 3   2  2
+--R           (- 114113083392a d  + 20747833344a b c d )n
+--R         + 
+--R                          5 3               2 3   2                 5 3
+--R           (- 93588929280a d  + 17016168960a b c d )n - 31614105600a d
+--R         + 
+--R                      2 3   2
+--R           5748019200a b c d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                6 3       3 3   2     6 2   11
+--R           (462a d  - 168a b c d  + 3b c d)n
+--R         + 
+--R                  6 3         3 3   2       6 2   10
+--R           (33264a d  - 12096a b c d  + 216b c d)n
+--R         + 
+--R                    6 3          3 3   2        6 2   9
+--R           (1055670a d  - 383880a b c d  + 6855b c d)n
+--R         + 
+--R                     6 3           3 3   2          6 2   8
+--R           (19431720a d  - 7066080a b c d  + 126180b c d)n
+--R         + 
+--R                      6 3            3 3   2           6 2   7
+--R           (229661586a d  - 83513304a b c d  + 1491309b c d)n
+--R         + 
+--R                       6 3             3 3   2            6 2   6
+--R           (1822135392a d  - 662594688a b c d  + 11832048b c d)n
+--R         + 
+--R                       6 3              3 3   2            6 2   5
+--R           (9852674370a d  - 3582790680a b c d  + 63978405b c d)n
+--R         + 
+--R                        6 3               3 3   2             6 2   4
+--R           (36088363080a d  - 13123041120a b c d  + 234340020b c d)n
+--R         + 
+--R                        6 3               3 3   2             6 2   3
+--R           (87099379752a d  - 31672501728a b c d  + 565580388b c d)n
+--R         + 
+--R                         6 3               3 3   2             6 2   2
+--R           (130678599744a d  - 47519490816a b c d  + 848562336b c d)n
+--R         + 
+--R                         6 3               3 3   2             6 2
+--R           (108308914560a d  - 39385059840a b c d  + 703304640b c d)n
+--R         + 
+--R                       6 3               3 3   2             6 2
+--R           36883123200a d  - 13412044800a b c d  + 239500800b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                  7 3       4 3   2        6 2   11
+--R           (- 330a d  + 210a b c d  - 15a b c d)n
+--R         + 
+--R                    7 3         4 3   2          6 2   10
+--R           (- 24090a d  + 15330a b c d  - 1095a b c d)n
+--R         + 
+--R                     7 3          4 3   2           6 2   9
+--R           (- 776160a d  + 493920a b c d  - 35280a b c d)n
+--R         + 
+--R                       7 3           4 3   2            6 2   8
+--R           (- 14523300a d  + 9242100a b c d  - 660150a b c d)n
+--R         + 
+--R                        7 3             4 3   2             6 2   7
+--R           (- 174706290a d  + 111176730a b c d  - 7941195a b c d)n
+--R         + 
+--R                         7 3             4 3   2              6 2   6
+--R           (- 1412257770a d  + 898709490a b c d  - 64193535a b c d)n
+--R         + 
+--R                         7 3              4 3   2               6 2   5
+--R           (- 7785487380a d  + 4954401060a b c d  - 353885790a b c d)n
+--R         + 
+--R                          7 3               4 3   2                6 2   4
+--R           (- 29075712600a d  + 18502726200a b c d  - 1321623300a b c d)n
+--R         + 
+--R                          7 3               4 3   2                6 2   3
+--R           (- 71499692880a d  + 45499804560a b c d  - 3249986040a b c d)n
+--R         + 
+--R                           7 3               4 3   2                6 2   2
+--R           (- 109126448640a d  + 69444103680a b c d  - 4960293120a b c d)n
+--R         + 
+--R                          7 3               4 3   2                6 2
+--R           (- 91782408960a d  + 58406987520a b c d  - 4171927680a b c d)n
+--R         + 
+--R                         7 3               4 3   2                6 2
+--R           - 31614105600a d  + 20118067200a b c d  - 1437004800a b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                8 3       5 3   2      2 6 2   11
+--R           (165a d  - 168a b c d  + 30a b c d)n
+--R         + 
+--R                  8 3         5 3   2        2 6 2   10
+--R           (12210a d  - 12432a b c d  + 2220a b c d)n
+--R         + 
+--R                   8 3          5 3   2         2 6 2   9
+--R           (399465a d  - 406728a b c d  + 72630a b c d)n
+--R         + 
+--R                    8 3           5 3   2           2 6 2   8
+--R           (7604190a d  - 7742448a b c d  + 1382580a b c d)n
+--R         + 
+--R                     8 3            5 3   2            2 6 2   7
+--R           (93244635a d  - 94939992a b c d  + 16953570a b c d)n
+--R         + 
+--R                      8 3             5 3   2             2 6 2   6
+--R           (769916070a d  - 783914544a b c d  + 139984740a b c d)n
+--R         + 
+--R                       8 3              5 3   2             2 6 2   5
+--R           (4343723835a d  - 4422700632a b c d  + 789767970a b c d)n
+--R         + 
+--R                        8 3               5 3   2              2 6 2   4
+--R           (16626679410a d  - 16928982672a b c d  + 3023032620a b c d)n
+--R         + 
+--R                        8 3               5 3   2              2 6 2   3
+--R           (41932410300a d  - 42694817760a b c d  + 7624074600a b c d)n
+--R         + 
+--R                        8 3               5 3   2               2 6 2   2
+--R           (65582815320a d  - 66775230144a b c d  + 11924148240a b c d)n
+--R         + 
+--R                        8 3               5 3   2               2 6 2
+--R           (56376064800a d  - 57401084160a b c d  + 10250193600a b c d)n
+--R         + 
+--R                       8 3               5 3   2              2 6 2
+--R           19758816000a d  - 20118067200a b c d  + 3592512000a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 9 3      6 3   2      3 6 2     9 3  11
+--R           (- 55a d  + 84a b c d  - 30a b c d + b c )n
+--R         + 
+--R                   9 3        6 3   2        3 6 2       9 3  10
+--R           (- 4125a d  + 6300a b c d  - 2250a b c d + 75b c )n
+--R         + 
+--R                     9 3          6 3   2         3 6 2         9 3  9
+--R           (- 137060a d  + 209328a b c d  - 74760a b c d + 2492b c )n
+--R         + 
+--R                      9 3           6 3   2           3 6 2          9 3  8
+--R           (- 2656170a d  + 4056696a b c d  - 1448820a b c d + 48294b c )n
+--R         + 
+--R                       9 3            6 3   2            3 6 2           9 3  7
+--R           (- 33251955a d  + 50784804a b c d  - 18137430a b c d + 604581b c )n
+--R         + 
+--R                           9 3             6 3   2             3 6 2
+--R               - 281209005a d  + 429482844a b c d  - 153386730a b c d
+--R             + 
+--R                       9 3
+--R               5112891b c
+--R          *
+--R              6
+--R             n
+--R         + 
+--R                            9 3              6 3   2             3 6 2
+--R               - 1630835690a d  + 2490730872a b c d  - 889546740a b c d
+--R             + 
+--R                        9 3
+--R               29651558b c
+--R          *
+--R              5
+--R             n
+--R         + 
+--R                            9 3              6 3   2              3 6 2
+--R               - 6441351180a d  + 9837699984a b c d  - 3513464280a b c d
+--R             + 
+--R                         9 3
+--R               117115476b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                             9 3               6 3   2              3 6 2
+--R               - 16822322440a d  + 25692274272a b c d  - 9175812240a b c d
+--R             + 
+--R                         9 3
+--R               305860408b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                             9 3               6 3   2               3 6 2
+--R               - 27303851520a d  + 41700427776a b c d  - 14893009920a b c d
+--R             + 
+--R                         9 3
+--R               496433664b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                             9 3               6 3   2               3 6 2
+--R               - 24324220800a d  + 37149719040a b c d  - 13267756800a b c d
+--R             + 
+--R                         9 3
+--R               442258560b c
+--R          *
+--R             n
+--R         + 
+--R                        9 3               6 3   2              3 6 2
+--R           - 8781696000a d  + 13412044800a b c d  - 4790016000a b c d
+--R         + 
+--R                     9 3
+--R           159667200b c
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R               10 3      7 3   2      4 6 2        9 3  11
+--R           (11a  d  - 24a b c d  + 15a b c d - 2a b c )n
+--R         + 
+--R                10 3        7 3   2        4 6 2          9 3  10
+--R           (836a  d  - 1824a b c d  + 1140a b c d - 152a b c )n
+--R         + 
+--R                  10 3         7 3   2         4 6 2           9 3  9
+--R           (28215a  d  - 61560a b c d  + 38475a b c d - 5130a b c )n
+--R         + 
+--R                   10 3           7 3   2          4 6 2             9 3  8
+--R           (557040a  d  - 1215360a b c d  + 759600a b c d - 101280a b c )n
+--R         + 
+--R                    10 3            7 3   2           4 6 2              9 3  7
+--R           (7130013a  d  - 15556392a b c d  + 9722745a b c d - 1296366a b c )n
+--R         + 
+--R                        10 3             7 3   2            4 6 2
+--R               61932948a  d  - 135126432a b c d  + 84454020a b c d
+--R             + 
+--R                            9 3
+--R               - 11260536a b c
+--R          *
+--R              6
+--R             n
+--R         + 
+--R                         10 3             7 3   2             4 6 2
+--R               371026645a  d  - 809512680a b c d  + 505945425a b c d
+--R             + 
+--R                            9 3
+--R               - 67459390a b c
+--R          *
+--R              5
+--R             n
+--R         + 
+--R                          10 3              7 3   2              4 6 2
+--R               1524718360a  d  - 3326658240a b c d  + 2079161400a b c d
+--R             + 
+--R                             9 3
+--R               - 277221520a b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                          10 3              7 3   2              4 6 2
+--R               4179838476a  d  - 9119647584a b c d  + 5699779740a b c d
+--R             + 
+--R                             9 3
+--R               - 759970632a b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                          10 3               7 3   2              4 6 2
+--R               7194486816a  d  - 15697062144a b c d  + 9810663840a b c d
+--R             + 
+--R                              9 3
+--R               - 1308088512a b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                          10 3               7 3   2              4 6 2
+--R               6858181440a  d  - 14963304960a b c d  + 9352065600a b c d
+--R             + 
+--R                              9 3
+--R               - 1246942080a b c
+--R          *
+--R             n
+--R         + 
+--R                      10 3              7 3   2              4 6 2
+--R           2634508800a  d  - 5748019200a b c d  + 3592512000a b c d
+--R         + 
+--R                         9 3
+--R           - 479001600a b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               11 3     8 3   2     5 6 2     2 9 3  11
+--R           (- a  d  + 3a b c d  - 3a b c d + a b c )n
+--R         + 
+--R                 11 3       8 3   2       5 6 2       2 9 3  10
+--R           (- 77a  d  + 231a b c d  - 231a b c d + 77a b c )n
+--R         + 
+--R                   11 3        8 3   2        5 6 2         2 9 3  9
+--R           (- 2640a  d  + 7920a b c d  - 7920a b c d + 2640a b c )n
+--R         + 
+--R                    11 3          8 3   2          5 6 2          2 9 3  8
+--R           (- 53130a  d  + 159390a b c d  - 159390a b c d + 53130a b c )n
+--R         + 
+--R                     11 3           8 3   2           5 6 2           2 9 3  7
+--R           (- 696333a  d  + 2088999a b c d  - 2088999a b c d + 696333a b c )n
+--R         + 
+--R                           11 3            8 3   2            5 6 2
+--R                 - 6230301a  d  + 18690903a b c d  - 18690903a b c d
+--R               + 
+--R                         2 9 3
+--R                 6230301a b c
+--R          *
+--R              6
+--R             n
+--R         + 
+--R                          11 3             8 3   2             5 6 2
+--R               - 38759930a  d  + 116279790a b c d  - 116279790a b c d
+--R             + 
+--R                        2 9 3
+--R               38759930a b c
+--R          *
+--R              5
+--R             n
+--R         + 
+--R                           11 3             8 3   2             5 6 2
+--R               - 167310220a  d  + 501930660a b c d  - 501930660a b c d
+--R             + 
+--R                         2 9 3
+--R               167310220a b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                           11 3              8 3   2              5 6 2
+--R               - 489896616a  d  + 1469689848a b c d  - 1469689848a b c d
+--R             + 
+--R                         2 9 3
+--R               489896616a b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                           11 3              8 3   2              5 6 2
+--R               - 924118272a  d  + 2772354816a b c d  - 2772354816a b c d
+--R             + 
+--R                         2 9 3
+--R               924118272a b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                            11 3              8 3   2              5 6 2
+--R               - 1007441280a  d  + 3022323840a b c d  - 3022323840a b c d
+--R             + 
+--R                          2 9 3
+--R               1007441280a b c
+--R          *
+--R             n
+--R         + 
+--R                       11 3              8 3   2              5 6 2
+--R           - 479001600a  d  + 1437004800a b c d  - 1437004800a b c d
+--R         + 
+--R                     2 9 3
+--R           479001600a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        12 12      12 11        12 10         12 9          12 8           12 7
+--R       b  n   + 78b  n   + 2717b  n   + 55770b  n  + 749463b  n  + 6926634b  n
+--R     + 
+--R                12 6             12 5             12 4              12 3
+--R       44990231b  n  + 206070150b  n  + 657206836b  n  + 1414014888b  n
+--R     + 
+--R                  12 2              12              12
+--R       1931559552b  n  + 1486442880b  n + 479001600b
+--R                                                    Type: Expression(Integer)
+--E 875
+
+--S 876 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              12 3 11      12 3 10        12 3 9         12 3 8          12 3 7
+--R             b  d n   + 66b  d n   + 1925b  d n  + 32670b  d n  + 357423b  d n
+--R           + 
+--R                     12 3 6            12 3 5            12 3 4
+--R             2637558b  d n  + 13339535b  d n  + 45995730b  d n
+--R           + 
+--R                     12 3 3             12 3 2             12 3             12 3
+--R           105258076b  d n  + 150917976b  d n  + 120543840b  d n + 39916800b  d
+--R        *
+--R            12
+--R           x
+--R       + 
+--R                11 3 11        11 3 10          11 3 9           11 3 8
+--R             a b  d n   + 55a b  d n   + 1320a b  d n  + 18150a b  d n
+--R           + 
+--R                      11 3 7            11 3 6             11 3 5
+--R             157773a b  d n  + 902055a b  d n  + 3416930a b  d n
+--R           + 
+--R                       11 3 4              11 3 3              11 3 2
+--R             8409500a b  d n  + 12753576a b  d n  + 10628640a b  d n
+--R           + 
+--R                       11 3
+--R             3628800a b  d n
+--R        *
+--R            11
+--R           x
+--R       + 
+--R                  2 10 3 10       2 10 3 9        2 10 3 8          2 10 3 7
+--R             - 11a b  d n   - 495a b  d n  - 9570a b  d n  - 103950a b  d n
+--R           + 
+--R                      2 10 3 6           2 10 3 5           2 10 3 4
+--R             - 696003a b  d n  - 2962575a b  d n  - 7960480a b  d n
+--R           + 
+--R                        2 10 3 3            2 10 3 2           2 10 3
+--R             - 12899700a b  d n  - 11292336a b  d n  - 3991680a b  d n
+--R        *
+--R            10
+--R           x
+--R       + 
+--R               12   2 11       12   2 10        3 9 3        12   2  9
+--R             3b  c d n   + 207b  c d n   + (110a b d  + 6288b  c d )n
+--R           + 
+--R                   3 9 3          12   2  8          3 9 3           12   2  7
+--R             (3960a b d  + 110718b  c d )n  + (60060a b d  + 1251927b  c d )n
+--R           + 
+--R                     3 9 3           12   2  6
+--R             (498960a b d  + 9512559b  c d )n
+--R           + 
+--R                      3 9 3            12   2  5
+--R             (2469390a b d  + 49357662b  c d )n
+--R           + 
+--R                      3 9 3             12   2  4
+--R             (7401240a b d  + 173991492b  c d )n
+--R           + 
+--R                       3 9 3             12   2  3
+--R             (12993640a b d  + 405697080b  c d )n
+--R           + 
+--R                       3 9 3             12   2  2
+--R             (12054240a b d  + 590770944b  c d )n
+--R           + 
+--R                      3 9 3             12   2               12   2
+--R             (4435200a b d  + 477740160b  c d )n + 159667200b  c d
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                 11   2 11         11   2 10          11   2 9
+--R             3a b  c d n   + 183a b  c d n   + 4824a b  c d n
+--R           + 
+--R                    4 8 3           11   2  8
+--R             (- 990a b d  + 72126a b  c d )n
+--R           + 
+--R                      4 8 3            11   2  7
+--R             (- 27720a b d  + 674919a b  c d )n
+--R           + 
+--R                       4 8 3             11   2  6
+--R             (- 318780a b d  + 4113207a b  c d )n
+--R           + 
+--R                        4 8 3              11   2  5
+--R             (- 1940400a b d  + 16452006a b  c d )n
+--R           + 
+--R                        4 8 3              11   2  4
+--R             (- 6701310a b d  + 42375444a b  c d )n
+--R           + 
+--R                         4 8 3              11   2  3
+--R             (- 13000680a b d  + 66693528a b  c d )n
+--R           + 
+--R                         4 8 3              11   2  2
+--R             (- 12937320a b d  + 57222720a b  c d )n
+--R           + 
+--R                        4 8 3              11   2
+--R             (- 4989600a b d  + 19958400a b  c d )n
+--R        *
+--R            8
+--R           x
+--R       + 
+--R                  2 10   2 10        2 10   2 9         2 10   2 8
+--R             - 24a b  c d n   - 1296a b  c d n  - 29520a b  c d n
+--R           + 
+--R                   5 7 3          2 10   2  7
+--R             (7920a b d  - 370368a b  c d )n
+--R           + 
+--R                     5 7 3           2 10   2  6
+--R             (166320a b d  - 2806776a b  c d )n
+--R           + 
+--R                      5 7 3            2 10   2  5
+--R             (1386000a b d  - 13258224a b  c d )n
+--R           + 
+--R                      5 7 3            2 10   2  4
+--R             (5821200a b d  - 38808480a b  c d )n
+--R           + 
+--R                       5 7 3            2 10   2  3
+--R             (12862080a b d  - 67344192a b  c d )n
+--R           + 
+--R                       5 7 3            2 10   2  2
+--R             (13970880a b d  - 62138880a b  c d )n
+--R           + 
+--R                      5 7 3            2 10   2
+--R             (5702400a b d  - 22809600a b  c d )n
+--R        *
+--R            7
+--R           x
+--R       + 
+--R               12 2   11       12 2   10        3 9   2        12 2   9
+--R             3b  c d n   + 216b  c d n   + (168a b c d  + 6855b  c d)n
+--R           + 
+--R                   3 9   2          12 2   8
+--R             (8064a b c d  + 126180b  c d)n
+--R           + 
+--R                     3 9   2           12 2   7
+--R             (158256a b c d  + 1491309b  c d)n
+--R           + 
+--R                      6 6 3           3 9   2            12 2   6
+--R             (- 55440a b d  + 1643040a b c d  + 11832048b  c d)n
+--R           + 
+--R                       6 6 3           3 9   2            12 2   5
+--R             (- 831600a b d  + 9789192a b c d  + 63978405b  c d)n
+--R           + 
+--R                        6 6 3            3 9   2             12 2   4
+--R             (- 4712400a b d  + 34072416a b c d  + 234340020b  c d)n
+--R           + 
+--R                         6 6 3            3 9   2             12 2   3
+--R             (- 12474000a b d  + 67224864a b c d  + 565580388b  c d)n
+--R           + 
+--R                         6 6 3            3 9   2             12 2   2
+--R             (- 15190560a b d  + 68060160a b c d  + 848562336b  c d)n
+--R           + 
+--R                        6 6 3            3 9   2             12 2
+--R             (- 6652800a b d  + 26611200a b c d  + 703304640b  c d)n
+--R           + 
+--R                       12 2
+--R             239500800b  c d
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                 11 2   11         11 2   10          11 2   9
+--R             3a b  c d n   + 201a b  c d n   + 5850a b  c d n
+--R           + 
+--R                     4 8   2           11 2   8
+--R             (- 1008a b c d  + 96930a b  c d)n
+--R           + 
+--R                      4 8   2             11 2   7
+--R             (- 43344a b c d  + 1006659a b  c d)n
+--R           + 
+--R                       4 8   2             11 2   6
+--R             (- 732816a b c d  + 6798753a b  c d)n
+--R           + 
+--R                     7 5 3           4 8   2              11 2   5
+--R             (332640a b d  - 6194160a b c d  + 29984640a b  c d)n
+--R           + 
+--R                      7 5 3            4 8   2              11 2   4
+--R             (3326400a b d  - 27764352a b c d  + 84416820a b  c d)n
+--R           + 
+--R                       7 5 3            4 8   2               11 2   3
+--R             (11642400a b d  - 65612736a b c d  + 143496288a b  c d)n
+--R           + 
+--R                       7 5 3            4 8   2               11 2   2
+--R             (16632000a b d  - 75285504a b c d  + 131080896a b  c d)n
+--R           + 
+--R                      7 5 3            4 8   2              11 2
+--R             (7983360a b d  - 31933440a b c d  + 47900160a b  c d)n
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                  2 10 2   10       2 10 2   9         2 10 2   8
+--R             - 15a b  c d n   - 945a b  c d n  - 25470a b  c d n
+--R           + 
+--R                   5 7   2          2 10 2   7
+--R             (5040a b c d  - 382770a b  c d)n
+--R           + 
+--R                     5 7   2           2 10 2   6
+--R             (196560a b c d  - 3502215a b  c d)n
+--R           + 
+--R                      5 7   2            2 10 2   5
+--R             (2877840a b c d  - 19984905a b  c d)n
+--R           + 
+--R                        8 4 3            5 7   2            2 10 2   4
+--R             (- 1663200a b d  + 19459440a b c d  - 69983580a b  c d)n
+--R           + 
+--R                        8 4 3            5 7   2             2 10 2   3
+--R             (- 9979200a b d  + 60984000a b c d  - 142149780a b  c d)n
+--R           + 
+--R                         8 4 3            5 7   2             2 10 2   2
+--R             (- 18295200a b d  + 84127680a b c d  - 148882320a b  c d)n
+--R           + 
+--R                        8 4 3            5 7   2            2 10 2
+--R             (- 9979200a b d  + 39916800a b c d  - 59875200a b  c d)n
+--R        *
+--R            4
+--R           x
+--R       + 
+--R              12 3 11      12 3 10       3 9 2         12 3  9
+--R             b  c n   + 75b  c n   + (60a b c d + 2492b  c )n
+--R           + 
+--R                   3 9 2          12 3  8          3 9 2           12 3  7
+--R             (3600a b c d + 48294b  c )n  + (91080a b c d + 604581b  c )n
+--R           + 
+--R                      6 6   2           3 9 2            12 3  6
+--R             (- 20160a b c d  + 1257840a b c d + 5112891b  c )n
+--R           + 
+--R                       6 6   2            3 9 2             12 3  5
+--R             (- 725760a b c d  + 10235340a b c d + 29651558b  c )n
+--R           + 
+--R                        6 6   2            3 9 2              12 3  4
+--R             (- 9334080a b c d  + 49233600a b c d + 117115476b  c )n
+--R           + 
+--R                         9 3 3            6 6   2             3 9 2
+--R                 6652800a b d  - 49835520a b c d  + 132233520a b c d
+--R               + 
+--R                           12 3
+--R                 305860408b  c
+--R            *
+--R                3
+--R               n
+--R           + 
+--R                          9 3 3            6 6   2             3 9 2
+--R                 19958400a b d  - 94429440a b c d  + 171898560a b c d
+--R               + 
+--R                           12 3
+--R                 496433664b  c
+--R            *
+--R                2
+--R               n
+--R           + 
+--R                          9 3 3            6 6   2            3 9 2
+--R                 13305600a b d  - 53222400a b c d  + 79833600a b c d
+--R               + 
+--R                           12 3
+--R                 442258560b  c
+--R            *
+--R               n
+--R           + 
+--R                       12 3
+--R             159667200b  c
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                11 3 11        11 3 10          11 3 9
+--R             a b  c n   + 73a b  c n   + 2346a b  c n
+--R           + 
+--R                    4 8 2            11 3  8
+--R             (- 180a b c d + 43602a b  c )n
+--R           + 
+--R                      4 8 2             11 3  7
+--R             (- 10440a b c d + 517377a b  c )n
+--R           + 
+--R                       4 8 2              11 3  6
+--R             (- 252360a b c d + 4078137a b  c )n
+--R           + 
+--R                    7 5   2           4 8 2               11 3  5
+--R             (60480a b c d  - 3268800a b c d + 21495284a b  c )n
+--R           + 
+--R                      7 5   2            4 8 2               11 3  4
+--R             (2056320a b c d  - 24168420a b c d + 74124908a b  c )n
+--R           + 
+--R                       7 5   2            4 8 2                11 3  3
+--R             (23889600a b c d  - 99363960a b c d + 157610592a b  c )n
+--R           + 
+--R                            10 2 3             7 5   2             4 8 2
+--R                 - 19958400a  b d  + 101727360a b c d  - 197972640a b c d
+--R               + 
+--R                             11 3
+--R                 181212480a b  c
+--R            *
+--R                2
+--R               n
+--R           + 
+--R                            10 2 3            7 5   2             4 8 2
+--R                 - 19958400a  b d  + 79833600a b c d  - 119750400a b c d
+--R               + 
+--R                            11 3
+--R                 79833600a b  c
+--R            *
+--R               n
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                 2 10 3 10       2 10 3 9        2 10 3 8
+--R             - 2a b  c n   - 144a b  c n  - 4548a b  c n
+--R           + 
+--R                  5 7 2          2 10 3  7          5 7 2           2 10 3  6
+--R             (360a b c d - 82656a b  c )n  + (20520a b c d - 952098a b  c )n
+--R           + 
+--R                     5 7 2            2 10 3  5
+--R             (484200a b c d - 7204176a b  c )n
+--R           + 
+--R                       8 4   2           5 7 2             2 10 3  4
+--R             (- 120960a b c d  + 6053400a b c d - 35786392a b  c )n
+--R           + 
+--R                        8 4   2            5 7 2              2 10 3  3
+--R             (- 3991680a b c d  + 42283440a b c d - 112463424a b  c )n
+--R           + 
+--R                         8 4   2             5 7 2              2 10 3  2
+--R             (- 43787520a b c d  + 156444480a b c d - 202757760a b  c )n
+--R           + 
+--R                          11   3             8 4   2             5 7 2
+--R                 39916800a  b d  - 159667200a b c d  + 239500800a b c d
+--R               + 
+--R                             2 10 3
+--R                 - 159667200a b  c
+--R            *
+--R               n
+--R        *
+--R           x
+--R       + 
+--R           3 9 3 9       3 9 3 8        3 9 3 7          6 6 2          3 9 3  6
+--R         2a b c n  + 144a b c n  + 4548a b c n  + (- 360a b c d + 82656a b c )n
+--R       + 
+--R                  6 6 2           3 9 3  5             6 6 2            3 9 3  4
+--R         (- 20520a b c d + 952098a b c )n  + (- 484200a b c d + 7204176a b c )n
+--R       + 
+--R                 9 3   2           6 6 2             3 9 3  3
+--R         (120960a b c d  - 6053400a b c d + 35786392a b c )n
+--R       + 
+--R                  9 3   2            6 6 2              3 9 3  2
+--R         (3991680a b c d  - 42283440a b c d + 112463424a b c )n
+--R       + 
+--R                   9 3   2             6 6 2              3 9 3
+--R         (43787520a b c d  - 156444480a b c d + 202757760a b c )n
+--R       + 
+--R                  12 3             9 3   2             6 6 2              3 9 3
+--R       - 39916800a  d  + 159667200a b c d  - 239500800a b c d + 159667200a b c
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R        12 12      12 11        12 10         12 9          12 8           12 7
+--R       b  n   + 78b  n   + 2717b  n   + 55770b  n  + 749463b  n  + 6926634b  n
+--R     + 
+--R                12 6             12 5             12 4              12 3
+--R       44990231b  n  + 206070150b  n  + 657206836b  n  + 1414014888b  n
+--R     + 
+--R                  12 2              12              12
+--R       1931559552b  n  + 1486442880b  n + 479001600b
+--R                                         Type: Union(Expression(Integer),...)
+--E 876
+
+--S 877 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                12 3 11      12 3 10        12 3 9         12 3 8
+--R               b  d n   + 66b  d n   + 1925b  d n  + 32670b  d n
+--R             + 
+--R                      12 3 7           12 3 6            12 3 5
+--R               357423b  d n  + 2637558b  d n  + 13339535b  d n
+--R             + 
+--R                        12 3 4             12 3 3             12 3 2
+--R               45995730b  d n  + 105258076b  d n  + 150917976b  d n
+--R             + 
+--R                         12 3             12 3
+--R               120543840b  d n + 39916800b  d
+--R          *
+--R              12
+--R             x
+--R         + 
+--R                  11 3 11        11 3 10          11 3 9           11 3 8
+--R               a b  d n   + 55a b  d n   + 1320a b  d n  + 18150a b  d n
+--R             + 
+--R                        11 3 7            11 3 6             11 3 5
+--R               157773a b  d n  + 902055a b  d n  + 3416930a b  d n
+--R             + 
+--R                         11 3 4              11 3 3              11 3 2
+--R               8409500a b  d n  + 12753576a b  d n  + 10628640a b  d n
+--R             + 
+--R                         11 3
+--R               3628800a b  d n
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                    2 10 3 10       2 10 3 9        2 10 3 8          2 10 3 7
+--R               - 11a b  d n   - 495a b  d n  - 9570a b  d n  - 103950a b  d n
+--R             + 
+--R                        2 10 3 6           2 10 3 5           2 10 3 4
+--R               - 696003a b  d n  - 2962575a b  d n  - 7960480a b  d n
+--R             + 
+--R                          2 10 3 3            2 10 3 2           2 10 3
+--R               - 12899700a b  d n  - 11292336a b  d n  - 3991680a b  d n
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                 12   2 11       12   2 10        3 9 3        12   2  9
+--R               3b  c d n   + 207b  c d n   + (110a b d  + 6288b  c d )n
+--R             + 
+--R                     3 9 3          12   2  8          3 9 3           12   2  7
+--R               (3960a b d  + 110718b  c d )n  + (60060a b d  + 1251927b  c d )n
+--R             + 
+--R                       3 9 3           12   2  6
+--R               (498960a b d  + 9512559b  c d )n
+--R             + 
+--R                        3 9 3            12   2  5
+--R               (2469390a b d  + 49357662b  c d )n
+--R             + 
+--R                        3 9 3             12   2  4
+--R               (7401240a b d  + 173991492b  c d )n
+--R             + 
+--R                         3 9 3             12   2  3
+--R               (12993640a b d  + 405697080b  c d )n
+--R             + 
+--R                         3 9 3             12   2  2
+--R               (12054240a b d  + 590770944b  c d )n
+--R             + 
+--R                        3 9 3             12   2               12   2
+--R               (4435200a b d  + 477740160b  c d )n + 159667200b  c d
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                   11   2 11         11   2 10          11   2 9
+--R               3a b  c d n   + 183a b  c d n   + 4824a b  c d n
+--R             + 
+--R                      4 8 3           11   2  8
+--R               (- 990a b d  + 72126a b  c d )n
+--R             + 
+--R                        4 8 3            11   2  7
+--R               (- 27720a b d  + 674919a b  c d )n
+--R             + 
+--R                         4 8 3             11   2  6
+--R               (- 318780a b d  + 4113207a b  c d )n
+--R             + 
+--R                          4 8 3              11   2  5
+--R               (- 1940400a b d  + 16452006a b  c d )n
+--R             + 
+--R                          4 8 3              11   2  4
+--R               (- 6701310a b d  + 42375444a b  c d )n
+--R             + 
+--R                           4 8 3              11   2  3
+--R               (- 13000680a b d  + 66693528a b  c d )n
+--R             + 
+--R                           4 8 3              11   2  2
+--R               (- 12937320a b d  + 57222720a b  c d )n
+--R             + 
+--R                          4 8 3              11   2
+--R               (- 4989600a b d  + 19958400a b  c d )n
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    2 10   2 10        2 10   2 9         2 10   2 8
+--R               - 24a b  c d n   - 1296a b  c d n  - 29520a b  c d n
+--R             + 
+--R                     5 7 3          2 10   2  7
+--R               (7920a b d  - 370368a b  c d )n
+--R             + 
+--R                       5 7 3           2 10   2  6
+--R               (166320a b d  - 2806776a b  c d )n
+--R             + 
+--R                        5 7 3            2 10   2  5
+--R               (1386000a b d  - 13258224a b  c d )n
+--R             + 
+--R                        5 7 3            2 10   2  4
+--R               (5821200a b d  - 38808480a b  c d )n
+--R             + 
+--R                         5 7 3            2 10   2  3
+--R               (12862080a b d  - 67344192a b  c d )n
+--R             + 
+--R                         5 7 3            2 10   2  2
+--R               (13970880a b d  - 62138880a b  c d )n
+--R             + 
+--R                        5 7 3            2 10   2
+--R               (5702400a b d  - 22809600a b  c d )n
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                 12 2   11       12 2   10        3 9   2        12 2   9
+--R               3b  c d n   + 216b  c d n   + (168a b c d  + 6855b  c d)n
+--R             + 
+--R                     3 9   2          12 2   8
+--R               (8064a b c d  + 126180b  c d)n
+--R             + 
+--R                       3 9   2           12 2   7
+--R               (158256a b c d  + 1491309b  c d)n
+--R             + 
+--R                        6 6 3           3 9   2            12 2   6
+--R               (- 55440a b d  + 1643040a b c d  + 11832048b  c d)n
+--R             + 
+--R                         6 6 3           3 9   2            12 2   5
+--R               (- 831600a b d  + 9789192a b c d  + 63978405b  c d)n
+--R             + 
+--R                          6 6 3            3 9   2             12 2   4
+--R               (- 4712400a b d  + 34072416a b c d  + 234340020b  c d)n
+--R             + 
+--R                           6 6 3            3 9   2             12 2   3
+--R               (- 12474000a b d  + 67224864a b c d  + 565580388b  c d)n
+--R             + 
+--R                           6 6 3            3 9   2             12 2   2
+--R               (- 15190560a b d  + 68060160a b c d  + 848562336b  c d)n
+--R             + 
+--R                          6 6 3            3 9   2             12 2
+--R               (- 6652800a b d  + 26611200a b c d  + 703304640b  c d)n
+--R             + 
+--R                         12 2
+--R               239500800b  c d
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                   11 2   11         11 2   10          11 2   9
+--R               3a b  c d n   + 201a b  c d n   + 5850a b  c d n
+--R             + 
+--R                       4 8   2           11 2   8
+--R               (- 1008a b c d  + 96930a b  c d)n
+--R             + 
+--R                        4 8   2             11 2   7
+--R               (- 43344a b c d  + 1006659a b  c d)n
+--R             + 
+--R                         4 8   2             11 2   6
+--R               (- 732816a b c d  + 6798753a b  c d)n
+--R             + 
+--R                       7 5 3           4 8   2              11 2   5
+--R               (332640a b d  - 6194160a b c d  + 29984640a b  c d)n
+--R             + 
+--R                        7 5 3            4 8   2              11 2   4
+--R               (3326400a b d  - 27764352a b c d  + 84416820a b  c d)n
+--R             + 
+--R                         7 5 3            4 8   2               11 2   3
+--R               (11642400a b d  - 65612736a b c d  + 143496288a b  c d)n
+--R             + 
+--R                         7 5 3            4 8   2               11 2   2
+--R               (16632000a b d  - 75285504a b c d  + 131080896a b  c d)n
+--R             + 
+--R                        7 5 3            4 8   2              11 2
+--R               (7983360a b d  - 31933440a b c d  + 47900160a b  c d)n
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    2 10 2   10       2 10 2   9         2 10 2   8
+--R               - 15a b  c d n   - 945a b  c d n  - 25470a b  c d n
+--R             + 
+--R                     5 7   2          2 10 2   7
+--R               (5040a b c d  - 382770a b  c d)n
+--R             + 
+--R                       5 7   2           2 10 2   6
+--R               (196560a b c d  - 3502215a b  c d)n
+--R             + 
+--R                        5 7   2            2 10 2   5
+--R               (2877840a b c d  - 19984905a b  c d)n
+--R             + 
+--R                          8 4 3            5 7   2            2 10 2   4
+--R               (- 1663200a b d  + 19459440a b c d  - 69983580a b  c d)n
+--R             + 
+--R                          8 4 3            5 7   2             2 10 2   3
+--R               (- 9979200a b d  + 60984000a b c d  - 142149780a b  c d)n
+--R             + 
+--R                           8 4 3            5 7   2             2 10 2   2
+--R               (- 18295200a b d  + 84127680a b c d  - 148882320a b  c d)n
+--R             + 
+--R                          8 4 3            5 7   2            2 10 2
+--R               (- 9979200a b d  + 39916800a b c d  - 59875200a b  c d)n
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                12 3 11      12 3 10       3 9 2         12 3  9
+--R               b  c n   + 75b  c n   + (60a b c d + 2492b  c )n
+--R             + 
+--R                     3 9 2          12 3  8          3 9 2           12 3  7
+--R               (3600a b c d + 48294b  c )n  + (91080a b c d + 604581b  c )n
+--R             + 
+--R                        6 6   2           3 9 2            12 3  6
+--R               (- 20160a b c d  + 1257840a b c d + 5112891b  c )n
+--R             + 
+--R                         6 6   2            3 9 2             12 3  5
+--R               (- 725760a b c d  + 10235340a b c d + 29651558b  c )n
+--R             + 
+--R                          6 6   2            3 9 2              12 3  4
+--R               (- 9334080a b c d  + 49233600a b c d + 117115476b  c )n
+--R             + 
+--R                           9 3 3            6 6   2             3 9 2
+--R                   6652800a b d  - 49835520a b c d  + 132233520a b c d
+--R                 + 
+--R                             12 3
+--R                   305860408b  c
+--R              *
+--R                  3
+--R                 n
+--R             + 
+--R                            9 3 3            6 6   2             3 9 2
+--R                   19958400a b d  - 94429440a b c d  + 171898560a b c d
+--R                 + 
+--R                             12 3
+--R                   496433664b  c
+--R              *
+--R                  2
+--R                 n
+--R             + 
+--R                            9 3 3            6 6   2            3 9 2
+--R                   13305600a b d  - 53222400a b c d  + 79833600a b c d
+--R                 + 
+--R                             12 3
+--R                   442258560b  c
+--R              *
+--R                 n
+--R             + 
+--R                         12 3
+--R               159667200b  c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                  11 3 11        11 3 10          11 3 9
+--R               a b  c n   + 73a b  c n   + 2346a b  c n
+--R             + 
+--R                      4 8 2            11 3  8
+--R               (- 180a b c d + 43602a b  c )n
+--R             + 
+--R                        4 8 2             11 3  7
+--R               (- 10440a b c d + 517377a b  c )n
+--R             + 
+--R                         4 8 2              11 3  6
+--R               (- 252360a b c d + 4078137a b  c )n
+--R             + 
+--R                      7 5   2           4 8 2               11 3  5
+--R               (60480a b c d  - 3268800a b c d + 21495284a b  c )n
+--R             + 
+--R                        7 5   2            4 8 2               11 3  4
+--R               (2056320a b c d  - 24168420a b c d + 74124908a b  c )n
+--R             + 
+--R                         7 5   2            4 8 2                11 3  3
+--R               (23889600a b c d  - 99363960a b c d + 157610592a b  c )n
+--R             + 
+--R                              10 2 3             7 5   2             4 8 2
+--R                   - 19958400a  b d  + 101727360a b c d  - 197972640a b c d
+--R                 + 
+--R                               11 3
+--R                   181212480a b  c
+--R              *
+--R                  2
+--R                 n
+--R             + 
+--R                              10 2 3            7 5   2             4 8 2
+--R                   - 19958400a  b d  + 79833600a b c d  - 119750400a b c d
+--R                 + 
+--R                              11 3
+--R                   79833600a b  c
+--R              *
+--R                 n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   2 10 3 10       2 10 3 9        2 10 3 8
+--R               - 2a b  c n   - 144a b  c n  - 4548a b  c n
+--R             + 
+--R                    5 7 2          2 10 3  7          5 7 2           2 10 3  6
+--R               (360a b c d - 82656a b  c )n  + (20520a b c d - 952098a b  c )n
+--R             + 
+--R                       5 7 2            2 10 3  5
+--R               (484200a b c d - 7204176a b  c )n
+--R             + 
+--R                         8 4   2           5 7 2             2 10 3  4
+--R               (- 120960a b c d  + 6053400a b c d - 35786392a b  c )n
+--R             + 
+--R                          8 4   2            5 7 2              2 10 3  3
+--R               (- 3991680a b c d  + 42283440a b c d - 112463424a b  c )n
+--R             + 
+--R                           8 4   2             5 7 2              2 10 3  2
+--R               (- 43787520a b c d  + 156444480a b c d - 202757760a b  c )n
+--R             + 
+--R                            11   3             8 4   2             5 7 2
+--R                   39916800a  b d  - 159667200a b c d  + 239500800a b c d
+--R                 + 
+--R                               2 10 3
+--R                   - 159667200a b  c
+--R              *
+--R                 n
+--R          *
+--R             x
+--R         + 
+--R             3 9 3 9       3 9 3 8        3 9 3 7
+--R           2a b c n  + 144a b c n  + 4548a b c n
+--R         + 
+--R                  6 6 2          3 9 3  6            6 6 2           3 9 3  5
+--R           (- 360a b c d + 82656a b c )n  + (- 20520a b c d + 952098a b c )n
+--R         + 
+--R                     6 6 2            3 9 3  4
+--R           (- 484200a b c d + 7204176a b c )n
+--R         + 
+--R                   9 3   2           6 6 2             3 9 3  3
+--R           (120960a b c d  - 6053400a b c d + 35786392a b c )n
+--R         + 
+--R                    9 3   2            6 6 2              3 9 3  2
+--R           (3991680a b c d  - 42283440a b c d + 112463424a b c )n
+--R         + 
+--R                     9 3   2             6 6 2              3 9 3
+--R           (43787520a b c d  - 156444480a b c d + 202757760a b c )n
+--R         + 
+--R                      12 3             9 3   2             6 6 2
+--R           - 39916800a  d  + 159667200a b c d  - 239500800a b c d
+--R         + 
+--R                     3 9 3
+--R           159667200a b c
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R              3 11      3 10        3 9         3 8          3 7           3 6
+--R           - d n   - 66d n   - 1925d n  - 32670d n  - 357423d n  - 2637558d n
+--R         + 
+--R                      3 5            3 4             3 3             3 2
+--R           - 13339535d n  - 45995730d n  - 105258076d n  - 150917976d n
+--R         + 
+--R                       3             3
+--R           - 120543840d n - 39916800d
+--R      *
+--R                  n + 12
+--R         (b x + a)
+--R     + 
+--R                3 11         3 10           3 9            3 8             3 7
+--R           11a d n   + 737a d n   + 21780a d n  + 373890a d n  + 4131303a d n
+--R         + 
+--R                      3 6               3 5               3 4                3 3
+--R           30748641a d n  + 156657490a d n  + 543539260a d n  + 1250343336a d n
+--R         + 
+--R                        3 2                3                3
+--R           1800387072a d n  + 1442897280a d n + 479001600a d
+--R      *
+--R                  n + 11
+--R         (b x + a)
+--R     + 
+--R                2 3 11        2 3 10          2 3 9           2 3 8
+--R           - 55a d n   - 3740a d n   - 112035a d n  - 1947000a d n
+--R         + 
+--R                      2 3 7             2 3 6             2 3 5
+--R           - 21750465a d n  - 163460220a d n  - 839860505a d n
+--R         + 
+--R                        2 3 4              2 3 3              2 3 2
+--R           - 2935253200a d n  - 6793843980a d n  - 9832379040a d n
+--R         + 
+--R                        2 3               2 3
+--R           - 7911984960a d n - 2634508800a d
+--R      *
+--R                  n + 10
+--R         (b x + a)
+--R     + 
+--R                3 3     3   2  11          3 3       3   2  10
+--R           (165a d  - 3b c d )n   + (11385a d  - 207b c d )n
+--R         + 
+--R                   3 3        3   2  9            3 3          3   2  8
+--R           (345840a d  - 6288b c d )n  + (6089490a d  - 110718b c d )n
+--R         + 
+--R                     3 3           3   2  7              3 3           3   2  6
+--R           (68855985a d  - 1251927b c d )n  + (523190745a d  - 9512559b c d )n
+--R         + 
+--R                       3 3            3   2  5
+--R           (2714671410a d  - 49357662b c d )n
+--R         + 
+--R                       3 3             3   2  4
+--R           (9569532060a d  - 173991492b c d )n
+--R         + 
+--R                        3 3             3   2  3
+--R           (22313339400a d  - 405697080b c d )n
+--R         + 
+--R                        3 3             3   2  2
+--R           (32492401920a d  - 590770944b c d )n
+--R         + 
+--R                      3 3             3   2                3 3             3   2
+--R         (26275708800a d  - 477740160b c d )n + 8781696000a d  - 159667200b c d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R                  4 3        3   2  11            4 3          3   2  10
+--R           (- 330a d  + 24a b c d )n   + (- 23100a d  + 1680a b c d )n
+--R         + 
+--R                     4 3           3   2  9
+--R           (- 711810a d  + 51768a b c d )n
+--R         + 
+--R                       4 3            3   2  8
+--R           (- 12709620a d  + 924336a b c d )n
+--R         + 
+--R                        4 3              3   2  7
+--R           (- 145645830a d  + 10592424a b c d )n
+--R         + 
+--R                         4 3              3   2  6
+--R           (- 1120622580a d  + 81499824a b c d )n
+--R         + 
+--R                         4 3               3   2  5
+--R           (- 5881795590a d  + 427766952a b c d )n
+--R         + 
+--R                          4 3                3   2  4
+--R           (- 20948784780a d  + 1523547984a b c d )n
+--R         + 
+--R                          4 3                3   2  3
+--R           (- 49287977640a d  + 3584580192a b c d )n
+--R         + 
+--R                          4 3                3   2  2
+--R           (- 72321091920a d  + 5259715776a b c d )n
+--R         + 
+--R                          4 3                3   2                 4 3
+--R           (- 58845916800a d  + 4279703040a b c d )n - 19758816000a d
+--R         + 
+--R                        3   2
+--R           1437004800a b c d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                5 3      2 3   2  11          5 3        2 3   2  10
+--R           (462a d  - 84a b c d )n   + (32802a d  - 5964a b c d )n
+--R         + 
+--R                    5 3          2 3   2  9             5 3           2 3   2  8
+--R           (1025640a d  - 186480a b c d )n  + (18586260a d  - 3379320a b c d )n
+--R         + 
+--R                      5 3            2 3   2  7
+--R           (216148086a d  - 39299652a b c d )n
+--R         + 
+--R                       5 3             2 3   2  6
+--R           (1687068306a d  - 306739692a b c d )n
+--R         + 
+--R                       5 3              2 3   2  5
+--R           (8976008580a d  - 1632001560a b c d )n
+--R         + 
+--R                        5 3              2 3   2  4
+--R           (32372349240a d  - 5885881680a b c d )n
+--R         + 
+--R                        5 3               2 3   2  3
+--R           (77023113552a d  - 14004202464a b c d )n
+--R         + 
+--R                         5 3               2 3   2  2
+--R           (114113083392a d  - 20747833344a b c d )n
+--R         + 
+--R                        5 3               2 3   2                 5 3
+--R           (93588929280a d  - 17016168960a b c d )n + 31614105600a d
+--R         + 
+--R                        2 3   2
+--R           - 5748019200a b c d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                  6 3       3 3   2     6 2   11
+--R           (- 462a d  + 168a b c d  - 3b c d)n
+--R         + 
+--R                    6 3         3 3   2       6 2   10
+--R           (- 33264a d  + 12096a b c d  - 216b c d)n
+--R         + 
+--R                      6 3          3 3   2        6 2   9
+--R           (- 1055670a d  + 383880a b c d  - 6855b c d)n
+--R         + 
+--R                       6 3           3 3   2          6 2   8
+--R           (- 19431720a d  + 7066080a b c d  - 126180b c d)n
+--R         + 
+--R                        6 3            3 3   2           6 2   7
+--R           (- 229661586a d  + 83513304a b c d  - 1491309b c d)n
+--R         + 
+--R                         6 3             3 3   2            6 2   6
+--R           (- 1822135392a d  + 662594688a b c d  - 11832048b c d)n
+--R         + 
+--R                         6 3              3 3   2            6 2   5
+--R           (- 9852674370a d  + 3582790680a b c d  - 63978405b c d)n
+--R         + 
+--R                          6 3               3 3   2             6 2   4
+--R           (- 36088363080a d  + 13123041120a b c d  - 234340020b c d)n
+--R         + 
+--R                          6 3               3 3   2             6 2   3
+--R           (- 87099379752a d  + 31672501728a b c d  - 565580388b c d)n
+--R         + 
+--R                           6 3               3 3   2             6 2   2
+--R           (- 130678599744a d  + 47519490816a b c d  - 848562336b c d)n
+--R         + 
+--R                           6 3               3 3   2             6 2
+--R           (- 108308914560a d  + 39385059840a b c d  - 703304640b c d)n
+--R         + 
+--R                         6 3               3 3   2             6 2
+--R           - 36883123200a d  + 13412044800a b c d  - 239500800b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                7 3       4 3   2        6 2   11
+--R           (330a d  - 210a b c d  + 15a b c d)n
+--R         + 
+--R                  7 3         4 3   2          6 2   10
+--R           (24090a d  - 15330a b c d  + 1095a b c d)n
+--R         + 
+--R                   7 3          4 3   2           6 2   9
+--R           (776160a d  - 493920a b c d  + 35280a b c d)n
+--R         + 
+--R                     7 3           4 3   2            6 2   8
+--R           (14523300a d  - 9242100a b c d  + 660150a b c d)n
+--R         + 
+--R                      7 3             4 3   2             6 2   7
+--R           (174706290a d  - 111176730a b c d  + 7941195a b c d)n
+--R         + 
+--R                       7 3             4 3   2              6 2   6
+--R           (1412257770a d  - 898709490a b c d  + 64193535a b c d)n
+--R         + 
+--R                       7 3              4 3   2               6 2   5
+--R           (7785487380a d  - 4954401060a b c d  + 353885790a b c d)n
+--R         + 
+--R                        7 3               4 3   2                6 2   4
+--R           (29075712600a d  - 18502726200a b c d  + 1321623300a b c d)n
+--R         + 
+--R                        7 3               4 3   2                6 2   3
+--R           (71499692880a d  - 45499804560a b c d  + 3249986040a b c d)n
+--R         + 
+--R                         7 3               4 3   2                6 2   2
+--R           (109126448640a d  - 69444103680a b c d  + 4960293120a b c d)n
+--R         + 
+--R                        7 3               4 3   2                6 2
+--R           (91782408960a d  - 58406987520a b c d  + 4171927680a b c d)n
+--R         + 
+--R                       7 3               4 3   2                6 2
+--R           31614105600a d  - 20118067200a b c d  + 1437004800a b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                  8 3       5 3   2      2 6 2   11
+--R           (- 165a d  + 168a b c d  - 30a b c d)n
+--R         + 
+--R                    8 3         5 3   2        2 6 2   10
+--R           (- 12210a d  + 12432a b c d  - 2220a b c d)n
+--R         + 
+--R                     8 3          5 3   2         2 6 2   9
+--R           (- 399465a d  + 406728a b c d  - 72630a b c d)n
+--R         + 
+--R                      8 3           5 3   2           2 6 2   8
+--R           (- 7604190a d  + 7742448a b c d  - 1382580a b c d)n
+--R         + 
+--R                       8 3            5 3   2            2 6 2   7
+--R           (- 93244635a d  + 94939992a b c d  - 16953570a b c d)n
+--R         + 
+--R                        8 3             5 3   2             2 6 2   6
+--R           (- 769916070a d  + 783914544a b c d  - 139984740a b c d)n
+--R         + 
+--R                         8 3              5 3   2             2 6 2   5
+--R           (- 4343723835a d  + 4422700632a b c d  - 789767970a b c d)n
+--R         + 
+--R                          8 3               5 3   2              2 6 2   4
+--R           (- 16626679410a d  + 16928982672a b c d  - 3023032620a b c d)n
+--R         + 
+--R                          8 3               5 3   2              2 6 2   3
+--R           (- 41932410300a d  + 42694817760a b c d  - 7624074600a b c d)n
+--R         + 
+--R                          8 3               5 3   2               2 6 2   2
+--R           (- 65582815320a d  + 66775230144a b c d  - 11924148240a b c d)n
+--R         + 
+--R                          8 3               5 3   2               2 6 2
+--R           (- 56376064800a d  + 57401084160a b c d  - 10250193600a b c d)n
+--R         + 
+--R                         8 3               5 3   2              2 6 2
+--R           - 19758816000a d  + 20118067200a b c d  - 3592512000a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R               9 3      6 3   2      3 6 2     9 3  11
+--R           (55a d  - 84a b c d  + 30a b c d - b c )n
+--R         + 
+--R                 9 3        6 3   2        3 6 2       9 3  10
+--R           (4125a d  - 6300a b c d  + 2250a b c d - 75b c )n
+--R         + 
+--R                   9 3          6 3   2         3 6 2         9 3  9
+--R           (137060a d  - 209328a b c d  + 74760a b c d - 2492b c )n
+--R         + 
+--R                    9 3           6 3   2           3 6 2          9 3  8
+--R           (2656170a d  - 4056696a b c d  + 1448820a b c d - 48294b c )n
+--R         + 
+--R                     9 3            6 3   2            3 6 2           9 3  7
+--R           (33251955a d  - 50784804a b c d  + 18137430a b c d - 604581b c )n
+--R         + 
+--R                           9 3             6 3   2             3 6 2
+--R                 281209005a d  - 429482844a b c d  + 153386730a b c d
+--R               + 
+--R                           9 3
+--R                 - 5112891b c
+--R          *
+--R              6
+--R             n
+--R         + 
+--R                          9 3              6 3   2             3 6 2
+--R               1630835690a d  - 2490730872a b c d  + 889546740a b c d
+--R             + 
+--R                          9 3
+--R               - 29651558b c
+--R          *
+--R              5
+--R             n
+--R         + 
+--R                          9 3              6 3   2              3 6 2
+--R               6441351180a d  - 9837699984a b c d  + 3513464280a b c d
+--R             + 
+--R                           9 3
+--R               - 117115476b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                           9 3               6 3   2              3 6 2
+--R               16822322440a d  - 25692274272a b c d  + 9175812240a b c d
+--R             + 
+--R                           9 3
+--R               - 305860408b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                           9 3               6 3   2               3 6 2
+--R               27303851520a d  - 41700427776a b c d  + 14893009920a b c d
+--R             + 
+--R                           9 3
+--R               - 496433664b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                           9 3               6 3   2               3 6 2
+--R               24324220800a d  - 37149719040a b c d  + 13267756800a b c d
+--R             + 
+--R                           9 3
+--R               - 442258560b c
+--R          *
+--R             n
+--R         + 
+--R                      9 3               6 3   2              3 6 2
+--R           8781696000a d  - 13412044800a b c d  + 4790016000a b c d
+--R         + 
+--R                       9 3
+--R           - 159667200b c
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R                 10 3      7 3   2      4 6 2        9 3  11
+--R           (- 11a  d  + 24a b c d  - 15a b c d + 2a b c )n
+--R         + 
+--R                  10 3        7 3   2        4 6 2          9 3  10
+--R           (- 836a  d  + 1824a b c d  - 1140a b c d + 152a b c )n
+--R         + 
+--R                    10 3         7 3   2         4 6 2           9 3  9
+--R           (- 28215a  d  + 61560a b c d  - 38475a b c d + 5130a b c )n
+--R         + 
+--R                     10 3           7 3   2          4 6 2             9 3  8
+--R           (- 557040a  d  + 1215360a b c d  - 759600a b c d + 101280a b c )n
+--R         + 
+--R                           10 3            7 3   2           4 6 2
+--R                 - 7130013a  d  + 15556392a b c d  - 9722745a b c d
+--R               + 
+--R                           9 3
+--R                 1296366a b c
+--R          *
+--R              7
+--R             n
+--R         + 
+--R                          10 3             7 3   2            4 6 2
+--R               - 61932948a  d  + 135126432a b c d  - 84454020a b c d
+--R             + 
+--R                          9 3
+--R               11260536a b c
+--R          *
+--R              6
+--R             n
+--R         + 
+--R                           10 3             7 3   2             4 6 2
+--R               - 371026645a  d  + 809512680a b c d  - 505945425a b c d
+--R             + 
+--R                          9 3
+--R               67459390a b c
+--R          *
+--R              5
+--R             n
+--R         + 
+--R                            10 3              7 3   2              4 6 2
+--R               - 1524718360a  d  + 3326658240a b c d  - 2079161400a b c d
+--R             + 
+--R                           9 3
+--R               277221520a b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                            10 3              7 3   2              4 6 2
+--R               - 4179838476a  d  + 9119647584a b c d  - 5699779740a b c d
+--R             + 
+--R                           9 3
+--R               759970632a b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                            10 3               7 3   2              4 6 2
+--R               - 7194486816a  d  + 15697062144a b c d  - 9810663840a b c d
+--R             + 
+--R                            9 3
+--R               1308088512a b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                            10 3               7 3   2              4 6 2
+--R               - 6858181440a  d  + 14963304960a b c d  - 9352065600a b c d
+--R             + 
+--R                            9 3
+--R               1246942080a b c
+--R          *
+--R             n
+--R         + 
+--R                        10 3              7 3   2              4 6 2
+--R           - 2634508800a  d  + 5748019200a b c d  - 3592512000a b c d
+--R         + 
+--R                       9 3
+--R           479001600a b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             11 3     8 3   2     5 6 2     2 9 3  11
+--R           (a  d  - 3a b c d  + 3a b c d - a b c )n
+--R         + 
+--R               11 3       8 3   2       5 6 2       2 9 3  10
+--R           (77a  d  - 231a b c d  + 231a b c d - 77a b c )n
+--R         + 
+--R                 11 3        8 3   2        5 6 2         2 9 3  9
+--R           (2640a  d  - 7920a b c d  + 7920a b c d - 2640a b c )n
+--R         + 
+--R                  11 3          8 3   2          5 6 2          2 9 3  8
+--R           (53130a  d  - 159390a b c d  + 159390a b c d - 53130a b c )n
+--R         + 
+--R                   11 3           8 3   2           5 6 2           2 9 3  7
+--R           (696333a  d  - 2088999a b c d  + 2088999a b c d - 696333a b c )n
+--R         + 
+--R                    11 3            8 3   2            5 6 2            2 9 3  6
+--R           (6230301a  d  - 18690903a b c d  + 18690903a b c d - 6230301a b c )n
+--R         + 
+--R                        11 3             8 3   2             5 6 2
+--R               38759930a  d  - 116279790a b c d  + 116279790a b c d
+--R             + 
+--R                          2 9 3
+--R               - 38759930a b c
+--R          *
+--R              5
+--R             n
+--R         + 
+--R                         11 3             8 3   2             5 6 2
+--R               167310220a  d  - 501930660a b c d  + 501930660a b c d
+--R             + 
+--R                           2 9 3
+--R               - 167310220a b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                         11 3              8 3   2              5 6 2
+--R               489896616a  d  - 1469689848a b c d  + 1469689848a b c d
+--R             + 
+--R                           2 9 3
+--R               - 489896616a b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                         11 3              8 3   2              5 6 2
+--R               924118272a  d  - 2772354816a b c d  + 2772354816a b c d
+--R             + 
+--R                           2 9 3
+--R               - 924118272a b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                          11 3              8 3   2              5 6 2
+--R               1007441280a  d  - 3022323840a b c d  + 3022323840a b c d
+--R             + 
+--R                            2 9 3
+--R               - 1007441280a b c
+--R          *
+--R             n
+--R         + 
+--R                     11 3              8 3   2              5 6 2
+--R           479001600a  d  - 1437004800a b c d  + 1437004800a b c d
+--R         + 
+--R                       2 9 3
+--R           - 479001600a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        12 12      12 11        12 10         12 9          12 8           12 7
+--R       b  n   + 78b  n   + 2717b  n   + 55770b  n  + 749463b  n  + 6926634b  n
+--R     + 
+--R                12 6             12 5             12 4              12 3
+--R       44990231b  n  + 206070150b  n  + 657206836b  n  + 1414014888b  n
+--R     + 
+--R                  12 2              12              12
+--R       1931559552b  n  + 1486442880b  n + 479001600b
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--S 878 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         11 3 11     11   2 8     11 2   5    11 3 2   n log(b x + a)
+--R       (b  d x   + 3b  c d x  + 3b  c d x  + b  c x )%e
+--R     + 
+--R          3         n + 11        3         n + 10      2 3         n + 9
+--R       - d (b x + a)       + 11a d (b x + a)       - 55a d (b x + a)
+--R     + 
+--R            3 3     3   2          n + 8
+--R       (165a d  - 3b c d )(b x + a)
+--R     + 
+--R              4 3        3   2          n + 7
+--R       (- 330a d  + 24a b c d )(b x + a)
+--R     + 
+--R            5 3      2 3   2          n + 6
+--R       (462a d  - 84a b c d )(b x + a)
+--R     + 
+--R              6 3       3 3   2     6 2           n + 5
+--R       (- 462a d  + 168a b c d  - 3b c d)(b x + a)
+--R     + 
+--R            7 3       4 3   2        6 2           n + 4
+--R       (330a d  - 210a b c d  + 15a b c d)(b x + a)
+--R     + 
+--R              8 3       5 3   2      2 6 2           n + 3
+--R       (- 165a d  + 168a b c d  - 30a b c d)(b x + a)
+--R     + 
+--R           9 3      6 3   2      3 6 2     9 3          n + 2
+--R       (55a d  - 84a b c d  + 30a b c d - b c )(b x + a)
+--R     + 
+--R             10 3      7 3   2      4 6 2        9 3          n + 1
+--R       (- 11a  d  + 24a b c d  - 15a b c d + 2a b c )(b x + a)
+--R     + 
+--R         11 3     8 3   2     5 6 2     2 9 3          n
+--R       (a  d  - 3a b c d  + 3a b c d - a b c )(b x + a)
+--R  /
+--R      11
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 878
+
+)clear all
+
+--S 879 of 953
+t0:=x*(a+b*x)^n*(c+d*x^3)^3
+--R 
+--R
+--R          3 10       2 7     2   4    3           n
+--R   (1)  (d x   + 3c d x  + 3c d x  + c x)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 879
+
+--S 880 of 953
+r0:=-a*(b^3*c-a^3*d)^3*(a+b*x)^(1+n)/(b^11*(1+n))+(b^3*c-10*a^3*d)*_
+   (b^3*c-a^3*d)^2*(a+b*x)^(2+n)/(b^11*(2+n))+9*a^2*d*(2*b^3*c-5*a^3*d)*_
+   (b^3*c-a^3*d)*(a+b*x)^(3+n)/(b^11*(3+n))-3*a*d*(4*b^6*c^2-35*a^3*b^3*_
+   c*d+40*a^6*d^2)*(a+b*x)^(4+n)/(b^11*(4+n))+3*d*(b^6*c^2-35*a^3*b^3*_
+   c*d+70*a^6*d^2)*(a+b*x)^(5+n)/(b^11*(5+n))+63*a^2*d^2*(b^3*c-4*a^3*d)*_
+   (a+b*x)^(6+n)/(b^11*(6+n))-21*a*d^2*(b^3*c-10*a^3*d)*(a+b*x)^(7+n)/_
+   (b^11*(7+n))+3*d^2*(b^3*c-40*a^3*d)*(a+b*x)^(8+n)/(b^11*(8+n))+45*a^2*_
+   d^3*(a+b*x)^(9+n)/(b^11*(9+n))-10*a*d^3*(a+b*x)^(10+n)/(b^11*(10+n))+_
+   d^3*(a+b*x)^(11+n)/(b^11*(11+n))
+--R 
+--R
+--R   (2)
+--R            3 10      3 9        3 8         3 7          3 6          3 5
+--R           d n   + 55d n  + 1320d n  + 18150d n  + 157773d n  + 902055d n
+--R         + 
+--R                   3 4           3 3            3 2            3            3
+--R           3416930d n  + 8409500d n  + 12753576d n  + 10628640d n + 3628800d
+--R      *
+--R                  n + 11
+--R         (b x + a)
+--R     + 
+--R                  3 10         3 9           3 8            3 7             3 6
+--R           - 10a d n   - 560a d n  - 13650a d n  - 190200a d n  - 1672230a d n
+--R         + 
+--R                       3 5              3 4              3 3               3 2
+--R           - 9653280a d n  - 36862550a d n  - 91331800a d n  - 139262760a d n
+--R         + 
+--R                         3               3
+--R           - 116552160a d n - 39916800a d
+--R      *
+--R                  n + 10
+--R         (b x + a)
+--R     + 
+--R              2 3 10        2 3 9         2 3 8          2 3 7           2 3 6
+--R           45a d n   + 2565a d n  + 63540a d n  + 898290a d n  + 7999425a d n
+--R         + 
+--R                    2 3 5             2 3 4             2 3 3             2 3 2
+--R           46695285a d n  + 180021510a d n  + 449614260a d n  + 690085080a d n
+--R         + 
+--R                     2 3              2 3
+--R           580543200a d n + 199584000a d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R                  3 3     3   2  10           3 3       3   2  9
+--R           (- 120a d  + 3b c d )n   + (- 6960a d  + 174b c d )n
+--R         + 
+--R                     3 3        3   2  8              3 3         3   2  7
+--R           (- 175320a d  + 4383b c d )n  + (- 2517840a d  + 62946b c d )n
+--R         + 
+--R                       3 3          3   2  6
+--R           (- 22748040a d  + 568701b c d )n
+--R         + 
+--R                        3 3           3   2  5
+--R           (- 134522640a d  + 3363066b c d )n
+--R         + 
+--R                        3 3            3   2  4
+--R           (- 524563080a d  + 13114077b c d )n
+--R         + 
+--R                         3 3            3   2  3
+--R           (- 1322982960a d  + 33074574b c d )n
+--R         + 
+--R                         3 3            3   2  2
+--R           (- 2047105440a d  + 51177636b c d )n
+--R         + 
+--R                       3 3            3   2               3 3            3   2
+--R         (- 1733313600a d  + 43332840b c d )n - 598752000a d  + 14968800b c d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                4 3        3   2  10          4 3          3   2  9
+--R           (210a d  - 21a b c d )n   + (12390a d  - 1239a b c d )n
+--R         + 
+--R                   4 3           3   2  8            4 3            3   2  7
+--R           (317520a d  - 31752a b c d )n  + (4638060a d  - 463806a b c d )n
+--R         + 
+--R                     4 3             3   2  6
+--R           (42592410a d  - 4259241a b c d )n
+--R         + 
+--R                      4 3              3   2  5
+--R           (255740310a d  - 25574031a b c d )n
+--R         + 
+--R                       4 3               3   2  4
+--R           (1011120180a d  - 101112018a b c d )n
+--R         + 
+--R                       4 3               3   2  3
+--R           (2581262040a d  - 258126204a b c d )n
+--R         + 
+--R                       4 3               3   2  2
+--R           (4035361680a d  - 403536168a b c d )n
+--R         + 
+--R                       4 3               3   2                4 3
+--R           (3445243200a d  - 344524320a b c d )n + 1197504000a d
+--R         + 
+--R                         3   2
+--R           - 119750400a b c d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                  5 3      2 3   2  10            5 3        2 3   2  9
+--R           (- 252a d  + 63a b c d )n   + (- 15120a d  + 3780a b c d )n
+--R         + 
+--R                     5 3         2 3   2  8
+--R           (- 394380a d  + 98595a b c d )n
+--R         + 
+--R                      5 3           2 3   2  7
+--R           (- 5866560a d  + 1466640a b c d )n
+--R         + 
+--R                       5 3            2 3   2  6
+--R           (- 54871236a d  + 13717809a b c d )n
+--R         + 
+--R                        5 3            2 3   2  5
+--R           (- 335437200a d  + 83859300a b c d )n
+--R         + 
+--R                         5 3             2 3   2  4
+--R           (- 1348939620a d  + 337234905a b c d )n
+--R         + 
+--R                         5 3             2 3   2  3
+--R           (- 3497286240a d  + 874321560a b c d )n
+--R         + 
+--R                         5 3              2 3   2  2
+--R           (- 5541317712a d  + 1385329428a b c d )n
+--R         + 
+--R                         5 3              2 3   2                5 3
+--R           (- 4783423680a d  + 1195855920a b c d )n - 1676505600a d
+--R         + 
+--R                     2 3   2
+--R           419126400a b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                6 3       3 3   2     6 2   10
+--R           (210a d  - 105a b c d  + 3b c d)n
+--R         + 
+--R                  6 3        3 3   2       6 2   9
+--R           (12810a d  - 6405a b c d  + 183b c d)n
+--R         + 
+--R                   6 3          3 3   2        6 2   8
+--R           (340200a d  - 170100a b c d  + 4860b c d)n
+--R         + 
+--R                    6 3           3 3   2         6 2   7
+--R           (5159700a d  - 2579850a b c d  + 73710b c d)n
+--R         + 
+--R                     6 3            3 3   2          6 2   6
+--R           (49260330a d  - 24630165a b c d  + 703719b c d)n
+--R         + 
+--R                      6 3             3 3   2           6 2   5
+--R           (307585530a d  - 153792765a b c d  + 4394079b c d)n
+--R         + 
+--R                       6 3             3 3   2            6 2   4
+--R           (1263374700a d  - 631687350a b c d  + 18048210b c d)n
+--R         + 
+--R                       6 3              3 3   2            6 2   3
+--R           (3342229800a d  - 1671114900a b c d  + 47746140b c d)n
+--R         + 
+--R                       6 3              3 3   2            6 2   2
+--R           (5393046960a d  - 2696523480a b c d  + 77043528b c d)n
+--R         + 
+--R                       6 3              3 3   2            6 2
+--R           (4727540160a d  - 2363770080a b c d  + 67536288b c d)n
+--R         + 
+--R                      6 3             3 3   2            6 2
+--R           1676505600a d  - 838252800a b c d  + 23950080b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                  7 3       4 3   2        6 2   10
+--R           (- 120a d  + 105a b c d  - 12a b c d)n
+--R         + 
+--R                   7 3        4 3   2         6 2   9
+--R           (- 7440a d  + 6510a b c d  - 744a b c d)n
+--R         + 
+--R                     7 3          4 3   2           6 2   8
+--R           (- 201240a d  + 176085a b c d  - 20124a b c d)n
+--R         + 
+--R                      7 3           4 3   2            6 2   7
+--R           (- 3115440a d  + 2726010a b c d  - 311544a b c d)n
+--R         + 
+--R                       7 3            4 3   2             6 2   6
+--R           (- 30429000a d  + 26625375a b c d  - 3042900a b c d)n
+--R         + 
+--R                        7 3             4 3   2              6 2   5
+--R           (- 194790960a d  + 170442090a b c d  - 19479096a b c d)n
+--R         + 
+--R                        7 3             4 3   2              6 2   4
+--R           (- 821580360a d  + 718882815a b c d  - 82158036a b c d)n
+--R         + 
+--R                         7 3              4 3   2               6 2   3
+--R           (- 2233166160a d  + 1954020390a b c d  - 223316616a b c d)n
+--R         + 
+--R                         7 3              4 3   2               6 2   2
+--R           (- 3698304480a d  + 3236016420a b c d  - 369830448a b c d)n
+--R         + 
+--R                         7 3              4 3   2               6 2
+--R           (- 3316939200a d  + 2902321800a b c d  - 331693920a b c d)n
+--R         + 
+--R                        7 3              4 3   2               6 2
+--R           - 1197504000a d  + 1047816000a b c d  - 119750400a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R               8 3      5 3   2      2 6 2   10
+--R           (45a d  - 63a b c d  + 18a b c d)n
+--R         + 
+--R                 8 3        5 3   2        2 6 2   9
+--R           (2835a d  - 3969a b c d  + 1134a b c d)n
+--R         + 
+--R                  8 3          5 3   2         2 6 2   8
+--R           (78120a d  - 109368a b c d  + 31248a b c d)n
+--R         + 
+--R                    8 3           5 3   2          2 6 2   7
+--R           (1235790a d  - 1730106a b c d  + 494316a b c d)n
+--R         + 
+--R                     8 3            5 3   2           2 6 2   6
+--R           (12376665a d  - 17327331a b c d  + 4950666a b c d)n
+--R         + 
+--R                     8 3             5 3   2            2 6 2   5
+--R           (81560115a d  - 114184161a b c d  + 32624046a b c d)n
+--R         + 
+--R                      8 3             5 3   2             2 6 2   4
+--R           (355598730a d  - 497838222a b c d  + 142239492a b c d)n
+--R         + 
+--R                       8 3              5 3   2             2 6 2   3
+--R           (1003011660a d  - 1404216324a b c d  + 401204664a b c d)n
+--R         + 
+--R                       8 3              5 3   2             2 6 2   2
+--R           (1727578440a d  - 2418609816a b c d  + 691031376a b c d)n
+--R         + 
+--R                       8 3              5 3   2             2 6 2
+--R           (1608573600a d  - 2252003040a b c d  + 643429440a b c d)n
+--R         + 
+--R                     8 3             5 3   2             2 6 2
+--R           598752000a d  - 838252800a b c d  + 239500800a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R                 9 3      6 3   2      3 6 2     9 3  10
+--R           (- 10a d  + 21a b c d  - 12a b c d + b c )n
+--R         + 
+--R                  9 3        6 3   2       3 6 2       9 3  9
+--R           (- 640a d  + 1344a b c d  - 768a b c d + 64b c )n
+--R         + 
+--R                    9 3         6 3   2         3 6 2         9 3  8
+--R           (- 17970a d  + 37737a b c d  - 21564a b c d + 1797b c )n
+--R         + 
+--R                     9 3          6 3   2          3 6 2          9 3  7
+--R           (- 290760a d  + 610596a b c d  - 348912a b c d + 29076b c )n
+--R         + 
+--R                      9 3           6 3   2           3 6 2           9 3  6
+--R           (- 2992710a d  + 6284691a b c d  - 3591252a b c d + 299271b c )n
+--R         + 
+--R                       9 3            6 3   2            3 6 2            9 3  5
+--R           (- 20390160a d  + 42819336a b c d  - 24468192a b c d + 2039016b c )n
+--R         + 
+--R                            9 3             6 3   2             3 6 2
+--R                 - 92615030a d  + 194491563a b c d  - 111138036a b c d
+--R               + 
+--R                         9 3
+--R                 9261503b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                           9 3             6 3   2             3 6 2
+--R               - 274727240a d  + 576927204a b c d  - 329672688a b c d
+--R             + 
+--R                        9 3
+--R               27472724b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                           9 3              6 3   2             3 6 2
+--R               - 503126280a d  + 1056565188a b c d  - 603751536a b c d
+--R             + 
+--R                        9 3
+--R               50312628b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                           9 3              6 3   2             3 6 2
+--R               - 502927200a d  + 1056147120a b c d  - 603512640a b c d
+--R             + 
+--R                        9 3
+--R               50292720b c
+--R          *
+--R             n
+--R         + 
+--R                     9 3             6 3   2             3 6 2             9 3
+--R         - 199584000a d  + 419126400a b c d  - 239500800a b c d + 19958400b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             10 3     7 3   2     4 6 2       9 3  10
+--R           (a  d  - 3a b c d  + 3a b c d - a b c )n
+--R         + 
+--R               10 3       7 3   2       4 6 2         9 3  9
+--R           (65a  d  - 195a b c d  + 195a b c d - 65a b c )n
+--R         + 
+--R                 10 3        7 3   2        4 6 2           9 3  8
+--R           (1860a  d  - 5580a b c d  + 5580a b c d - 1860a b c )n
+--R         + 
+--R                  10 3         7 3   2         4 6 2            9 3  7
+--R           (30810a  d  - 92430a b c d  + 92430a b c d - 30810a b c )n
+--R         + 
+--R                   10 3          7 3   2          4 6 2             9 3  6
+--R           (326613a  d  - 979839a b c d  + 979839a b c d - 326613a b c )n
+--R         + 
+--R                    10 3           7 3   2           4 6 2              9 3  5
+--R           (2310945a  d  - 6932835a b c d  + 6932835a b c d - 2310945a b c )n
+--R         + 
+--R                          10 3            7 3   2            4 6 2
+--R                 11028590a  d  - 33085770a b c d  + 33085770a b c d
+--R               + 
+--R                              9 3
+--R                 - 11028590a b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                        10 3             7 3   2             4 6 2
+--R               34967140a  d  - 104901420a b c d  + 104901420a b c d
+--R             + 
+--R                            9 3
+--R               - 34967140a b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                        10 3             7 3   2             4 6 2
+--R               70290936a  d  - 210872808a b c d  + 210872808a b c d
+--R             + 
+--R                            9 3
+--R               - 70290936a b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                        10 3             7 3   2             4 6 2
+--R               80627040a  d  - 241881120a b c d  + 241881120a b c d
+--R             + 
+--R                            9 3
+--R               - 80627040a b c
+--R          *
+--R             n
+--R         + 
+--R                  10 3             7 3   2             4 6 2               9 3
+--R         39916800a  d  - 119750400a b c d  + 119750400a b c d - 39916800a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        11 11      11 10        11 9         11 8          11 7           11 6
+--R       b  n   + 66b  n   + 1925b  n  + 32670b  n  + 357423b  n  + 2637558b  n
+--R     + 
+--R                11 5            11 4             11 3             11 2
+--R       13339535b  n  + 45995730b  n  + 105258076b  n  + 150917976b  n
+--R     + 
+--R                 11             11
+--R       120543840b  n + 39916800b
+--R                                                    Type: Expression(Integer)
+--E 880
+
+--S 881 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              11 3 10      11 3 9        11 3 8         11 3 7          11 3 6
+--R             b  d n   + 55b  d n  + 1320b  d n  + 18150b  d n  + 157773b  d n
+--R           + 
+--R                    11 3 5           11 3 4           11 3 3            11 3 2
+--R             902055b  d n  + 3416930b  d n  + 8409500b  d n  + 12753576b  d n
+--R           + 
+--R                      11 3            11 3
+--R             10628640b  d n + 3628800b  d
+--R        *
+--R            11
+--R           x
+--R       + 
+--R                10 3 10        10 3 9         10 3 8          10 3 7
+--R             a b  d n   + 45a b  d n  + 870a b  d n  + 9450a b  d n
+--R           + 
+--R                     10 3 6            10 3 5            10 3 4
+--R             63273a b  d n  + 269325a b  d n  + 723680a b  d n
+--R           + 
+--R                       10 3 3             10 3 2            10 3
+--R             1172700a b  d n  + 1026576a b  d n  + 362880a b  d n
+--R        *
+--R            10
+--R           x
+--R       + 
+--R                  2 9 3 9       2 9 3 8        2 9 3 7         2 9 3 6
+--R             - 10a b d n  - 360a b d n  - 5460a b d n  - 45360a b d n
+--R           + 
+--R                      2 9 3 5          2 9 3 4           2 9 3 3
+--R             - 224490a b d n  - 672840a b d n  - 1181240a b d n
+--R           + 
+--R                       2 9 3 2          2 9 3
+--R             - 1095840a b d n  - 403200a b d n
+--R        *
+--R            9
+--R           x
+--R       + 
+--R               11   2 10       11   2 9       3 8 3        11   2  8
+--R             3b  c d n   + 174b  c d n  + (90a b d  + 4383b  c d )n
+--R           + 
+--R                   3 8 3         11   2  7          3 8 3          11   2  6
+--R             (2520a b d  + 62946b  c d )n  + (28980a b d  + 568701b  c d )n
+--R           + 
+--R                     3 8 3           11   2  5
+--R             (176400a b d  + 3363066b  c d )n
+--R           + 
+--R                     3 8 3            11   2  4
+--R             (609210a b d  + 13114077b  c d )n
+--R           + 
+--R                      3 8 3            11   2  3
+--R             (1181880a b d  + 33074574b  c d )n
+--R           + 
+--R                      3 8 3            11   2  2
+--R             (1176120a b d  + 51177636b  c d )n
+--R           + 
+--R                     3 8 3            11   2              11   2
+--R             (453600a b d  + 43332840b  c d )n + 14968800b  c d
+--R        *
+--R            8
+--R           x
+--R       + 
+--R                 10   2 10         10   2 9          10   2 8
+--R             3a b  c d n   + 153a b  c d n  + 3312a b  c d n
+--R           + 
+--R                    4 7 3           10   2  7
+--R             (- 720a b d  + 39762a b  c d )n
+--R           + 
+--R                      4 7 3            10   2  6
+--R             (- 15120a b d  + 290367a b  c d )n
+--R           + 
+--R                       4 7 3             10   2  5
+--R             (- 126000a b d  + 1330497a b  c d )n
+--R           + 
+--R                       4 7 3             10   2  4
+--R             (- 529200a b d  + 3800598a b  c d )n
+--R           + 
+--R                        4 7 3             10   2  3
+--R             (- 1169280a b d  + 6470388a b  c d )n
+--R           + 
+--R                        4 7 3             10   2  2
+--R             (- 1270080a b d  + 5884920a b  c d )n
+--R           + 
+--R                       4 7 3             10   2
+--R             (- 518400a b d  + 2138400a b  c d )n
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                  2 9   2 9       2 9   2 8         2 9   2 7
+--R             - 21a b c d n  - 945a b c d n  - 17514a b c d n
+--R           + 
+--R                   5 6 3          2 9   2  6          5 6 3          2 9   2  5
+--R             (5040a b d  - 173250a b c d )n  + (75600a b d  - 993069a b c d )n
+--R           + 
+--R                     5 6 3           2 9   2  4
+--R             (428400a b d  - 3355065a b c d )n
+--R           + 
+--R                      5 6 3           2 9   2  3
+--R             (1134000a b d  - 6473796a b c d )n
+--R           + 
+--R                      5 6 3           2 9   2  2
+--R             (1380960a b d  - 6449940a b c d )n
+--R           + 
+--R                     5 6 3           2 9   2
+--R             (604800a b d  - 2494800a b c d )n
+--R        *
+--R            6
+--R           x
+--R       + 
+--R               11 2   10       11 2   9        3 8   2        11 2   8
+--R             3b  c d n   + 183b  c d n  + (126a b c d  + 4860b  c d)n
+--R           + 
+--R                   3 8   2         11 2   7          3 8   2          11 2   6
+--R             (5040a b c d  + 73710b  c d)n  + (79884a b c d  + 703719b  c d)n
+--R           + 
+--R                      6 5 3          3 8   2           11 2   5
+--R             (- 30240a b d  + 640080a b c d  + 4394079b  c d)n
+--R           + 
+--R                       6 5 3           3 8   2            11 2   4
+--R             (- 302400a b d  + 2758014a b c d  + 18048210b  c d)n
+--R           + 
+--R                        6 5 3           3 8   2            11 2   3
+--R             (- 1058400a b d  + 6340320a b c d  + 47746140b  c d)n
+--R           + 
+--R                        6 5 3           3 8   2            11 2   2
+--R             (- 1512000a b d  + 7141176a b c d  + 77043528b  c d)n
+--R           + 
+--R                     6 5 3           3 8   2            11 2               11 2
+--R           (- 725760a b d  + 2993760a b c d  + 67536288b  c d)n + 23950080b  c d
+--R        *
+--R            5
+--R           x
+--R       + 
+--R                 10 2   10         10 2   9          10 2   8
+--R             3a b  c d n   + 171a b  c d n  + 4176a b  c d n
+--R           + 
+--R                    4 7   2           10 2   7
+--R             (- 630a b c d  + 57006a b  c d)n
+--R           + 
+--R                      4 7   2            10 2   6
+--R             (- 22680a b c d  + 475695a b  c d)n
+--R           + 
+--R                       4 7   2             10 2   5
+--R             (- 308700a b c d  + 2491299a b  c d)n
+--R           + 
+--R                     7 4 3           4 7   2             10 2   4
+--R             (151200a b d  - 1965600a b c d  + 8083014a b  c d)n
+--R           + 
+--R                     7 4 3           4 7   2              10 2   3
+--R             (907200a b d  - 5927670a b c d  + 15414084a b  c d)n
+--R           + 
+--R                      7 4 3           4 7   2              10 2   2
+--R             (1663200a b d  - 7990920a b c d  + 15387192a b  c d)n
+--R           + 
+--R                     7 4 3           4 7   2             10 2
+--R             (907200a b d  - 3742200a b c d  + 5987520a b  c d)n
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                  2 9 2   9       2 9 2   8         2 9 2   7
+--R             - 12a b c d n  - 648a b c d n  - 14760a b c d n
+--R           + 
+--R                   5 6   2          2 9 2   6
+--R             (2520a b c d  - 183744a b c d)n
+--R           + 
+--R                    5 6   2           2 9 2   5
+--R             (83160a b c d  - 1351548a b c d)n
+--R           + 
+--R                     5 6   2           2 9 2   4
+--R             (985320a b c d  - 5910552a b c d)n
+--R           + 
+--R                       8 3 3           5 6   2            2 9 2   3
+--R             (- 604800a b d  + 4906440a b c d  - 14600400a b c d)n
+--R           + 
+--R                        8 3 3           5 6   2            2 9 2   2
+--R             (- 1814400a b d  + 8991360a b c d  - 17855136a b c d)n
+--R           + 
+--R                        8 3 3           5 6   2           2 9 2
+--R             (- 1209600a b d  + 4989600a b c d  - 7983360a b c d)n
+--R        *
+--R            3
+--R           x
+--R       + 
+--R              11 3 10      11 3 9       3 8 2         11 3  8
+--R             b  c n   + 64b  c n  + (36a b c d + 1797b  c )n
+--R           + 
+--R                   3 8 2          11 3  7          3 8 2           11 3  6
+--R             (1872a b c d + 29076b  c )n  + (40536a b c d + 299271b  c )n
+--R           + 
+--R                     6 5   2          3 8 2            11 3  5
+--R             (- 7560a b c d  + 470160a b c d + 2039016b  c )n
+--R           + 
+--R                       6 5   2           3 8 2            11 3  4
+--R             (- 234360a b c d  + 3114324a b c d + 9261503b  c )n
+--R           + 
+--R                        6 5   2            3 8 2             11 3  3
+--R             (- 2487240a b c d  + 11503008a b c d + 27472724b  c )n
+--R           + 
+--R                           9 2 3           6 5   2            3 8 2
+--R                   1814400a b d  - 9744840a b c d  + 20795184a b c d
+--R                 + 
+--R                            11 3
+--R                   50312628b  c
+--R            *
+--R                2
+--R               n
+--R           + 
+--R                           9 2 3           6 5   2            3 8 2
+--R                   1814400a b d  - 7484400a b c d  + 11975040a b c d
+--R                 + 
+--R                            11 3
+--R                   50292720b  c
+--R            *
+--R               n
+--R           + 
+--R                      11 3
+--R             19958400b  c
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                10 3 10        10 3 9          10 3 8
+--R             a b  c n   + 63a b  c n  + 1734a b  c n
+--R           + 
+--R                   4 7 2            10 3  7           4 7 2             10 3  6
+--R             (- 72a b c d + 27342a b  c )n  + (- 3672a b c d + 271929a b  c )n
+--R           + 
+--R                      4 7 2              10 3  5
+--R             (- 77400a b c d + 1767087a b  c )n
+--R           + 
+--R                    7 4   2          4 7 2              10 3  4
+--R             (15120a b c d  - 862920a b c d + 7494416a b  c )n
+--R           + 
+--R                     7 4   2           4 7 2               10 3  3
+--R             (453600a b c d  - 5365728a b c d + 19978308a b  c )n
+--R           + 
+--R                      7 4   2            4 7 2               10 3  2
+--R             (4520880a b c d  - 17640288a b c d + 30334320a b  c )n
+--R           + 
+--R                           10   3            7 4   2            4 7 2
+--R                 - 3628800a  b d  + 14968800a b c d  - 23950080a b c d
+--R               + 
+--R                            10 3
+--R                 19958400a b  c
+--R            *
+--R               n
+--R        *
+--R           x
+--R       + 
+--R            2 9 3 9      2 9 3 8        2 9 3 7       5 6 2          2 9 3  6
+--R         - a b c n  - 63a b c n  - 1734a b c n  + (72a b c d - 27342a b c )n
+--R       + 
+--R               5 6 2           2 9 3  5          5 6 2            2 9 3  4
+--R         (3672a b c d - 271929a b c )n  + (77400a b c d - 1767087a b c )n
+--R       + 
+--R                  8 3   2          5 6 2            2 9 3  3
+--R         (- 15120a b c d  + 862920a b c d - 7494416a b c )n
+--R       + 
+--R                   8 3   2           5 6 2             2 9 3  2
+--R         (- 453600a b c d  + 5365728a b c d - 19978308a b c )n
+--R       + 
+--R                    8 3   2            5 6 2             2 9 3             11 3
+--R         (- 4520880a b c d  + 17640288a b c d - 30334320a b c )n + 3628800a  d
+--R       + 
+--R                    8 3   2            5 6 2             2 9 3
+--R         - 14968800a b c d  + 23950080a b c d - 19958400a b c
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R        11 11      11 10        11 9         11 8          11 7           11 6
+--R       b  n   + 66b  n   + 1925b  n  + 32670b  n  + 357423b  n  + 2637558b  n
+--R     + 
+--R                11 5            11 4             11 3             11 2
+--R       13339535b  n  + 45995730b  n  + 105258076b  n  + 150917976b  n
+--R     + 
+--R                 11             11
+--R       120543840b  n + 39916800b
+--R                                         Type: Union(Expression(Integer),...)
+--E 881
+
+--S 882 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                11 3 10      11 3 9        11 3 8         11 3 7          11 3 6
+--R               b  d n   + 55b  d n  + 1320b  d n  + 18150b  d n  + 157773b  d n
+--R             + 
+--R                      11 3 5           11 3 4           11 3 3            11 3 2
+--R               902055b  d n  + 3416930b  d n  + 8409500b  d n  + 12753576b  d n
+--R             + 
+--R                        11 3            11 3
+--R               10628640b  d n + 3628800b  d
+--R          *
+--R              11
+--R             x
+--R         + 
+--R                  10 3 10        10 3 9         10 3 8          10 3 7
+--R               a b  d n   + 45a b  d n  + 870a b  d n  + 9450a b  d n
+--R             + 
+--R                       10 3 6            10 3 5            10 3 4
+--R               63273a b  d n  + 269325a b  d n  + 723680a b  d n
+--R             + 
+--R                         10 3 3             10 3 2            10 3
+--R               1172700a b  d n  + 1026576a b  d n  + 362880a b  d n
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                    2 9 3 9       2 9 3 8        2 9 3 7         2 9 3 6
+--R               - 10a b d n  - 360a b d n  - 5460a b d n  - 45360a b d n
+--R             + 
+--R                        2 9 3 5          2 9 3 4           2 9 3 3
+--R               - 224490a b d n  - 672840a b d n  - 1181240a b d n
+--R             + 
+--R                         2 9 3 2          2 9 3
+--R               - 1095840a b d n  - 403200a b d n
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                 11   2 10       11   2 9       3 8 3        11   2  8
+--R               3b  c d n   + 174b  c d n  + (90a b d  + 4383b  c d )n
+--R             + 
+--R                     3 8 3         11   2  7          3 8 3          11   2  6
+--R               (2520a b d  + 62946b  c d )n  + (28980a b d  + 568701b  c d )n
+--R             + 
+--R                       3 8 3           11   2  5
+--R               (176400a b d  + 3363066b  c d )n
+--R             + 
+--R                       3 8 3            11   2  4
+--R               (609210a b d  + 13114077b  c d )n
+--R             + 
+--R                        3 8 3            11   2  3
+--R               (1181880a b d  + 33074574b  c d )n
+--R             + 
+--R                        3 8 3            11   2  2
+--R               (1176120a b d  + 51177636b  c d )n
+--R             + 
+--R                       3 8 3            11   2              11   2
+--R               (453600a b d  + 43332840b  c d )n + 14968800b  c d
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                   10   2 10         10   2 9          10   2 8
+--R               3a b  c d n   + 153a b  c d n  + 3312a b  c d n
+--R             + 
+--R                      4 7 3           10   2  7
+--R               (- 720a b d  + 39762a b  c d )n
+--R             + 
+--R                        4 7 3            10   2  6
+--R               (- 15120a b d  + 290367a b  c d )n
+--R             + 
+--R                         4 7 3             10   2  5
+--R               (- 126000a b d  + 1330497a b  c d )n
+--R             + 
+--R                         4 7 3             10   2  4
+--R               (- 529200a b d  + 3800598a b  c d )n
+--R             + 
+--R                          4 7 3             10   2  3
+--R               (- 1169280a b d  + 6470388a b  c d )n
+--R             + 
+--R                          4 7 3             10   2  2
+--R               (- 1270080a b d  + 5884920a b  c d )n
+--R             + 
+--R                         4 7 3             10   2
+--R               (- 518400a b d  + 2138400a b  c d )n
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                    2 9   2 9       2 9   2 8         2 9   2 7
+--R               - 21a b c d n  - 945a b c d n  - 17514a b c d n
+--R             + 
+--R                     5 6 3          2 9   2  6
+--R               (5040a b d  - 173250a b c d )n
+--R             + 
+--R                      5 6 3          2 9   2  5
+--R               (75600a b d  - 993069a b c d )n
+--R             + 
+--R                       5 6 3           2 9   2  4
+--R               (428400a b d  - 3355065a b c d )n
+--R             + 
+--R                        5 6 3           2 9   2  3
+--R               (1134000a b d  - 6473796a b c d )n
+--R             + 
+--R                        5 6 3           2 9   2  2
+--R               (1380960a b d  - 6449940a b c d )n
+--R             + 
+--R                       5 6 3           2 9   2
+--R               (604800a b d  - 2494800a b c d )n
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                 11 2   10       11 2   9        3 8   2        11 2   8
+--R               3b  c d n   + 183b  c d n  + (126a b c d  + 4860b  c d)n
+--R             + 
+--R                     3 8   2         11 2   7          3 8   2          11 2   6
+--R               (5040a b c d  + 73710b  c d)n  + (79884a b c d  + 703719b  c d)n
+--R             + 
+--R                        6 5 3          3 8   2           11 2   5
+--R               (- 30240a b d  + 640080a b c d  + 4394079b  c d)n
+--R             + 
+--R                         6 5 3           3 8   2            11 2   4
+--R               (- 302400a b d  + 2758014a b c d  + 18048210b  c d)n
+--R             + 
+--R                          6 5 3           3 8   2            11 2   3
+--R               (- 1058400a b d  + 6340320a b c d  + 47746140b  c d)n
+--R             + 
+--R                          6 5 3           3 8   2            11 2   2
+--R               (- 1512000a b d  + 7141176a b c d  + 77043528b  c d)n
+--R             + 
+--R                         6 5 3           3 8   2            11 2
+--R               (- 725760a b d  + 2993760a b c d  + 67536288b  c d)n
+--R             + 
+--R                        11 2
+--R               23950080b  c d
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                   10 2   10         10 2   9          10 2   8
+--R               3a b  c d n   + 171a b  c d n  + 4176a b  c d n
+--R             + 
+--R                      4 7   2           10 2   7
+--R               (- 630a b c d  + 57006a b  c d)n
+--R             + 
+--R                        4 7   2            10 2   6
+--R               (- 22680a b c d  + 475695a b  c d)n
+--R             + 
+--R                         4 7   2             10 2   5
+--R               (- 308700a b c d  + 2491299a b  c d)n
+--R             + 
+--R                       7 4 3           4 7   2             10 2   4
+--R               (151200a b d  - 1965600a b c d  + 8083014a b  c d)n
+--R             + 
+--R                       7 4 3           4 7   2              10 2   3
+--R               (907200a b d  - 5927670a b c d  + 15414084a b  c d)n
+--R             + 
+--R                        7 4 3           4 7   2              10 2   2
+--R               (1663200a b d  - 7990920a b c d  + 15387192a b  c d)n
+--R             + 
+--R                       7 4 3           4 7   2             10 2
+--R               (907200a b d  - 3742200a b c d  + 5987520a b  c d)n
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    2 9 2   9       2 9 2   8         2 9 2   7
+--R               - 12a b c d n  - 648a b c d n  - 14760a b c d n
+--R             + 
+--R                     5 6   2          2 9 2   6
+--R               (2520a b c d  - 183744a b c d)n
+--R             + 
+--R                      5 6   2           2 9 2   5
+--R               (83160a b c d  - 1351548a b c d)n
+--R             + 
+--R                       5 6   2           2 9 2   4
+--R               (985320a b c d  - 5910552a b c d)n
+--R             + 
+--R                         8 3 3           5 6   2            2 9 2   3
+--R               (- 604800a b d  + 4906440a b c d  - 14600400a b c d)n
+--R             + 
+--R                          8 3 3           5 6   2            2 9 2   2
+--R               (- 1814400a b d  + 8991360a b c d  - 17855136a b c d)n
+--R             + 
+--R                          8 3 3           5 6   2           2 9 2
+--R               (- 1209600a b d  + 4989600a b c d  - 7983360a b c d)n
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                11 3 10      11 3 9       3 8 2         11 3  8
+--R               b  c n   + 64b  c n  + (36a b c d + 1797b  c )n
+--R             + 
+--R                     3 8 2          11 3  7          3 8 2           11 3  6
+--R               (1872a b c d + 29076b  c )n  + (40536a b c d + 299271b  c )n
+--R             + 
+--R                       6 5   2          3 8 2            11 3  5
+--R               (- 7560a b c d  + 470160a b c d + 2039016b  c )n
+--R             + 
+--R                         6 5   2           3 8 2            11 3  4
+--R               (- 234360a b c d  + 3114324a b c d + 9261503b  c )n
+--R             + 
+--R                          6 5   2            3 8 2             11 3  3
+--R               (- 2487240a b c d  + 11503008a b c d + 27472724b  c )n
+--R             + 
+--R                           9 2 3           6 5   2            3 8 2
+--R                   1814400a b d  - 9744840a b c d  + 20795184a b c d
+--R                 + 
+--R                            11 3
+--R                   50312628b  c
+--R              *
+--R                  2
+--R                 n
+--R             + 
+--R                           9 2 3           6 5   2            3 8 2
+--R                   1814400a b d  - 7484400a b c d  + 11975040a b c d
+--R                 + 
+--R                            11 3
+--R                   50292720b  c
+--R              *
+--R                 n
+--R             + 
+--R                        11 3
+--R               19958400b  c
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                  10 3 10        10 3 9          10 3 8
+--R               a b  c n   + 63a b  c n  + 1734a b  c n
+--R             + 
+--R                     4 7 2            10 3  7
+--R               (- 72a b c d + 27342a b  c )n
+--R             + 
+--R                       4 7 2             10 3  6
+--R               (- 3672a b c d + 271929a b  c )n
+--R             + 
+--R                        4 7 2              10 3  5
+--R               (- 77400a b c d + 1767087a b  c )n
+--R             + 
+--R                      7 4   2          4 7 2              10 3  4
+--R               (15120a b c d  - 862920a b c d + 7494416a b  c )n
+--R             + 
+--R                       7 4   2           4 7 2               10 3  3
+--R               (453600a b c d  - 5365728a b c d + 19978308a b  c )n
+--R             + 
+--R                        7 4   2            4 7 2               10 3  2
+--R               (4520880a b c d  - 17640288a b c d + 30334320a b  c )n
+--R             + 
+--R                             10   3            7 4   2            4 7 2
+--R                   - 3628800a  b d  + 14968800a b c d  - 23950080a b c d
+--R                 + 
+--R                              10 3
+--R                   19958400a b  c
+--R              *
+--R                 n
+--R          *
+--R             x
+--R         + 
+--R              2 9 3 9      2 9 3 8        2 9 3 7       5 6 2          2 9 3  6
+--R           - a b c n  - 63a b c n  - 1734a b c n  + (72a b c d - 27342a b c )n
+--R         + 
+--R                 5 6 2           2 9 3  5          5 6 2            2 9 3  4
+--R           (3672a b c d - 271929a b c )n  + (77400a b c d - 1767087a b c )n
+--R         + 
+--R                    8 3   2          5 6 2            2 9 3  3
+--R           (- 15120a b c d  + 862920a b c d - 7494416a b c )n
+--R         + 
+--R                     8 3   2           5 6 2             2 9 3  2
+--R           (- 453600a b c d  + 5365728a b c d - 19978308a b c )n
+--R         + 
+--R                      8 3   2            5 6 2             2 9 3
+--R           (- 4520880a b c d  + 17640288a b c d - 30334320a b c )n
+--R         + 
+--R                   11 3            8 3   2            5 6 2             2 9 3
+--R           3628800a  d  - 14968800a b c d  + 23950080a b c d - 19958400a b c
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R              3 10      3 9        3 8         3 7          3 6          3 5
+--R           - d n   - 55d n  - 1320d n  - 18150d n  - 157773d n  - 902055d n
+--R         + 
+--R                     3 4           3 3            3 2            3            3
+--R           - 3416930d n  - 8409500d n  - 12753576d n  - 10628640d n - 3628800d
+--R      *
+--R                  n + 11
+--R         (b x + a)
+--R     + 
+--R                3 10         3 9           3 8            3 7             3 6
+--R           10a d n   + 560a d n  + 13650a d n  + 190200a d n  + 1672230a d n
+--R         + 
+--R                     3 5              3 4              3 3               3 2
+--R           9653280a d n  + 36862550a d n  + 91331800a d n  + 139262760a d n
+--R         + 
+--R                       3               3
+--R           116552160a d n + 39916800a d
+--R      *
+--R                  n + 10
+--R         (b x + a)
+--R     + 
+--R                2 3 10        2 3 9         2 3 8          2 3 7           2 3 6
+--R           - 45a d n   - 2565a d n  - 63540a d n  - 898290a d n  - 7999425a d n
+--R         + 
+--R                      2 3 5             2 3 4             2 3 3
+--R           - 46695285a d n  - 180021510a d n  - 449614260a d n
+--R         + 
+--R                       2 3 2             2 3              2 3
+--R           - 690085080a d n  - 580543200a d n - 199584000a d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R                3 3     3   2  10         3 3       3   2  9
+--R           (120a d  - 3b c d )n   + (6960a d  - 174b c d )n
+--R         + 
+--R                   3 3        3   2  8            3 3         3   2  7
+--R           (175320a d  - 4383b c d )n  + (2517840a d  - 62946b c d )n
+--R         + 
+--R                     3 3          3   2  6              3 3           3   2  5
+--R           (22748040a d  - 568701b c d )n  + (134522640a d  - 3363066b c d )n
+--R         + 
+--R                      3 3            3   2  4
+--R           (524563080a d  - 13114077b c d )n
+--R         + 
+--R                       3 3            3   2  3
+--R           (1322982960a d  - 33074574b c d )n
+--R         + 
+--R                       3 3            3   2  2
+--R           (2047105440a d  - 51177636b c d )n
+--R         + 
+--R                       3 3            3   2               3 3            3   2
+--R           (1733313600a d  - 43332840b c d )n + 598752000a d  - 14968800b c d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                  4 3        3   2  10            4 3          3   2  9
+--R           (- 210a d  + 21a b c d )n   + (- 12390a d  + 1239a b c d )n
+--R         + 
+--R                     4 3           3   2  8              4 3            3   2  7
+--R           (- 317520a d  + 31752a b c d )n  + (- 4638060a d  + 463806a b c d )n
+--R         + 
+--R                       4 3             3   2  6
+--R           (- 42592410a d  + 4259241a b c d )n
+--R         + 
+--R                        4 3              3   2  5
+--R           (- 255740310a d  + 25574031a b c d )n
+--R         + 
+--R                         4 3               3   2  4
+--R           (- 1011120180a d  + 101112018a b c d )n
+--R         + 
+--R                         4 3               3   2  3
+--R           (- 2581262040a d  + 258126204a b c d )n
+--R         + 
+--R                         4 3               3   2  2
+--R           (- 4035361680a d  + 403536168a b c d )n
+--R         + 
+--R                         4 3               3   2                4 3
+--R           (- 3445243200a d  + 344524320a b c d )n - 1197504000a d
+--R         + 
+--R                       3   2
+--R           119750400a b c d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                5 3      2 3   2  10          5 3        2 3   2  9
+--R           (252a d  - 63a b c d )n   + (15120a d  - 3780a b c d )n
+--R         + 
+--R                   5 3         2 3   2  8            5 3           2 3   2  7
+--R           (394380a d  - 98595a b c d )n  + (5866560a d  - 1466640a b c d )n
+--R         + 
+--R                     5 3            2 3   2  6
+--R           (54871236a d  - 13717809a b c d )n
+--R         + 
+--R                      5 3            2 3   2  5
+--R           (335437200a d  - 83859300a b c d )n
+--R         + 
+--R                       5 3             2 3   2  4
+--R           (1348939620a d  - 337234905a b c d )n
+--R         + 
+--R                       5 3             2 3   2  3
+--R           (3497286240a d  - 874321560a b c d )n
+--R         + 
+--R                       5 3              2 3   2  2
+--R           (5541317712a d  - 1385329428a b c d )n
+--R         + 
+--R                       5 3              2 3   2                5 3
+--R           (4783423680a d  - 1195855920a b c d )n + 1676505600a d
+--R         + 
+--R                       2 3   2
+--R           - 419126400a b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                  6 3       3 3   2     6 2   10
+--R           (- 210a d  + 105a b c d  - 3b c d)n
+--R         + 
+--R                    6 3        3 3   2       6 2   9
+--R           (- 12810a d  + 6405a b c d  - 183b c d)n
+--R         + 
+--R                     6 3          3 3   2        6 2   8
+--R           (- 340200a d  + 170100a b c d  - 4860b c d)n
+--R         + 
+--R                      6 3           3 3   2         6 2   7
+--R           (- 5159700a d  + 2579850a b c d  - 73710b c d)n
+--R         + 
+--R                       6 3            3 3   2          6 2   6
+--R           (- 49260330a d  + 24630165a b c d  - 703719b c d)n
+--R         + 
+--R                        6 3             3 3   2           6 2   5
+--R           (- 307585530a d  + 153792765a b c d  - 4394079b c d)n
+--R         + 
+--R                         6 3             3 3   2            6 2   4
+--R           (- 1263374700a d  + 631687350a b c d  - 18048210b c d)n
+--R         + 
+--R                         6 3              3 3   2            6 2   3
+--R           (- 3342229800a d  + 1671114900a b c d  - 47746140b c d)n
+--R         + 
+--R                         6 3              3 3   2            6 2   2
+--R           (- 5393046960a d  + 2696523480a b c d  - 77043528b c d)n
+--R         + 
+--R                         6 3              3 3   2            6 2
+--R           (- 4727540160a d  + 2363770080a b c d  - 67536288b c d)n
+--R         + 
+--R                        6 3             3 3   2            6 2
+--R           - 1676505600a d  + 838252800a b c d  - 23950080b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                7 3       4 3   2        6 2   10
+--R           (120a d  - 105a b c d  + 12a b c d)n
+--R         + 
+--R                 7 3        4 3   2         6 2   9
+--R           (7440a d  - 6510a b c d  + 744a b c d)n
+--R         + 
+--R                   7 3          4 3   2           6 2   8
+--R           (201240a d  - 176085a b c d  + 20124a b c d)n
+--R         + 
+--R                    7 3           4 3   2            6 2   7
+--R           (3115440a d  - 2726010a b c d  + 311544a b c d)n
+--R         + 
+--R                     7 3            4 3   2             6 2   6
+--R           (30429000a d  - 26625375a b c d  + 3042900a b c d)n
+--R         + 
+--R                      7 3             4 3   2              6 2   5
+--R           (194790960a d  - 170442090a b c d  + 19479096a b c d)n
+--R         + 
+--R                      7 3             4 3   2              6 2   4
+--R           (821580360a d  - 718882815a b c d  + 82158036a b c d)n
+--R         + 
+--R                       7 3              4 3   2               6 2   3
+--R           (2233166160a d  - 1954020390a b c d  + 223316616a b c d)n
+--R         + 
+--R                       7 3              4 3   2               6 2   2
+--R           (3698304480a d  - 3236016420a b c d  + 369830448a b c d)n
+--R         + 
+--R                       7 3              4 3   2               6 2
+--R           (3316939200a d  - 2902321800a b c d  + 331693920a b c d)n
+--R         + 
+--R                      7 3              4 3   2               6 2
+--R           1197504000a d  - 1047816000a b c d  + 119750400a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 8 3      5 3   2      2 6 2   10
+--R           (- 45a d  + 63a b c d  - 18a b c d)n
+--R         + 
+--R                   8 3        5 3   2        2 6 2   9
+--R           (- 2835a d  + 3969a b c d  - 1134a b c d)n
+--R         + 
+--R                    8 3          5 3   2         2 6 2   8
+--R           (- 78120a d  + 109368a b c d  - 31248a b c d)n
+--R         + 
+--R                      8 3           5 3   2          2 6 2   7
+--R           (- 1235790a d  + 1730106a b c d  - 494316a b c d)n
+--R         + 
+--R                       8 3            5 3   2           2 6 2   6
+--R           (- 12376665a d  + 17327331a b c d  - 4950666a b c d)n
+--R         + 
+--R                       8 3             5 3   2            2 6 2   5
+--R           (- 81560115a d  + 114184161a b c d  - 32624046a b c d)n
+--R         + 
+--R                        8 3             5 3   2             2 6 2   4
+--R           (- 355598730a d  + 497838222a b c d  - 142239492a b c d)n
+--R         + 
+--R                         8 3              5 3   2             2 6 2   3
+--R           (- 1003011660a d  + 1404216324a b c d  - 401204664a b c d)n
+--R         + 
+--R                         8 3              5 3   2             2 6 2   2
+--R           (- 1727578440a d  + 2418609816a b c d  - 691031376a b c d)n
+--R         + 
+--R                         8 3              5 3   2             2 6 2
+--R           (- 1608573600a d  + 2252003040a b c d  - 643429440a b c d)n
+--R         + 
+--R                       8 3             5 3   2             2 6 2
+--R           - 598752000a d  + 838252800a b c d  - 239500800a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R               9 3      6 3   2      3 6 2     9 3  10
+--R           (10a d  - 21a b c d  + 12a b c d - b c )n
+--R         + 
+--R                9 3        6 3   2       3 6 2       9 3  9
+--R           (640a d  - 1344a b c d  + 768a b c d - 64b c )n
+--R         + 
+--R                  9 3         6 3   2         3 6 2         9 3  8
+--R           (17970a d  - 37737a b c d  + 21564a b c d - 1797b c )n
+--R         + 
+--R                   9 3          6 3   2          3 6 2          9 3  7
+--R           (290760a d  - 610596a b c d  + 348912a b c d - 29076b c )n
+--R         + 
+--R                    9 3           6 3   2           3 6 2           9 3  6
+--R           (2992710a d  - 6284691a b c d  + 3591252a b c d - 299271b c )n
+--R         + 
+--R                     9 3            6 3   2            3 6 2            9 3  5
+--R           (20390160a d  - 42819336a b c d  + 24468192a b c d - 2039016b c )n
+--R         + 
+--R                     9 3             6 3   2             3 6 2            9 3  4
+--R           (92615030a d  - 194491563a b c d  + 111138036a b c d - 9261503b c )n
+--R         + 
+--R                           9 3             6 3   2             3 6 2
+--R                 274727240a d  - 576927204a b c d  + 329672688a b c d
+--R               + 
+--R                            9 3
+--R                 - 27472724b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                         9 3              6 3   2             3 6 2
+--R               503126280a d  - 1056565188a b c d  + 603751536a b c d
+--R             + 
+--R                          9 3
+--R               - 50312628b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                         9 3              6 3   2             3 6 2
+--R               502927200a d  - 1056147120a b c d  + 603512640a b c d
+--R             + 
+--R                          9 3
+--R               - 50292720b c
+--R          *
+--R             n
+--R         + 
+--R                     9 3             6 3   2             3 6 2             9 3
+--R           199584000a d  - 419126400a b c d  + 239500800a b c d - 19958400b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               10 3     7 3   2     4 6 2       9 3  10
+--R           (- a  d  + 3a b c d  - 3a b c d + a b c )n
+--R         + 
+--R                 10 3       7 3   2       4 6 2         9 3  9
+--R           (- 65a  d  + 195a b c d  - 195a b c d + 65a b c )n
+--R         + 
+--R                   10 3        7 3   2        4 6 2           9 3  8
+--R           (- 1860a  d  + 5580a b c d  - 5580a b c d + 1860a b c )n
+--R         + 
+--R                    10 3         7 3   2         4 6 2            9 3  7
+--R           (- 30810a  d  + 92430a b c d  - 92430a b c d + 30810a b c )n
+--R         + 
+--R                     10 3          7 3   2          4 6 2             9 3  6
+--R           (- 326613a  d  + 979839a b c d  - 979839a b c d + 326613a b c )n
+--R         + 
+--R                      10 3           7 3   2           4 6 2              9 3  5
+--R           (- 2310945a  d  + 6932835a b c d  - 6932835a b c d + 2310945a b c )n
+--R         + 
+--R                          10 3            7 3   2            4 6 2
+--R               - 11028590a  d  + 33085770a b c d  - 33085770a b c d
+--R             + 
+--R                          9 3
+--R               11028590a b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                          10 3             7 3   2             4 6 2
+--R               - 34967140a  d  + 104901420a b c d  - 104901420a b c d
+--R             + 
+--R                          9 3
+--R               34967140a b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                          10 3             7 3   2             4 6 2
+--R               - 70290936a  d  + 210872808a b c d  - 210872808a b c d
+--R             + 
+--R                          9 3
+--R               70290936a b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                          10 3             7 3   2             4 6 2
+--R               - 80627040a  d  + 241881120a b c d  - 241881120a b c d
+--R             + 
+--R                          9 3
+--R               80627040a b c
+--R          *
+--R             n
+--R         + 
+--R                    10 3             7 3   2             4 6 2               9 3
+--R         - 39916800a  d  + 119750400a b c d  - 119750400a b c d + 39916800a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        11 11      11 10        11 9         11 8          11 7           11 6
+--R       b  n   + 66b  n   + 1925b  n  + 32670b  n  + 357423b  n  + 2637558b  n
+--R     + 
+--R                11 5            11 4             11 3             11 2
+--R       13339535b  n  + 45995730b  n  + 105258076b  n  + 150917976b  n
+--R     + 
+--R                 11             11
+--R       120543840b  n + 39916800b
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         10 3 10     10   2 7     10 2   4    10 3    n log(b x + a)
+--R       (b  d x   + 3b  c d x  + 3b  c d x  + b  c x)%e
+--R     + 
+--R          3         n + 10        3         n + 9      2 3         n + 8
+--R       - d (b x + a)       + 10a d (b x + a)      - 45a d (b x + a)
+--R     + 
+--R            3 3     3   2          n + 7
+--R       (120a d  - 3b c d )(b x + a)
+--R     + 
+--R              4 3        3   2          n + 6
+--R       (- 210a d  + 21a b c d )(b x + a)
+--R     + 
+--R            5 3      2 3   2          n + 5
+--R       (252a d  - 63a b c d )(b x + a)
+--R     + 
+--R              6 3       3 3   2     6 2           n + 4
+--R       (- 210a d  + 105a b c d  - 3b c d)(b x + a)
+--R     + 
+--R            7 3       4 3   2        6 2           n + 3
+--R       (120a d  - 105a b c d  + 12a b c d)(b x + a)
+--R     + 
+--R             8 3      5 3   2      2 6 2           n + 2
+--R       (- 45a d  + 63a b c d  - 18a b c d)(b x + a)
+--R     + 
+--R           9 3      6 3   2      3 6 2     9 3          n + 1
+--R       (10a d  - 21a b c d  + 12a b c d - b c )(b x + a)
+--R     + 
+--R           10 3     7 3   2     4 6 2       9 3          n
+--R       (- a  d  + 3a b c d  - 3a b c d + a b c )(b x + a)
+--R  /
+--R      10
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 883
+
+)clear all
+
+--S 884 of 953
+t0:=(a+b*x)^n*(c+d*x^3)^3
+--R 
+--R
+--R          3 9       2 6     2   3    3          n
+--R   (1)  (d x  + 3c d x  + 3c d x  + c )(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 884
+
+--S 885 of 953
+r0:=(b^3*c-a^3*d)^3*(a+b*x)^(1+n)/(b^10*(1+n))+9*a^2*d*(b^3*c-a^3*d)^2*_
+   (a+b*x)^(2+n)/(b^10*(2+n))-9*a*d*(b^3*c-4*a^3*d)*(b^3*c-a^3*d)*_
+   (a+b*x)^(3+n)/(b^10*(3+n))+3*d*(b^6*c^2-20*a^3*b^3*c*d+28*a^6*d^2)*_
+   (a+b*x)^(4+n)/(b^10*(4+n))+9*a^2*d^2*(5*b^3*c-14*a^3*d)*(a+b*x)^(5+n)/_
+   (b^10*(5+n))-18*a*d^2*(b^3*c-7*a^3*d)*(a+b*x)^(6+n)/(b^10*(6+n))+_
+   3*d^2*(b^3*c-28*a^3*d)*(a+b*x)^(7+n)/(b^10*(7+n))+36*a^2*d^3*_
+   (a+b*x)^(8+n)/(b^10*(8+n))-9*a*d^3*(a+b*x)^(9+n)/(b^10*(9+n))+_
+   d^3*(a+b*x)^(10+n)/(b^10*(10+n))
+--R 
+--R
+--R   (2)
+--R            3 9      3 8       3 7        3 6         3 5          3 4
+--R           d n  + 45d n  + 870d n  + 9450d n  + 63273d n  + 269325d n
+--R         + 
+--R                  3 3           3 2           3           3
+--R           723680d n  + 1172700d n  + 1026576d n + 362880d
+--R      *
+--R                  n + 10
+--R         (b x + a)
+--R     + 
+--R                 3 9         3 8          3 7           3 6            3 5
+--R           - 9a d n  - 414a d n  - 8154a d n  - 89964a d n  - 610281a d n
+--R         + 
+--R                       3 4             3 3              3 2              3
+--R           - 2625966a d n  - 7118676a d n  - 11617416a d n  - 10225440a d n
+--R         + 
+--R                       3
+--R           - 3628800a d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R              2 3 9        2 3 8         2 3 7          2 3 6           2 3 5
+--R           36a d n  + 1692a d n  + 33984a d n  + 381528a d n  + 2627604a d n
+--R         + 
+--R                    2 3 4            2 3 3            2 3 2            2 3
+--R           11453148a d n  + 31384296a d n  + 51667632a d n  + 45787680a d n
+--R         + 
+--R                    2 3
+--R           16329600a d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                 3 3     3   2  9           3 3       3   2  8
+--R           (- 84a d  + 3b c d )n  + (- 4032a d  + 144b c d )n
+--R         + 
+--R                    3 3        3   2  7             3 3         3   2  6
+--R           (- 82656a d  + 2952b c d )n  + (- 946008a d  + 33786b c d )n
+--R         + 
+--R                      3 3          3   2  5               3 3           3   2  4
+--R           (- 6630876a d  + 236817b c d )n  + (- 29356488a d  + 1048446b c d )n
+--R         + 
+--R                       3 3           3   2  3
+--R           (- 81526704a d  + 2911668b c d )n
+--R         + 
+--R                        3 3           3   2  2
+--R           (- 135711072a d  + 4846824b c d )n
+--R         + 
+--R                        3 3           3   2              3 3           3   2
+--R           (- 121322880a d  + 4332960b c d )n - 43545600a d  + 1555200b c d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                4 3        3   2  9         4 3         3   2  8
+--R           (126a d  - 18a b c d )n  + (6174a d  - 882a b c d )n
+--R         + 
+--R                   4 3           3   2  7            4 3            3   2  6
+--R           (129276a d  - 18468a b c d )n  + (1511244a d  - 215892a b c d )n
+--R         + 
+--R                     4 3             3   2  5
+--R           (10811934a d  - 1544562a b c d )n
+--R         + 
+--R                     4 3             3   2  4
+--R           (48787326a d  - 6969618a b c d )n
+--R         + 
+--R                      4 3              3   2  3
+--R           (137809224a d  - 19687032a b c d )n
+--R         + 
+--R                      4 3              3   2  2
+--R           (232741656a d  - 33248808a b c d )n
+--R         + 
+--R                    4 3              3   2              4 3              3   2
+--R         (210500640a d  - 30071520a b c d )n + 76204800a d  - 10886400a b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                  5 3      2 3   2  9           5 3        2 3   2  8
+--R           (- 126a d  + 45a b c d )n  + (- 6300a d  + 2250a b c d )n
+--R         + 
+--R                     5 3         2 3   2  7              5 3          2 3   2  6
+--R           (- 134820a d  + 48150a b c d )n  + (- 1612800a d  + 576000a b c d )n
+--R         + 
+--R                       5 3           2 3   2  5
+--R           (- 11815398a d  + 4219785a b c d )n
+--R         + 
+--R                       5 3            2 3   2  4
+--R           (- 54581940a d  + 19493550a b c d )n
+--R         + 
+--R                        5 3            2 3   2  3
+--R           (- 157623480a d  + 56294100a b c d )n
+--R         + 
+--R                        5 3            2 3   2  2
+--R           (- 271479600a d  + 96957000a b c d )n
+--R         + 
+--R                      5 3            2 3   2              5 3            2 3   2
+--R         (- 249552576a d  + 89125920a b c d )n - 91445760a d  + 32659200a b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R               6 3      3 3   2     6 2   9
+--R           (84a d  - 60a b c d  + 3b c d)n
+--R         + 
+--R                 6 3        3 3   2       6 2   8
+--R           (4284a d  - 3060a b c d  + 153b c d)n
+--R         + 
+--R                  6 3         3 3   2        6 2   7
+--R           (93744a d  - 66960a b c d  + 3348b c d)n
+--R         + 
+--R                    6 3          3 3   2         6 2   6
+--R           (1149624a d  - 821160a b c d  + 41058b c d)n
+--R         + 
+--R                    6 3           3 3   2          6 2   5
+--R           (8654436a d  - 6181740a b c d  + 309087b c d)n
+--R         + 
+--R                     6 3            3 3   2           6 2   4
+--R           (41154876a d  - 29396340a b c d  + 1469817b c d)n
+--R         + 
+--R                      6 3            3 3   2           6 2   3
+--R           (122402616a d  - 87430440a b c d  + 4371522b c d)n
+--R         + 
+--R                      6 3             3 3   2           6 2   2
+--R           (216787536a d  - 154848240a b c d  + 7742412b c d)n
+--R         + 
+--R                      6 3             3 3   2           6 2               6 3
+--R           (204150240a d  - 145821600a b c d  + 7291080b c d)n + 76204800a d
+--R         + 
+--R                      3 3   2           6 2
+--R           - 54432000a b c d  + 2721600b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 7 3      4 3   2       6 2   9
+--R           (- 36a d  + 45a b c d  - 9a b c d)n
+--R         + 
+--R                   7 3        4 3   2         6 2   8
+--R           (- 1872a d  + 2340a b c d  - 468a b c d)n
+--R         + 
+--R                    7 3         4 3   2           6 2   7
+--R           (- 41904a d  + 52380a b c d  - 10476a b c d)n
+--R         + 
+--R                     7 3          4 3   2            6 2   6
+--R           (- 527688a d  + 659610a b c d  - 131922a b c d)n
+--R         + 
+--R                      7 3           4 3   2             6 2   5
+--R           (- 4096764a d  + 5120955a b c d  - 1024191a b c d)n
+--R         + 
+--R                       7 3            4 3   2             6 2   4
+--R           (- 20183688a d  + 25229610a b c d  - 5045922a b c d)n
+--R         + 
+--R                       7 3            4 3   2              6 2   3
+--R           (- 62458416a d  + 78073020a b c d  - 15614604a b c d)n
+--R         + 
+--R                        7 3             4 3   2              6 2   2
+--R           (- 115366752a d  + 144208440a b c d  - 28841688a b c d)n
+--R         + 
+--R                        7 3             4 3   2              6 2
+--R           (- 113028480a d  + 141285600a b c d  - 28257120a b c d)n
+--R         + 
+--R                      7 3            4 3   2              6 2
+--R           - 43545600a d  + 54432000a b c d  - 10886400a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R              8 3      5 3   2     2 6 2   9
+--R           (9a d  - 18a b c d  + 9a b c d)n
+--R         + 
+--R                8 3       5 3   2       2 6 2   8
+--R           (477a d  - 954a b c d  + 477a b c d)n
+--R         + 
+--R                  8 3         5 3   2         2 6 2   7
+--R           (10926a d  - 21852a b c d  + 10926a b c d)n
+--R         + 
+--R                   8 3          5 3   2          2 6 2   6
+--R           (141498a d  - 282996a b c d  + 141498a b c d)n
+--R         + 
+--R                    8 3           5 3   2           2 6 2   5
+--R           (1136961a d  - 2273922a b c d  + 1136961a b c d)n
+--R         + 
+--R                    8 3            5 3   2           2 6 2   4
+--R           (5844573a d  - 11689146a b c d  + 5844573a b c d)n
+--R         + 
+--R                     8 3            5 3   2            2 6 2   3
+--R           (19063224a d  - 38126448a b c d  + 19063224a b c d)n
+--R         + 
+--R                     8 3            5 3   2            2 6 2   2
+--R           (37559052a d  - 75118104a b c d  + 37559052a b c d)n
+--R         + 
+--R                     8 3            5 3   2            2 6 2               8 3
+--R           (39664080a d  - 79328160a b c d  + 39664080a b c d)n + 16329600a d
+--R         + 
+--R                      5 3   2            2 6 2
+--R           - 32659200a b c d  + 16329600a b c d
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               9 3     6 3   2     3 6 2     9 3  9
+--R           (- a d  + 3a b c d  - 3a b c d + b c )n
+--R         + 
+--R                 9 3       6 3   2       3 6 2       9 3  8
+--R           (- 54a d  + 162a b c d  - 162a b c d + 54b c )n
+--R         + 
+--R                   9 3        6 3   2        3 6 2         9 3  7
+--R           (- 1266a d  + 3798a b c d  - 3798a b c d + 1266b c )n
+--R         + 
+--R                    9 3         6 3   2         3 6 2          9 3  6
+--R           (- 16884a d  + 50652a b c d  - 50652a b c d + 16884b c )n
+--R         + 
+--R                     9 3          6 3   2          3 6 2           9 3  5
+--R           (- 140889a d  + 422667a b c d  - 422667a b c d + 140889b c )n
+--R         + 
+--R                     9 3           6 3   2           3 6 2           9 3  4
+--R           (- 761166a d  + 2283498a b c d  - 2283498a b c d + 761166b c )n
+--R         + 
+--R                      9 3           6 3   2           3 6 2            9 3  3
+--R           (- 2655764a d  + 7967292a b c d  - 7967292a b c d + 2655764b c )n
+--R         + 
+--R                      9 3            6 3   2            3 6 2            9 3  2
+--R           (- 5753736a d  + 17261208a b c d  - 17261208a b c d + 5753736b c )n
+--R         + 
+--R                      9 3            6 3   2            3 6 2            9 3
+--R           (- 6999840a d  + 20999520a b c d  - 20999520a b c d + 6999840b c )n
+--R         + 
+--R                     9 3            6 3   2            3 6 2            9 3
+--R           - 3628800a d  + 10886400a b c d  - 10886400a b c d + 3628800b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        10 10      10 9        10 8         10 7          10 6          10 5
+--R       b  n   + 55b  n  + 1320b  n  + 18150b  n  + 157773b  n  + 902055b  n
+--R     + 
+--R               10 4           10 3            10 2            10            10
+--R       3416930b  n  + 8409500b  n  + 12753576b  n  + 10628640b  n + 3628800b
+--R                                                    Type: Expression(Integer)
+--E 885
+
+--S 886 of 953
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              10 3 9      10 3 8       10 3 7        10 3 6         10 3 5
+--R             b  d n  + 45b  d n  + 870b  d n  + 9450b  d n  + 63273b  d n
+--R           + 
+--R                    10 3 4          10 3 3           10 3 2           10 3
+--R             269325b  d n  + 723680b  d n  + 1172700b  d n  + 1026576b  d n
+--R           + 
+--R                    10 3
+--R             362880b  d
+--R        *
+--R            10
+--R           x
+--R       + 
+--R                9 3 9        9 3 8         9 3 7          9 3 6           9 3 5
+--R             a b d n  + 36a b d n  + 546a b d n  + 4536a b d n  + 22449a b d n
+--R           + 
+--R                     9 3 4            9 3 3            9 3 2           9 3
+--R             67284a b d n  + 118124a b d n  + 109584a b d n  + 40320a b d n
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                 2 8 3 8       2 8 3 7        2 8 3 6         2 8 3 5
+--R             - 9a b d n  - 252a b d n  - 2898a b d n  - 17640a b d n
+--R           + 
+--R                     2 8 3 4          2 8 3 3          2 8 3 2         2 8 3
+--R             - 60921a b d n  - 118188a b d n  - 117612a b d n  - 45360a b d n
+--R        *
+--R            8
+--R           x
+--R       + 
+--R               10   2 9       10   2 8       3 7 3        10   2  7
+--R             3b  c d n  + 144b  c d n  + (72a b d  + 2952b  c d )n
+--R           + 
+--R                   3 7 3         10   2  6          3 7 3          10   2  5
+--R             (1512a b d  + 33786b  c d )n  + (12600a b d  + 236817b  c d )n
+--R           + 
+--R                    3 7 3           10   2  4
+--R             (52920a b d  + 1048446b  c d )n
+--R           + 
+--R                     3 7 3           10   2  3
+--R             (116928a b d  + 2911668b  c d )n
+--R           + 
+--R                     3 7 3           10   2  2          3 7 3           10   2
+--R             (127008a b d  + 4846824b  c d )n  + (51840a b d  + 4332960b  c d )n
+--R           + 
+--R                     10   2
+--R             1555200b  c d
+--R        *
+--R            7
+--R           x
+--R       + 
+--R                 9   2 9         9   2 8          9   2 7
+--R             3a b c d n  + 126a b c d n  + 2196a b c d n
+--R           + 
+--R                    4 6 3           9   2  6           4 6 3            9   2  5
+--R             (- 504a b d  + 20610a b c d )n  + (- 7560a b d  + 113157a b c d )n
+--R           + 
+--R                      4 6 3            9   2  4
+--R             (- 42840a b d  + 369504a b c d )n
+--R           + 
+--R                       4 6 3            9   2  3
+--R             (- 113400a b d  + 694644a b c d )n
+--R           + 
+--R                       4 6 3            9   2  2
+--R             (- 138096a b d  + 678960a b c d )n
+--R           + 
+--R                      4 6 3            9   2
+--R             (- 60480a b d  + 259200a b c d )n
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                  2 8   2 8       2 8   2 7        2 8   2 6
+--R             - 18a b c d n  - 666a b c d n  - 9846a b c d n
+--R           + 
+--R                   5 5 3         2 8   2  5          5 5 3          2 8   2  4
+--R             (3024a b d  - 74430a b c d )n  + (30240a b d  - 306792a b c d )n
+--R           + 
+--R                     5 5 3          2 8   2  3
+--R             (105840a b d  - 683064a b c d )n
+--R           + 
+--R                   5 5 3          2 8   2  2          5 5 3          2 8   2
+--R           (151200a b d  - 752544a b c d )n  + (72576a b d  - 311040a b c d )n
+--R        *
+--R            5
+--R           x
+--R       + 
+--R               10 2   9       10 2   8       3 7   2        10 2   7
+--R             3b  c d n  + 153b  c d n  + (90a b c d  + 3348b  c d)n
+--R           + 
+--R                   3 7   2         10 2   6          3 7   2          10 2   5
+--R             (2970a b c d  + 41058b  c d)n  + (37350a b c d  + 309087b  c d)n
+--R           + 
+--R                      6 4 3          3 7   2           10 2   4
+--R             (- 15120a b d  + 222750a b c d  + 1469817b  c d)n
+--R           + 
+--R                      6 4 3          3 7   2           10 2   3
+--R             (- 90720a b d  + 642960a b c d  + 4371522b  c d)n
+--R           + 
+--R                       6 4 3          3 7   2           10 2   2
+--R             (- 166320a b d  + 843480a b c d  + 7742412b  c d)n
+--R           + 
+--R                      6 4 3          3 7   2           10 2              10 2
+--R             (- 90720a b d  + 388800a b c d  + 7291080b  c d)n + 2721600b  c d
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                 9 2   9         9 2   8          9 2   7
+--R             3a b c d n  + 144a b c d n  + 2916a b c d n
+--R           + 
+--R                    4 6   2           9 2   6
+--R             (- 360a b c d  + 32310a b c d)n
+--R           + 
+--R                      4 6   2            9 2   5
+--R             (- 10800a b c d  + 212157a b c d)n
+--R           + 
+--R                       4 6   2            9 2   4
+--R             (- 117000a b c d  + 833346a b c d)n
+--R           + 
+--R                    7 3 3          4 6   2             9 2   3
+--R             (60480a b d  - 540000a b c d  + 1871484a b c d)n
+--R           + 
+--R                     7 3 3          4 6   2             9 2   2
+--R             (181440a b d  - 951840a b c d  + 2127960a b c d)n
+--R           + 
+--R                     7 3 3          4 6   2            9 2
+--R             (120960a b d  - 518400a b c d  + 907200a b c d)n
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                 2 8 2   8       2 8 2   7        2 8 2   6
+--R             - 9a b c d n  - 414a b c d n  - 7920a b c d n
+--R           + 
+--R                   5 5   2         2 8 2   5          5 5   2          2 8 2   4
+--R             (1080a b c d  - 81090a b c d)n  + (30240a b c d  - 474291a b c d)n
+--R           + 
+--R                     5 5   2           2 8 2   3
+--R             (290520a b c d  - 1551456a b c d)n
+--R           + 
+--R                       8 2 3           5 5   2           2 8 2   2
+--R             (- 181440a b d  + 1038960a b c d  - 2511540a b c d)n
+--R           + 
+--R                       8 2 3          5 5   2           2 8 2
+--R             (- 181440a b d  + 777600a b c d  - 1360800a b c d)n
+--R        *
+--R            2
+--R           x
+--R       + 
+--R              10 3 9      10 3 8       3 7 2         10 3  7
+--R             b  c n  + 54b  c n  + (18a b c d + 1266b  c )n
+--R           + 
+--R                  3 7 2          10 3  6          3 7 2           10 3  5
+--R             (810a b c d + 16884b  c )n  + (15030a b c d + 140889b  c )n
+--R           + 
+--R                     6 4   2          3 7 2           10 3  4
+--R             (- 2160a b c d  + 147150a b c d + 761166b  c )n
+--R           + 
+--R                      6 4   2          3 7 2            10 3  3
+--R             (- 58320a b c d  + 801432a b c d + 2655764b  c )n
+--R           + 
+--R                       6 4   2           3 7 2            10 3  2
+--R             (- 522720a b c d  + 2301480a b c d + 5753736b  c )n
+--R           + 
+--R                     9   3           6 4   2           3 7 2            10 3
+--R             (362880a b d  - 1555200a b c d  + 2721600a b c d + 6999840b  c )n
+--R           + 
+--R                     10 3
+--R             3628800b  c
+--R        *
+--R           x
+--R       + 
+--R            9 3 9        9 3 8          9 3 7         4 6 2            9 3  6
+--R         a b c n  + 54a b c n  + 1266a b c n  + (- 18a b c d + 16884a b c )n
+--R       + 
+--R                4 6 2             9 3  5            4 6 2             9 3  4
+--R         (- 810a b c d + 140889a b c )n  + (- 15030a b c d + 761166a b c )n
+--R       + 
+--R               7 3   2          4 6 2              9 3  3
+--R         (2160a b c d  - 147150a b c d + 2655764a b c )n
+--R       + 
+--R                7 3   2          4 6 2              9 3  2
+--R         (58320a b c d  - 801432a b c d + 5753736a b c )n
+--R       + 
+--R                 7 3   2           4 6 2              9 3            10 3
+--R         (522720a b c d  - 2301480a b c d + 6999840a b c )n - 362880a  d
+--R       + 
+--R                 7 3   2           4 6 2              9 3
+--R         1555200a b c d  - 2721600a b c d + 3628800a b c
+--R    *
+--R         n log(b x + a)
+--R       %e
+--R  /
+--R        10 10      10 9        10 8         10 7          10 6          10 5
+--R       b  n   + 55b  n  + 1320b  n  + 18150b  n  + 157773b  n  + 902055b  n
+--R     + 
+--R               10 4           10 3            10 2            10            10
+--R       3416930b  n  + 8409500b  n  + 12753576b  n  + 10628640b  n + 3628800b
+--R                                         Type: Union(Expression(Integer),...)
+--E 886
+
+--S 887 of 953
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                10 3 9      10 3 8       10 3 7        10 3 6         10 3 5
+--R               b  d n  + 45b  d n  + 870b  d n  + 9450b  d n  + 63273b  d n
+--R             + 
+--R                      10 3 4          10 3 3           10 3 2           10 3
+--R               269325b  d n  + 723680b  d n  + 1172700b  d n  + 1026576b  d n
+--R             + 
+--R                      10 3
+--R               362880b  d
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                  9 3 9        9 3 8         9 3 7          9 3 6
+--R               a b d n  + 36a b d n  + 546a b d n  + 4536a b d n
+--R             + 
+--R                       9 3 5           9 3 4            9 3 3            9 3 2
+--R               22449a b d n  + 67284a b d n  + 118124a b d n  + 109584a b d n
+--R             + 
+--R                       9 3
+--R               40320a b d n
+--R          *
+--R              9
+--R             x
+--R         + 
+--R                   2 8 3 8       2 8 3 7        2 8 3 6         2 8 3 5
+--R               - 9a b d n  - 252a b d n  - 2898a b d n  - 17640a b d n
+--R             + 
+--R                       2 8 3 4          2 8 3 3          2 8 3 2         2 8 3
+--R               - 60921a b d n  - 118188a b d n  - 117612a b d n  - 45360a b d n
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                 10   2 9       10   2 8       3 7 3        10   2  7
+--R               3b  c d n  + 144b  c d n  + (72a b d  + 2952b  c d )n
+--R             + 
+--R                     3 7 3         10   2  6          3 7 3          10   2  5
+--R               (1512a b d  + 33786b  c d )n  + (12600a b d  + 236817b  c d )n
+--R             + 
+--R                      3 7 3           10   2  4
+--R               (52920a b d  + 1048446b  c d )n
+--R             + 
+--R                       3 7 3           10   2  3
+--R               (116928a b d  + 2911668b  c d )n
+--R             + 
+--R                       3 7 3           10   2  2
+--R               (127008a b d  + 4846824b  c d )n
+--R             + 
+--R                      3 7 3           10   2             10   2
+--R               (51840a b d  + 4332960b  c d )n + 1555200b  c d
+--R          *
+--R              7
+--R             x
+--R         + 
+--R                   9   2 9         9   2 8          9   2 7
+--R               3a b c d n  + 126a b c d n  + 2196a b c d n
+--R             + 
+--R                      4 6 3           9   2  6
+--R               (- 504a b d  + 20610a b c d )n
+--R             + 
+--R                       4 6 3            9   2  5
+--R               (- 7560a b d  + 113157a b c d )n
+--R             + 
+--R                        4 6 3            9   2  4
+--R               (- 42840a b d  + 369504a b c d )n
+--R             + 
+--R                         4 6 3            9   2  3
+--R               (- 113400a b d  + 694644a b c d )n
+--R             + 
+--R                         4 6 3            9   2  2
+--R               (- 138096a b d  + 678960a b c d )n
+--R             + 
+--R                        4 6 3            9   2
+--R               (- 60480a b d  + 259200a b c d )n
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                    2 8   2 8       2 8   2 7        2 8   2 6
+--R               - 18a b c d n  - 666a b c d n  - 9846a b c d n
+--R             + 
+--R                     5 5 3         2 8   2  5          5 5 3          2 8   2  4
+--R               (3024a b d  - 74430a b c d )n  + (30240a b d  - 306792a b c d )n
+--R             + 
+--R                       5 5 3          2 8   2  3
+--R               (105840a b d  - 683064a b c d )n
+--R             + 
+--R                     5 5 3          2 8   2  2          5 5 3          2 8   2
+--R             (151200a b d  - 752544a b c d )n  + (72576a b d  - 311040a b c d )n
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                 10 2   9       10 2   8       3 7   2        10 2   7
+--R               3b  c d n  + 153b  c d n  + (90a b c d  + 3348b  c d)n
+--R             + 
+--R                     3 7   2         10 2   6          3 7   2          10 2   5
+--R               (2970a b c d  + 41058b  c d)n  + (37350a b c d  + 309087b  c d)n
+--R             + 
+--R                        6 4 3          3 7   2           10 2   4
+--R               (- 15120a b d  + 222750a b c d  + 1469817b  c d)n
+--R             + 
+--R                        6 4 3          3 7   2           10 2   3
+--R               (- 90720a b d  + 642960a b c d  + 4371522b  c d)n
+--R             + 
+--R                         6 4 3          3 7   2           10 2   2
+--R               (- 166320a b d  + 843480a b c d  + 7742412b  c d)n
+--R             + 
+--R                      6 4 3          3 7   2           10 2              10 2
+--R             (- 90720a b d  + 388800a b c d  + 7291080b  c d)n + 2721600b  c d
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   9 2   9         9 2   8          9 2   7
+--R               3a b c d n  + 144a b c d n  + 2916a b c d n
+--R             + 
+--R                      4 6   2           9 2   6
+--R               (- 360a b c d  + 32310a b c d)n
+--R             + 
+--R                        4 6   2            9 2   5
+--R               (- 10800a b c d  + 212157a b c d)n
+--R             + 
+--R                         4 6   2            9 2   4
+--R               (- 117000a b c d  + 833346a b c d)n
+--R             + 
+--R                      7 3 3          4 6   2             9 2   3
+--R               (60480a b d  - 540000a b c d  + 1871484a b c d)n
+--R             + 
+--R                       7 3 3          4 6   2             9 2   2
+--R               (181440a b d  - 951840a b c d  + 2127960a b c d)n
+--R             + 
+--R                       7 3 3          4 6   2            9 2
+--R               (120960a b d  - 518400a b c d  + 907200a b c d)n
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   2 8 2   8       2 8 2   7        2 8 2   6
+--R               - 9a b c d n  - 414a b c d n  - 7920a b c d n
+--R             + 
+--R                     5 5   2         2 8 2   5
+--R               (1080a b c d  - 81090a b c d)n
+--R             + 
+--R                      5 5   2          2 8 2   4
+--R               (30240a b c d  - 474291a b c d)n
+--R             + 
+--R                       5 5   2           2 8 2   3
+--R               (290520a b c d  - 1551456a b c d)n
+--R             + 
+--R                         8 2 3           5 5   2           2 8 2   2
+--R               (- 181440a b d  + 1038960a b c d  - 2511540a b c d)n
+--R             + 
+--R                         8 2 3          5 5   2           2 8 2
+--R               (- 181440a b d  + 777600a b c d  - 1360800a b c d)n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                10 3 9      10 3 8       3 7 2         10 3  7
+--R               b  c n  + 54b  c n  + (18a b c d + 1266b  c )n
+--R             + 
+--R                    3 7 2          10 3  6          3 7 2           10 3  5
+--R               (810a b c d + 16884b  c )n  + (15030a b c d + 140889b  c )n
+--R             + 
+--R                       6 4   2          3 7 2           10 3  4
+--R               (- 2160a b c d  + 147150a b c d + 761166b  c )n
+--R             + 
+--R                        6 4   2          3 7 2            10 3  3
+--R               (- 58320a b c d  + 801432a b c d + 2655764b  c )n
+--R             + 
+--R                         6 4   2           3 7 2            10 3  2
+--R               (- 522720a b c d  + 2301480a b c d + 5753736b  c )n
+--R             + 
+--R                       9   3           6 4   2           3 7 2            10 3
+--R               (362880a b d  - 1555200a b c d  + 2721600a b c d + 6999840b  c )n
+--R             + 
+--R                       10 3
+--R               3628800b  c
+--R          *
+--R             x
+--R         + 
+--R              9 3 9        9 3 8          9 3 7         4 6 2            9 3  6
+--R           a b c n  + 54a b c n  + 1266a b c n  + (- 18a b c d + 16884a b c )n
+--R         + 
+--R                  4 6 2             9 3  5            4 6 2             9 3  4
+--R           (- 810a b c d + 140889a b c )n  + (- 15030a b c d + 761166a b c )n
+--R         + 
+--R                 7 3   2          4 6 2              9 3  3
+--R           (2160a b c d  - 147150a b c d + 2655764a b c )n
+--R         + 
+--R                  7 3   2          4 6 2              9 3  2
+--R           (58320a b c d  - 801432a b c d + 5753736a b c )n
+--R         + 
+--R                   7 3   2           4 6 2              9 3            10 3
+--R           (522720a b c d  - 2301480a b c d + 6999840a b c )n - 362880a  d
+--R         + 
+--R                   7 3   2           4 6 2              9 3
+--R           1555200a b c d  - 2721600a b c d + 3628800a b c
+--R      *
+--R           n log(b x + a)
+--R         %e
+--R     + 
+--R              3 9      3 8       3 7        3 6         3 5          3 4
+--R           - d n  - 45d n  - 870d n  - 9450d n  - 63273d n  - 269325d n
+--R         + 
+--R                    3 3           3 2           3           3
+--R           - 723680d n  - 1172700d n  - 1026576d n - 362880d
+--R      *
+--R                  n + 10
+--R         (b x + a)
+--R     + 
+--R               3 9         3 8          3 7           3 6            3 5
+--R           9a d n  + 414a d n  + 8154a d n  + 89964a d n  + 610281a d n
+--R         + 
+--R                     3 4             3 3              3 2              3
+--R           2625966a d n  + 7118676a d n  + 11617416a d n  + 10225440a d n
+--R         + 
+--R                     3
+--R           3628800a d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R                2 3 9        2 3 8         2 3 7          2 3 6           2 3 5
+--R           - 36a d n  - 1692a d n  - 33984a d n  - 381528a d n  - 2627604a d n
+--R         + 
+--R                      2 3 4            2 3 3            2 3 2            2 3
+--R           - 11453148a d n  - 31384296a d n  - 51667632a d n  - 45787680a d n
+--R         + 
+--R                      2 3
+--R           - 16329600a d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R               3 3     3   2  9         3 3       3   2  8
+--R           (84a d  - 3b c d )n  + (4032a d  - 144b c d )n
+--R         + 
+--R                  3 3        3   2  7           3 3         3   2  6
+--R           (82656a d  - 2952b c d )n  + (946008a d  - 33786b c d )n
+--R         + 
+--R                    3 3          3   2  5             3 3           3   2  4
+--R           (6630876a d  - 236817b c d )n  + (29356488a d  - 1048446b c d )n
+--R         + 
+--R                     3 3           3   2  3              3 3           3   2  2
+--R           (81526704a d  - 2911668b c d )n  + (135711072a d  - 4846824b c d )n
+--R         + 
+--R                      3 3           3   2              3 3           3   2
+--R           (121322880a d  - 4332960b c d )n + 43545600a d  - 1555200b c d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                  4 3        3   2  9           4 3         3   2  8
+--R           (- 126a d  + 18a b c d )n  + (- 6174a d  + 882a b c d )n
+--R         + 
+--R                     4 3           3   2  7              4 3            3   2  6
+--R           (- 129276a d  + 18468a b c d )n  + (- 1511244a d  + 215892a b c d )n
+--R         + 
+--R                       4 3             3   2  5
+--R           (- 10811934a d  + 1544562a b c d )n
+--R         + 
+--R                       4 3             3   2  4
+--R           (- 48787326a d  + 6969618a b c d )n
+--R         + 
+--R                        4 3              3   2  3
+--R           (- 137809224a d  + 19687032a b c d )n
+--R         + 
+--R                        4 3              3   2  2
+--R           (- 232741656a d  + 33248808a b c d )n
+--R         + 
+--R                      4 3              3   2              4 3              3   2
+--R         (- 210500640a d  + 30071520a b c d )n - 76204800a d  + 10886400a b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                5 3      2 3   2  9         5 3        2 3   2  8
+--R           (126a d  - 45a b c d )n  + (6300a d  - 2250a b c d )n
+--R         + 
+--R                   5 3         2 3   2  7            5 3          2 3   2  6
+--R           (134820a d  - 48150a b c d )n  + (1612800a d  - 576000a b c d )n
+--R         + 
+--R                     5 3           2 3   2  5
+--R           (11815398a d  - 4219785a b c d )n
+--R         + 
+--R                     5 3            2 3   2  4
+--R           (54581940a d  - 19493550a b c d )n
+--R         + 
+--R                      5 3            2 3   2  3
+--R           (157623480a d  - 56294100a b c d )n
+--R         + 
+--R                      5 3            2 3   2  2
+--R           (271479600a d  - 96957000a b c d )n
+--R         + 
+--R                    5 3            2 3   2              5 3            2 3   2
+--R         (249552576a d  - 89125920a b c d )n + 91445760a d  - 32659200a b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                 6 3      3 3   2     6 2   9
+--R           (- 84a d  + 60a b c d  - 3b c d)n
+--R         + 
+--R                   6 3        3 3   2       6 2   8
+--R           (- 4284a d  + 3060a b c d  - 153b c d)n
+--R         + 
+--R                    6 3         3 3   2        6 2   7
+--R           (- 93744a d  + 66960a b c d  - 3348b c d)n
+--R         + 
+--R                      6 3          3 3   2         6 2   6
+--R           (- 1149624a d  + 821160a b c d  - 41058b c d)n
+--R         + 
+--R                      6 3           3 3   2          6 2   5
+--R           (- 8654436a d  + 6181740a b c d  - 309087b c d)n
+--R         + 
+--R                       6 3            3 3   2           6 2   4
+--R           (- 41154876a d  + 29396340a b c d  - 1469817b c d)n
+--R         + 
+--R                        6 3            3 3   2           6 2   3
+--R           (- 122402616a d  + 87430440a b c d  - 4371522b c d)n
+--R         + 
+--R                        6 3             3 3   2           6 2   2
+--R           (- 216787536a d  + 154848240a b c d  - 7742412b c d)n
+--R         + 
+--R                        6 3             3 3   2           6 2               6 3
+--R           (- 204150240a d  + 145821600a b c d  - 7291080b c d)n - 76204800a d
+--R         + 
+--R                    3 3   2           6 2
+--R           54432000a b c d  - 2721600b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R               7 3      4 3   2       6 2   9
+--R           (36a d  - 45a b c d  + 9a b c d)n
+--R         + 
+--R                 7 3        4 3   2         6 2   8
+--R           (1872a d  - 2340a b c d  + 468a b c d)n
+--R         + 
+--R                  7 3         4 3   2           6 2   7
+--R           (41904a d  - 52380a b c d  + 10476a b c d)n
+--R         + 
+--R                   7 3          4 3   2            6 2   6
+--R           (527688a d  - 659610a b c d  + 131922a b c d)n
+--R         + 
+--R                    7 3           4 3   2             6 2   5
+--R           (4096764a d  - 5120955a b c d  + 1024191a b c d)n
+--R         + 
+--R                     7 3            4 3   2             6 2   4
+--R           (20183688a d  - 25229610a b c d  + 5045922a b c d)n
+--R         + 
+--R                     7 3            4 3   2              6 2   3
+--R           (62458416a d  - 78073020a b c d  + 15614604a b c d)n
+--R         + 
+--R                      7 3             4 3   2              6 2   2
+--R           (115366752a d  - 144208440a b c d  + 28841688a b c d)n
+--R         + 
+--R                      7 3             4 3   2              6 2               7 3
+--R           (113028480a d  - 141285600a b c d  + 28257120a b c d)n + 43545600a d
+--R         + 
+--R                      4 3   2              6 2
+--R           - 54432000a b c d  + 10886400a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R                8 3      5 3   2     2 6 2   9
+--R           (- 9a d  + 18a b c d  - 9a b c d)n
+--R         + 
+--R                  8 3       5 3   2       2 6 2   8
+--R           (- 477a d  + 954a b c d  - 477a b c d)n
+--R         + 
+--R                    8 3         5 3   2         2 6 2   7
+--R           (- 10926a d  + 21852a b c d  - 10926a b c d)n
+--R         + 
+--R                     8 3          5 3   2          2 6 2   6
+--R           (- 141498a d  + 282996a b c d  - 141498a b c d)n
+--R         + 
+--R                      8 3           5 3   2           2 6 2   5
+--R           (- 1136961a d  + 2273922a b c d  - 1136961a b c d)n
+--R         + 
+--R                      8 3            5 3   2           2 6 2   4
+--R           (- 5844573a d  + 11689146a b c d  - 5844573a b c d)n
+--R         + 
+--R                       8 3            5 3   2            2 6 2   3
+--R           (- 19063224a d  + 38126448a b c d  - 19063224a b c d)n
+--R         + 
+--R                       8 3            5 3   2            2 6 2   2
+--R           (- 37559052a d  + 75118104a b c d  - 37559052a b c d)n
+--R         + 
+--R                       8 3            5 3   2            2 6 2               8 3
+--R           (- 39664080a d  + 79328160a b c d  - 39664080a b c d)n - 16329600a d
+--R         + 
+--R                    5 3   2            2 6 2
+--R           32659200a b c d  - 16329600a b c d
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             9 3     6 3   2     3 6 2     9 3  9
+--R           (a d  - 3a b c d  + 3a b c d - b c )n
+--R         + 
+--R               9 3       6 3   2       3 6 2       9 3  8
+--R           (54a d  - 162a b c d  + 162a b c d - 54b c )n
+--R         + 
+--R                 9 3        6 3   2        3 6 2         9 3  7
+--R           (1266a d  - 3798a b c d  + 3798a b c d - 1266b c )n
+--R         + 
+--R                  9 3         6 3   2         3 6 2          9 3  6
+--R           (16884a d  - 50652a b c d  + 50652a b c d - 16884b c )n
+--R         + 
+--R                   9 3          6 3   2          3 6 2           9 3  5
+--R           (140889a d  - 422667a b c d  + 422667a b c d - 140889b c )n
+--R         + 
+--R                   9 3           6 3   2           3 6 2           9 3  4
+--R           (761166a d  - 2283498a b c d  + 2283498a b c d - 761166b c )n
+--R         + 
+--R                    9 3           6 3   2           3 6 2            9 3  3
+--R           (2655764a d  - 7967292a b c d  + 7967292a b c d - 2655764b c )n
+--R         + 
+--R                    9 3            6 3   2            3 6 2            9 3  2
+--R           (5753736a d  - 17261208a b c d  + 17261208a b c d - 5753736b c )n
+--R         + 
+--R                    9 3            6 3   2            3 6 2            9 3
+--R           (6999840a d  - 20999520a b c d  + 20999520a b c d - 6999840b c )n
+--R         + 
+--R                   9 3            6 3   2            3 6 2            9 3
+--R           3628800a d  - 10886400a b c d  + 10886400a b c d - 3628800b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        10 10      10 9        10 8         10 7          10 6          10 5
+--R       b  n   + 55b  n  + 1320b  n  + 18150b  n  + 157773b  n  + 902055b  n
+--R     + 
+--R               10 4           10 3            10 2            10            10
+--R       3416930b  n  + 8409500b  n  + 12753576b  n  + 10628640b  n + 3628800b
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 953
+d0:=D(m0,x)
+--R 
+--R
+--R   (5)
+--R         9 3 9     9   2 6     9 2   3    9 3   n log(b x + a)
+--R       (b d x  + 3b c d x  + 3b c d x  + b c )%e
+--R     + 
+--R          3         n + 9       3         n + 8      2 3         n + 7
+--R       - d (b x + a)      + 9a d (b x + a)      - 36a d (b x + a)
+--R     + 
+--R           3 3     3   2          n + 6          4 3        3   2          n + 5
+--R       (84a d  - 3b c d )(b x + a)      + (- 126a d  + 18a b c d )(b x + a)
+--R     + 
+--R            5 3      2 3   2          n + 4
+--R       (126a d  - 45a b c d )(b x + a)
+--R     + 
+--R             6 3      3 3   2     6 2           n + 3
+--R       (- 84a d  + 60a b c d  - 3b c d)(b x + a)
+--R     + 
+--R           7 3      4 3   2       6 2           n + 2
+--R       (36a d  - 45a b c d  + 9a b c d)(b x + a)
+--R     + 
+--R            8 3      5 3   2     2 6 2           n + 1
+--R       (- 9a d  + 18a b c d  - 9a b c d)(b x + a)
+--R     + 
+--R         9 3     6 3   2     3 6 2     9 3          n
+--R       (a d  - 3a b c d  + 3a b c d - b c )(b x + a)
+--R  /
+--R      9
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 888
+
+)clear all
+
+--S 889 of 953
+t0:=(a+b*x)^n*(c+d*x^3)^3/x
+--R 
+--R
+--R          3 9       2 6     2   3    3          n
+--R        (d x  + 3c d x  + 3c d x  + c )(b x + a)
+--R   (1)  -----------------------------------------
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 889
+
+--S 890 of 953
+--r0:=3*a^2*c^2*d*(a+b*x)^(1+n)/(b^3*(1+n))-3*a^5*c*d^2*(a+b*x)^(1+n)/_
+--   (b^6*(1+n))+a^8*d^3*(a+b*x)^(1+n)/(b^9*(1+n))-6*a*c^2*d*(a+b*x)^(2+n)/_
+--   (b^3*(2+n))+15*a^4*c*d^2*(a+b*x)^(2+n)/(b^6*(2+n))-8*a^7*d^3*_
+--   (a+b*x)^(2+n)/(b^9*(2+n))+3*c^2*d*(a+b*x)^(3+n)/(b^3*(3+n))-_
+--   30*a^3*c*d^2*(a+b*x)^(3+n)/(b^6*(3+n))+28*a^6*d^3*(a+b*x)^(3+n)/_
+--   (b^9*(3+n))+30*a^2*c*d^2*(a+b*x)^(4+n)/(b^6*(4+n))-56*a^5*d^3*_
+--   (a+b*x)^(4+n)/(b^9*(4+n))-15*a*c*d^2*(a+b*x)^(5+n)/(b^6*(5+n))+_
+--   70*a^4*d^3*(a+b*x)^(5+n)/(b^9*(5+n))+3*c*d^2*(a+b*x)^(6+n)/(b^6*_
+--   (6+n))-56*a^3*d^3*(a+b*x)^(6+n)/(b^9*(6+n))+28*a^2*d^3*_
+--   (a+b*x)^(7+n)/(b^9*(7+n))-8*a*d^3*(a+b*x)^(8+n)/(b^9*(8+n))+d^3*_
+--   (a+b*x)^(9+n)/(b^9*(9+n))-c^3*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*(1+n))
+--E 890
+
+--S 891 of 953
+--a0:=integrate(t0,x)
+--E 891
+
+--S 892 of 953
+--m0:=a0-r0
+--E 892
+
+--S 893 of 953
+--d0:=D(m0,x)
+--E 893
+
+)clear all
+
+--S 894 of 953
+t0:=x^m*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R         m         n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 894
+
+--S 895 of 953
+--r0:=1/3*x^(1+m)*(e+f*x)^n*AppellF1(1+m,1,-n,2+m,-b^(1/3)*x/a^(1/3),_
+--   -f*x/e)/(a*(1+m)*((e+f*x)/e)^n)+1/3*x^(1+m)*(e+f*x)^n*_
+--   AppellF1(1+m,1,-n,2+m,(-1)^(1/3)*b^(1/3)*x/a^(1/3),-f*x/e)/_
+--   (a*(1+m)*((e+f*x)/e)^n)+1/3*x^(1+m)*(e+f*x)^n*AppellF1(1+m,1,-n,_
+--   2+m,-(-1)^(2/3)*b^(1/3)*x/a^(1/3),-f*x/e)/(a*(1+m)*((e+f*x)/e)^n)
+--E 895
+
+--S 896 of 953
+--a0:=integrate(t0,x)
+--E 896
+
+--S 897 of 953
+--m0:=a0-r0
+--E 897
+
+--S 898 of 953
+--d0:=D(m0,x)
+--E 898
+
+)clear all
+
+--S 899 of 953
+t0:=x^5*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R         5         n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 899
+
+--S 900 of 953
+--r0:=e^2*(e+f*x)^(1+n)/(b*f^3*(1+n))-2*e*(e+f*x)^(2+n)/(b*f^3*(2+n))+_
+--   (e+f*x)^(3+n)/(b*f^3*(3+n))+1/3*a*(e+f*x)^(1+n)*hypergeometric(1,_
+--   1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-a^(1/3)*f))/(b^(5/3)*(b^(1/3)*e-_
+--   a^(1/3)*f)*(1+n))+1/3*a*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*_
+--   (e+f*x)/(b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f))/(b^(5/3)*(b^(1/3)*e+_
+--   (-1)^(1/3)*a^(1/3)*f)*(1+n))+1/3*a*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-(-1)^(2/3)*_
+--   a^(1/3)*f))/(b^(5/3)*(b^(1/3)*e-(-1)^(2/3)*a^(1/3)*f)*(1+n))
+--E 900
+
+--S 901 of 953
+--a0:=integrate(t0,x)
+--E 901
+
+--S 902 of 953
+--m0:=a0-r0
+--E 902
+
+--S 903 of 953
+--d0:=D(m0,x)
+--E 903
+
+)clear all
+
+--S 904 of 953
+t0:=x^4*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R         4         n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 953
+--r0:=-e*(e+f*x)^(1+n)/(b*f^2*(1+n))+(e+f*x)^(2+n)/(b*f^2*(2+n))-_
+--   1/3*a^(2/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*_
+--   (e+f*x)/(b^(1/3)*e-a^(1/3)*f))/(b^(4/3)*(b^(1/3)*e-a^(1/3)*f)*_
+--   (1+n))+1/3*(-1)^(1/3)*a^(2/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,_
+--   2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f))/(b^(4/3)*_
+--   ((-1)^(2/3)*b^(1/3)*e-a^(1/3)*f)*(1+n))+1/3*(-1)^(2/3)*a^(2/3)*_
+--   (e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*_
+--   e-(-1)^(2/3)*a^(1/3)*f))/(b^(4/3)*((-1)^(1/3)*b^(1/3)*e+a^(1/3)*f)*(1+n))
+--E 905
+
+--S 906 of 953
+--a0:=integrate(t0,x)
+--E 906
+
+--S 907 of 953
+--m0:=a0-r0
+--E 907
+
+--S 908 of 953
+--d0:=D(m0,x)
+--E 908
+
+)clear all
+
+--S 909 of 953
+t0:=x^3*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R         3         n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 909
+
+--S 910 of 953
+--r0:=(e+f*x)^(1+n)/(b*f*(1+n))+1/3*a^(1/3)*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-a^(1/3)*f))/_
+--   (b*(b^(1/3)*e-a^(1/3)*f)*(1+n))+1/3*a^(1/3)*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e+(-1)^(1/3)*_
+--   a^(1/3)*f))/(b*((-1)^(2/3)*b^(1/3)*e-a^(1/3)*f)*(1+n))-1/3*a^(1/3)*_
+--   (e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*_
+--   e-(-1)^(2/3)*a^(1/3)*f))/(b*((-1)^(1/3)*b^(1/3)*e+a^(1/3)*f)*(1+n))
+--E 910
+
+--S 911 of 953
+--a0:=integrate(t0,x)
+--E 911
+
+--S 912 of 953
+--m0:=a0-r0
+--E 912
+
+--S 913 of 953
+--d0:=D(m0,x)
+--E 913
+
+)clear all
+
+--S 914 of 953
+t0:=x^2*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R         2         n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 914
+
+--S 915 of 953
+--r0:=-1/3*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/_
+--   (b^(1/3)*e-a^(1/3)*f))/(b^(2/3)*(b^(1/3)*e-a^(1/3)*f)*(1+n))-_
+--   1/3*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*_
+--   e+(-1)^(1/3)*a^(1/3)*f))/(b^(2/3)*(b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f)*_
+--   (1+n))-1/3*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/_
+--   (b^(1/3)*e-(-1)^(2/3)*a^(1/3)*f))/(b^(2/3)*(b^(1/3)*e-(-1)^(2/3)*_
+--   a^(1/3)*f)*(1+n))
+--E 915
+
+--S 916 of 953
+--a0:=integrate(t0,x)
+--E 916
+
+--S 917 of 953
+--m0:=a0-r0
+--E 917
+
+--S 918 of 953
+--d0:=D(m0,x)
+--E 918
+
+)clear all
+
+--S 919 of 953
+t0:=x*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R                   n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 919
+
+--S 920 of 953
+--r0:=1/3*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-_
+--   a^(1/3)*f))/(a^(1/3)*b^(1/3)*(b^(1/3)*e-a^(1/3)*f)*(1+n))-_
+--   1/3*(-1)^(1/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*_
+--   (e+f*x)/(b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f))/(a^(1/3)*b^(1/3)*_
+--   ((-1)^(2/3)*b^(1/3)*e-a^(1/3)*f)*(1+n))-1/3*(-1)^(2/3)*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-(-1)^(2/3)*_
+--   a^(1/3)*f))/(a^(1/3)*b^(1/3)*((-1)^(1/3)*b^(1/3)*e+a^(1/3)*f)*(1+n))
+--E 920
+
+--S 921 of 953
+--a0:=integrate(t0,x)
+--E 921
+
+--S 922 of 953
+--m0:=a0-r0
+--E 922
+
+--S 923 of 953
+--d0:=D(m0,x)
+--E 923
+
+)clear all
+
+--S 924 of 953
+t0:=(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R                 n
+--R        (f x + e)
+--R   (1)  ----------
+--R            3
+--R         b x  + a
+--R                                                    Type: Expression(Integer)
+--E 924
+
+--S 925 of 953
+--r0:=-1/3*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-_
+--   a^(1/3)*f))/(a^(2/3)*(b^(1/3)*e-a^(1/3)*f)*(1+n))-1/3*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e+(-1)^(1/3)*_
+--   a^(1/3)*f))/(a^(2/3)*((-1)^(2/3)*b^(1/3)*e-a^(1/3)*f)*(1+n))+1/3*_
+--   (e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*_
+--   e-(-1)^(2/3)*a^(1/3)*f))/(a^(2/3)*((-1)^(1/3)*b^(1/3)*e+a^(1/3)*f)*(1+n))
+--E 925
+
+--S 926 of 953
+--a0:=integrate(t0,x)
+--E 926
+
+--S 927 of 953
+--m0:=a0-r0
+--E 927
+
+--S 928 of 953
+--d0:=D(m0,x)
+--E 928
+
+)clear all
+
+--S 929 of 953
+t0:=(e+f*x)^n/(x*(a+b*x^3))
+--R 
+--R
+--R                 n
+--R        (f x + e)
+--R   (1)  ----------
+--R           4
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 929
+
+--S 930 of 953
+--r0:=-(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,(e+f*x)/e)/(a*e*(1+n))+_
+--   1/3*b^(1/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/_
+--   (b^(1/3)*e-a^(1/3)*f))/(a*(b^(1/3)*e-a^(1/3)*f)*(1+n))+1/3*b^(1/3)*_
+--   (e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*_
+--   e+(-1)^(1/3)*a^(1/3)*f))/(a*(b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f)*(1+n))+_
+--   1/3*b^(1/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/_
+--   (b^(1/3)*e-(-1)^(2/3)*a^(1/3)*f))/(a*(b^(1/3)*e-(-1)^(2/3)*_
+--   a^(1/3)*f)*(1+n))
+--E 930
+
+--S 931 of 953
+--a0:=integrate(t0,x)
+--E 931
+
+--S 932 of 953
+--m0:=a0-r0
+--E 932
+
+--S 933 of 953
+--d0:=D(m0,x)
+--E 933
+
+)clear all
+
+--S 934 of 953
+t0:=(e+f*x)^n/(x^2*(a+b*x^3))
+--R 
+--R
+--R                  n
+--R         (f x + e)
+--R   (1)  -----------
+--R           5      2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 934
+
+--S 935 of 953
+--r0:=-(e+f*x)^(1+n)/(a*e*x)-f*n*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(e+f*x)/e)/(a*e^2*(1+n))-1/3*b^(2/3)*_
+--   (e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-_
+--   a^(1/3)*f))/(a^(4/3)*(b^(1/3)*e-a^(1/3)*f)*(1+n))+1/3*(-1)^(1/3)*_
+--   b^(2/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/_
+--   (b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f))/(a^(4/3)*((-1)^(2/3)*b^(1/3)*e-_
+--   a^(1/3)*f)*(1+n))+1/3*(-1)^(2/3)*b^(2/3)*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-(-1)^(2/3)*_
+--   a^(1/3)*f))/(a^(4/3)*((-1)^(1/3)*b^(1/3)*e+a^(1/3)*f)*(1+n))
+--E 935
+
+--S 936 of 953
+--a0:=integrate(t0,x)
+--E 936
+
+--S 937 of 953
+--m0:=a0-r0
+--E 937
+
+--S 938 of 953
+--d0:=D(m0,x)
+--E 938
+
+)clear all
+
+--S 939 of 953
+t0:=x^2*(c+d*x)^(1+n)/(a+b*x^3)
+--R 
+--R
+--R         2         n + 1
+--R        x (d x + c)
+--R   (1)  ----------------
+--R               3
+--R            b x  + a
+--R                                                    Type: Expression(Integer)
+--E 939
+
+--S 940 of 953
+--r0:=-1/3*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/3)*(c+d*x)/_
+--   (b^(1/3)*c-a^(1/3)*d))/(b^(2/3)*(b^(1/3)*c-a^(1/3)*d)*(2+n))-_
+--   1/3*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/3)*(c+d*x)/(b^(1/3)*_
+--   c+(-1)^(1/3)*a^(1/3)*d))/(b^(2/3)*(b^(1/3)*c+(-1)^(1/3)*a^(1/3)*d)*_
+--   (2+n))-1/3*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/3)*(c+d*x)/_
+--   (b^(1/3)*c-(-1)^(2/3)*a^(1/3)*d))/(b^(2/3)*(b^(1/3)*c-(-1)^(2/3)*_
+--   a^(1/3)*d)*(2+n))
+--E 940
+
+--S 941 of 953
+--a0:=integrate(t0,x)
+--E 941
+
+--S 942 of 953
+--m0:=a0-r0
+--E 942
+
+--S 943 of 953
+--d0:=D(m0,x)
+--E 943
+
+)clear all
+
+--S 944 of 953
+t0:=x^3*(c+d*x)^n/(a+b*x^4)
+--R 
+--R
+--R         3         n
+--R        x (d x + c)
+--R   (1)  ------------
+--R             4
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 944
+
+--S 945 of 953
+--r0:=-1/4*(c+d*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/4)*(c+d*x)/_
+--   (b^(1/4)*c-(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c-(-a)^(1/4)*d)*(1+n))-_
+--   1/4*(c+d*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c-%i*(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c-%i*(-a)^(1/4)*d)*(1+n))-_
+--   1/4*(c+d*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c+%i*(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c+%i*(-a)^(1/4)*d)*(1+n))-_
+--   1/4*(c+d*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c+(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c+(-a)^(1/4)*d)*(1+n))
+--E 945
+
+--S 946 of 953
+--a0:=integrate(t0,x)
+--E 946
+
+--S 947 of 953
+--m0:=a0-r0
+--E 947
+
+--S 948 of 953
+--d0:=D(m0,x)
+--E 948
+
+)clear all
+
+--S 949 of 953
+t0:=x^3*(c+d*x)^(1+n)/(a+b*x^4)
+--R 
+--R
+--R         3         n + 1
+--R        x (d x + c)
+--R   (1)  ----------------
+--R               4
+--R            b x  + a
+--R                                                    Type: Expression(Integer)
+--E 949
+
+--S 950 of 953
+--r0:=-1/4*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/4)*(c+d*x)/_
+--   (b^(1/4)*c-(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c-(-a)^(1/4)*d)*(2+n))-_
+--   1/4*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c-%i*(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c-%i*(-a)^(1/4)*d)*(2+n))-_
+--   1/4*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c+%i*(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c+%i*(-a)^(1/4)*d)*(2+n))-_
+--   1/4*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c+(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c+(-a)^(1/4)*d)*(2+n))
+--E 950
+
+--S 951 of 953
+--a0:=integrate(t0,x)
+--E 951
+
+--S 952 of 953
+--m0:=a0-r0
+--E 952
+
+--S 953 of 953
+--d0:=D(m0,x)
+--E 953
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich24a.input.pamphlet b/src/input/rich24a.input.pamphlet
new file mode 100644
index 0000000..b4361b9
--- /dev/null
+++ b/src/input/rich24a.input.pamphlet
@@ -0,0 +1,9533 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich24a.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Exponential Functions
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich24a.output
+)spool rich24a.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^m
+--R 
+--R
+--R         b c x + a c         m
+--R   (1)  F           (e x + d)
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)^(1+m)*GAMMA(1+m,-b*c*(d+e*x)*log(F)/e)*_
+--  (-b*c*(d+e*x)*log(F)/e)^(-1-m)/e
+--E 2
+
+--S 3 of 1000
+--a0:=integrate(t0,x)
+--E 3
+
+--S 4 of 1000
+--m0:=a0-r0
+--E 4
+
+--S 5 of 1000
+--d0:=normalize(D(m0,x))
+--E 5
+
+)clear all
+
+--S 6 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^5
+--R 
+--R
+--R          5 5       4 4      2 3 3      3 2 2     4       5  b c x + a c
+--R   (1)  (e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 1000
+--r0:=-e^5*F^(c*(a-b*d/e))*GAMMA(6,-b*c*(d+e*x)*log(F)/e)/(b^6*c^6*log(F)^6)
+--E 7
+
+--S 8 of 1000
+--a0:=integrate(t0,x)
+--E 8
+
+--S 9 of 1000
+--m0:=a0-r0
+--E 9
+
+--S 10 of 1000
+--d0:=normalize(D(m0,x))
+--E 10
+
+)clear all
+
+--S 11 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b c x + a c
+--R   (1)  (e x  + 4d e x  + 6d e x  + 4d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1000
+--r0:=e^4*F^(c*(a-b*d/e))*GAMMA(5,-b*c*(d+e*x)*log(F)/e)/(b^5*c^5*log(F)^5)
+--E 12
+
+--S 13 of 1000
+--a0:=integrate(t0,x)
+--E 13
+
+--S 14 of 1000
+--m0:=a0-r0
+--E 14
+
+--S 15 of 1000
+--d0:=normalize(D(m0,x))
+--E 15
+
+)clear all
+
+--S 16 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^3
+--R 
+--R
+--R          3 3       2 2     2       3  b c x + a c
+--R   (1)  (e x  + 3d e x  + 3d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1000
+r0:=-6*e^3*F^(c*(a+b*x))/(b^4*c^4*log(F)^4)+6*e^2*F^(c*(a+b*x))*_
+   (d+e*x)/(b^3*c^3*log(F)^3)-3*e*F^(c*(a+b*x))*(d+e*x)^2/(b^2*c^2*_
+   log(F)^2)+F^(c*(a+b*x))*(d+e*x)^3/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R           3 3 3 3     3 3   2 2     3 3 2       3 3 3       3
+--R         (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F)
+--R       + 
+--R              2 2 3 2     2 2   2      2 2 2        2
+--R         (- 3b c e x  - 6b c d e x - 3b c d e)log(F)
+--R       + 
+--R                3            2            3
+--R         (6b c e x + 6b c d e )log(F) - 6e
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 3 3 3     3 3   2 2     3 3 2       3 3 3       3
+--R         (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F)
+--R       + 
+--R              2 2 3 2     2 2   2      2 2 2        2
+--R         (- 3b c e x  - 6b c d e x - 3b c d e)log(F)
+--R       + 
+--R                3            2            3
+--R         (6b c e x + 6b c d e )log(F) - 6e
+--R    *
+--R         (b c x + a c)log(F)
+--R       %e
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3 3 3 3     3 3   2 2     3 3 2       3 3 3       3
+--R           (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F)
+--R         + 
+--R                2 2 3 2     2 2   2      2 2 2        2
+--R           (- 3b c e x  - 6b c d e x - 3b c d e)log(F)
+--R         + 
+--R                  3            2            3
+--R           (6b c e x + 6b c d e )log(F) - 6e
+--R      *
+--R           (b c x + a c)log(F)
+--R         %e
+--R     + 
+--R               3 3 3 3     3 3   2 2     3 3 2       3 3 3       3
+--R           (- b c e x  - 3b c d e x  - 3b c d e x - b c d )log(F)
+--R         + 
+--R              2 2 3 2     2 2   2      2 2 2        2
+--R           (3b c e x  + 6b c d e x + 3b c d e)log(F)
+--R         + 
+--R                    3            2            3
+--R           (- 6b c e x - 6b c d e )log(F) + 6e
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^2
+--R 
+--R
+--R          2 2             2  b c x + a c
+--R   (1)  (e x  + 2d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 1000
+r0:=2*e^2*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)-2*e*F^(c*(a+b*x))*(d+e*x)/_
+   (b^2*c^2*log(F)^2)+F^(c*(a+b*x))*(d+e*x)^2/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R           2 2 2 2     2 2         2 2 2       2            2
+--R         (b c e x  + 2b c d e x + b c d )log(F)  + (- 2b c e x - 2b c d e)log(F)
+--R       + 
+--R           2
+--R         2e
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 2 2 2     2 2         2 2 2       2            2
+--R         (b c e x  + 2b c d e x + b c d )log(F)  + (- 2b c e x - 2b c d e)log(F)
+--R       + 
+--R           2
+--R         2e
+--R    *
+--R         (b c x + a c)log(F)
+--R       %e
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 23
+
+--S 24 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2 2 2 2     2 2         2 2 2       2
+--R           (b c e x  + 2b c d e x + b c d )log(F)
+--R         + 
+--R                    2                        2
+--R           (- 2b c e x - 2b c d e)log(F) + 2e
+--R      *
+--R           (b c x + a c)log(F)
+--R         %e
+--R     + 
+--R               2 2 2 2     2 2         2 2 2       2
+--R           (- b c e x  - 2b c d e x - b c d )log(F)
+--R         + 
+--R                  2                        2
+--R           (2b c e x + 2b c d e)log(F) - 2e
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 25
+
+)clear all
+
+--S 26 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)
+--R 
+--R
+--R                  b c x + a c
+--R   (1)  (e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1000
+r0:=-e*F^(c*(a+b*x))/(b^2*c^2*log(F)^2)+F^(c*(a+b*x))*(d+e*x)/(b*c*log(F))
+--R 
+--R
+--R                                      b c x + a c
+--R        ((b c e x + b c d)log(F) - e)F
+--R   (2)  -----------------------------------------
+--R                        2 2      2
+--R                       b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                       (b c x + a c)log(F)
+--R        ((b c e x + b c d)log(F) - e)%e
+--R   (3)  --------------------------------------------------
+--R                             2 2      2
+--R                            b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 28
+
+--S 29 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      (b c x + a c)log(F)
+--R       ((b c e x + b c d)log(F) - e)%e
+--R     + 
+--R                                       b c x + a c
+--R       ((- b c e x - b c d)log(F) + e)F
+--R  /
+--R      2 2      2
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 1000
+t0:=F^(c*(a+b*x))
+--R 
+--R
+--R         b c x + a c
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 1000
+r0:=F^(c*(a+b*x))/(b*c*log(F))
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (2)  ------------
+--R         b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R          (b c x + a c)log(F)
+--R        %e
+--R   (3)  ---------------------
+--R              b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 33
+
+--S 34 of 1000
+m0:=a0-r0
+--R 
+--R
+--R          (b c x + a c)log(F)    b c x + a c
+--R        %e                    - F
+--R   (4)  ------------------------------------
+--R                     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 35
+
+)clear all
+
+--S 36 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (1)  ------------
+--R           e x + d
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 1000
+r0:=F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*log(F)/e)/e
+--R 
+--R
+--R         a c e - b c d
+--R         -------------
+--R               e         (b c e x + b c d)log(F)
+--R        F             Ei(-----------------------)
+--R                                    e
+--R   (2)  -----------------------------------------
+--R                            e
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x  (%D b + a)c
+--R         ++  F
+--R   (3)   |   ------------ d%D
+--R        ++     %D e + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 38
+
+--S 39 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                                   a c e - b c d
+--R            x  (%D b + a)c         -------------
+--R          ++  F                          e         (b c e x + b c d)log(F)
+--R        e |   ------------ d%D  - F             Ei(-----------------------)
+--R         ++     %D e + d                                      e
+--R   (4)  -------------------------------------------------------------------
+--R                                         e
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 40
+
+)clear all
+
+--S 41 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^2
+--R 
+--R
+--R            b c x + a c
+--R           F
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 1000
+r0:=-F^(c*(a+b*x))/(e*(d+e*x))+b*c*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*_
+   log(F)/e)*log(F)/e^2
+--R 
+--R
+--R   (2)
+--R                               a c e - b c d
+--R                               -------------
+--R                                     e         (b c e x + b c d)log(F)
+--R       (b c e x + b c d)log(F)F             Ei(-----------------------)
+--R                                                          e
+--R     + 
+--R            b c x + a c
+--R       - e F
+--R  /
+--R      3       2
+--R     e x + d e
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x      (%D b + a)c
+--R         ++      F
+--R   (3)   |   -------------------- d%D
+--R        ++     2 2              2
+--R             %D e  + 2%D d e + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 43
+
+--S 44 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      x      (%D b + a)c
+--R         3       2  ++      F
+--R       (e x + d e ) |   -------------------- d%D
+--R                   ++     2 2              2
+--R                        %D e  + 2%D d e + d
+--R     + 
+--R                                 a c e - b c d
+--R                                 -------------
+--R                                       e         (b c e x + b c d)log(F)
+--R       (- b c e x - b c d)log(F)F             Ei(-----------------------)
+--R                                                            e
+--R     + 
+--R          b c x + a c
+--R       e F
+--R  /
+--R      3       2
+--R     e x + d e
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^3
+--R 
+--R
+--R                 b c x + a c
+--R                F
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 1000
+r0:=-1/2*F^(c*(a+b*x))/(e*(d+e*x)^2)-1/2*b*c*F^(c*(a+b*x))*_
+   log(F)/(e^2*(d+e*x))+1/2*b^2*c^2*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*_
+   log(F)/e)*log(F)^2/e^3
+--R 
+--R
+--R   (2)
+--R                                                 a c e - b c d
+--R                                                 -------------
+--R           2 2 2 2     2 2         2 2 2       2       e
+--R         (b c e x  + 2b c d e x + b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R                2                      2  b c x + a c
+--R       ((- b c e x - b c d e)log(F) - e )F
+--R  /
+--R       5 2       4      2 3
+--R     2e x  + 4d e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x            (%D b + a)c
+--R         ++            F
+--R   (3)   |   ------------------------------- d%D
+--R        ++     3 3      2   2        2     3
+--R             %D e  + 3%D d e  + 3%D d e + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  x            (%D b + a)c
+--R          5 2       4      2 3  ++            F
+--R       (2e x  + 4d e x + 2d e ) |   ------------------------------- d%D
+--R                               ++     3 3      2   2        2     3
+--R                                    %D e  + 3%D d e  + 3%D d e + d
+--R     + 
+--R                                                   a c e - b c d
+--R                                                   -------------
+--R             2 2 2 2     2 2         2 2 2       2       e
+--R         (- b c e x  - 2b c d e x - b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R              2                      2  b c x + a c
+--R       ((b c e x + b c d e)log(F) + e )F
+--R  /
+--R       5 2       4      2 3
+--R     2e x  + 4d e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^4
+--R 
+--R
+--R                      b c x + a c
+--R                     F
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 1000
+r0:=-1/3*F^(c*(a+b*x))/(e*(d+e*x)^3)-1/6*b*c*F^(c*(a+b*x))*log(F)/(e^2*_
+   (d+e*x)^2)-1/6*b^2*c^2*F^(c*(a+b*x))*log(F)^2/(e^3*(d+e*x))+_
+   1/6*b^3*c^3*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*log(F)/e)*log(F)^3/e^4
+--R 
+--R
+--R   (2)
+--R                                                               a c e - b c d
+--R                                                               -------------
+--R           3 3 3 3     3 3   2 2     3 3 2       3 3 3       3       e
+--R         (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R               2 2 3 2     2 2   2     2 2 2        2
+--R           (- b c e x  - 2b c d e x - b c d e)log(F)
+--R         + 
+--R                   3           2            3
+--R           (- b c e x - b c d e )log(F) - 2e
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R       7 3        6 2      2 5      3 4
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x                 (%D b + a)c
+--R         ++                 F
+--R   (3)   |   ------------------------------------------ d%D
+--R        ++     4 4      3   3      2 2 2        3     4
+--R             %D e  + 4%D d e  + 6%D d e  + 4%D d e + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 53
+
+--S 54 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            7 3        6 2      2 5      3 4
+--R         (6e x  + 18d e x  + 18d e x + 6d e )
+--R      *
+--R            x                 (%D b + a)c
+--R          ++                 F
+--R          |   ------------------------------------------ d%D
+--R         ++     4 4      3   3      2 2 2        3     4
+--R              %D e  + 4%D d e  + 6%D d e  + 4%D d e + d
+--R     + 
+--R                                                                 a c e - b c d
+--R                                                                 -------------
+--R             3 3 3 3     3 3   2 2     3 3 2       3 3 3       3       e
+--R         (- b c e x  - 3b c d e x  - 3b c d e x - b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R             2 2 3 2     2 2   2     2 2 2        2         3           2
+--R           (b c e x  + 2b c d e x + b c d e)log(F)  + (b c e x + b c d e )log(F)
+--R         + 
+--R             3
+--R           2e
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R       7 3        6 2      2 5      3 4
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 55
+
+)clear all
+
+--S 56 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^5
+--R 
+--R
+--R                            b c x + a c
+--R                           F
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1000
+--r0:=-b^4*c^4*F^(c*(a-b*d/e))*GAMMA(-4,-b*c*(d+e*x)*log(F)/e)*log(F)^4/e^5
+--E 57
+
+--S 58 of 1000
+--a0:=integrate(t0,x)
+--E 58
+
+--S 59 of 1000
+--m0:=a0-r0
+--E 59
+
+--S 60 of 1000
+--d0:=normalize(D(m0,x))
+--E 60
+
+)clear all
+
+--S 61 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^6
+--R 
+--R
+--R                                  b c x + a c
+--R                                 F
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 1000
+--r0:=b^5*c^5*F^(c*(a-b*d/e))*GAMMA(-5,-b*c*(d+e*x)*log(F)/e)*log(F)^5/e^6
+--E 62
+
+--S 63 of 1000
+--a0:=integrate(t0,x)
+--E 63
+
+--S 64 of 1000
+--m0:=a0-r0
+--E 64
+
+--S 65 of 1000
+--d0:=normalize(D(m0,x))
+--E 65
+
+)clear all
+
+--S 66 of 1000
+t0:=F^(c*(a+b*x))*(d^5+5*d^4*e*x+10*d^3*e^2*x^2+10*d^2*e^3*x^3+_
+   5*d*e^4*x^4+e^5*x^5)
+--R 
+--R
+--R          5 5       4 4      2 3 3      3 2 2     4       5  b c x + a c
+--R   (1)  (e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 1000
+--r0:=-e^5*F^(c*(a-b*d/e))*GAMMA(6,-b*c*(d+e*x)*log(F)/e)/(b^6*c^6*log(F)^6)
+--E 67
+
+--S 68 of 1000
+--a0:=integrate(t0,x)
+--E 68
+
+--S 69 of 1000
+--m0:=a0-r0
+--E 69
+
+--S 70 of 1000
+--d0:=normalize(D(m0,x))
+--E 70
+
+)clear all
+
+--S 71 of 1000
+t0:=F^(c*(a+b*x))*(d^4+4*d^3*e*x+6*d^2*e^2*x^2+4*d*e^3*x^3+e^4*x^4)
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b c x + a c
+--R   (1)  (e x  + 4d e x  + 6d e x  + 4d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1000
+--r0:=e^4*F^(c*(a-b*d/e))*GAMMA(5,-b*c*(d+e*x)*log(F)/e)/(b^5*c^5*log(F)^5)
+--E 72
+
+--S 73 of 1000
+--a0:=integrate(t0,x)
+--E 73
+
+--S 74 of 1000
+--m0:=a0-r0
+--E 74
+
+--S 75 of 1000
+--d0:=normalize(D(m0,x))
+--E 75
+
+)clear all
+
+--S 76 of 1000
+t0:=F^(c*(a+b*x))*(d^3+3*d^2*e*x+3*d*e^2*x^2+e^3*x^3)
+--R 
+--R
+--R          3 3       2 2     2       3  b c x + a c
+--R   (1)  (e x  + 3d e x  + 3d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 1000
+r0:=-6*e^3*F^(c*(a+b*x))/(b^4*c^4*log(F)^4)+6*e^2*F^(c*(a+b*x))*(d+e*x)/_
+   (b^3*c^3*log(F)^3)-3*e*F^(c*(a+b*x))*(d+e*x)^2/(b^2*c^2*log(F)^2)+_
+   F^(c*(a+b*x))*(d+e*x)^3/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R           3 3 3 3     3 3   2 2     3 3 2       3 3 3       3
+--R         (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F)
+--R       + 
+--R              2 2 3 2     2 2   2      2 2 2        2
+--R         (- 3b c e x  - 6b c d e x - 3b c d e)log(F)
+--R       + 
+--R                3            2            3
+--R         (6b c e x + 6b c d e )log(F) - 6e
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 3 3 3     3 3   2 2     3 3 2       3 3 3       3
+--R         (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F)
+--R       + 
+--R              2 2 3 2     2 2   2      2 2 2        2
+--R         (- 3b c e x  - 6b c d e x - 3b c d e)log(F)
+--R       + 
+--R                3            2            3
+--R         (6b c e x + 6b c d e )log(F) - 6e
+--R    *
+--R         (b c x + a c)log(F)
+--R       %e
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 78
+
+--S 79 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3 3 3 3     3 3   2 2     3 3 2       3 3 3       3
+--R           (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F)
+--R         + 
+--R                2 2 3 2     2 2   2      2 2 2        2
+--R           (- 3b c e x  - 6b c d e x - 3b c d e)log(F)
+--R         + 
+--R                  3            2            3
+--R           (6b c e x + 6b c d e )log(F) - 6e
+--R      *
+--R           (b c x + a c)log(F)
+--R         %e
+--R     + 
+--R               3 3 3 3     3 3   2 2     3 3 2       3 3 3       3
+--R           (- b c e x  - 3b c d e x  - 3b c d e x - b c d )log(F)
+--R         + 
+--R              2 2 3 2     2 2   2      2 2 2        2
+--R           (3b c e x  + 6b c d e x + 3b c d e)log(F)
+--R         + 
+--R                    3            2            3
+--R           (- 6b c e x - 6b c d e )log(F) + 6e
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 80
+
+)clear all
+
+--S 81 of 1000
+t0:=F^(c*(a+b*x))*(d^2+2*d*e*x+e^2*x^2)
+--R 
+--R
+--R          2 2             2  b c x + a c
+--R   (1)  (e x  + 2d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 1000
+r0:=2*e^2*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)-2*e*F^(c*(a+b*x))*(d+e*x)/_
+   (b^2*c^2*log(F)^2)+F^(c*(a+b*x))*(d+e*x)^2/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R           2 2 2 2     2 2         2 2 2       2            2
+--R         (b c e x  + 2b c d e x + b c d )log(F)  + (- 2b c e x - 2b c d e)log(F)
+--R       + 
+--R           2
+--R         2e
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 2 2 2     2 2         2 2 2       2            2
+--R         (b c e x  + 2b c d e x + b c d )log(F)  + (- 2b c e x - 2b c d e)log(F)
+--R       + 
+--R           2
+--R         2e
+--R    *
+--R         (b c x + a c)log(F)
+--R       %e
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 83
+
+--S 84 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2 2 2 2     2 2         2 2 2       2
+--R           (b c e x  + 2b c d e x + b c d )log(F)
+--R         + 
+--R                    2                        2
+--R           (- 2b c e x - 2b c d e)log(F) + 2e
+--R      *
+--R           (b c x + a c)log(F)
+--R         %e
+--R     + 
+--R               2 2 2 2     2 2         2 2 2       2
+--R           (- b c e x  - 2b c d e x - b c d )log(F)
+--R         + 
+--R                  2                        2
+--R           (2b c e x + 2b c d e)log(F) - 2e
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)
+--R 
+--R
+--R                  b c x + a c
+--R   (1)  (e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 1000
+r0:=-e*F^(c*(a+b*x))/(b^2*c^2*log(F)^2)+F^(c*(a+b*x))*(d+e*x)/(b*c*log(F))
+--R 
+--R
+--R                                      b c x + a c
+--R        ((b c e x + b c d)log(F) - e)F
+--R   (2)  -----------------------------------------
+--R                        2 2      2
+--R                       b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                       (b c x + a c)log(F)
+--R        ((b c e x + b c d)log(F) - e)%e
+--R   (3)  --------------------------------------------------
+--R                             2 2      2
+--R                            b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 88
+
+--S 89 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      (b c x + a c)log(F)
+--R       ((b c e x + b c d)log(F) - e)%e
+--R     + 
+--R                                       b c x + a c
+--R       ((- b c e x - b c d)log(F) + e)F
+--R  /
+--R      2 2      2
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 1000
+t0:=F^(c*(a+b*x))
+--R 
+--R
+--R         b c x + a c
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1000
+r0:=F^(c*(a+b*x))/(b*c*log(F))
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (2)  ------------
+--R         b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R          (b c x + a c)log(F)
+--R        %e
+--R   (3)  ---------------------
+--R              b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 93
+
+--S 94 of 1000
+m0:=a0-r0
+--R 
+--R
+--R          (b c x + a c)log(F)    b c x + a c
+--R        %e                    - F
+--R   (4)  ------------------------------------
+--R                     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 95
+
+)clear all
+
+--S 96 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (1)  ------------
+--R           e x + d
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 1000
+r0:=F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*log(F)/e)/e
+--R 
+--R
+--R         a c e - b c d
+--R         -------------
+--R               e         (b c e x + b c d)log(F)
+--R        F             Ei(-----------------------)
+--R                                    e
+--R   (2)  -----------------------------------------
+--R                            e
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x  (%D b + a)c
+--R         ++  F
+--R   (3)   |   ------------ d%D
+--R        ++     %D e + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 98
+
+--S 99 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                                   a c e - b c d
+--R            x  (%D b + a)c         -------------
+--R          ++  F                          e         (b c e x + b c d)log(F)
+--R        e |   ------------ d%D  - F             Ei(-----------------------)
+--R         ++     %D e + d                                      e
+--R   (4)  -------------------------------------------------------------------
+--R                                         e
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 100
+
+)clear all
+
+--S 101 of 1000
+t0:=F^(c*(a+b*x))/(d^2+2*d*e*x+e^2*x^2)
+--R 
+--R
+--R            b c x + a c
+--R           F
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1000
+r0:=-F^(c*(a+b*x))/(e*(d+e*x))+b*c*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*_
+   log(F)/e)*log(F)/e^2
+--R 
+--R
+--R   (2)
+--R                               a c e - b c d
+--R                               -------------
+--R                                     e         (b c e x + b c d)log(F)
+--R       (b c e x + b c d)log(F)F             Ei(-----------------------)
+--R                                                          e
+--R     + 
+--R            b c x + a c
+--R       - e F
+--R  /
+--R      3       2
+--R     e x + d e
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x      (%D b + a)c
+--R         ++      F
+--R   (3)   |   -------------------- d%D
+--R        ++     2 2              2
+--R             %D e  + 2%D d e + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 103
+
+--S 104 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      x      (%D b + a)c
+--R         3       2  ++      F
+--R       (e x + d e ) |   -------------------- d%D
+--R                   ++     2 2              2
+--R                        %D e  + 2%D d e + d
+--R     + 
+--R                                 a c e - b c d
+--R                                 -------------
+--R                                       e         (b c e x + b c d)log(F)
+--R       (- b c e x - b c d)log(F)F             Ei(-----------------------)
+--R                                                            e
+--R     + 
+--R          b c x + a c
+--R       e F
+--R  /
+--R      3       2
+--R     e x + d e
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 1000
+t0:=F^(c*(a+b*x))/(d^3+3*d^2*e*x+3*d*e^2*x^2+e^3*x^3)
+--R 
+--R
+--R                 b c x + a c
+--R                F
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 1000
+r0:=-1/2*F^(c*(a+b*x))/(e*(d+e*x)^2)-1/2*b*c*F^(c*(a+b*x))*log(F)/_
+   (e^2*(d+e*x))+1/2*b^2*c^2*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*log(F)/e)*_
+   log(F)^2/e^3
+--R 
+--R
+--R   (2)
+--R                                                 a c e - b c d
+--R                                                 -------------
+--R           2 2 2 2     2 2         2 2 2       2       e
+--R         (b c e x  + 2b c d e x + b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R                2                      2  b c x + a c
+--R       ((- b c e x - b c d e)log(F) - e )F
+--R  /
+--R       5 2       4      2 3
+--R     2e x  + 4d e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x            (%D b + a)c
+--R         ++            F
+--R   (3)   |   ------------------------------- d%D
+--R        ++     3 3      2   2        2     3
+--R             %D e  + 3%D d e  + 3%D d e + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 108
+
+--S 109 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  x            (%D b + a)c
+--R          5 2       4      2 3  ++            F
+--R       (2e x  + 4d e x + 2d e ) |   ------------------------------- d%D
+--R                               ++     3 3      2   2        2     3
+--R                                    %D e  + 3%D d e  + 3%D d e + d
+--R     + 
+--R                                                   a c e - b c d
+--R                                                   -------------
+--R             2 2 2 2     2 2         2 2 2       2       e
+--R         (- b c e x  - 2b c d e x - b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R              2                      2  b c x + a c
+--R       ((b c e x + b c d e)log(F) + e )F
+--R  /
+--R       5 2       4      2 3
+--R     2e x  + 4d e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 110
+
+)clear all
+
+--S 111 of 1000
+t0:=F^(c*(a+b*x))/(d^4+4*d^3*e*x+6*d^2*e^2*x^2+4*d*e^3*x^3+e^4*x^4)
+--R 
+--R
+--R                      b c x + a c
+--R                     F
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 1000
+r0:=-1/3*F^(c*(a+b*x))/(e*(d+e*x)^3)-1/6*b*c*F^(c*(a+b*x))*log(F)/_
+   (e^2*(d+e*x)^2)-1/6*b^2*c^2*F^(c*(a+b*x))*log(F)^2/(e^3*(d+e*x))+_
+   1/6*b^3*c^3*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*log(F)/e)*log(F)^3/e^4
+--R 
+--R
+--R   (2)
+--R                                                               a c e - b c d
+--R                                                               -------------
+--R           3 3 3 3     3 3   2 2     3 3 2       3 3 3       3       e
+--R         (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R               2 2 3 2     2 2   2     2 2 2        2
+--R           (- b c e x  - 2b c d e x - b c d e)log(F)
+--R         + 
+--R                   3           2            3
+--R           (- b c e x - b c d e )log(F) - 2e
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R       7 3        6 2      2 5      3 4
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x                 (%D b + a)c
+--R         ++                 F
+--R   (3)   |   ------------------------------------------ d%D
+--R        ++     4 4      3   3      2 2 2        3     4
+--R             %D e  + 4%D d e  + 6%D d e  + 4%D d e + d
+--R                                         Type: Union(Expression(Integer),...)
+--E 113
+
+--S 114 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            7 3        6 2      2 5      3 4
+--R         (6e x  + 18d e x  + 18d e x + 6d e )
+--R      *
+--R            x                 (%D b + a)c
+--R          ++                 F
+--R          |   ------------------------------------------ d%D
+--R         ++     4 4      3   3      2 2 2        3     4
+--R              %D e  + 4%D d e  + 6%D d e  + 4%D d e + d
+--R     + 
+--R                                                                 a c e - b c d
+--R                                                                 -------------
+--R             3 3 3 3     3 3   2 2     3 3 2       3 3 3       3       e
+--R         (- b c e x  - 3b c d e x  - 3b c d e x - b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R             2 2 3 2     2 2   2     2 2 2        2         3           2
+--R           (b c e x  + 2b c d e x + b c d e)log(F)  + (b c e x + b c d e )log(F)
+--R         + 
+--R             3
+--R           2e
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R       7 3        6 2      2 5      3 4
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 115
+
+)clear all
+
+--S 116 of 1000
+t0:=F^(c*(a+b*x))/(d^5+5*d^4*e*x+10*d^3*e^2*x^2+10*d^2*e^3*x^3+_
+   5*d*e^4*x^4+e^5*x^5)
+--R 
+--R
+--R                            b c x + a c
+--R                           F
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1000
+--r0:=-b^4*c^4*F^(c*(a-b*d/e))*GAMMA(-4,-b*c*(d+e*x)*log(F)/e)*log(F)^4/e^5
+--E 117
+
+--S 118 of 1000
+--a0:=integrate(t0,x)
+--E 118
+
+--S 119 of 1000
+--m0:=a0-r0
+--E 119
+
+--S 120 of 1000
+--d0:=normalize(D(m0,x))
+--E 120
+
+)clear all
+
+--S 121 of 1000
+t0:=F^(c*(a+b*x))/(d^6+6*d^5*e*x+15*d^4*e^2*x^2+20*d^3*e^3*x^3+_
+   15*d^2*e^4*x^4+6*d*e^5*x^5+e^6*x^6)
+--R 
+--R
+--R                                  b c x + a c
+--R                                 F
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1000
+--r0:=b^5*c^5*F^(c*(a-b*d/e))*GAMMA(-5,-b*c*(d+e*x)*log(F)/e)*log(F)^5/e^6
+--E 122
+
+--S 123 of 1000
+--a0:=integrate(t0,x)
+--E 123
+
+--S 124 of 1000
+--m0:=a0-r0
+--E 124
+
+--S 125 of 1000
+--d0:=normalize(D(m0,x))
+--E 125
+
+)clear all
+
+--S 126 of 1000
+t0:=F^(c*(a+b*x))*((d+e*x)^n)^m
+--R 
+--R
+--R         b c x + a c         m n
+--R   (1)  F           (e x + d)
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*((d+e*x)^n)^m*GAMMA(1+m*n,-b*c*(d+e*x)*_
+--  log(F)/e)*(-b*c*(d+e*x)*log(F)/e)^(-1-m*n)/e
+--E 127
+
+--S 128 of 1000
+--a0:=integrate(t0,x)
+--E 128
+
+--S 129 of 1000
+--m0:=a0-r0
+--E 129
+
+--S 130 of 1000
+--d0:=normalize(D(m0,x))
+--E 130
+
+)clear all
+
+--S 131 of 1000
+t0:=F^(c*(a+b*x))*(d^4+4*d^3*e*x+6*d^2*e^2*x^2+4*d*e^3*x^3+e^4*x^4)^m
+--R 
+--R
+--R         b c x + a c  4 4       3 3     2 2 2     3       4 m
+--R   (1)  F           (e x  + 4d e x  + 6d e x  + 4d e x + d )
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*((d+e*x)^4)^m*GAMMA(1+4*m,-b*c*(d+e*x)*_
+--  log(F)/e)*(-b*c*(d+e*x)*log(F)/e)^(-1-4*m)/e
+--E 132
+
+--S 133 of 1000
+--a0:=integrate(t0,x)
+--E 133
+
+--S 134 of 1000
+--m0:=a0-r0
+--E 134
+
+--S 135 of 1000
+--d0:=normalize(D(m0,x))
+--E 135
+
+)clear all
+
+--S 136 of 1000
+t0:=F^(c*(a+b*x))*(d^3+3*d^2*e*x+3*d*e^2*x^2+e^3*x^3)^m
+--R 
+--R
+--R         b c x + a c  3 3       2 2     2       3 m
+--R   (1)  F           (e x  + 3d e x  + 3d e x + d )
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*((d+e*x)^3)^m*GAMMA(1+3*m,-b*c*(d+e*x)*_
+--  log(F)/e)*(-b*c*(d+e*x)*log(F)/e)^(-1-3*m)/e
+--E 137
+
+--S 138 of 1000
+--a0:=integrate(t0,x)
+--E 138
+
+--S 139 of 1000
+--m0:=a0-r0
+--E 139
+
+--S 140 of 1000
+--d0:=normalize(D(m0,x))
+--E 140
+
+)clear all
+
+--S 141 of 1000
+t0:=F^(c*(a+b*x))*(d^2+2*d*e*x+e^2*x^2)^m
+--R 
+--R
+--R         b c x + a c  2 2             2 m
+--R   (1)  F           (e x  + 2d e x + d )
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*((d+e*x)^2)^m*GAMMA(1+2*m,-b*c*(d+e*x)*_
+--  log(F)/e)*(-b*c*(d+e*x)*log(F)/e)^(-1-2*m)/e
+--E 142
+
+--S 143 of 1000
+--a0:=integrate(t0,x)
+--E 143
+
+--S 144 of 1000
+--m0:=a0-r0
+--E 144
+
+--S 145 of 1000
+--d0:=normalize(D(m0,x))
+--E 145
+
+)clear all
+
+--S 146 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^m
+--R 
+--R
+--R         b c x + a c         m
+--R   (1)  F           (e x + d)
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)^(1+m)*GAMMA(1+m,-b*c*(d+e*x)*log(F)/e)*_
+--  (-b*c*(d+e*x)*log(F)/e)^(-1-m)/e
+--E 147
+
+--S 148 of 1000
+--a0:=integrate(t0,x)
+--E 148
+
+--S 149 of 1000
+--m0:=a0-r0
+--E 149
+
+--S 150 of 1000
+--d0:=normalize(D(m0,x))
+--E 150
+
+)clear all
+
+--S 151 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^m
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (1)  ------------
+--R                  m
+--R         (e x + d)
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)^(1-m)*GAMMA(1-m,-b*c*(d+e*x)*log(F)/e)*_
+--  (-b*c*(d+e*x)*log(F)/e)^(-1+m)/e
+--E 152
+
+--S 153 of 1000
+--a0:=integrate(t0,x)
+--E 153
+
+--S 154 of 1000
+--m0:=a0-r0
+--E 154
+
+--S 155 of 1000
+--d0:=normalize(D(m0,x))
+--E 155
+
+)clear all
+
+--S 156 of 1000
+t0:=F^(c*(a+b*x))/(d^2+2*d*e*x+e^2*x^2)^m
+--R 
+--R
+--R              b c x + a c
+--R             F
+--R   (1)  ---------------------
+--R          2 2             2 m
+--R        (e x  + 2d e x + d )
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*GAMMA(1-2*m,-b*c*(d+e*x)*log(F)/e)*_
+--  (-b*c*(d+e*x)*log(F)/e)^(-1+2*m)/(e*((d+e*x)^2)^m)
+--E 157
+
+--S 158 of 1000
+--a0:=integrate(t0,x)
+--E 158
+
+--S 159 of 1000
+--m0:=a0-r0
+--E 159
+
+--S 160 of 1000
+--d0:=normalize(D(m0,x))
+--E 160
+
+)clear all
+
+--S 161 of 1000
+t0:=F^(c*(a+b*x))/(d^3+3*d^2*e*x+3*d*e^2*x^2+e^3*x^3)^m
+--R 
+--R
+--R                   b c x + a c
+--R                  F
+--R   (1)  -------------------------------
+--R          3 3       2 2     2       3 m
+--R        (e x  + 3d e x  + 3d e x + d )
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*GAMMA(1-3*m,-b*c*(d+e*x)*log(F)/e)*_
+--  (-b*c*(d+e*x)*log(F)/e)^(-1+3*m)/(e*((d+e*x)^3)^m)
+--E 162
+
+--S 163 of 1000
+--a0:=integrate(t0,x)
+--E 163
+
+--S 164 of 1000
+--m0:=a0-r0
+--E 164
+
+--S 165 of 1000
+--d0:=normalize(D(m0,x))
+--E 165
+
+)clear all
+
+--S 166 of 1000
+t0:=f^(2+5*x)
+--R 
+--R
+--R         5x + 2
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 1000
+r0:=1/5*f^(2+5*x)/log(f)
+--R 
+--R
+--R         5x + 2
+--R        f
+--R   (2)  -------
+--R        5log(f)
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R          (5x + 2)log(f)
+--R        %e
+--R   (3)  ----------------
+--R             5log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 168
+
+--S 169 of 1000
+m0:=a0-r0
+--R 
+--R
+--R          (5x + 2)log(f)    5x + 2
+--R        %e               - f
+--R   (4)  --------------------------
+--R                  5log(f)
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 170
+
+)clear all
+
+--S 171 of 1000
+t0:=f^(a+b*x)
+--R 
+--R
+--R         b x + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 1000
+r0:=f^(a+b*x)/(b*log(f))
+--R 
+--R
+--R         b x + a
+--R        f
+--R   (2)  --------
+--R        b log(f)
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R          (b x + a)log(f)
+--R        %e
+--R   (3)  -----------------
+--R             b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 173
+
+--S 174 of 1000
+m0:=a0-r0
+--R 
+--R
+--R          (b x + a)log(f)    b x + a
+--R        %e                - f
+--R   (4)  ----------------------------
+--R                  b log(f)
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 175
+
+)clear all
+
+--S 176 of 1000
+t0:=10^(2+5*x)
+--R 
+--R
+--R          5x + 2
+--R   (1)  10
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 1000
+r0:=2^(2+5*x)*5^(1+5*x)/log(10)
+--R 
+--R
+--R         5x + 2 5x + 1
+--R        2      5
+--R   (2)  --------------
+--R            log(10)
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R          (5x + 2)log(10)
+--R        %e
+--R   (3)  -----------------
+--R             5log(10)
+--R                                         Type: Union(Expression(Integer),...)
+--E 178
+
+--S 179 of 1000
+m0:=a0-r0
+--R 
+--R
+--R             5x + 2 5x + 1     (5x + 2)log(10)
+--R        - 5 2      5       + %e
+--R   (4)  --------------------------------------
+--R                       5log(10)
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                (5x + 2)log(10)
+--R       log(10)%e
+--R     + 
+--R                              (5x + 2)log(2)  (5x + 1)log(5)
+--R       (- 5log(5) - 5log(2))%e              %e
+--R  /
+--R     log(10)
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^(11/2)
+--R 
+--R
+--R   (1)
+--R     5 5       4 4      2 3 3      3 2 2     4       5  b c x + a c +-------+
+--R   (e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d )F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)^(13/2)*GAMMA(13/2,-b*c*(d+e*x)*log(F)/e)/_
+--  (e*(-b*c*(d+e*x)*log(F)/e)^(13/2))
+--E 182
+
+--S 183 of 1000
+--a0:=integrate(t0,x)
+--E 183
+
+--S 184 of 1000
+--m0:=a0-r0
+--E 184
+
+--S 185 of 1000
+--d0:=normalize(D(m0,x))
+--E 185
+
+)clear all
+
+--S 186 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^(9/2)
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b c x + a c +-------+
+--R   (1)  (e x  + 4d e x  + 6d e x  + 4d e x + d )F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 1000
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)^(11/2)*GAMMA(11/2,-b*c*(d+e*x)*log(F)/e)/_
+--  (e*(-b*c*(d+e*x)*log(F)/e)^(11/2))
+--E 187
+
+--S 188 of 1000
+--a0:=integrate(t0,x)
+--E 188
+
+--S 189 of 1000
+--m0:=a0-r0
+--E 189
+
+--S 190 of 1000
+--d0:=normalize(D(m0,x))
+--E 190
+
+)clear all
+
+--S 191 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^(7/2)
+--R 
+--R
+--R          3 3       2 2     2       3  b c x + a c +-------+
+--R   (1)  (e x  + 3d e x  + 3d e x + d )F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1000
+--r0:=35/4*e^2*F^(c*(a+b*x))*(d+e*x)^(3/2)/(b^3*c^3*log(F)^3)-_
+--   7/2*e*F^(c*(a+b*x))*(d+e*x)^(5/2)/(b^2*c^2*log(F)^2)+F^(c*(a+b*x))*_
+--   (d+e*x)^(7/2)/(b*c*log(F))+105/16*e^(7/2)*F^(c*(a-b*d/e))*_
+--   erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/sqrt(e))*sqrt(%pi)/_
+--   (b^(9/2)*c^(9/2)*log(F)^(9/2))-105/8*e^3*F^(c*(a+b*x))*_
+--   sqrt(d+e*x)/(b^4*c^4*log(F)^4)
+--E 192
+
+--S 193 of 1000
+--a0:=integrate(t0,x)
+--E 193
+
+--S 194 of 1000
+--m0:=a0-r0
+--E 194
+
+--S 195 of 1000
+--d0:=normalize(D(m0,x))
+--E 195
+
+)clear all
+
+--S 196 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^(5/2)
+--R 
+--R
+--R          2 2             2  b c x + a c +-------+
+--R   (1)  (e x  + 2d e x + d )F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1000
+--r0:=-5/2*e*F^(c*(a+b*x))*(d+e*x)^(3/2)/(b^2*c^2*log(F)^2)+F^(c*(a+b*x))*_
+--  (d+e*x)^(5/2)/(b*c*log(F))-15/8*e^(5/2)*F^(c*(a-b*d/e))*_
+--  erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/sqrt(e))*_
+--  sqrt(%pi)/(b^(7/2)*c^(7/2)*log(F)^(7/2))+15/4*e^2*F^(c*(a+b*x))*_
+--  sqrt(d+e*x)/(b^3*c^3*log(F)^3)
+--E 197
+
+--S 198 of 1000
+--a0:=integrate(t0,x)
+--E 198
+
+--S 199 of 1000
+--m0:=a0-r0
+--E 199
+
+--S 200 of 1000
+--d0:=normalize(D(m0,x))
+--E 200
+
+)clear all
+
+--S 201 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^(3/2)
+--R 
+--R
+--R                  b c x + a c +-------+
+--R   (1)  (e x + d)F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 1000
+--r0:=F^(c*(a+b*x))*(d+e*x)^(3/2)/(b*c*log(F))+3/4*e^(3/2)*_
+--  F^(c*(a-b*d/e))*erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/_
+--  sqrt(e))*sqrt(%pi)/(b^(5/2)*c^(5/2)*log(F)^(5/2))-3/2*e*F^(c*_
+--  (a+b*x))*sqrt(d+e*x)/(b^2*c^2*log(F)^2)
+--E 202
+
+--S 203 of 1000
+--a0:=integrate(t0,x)
+--E 203
+
+--S 204 of 1000
+--m0:=a0-r0
+--E 204
+
+--S 205 of 1000
+--d0:=normalize(D(m0,x))
+--E 205
+
+)clear all
+
+--S 206 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)^(1/2)
+--R 
+--R
+--R         b c x + a c +-------+
+--R   (1)  F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 1000
+--r0:=-1/2*F^(c*(a-b*d/e))*erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/_
+--  sqrt(e))*sqrt(%pi)*sqrt(e)/(b^(3/2)*c^(3/2)*log(F)^(3/2))+_
+--  F^(c*(a+b*x))*sqrt(d+e*x)/(b*c*log(F))
+--E 207
+
+--S 208 of 1000
+--a0:=integrate(t0,x)
+--E 208
+
+--S 209 of 1000
+--m0:=a0-r0
+--E 209
+
+--S 210 of 1000
+--d0:=normalize(D(m0,x))
+--E 210
+
+)clear all
+
+--S 211 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^(1/2)
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (1)  ------------
+--R          +-------+
+--R         \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 1000
+--r0:=F^(c*(a-b*d/e))*erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/_
+--  sqrt(e))*sqrt(%pi)/(sqrt(b)*sqrt(c)*sqrt(e)*sqrt(log(F)))
+--E 212
+
+--S 213 of 1000
+--a0:=integrate(t0,x)
+--E 213
+
+--S 214 of 1000
+--m0:=a0-r0
+--E 214
+
+--S 215 of 1000
+--d0:=normalize(D(m0,x))
+--E 215
+
+)clear all
+
+--S 216 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^(3/2)
+--R 
+--R
+--R             b c x + a c
+--R            F
+--R   (1)  -------------------
+--R                  +-------+
+--R        (e x + d)\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 1000
+--r0:=-2*F^(c*(a+b*x))/(e*sqrt(d+e*x))+2*F^(c*(a-b*d/e))*erfi(sqrt(b)*_
+--  sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/sqrt(e))*sqrt(%pi)*sqrt(b)*_
+--  sqrt(c)*sqrt(log(F))/e^(3/2)
+--E 217
+
+--S 218 of 1000
+--a0:=integrate(t0,x)
+--E 218
+
+--S 219 of 1000
+--m0:=a0-r0
+--E 219
+
+--S 220 of 1000
+--d0:=normalize(D(m0,x))
+--E 220
+
+)clear all
+
+--S 221 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^(5/2)
+--R 
+--R
+--R                  b c x + a c
+--R                 F
+--R   (1)  ------------------------------
+--R          2 2             2  +-------+
+--R        (e x  + 2d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1000
+--r0:=-2/3*F^(c*(a+b*x))/(e*(d+e*x)^(3/2))+4/3*b^(3/2)*c^(3/2)*_
+--  F^(c*(a-b*d/e))*erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/_
+--  sqrt(e))*log(F)^(3/2)*sqrt(%pi)/e^(5/2)-4/3*b*c*F^(c*(a+b*x))*_
+--  log(F)/(e^2*sqrt(d+e*x))
+--E 222
+
+--S 223 of 1000
+--a0:=integrate(t0,x)
+--E 223
+
+--S 224 of 1000
+--m0:=a0-r0
+--E 224
+
+--S 225 of 1000
+--d0:=normalize(D(m0,x))
+--E 225
+
+)clear all
+
+--S 226 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^(7/2)
+--R 
+--R
+--R                       b c x + a c
+--R                      F
+--R   (1)  ----------------------------------------
+--R          3 3       2 2     2       3  +-------+
+--R        (e x  + 3d e x  + 3d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 1000
+--r0:=-2/5*F^(c*(a+b*x))/(e*(d+e*x)^(5/2))-4/15*b*c*F^(c*(a+b*x))*_
+--  log(F)/(e^2*(d+e*x)^(3/2))+8/15*b^(5/2)*c^(5/2)*F^(c*(a-b*d/e))*_
+--  erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/sqrt(e))*log(F)^(5/2)*_
+--  sqrt(%pi)/e^(7/2)-8/15*b^2*c^2*F^(c*(a+b*x))*log(F)^2/(e^3*sqrt(d+e*x))
+--E 227
+
+--S 228 of 1000
+--a0:=integrate(t0,x)
+--E 228
+
+--S 229 of 1000
+--m0:=a0-r0
+--E 229
+
+--S 230 of 1000
+--d0:=normalize(D(m0,x))
+--E 230
+
+)clear all
+
+--S 231 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^(9/2)
+--R 
+--R
+--R                            b c x + a c
+--R                           F
+--R   (1)  --------------------------------------------------
+--R          4 4       3 3     2 2 2     3       4  +-------+
+--R        (e x  + 4d e x  + 6d e x  + 4d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 1000
+--r0:=-2/7*F^(c*(a+b*x))/(e*(d+e*x)^(7/2))-4/35*b*c*F^(c*(a+b*x))*_
+--  log(F)/(e^2*(d+e*x)^(5/2))-8/105*b^2*c^2*F^(c*(a+b*x))*_
+--  log(F)^2/(e^3*(d+e*x)^(3/2))+16/105*b^(7/2)*c^(7/2)*F^(c*(a-b*d/e))*_
+--  erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/sqrt(e))*log(F)^(7/2)*_
+--  sqrt(%pi)/e^(9/2)-16/105*b^3*c^3*F^(c*(a+b*x))*log(F)^3/(e^4*sqrt(d+e*x))
+--E 232
+
+--S 233 of 1000
+--a0:=integrate(t0,x)
+--E 233
+
+--S 234 of 1000
+--m0:=a0-r0
+--E 234
+
+--S 235 of 1000
+--d0:=normalize(D(m0,x))
+--E 235
+
+)clear all
+
+--S 236 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^(11/2)
+--R 
+--R
+--R                                  b c x + a c
+--R                                 F
+--R   (1)  --------------------------------------------------------------
+--R          5 5       4 4      2 3 3      3 2 2     4       5  +-------+
+--R        (e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 1000
+--r0:=-F^(c*(a-b*d/e))*GAMMA(-9/2,-b*c*(d+e*x)*log(F)/e)*(-b*c*(d+e*x)*_
+--  log(F)/e)^(9/2)/(e*(d+e*x)^(9/2))
+--E 237
+
+--S 238 of 1000
+--a0:=integrate(t0,x)
+--E 238
+
+--S 239 of 1000
+--m0:=a0-r0
+--E 239
+
+--S 240 of 1000
+--d0:=normalize(D(m0,x))
+--E 240
+
+)clear all
+
+--S 241 of 1000
+t0:=F^(c*(a+b*x))/(d+e*x)^(13/2)
+--R 
+--R
+--R   (1)
+--R                                   b c x + a c
+--R                                  F
+--R   -------------------------------------------------------------------------
+--R     6 6       5 5      2 4 4      3 3 3      4 2 2     5       6  +-------+
+--R   (e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 1000
+--r0:=-F^(c*(a-b*d/e))*GAMMA(-11/2,-b*c*(d+e*x)*log(F)/e)*(-b*c*(d+e*x)*_
+--  log(F)/e)^(11/2)/(e*(d+e*x)^(11/2))
+--E 242
+
+--S 243 of 1000
+--a0:=integrate(t0,x)
+--E 243
+
+--S 244 of 1000
+--m0:=a0-r0
+--E 244
+
+--S 245 of 1000
+--d0:=normalize(D(m0,x))
+--E 245
+
+)clear all
+
+--S 246 of 1000
+t0:=x^(13/2)/%e^(b*x)
+--R 
+--R
+--R         6 +-+
+--R        x \|x
+--R   (1)  ------
+--R           b x
+--R         %e
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 1000
+--r0:=-x^(13/2)*GAMMA(15/2,b*x)/(b*(b*x)^(13/2))
+--E 247
+
+--S 248 of 1000
+--a0:=integrate(t0,x)
+--E 248
+
+--S 249 of 1000
+--m0:=a0-r0
+--E 249
+
+--S 250 of 1000
+--d0:=normalize(D(m0,x))
+--E 250
+
+)clear all
+
+--S 251 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x)
+--R 
+--R
+--R                  b c x + a c
+--R   (1)  (e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 1000
+r0:=-e*F^(c*(a+b*x))/(b^2*c^2*log(F)^2)+F^(c*(a+b*x))*(d+e*x)/(b*c*log(F))
+--R 
+--R
+--R                                      b c x + a c
+--R        ((b c e x + b c d)log(F) - e)F
+--R   (2)  -----------------------------------------
+--R                        2 2      2
+--R                       b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                       (b c x + a c)log(F)
+--R        ((b c e x + b c d)log(F) - e)%e
+--R   (3)  --------------------------------------------------
+--R                             2 2      2
+--R                            b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 253
+
+--S 254 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                      (b c x + a c)log(F)
+--R       ((b c e x + b c d)log(F) - e)%e
+--R     + 
+--R                                       b c x + a c
+--R       ((- b c e x - b c d)log(F) + e)F
+--R  /
+--R      2 2      2
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x+f*x^2)
+--R 
+--R
+--R            2            b c x + a c
+--R   (1)  (f x  + e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 1000
+r0:=2*f*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)-e*F^(c*(a+b*x))/(b^2*c^2*log(F)^2)-_
+   2*f*F^(c*(a+b*x))*x/(b^2*c^2*log(F)^2)+d*F^(c*(a+b*x))/(b*c*log(F))+_
+   e*F^(c*(a+b*x))*x/(b*c*log(F))+f*F^(c*(a+b*x))*x^2/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R          2 2   2    2 2       2 2        2
+--R       ((b c f x  + b c e x + b c d)log(F)  + (- 2b c f x - b c e)log(F) + 2f)
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2   2    2 2       2 2        2
+--R       ((b c f x  + b c e x + b c d)log(F)  + (- 2b c f x - b c e)log(F) + 2f)
+--R    *
+--R         (b c x + a c)log(F)
+--R       %e
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 258
+
+--S 259 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            2 2   2    2 2       2 2        2
+--R         ((b c f x  + b c e x + b c d)log(F)  + (- 2b c f x - b c e)log(F) + 2f)
+--R      *
+--R           (b c x + a c)log(F)
+--R         %e
+--R     + 
+--R              2 2   2    2 2       2 2        2
+--R         ((- b c f x  - b c e x - b c d)log(F)  + (2b c f x + b c e)log(F) - 2f)
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 260
+
+)clear all
+
+--S 261 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x+f*x^2+g*x^3)
+--R 
+--R
+--R            3      2            b c x + a c
+--R   (1)  (g x  + f x  + e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 1000
+r0:=-6*F^(c*(a+b*x))*g/(b^4*c^4*log(F)^4)+2*f*F^(c*(a+b*x))/(b^3*c^3*_
+   log(F)^3)+6*F^(c*(a+b*x))*g*x/(b^3*c^3*log(F)^3)-e*F^(c*(a+b*x))/_
+   (b^2*c^2*log(F)^2)-2*f*F^(c*(a+b*x))*x/(b^2*c^2*log(F)^2)-3*F^(c*_
+   (a+b*x))*g*x^2/(b^2*c^2*log(F)^2)+d*F^(c*(a+b*x))/(b*c*log(F))+_
+   e*F^(c*(a+b*x))*x/(b*c*log(F))+f*F^(c*(a+b*x))*x^2/(b*c*log(F))+_
+   F^(c*(a+b*x))*g*x^3/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R           3 3   3    3 3   2    3 3       3 3        3
+--R         (b c g x  + b c f x  + b c e x + b c d)log(F)
+--R       + 
+--R            2 2   2     2 2       2 2        2
+--R       (- 3b c g x  - 2b c f x - b c e)log(F)  + (6b c g x + 2b c f)log(F) - 6g
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 3   3    3 3   2    3 3       3 3        3
+--R         (b c g x  + b c f x  + b c e x + b c d)log(F)
+--R       + 
+--R            2 2   2     2 2       2 2        2
+--R       (- 3b c g x  - 2b c f x - b c e)log(F)  + (6b c g x + 2b c f)log(F) - 6g
+--R    *
+--R         (b c x + a c)log(F)
+--R       %e
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 263
+
+--S 264 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3 3   3    3 3   2    3 3       3 3        3
+--R           (b c g x  + b c f x  + b c e x + b c d)log(F)
+--R         + 
+--R                2 2   2     2 2       2 2        2
+--R           (- 3b c g x  - 2b c f x - b c e)log(F)  + (6b c g x + 2b c f)log(F)
+--R         + 
+--R           - 6g
+--R      *
+--R           (b c x + a c)log(F)
+--R         %e
+--R     + 
+--R               3 3   3    3 3   2    3 3       3 3        3
+--R           (- b c g x  - b c f x  - b c e x - b c d)log(F)
+--R         + 
+--R              2 2   2     2 2       2 2        2
+--R           (3b c g x  + 2b c f x + b c e)log(F)  + (- 6b c g x - 2b c f)log(F)
+--R         + 
+--R           6g
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 265
+
+)clear all
+
+--S 266 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x+f*x^2+g*x^3+h*x^4)
+--R 
+--R
+--R            4      3      2            b c x + a c
+--R   (1)  (h x  + g x  + f x  + e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1000
+--r0:=F^(a*c)*h*GAMMA(5,-b*c*x*log(F))/(b^5*c^5*log(F)^5)-6*F^(c*(a+b*x))*_
+--  g/(b^4*c^4*log(F)^4)+2*f*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)+_
+--  6*F^(c*(a+b*x))*g*x/(b^3*c^3*log(F)^3)-e*F^(c*(a+b*x))/(b^2*c^2*_
+--  log(F)^2)-2*f*F^(c*(a+b*x))*x/(b^2*c^2*log(F)^2)-3*F^(c*(a+b*x))*_
+--  g*x^2/(b^2*c^2*log(F)^2)+d*F^(c*(a+b*x))/(b*c*log(F))+e*F^(c*(a+b*x))*_
+--  x/(b*c*log(F))+f*F^(c*(a+b*x))*x^2/(b*c*log(F))+F^(c*(a+b*x))*_
+--  g*x^3/(b*c*log(F))
+--E 267
+
+--S 268 of 1000
+--a0:=integrate(t0,x)
+--E 268
+
+--S 269 of 1000
+--m0:=a0-r0
+--E 269
+
+--S 270 of 1000
+--d0:=normalize(D(m0,x))
+--E 270
+
+)clear all
+
+--S 271 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x+f*x^2+g*x^3+h*x^4+j*x^5)
+--R 
+--R
+--R            5      4      3      2            b c x + a c
+--R   (1)  (j x  + h x  + g x  + f x  + e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 1000
+--r0:=-F^(a*c)*j*GAMMA(6,-b*c*x*log(F))/(b^6*c^6*log(F)^6)+F^(a*c)*h*_
+--  GAMMA(5,-b*c*x*log(F))/(b^5*c^5*log(F)^5)-6*F^(c*(a+b*x))*g/_
+--  (b^4*c^4*log(F)^4)+2*f*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)+_
+--  6*F^(c*(a+b*x))*g*x/(b^3*c^3*log(F)^3)-e*F^(c*(a+b*x))/_
+--  (b^2*c^2*log(F)^2)-2*f*F^(c*(a+b*x))*x/(b^2*c^2*log(F)^2)-_
+--  3*F^(c*(a+b*x))*g*x^2/(b^2*c^2*log(F)^2)+d*F^(c*(a+b*x))/_
+--  (b*c*log(F))+e*F^(c*(a+b*x))*x/(b*c*log(F))+f*F^(c*(a+b*x))*_
+--  x^2/(b*c*log(F))+F^(c*(a+b*x))*g*x^3/(b*c*log(F))
+--E 272
+
+--S 273 of 1000
+--a0:=integrate(t0,x)
+--E 273
+
+--S 274 of 1000
+--m0:=a0-r0
+--E 274
+
+--S 275 of 1000
+--d0:=normalize(D(m0,x))
+--E 275
+
+)clear all
+
+--S 276 of 1000
+t0:=F^(c*(a+b*x))*(d+e*x+f*x^2+g*x^3+h*x^4+j*x^5+k*x^6)
+--R 
+--R
+--R            6      5      4      3      2            b c x + a c
+--R   (1)  (k x  + j x  + h x  + g x  + f x  + e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 1000
+--r0:=F^(a*c)*k*GAMMA(7,-b*c*x*log(F))/(b^7*c^7*log(F)^7)-F^(a*c)*j*_
+--  GAMMA(6,-b*c*x*log(F))/(b^6*c^6*log(F)^6)+F^(a*c)*h*_
+--  GAMMA(5,-b*c*x*log(F))/(b^5*c^5*log(F)^5)-6*F^(c*(a+b*x))*_
+--  g/(b^4*c^4*log(F)^4)+2*f*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)+_
+--  6*F^(c*(a+b*x))*g*x/(b^3*c^3*log(F)^3)-e*F^(c*(a+b*x))/_
+--  (b^2*c^2*log(F)^2)-2*f*F^(c*(a+b*x))*x/(b^2*c^2*log(F)^2)-_
+--  3*F^(c*(a+b*x))*g*x^2/(b^2*c^2*log(F)^2)+d*F^(c*(a+b*x))/_
+--  (b*c*log(F))+e*F^(c*(a+b*x))*x/(b*c*log(F))+f*F^(c*(a+b*x))*_
+--  x^2/(b*c*log(F))+F^(c*(a+b*x))*g*x^3/(b*c*log(F))
+--E 277
+
+--S 278 of 1000
+--a0:=integrate(t0,x)
+--E 278
+
+--S 279 of 1000
+--m0:=a0-r0
+--E 279
+
+--S 280 of 1000
+--d0:=normalize(D(m0,x))
+--E 280
+
+)clear all
+
+--S 281 of 1000
+t0:=%e^(-a-b*x)*x^m*(a+b*x)^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a m
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x + a )%e         x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 1000
+--r0:=-a^4*x^m*GAMMA(1+m,b*x)/(%e^a*b*(b*x)^m)-4*a^3*x^(1+m)*(b*x)^(-1-m)*_
+--  GAMMA(2+m,b*x)/%e^a-6*a^2*b*x^(2+m)*(b*x)^(-2-m)*GAMMA(3+m,b*x)/%e^a-_
+--  4*a*b^2*x^(3+m)*(b*x)^(-3-m)*GAMMA(4+m,b*x)/%e^a-b^3*x^(4+m)*_
+--  (b*x)^(-4-m)*GAMMA(5+m,b*x)/%e^a
+--E 282
+
+--S 283 of 1000
+--a0:=integrate(t0,x)
+--E 283
+
+--S 284 of 1000
+--m0:=a0-r0
+--E 284
+
+--S 285 of 1000
+--d0:=normalize(D(m0,x))
+--E 285
+
+)clear all
+
+--S 286 of 1000
+t0:=%e^(-a-b*x)*x^7*(a+b*x)^4
+--R 
+--R
+--R          4 11       3 10     2 2 9     3   8    4 7   - b x - a
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 1000
+--r0:=-a^4*GAMMA(8,b*x)/(%e^a*b^8)-4*a^3*GAMMA(9,b*x)/(%e^a*b^8)-_
+--  6*a^2*GAMMA(10,b*x)/(%e^a*b^8)-4*a*GAMMA(11,b*x)/(%e^a*b^8)-_
+--  GAMMA(12,b*x)/(%e^a*b^8)
+--E 287
+
+--S 288 of 1000
+--a0:=integrate(t0,x)
+--E 288
+
+--S 289 of 1000
+--m0:=a0-r0
+--E 289
+
+--S 290 of 1000
+--d0:=normalize(D(m0,x))
+--E 290
+
+)clear all
+
+--S 291 of 1000
+t0:=%e^(-a-b*x)*x^6*(a+b*x)^4
+--R 
+--R
+--R          4 10       3 9     2 2 8     3   7    4 6   - b x - a
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 1000
+--r0:=-a^4*GAMMA(7,b*x)/(%e^a*b^7)-4*a^3*GAMMA(8,b*x)/(%e^a*b^7)-_
+--  6*a^2*GAMMA(9,b*x)/(%e^a*b^7)-4*a*GAMMA(10,b*x)/(%e^a*b^7)-_
+--  GAMMA(11,b*x)/(%e^a*b^7)
+--E 292
+
+--S 293 of 1000
+--a0:=integrate(t0,x)
+--E 293
+
+--S 294 of 1000
+--m0:=a0-r0
+--E 294
+
+--S 295 of 1000
+--d0:=normalize(D(m0,x))
+--E 295
+
+)clear all
+
+--S 296 of 1000
+t0:=%e^(-a-b*x)*x^5*(a+b*x)^4
+--R 
+--R
+--R          4 9       3 8     2 2 7     3   6    4 5   - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1000
+--r0:=-a^4*GAMMA(6,b*x)/(%e^a*b^6)-4*a^3*GAMMA(7,b*x)/(%e^a*b^6)-_
+--  6*a^2*GAMMA(8,b*x)/(%e^a*b^6)-4*a*GAMMA(9,b*x)/(%e^a*b^6)-_
+--  GAMMA(10,b*x)/(%e^a*b^6)
+--E 297
+
+--S 298 of 1000
+--a0:=integrate(t0,x)
+--E 298
+
+--S 299 of 1000
+--m0:=a0-r0
+--E 299
+
+--S 300 of 1000
+--d0:=normalize(D(m0,x))
+--E 300
+
+)clear all
+
+--S 301 of 1000
+t0:=%e^(-a-b*x)*x^4*(a+b*x)^4
+--R 
+--R
+--R          4 8       3 7     2 2 6     3   5    4 4   - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1000
+--r0:=-a^4*GAMMA(5,a+b*x)/b^5+4*a^3*GAMMA(6,a+b*x)/b^5-_
+--  6*a^2*GAMMA(7,a+b*x)/b^5+4*a*GAMMA(8,a+b*x)/b^5-GAMMA(9,a+b*x)/b^5
+--E 302
+
+--S 303 of 1000
+--a0:=integrate(t0,x)
+--E 303
+
+--S 304 of 1000
+--m0:=a0-r0
+--E 304
+
+--S 305 of 1000
+--d0:=normalize(D(m0,x))
+--E 305
+
+)clear all
+
+--S 306 of 1000
+t0:=%e^(-a-b*x)*x^3*(a+b*x)^4
+--R 
+--R
+--R          4 7       3 6     2 2 5     3   4    4 3   - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 1000
+--r0:=a^3*GAMMA(5,a+b*x)/b^4-3*a^2*GAMMA(6,a+b*x)/b^4+_
+--  3*a*GAMMA(7,a+b*x)/b^4-GAMMA(8,a+b*x)/b^4
+--E 307
+
+--S 308 of 1000
+--a0:=integrate(t0,x)
+--E 308
+
+--S 309 of 1000
+--m0:=a0-r0
+--E 309
+
+--S 310 of 1000
+--d0:=normalize(D(m0,x))
+--E 310
+
+)clear all
+
+--S 311 of 1000
+t0:=%e^(-a-b*x)*x^2*(a+b*x)^4
+--R 
+--R
+--R          4 6       3 5     2 2 4     3   3    4 2   - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 1000
+--r0:=-a^2*GAMMA(5,a+b*x)/b^3+2*a*GAMMA(6,a+b*x)/b^3-GAMMA(7,a+b*x)/b^3
+--E 312
+
+--S 313 of 1000
+--a0:=integrate(t0,x)
+--E 313
+
+--S 314 of 1000
+--m0:=a0-r0
+--E 314
+
+--S 315 of 1000
+--d0:=normalize(D(m0,x))
+--E 315
+
+)clear all
+
+--S 316 of 1000
+t0:=%e^(-a-b*x)*x*(a+b*x)^4
+--R 
+--R
+--R          4 5       3 4     2 2 3     3   2    4    - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x)%e
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 1000
+--r0:=a*GAMMA(5,a+b*x)/b^2-GAMMA(6,a+b*x)/b^2
+--E 317
+
+--S 318 of 1000
+--a0:=integrate(t0,x)
+--E 318
+
+--S 319 of 1000
+--m0:=a0-r0
+--E 319
+
+--S 320 of 1000
+--d0:=normalize(D(m0,x))
+--E 320
+
+)clear all
+
+--S 321 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 1000
+--r0:=-GAMMA(5,a+b*x)/b
+--E 322
+
+--S 323 of 1000
+--a0:=integrate(t0,x)
+--E 323
+
+--S 324 of 1000
+--m0:=a0-r0
+--E 324
+
+--S 325 of 1000
+--d0:=normalize(D(m0,x))
+--E 325
+
+)clear all
+
+--S 326 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^4/x
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 1000
+r0:=-6*%e^(-a-b*x)-2*%e^(-a-b*x)*a-%e^(-a-b*x)*a^2-%e^(-a-b*x)*a^3-_
+   6*%e^(-a-b*x)*(a+b*x)-2*%e^(-a-b*x)*a*(a+b*x)-%e^(-a-b*x)*a^2*(a+b*x)-_
+   3*%e^(-a-b*x)*(a+b*x)^2-%e^(-a-b*x)*a*(a+b*x)^2-%e^(-a-b*x)*(a+b*x)^3+_
+   a^4*Ei(-b*x)/%e^a
+--R 
+--R
+--R   (2)
+--R             3 3              2 2        2                  3     2
+--R         (- b x  + (- 4a - 3)b x  + (- 6a  - 8a - 6)b x - 4a  - 6a  - 8a - 6)
+--R      *
+--R           - b x - a  a
+--R         %e         %e
+--R     + 
+--R        4
+--R       a Ei(- b x)
+--R  /
+--R       a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x    4 4      3   3      2 2 2        3     4   - %D b - a
+--R         ++  (%D b  + 4%D a b  + 6%D a b  + 4%D a b + a )%e
+--R   (3)   |   -------------------------------------------------------- d%D
+--R        ++                              %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 328
+
+--S 329 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             x    4 4      3   3      2 2 2        3     4   - %D b - a
+--R         a ++  (%D b  + 4%D a b  + 6%D a b  + 4%D a b + a )%e
+--R       %e  |   -------------------------------------------------------- d%D
+--R          ++                              %D
+--R     + 
+--R           3 3            2 2      2                  3     2
+--R         (b x  + (4a + 3)b x  + (6a  + 8a + 6)b x + 4a  + 6a  + 8a + 6)
+--R      *
+--R           - b x - a  a
+--R         %e         %e
+--R     + 
+--R          4
+--R       - a Ei(- b x)
+--R  /
+--R       a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^2
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  2
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 1000
+r0:=-2*%e^(-a-b*x)*b-4*%e^(-a-b*x)*a*b-6*%e^(-a-b*x)*a^2*b-%e^(-a-b*x)*a^4/x-_
+   2*%e^(-a-b*x)*b^2*x-4*%e^(-a-b*x)*a*b^2*x-%e^(-a-b*x)*b^3*x^2+_
+   4*a^3*b*Ei(-b*x)/%e^a-a^4*b*Ei(-b*x)/%e^a
+--R 
+--R
+--R   (2)
+--R           3 3              2 2        2                 4   - b x - a  a
+--R       (- b x  + (- 4a - 2)b x  + (- 6a  - 4a - 2)b x - a )%e         %e
+--R     + 
+--R           4     3
+--R       (- a  + 4a )b x Ei(- b x)
+--R  /
+--R         a
+--R     x %e
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x    4 4      3   3      2 2 2        3     4   - %D b - a
+--R         ++  (%D b  + 4%D a b  + 6%D a b  + 4%D a b + a )%e
+--R   (3)   |   -------------------------------------------------------- d%D
+--R        ++                                2
+--R                                        %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 333
+
+--S 334 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               x    4 4      3   3      2 2 2        3     4   - %D b - a
+--R           a ++  (%D b  + 4%D a b  + 6%D a b  + 4%D a b + a )%e
+--R       x %e  |   -------------------------------------------------------- d%D
+--R            ++                                2
+--R                                            %D
+--R     + 
+--R         3 3            2 2      2                 4   - b x - a  a
+--R       (b x  + (4a + 2)b x  + (6a  + 4a + 2)b x + a )%e         %e
+--R     + 
+--R         4     3
+--R       (a  - 4a )b x Ei(- b x)
+--R  /
+--R         a
+--R     x %e
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 335
+
+)clear all
+
+--S 336 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^3
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  3
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 1000
+r0:=-%e^(-a-b*x)*b^2-4*%e^(-a-b*x)*a*b^2-1/2*%e^(-a-b*x)*a^4/x^2-_
+   4*%e^(-a-b*x)*a^3*b/x+1/2*%e^(-a-b*x)*a^4*b/x-%e^(-a-b*x)*b^3*x+_
+   6*a^2*b^2*Ei(-b*x)/%e^a-4*a^3*b^2*Ei(-b*x)/%e^a+1/2*a^4*b^2*Ei(-b*x)/%e^a
+--R 
+--R
+--R   (2)
+--R            3 3              2 2     4     3        4   - b x - a  a
+--R       (- 2b x  + (- 8a - 2)b x  + (a  - 8a )b x - a )%e         %e
+--R     + 
+--R         4     3      2  2 2
+--R       (a  - 8a  + 12a )b x Ei(- b x)
+--R  /
+--R       2  a
+--R     2x %e
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x    4 4      3   3      2 2 2        3     4   - %D b - a
+--R         ++  (%D b  + 4%D a b  + 6%D a b  + 4%D a b + a )%e
+--R   (3)   |   -------------------------------------------------------- d%D
+--R        ++                                3
+--R                                        %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 338
+
+--S 339 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                x    4 4      3   3      2 2 2        3     4   - %D b - a
+--R         2  a ++  (%D b  + 4%D a b  + 6%D a b  + 4%D a b + a )%e
+--R       2x %e  |   -------------------------------------------------------- d%D
+--R             ++                                3
+--R                                             %D
+--R     + 
+--R          3 3            2 2       4     3        4   - b x - a  a
+--R       (2b x  + (8a + 2)b x  + (- a  + 8a )b x + a )%e         %e
+--R     + 
+--R           4     3      2  2 2
+--R       (- a  + 8a  - 12a )b x Ei(- b x)
+--R  /
+--R       2  a
+--R     2x %e
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 340
+
+)clear all
+
+--S 341 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  4
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 1000
+r0:=-%e^(-a-b*x)*b^3-1/3*%e^(-a-b*x)*a^4/x^3-2*%e^(-a-b*x)*a^3*b/x^2+_
+   1/6*%e^(-a-b*x)*a^4*b/x^2-6*%e^(-a-b*x)*a^2*b^2/x+2*%e^(-a-b*x)*a^3*b^2/x-_
+   1/6*%e^(-a-b*x)*a^4*b^2/x+4*a*b^3*Ei(-b*x)/%e^a-6*a^2*b^3*Ei(-b*x)/%e^a+_
+   2*a^3*b^3*Ei(-b*x)/%e^a-1/6*a^4*b^3*Ei(-b*x)/%e^a
+--R 
+--R
+--R   (2)
+--R            3 3       4      3      2  2 2     4      3         4   - b x - a  a
+--R       (- 6b x  + (- a  + 12a  - 36a )b x  + (a  - 12a )b x - 2a )%e         %e
+--R     + 
+--R           4      3      2        3 3
+--R       (- a  + 12a  - 36a  + 24a)b x Ei(- b x)
+--R  /
+--R       3  a
+--R     6x %e
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x    4 4      3   3      2 2 2        3     4   - %D b - a
+--R         ++  (%D b  + 4%D a b  + 6%D a b  + 4%D a b + a )%e
+--R   (3)   |   -------------------------------------------------------- d%D
+--R        ++                                4
+--R                                        %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 343
+
+--S 344 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                x    4 4      3   3      2 2 2        3     4   - %D b - a
+--R         3  a ++  (%D b  + 4%D a b  + 6%D a b  + 4%D a b + a )%e
+--R       6x %e  |   -------------------------------------------------------- d%D
+--R             ++                                4
+--R                                             %D
+--R     + 
+--R          3 3     4      3      2  2 2       4      3         4   - b x - a  a
+--R       (6b x  + (a  - 12a  + 36a )b x  + (- a  + 12a )b x + 2a )%e         %e
+--R     + 
+--R         4      3      2        3 3
+--R       (a  - 12a  + 36a  - 24a)b x Ei(- b x)
+--R  /
+--R       3  a
+--R     6x %e
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^5
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  5
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 1000
+--r0:=-4/3*%e^(-a-b*x)*a^3*b/x^3-3*%e^(-a-b*x)*a^2*b^2/x^2+_
+--  2/3*%e^(-a-b*x)*a^3*b^2/x^2-4*%e^(-a-b*x)*a*b^3/x+3*%e^(-a-b*x)*_
+--  a^2*b^3/x-2/3*%e^(-a-b*x)*a^3*b^3/x+b^4*Ei(-b*x)/%e^a-4*a*b^4*_
+--  Ei(-b*x)/%e^a+3*a^2*b^4*Ei(-b*x)/%e^a-2/3*a^3*b^4*Ei(-b*x)/%e^a-_
+--  a^4*b^4*GAMMA(-4,b*x)/%e^a
+--E 347
+
+--S 348 of 1000
+--a0:=integrate(t0,x)
+--E 348
+
+--S 349 of 1000
+--m0:=a0-r0
+--E 349
+
+--S 350 of 1000
+--d0:=normalize(D(m0,x))
+--E 350
+
+)clear all
+
+--S 351 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^6
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  6
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 1000
+--r0:=-2*%e^(-a-b*x)*a^2*b^2/x^3-2*%e^(-a-b*x)*a*b^3/x^2+%e^(-a-b*x)*_
+--  a^2*b^3/x^2-%e^(-a-b*x)*b^4/x+2*%e^(-a-b*x)*a*b^4/x-%e^(-a-b*x)*_
+--  a^2*b^4/x-b^5*Ei(-b*x)/%e^a+2*a*b^5*Ei(-b*x)/%e^a-a^2*b^5*Ei(-b*x)/%e^a-_
+--  a^4*b^5*GAMMA(-5,b*x)/%e^a-4*a^3*b^5*GAMMA(-4,b*x)/%e^a
+--E 352
+
+--S 353 of 1000
+--a0:=integrate(t0,x)
+--E 353
+
+--S 354 of 1000
+--m0:=a0-r0
+--E 354
+
+--S 355 of 1000
+--d0:=normalize(D(m0,x))
+--E 355
+
+)clear all
+
+--S 356 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^7
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  7
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 1000
+--r0:=-4/3*%e^(-a-b*x)*a*b^3/x^3-1/2*%e^(-a-b*x)*b^4/x^2+2/3*%e^(-a-b*x)*_
+--  a*b^4/x^2+1/2*%e^(-a-b*x)*b^5/x-2/3*%e^(-a-b*x)*a*b^5/x+1/2*b^6*_
+--  Ei(-b*x)/%e^a-2/3*a*b^6*Ei(-b*x)/%e^a-a^4*b^6*GAMMA(-6,b*x)/%e^a-4*_
+--  a^3*b^6*GAMMA(-5,b*x)/%e^a-6*a^2*b^6*GAMMA(-4,b*x)/%e^a
+--E 357
+
+--S 358 of 1000
+--a0:=integrate(t0,x)
+--E 358
+
+--S 359 of 1000
+--m0:=a0-r0
+--E 359
+
+--S 360 of 1000
+--d0:=normalize(D(m0,x))
+--E 360
+
+)clear all
+
+--S 361 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^8
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  8
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 1000
+--r0:=-1/3*%e^(-a-b*x)*b^4/x^3+1/6*%e^(-a-b*x)*b^5/x^2-1/6*%e^(-a-b*x)*_
+--  b^6/x-1/6*b^7*Ei(-b*x)/%e^a-a^4*b^7*GAMMA(-7,b*x)/%e^a-4*a^3*b^7*_
+--  GAMMA(-6,b*x)/%e^a-6*a^2*b^7*GAMMA(-5,b*x)/%e^a-4*a*b^7*GAMMA(-4,b*x)/%e^a
+--E 362
+
+--S 363 of 1000
+--a0:=integrate(t0,x)
+--E 363
+
+--S 364 of 1000
+--m0:=a0-r0
+--E 364
+
+--S 365 of 1000
+--d0:=normalize(D(m0,x))
+--E 365
+
+)clear all
+
+--S 366 of 1000
+t0:=F^(a+b*(c+d*x))*x^m*(e+f*x)^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a m
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x + e )F               x
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 1000
+--r0:=-f^4*F^(a+b*c)*x^(5+m)*GAMMA(5+m,-b*d*x*log(F))*(-b*d*x*_
+--  log(F))^(-5-m)-4*e*f^3*F^(a+b*c)*x^(4+m)*GAMMA(4+m,-b*d*x*log(F))*_
+--  (-b*d*x*log(F))^(-4-m)-6*e^2*f^2*F^(a+b*c)*x^(3+m)*GAMMA(3+m,-b*d*x*_
+--  log(F))*(-b*d*x*log(F))^(-3-m)-4*e^3*f*F^(a+b*c)*x^(2+m)*GAMMA(2+m,_
+--  -b*d*x*log(F))*(-b*d*x*log(F))^(-2-m)-e^4*F^(a+b*c)*x^(1+m)*_
+--  GAMMA(1+m,-b*d*x*log(F))*(-b*d*x*log(F))^(-1-m)
+--E 367
+
+--S 368 of 1000
+--a0:=integrate(t0,x)
+--E 368
+
+--S 369 of 1000
+--m0:=a0-r0
+--E 369
+
+--S 370 of 1000
+--d0:=normalize(D(m0,x))
+--E 370
+
+)clear all
+
+--S 371 of 1000
+t0:=F^(a+b*(c+d*x))*x^7*(e+f*x)^4
+--R 
+--R
+--R          4 11       3 10     2 2 9     3   8    4 7  b d x + b c + a
+--R   (1)  (f x   + 4e f x   + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1000
+--r0:=-f^4*F^(a+b*c)*GAMMA(12,-b*d*x*log(F))/(b^12*d^12*log(F)^12)+_
+--  4*e*f^3*F^(a+b*c)*GAMMA(11,-b*d*x*log(F))/(b^11*d^11*log(F)^11)-_
+--  6*e^2*f^2*F^(a+b*c)*GAMMA(10,-b*d*x*log(F))/(b^10*d^10*log(F)^10)+_
+--  4*e^3*f*F^(a+b*c)*GAMMA(9,-b*d*x*log(F))/(b^9*d^9*log(F)^9)-_
+--  e^4*F^(a+b*c)*GAMMA(8,-b*d*x*log(F))/(b^8*d^8*log(F)^8)
+--E 372
+
+--S 373 of 1000
+--a0:=integrate(t0,x)
+--E 373
+
+--S 374 of 1000
+--m0:=a0-r0
+--E 374
+
+--S 375 of 1000
+--d0:=normalize(D(m0,x))
+--E 375
+
+)clear all
+
+--S 376 of 1000
+t0:=F^(a+b*(c+d*x))*x^6*(e+f*x)^4
+--R 
+--R
+--R          4 10       3 9     2 2 8     3   7    4 6  b d x + b c + a
+--R   (1)  (f x   + 4e f x  + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1000
+--r0:=f^4*F^(a+b*c)*GAMMA(11,-b*d*x*log(F))/(b^11*d^11*log(F)^11)-_
+--  4*e*f^3*F^(a+b*c)*GAMMA(10,-b*d*x*log(F))/(b^10*d^10*log(F)^10)+_
+--  6*e^2*f^2*F^(a+b*c)*GAMMA(9,-b*d*x*log(F))/(b^9*d^9*log(F)^9)-_
+--  4*e^3*f*F^(a+b*c)*GAMMA(8,-b*d*x*log(F))/(b^8*d^8*log(F)^8)+_
+--  e^4*F^(a+b*c)*GAMMA(7,-b*d*x*log(F))/(b^7*d^7*log(F)^7)
+--E 377
+
+--S 378 of 1000
+--a0:=integrate(t0,x)
+--E 378
+
+--S 379 of 1000
+--m0:=a0-r0
+--E 379
+
+--S 380 of 1000
+--d0:=normalize(D(m0,x))
+--E 380
+
+)clear all
+
+--S 381 of 1000
+t0:=F^(a+b*(c+d*x))*x^5*(e+f*x)^4
+--R 
+--R
+--R          4 9       3 8     2 2 7     3   6    4 5  b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 1000
+--r0:=-f^4*F^(a+b*c)*GAMMA(10,-b*d*x*log(F))/(b^10*d^10*log(F)^10)+_
+--  4*e*f^3*F^(a+b*c)*GAMMA(9,-b*d*x*log(F))/(b^9*d^9*log(F)^9)-_
+--  6*e^2*f^2*F^(a+b*c)*GAMMA(8,-b*d*x*log(F))/(b^8*d^8*log(F)^8)+_
+--  4*e^3*f*F^(a+b*c)*GAMMA(7,-b*d*x*log(F))/(b^7*d^7*log(F)^7)-_
+--  e^4*F^(a+b*c)*GAMMA(6,-b*d*x*log(F))/(b^6*d^6*log(F)^6)
+--E 382
+
+--S 383 of 1000
+--a0:=integrate(t0,x)
+--E 383
+
+--S 384 of 1000
+--m0:=a0-r0
+--E 384
+
+--S 385 of 1000
+--d0:=normalize(D(m0,x))
+--E 385
+
+)clear all
+
+--S 386 of 1000
+t0:=F^(a+b*(c+d*x))*x^4*(e+f*x)^4
+--R 
+--R
+--R          4 8       3 7     2 2 6     3   5    4 4  b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 1000
+--r0:=f^4*F^(a+b*c-b*d*e/f)*GAMMA(9,-b*d*(e+f*x)*log(F)/f)/(b^9*d^9*_
+--  log(F)^9)+4*e*f^3*F^(a+b*c-b*d*e/f)*GAMMA(8,-b*d*(e+f*x)*log(F)/f)/_
+--  (b^8*d^8*log(F)^8)+6*e^2*f^2*F^(a+b*c-b*d*e/f)*GAMMA(7,-b*d*(e+f*x)*_
+--  log(F)/f)/(b^7*d^7*log(F)^7)+4*e^3*f*F^(a+b*c-b*d*e/f)*GAMMA(6,_
+--  -b*d*(e+f*x)*log(F)/f)/(b^6*d^6*log(F)^6)+e^4*F^(a+b*c-b*d*e/f)*_
+--  GAMMA(5,-b*d*(e+f*x)*log(F)/f)/(b^5*d^5*log(F)^5)
+--E 387
+
+--S 388 of 1000
+--a0:=integrate(t0,x)
+--E 388
+
+--S 389 of 1000
+--m0:=a0-r0
+--E 389
+
+--S 390 of 1000
+--d0:=normalize(D(m0,x))
+--E 390
+
+)clear all
+
+--S 391 of 1000
+t0:=F^(a+b*(c+d*x))*x^3*(e+f*x)^4
+--R 
+--R
+--R          4 7       3 6     2 2 5     3   4    4 3  b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1000
+--r0:=-f^4*F^(a+b*c-b*d*e/f)*GAMMA(8,-b*d*(e+f*x)*log(F)/f)/(b^8*d^8*_
+--  log(F)^8)-3*e*f^3*F^(a+b*c-b*d*e/f)*GAMMA(7,-b*d*(e+f*x)*log(F)/f)/_
+--  (b^7*d^7*log(F)^7)-3*e^2*f^2*F^(a+b*c-b*d*e/f)*GAMMA(6,-b*d*(e+f*x)*_
+--  log(F)/f)/(b^6*d^6*log(F)^6)-e^3*f*F^(a+b*c-b*d*e/f)*GAMMA(5,_
+--  -b*d*(e+f*x)*log(F)/f)/(b^5*d^5*log(F)^5)
+--E 392
+
+--S 393 of 1000
+--a0:=integrate(t0,x)
+--E 393
+
+--S 394 of 1000
+--m0:=a0-r0
+--E 394
+
+--S 395 of 1000
+--d0:=normalize(D(m0,x))
+--E 395
+
+)clear all
+
+--S 396 of 1000
+t0:=F^(a+b*(c+d*x))*x^2*(e+f*x)^4
+--R 
+--R
+--R          4 6       3 5     2 2 4     3   3    4 2  b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 396
+
+--S 397 of 1000
+--r0:=f^4*F^(a+b*c-b*d*e/f)*GAMMA(7,-b*d*(e+f*x)*log(F)/f)/(b^7*d^7*_
+--  log(F)^7)+2*e*f^3*F^(a+b*c-b*d*e/f)*GAMMA(6,-b*d*(e+f*x)*log(F)/f)/_
+--  (b^6*d^6*log(F)^6)+e^2*f^2*F^(a+b*c-b*d*e/f)*GAMMA(5,-b*d*(e+f*x)*_
+--  log(F)/f)/(b^5*d^5*log(F)^5)
+--E 397
+
+--S 398 of 1000
+--a0:=integrate(t0,x)
+--E 398
+
+--S 399 of 1000
+--m0:=a0-r0
+--E 399
+
+--S 400 of 1000
+--d0:=normalize(D(m0,x))
+--E 400
+
+)clear all
+
+--S 401 of 1000
+t0:=F^(a+b*(c+d*x))*x*(e+f*x)^4
+--R 
+--R
+--R          4 5       3 4     2 2 3     3   2    4   b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x  + e x)F
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 1000
+--r0:=-f^4*F^(a+b*c-b*d*e/f)*GAMMA(6,-b*d*(e+f*x)*log(F)/f)/(b^6*d^6*_
+--  log(F)^6)-e*f^3*F^(a+b*c-b*d*e/f)*GAMMA(5,-b*d*(e+f*x)*log(F)/f)/_
+--  (b^5*d^5*log(F)^5)
+--E 402
+
+--S 403 of 1000
+--a0:=integrate(t0,x)
+--E 403
+
+--S 404 of 1000
+--m0:=a0-r0
+--E 404
+
+--S 405 of 1000
+--d0:=normalize(D(m0,x))
+--E 405
+
+)clear all
+
+--S 406 of 1000
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 1000
+--r0:=f^4*F^(a+b*c-b*d*e/f)*GAMMA(5,-b*d*(e+f*x)*log(F)/f)/(b^5*d^5*log(F)^5)
+--E 407
+
+--S 408 of 1000
+--a0:=integrate(t0,x)
+--E 408
+
+--S 409 of 1000
+--m0:=a0-r0
+--E 409
+
+--S 410 of 1000
+--d0:=normalize(D(m0,x))
+--E 410
+
+)clear all
+
+--S 411 of 1000
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    x
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 1000
+r0:=e^4*F^(a+b*c)*Ei(b*d*x*log(F))-6*f^4*F^(a+b*c+b*d*x)/(b^4*d^4*log(F)^4)+_
+   8*e*f^3*F^(a+b*c+b*d*x)/(b^3*d^3*log(F)^3)+6*f^4*F^(a+b*c+b*d*x)*x/_
+   (b^3*d^3*log(F)^3)-6*e^2*f^2*F^(a+b*c+b*d*x)/(b^2*d^2*log(F)^2)-_
+   8*e*f^3*F^(a+b*c+b*d*x)*x/(b^2*d^2*log(F)^2)-3*f^4*F^(a+b*c+b*d*x)*_
+   x^2/(b^2*d^2*log(F)^2)+4*e^3*f*F^(a+b*c+b*d*x)/(b*d*log(F))+_
+   6*e^2*f^2*F^(a+b*c+b*d*x)*x/(b*d*log(F))+4*e*f^3*F^(a+b*c+b*d*x)*_
+   x^2/(b*d*log(F))+f^4*F^(a+b*c+b*d*x)*x^3/(b*d*log(F))
+--R 
+--R
+--R   (2)
+--R        4 4 4      4 b c + a
+--R       b d e log(F) F       Ei(b d x log(F))
+--R     + 
+--R             3 3 4 3     3 3   3 2     3 3 2 2      3 3 3        3
+--R           (b d f x  + 4b d e f x  + 6b d e f x + 4b d e f)log(F)
+--R         + 
+--R                2 2 4 2     2 2   3      2 2 2 2       2
+--R           (- 3b d f x  - 8b d e f x - 6b d e f )log(F)
+--R         + 
+--R                  4            3            4
+--R           (6b d f x + 8b d e f )log(F) - 6f
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R      4 4      4
+--R     b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      x    4 4      3   3      2 2 2        3     4  %D b d + b c + a
+--R    ++  (%D f  + 4%D e f  + 6%D e f  + 4%D e f + e )F
+--R    |   ------------------------------------------------------------- d%D
+--R   ++                                 %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 413
+
+--S 414 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          4 4      4
+--R         b d log(F)
+--R      *
+--R          x    4 4      3   3      2 2 2        3     4  %D b d + b c + a
+--R        ++  (%D f  + 4%D e f  + 6%D e f  + 4%D e f + e )F
+--R        |   ------------------------------------------------------------- d%D
+--R       ++                                 %D
+--R     + 
+--R          4 4 4      4 b c + a
+--R       - b d e log(F) F       Ei(b d x log(F))
+--R     + 
+--R               3 3 4 3     3 3   3 2     3 3 2 2      3 3 3        3
+--R           (- b d f x  - 4b d e f x  - 6b d e f x - 4b d e f)log(F)
+--R         + 
+--R              2 2 4 2     2 2   3      2 2 2 2       2
+--R           (3b d f x  + 8b d e f x + 6b d e f )log(F)
+--R         + 
+--R                    4            3            4
+--R           (- 6b d f x - 8b d e f )log(F) + 6f
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R      4 4      4
+--R     b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 414
+
+--S 415 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 415
+
+)clear all
+
+--S 416 of 1000
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^2
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    2
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 1000
+r0:=-e^4*F^(a+b*c+b*d*x)/x+4*e^3*f*F^(a+b*c)*Ei(b*d*x*log(F))+_
+   2*f^4*F^(a+b*c+b*d*x)/(b^3*d^3*log(F)^3)-4*e*f^3*F^(a+b*c+b*d*x)/_
+   (b^2*d^2*log(F)^2)-2*f^4*F^(a+b*c+b*d*x)*x/(b^2*d^2*log(F)^2)+_
+   6*e^2*f^2*F^(a+b*c+b*d*x)/(b*d*log(F))+4*e*f^3*F^(a+b*c+b*d*x)*x/_
+   (b*d*log(F))+f^4*F^(a+b*c+b*d*x)*x^2/(b*d*log(F))+b*d*e^4*F^(a+b*c)*_
+   Ei(b*d*x*log(F))*log(F)
+--R 
+--R
+--R   (2)
+--R         4 4 4        4     3 3 3          3  b c + a
+--R       (b d e x log(F)  + 4b d e f x log(F) )F       Ei(b d x log(F))
+--R     + 
+--R              3 3 4      3     2 2 4 3     2 2   3 2     2 2 2 2        2
+--R           - b d e log(F)  + (b d f x  + 4b d e f x  + 6b d e f x)log(F)
+--R         + 
+--R                    4 2           3             4
+--R           (- 2b d f x  - 4b d e f x)log(F) + 2f x
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R      3 3        3
+--R     b d x log(F)
+--R                                                    Type: Expression(Integer)
+--E 417
+
+--S 418 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      x    4 4      3   3      2 2 2        3     4  %D b d + b c + a
+--R    ++  (%D f  + 4%D e f  + 6%D e f  + 4%D e f + e )F
+--R    |   ------------------------------------------------------------- d%D
+--R   ++                                  2
+--R                                     %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 418
+
+--S 419 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          3 3        3
+--R         b d x log(F)
+--R      *
+--R          x    4 4      3   3      2 2 2        3     4  %D b d + b c + a
+--R        ++  (%D f  + 4%D e f  + 6%D e f  + 4%D e f + e )F
+--R        |   ------------------------------------------------------------- d%D
+--R       ++                                  2
+--R                                         %D
+--R     + 
+--R           4 4 4        4     3 3 3          3  b c + a
+--R       (- b d e x log(F)  - 4b d e f x log(F) )F       Ei(b d x log(F))
+--R     + 
+--R            3 3 4      3       2 2 4 3     2 2   3 2     2 2 2 2        2
+--R           b d e log(F)  + (- b d f x  - 4b d e f x  - 6b d e f x)log(F)
+--R         + 
+--R                  4 2           3             4
+--R           (2b d f x  + 4b d e f x)log(F) - 2f x
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R      3 3        3
+--R     b d x log(F)
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 1000
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^3
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    3
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 1000
+r0:=-1/2*e^4*F^(a+b*c+b*d*x)/x^2-4*e^3*f*F^(a+b*c+b*d*x)/x+_
+   6*e^2*f^2*F^(a+b*c)*Ei(b*d*x*log(F))-f^4*F^(a+b*c+b*d*x)/(b^2*d^2*_
+   log(F)^2)+4*e*f^3*F^(a+b*c+b*d*x)/(b*d*log(F))+f^4*F^(a+b*c+b*d*x)*_
+   x/(b*d*log(F))-1/2*b*d*e^4*F^(a+b*c+b*d*x)*log(F)/x+4*b*d*e^3*_
+   f*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)+1/2*b^2*d^2*e^4*F^(a+b*c)*_
+   Ei(b*d*x*log(F))*log(F)^2
+--R 
+--R
+--R   (2)
+--R           4 4 4 2      4     3 3 3   2      3      2 2 2 2 2      2  b c + a
+--R         (b d e x log(F)  + 8b d e f x log(F)  + 12b d e f x log(F) )F
+--R      *
+--R         Ei(b d x log(F))
+--R     + 
+--R              3 3 4        3        2 2 3       2 2 4       2
+--R           - b d e x log(F)  + (- 8b d e f x - b d e )log(F)
+--R         + 
+--R                  4 3           3 2            4 2
+--R           (2b d f x  + 8b d e f x )log(F) - 2f x
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R       2 2 2      2
+--R     2b d x log(F)
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      x    4 4      3   3      2 2 2        3     4  %D b d + b c + a
+--R    ++  (%D f  + 4%D e f  + 6%D e f  + 4%D e f + e )F
+--R    |   ------------------------------------------------------------- d%D
+--R   ++                                  3
+--R                                     %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 423
+
+--S 424 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2 2 2      2
+--R         2b d x log(F)
+--R      *
+--R          x    4 4      3   3      2 2 2        3     4  %D b d + b c + a
+--R        ++  (%D f  + 4%D e f  + 6%D e f  + 4%D e f + e )F
+--R        |   ------------------------------------------------------------- d%D
+--R       ++                                  3
+--R                                         %D
+--R     + 
+--R             4 4 4 2      4     3 3 3   2      3      2 2 2 2 2      2  b c + a
+--R         (- b d e x log(F)  - 8b d e f x log(F)  - 12b d e f x log(F) )F
+--R      *
+--R         Ei(b d x log(F))
+--R     + 
+--R            3 3 4        3      2 2 3       2 2 4       2
+--R           b d e x log(F)  + (8b d e f x + b d e )log(F)
+--R         + 
+--R                    4 3           3 2            4 2
+--R           (- 2b d f x  - 8b d e f x )log(F) + 2f x
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R       2 2 2      2
+--R     2b d x log(F)
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 425
+
+)clear all
+
+--S 426 of 1000
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    4
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 1000
+r0:=-1/3*e^4*F^(a+b*c+b*d*x)/x^3-2*e^3*f*F^(a+b*c+b*d*x)/x^2-6*e^2*_
+   f^2*F^(a+b*c+b*d*x)/x+4*e*f^3*F^(a+b*c)*Ei(b*d*x*log(F))+f^4*_
+   F^(a+b*c+b*d*x)/(b*d*log(F))-1/6*b*d*e^4*F^(a+b*c+b*d*x)*log(F)/x^2-_
+   2*b*d*e^3*f*F^(a+b*c+b*d*x)*log(F)/x+6*b*d*e^2*f^2*F^(a+b*c)*_
+   Ei(b*d*x*log(F))*log(F)-1/6*b^2*d^2*e^4*F^(a+b*c+b*d*x)*log(F)^2/x+_
+   2*b^2*d^2*e^3*f*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^2+1/6*b^3*_
+   d^3*e^4*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^3
+--R 
+--R
+--R   (2)
+--R            4 4 4 3      4      3 3 3   3      3      2 2 2 2 3      2
+--R           b d e x log(F)  + 12b d e f x log(F)  + 36b d e f x log(F)
+--R         + 
+--R                    3 3
+--R           24b d e f x log(F)
+--R      *
+--R          b c + a
+--R         F       Ei(b d x log(F))
+--R     + 
+--R              3 3 4 2      3         2 2 3   2    2 2 4        2
+--R           - b d e x log(F)  + (- 12b d e f x  - b d e x)log(F)
+--R         + 
+--R                     2 2 2          3            4            4 3
+--R           (- 36b d e f x  - 12b d e f x - 2b d e )log(F) + 6f x
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R           3
+--R     6b d x log(F)
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      x    4 4      3   3      2 2 2        3     4  %D b d + b c + a
+--R    ++  (%D f  + 4%D e f  + 6%D e f  + 4%D e f + e )F
+--R    |   ------------------------------------------------------------- d%D
+--R   ++                                  4
+--R                                     %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 428
+
+--S 429 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               3
+--R         6b d x log(F)
+--R      *
+--R          x    4 4      3   3      2 2 2        3     4  %D b d + b c + a
+--R        ++  (%D f  + 4%D e f  + 6%D e f  + 4%D e f + e )F
+--R        |   ------------------------------------------------------------- d%D
+--R       ++                                  4
+--R                                         %D
+--R     + 
+--R              4 4 4 3      4      3 3 3   3      3      2 2 2 2 3      2
+--R           - b d e x log(F)  - 12b d e f x log(F)  - 36b d e f x log(F)
+--R         + 
+--R                      3 3
+--R           - 24b d e f x log(F)
+--R      *
+--R          b c + a
+--R         F       Ei(b d x log(F))
+--R     + 
+--R            3 3 4 2      3       2 2 3   2    2 2 4        2
+--R           b d e x log(F)  + (12b d e f x  + b d e x)log(F)
+--R         + 
+--R                   2 2 2          3            4            4 3
+--R           (36b d e f x  + 12b d e f x + 2b d e )log(F) - 6f x
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R           3
+--R     6b d x log(F)
+--R                                                    Type: Expression(Integer)
+--E 429
+
+--S 430 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 430
+
+)clear all
+
+--S 431 of 1000
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^5
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    5
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1000
+--r0:=-4/3*e^3*f*F^(a+b*c+b*d*x)/x^3-3*e^2*f^2*F^(a+b*c+b*d*x)/x^2-_
+--  4*e*f^3*F^(a+b*c+b*d*x)/x+f^4*F^(a+b*c)*Ei(b*d*x*log(F))-2/3*b*d*_
+--  e^3*f*F^(a+b*c+b*d*x)*log(F)/x^2-3*b*d*e^2*f^2*F^(a+b*c+b*d*x)*_
+--  log(F)/x+4*b*d*e*f^3*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)-2/3*b^2*_
+--  d^2*e^3*f*F^(a+b*c+b*d*x)*log(F)^2/x+3*b^2*d^2*e^2*f^2*F^(a+b*c)*_
+--  Ei(b*d*x*log(F))*log(F)^2+2/3*b^3*d^3*e^3*f*F^(a+b*c)*Ei(b*d*x*_
+--  log(F))*log(F)^3-b^4*d^4*e^4*F^(a+b*c)*GAMMA(-4,-b*d*x*log(F))*log(F)^4
+--E 432
+
+--S 433 of 1000
+--a0:=integrate(t0,x)
+--E 433
+
+--S 434 of 1000
+--m0:=a0-r0
+--E 434
+
+--S 435 of 1000
+--d0:=normalize(D(m0,x))
+--E 435
+
+)clear all
+
+--S 436 of 1000
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^6
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    6
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 1000
+--r0:=-2*e^2*f^2*F^(a+b*c+b*d*x)/x^3-2*e*f^3*F^(a+b*c+b*d*x)/x^2-_
+--  f^4*F^(a+b*c+b*d*x)/x-b*d*e^2*f^2*F^(a+b*c+b*d*x)*log(F)/x^2-2*b*d*_
+--  e*f^3*F^(a+b*c+b*d*x)*log(F)/x+b*d*f^4*F^(a+b*c)*Ei(b*d*x*log(F))*_
+--  log(F)-b^2*d^2*e^2*f^2*F^(a+b*c+b*d*x)*log(F)^2/x+2*b^2*d^2*e*f^3*_
+--  F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^2+b^3*d^3*e^2*f^2*F^(a+b*c)*_
+--  Ei(b*d*x*log(F))*log(F)^3-4*b^4*d^4*e^3*f*F^(a+b*c)*GAMMA(-4,_
+--  -b*d*x*log(F))*log(F)^4+b^5*d^5*e^4*F^(a+b*c)*GAMMA(-5,-b*_
+--  d*x*log(F))*log(F)^5
+--E 437
+
+--S 438 of 1000
+--a0:=integrate(t0,x)
+--E 438
+
+--S 439 of 1000
+--m0:=a0-r0
+--E 439
+
+--S 440 of 1000
+--d0:=normalize(D(m0,x))
+--E 440
+
+)clear all
+
+--S 441 of 1000
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^7
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    7
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 1000
+--r0:=-4/3*e*f^3*F^(a+b*c+b*d*x)/x^3-1/2*f^4*F^(a+b*c+b*d*x)/x^2-_
+--  2/3*b*d*e*f^3*F^(a+b*c+b*d*x)*log(F)/x^2-1/2*b*d*f^4*F^(a+b*c+_
+--  b*d*x)*log(F)/x-2/3*b^2*d^2*e*f^3*F^(a+b*c+b*d*x)*log(F)^2/x+_
+--  1/2*b^2*d^2*f^4*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^2+2/3*b^3*d^3*_
+--  e*f^3*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^3-6*b^4*d^4*e^2*f^2*_
+--  F^(a+b*c)*GAMMA(-4,-b*d*x*log(F))*log(F)^4+4*b^5*d^5*e^3*f*_
+--  F^(a+b*c)*GAMMA(-5,-b*d*x*log(F))*log(F)^5-b^6*d^6*e^4*F^(a+b*c)*_
+--  GAMMA(-6,-b*d*x*log(F))*log(F)^6
+--E 442
+
+--S 443 of 1000
+--a0:=integrate(t0,x)
+--E 443
+
+--S 444 of 1000
+--m0:=a0-r0
+--E 444
+
+--S 445 of 1000
+--d0:=normalize(D(m0,x))
+--E 445
+
+)clear all
+
+--S 446 of 1000
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^8
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    8
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1000
+--r0:=-1/3*f^4*F^(a+b*c+b*d*x)/x^3-1/6*b*d*f^4*F^(a+b*c+b*d*x)*_
+--  log(F)/x^2-1/6*b^2*d^2*f^4*F^(a+b*c+b*d*x)*log(F)^2/x+1/6*b^3*_
+--  d^3*f^4*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^3-4*b^4*d^4*e*f^3*_
+--  F^(a+b*c)*GAMMA(-4,-b*d*x*log(F))*log(F)^4+6*b^5*d^5*e^2*f^2*_
+--  F^(a+b*c)*GAMMA(-5,-b*d*x*log(F))*log(F)^5-4*b^6*d^6*e^3*f*_
+--  F^(a+b*c)*GAMMA(-6,-b*d*x*log(F))*log(F)^6+b^7*d^7*e^4*_
+--  F^(a+b*c)*GAMMA(-7,-b*d*x*log(F))*log(F)^7
+--E 447
+
+--S 448 of 1000
+--a0:=integrate(t0,x)
+--E 448
+
+--S 449 of 1000
+--m0:=a0-r0
+--E 449
+
+--S 450 of 1000
+--d0:=normalize(D(m0,x))
+--E 450
+
+)clear all
+
+--S 451 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)^6
+--R 
+--R
+--R   (1)
+--R        6 6 12        5 6     6   5  11       2 4 6        5   5      6 2 4  10
+--R       b d x   + (6a b d  + 6b c d )x   + (15a b d  + 36a b c d  + 15b c d )x
+--R     + 
+--R           3 3 6      2 4   5        5 2 4      6 3 3  9
+--R       (20a b d  + 90a b c d  + 90a b c d  + 20b c d )x
+--R     + 
+--R           4 2 6       3 3   5       2 4 2 4         5 3 3      6 4 2  8
+--R       (15a b d  + 120a b c d  + 225a b c d  + 120a b c d  + 15b c d )x
+--R     + 
+--R               5   6      4 2   5       3 3 2 4       2 4 3 3        5 4 2
+--R             6a b d  + 90a b c d  + 300a b c d  + 300a b c d  + 90a b c d
+--R           + 
+--R               6 5
+--R             6b c d
+--R      *
+--R          7
+--R         x
+--R     + 
+--R            6 6      5     5       4 2 2 4       3 3 3 3       2 4 4 2
+--R           a d  + 36a b c d  + 225a b c d  + 400a b c d  + 225a b c d
+--R         + 
+--R                5 5     6 6
+--R           36a b c d + b c
+--R      *
+--R          6
+--R         x
+--R     + 
+--R               6   5      5   2 4       4 2 3 3       3 3 4 2      2 4 5
+--R             6a c d  + 90a b c d  + 300a b c d  + 300a b c d  + 90a b c d
+--R           + 
+--R                 5 6
+--R             6a b c
+--R      *
+--R          5
+--R         x
+--R     + 
+--R           6 2 4       5   3 3       4 2 4 2       3 3 5       2 4 6  4
+--R       (15a c d  + 120a b c d  + 225a b c d  + 120a b c d + 15a b c )x
+--R     + 
+--R           6 3 3      5   4 2      4 2 5       3 3 6  3
+--R       (20a c d  + 90a b c d  + 90a b c d + 20a b c )x
+--R     + 
+--R           6 4 2      5   5       4 2 6  2      6 5      5   6      6 6
+--R       (15a c d  + 36a b c d + 15a b c )x  + (6a c d + 6a b c )x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 1000
+--r0:=-(b*c-a*d)^6*GAMMA(7,a+b*x)/b^7-6*d*(b*c-a*d)^5*GAMMA(8,_
+--  a+b*x)/b^7-15*d^2*(b*c-a*d)^4*GAMMA(9,a+b*x)/b^7-20*d^3*(b*c-_
+--  a*d)^3*GAMMA(10,a+b*x)/b^7-15*d^4*(b*c-a*d)^2*GAMMA(11,a+b*x)/b^7-_
+--  6*d^5*(b*c-a*d)*GAMMA(12,a+b*x)/b^7-d^6*GAMMA(13,a+b*x)/b^7
+--E 452
+
+--S 453 of 1000
+--a0:=integrate(t0,x)
+--E 453
+
+--S 454 of 1000
+--m0:=a0-r0
+--E 454
+
+--S 455 of 1000
+--d0:=normalize(D(m0,x))
+--E 455
+
+)clear all
+
+--S 456 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)^5
+--R 
+--R
+--R   (1)
+--R        6 5 11        5 5     6   4  10       2 4 5        5   4      6 2 3  9
+--R       b d x   + (6a b d  + 5b c d )x   + (15a b d  + 30a b c d  + 10b c d )x
+--R     + 
+--R           3 3 5      2 4   4        5 2 3      6 3 2  8
+--R       (20a b d  + 75a b c d  + 60a b c d  + 10b c d )x
+--R     + 
+--R           4 2 5       3 3   4       2 4 2 3        5 3 2     6 4   7
+--R       (15a b d  + 100a b c d  + 150a b c d  + 60a b c d  + 5b c d)x
+--R     + 
+--R          5   5      4 2   4       3 3 2 3       2 4 3 2        5 4     6 5  6
+--R       (6a b d  + 75a b c d  + 200a b c d  + 150a b c d  + 30a b c d + b c )x
+--R     + 
+--R         6 5      5     4       4 2 2 3       3 3 3 2      2 4 4        5 5  5
+--R       (a d  + 30a b c d  + 150a b c d  + 200a b c d  + 75a b c d + 6a b c )x
+--R     + 
+--R          6   4      5   2 3       4 2 3 2       3 3 4       2 4 5  4
+--R       (5a c d  + 60a b c d  + 150a b c d  + 100a b c d + 15a b c )x
+--R     + 
+--R           6 2 3      5   3 2      4 2 4       3 3 5  3
+--R       (10a c d  + 60a b c d  + 75a b c d + 20a b c )x
+--R     + 
+--R           6 3 2      5   4       4 2 5  2      6 4      5   5      6 5
+--R       (10a c d  + 30a b c d + 15a b c )x  + (5a c d + 6a b c )x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 1000
+--r0:=-(b*c-a*d)^5*GAMMA(7,a+b*x)/b^6-5*d*(b*c-a*d)^4*GAMMA(8,a+b*x)/b^6-_
+--  10*d^2*(b*c-a*d)^3*GAMMA(9,a+b*x)/b^6-10*d^3*(b*c-a*d)^2*_
+--  GAMMA(10,a+b*x)/b^6-5*d^4*(b*c-a*d)*GAMMA(11,a+b*x)/b^6-d^5*_
+--  GAMMA(12,a+b*x)/b^6
+--E 457
+
+--S 458 of 1000
+--a0:=integrate(t0,x)
+--E 458
+
+--S 459 of 1000
+--m0:=a0-r0
+--E 459
+
+--S 460 of 1000
+--d0:=normalize(D(m0,x))
+--E 460
+
+)clear all
+
+--S 461 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)^4
+--R 
+--R
+--R   (1)
+--R        6 4 10        5 4     6   3  9       2 4 4        5   3     6 2 2  8
+--R       b d x   + (6a b d  + 4b c d )x  + (15a b d  + 24a b c d  + 6b c d )x
+--R     + 
+--R           3 3 4      2 4   3        5 2 2     6 3   7
+--R       (20a b d  + 60a b c d  + 36a b c d  + 4b c d)x
+--R     + 
+--R           4 2 4      3 3   3      2 4 2 2        5 3     6 4  6
+--R       (15a b d  + 80a b c d  + 90a b c d  + 24a b c d + b c )x
+--R     + 
+--R          5   4      4 2   3       3 3 2 2      2 4 3        5 4  5
+--R       (6a b d  + 60a b c d  + 120a b c d  + 60a b c d + 6a b c )x
+--R     + 
+--R         6 4      5     3      4 2 2 2      3 3 3       2 4 4  4
+--R       (a d  + 24a b c d  + 90a b c d  + 80a b c d + 15a b c )x
+--R     + 
+--R          6   3      5   2 2      4 2 3       3 3 4  3
+--R       (4a c d  + 36a b c d  + 60a b c d + 20a b c )x
+--R     + 
+--R          6 2 2      5   3       4 2 4  2      6 3      5   4      6 4
+--R       (6a c d  + 24a b c d + 15a b c )x  + (4a c d + 6a b c )x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 1000
+--r0:=-(b*c-a*d)^4*GAMMA(7,a+b*x)/b^5-4*d*(b*c-a*d)^3*GAMMA(8,a+b*x)/b^5-_
+--  6*d^2*(b*c-a*d)^2*GAMMA(9,a+b*x)/b^5-4*d^3*(b*c-a*d)*GAMMA(10,a+b*x)/_
+--  b^5-d^4*GAMMA(11,a+b*x)/b^5
+--E 462
+
+--S 463 of 1000
+--a0:=integrate(t0,x)
+--E 463
+
+--S 464 of 1000
+--m0:=a0-r0
+--E 464
+
+--S 465 of 1000
+--d0:=normalize(D(m0,x))
+--E 465
+
+)clear all
+
+--S 466 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)^3
+--R 
+--R
+--R   (1)
+--R        6 3 9        5 3     6   2  8       2 4 3        5   2     6 2   7
+--R       b d x  + (6a b d  + 3b c d )x  + (15a b d  + 18a b c d  + 3b c d)x
+--R     + 
+--R           3 3 3      2 4   2        5 2     6 3  6
+--R       (20a b d  + 45a b c d  + 18a b c d + b c )x
+--R     + 
+--R           4 2 3      3 3   2      2 4 2        5 3  5
+--R       (15a b d  + 60a b c d  + 45a b c d + 6a b c )x
+--R     + 
+--R          5   3      4 2   2      3 3 2       2 4 3  4
+--R       (6a b d  + 45a b c d  + 60a b c d + 15a b c )x
+--R     + 
+--R         6 3      5     2      4 2 2       3 3 3  3
+--R       (a d  + 18a b c d  + 45a b c d + 20a b c )x
+--R     + 
+--R          6   2      5   2       4 2 3  2      6 2      5   3      6 3
+--R       (3a c d  + 18a b c d + 15a b c )x  + (3a c d + 6a b c )x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 1000
+--r0:=-(b*c-a*d)^3*GAMMA(7,a+b*x)/b^4-3*d*(b*c-a*d)^2*GAMMA(8,a+b*x)/b^4-_
+--  3*d^2*(b*c-a*d)*GAMMA(9,a+b*x)/b^4-d^3*GAMMA(10,a+b*x)/b^4
+--E 467
+
+--S 468 of 1000
+--a0:=integrate(t0,x)
+--E 468
+
+--S 469 of 1000
+--m0:=a0-r0
+--E 469
+
+--S 470 of 1000
+--d0:=normalize(D(m0,x))
+--E 470
+
+)clear all
+
+--S 471 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)^2
+--R 
+--R
+--R   (1)
+--R        6 2 8        5 2     6     7       2 4 2        5       6 2  6
+--R       b d x  + (6a b d  + 2b c d)x  + (15a b d  + 12a b c d + b c )x
+--R     + 
+--R           3 3 2      2 4          5 2  5       4 2 2      3 3         2 4 2  4
+--R       (20a b d  + 30a b c d + 6a b c )x  + (15a b d  + 40a b c d + 15a b c )x
+--R     + 
+--R          5   2      4 2         3 3 2  3     6 2      5           4 2 2  2
+--R       (6a b d  + 30a b c d + 20a b c )x  + (a d  + 12a b c d + 15a b c )x
+--R     + 
+--R          6        5   2      6 2
+--R       (2a c d + 6a b c )x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 1000
+--r0:=-(b*c-a*d)^2*GAMMA(7,a+b*x)/b^3-2*d*(b*c-a*d)*GAMMA(8,a+b*x)/b^3-_
+--  d^2*GAMMA(9,a+b*x)/b^3
+--E 472
+
+--S 473 of 1000
+--a0:=integrate(t0,x)
+--E 473
+
+--S 474 of 1000
+--m0:=a0-r0
+--E 474
+
+--S 475 of 1000
+--d0:=normalize(D(m0,x))
+--E 475
+
+)clear all
+
+--S 476 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)
+--R 
+--R
+--R   (1)
+--R        6   7        5     6   6       2 4        5   5       3 3       2 4   4
+--R       b d x  + (6a b d + b c)x  + (15a b d + 6a b c)x  + (20a b d + 15a b c)x
+--R     + 
+--R           4 2       3 3   3      5         4 2   2     6      5         6
+--R       (15a b d + 20a b c)x  + (6a b d + 15a b c)x  + (a d + 6a b c)x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 1000
+--r0:=-(b*c-a*d)*GAMMA(7,a+b*x)/b^2-d*GAMMA(8,a+b*x)/b^2
+--E 477
+
+--S 478 of 1000
+--a0:=integrate(t0,x)
+--E 478
+
+--S 479 of 1000
+--m0:=a0-r0
+--E 479
+
+--S 480 of 1000
+--d0:=normalize(D(m0,x))
+--E 480
+
+)clear all
+
+--S 481 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^6
+--R 
+--R
+--R   (1)
+--R     6 6       5 5      2 4 4      3 3 3      4 2 2     5       6   - b x - a
+--R   (b x  + 6a b x  + 15a b x  + 20a b x  + 15a b x  + 6a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 1000
+--r0:=-GAMMA(7,a+b*x)/b
+--E 482
+
+--S 483 of 1000
+--a0:=integrate(t0,x)
+--E 483
+
+--S 484 of 1000
+--m0:=a0-r0
+--E 484
+
+--S 485 of 1000
+--d0:=normalize(D(m0,x))
+--E 485
+
+)clear all
+
+--S 486 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^6/(c+d*x)
+--R 
+--R
+--R   (1)
+--R     6 6       5 5      2 4 4      3 3 3      4 2 2     5       6   - b x - a
+--R   (b x  + 6a b x  + 15a b x  + 20a b x  + 15a b x  + 6a b x + a )%e
+--R   --------------------------------------------------------------------------
+--R                                     d x + c
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 1000
+--r0:=-6*%e^(-a-b*x)*(b*c-a*d)^2/d^3+2*%e^(-a-b*x)*(b*c-a*d)^3/_
+--  d^4-%e^(-a-b*x)*(b*c-a*d)^4/d^5+%e^(-a-b*x)*(b*c-a*d)^5/d^6-_
+--  6*%e^(-a-b*x)*(b*c-a*d)^2*(a+b*x)/d^3+2*%e^(-a-b*x)*(b*c-a*d)^3*_
+--  (a+b*x)/d^4-%e^(-a-b*x)*(b*c-a*d)^4*(a+b*x)/d^5-3*%e^(-a-b*x)*_
+--  (b*c-a*d)^2*(a+b*x)^2/d^3+%e^(-a-b*x)*(b*c-a*d)^3*(a+b*x)^2/d^4-_
+--  %e^(-a-b*x)*(b*c-a*d)^2*(a+b*x)^3/d^3+%e^(-a+b*c/d)*(b*c-a*d)^6*_
+--  Ei(-b*(c+d*x)/d)/d^7+(b*c-a*d)*GAMMA(5,a+b*x)/d^2-GAMMA(6,a+b*x)/d
+--E 487
+
+--S 488 of 1000
+--a0:=integrate(t0,x)
+--E 488
+
+--S 489 of 1000
+--m0:=a0-r0
+--E 489
+
+--S 490 of 1000
+--d0:=normalize(D(m0,x))
+--E 490
+
+)clear all
+
+--S 491 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^6/(c+d*x)^2
+--R 
+--R
+--R   (1)
+--R     6 6       5 5      2 4 4      3 3 3      4 2 2     5       6   - b x - a
+--R   (b x  + 6a b x  + 15a b x  + 20a b x  + 15a b x  + 6a b x + a )%e
+--R   --------------------------------------------------------------------------
+--R                                2 2             2
+--R                               d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 1000
+--r0:=36*%e^(-a-b*x)*b*(b*c-a*d)/d^3-30*%e^(-a-b*x)*b*(b*c-a*d)^2/d^4+_
+--  20*%e^(-a-b*x)*b*(b*c-a*d)^3/d^5-15*%e^(-a-b*x)*b*(b*c-a*d)^4/d^6-_
+--  %e^(-a-b*x)*(b*c-a*d)^6/(d^7*(c+d*x))+36*%e^(-a-b*x)*b^2*(b*c-a*d)*_
+--  (c+d*x)/d^4-30*%e^(-a-b*x)*b^2*(b*c-a*d)^2*(c+d*x)/d^5+_
+--  20*%e^(-a-b*x)*b^2*(b*c-a*d)^3*(c+d*x)/d^6+18*%e^(-a-b*x)*_
+--  b^3*(b*c-a*d)*(c+d*x)^2/d^5-15*%e^(-a-b*x)*b^3*(b*c-a*d)^2*(c+d*x)^2/_
+--  d^6+6*%e^(-a-b*x)*b^4*(b*c-a*d)*(c+d*x)^3/d^6-6*%e^(-a+b*c/d)*b*_
+--  (b*c-a*d)^5*Ei(-b*(c+d*x)/d)/d^7-%e^(-a+b*c/d)*b*(b*c-a*d)^6*_
+--  Ei(-b*(c+d*x)/d)/d^8-%e^(-a+b*c/d)*b*GAMMA(5,b*(c+d*x)/d)/d^2
+--E 492
+
+--S 493 of 1000
+--a0:=integrate(t0,x)
+--E 493
+
+--S 494 of 1000
+--m0:=a0-r0
+--E 494
+
+--S 495 of 1000
+--d0:=normalize(D(m0,x))
+--E 495
+
+)clear all
+
+--S 496 of 1000
+t0:=%e^(-a-b*x)*(a+b*x)^6/(c+d*x)^3
+--R 
+--R
+--R   (1)
+--R     6 6       5 5      2 4 4      3 3 3      4 2 2     5       6   - b x - a
+--R   (b x  + 6a b x  + 15a b x  + 20a b x  + 15a b x  + 6a b x + a )%e
+--R   --------------------------------------------------------------------------
+--R                           3 3       2 2     2       3
+--R                          d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 1000
+r0:=-6*%e^(-a-b*x)*b^2/d^3+12*%e^(-a-b*x)*b^2*(b*c-a*d)/d^4-15*%e^(-a-b*x)*_
+   b^2*(b*c-a*d)^2/d^5+20*%e^(-a-b*x)*b^2*(b*c-a*d)^3/d^6-1/2*%e^(-a-b*x)*_
+   (b*c-a*d)^6/(d^7*(c+d*x)^2)+6*%e^(-a-b*x)*b*(b*c-a*d)^5/(d^7*(c+d*x))+_
+   1/2*%e^(-a-b*x)*b*(b*c-a*d)^6/(d^8*(c+d*x))-6*%e^(-a-b*x)*b^3*(c+d*x)/_
+   d^4+12*%e^(-a-b*x)*b^3*(b*c-a*d)*(c+d*x)/d^5-15*%e^(-a-b*x)*b^3*_
+   (b*c-a*d)^2*(c+d*x)/d^6-3*%e^(-a-b*x)*b^4*(c+d*x)^2/d^5+6*%e^(-a-b*x)*_
+   b^4*(b*c-a*d)*(c+d*x)^2/d^6-%e^(-a-b*x)*b^5*(c+d*x)^3/d^6+_
+   15*%e^(-a+b*c/d)*b^2*(b*c-a*d)^4*Ei(-b*(c+d*x)/d)/d^7+6*%e^(-a+b*c/d)*_
+   b^2*(b*c-a*d)^5*Ei(-b*(c+d*x)/d)/d^8+1/2*%e^(-a+b*c/d)*b^2*(b*c-a*d)^6*_
+   Ei(-b*(c+d*x)/d)/d^9
+--R 
+--R
+--R   (2)
+--R                 6      5      4  2 8        5      4       3  3   7
+--R               (a  - 12a  + 30a )b d  + (- 6a  + 60a  - 120a )b c d
+--R             + 
+--R                   4       3       2  4 2 6         3       2         5 3 5
+--R               (15a  - 120a  + 180a )b c d  + (- 20a  + 120a  - 120a)b c d
+--R             + 
+--R                   2             6 4 4               7 5 3    8 6 2
+--R               (15a  - 60a + 30)b c d  + (- 6a + 12)b c d  + b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                  6      5      4  2   7         5       4       3  3 2 6
+--R               (2a  - 24a  + 60a )b c d  + (- 12a  + 120a  - 240a )b c d
+--R             + 
+--R                   4       3       2  4 3 5         3       2         5 4 4
+--R               (30a  - 240a  + 360a )b c d  + (- 40a  + 240a  - 240a)b c d
+--R             + 
+--R                   2              6 5 3                7 6 2     8 7
+--R               (30a  - 120a + 60)b c d  + (- 12a + 24)b c d  + 2b c d
+--R          *
+--R             x
+--R         + 
+--R             6      5      4  2 2 6        5      4       3  3 3 5
+--R           (a  - 12a  + 30a )b c d  + (- 6a  + 60a  - 120a )b c d
+--R         + 
+--R               4       3       2  4 4 4         3       2         5 5 3
+--R           (15a  - 120a  + 180a )b c d  + (- 20a  + 120a  - 120a)b c d
+--R         + 
+--R               2             6 6 2               7 7     8 8
+--R           (15a  - 60a + 30)b c d  + (- 6a + 12)b c d + b c
+--R      *
+--R                            - a d + b c
+--R                            -----------
+--R            - b d x - b c        d
+--R         Ei(-------------)%e
+--R                  d
+--R     + 
+--R               5 8 5                4 8     5   7  4
+--R           - 2b d x  + ((- 12a - 6)b d  + 2b c d )x
+--R         + 
+--R                  2             3 8        4   7     5 2 6  3
+--R           ((- 30a  - 24a - 12)b d  + 12a b c d  - 2b c d )x
+--R         + 
+--R                     3      2             2 8       2             3   7
+--R               (- 40a  - 30a  - 24a - 12)b d  + (30a  - 12a - 12)b c d
+--R             + 
+--R                           4 2 6     5 3 5
+--R               (- 12a + 6)b c d  + 2b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                 6      5    8        5      4      3      2             2   7
+--R               (a  - 12a )b d  + (- 6a  + 60a  - 80a  - 60a  - 48a - 24)b c d
+--R             + 
+--R                   4       3       2             3 2 6
+--R               (15a  - 120a  + 150a  + 48a + 12)b c d
+--R             + 
+--R                     3       2              4 3 5       2             5 4 4
+--R               (- 20a  + 120a  - 108a - 12)b c d  + (15a  - 60a + 28)b c d
+--R             + 
+--R                           6 5 3    7 6 2
+--R               (- 6a + 12)b c d  + b c d
+--R          *
+--R             x
+--R         + 
+--R              6 8     6     5      7
+--R           - a d  + (a  - 6a )b c d
+--R         + 
+--R                5      4      3      2             2 2 6
+--R           (- 6a  + 45a  - 40a  - 30a  - 24a - 12)b c d
+--R         + 
+--R               4       3      2             3 3 5
+--R           (15a  - 100a  + 90a  + 36a + 12)b c d
+--R         + 
+--R                 3       2             4 4 4       2             5 5 3
+--R           (- 20a  + 105a  - 72a - 12)b c d  + (15a  - 54a + 20)b c d
+--R         + 
+--R                       6 6 2    7 7
+--R           (- 6a + 11)b c d  + b c d
+--R      *
+--R           - b x - a
+--R         %e
+--R  /
+--R       11 2       10      2 9
+--R     2d  x  + 4c d  x + 2c d
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   INTSIGN
+--R  ,
+--R      x
+--R  ,
+--R                  6 6      5   5       4 2 4       3 3 3       2 4 2        5
+--R                %D b  + 6%D a b  + 15%D a b  + 20%D a b  + 15%D a b  + 6%D a b
+--R              + 
+--R                 6
+--R                a
+--R         *
+--R              - %D b - a
+--R            %e
+--R       /
+--R            3 3      2   2        2     3
+--R          %D d  + 3%D c d  + 3%D c d + c
+--R     *
+--R        d%D
+--R                                         Type: Union(Expression(Integer),...)
+--E 498
+
+--S 499 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            11 2       10      2 9
+--R         (2d  x  + 4c d  x + 2c d )
+--R      *
+--R         INTSIGN
+--R        ,
+--R            x
+--R        ,
+--R                      6 6      5   5       4 2 4       3 3 3       2 4 2
+--R                    %D b  + 6%D a b  + 15%D a b  + 20%D a b  + 15%D a b
+--R                  + 
+--R                         5     6
+--R                    6%D a b + a
+--R               *
+--R                    - %D b - a
+--R                  %e
+--R             /
+--R                  3 3      2   2        2     3
+--R                %D d  + 3%D c d  + 3%D c d + c
+--R           *
+--R              d%D
+--R     + 
+--R                   6      5      4  2 8      5      4       3  3   7
+--R               (- a  + 12a  - 30a )b d  + (6a  - 60a  + 120a )b c d
+--R             + 
+--R                     4       3       2  4 2 6       3       2         5 3 5
+--R               (- 15a  + 120a  - 180a )b c d  + (20a  - 120a  + 120a)b c d
+--R             + 
+--R                     2             6 4 4             7 5 3    8 6 2
+--R               (- 15a  + 60a - 30)b c d  + (6a - 12)b c d  - b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    6      5      4  2   7       5       4       3  3 2 6
+--R               (- 2a  + 24a  - 60a )b c d  + (12a  - 120a  + 240a )b c d
+--R             + 
+--R                     4       3       2  4 3 5       3       2         5 4 4
+--R               (- 30a  + 240a  - 360a )b c d  + (40a  - 240a  + 240a)b c d
+--R             + 
+--R                     2              6 5 3              7 6 2     8 7
+--R               (- 30a  + 120a - 60)b c d  + (12a - 24)b c d  - 2b c d
+--R          *
+--R             x
+--R         + 
+--R               6      5      4  2 2 6      5      4       3  3 3 5
+--R           (- a  + 12a  - 30a )b c d  + (6a  - 60a  + 120a )b c d
+--R         + 
+--R                 4       3       2  4 4 4       3       2         5 5 3
+--R           (- 15a  + 120a  - 180a )b c d  + (20a  - 120a  + 120a)b c d
+--R         + 
+--R                 2             6 6 2             7 7     8 8
+--R           (- 15a  + 60a - 30)b c d  + (6a - 12)b c d - b c
+--R      *
+--R                            - a d + b c
+--R                            -----------
+--R            - b d x - b c        d
+--R         Ei(-------------)%e
+--R                  d
+--R     + 
+--R             5 8 5              4 8     5   7  4
+--R           2b d x  + ((12a + 6)b d  - 2b c d )x
+--R         + 
+--R                2             3 8        4   7     5 2 6  3
+--R           ((30a  + 24a + 12)b d  - 12a b c d  + 2b c d )x
+--R         + 
+--R                   3      2             2 8         2             3   7
+--R               (40a  + 30a  + 24a + 12)b d  + (- 30a  + 12a + 12)b c d
+--R             + 
+--R                         4 2 6     5 3 5
+--R               (12a - 6)b c d  - 2b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                   6      5    8      5      4      3      2             2   7
+--R               (- a  + 12a )b d  + (6a  - 60a  + 80a  + 60a  + 48a + 24)b c d
+--R             + 
+--R                     4       3       2             3 2 6
+--R               (- 15a  + 120a  - 150a  - 48a - 12)b c d
+--R             + 
+--R                   3       2              4 3 5         2             5 4 4
+--R               (20a  - 120a  + 108a + 12)b c d  + (- 15a  + 60a - 28)b c d
+--R             + 
+--R                         6 5 3    7 6 2
+--R               (6a - 12)b c d  - b c d
+--R          *
+--R             x
+--R         + 
+--R            6 8       6     5      7
+--R           a d  + (- a  + 6a )b c d
+--R         + 
+--R              5      4      3      2             2 2 6
+--R           (6a  - 45a  + 40a  + 30a  + 24a + 12)b c d
+--R         + 
+--R                 4       3      2             3 3 5
+--R           (- 15a  + 100a  - 90a  - 36a - 12)b c d
+--R         + 
+--R               3       2             4 4 4         2             5 5 3
+--R           (20a  - 105a  + 72a + 12)b c d  + (- 15a  + 54a - 20)b c d
+--R         + 
+--R                     6 6 2    7 7
+--R           (6a - 11)b c d  - b c d
+--R      *
+--R           - b x - a
+--R         %e
+--R  /
+--R       11 2       10      2 9
+--R     2d  x  + 4c d  x + 2c d
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 500
+
+)clear all
+
+--S 501 of 1000
+t0:=f^(a+b*x^2)*x^m
+--R 
+--R
+--R            2
+--R         b x  + a m
+--R   (1)  f        x
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 1000
+--r0:=-1/2*f^a*x^(1+m)*GAMMA(1/2*(1+m),-b*x^2*log(f))*_
+--  (-b*x^2*log(f))^(1/2*(-1-m))
+--E 502
+
+--S 503 of 1000
+--a0:=integrate(t0,x)
+--E 503
+
+--S 504 of 1000
+--m0:=a0-r0
+--E 504
+
+--S 505 of 1000
+--d0:=normalize(D(m0,x))
+--E 505
+
+)clear all
+
+--S 506 of 1000
+t0:=f^(a+b*x^2)*x^11
+--R 
+--R
+--R               2
+--R         11 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 1000
+--r0:=-1/2*f^a*GAMMA(6,-b*x^2*log(f))/(b^6*log(f)^6)
+--E 507
+
+--S 508 of 1000
+--a0:=integrate(t0,x)
+--E 508
+
+--S 509 of 1000
+--m0:=a0-r0
+--E 509
+
+--S 510 of 1000
+--d0:=normalize(D(m0,x))
+--E 510
+
+)clear all
+
+--S 511 of 1000
+t0:=f^(a+b*x^2)*x^9
+--R 
+--R
+--R              2
+--R         9 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 1000
+--r0:=1/2*f^a*GAMMA(5,-b*x^2*log(f))/(b^5*log(f)^5)
+--E 512
+
+--S 513 of 1000
+--a0:=integrate(t0,x)
+--E 513
+
+--S 514 of 1000
+--m0:=a0-r0
+--E 514
+
+--S 515 of 1000
+--d0:=normalize(D(m0,x))
+--E 515
+
+)clear all
+
+--S 516 of 1000
+t0:=f^(a+b*x^2)*x^7
+--R 
+--R
+--R              2
+--R         7 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 1000
+r0:=-3*f^(a+b*x^2)/(b^4*log(f)^4)+3*f^(a+b*x^2)*x^2/(b^3*log(f)^3)-_
+   3/2*f^(a+b*x^2)*x^4/(b^2*log(f)^2)+1/2*f^(a+b*x^2)*x^6/(b*log(f))
+--R 
+--R
+--R                                                          2
+--R          3 6      3     2 4      2       2            b x  + a
+--R        (b x log(f)  - 3b x log(f)  + 6b x log(f) - 6)f
+--R   (2)  -------------------------------------------------------
+--R                                 4      4
+--R                               2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                            2
+--R          3 6      3     2 4      2       2             (b x  + a)log(f)
+--R        (b x log(f)  - 3b x log(f)  + 6b x log(f) - 6)%e
+--R   (3)  ----------------------------------------------------------------
+--R                                     4      4
+--R                                   2b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 518
+
+--S 519 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                           2
+--R         3 6      3     2 4      2       2             (b x  + a)log(f)
+--R       (b x log(f)  - 3b x log(f)  + 6b x log(f) - 6)%e
+--R     + 
+--R                                                           2
+--R           3 6      3     2 4      2       2            b x  + a
+--R       (- b x log(f)  + 3b x log(f)  - 6b x log(f) + 6)f
+--R  /
+--R       4      4
+--R     2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 520
+
+)clear all
+
+--S 521 of 1000
+t0:=f^(a+b*x^2)*x^5
+--R 
+--R
+--R              2
+--R         5 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 1000
+r0:=f^(a+b*x^2)/(b^3*log(f)^3)-f^(a+b*x^2)*x^2/(b^2*log(f)^2)+_
+   1/2*f^(a+b*x^2)*x^4/(b*log(f))
+--R 
+--R
+--R                                           2
+--R          2 4      2       2            b x  + a
+--R        (b x log(f)  - 2b x log(f) + 2)f
+--R   (2)  ----------------------------------------
+--R                         3      3
+--R                       2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                             2
+--R          2 4      2       2             (b x  + a)log(f)
+--R        (b x log(f)  - 2b x log(f) + 2)%e
+--R   (3)  -------------------------------------------------
+--R                              3      3
+--R                            2b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 523
+
+--S 524 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            2
+--R         2 4      2       2             (b x  + a)log(f)
+--R       (b x log(f)  - 2b x log(f) + 2)%e
+--R     + 
+--R                                            2
+--R           2 4      2       2            b x  + a
+--R       (- b x log(f)  + 2b x log(f) - 2)f
+--R  /
+--R       3      3
+--R     2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 1000
+t0:=f^(a+b*x^2)*x^3
+--R 
+--R
+--R              2
+--R         3 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 1000
+r0:=-1/2*f^(a+b*x^2)/(b^2*log(f)^2)+1/2*f^(a+b*x^2)*x^2/(b*log(f))
+--R 
+--R
+--R                            2
+--R            2            b x  + a
+--R        (b x log(f) - 1)f
+--R   (2)  -------------------------
+--R                  2      2
+--R                2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                              2
+--R            2             (b x  + a)log(f)
+--R        (b x log(f) - 1)%e
+--R   (3)  ----------------------------------
+--R                      2      2
+--R                    2b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 528
+
+--S 529 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                              2                                    2
+--R            2             (b x  + a)log(f)         2            b x  + a
+--R        (b x log(f) - 1)%e                 + (- b x log(f) + 1)f
+--R   (4)  ----------------------------------------------------------------
+--R                                     2      2
+--R                                   2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 530
+
+)clear all
+
+--S 531 of 1000
+t0:=f^(a+b*x^2)*x
+--R 
+--R
+--R              2
+--R           b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 1000
+r0:=1/2*f^(a+b*x^2)/(b*log(f))
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (2)  ---------
+--R        2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R          (b x  + a)log(f)
+--R        %e
+--R   (3)  ------------------
+--R             2b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 533
+
+--S 534 of 1000
+m0:=a0-r0
+--R 
+--R
+--R              2                  2
+--R          (b x  + a)log(f)    b x  + a
+--R        %e                 - f
+--R   (4)  ------------------------------
+--R                   2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 535
+
+)clear all
+
+--S 536 of 1000
+t0:=f^(a+b*x^2)/x
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1000
+r0:=1/2*f^a*Ei(b*x^2*log(f))
+--R 
+--R
+--R         a      2
+--R        f Ei(b x log(f))
+--R   (2)  ----------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2
+--R           x  %D b + a
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++       %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 538
+
+--S 539 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                 2
+--R            x  %D b + a
+--R          ++  f                 a      2
+--R        2 |   --------- d%D  - f Ei(b x log(f))
+--R         ++       %D
+--R   (4)  ---------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 1000
+t0:=f^(a+b*x^2)/x^3
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 1000
+r0:=-1/2*f^(a+b*x^2)/x^2+1/2*b*f^a*Ei(b*x^2*log(f))*log(f)
+--R 
+--R
+--R                                         2
+--R           2       a      2           b x  + a
+--R        b x log(f)f Ei(b x log(f)) - f
+--R   (2)  --------------------------------------
+--R                            2
+--R                          2x
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2
+--R           x  %D b + a
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++        3
+--R                %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 543
+
+--S 544 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                   2
+--R              x  %D b + a                                         2
+--R          2 ++  f                   2       a      2           b x  + a
+--R        2x  |   --------- d%D  - b x log(f)f Ei(b x log(f)) + f
+--R           ++        3
+--R                   %D
+--R   (4)  ---------------------------------------------------------------
+--R                                        2
+--R                                      2x
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 545
+
+)clear all
+
+--S 546 of 1000
+t0:=f^(a+b*x^2)/x^5
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             5
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 1000
+r0:=-1/4*f^(a+b*x^2)/x^4-1/4*b*f^(a+b*x^2)*log(f)/x^2+1/4*b^2*f^a*_
+   Ei(b*x^2*log(f))*log(f)^2
+--R 
+--R
+--R                                                            2
+--R         2 4      2 a      2                2            b x  + a
+--R        b x log(f) f Ei(b x log(f)) + (- b x log(f) - 1)f
+--R   (2)  ---------------------------------------------------------
+--R                                     4
+--R                                   4x
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2
+--R           x  %D b + a
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++        5
+--R                %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 548
+
+--S 549 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  2
+--R             x  %D b + a
+--R         4 ++  f                 2 4      2 a      2
+--R       4x  |   --------- d%D  - b x log(f) f Ei(b x log(f))
+--R          ++        5
+--R                  %D
+--R     + 
+--R                           2
+--R           2            b x  + a
+--R       (b x log(f) + 1)f
+--R  /
+--R       4
+--R     4x
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 550
+
+)clear all
+
+--S 551 of 1000
+t0:=f^(a+b*x^2)/x^7
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             7
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 1000
+r0:=-1/6*f^(a+b*x^2)/x^6-1/12*b*f^(a+b*x^2)*log(f)/x^4-_
+   1/12*b^2*f^(a+b*x^2)*log(f)^2/x^2+1/12*b^3*f^a*Ei(b*x^2*log(f))*log(f)^3
+--R 
+--R
+--R   (2)
+--R                                                                     2
+--R    3 6      3 a      2              2 4      2      2            b x  + a
+--R   b x log(f) f Ei(b x log(f)) + (- b x log(f)  - b x log(f) - 2)f
+--R   -----------------------------------------------------------------------
+--R                                        6
+--R                                     12x
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2
+--R           x  %D b + a
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++        7
+--R                %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 553
+
+--S 554 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   2
+--R              x  %D b + a
+--R          6 ++  f                 3 6      3 a      2
+--R       12x  |   --------- d%D  - b x log(f) f Ei(b x log(f))
+--R           ++        7
+--R                   %D
+--R     + 
+--R                                         2
+--R         2 4      2      2            b x  + a
+--R       (b x log(f)  + b x log(f) + 2)f
+--R  /
+--R        6
+--R     12x
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 1000
+t0:=f^(a+b*x^2)/x^9
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             9
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 1000
+--r0:=-1/2*b^4*f^a*GAMMA(-4,-b*x^2*log(f))*log(f)^4
+--E 557
+
+--S 558 of 1000
+--a0:=integrate(t0,x)
+--E 558
+
+--S 559 of 1000
+--m0:=a0-r0
+--E 559
+
+--S 560 of 1000
+--d0:=normalize(D(m0,x))
+--E 560
+
+)clear all
+
+--S 561 of 1000
+t0:=f^(a+b*x^2)/x^11
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            11
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 1000
+--r0:=1/2*b^5*f^a*GAMMA(-5,-b*x^2*log(f))*log(f)^5
+--E 562
+
+--S 563 of 1000
+--a0:=integrate(t0,x)
+--E 563
+
+--S 564 of 1000
+--m0:=a0-r0
+--E 564
+
+--S 565 of 1000
+--d0:=normalize(D(m0,x))
+--E 565
+
+)clear all
+
+--S 566 of 1000
+t0:=f^(a+b*x^2)*x^12
+--R 
+--R
+--R               2
+--R         12 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1000
+--r0:=-1/2*f^a*x^13*GAMMA(13/2,-b*x^2*log(f))/(-b*x^2*log(f))^(13/2)
+--E 567
+
+--S 568 of 1000
+--a0:=integrate(t0,x)
+--E 568
+
+--S 569 of 1000
+--m0:=a0-r0
+--E 569
+
+--S 570 of 1000
+--d0:=normalize(D(m0,x))
+--E 570
+
+)clear all
+
+--S 571 of 1000
+t0:=f^(a+b*x^2)*x^10
+--R 
+--R
+--R               2
+--R         10 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 1000
+--r0:=-1/2*f^a*x^11*GAMMA(11/2,-b*x^2*log(f))/(-b*x^2*log(f))^(11/2)
+--E 572
+
+--S 573 of 1000
+--a0:=integrate(t0,x)
+--E 573
+
+--S 574 of 1000
+--m0:=a0-r0
+--E 574
+
+--S 575 of 1000
+--d0:=normalize(D(m0,x))
+--E 575
+
+)clear all
+
+--S 576 of 1000
+t0:=f^(a+b*x^2)*x^8
+--R 
+--R
+--R              2
+--R         8 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 1000
+--r0:=-105/16*f^(a+b*x^2)*x/(b^4*log(f)^4)+35/8*f^(a+b*x^2)*x^3/_
+--  (b^3*log(f)^3)-7/4*f^(a+b*x^2)*x^5/(b^2*log(f)^2)+1/2*f^(a+b*x^2)*_
+--  x^7/(b*log(f))+105/32*f^a*erfi(x*sqrt(b)*sqrt(log(f)))*_
+--  sqrt(%pi)/(b^(9/2)*log(f)^(9/2))
+--E 577
+
+--S 578 of 1000
+--a0:=integrate(t0,x)
+--E 578
+
+--S 579 of 1000
+--m0:=a0-r0
+--E 579
+
+--S 580 of 1000
+--d0:=normalize(D(m0,x))
+--E 580
+
+)clear all
+
+--S 581 of 1000
+t0:=f^(a+b*x^2)*x^6
+--R 
+--R
+--R              2
+--R         6 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1000
+--r0:=15/8*f^(a+b*x^2)*x/(b^3*log(f)^3)-5/4*f^(a+b*x^2)*x^3/_
+--  (b^2*log(f)^2)+1/2*f^(a+b*x^2)*x^5/(b*log(f))-15/16*f^a*_
+--  erfi(x*sqrt(b)*sqrt(log(f)))*sqrt(%pi)/(b^(7/2)*log(f)^(7/2))
+--E 582
+
+--S 583 of 1000
+--a0:=integrate(t0,x)
+--E 583
+
+--S 584 of 1000
+--m0:=a0-r0
+--E 584
+
+--S 585 of 1000
+--d0:=normalize(D(m0,x))
+--E 585
+
+)clear all
+
+--S 586 of 1000
+t0:=f^(a+b*x^2)*x^4
+--R 
+--R
+--R              2
+--R         4 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 1000
+--r0:=-3/4*f^(a+b*x^2)*x/(b^2*log(f)^2)+1/2*f^(a+b*x^2)*x^3/(b*log(f))+_
+--  3/8*f^a*erfi(x*sqrt(b)*sqrt(log(f)))*sqrt(%pi)/(b^(5/2)*log(f)^(5/2))
+--E 587
+
+--S 588 of 1000
+--a0:=integrate(t0,x)
+--E 588
+
+--S 589 of 1000
+--m0:=a0-r0
+--E 589
+
+--S 590 of 1000
+--d0:=normalize(D(m0,x))
+--E 590
+
+)clear all
+
+--S 591 of 1000
+t0:=f^(a+b*x^2)*x^2
+--R 
+--R
+--R              2
+--R         2 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 1000
+--r0:=1/2*f^(a+b*x^2)*x/(b*log(f))-1/4*f^a*erfi(x*sqrt(b)*sqrt(log(f)))*_
+--  sqrt(%pi)/(b^(3/2)*log(f)^(3/2))
+--E 592
+
+--S 593 of 1000
+--a0:=integrate(t0,x)
+--E 593
+
+--S 594 of 1000
+--m0:=a0-r0
+--E 594
+
+--S 595 of 1000
+--d0:=normalize(D(m0,x))
+--E 595
+
+)clear all
+
+--S 596 of 1000
+t0:=f^(a+b*x^2)
+--R 
+--R
+--R            2
+--R         b x  + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1000
+--r0:=1/2*f^a*erfi(x*sqrt(b)*sqrt(log(f)))*sqrt(%pi)/(sqrt(b)*sqrt(log(f)))
+--E 597
+
+--S 598 of 1000
+--a0:=integrate(t0,x)
+--E 598
+
+--S 599 of 1000
+--m0:=a0-r0
+--E 599
+
+--S 600 of 1000
+--d0:=normalize(D(m0,x))
+--E 600
+
+)clear all
+
+--S 601 of 1000
+t0:=f^(a+b*x^2)/x^2
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 1000
+--r0:=-f^(a+b*x^2)/x+f^a*erfi(x*sqrt(b)*sqrt(log(f)))*sqrt(%pi)*_
+--  sqrt(b)*sqrt(log(f))
+--E 602
+
+--S 603 of 1000
+--a0:=integrate(t0,x)
+--E 603
+
+--S 604 of 1000
+--m0:=a0-r0
+--E 604
+
+--S 605 of 1000
+--d0:=normalize(D(m0,x))
+--E 605
+
+)clear all
+
+--S 606 of 1000
+t0:=f^(a+b*x^2)/x^4
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             4
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 1000
+--r0:=-1/3*f^(a+b*x^2)/x^3-2/3*b*f^(a+b*x^2)*log(f)/x+2/3*b^(3/2)*f^a*_
+--  erfi(x*sqrt(b)*sqrt(log(f)))*log(f)^(3/2)*sqrt(%pi)
+--E 607
+
+--S 608 of 1000
+--a0:=integrate(t0,x)
+--E 608
+
+--S 609 of 1000
+--m0:=a0-r0
+--E 609
+
+--S 610 of 1000
+--d0:=normalize(D(m0,x))
+--E 610
+
+)clear all
+
+--S 611 of 1000
+t0:=f^(a+b*x^2)/x^6
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             6
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 1000
+--r0:=-1/5*f^(a+b*x^2)/x^5-2/15*b*f^(a+b*x^2)*log(f)/x^3-4/15*b^2*_
+--  f^(a+b*x^2)*log(f)^2/x+4/15*b^(5/2)*f^a*erfi(x*sqrt(b)*_
+--  sqrt(log(f)))*log(f)^(5/2)*sqrt(%pi)
+--E 612
+
+--S 613 of 1000
+--a0:=integrate(t0,x)
+--E 613
+
+--S 614 of 1000
+--m0:=a0-r0
+--E 614
+
+--S 615 of 1000
+--d0:=normalize(D(m0,x))
+--E 615
+
+)clear all
+
+--S 616 of 1000
+t0:=f^(a+b*x^2)/x^8
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             8
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 1000
+--r0:=-1/7*f^(a+b*x^2)/x^7-2/35*b*f^(a+b*x^2)*log(f)/x^5-4/105*b^2*_
+--  f^(a+b*x^2)*log(f)^2/x^3-8/105*b^3*f^(a+b*x^2)*log(f)^3/x+_
+--  8/105*b^(7/2)*f^a*erfi(x*sqrt(b)*sqrt(log(f)))*log(f)^(7/2)*sqrt(%pi)
+--E 617
+
+--S 618 of 1000
+--a0:=integrate(t0,x)
+--E 618
+
+--S 619 of 1000
+--m0:=a0-r0
+--E 619
+
+--S 620 of 1000
+--d0:=normalize(D(m0,x))
+--E 620
+
+)clear all
+
+--S 621 of 1000
+t0:=f^(a+b*x^2)/x^10
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            10
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 1000
+--r0:=-1/2*f^a*GAMMA(-9/2,-b*x^2*log(f))*(-b*x^2*log(f))^(9/2)/x^9
+--E 622
+
+--S 623 of 1000
+--a0:=integrate(t0,x)
+--E 623
+
+--S 624 of 1000
+--m0:=a0-r0
+--E 624
+
+--S 625 of 1000
+--d0:=normalize(D(m0,x))
+--E 625
+
+)clear all
+
+--S 626 of 1000
+t0:=f^(a+b*x^2)/x^12
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            12
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 1000
+--r0:=-1/2*f^a*GAMMA(-11/2,-b*x^2*log(f))*(-b*x^2*log(f))^(11/2)/x^11
+--E 627
+
+--S 628 of 1000
+--a0:=integrate(t0,x)
+--E 628
+
+--S 629 of 1000
+--m0:=a0-r0
+--E 629
+
+--S 630 of 1000
+--d0:=normalize(D(m0,x))
+--E 630
+
+)clear all
+
+--S 631 of 1000
+t0:=f^(a+b*x^3)*x^m
+--R 
+--R
+--R            3
+--R         b x  + a m
+--R   (1)  f        x
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 1000
+--r0:=-1/3*f^a*x^(1+m)*GAMMA(1/3*(1+m),-b*x^3*log(f))*_
+--  (-b*x^3*log(f))^(1/3*(-1-m))
+--E 632
+
+--S 633 of 1000
+--a0:=integrate(t0,x)
+--E 633
+
+--S 634 of 1000
+--m0:=a0-r0
+--E 634
+
+--S 635 of 1000
+--d0:=normalize(D(m0,x))
+--E 635
+
+)clear all
+
+--S 636 of 1000
+t0:=f^(a+b*x^3)*x^17
+--R 
+--R
+--R               3
+--R         17 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 1000
+--r0:=-1/3*f^a*GAMMA(6,-b*x^3*log(f))/(b^6*log(f)^6)
+--E 637
+
+--S 638 of 1000
+--a0:=integrate(t0,x)
+--E 638
+
+--S 639 of 1000
+--m0:=a0-r0
+--E 639
+
+--S 640 of 1000
+--d0:=normalize(D(m0,x))
+--E 640
+
+)clear all
+
+--S 641 of 1000
+t0:=f^(a+b*x^3)*x^14
+--R 
+--R
+--R               3
+--R         14 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 1000
+--r0:=1/3*f^a*GAMMA(5,-b*x^3*log(f))/(b^5*log(f)^5)
+--E 642
+
+--S 643 of 1000
+--a0:=integrate(t0,x)
+--E 643
+
+--S 644 of 1000
+--m0:=a0-r0
+--E 644
+
+--S 645 of 1000
+--d0:=normalize(D(m0,x))
+--E 645
+
+)clear all
+
+--S 646 of 1000
+t0:=f^(a+b*x^3)*x^11
+--R 
+--R
+--R               3
+--R         11 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 1000
+r0:=-2*f^(a+b*x^3)/(b^4*log(f)^4)+2*f^(a+b*x^3)*x^3/(b^3*log(f)^3)-_
+   f^(a+b*x^3)*x^6/(b^2*log(f)^2)+1/3*f^(a+b*x^3)*x^9/(b*log(f))
+--R 
+--R
+--R                                                          3
+--R          3 9      3     2 6      2       3            b x  + a
+--R        (b x log(f)  - 3b x log(f)  + 6b x log(f) - 6)f
+--R   (2)  -------------------------------------------------------
+--R                                 4      4
+--R                               3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                            3
+--R          3 9      3     2 6      2       3             (b x  + a)log(f)
+--R        (b x log(f)  - 3b x log(f)  + 6b x log(f) - 6)%e
+--R   (3)  ----------------------------------------------------------------
+--R                                     4      4
+--R                                   3b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 648
+
+--S 649 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                           3
+--R         3 9      3     2 6      2       3             (b x  + a)log(f)
+--R       (b x log(f)  - 3b x log(f)  + 6b x log(f) - 6)%e
+--R     + 
+--R                                                           3
+--R           3 9      3     2 6      2       3            b x  + a
+--R       (- b x log(f)  + 3b x log(f)  - 6b x log(f) + 6)f
+--R  /
+--R       4      4
+--R     3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 649
+
+--S 650 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 650
+
+)clear all
+
+--S 651 of 1000
+t0:=f^(a+b*x^3)*x^8
+--R 
+--R
+--R              3
+--R         8 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 1000
+r0:=2/3*f^(a+b*x^3)/(b^3*log(f)^3)-2/3*f^(a+b*x^3)*x^3/(b^2*log(f)^2)+_
+   1/3*f^(a+b*x^3)*x^6/(b*log(f))
+--R 
+--R
+--R                                           3
+--R          2 6      2       3            b x  + a
+--R        (b x log(f)  - 2b x log(f) + 2)f
+--R   (2)  ----------------------------------------
+--R                         3      3
+--R                       3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                             3
+--R          2 6      2       3             (b x  + a)log(f)
+--R        (b x log(f)  - 2b x log(f) + 2)%e
+--R   (3)  -------------------------------------------------
+--R                              3      3
+--R                            3b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 653
+
+--S 654 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            3
+--R         2 6      2       3             (b x  + a)log(f)
+--R       (b x log(f)  - 2b x log(f) + 2)%e
+--R     + 
+--R                                            3
+--R           2 6      2       3            b x  + a
+--R       (- b x log(f)  + 2b x log(f) - 2)f
+--R  /
+--R       3      3
+--R     3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 654
+
+--S 655 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 655
+
+)clear all
+
+--S 656 of 1000
+t0:=f^(a+b*x^3)*x^5
+--R 
+--R
+--R              3
+--R         5 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 1000
+r0:=-1/3*f^(a+b*x^3)/(b^2*log(f)^2)+1/3*f^(a+b*x^3)*x^3/(b*log(f))
+--R 
+--R
+--R                            3
+--R            3            b x  + a
+--R        (b x log(f) - 1)f
+--R   (2)  -------------------------
+--R                  2      2
+--R                3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 657
+
+--S 658 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                              3
+--R            3             (b x  + a)log(f)
+--R        (b x log(f) - 1)%e
+--R   (3)  ----------------------------------
+--R                      2      2
+--R                    3b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 658
+
+--S 659 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                              3                                    3
+--R            3             (b x  + a)log(f)         3            b x  + a
+--R        (b x log(f) - 1)%e                 + (- b x log(f) + 1)f
+--R   (4)  ----------------------------------------------------------------
+--R                                     2      2
+--R                                   3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 659
+
+--S 660 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 660
+
+)clear all
+
+--S 661 of 1000
+t0:=f^(a+b*x^3)*x^2
+--R 
+--R
+--R              3
+--R         2 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 1000
+r0:=1/3*f^(a+b*x^3)/(b*log(f))
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (2)  ---------
+--R        3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3
+--R          (b x  + a)log(f)
+--R        %e
+--R   (3)  ------------------
+--R             3b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 663
+
+--S 664 of 1000
+m0:=a0-r0
+--R 
+--R
+--R              3                  3
+--R          (b x  + a)log(f)    b x  + a
+--R        %e                 - f
+--R   (4)  ------------------------------
+--R                   3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 664
+
+--S 665 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 665
+
+)clear all
+
+--S 666 of 1000
+t0:=f^(a+b*x^3)/x
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 1000
+r0:=1/3*f^a*Ei(b*x^3*log(f))
+--R 
+--R
+--R         a      3
+--R        f Ei(b x log(f))
+--R   (2)  ----------------
+--R                3
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3
+--R           x  %D b + a
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++       %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 668
+
+--S 669 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                 3
+--R            x  %D b + a
+--R          ++  f                 a      3
+--R        3 |   --------- d%D  - f Ei(b x log(f))
+--R         ++       %D
+--R   (4)  ---------------------------------------
+--R                           3
+--R                                                    Type: Expression(Integer)
+--E 669
+
+--S 670 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 670
+
+)clear all
+
+--S 671 of 1000
+t0:=f^(a+b*x^3)/x^4
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             4
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 1000
+r0:=-1/3*f^(a+b*x^3)/x^3+1/3*b*f^a*Ei(b*x^3*log(f))*log(f)
+--R 
+--R
+--R                                         3
+--R           3       a      3           b x  + a
+--R        b x log(f)f Ei(b x log(f)) - f
+--R   (2)  --------------------------------------
+--R                            3
+--R                          3x
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3
+--R           x  %D b + a
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++        4
+--R                %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 673
+
+--S 674 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                   3
+--R              x  %D b + a                                         3
+--R          3 ++  f                   3       a      3           b x  + a
+--R        3x  |   --------- d%D  - b x log(f)f Ei(b x log(f)) + f
+--R           ++        4
+--R                   %D
+--R   (4)  ---------------------------------------------------------------
+--R                                        3
+--R                                      3x
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+)clear all
+
+--S 676 of 1000
+t0:=f^(a+b*x^3)/x^7
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             7
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 1000
+r0:=-1/6*f^(a+b*x^3)/x^6-1/6*b*f^(a+b*x^3)*log(f)/x^3+1/6*b^2*f^a*_
+   Ei(b*x^3*log(f))*log(f)^2
+--R 
+--R
+--R                                                            3
+--R         2 6      2 a      3                3            b x  + a
+--R        b x log(f) f Ei(b x log(f)) + (- b x log(f) - 1)f
+--R   (2)  ---------------------------------------------------------
+--R                                     6
+--R                                   6x
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3
+--R           x  %D b + a
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++        7
+--R                %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 678
+
+--S 679 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  3
+--R             x  %D b + a
+--R         6 ++  f                 2 6      2 a      3
+--R       6x  |   --------- d%D  - b x log(f) f Ei(b x log(f))
+--R          ++        7
+--R                  %D
+--R     + 
+--R                           3
+--R           3            b x  + a
+--R       (b x log(f) + 1)f
+--R  /
+--R       6
+--R     6x
+--R                                                    Type: Expression(Integer)
+--E 679
+
+--S 680 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 680
+
+)clear all
+
+--S 681 of 1000
+t0:=f^(a+b*x^3)/x^10
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            10
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 1000
+r0:=-1/9*f^(a+b*x^3)/x^9-1/18*b*f^(a+b*x^3)*log(f)/x^6-1/18*b^2*f^(a+b*x^3)*_
+   log(f)^2/x^3+1/18*b^3*f^a*Ei(b*x^3*log(f))*log(f)^3
+--R 
+--R
+--R   (2)
+--R                                                                     3
+--R    3 9      3 a      3              2 6      2      3            b x  + a
+--R   b x log(f) f Ei(b x log(f)) + (- b x log(f)  - b x log(f) - 2)f
+--R   -----------------------------------------------------------------------
+--R                                        9
+--R                                     18x
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3
+--R           x  %D b + a
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++        10
+--R                %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 683
+
+--S 684 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   3
+--R              x  %D b + a
+--R          9 ++  f                 3 9      3 a      3
+--R       18x  |   --------- d%D  - b x log(f) f Ei(b x log(f))
+--R           ++        10
+--R                   %D
+--R     + 
+--R                                         3
+--R         2 6      2      3            b x  + a
+--R       (b x log(f)  + b x log(f) + 2)f
+--R  /
+--R        9
+--R     18x
+--R                                                    Type: Expression(Integer)
+--E 684
+
+--S 685 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 685
+
+)clear all
+
+--S 686 of 1000
+t0:=f^(a+b*x^3)/x^13
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            13
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 1000
+--r0:=-1/3*b^4*f^a*GAMMA(-4,-b*x^3*log(f))*log(f)^4
+--E 687
+
+--S 688 of 1000
+--a0:=integrate(t0,x)
+--E 688
+
+--S 689 of 1000
+--m0:=a0-r0
+--E 689
+
+--S 690 of 1000
+--d0:=normalize(D(m0,x))
+--E 690
+
+)clear all
+
+--S 691 of 1000
+t0:=f^(a+b*x^3)/x^16
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            16
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 691
+
+--S 692 of 1000
+--r0:=1/3*b^5*f^a*GAMMA(-5,-b*x^3*log(f))*log(f)^5
+--E 692
+
+--S 693 of 1000
+--a0:=integrate(t0,x)
+--E 693
+
+--S 694 of 1000
+--m0:=a0-r0
+--E 694
+
+--S 695 of 1000
+--d0:=normalize(D(m0,x))
+--E 695
+
+)clear all
+
+--S 696 of 1000
+t0:=f^(a+b*x^3)*x^4
+--R 
+--R
+--R              3
+--R         4 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 1000
+--r0:=-1/3*f^a*x^5*GAMMA(5/3,-b*x^3*log(f))/(-b*x^3*log(f))^(5/3)
+--E 697
+
+--S 698 of 1000
+--a0:=integrate(t0,x)
+--E 698
+
+--S 699 of 1000
+--m0:=a0-r0
+--E 699
+
+--S 700 of 1000
+--d0:=normalize(D(m0,x))
+--E 700
+
+)clear all
+
+--S 701 of 1000
+t0:=f^(a+b*x^3)*x^3
+--R 
+--R
+--R              3
+--R         3 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 1000
+--r0:=-1/3*f^a*x^4*GAMMA(4/3,-b*x^3*log(f))/(-b*x^3*log(f))^(4/3)
+--E 702
+
+--S 703 of 1000
+--a0:=integrate(t0,x)
+--E 703
+
+--S 704 of 1000
+--m0:=a0-r0
+--E 704
+
+--S 705 of 1000
+--d0:=normalize(D(m0,x))
+--E 705
+
+)clear all
+
+--S 706 of 1000
+t0:=f^(a+b*x^3)*x
+--R 
+--R
+--R              3
+--R           b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 1000
+--r0:=-1/3*f^a*x^2*GAMMA(2/3,-b*x^3*log(f))/(-b*x^3*log(f))^(2/3)
+--E 707
+
+--S 708 of 1000
+--a0:=integrate(t0,x)
+--E 708
+
+--S 709 of 1000
+--m0:=a0-r0
+--E 709
+
+--S 710 of 1000
+--d0:=normalize(D(m0,x))
+--E 710
+
+)clear all
+
+--S 711 of 1000
+t0:=f^(a+b*x^3)
+--R 
+--R
+--R            3
+--R         b x  + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 1000
+--r0:=-1/3*f^a*x*GAMMA(1/3,-b*x^3*log(f))/(-b*x^3*log(f))^(1/3)
+--E 712
+
+--S 713 of 1000
+--a0:=integrate(t0,x)
+--E 713
+
+--S 714 of 1000
+--m0:=a0-r0
+--E 714
+
+--S 715 of 1000
+--d0:=normalize(D(m0,x))
+--E 715
+
+)clear all
+
+--S 716 of 1000
+t0:=f^(a+b*x^3)/x^2
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1000
+--r0:=-1/3*f^a*GAMMA(-1/3,-b*x^3*log(f))*(-b*x^3*log(f))^(1/3)/x
+--E 717
+
+--S 718 of 1000
+--a0:=integrate(t0,x)
+--E 718
+
+--S 719 of 1000
+--m0:=a0-r0
+--E 719
+
+--S 720 of 1000
+--d0:=normalize(D(m0,x))
+--E 720
+
+)clear all
+
+--S 721 of 1000
+t0:=f^(a+b*x^3)/x^3
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 1000
+--r0:=-1/3*f^a*GAMMA(-2/3,-b*x^3*log(f))*(-b*x^3*log(f))^(2/3)/x^2
+--E 722
+
+--S 723 of 1000
+--a0:=integrate(t0,x)
+--E 723
+
+--S 724 of 1000
+--m0:=a0-r0
+--E 724
+
+--S 725 of 1000
+--d0:=normalize(D(m0,x))
+--E 725
+
+)clear all
+
+--S 726 of 1000
+t0:=%e^(4*x^3)*x^2
+--R 
+--R
+--R              3
+--R         2  4x
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 726
+
+--S 727 of 1000
+r0:=1/12*%e^(4*x^3)
+--R 
+--R
+--R            3
+--R          4x
+--R        %e
+--R   (2)  -----
+--R          12
+--R                                                    Type: Expression(Integer)
+--E 727
+
+--S 728 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3
+--R          4x
+--R        %e
+--R   (3)  -----
+--R          12
+--R                                         Type: Union(Expression(Integer),...)
+--E 728
+
+--S 729 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 729
+
+--S 730 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 730
+
+)clear all
+
+--S 731 of 1000
+t0:=f^(a+b/x)*x^m
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x    m
+--R   (1)  f       x
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 1000
+--r0:=f^a*x^(1+m)*GAMMA(-1-m,-b*log(f)/x)*(-b*log(f)/x)^(1+m)
+--E 732
+
+--S 733 of 1000
+--a0:=integrate(t0,x)
+--E 733
+
+--S 734 of 1000
+--m0:=a0-r0
+--E 734
+
+--S 735 of 1000
+--d0:=normalize(D(m0,x))
+--E 735
+
+)clear all
+
+--S 736 of 1000
+t0:=f^(a+b/x)*x^4
+--R 
+--R
+--R           a x + b
+--R           -------
+--R         4    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 736
+
+--S 737 of 1000
+--r0:=-b^5*f^a*GAMMA(-5,-b*log(f)/x)*log(f)^5
+--E 737
+
+--S 738 of 1000
+--a0:=integrate(t0,x)
+--E 738
+
+--S 739 of 1000
+--m0:=a0-r0
+--E 739
+
+--S 740 of 1000
+--d0:=normalize(D(m0,x))
+--E 740
+
+)clear all
+
+--S 741 of 1000
+t0:=f^(a+b/x)*x^3
+--R 
+--R
+--R           a x + b
+--R           -------
+--R         3    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 741
+
+--S 742 of 1000
+--r0:=b^4*f^a*GAMMA(-4,-b*log(f)/x)*log(f)^4
+--E 742
+
+--S 743 of 1000
+--a0:=integrate(t0,x)
+--E 743
+
+--S 744 of 1000
+--m0:=a0-r0
+--E 744
+
+--S 745 of 1000
+--d0:=normalize(D(m0,x))
+--E 745
+
+)clear all
+
+--S 746 of 1000
+t0:=f^(a+b/x)*x^2
+--R 
+--R
+--R           a x + b
+--R           -------
+--R         2    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 1000
+r0:=1/3*f^(a+b/x)*x^3+1/6*b*f^(a+b/x)*x^2*log(f)+1/6*b^2*f^(a+b/x)*x*_
+   log(f)^2-1/6*b^3*f^a*Ei(b*log(f)/x)*log(f)^3
+--R 
+--R
+--R                                                                     a x + b
+--R                                                                     -------
+--R           3      3 a   b log(f)      2        2      2           3     x
+--R        - b log(f) f Ei(--------) + (b x log(f)  + b x log(f) + 2x )f
+--R                            x
+--R   (2)  --------------------------------------------------------------------
+--R                                          6
+--R                                                    Type: Expression(Integer)
+--E 747
+
+--S 748 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 b + %D a
+--R           x     --------
+--R         ++    2    %D
+--R   (3)   |   %D f        d%D
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 748
+
+--S 749 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 b + %D a
+--R           x     --------
+--R         ++    2    %D           3      3 a   b log(f)
+--R       6 |   %D f        d%D  + b log(f) f Ei(--------)
+--R        ++                                        x
+--R     + 
+--R                                          a x + b
+--R                                          -------
+--R           2        2      2           3     x
+--R       (- b x log(f)  - b x log(f) - 2x )f
+--R  /
+--R     6
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 750
+
+)clear all
+
+--S 751 of 1000
+t0:=f^(a+b/x)*x
+--R 
+--R
+--R           a x + b
+--R           -------
+--R              x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 1000
+r0:=1/2*f^(a+b/x)*x^2+1/2*b*f^(a+b/x)*x*log(f)-1/2*b^2*f^a*Ei(b*log(f)/x)*_
+   log(f)^2
+--R 
+--R
+--R                                                      a x + b
+--R                                                      -------
+--R           2      2 a   b log(f)                   2     x
+--R        - b log(f) f Ei(--------) + (b x log(f) + x )f
+--R                            x
+--R   (2)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 b + %D a
+--R           x     --------
+--R         ++         %D
+--R   (3)   |   %D f        d%D
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 753
+
+--S 754 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 b + %D a
+--R           x     --------
+--R         ++         %D           2      2 a   b log(f)
+--R       2 |   %D f        d%D  + b log(f) f Ei(--------)
+--R        ++                                        x
+--R     + 
+--R                           a x + b
+--R                           -------
+--R                        2     x
+--R       (- b x log(f) - x )f
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 755
+
+)clear all
+
+--S 756 of 1000
+t0:=f^(a+b/x)
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 1000
+r0:=f^(a+b/x)*x-b*f^a*Ei(b*log(f)/x)*log(f)
+--R 
+--R
+--R                                      a x + b
+--R                                      -------
+--R                   a   b log(f)          x
+--R   (2)  - b log(f)f Ei(--------) + x f
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R              b + %D a
+--R           x  --------
+--R         ++      %D
+--R   (3)   |   f        d%D
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 758
+
+--S 759 of 1000
+m0:=a0-r0
+--R 
+--R
+--R              b + %D a                                   a x + b
+--R           x  --------                                   -------
+--R         ++      %D                   a   b log(f)          x
+--R   (4)   |   f        d%D  + b log(f)f Ei(--------) - x f
+--R        ++                                    x
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 760
+
+)clear all
+
+--S 761 of 1000
+t0:=f^(a+b/x)/x
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 1000
+r0:=-f^a*Ei(b*log(f)/x)
+--R 
+--R
+--R           a   b log(f)
+--R   (2)  - f Ei(--------)
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R              b + %D a
+--R              --------
+--R           x     %D
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++       %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 763
+
+--S 764 of 1000
+m0:=a0-r0
+--R 
+--R
+--R              b + %D a
+--R              --------
+--R           x     %D
+--R         ++  f                 a   b log(f)
+--R   (4)   |   --------- d%D  + f Ei(--------)
+--R        ++       %D                    x
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 765
+
+)clear all
+
+--S 766 of 1000
+t0:=f^(a+b/x)/x^2
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            2
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 1000
+r0:=-f^(a+b/x)/(b*log(f))
+--R 
+--R
+--R           a x + b
+--R           -------
+--R              x
+--R          f
+--R   (2)  - --------
+--R          b log(f)
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R            (a x + b)log(f)
+--R            ---------------
+--R                   x
+--R          %e
+--R   (3)  - -----------------
+--R               b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 768
+
+--S 769 of 1000
+m0:=a0-r0
+--R 
+--R
+--R            (a x + b)log(f)    a x + b
+--R            ---------------    -------
+--R                   x              x
+--R        - %e                + f
+--R   (4)  ------------------------------
+--R                   b log(f)
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 770
+
+)clear all
+
+--S 771 of 1000
+t0:=f^(a+b/x)/x^3
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            3
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 771
+
+--S 772 of 1000
+r0:=f^(a+b/x)/(b^2*log(f)^2)-f^(a+b/x)/(b*x*log(f))
+--R 
+--R
+--R                         a x + b
+--R                         -------
+--R                            x
+--R        (- b log(f) + x)f
+--R   (2)  ------------------------
+--R                2        2
+--R               b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          (a x + b)log(f)
+--R                          ---------------
+--R                                 x
+--R        (- b log(f) + x)%e
+--R   (3)  ---------------------------------
+--R                    2        2
+--R                   b x log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 773
+
+--S 774 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                          (a x + b)log(f)                  a x + b
+--R                          ---------------                  -------
+--R                                 x                            x
+--R        (- b log(f) + x)%e                + (b log(f) - x)f
+--R   (4)  ----------------------------------------------------------
+--R                                 2        2
+--R                                b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 775
+
+)clear all
+
+--S 776 of 1000
+t0:=f^(a+b/x)/x^4
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            4
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 1000
+r0:=-2*f^(a+b/x)/(b^3*log(f)^3)+2*f^(a+b/x)/(b^2*x*log(f)^2)-_
+   f^(a+b/x)/(b*x^2*log(f))
+--R 
+--R
+--R                                          a x + b
+--R                                          -------
+--R            2      2                   2     x
+--R        (- b log(f)  + 2b x log(f) - 2x )f
+--R   (2)  -----------------------------------------
+--R                        3 2      3
+--R                       b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                           (a x + b)log(f)
+--R                                           ---------------
+--R            2      2                   2          x
+--R        (- b log(f)  + 2b x log(f) - 2x )%e
+--R   (3)  --------------------------------------------------
+--R                             3 2      3
+--R                            b x log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 778
+
+--S 779 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                          (a x + b)log(f)
+--R                                          ---------------
+--R           2      2                   2          x
+--R       (- b log(f)  + 2b x log(f) - 2x )%e
+--R     + 
+--R                                       a x + b
+--R                                       -------
+--R         2      2                   2     x
+--R       (b log(f)  - 2b x log(f) + 2x )f
+--R  /
+--R      3 2      3
+--R     b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 780
+
+)clear all
+
+--S 781 of 1000
+t0:=f^(a+b/x)/x^5
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            5
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 781
+
+--S 782 of 1000
+r0:=6*f^(a+b/x)/(b^4*log(f)^4)-6*f^(a+b/x)/(b^3*x*log(f)^3)+_
+   3*f^(a+b/x)/(b^2*x^2*log(f)^2)-f^(a+b/x)/(b*x^3*log(f))
+--R 
+--R
+--R                                                         a x + b
+--R                                                         -------
+--R            3      3     2        2       2           3     x
+--R        (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )f
+--R   (2)  --------------------------------------------------------
+--R                                4 3      4
+--R                               b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                          (a x + b)log(f)
+--R                                                          ---------------
+--R            3      3     2        2       2           3          x
+--R        (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )%e
+--R   (3)  -----------------------------------------------------------------
+--R                                    4 3      4
+--R                                   b x log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 783
+
+--S 784 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                         (a x + b)log(f)
+--R                                                         ---------------
+--R           3      3     2        2       2           3          x
+--R       (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )%e
+--R     + 
+--R                                                      a x + b
+--R                                                      -------
+--R         3      3     2        2       2           3     x
+--R       (b log(f)  - 3b x log(f)  + 6b x log(f) - 6x )f
+--R  /
+--R      4 3      4
+--R     b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 785
+
+)clear all
+
+--S 786 of 1000
+t0:=f^(a+b/x)/x^6
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            6
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 1000
+--r0:=-f^a*GAMMA(5,-b*log(f)/x)/(b^5*log(f)^5)
+--E 787
+
+--S 788 of 1000
+--a0:=integrate(t0,x)
+--E 788
+
+--S 789 of 1000
+--m0:=a0-r0
+--E 789
+
+--S 790 of 1000
+--d0:=normalize(D(m0,x))
+--E 790
+
+)clear all
+
+--S 791 of 1000
+t0:=f^(a+b/x)/x^7
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            7
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 1000
+--r0:=f^a*GAMMA(6,-b*log(f)/x)/(b^6*log(f)^6)
+--E 792
+
+--S 793 of 1000
+--a0:=integrate(t0,x)
+--E 793
+
+--S 794 of 1000
+--m0:=a0-r0
+--E 794
+
+--S 795 of 1000
+--d0:=normalize(D(m0,x))
+--E 795
+
+)clear all
+
+--S 796 of 1000
+t0:=f^(a+b/x^2)*x^m
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x     m
+--R   (1)  f        x
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 1000
+--r0:=1/2*f^a*x^(1+m)*GAMMA(1/2*(-1-m),-b*log(f)/x^2)*_
+--  (-b*log(f)/x^2)^(1/2*(1+m))
+--E 797
+
+--S 798 of 1000
+--a0:=integrate(t0,x)
+--E 798
+
+--S 799 of 1000
+--m0:=a0-r0
+--E 799
+
+--S 800 of 1000
+--d0:=normalize(D(m0,x))
+--E 800
+
+)clear all
+
+--S 801 of 1000
+t0:=f^(a+b/x^2)*x^9
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         9    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 801
+
+--S 802 of 1000
+--r0:=-1/2*b^5*f^a*GAMMA(-5,-b*log(f)/x^2)*log(f)^5
+--E 802
+
+--S 803 of 1000
+--a0:=integrate(t0,x)
+--E 803
+
+--S 804 of 1000
+--m0:=a0-r0
+--E 804
+
+--S 805 of 1000
+--d0:=normalize(D(m0,x))
+--E 805
+
+)clear all
+
+--S 806 of 1000
+t0:=f^(a+b/x^2)*x^7
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         7    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 1000
+--r0:=1/2*b^4*f^a*GAMMA(-4,-b*log(f)/x^2)*log(f)^4
+--E 807
+
+--S 808 of 1000
+--a0:=integrate(t0,x)
+--E 808
+
+--S 809 of 1000
+--m0:=a0-r0
+--E 809
+
+--S 810 of 1000
+--d0:=normalize(D(m0,x))
+--E 810
+
+)clear all
+
+--S 811 of 1000
+t0:=f^(a+b/x^2)*x^5
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         5    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 1000
+r0:=1/6*f^(a+b/x^2)*x^6+1/12*b*f^(a+b/x^2)*x^4*log(f)+_
+   1/12*b^2*f^(a+b/x^2)*x^2*log(f)^2-1/12*b^3*f^a*Ei(b*log(f)/x^2)*log(f)^3
+--R 
+--R
+--R                                                                        2
+--R                                                                     a x  + b
+--R                                                                     --------
+--R                                                                         2
+--R           3      3 a   b log(f)      2 2      2      4           6     x
+--R        - b log(f) f Ei(--------) + (b x log(f)  + b x log(f) + 2x )f
+--R                            2
+--R                           x
+--R   (2)  ---------------------------------------------------------------------
+--R                                          12
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       2
+--R                 b + %D a
+--R                 --------
+--R           x          2
+--R         ++    5    %D
+--R   (3)   |   %D f        d%D
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 813
+
+--S 814 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        2
+--R                  b + %D a
+--R                  --------
+--R            x          2
+--R          ++    5    %D           3      3 a   b log(f)
+--R       12 |   %D f        d%D  + b log(f) f Ei(--------)
+--R         ++                                        2
+--R                                                  x
+--R     + 
+--R                                             2
+--R                                          a x  + b
+--R                                          --------
+--R                                              2
+--R           2 2      2      4           6     x
+--R       (- b x log(f)  - b x log(f) - 2x )f
+--R  /
+--R     12
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 815
+
+)clear all
+
+--S 816 of 1000
+t0:=f^(a+b/x^2)*x^3
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         3    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 1000
+r0:=1/4*f^(a+b/x^2)*x^4+1/4*b*f^(a+b/x^2)*x^2*log(f)-_
+   1/4*b^2*f^a*Ei(b*log(f)/x^2)*log(f)^2
+--R 
+--R
+--R                                                         2
+--R                                                      a x  + b
+--R                                                      --------
+--R                                                          2
+--R           2      2 a   b log(f)        2          4     x
+--R        - b log(f) f Ei(--------) + (b x log(f) + x )f
+--R                            2
+--R                           x
+--R   (2)  ------------------------------------------------------
+--R                                   4
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       2
+--R                 b + %D a
+--R                 --------
+--R           x          2
+--R         ++    3    %D
+--R   (3)   |   %D f        d%D
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 818
+
+--S 819 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       2
+--R                 b + %D a
+--R                 --------
+--R           x          2
+--R         ++    3    %D           2      2 a   b log(f)
+--R       4 |   %D f        d%D  + b log(f) f Ei(--------)
+--R        ++                                        2
+--R                                                 x
+--R     + 
+--R                              2
+--R                           a x  + b
+--R                           --------
+--R                               2
+--R             2          4     x
+--R       (- b x log(f) - x )f
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 820
+
+)clear all
+
+--S 821 of 1000
+t0:=f^(a+b/x^2)*x
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R              x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 1000
+r0:=1/2*f^(a+b/x^2)*x^2-1/2*b*f^a*Ei(b*log(f)/x^2)*log(f)
+--R 
+--R
+--R                                         2
+--R                                      a x  + b
+--R                                      --------
+--R                                          2
+--R                   a   b log(f)     2    x
+--R        - b log(f)f Ei(--------) + x f
+--R                           2
+--R                          x
+--R   (2)  --------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 822
+
+--S 823 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       2
+--R                 b + %D a
+--R                 --------
+--R           x          2
+--R         ++         %D
+--R   (3)   |   %D f        d%D
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 823
+
+--S 824 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                        2                                       2
+--R                  b + %D a                                   a x  + b
+--R                  --------                                   --------
+--R            x          2                                         2
+--R          ++         %D                   a   b log(f)     2    x
+--R        2 |   %D f        d%D  + b log(f)f Ei(--------) - x f
+--R         ++                                       2
+--R                                                 x
+--R   (4)  -------------------------------------------------------------
+--R                                      2
+--R                                                    Type: Expression(Integer)
+--E 824
+
+--S 825 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 825
+
+)clear all
+
+--S 826 of 1000
+t0:=f^(a+b/x^2)/x
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 1000
+r0:=-1/2*f^a*Ei(b*log(f)/x^2)
+--R 
+--R
+--R           a   b log(f)
+--R          f Ei(--------)
+--R                   2
+--R                  x
+--R   (2)  - --------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 827
+
+--S 828 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    2
+--R              b + %D a
+--R              --------
+--R                   2
+--R           x     %D
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++       %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 828
+
+--S 829 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                     2
+--R               b + %D a
+--R               --------
+--R                    2
+--R            x     %D
+--R          ++  f                 a   b log(f)
+--R        2 |   --------- d%D  + f Ei(--------)
+--R         ++       %D                    2
+--R                                       x
+--R   (4)  -------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 830
+
+)clear all
+
+--S 831 of 1000
+t0:=f^(a+b/x^2)/x^3
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 1000
+r0:=-1/2*f^(a+b/x^2)/(b*log(f))
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R              x
+--R          f
+--R   (2)  - ---------
+--R          2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2
+--R            (a x  + b)log(f)
+--R            ----------------
+--R                    2
+--R                   x
+--R          %e
+--R   (3)  - ------------------
+--R               2b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 833
+
+--S 834 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                2                  2
+--R            (a x  + b)log(f)    a x  + b
+--R            ----------------    --------
+--R                    2               2
+--R                   x               x
+--R        - %e                 + f
+--R   (4)  --------------------------------
+--R                    2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 834
+
+--S 835 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 835
+
+)clear all
+
+--S 836 of 1000
+t0:=f^(a+b/x^2)/x^5
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             5
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 1000
+r0:=1/2*f^(a+b/x^2)/(b^2*log(f)^2)-1/2*f^(a+b/x^2)/(b*x^2*log(f))
+--R 
+--R
+--R                             2
+--R                          a x  + b
+--R                          --------
+--R                              2
+--R                       2     x
+--R        (- b log(f) + x )f
+--R   (2)  --------------------------
+--R                 2 2      2
+--R               2b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               2
+--R                           (a x  + b)log(f)
+--R                           ----------------
+--R                                   2
+--R                       2          x
+--R        (- b log(f) + x )%e
+--R   (3)  -----------------------------------
+--R                      2 2      2
+--R                    2b x log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 838
+
+--S 839 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                               2                                 2
+--R                           (a x  + b)log(f)                   a x  + b
+--R                           ----------------                   --------
+--R                                   2                              2
+--R                       2          x                        2     x
+--R        (- b log(f) + x )%e                 + (b log(f) - x )f
+--R   (4)  --------------------------------------------------------------
+--R                                   2 2      2
+--R                                 2b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 839
+
+--S 840 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 840
+
+)clear all
+
+--S 841 of 1000
+t0:=f^(a+b/x^2)/x^7
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             7
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 841
+
+--S 842 of 1000
+r0:=-f^(a+b/x^2)/(b^3*log(f)^3)+f^(a+b/x^2)/(b^2*x^2*log(f)^2)-_
+   1/2*f^(a+b/x^2)/(b*x^4*log(f))
+--R 
+--R
+--R                                             2
+--R                                          a x  + b
+--R                                          --------
+--R                                              2
+--R            2      2       2           4     x
+--R        (- b log(f)  + 2b x log(f) - 2x )f
+--R   (2)  ------------------------------------------
+--R                         3 4      3
+--R                       2b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                               2
+--R                                           (a x  + b)log(f)
+--R                                           ----------------
+--R                                                   2
+--R            2      2       2           4          x
+--R        (- b log(f)  + 2b x log(f) - 2x )%e
+--R   (3)  ---------------------------------------------------
+--R                              3 4      3
+--R                            2b x log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 843
+
+--S 844 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              2
+--R                                          (a x  + b)log(f)
+--R                                          ----------------
+--R                                                  2
+--R           2      2       2           4          x
+--R       (- b log(f)  + 2b x log(f) - 2x )%e
+--R     + 
+--R                                          2
+--R                                       a x  + b
+--R                                       --------
+--R                                           2
+--R         2      2       2           4     x
+--R       (b log(f)  - 2b x log(f) + 2x )f
+--R  /
+--R       3 4      3
+--R     2b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 844
+
+--S 845 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 845
+
+)clear all
+
+--S 846 of 1000
+t0:=f^(a+b/x^2)/x^9
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             9
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 846
+
+--S 847 of 1000
+r0:=3*f^(a+b/x^2)/(b^4*log(f)^4)-3*f^(a+b/x^2)/(b^3*x^2*log(f)^3)+_
+   3/2*f^(a+b/x^2)/(b^2*x^4*log(f)^2)-1/2*f^(a+b/x^2)/(b*x^6*log(f))
+--R 
+--R
+--R                                                            2
+--R                                                         a x  + b
+--R                                                         --------
+--R                                                             2
+--R            3      3     2 2      2       4           6     x
+--R        (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )f
+--R   (2)  ---------------------------------------------------------
+--R                                 4 6      4
+--R                               2b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                              2
+--R                                                          (a x  + b)log(f)
+--R                                                          ----------------
+--R                                                                  2
+--R            3      3     2 2      2       4           6          x
+--R        (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )%e
+--R   (3)  ------------------------------------------------------------------
+--R                                     4 6      4
+--R                                   2b x log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 848
+
+--S 849 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                             2
+--R                                                         (a x  + b)log(f)
+--R                                                         ----------------
+--R                                                                 2
+--R           3      3     2 2      2       4           6          x
+--R       (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )%e
+--R     + 
+--R                                                         2
+--R                                                      a x  + b
+--R                                                      --------
+--R                                                          2
+--R         3      3     2 2      2       4           6     x
+--R       (b log(f)  - 3b x log(f)  + 6b x log(f) - 6x )f
+--R  /
+--R       4 6      4
+--R     2b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 849
+
+--S 850 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 850
+
+)clear all
+
+--S 851 of 1000
+t0:=f^(a+b/x^2)/x^11
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            11
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 1000
+--r0:=-1/2*f^a*GAMMA(5,-b*log(f)/x^2)/(b^5*log(f)^5)
+--E 852
+
+--S 853 of 1000
+--a0:=integrate(t0,x)
+--E 853
+
+--S 854 of 1000
+--m0:=a0-r0
+--E 854
+
+--S 855 of 1000
+--d0:=normalize(D(m0,x))
+--E 855
+
+)clear all
+
+--S 856 of 1000
+t0:=f^(a+b/x^2)/x^13
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            13
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 856
+
+--S 857 of 1000
+--r0:=1/2*f^a*GAMMA(6,-b*log(f)/x^2)/(b^6*log(f)^6)
+--E 857
+
+--S 858 of 1000
+--a0:=integrate(t0,x)
+--E 858
+
+--S 859 of 1000
+--m0:=a0-r0
+--E 859
+
+--S 860 of 1000
+--d0:=normalize(D(m0,x))
+--E 860
+
+)clear all
+
+--S 861 of 1000
+t0:=f^(a+b/x^2)*x^10
+--R 
+--R
+--R               2
+--R            a x  + b
+--R            --------
+--R                2
+--R         10    x
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 861
+
+--S 862 of 1000
+--r0:=1/2*f^a*x^11*GAMMA(-11/2,-b*log(f)/x^2)*(-b*log(f)/x^2)^(11/2)
+--E 862
+
+--S 863 of 1000
+--a0:=integrate(t0,x)
+--E 863
+
+--S 864 of 1000
+--m0:=a0-r0
+--E 864
+
+--S 865 of 1000
+--d0:=normalize(D(m0,x))
+--E 865
+
+)clear all
+
+--S 866 of 1000
+t0:=f^(a+b/x^2)*x^8
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         8    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 1000
+--r0:=1/2*f^a*x^9*GAMMA(-9/2,-b*log(f)/x^2)*(-b*log(f)/x^2)^(9/2)
+--E 867
+
+--S 868 of 1000
+--a0:=integrate(t0,x)
+--E 868
+
+--S 869 of 1000
+--m0:=a0-r0
+--E 869
+
+--S 870 of 1000
+--d0:=normalize(D(m0,x))
+--E 870
+
+)clear all
+
+--S 871 of 1000
+t0:=f^(a+b/x^2)*x^6
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         6    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 871
+
+--S 872 of 1000
+--r0:=1/7*f^(a+b/x^2)*x^7+2/35*b*f^(a+b/x^2)*x^5*log(f)+4/105*b^2*_
+--  f^(a+b/x^2)*x^3*log(f)^2+8/105*b^3*f^(a+b/x^2)*x*log(f)^3-_
+--  8/105*b^(7/2)*f^a*erfi(sqrt(b)*sqrt(log(f))/x)*log(f)^(7/2)*sqrt(%pi)
+--E 872
+
+--S 873 of 1000
+--a0:=integrate(t0,x)
+--E 873
+
+--S 874 of 1000
+--m0:=a0-r0
+--E 874
+
+--S 875 of 1000
+--d0:=normalize(D(m0,x))
+--E 875
+
+)clear all
+
+--S 876 of 1000
+t0:=f^(a+b/x^2)*x^4
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         4    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 876
+
+--S 877 of 1000
+--r0:=1/5*f^(a+b/x^2)*x^5+2/15*b*f^(a+b/x^2)*x^3*log(f)+_
+--  4/15*b^2*f^(a+b/x^2)*x*log(f)^2-4/15*b^(5/2)*f^a*erfi(sqrt(b)*_
+--  sqrt(log(f))/x)*log(f)^(5/2)*sqrt(%pi)
+--E 877
+
+--S 878 of 1000
+--a0:=integrate(t0,x)
+--E 878
+
+--S 879 of 1000
+--m0:=a0-r0
+--E 879
+
+--S 880 of 1000
+--d0:=normalize(D(m0,x))
+--E 880
+
+)clear all
+
+--S 881 of 1000
+t0:=f^(a+b/x^2)*x^2
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         2    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 881
+
+--S 882 of 1000
+--r0:=1/3*f^(a+b/x^2)*x^3+2/3*b*f^(a+b/x^2)*x*log(f)-_
+--  2/3*b^(3/2)*f^a*erfi(sqrt(b)*sqrt(log(f))/x)*log(f)^(3/2)*sqrt(%pi)
+--E 882
+
+--S 883 of 1000
+--a0:=integrate(t0,x)
+--E 883
+
+--S 884 of 1000
+--m0:=a0-r0
+--E 884
+
+--S 885 of 1000
+--d0:=normalize(D(m0,x))
+--E 885
+
+)clear all
+
+--S 886 of 1000
+t0:=f^(a+b/x^2)
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 886
+
+--S 887 of 1000
+--r0:=f^(a+b/x^2)*x-f^a*erfi(sqrt(b)*sqrt(log(f))/x)*sqrt(%pi)*_
+--  sqrt(b)*sqrt(log(f))
+--E 887
+
+--S 888 of 1000
+--a0:=integrate(t0,x)
+--E 888
+
+--S 889 of 1000
+--m0:=a0-r0
+--E 889
+
+--S 890 of 1000
+--d0:=normalize(D(m0,x))
+--E 890
+
+)clear all
+
+--S 891 of 1000
+t0:=f^(a+b/x^2)/x^2
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 891
+
+--S 892 of 1000
+--r0:=-1/2*f^a*erfi(sqrt(b)*sqrt(log(f))/x)*sqrt(%pi)/(sqrt(b)*sqrt(log(f)))
+--E 892
+
+--S 893 of 1000
+--a0:=integrate(t0,x)
+--E 893
+
+--S 894 of 1000
+--m0:=a0-r0
+--E 894
+
+--S 895 of 1000
+--d0:=normalize(D(m0,x))
+--E 895
+
+)clear all
+
+--S 896 of 1000
+t0:=f^(a+b/x^2)/x^4
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             4
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 896
+
+--S 897 of 1000
+--r0:=-1/2*f^(a+b/x^2)/(b*x*log(f))+1/4*f^a*erfi(sqrt(b)*_
+--  sqrt(log(f))/x)*sqrt(%pi)/(b^(3/2)*log(f)^(3/2))
+--E 897
+
+--S 898 of 1000
+--a0:=integrate(t0,x)
+--E 898
+
+--S 899 of 1000
+--m0:=a0-r0
+--E 899
+
+--S 900 of 1000
+--d0:=normalize(D(m0,x))
+--E 900
+
+)clear all
+
+--S 901 of 1000
+t0:=f^(a+b/x^2)/x^6
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             6
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 1000
+--r0:=3/4*f^(a+b/x^2)/(b^2*x*log(f)^2)-1/2*f^(a+b/x^2)/(b*x^3*log(f))-_
+--  3/8*f^a*erfi(sqrt(b)*sqrt(log(f))/x)*sqrt(%pi)/(b^(5/2)*log(f)^(5/2))
+--E 902
+
+--S 903 of 1000
+--a0:=integrate(t0,x)
+--E 903
+
+--S 904 of 1000
+--m0:=a0-r0
+--E 904
+
+--S 905 of 1000
+--d0:=normalize(D(m0,x))
+--E 905
+
+)clear all
+
+--S 906 of 1000
+t0:=f^(a+b/x^2)/x^8
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             8
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 906
+
+--S 907 of 1000
+--r0:=-15/8*f^(a+b/x^2)/(b^3*x*log(f)^3)+5/4*f^(a+b/x^2)/(b^2*x^3*_
+--  log(f)^2)-1/2*f^(a+b/x^2)/(b*x^5*log(f))+15/16*f^a*erfi(sqrt(b)*_
+--  sqrt(log(f))/x)*sqrt(%pi)/(b^(7/2)*log(f)^(7/2))
+--E 907
+
+--S 908 of 1000
+--a0:=integrate(t0,x)
+--E 908
+
+--S 909 of 1000
+--m0:=a0-r0
+--E 909
+
+--S 910 of 1000
+--d0:=normalize(D(m0,x))
+--E 910
+
+)clear all
+
+--S 911 of 1000
+t0:=f^(a+b/x^2)/x^10
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            10
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 911
+
+--S 912 of 1000
+--r0:=105/16*f^(a+b/x^2)/(b^4*x*log(f)^4)-35/8*f^(a+b/x^2)/_
+--  (b^3*x^3*log(f)^3)+7/4*f^(a+b/x^2)/(b^2*x^5*log(f)^2)-_
+--  1/2*f^(a+b/x^2)/(b*x^7*log(f))-105/32*f^a*erfi(sqrt(b)*_
+--  sqrt(log(f))/x)*sqrt(%pi)/(b^(9/2)*log(f)^(9/2))
+--E 912
+
+--S 913 of 1000
+--a0:=integrate(t0,x)
+--E 913
+
+--S 914 of 1000
+--m0:=a0-r0
+--E 914
+
+--S 915 of 1000
+--d0:=normalize(D(m0,x))
+--E 915
+
+)clear all
+
+--S 916 of 1000
+t0:=f^(a+b/x^2)/x^12
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            12
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 916
+
+--S 917 of 1000
+--r0:=1/2*f^a*GAMMA(11/2,-b*log(f)/x^2)/(x^11*(-b*log(f)/x^2)^(11/2))
+--E 917
+
+--S 918 of 1000
+--a0:=integrate(t0,x)
+--E 918
+
+--S 919 of 1000
+--m0:=a0-r0
+--E 919
+
+--S 920 of 1000
+--d0:=normalize(D(m0,x))
+--E 920
+
+)clear all
+
+--S 921 of 1000
+t0:=f^(a+b/x^2)/x^14
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            14
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 921
+
+--S 922 of 1000
+--r0:=1/2*f^a*GAMMA(13/2,-b*log(f)/x^2)/(x^13*(-b*log(f)/x^2)^(13/2))
+--E 922
+
+--S 923 of 1000
+--a0:=integrate(t0,x)
+--E 923
+
+--S 924 of 1000
+--m0:=a0-r0
+--E 924
+
+--S 925 of 1000
+--d0:=normalize(D(m0,x))
+--E 925
+
+)clear all
+
+--S 926 of 1000
+t0:=f^(a+b/x^3)*x^m
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x     m
+--R   (1)  f        x
+--R                                                    Type: Expression(Integer)
+--E 926
+
+--S 927 of 1000
+--r0:=1/3*f^a*x^(1+m)*GAMMA(1/3*(-1-m),-b*log(f)/x^3)*_
+--  (-b*log(f)/x^3)^(1/3*(1+m))
+--E 927
+
+--S 928 of 1000
+--a0:=integrate(t0,x)
+--E 928
+
+--S 929 of 1000
+--m0:=a0-r0
+--E 929
+
+--S 930 of 1000
+--d0:=normalize(D(m0,x))
+--E 930
+
+)clear all
+
+--S 931 of 1000
+t0:=f^(a+b/x^3)*x^14
+--R 
+--R
+--R               3
+--R            a x  + b
+--R            --------
+--R                3
+--R         14    x
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 931
+
+--S 932 of 1000
+--r0:=-1/3*b^5*f^a*GAMMA(-5,-b*log(f)/x^3)*log(f)^5
+--E 932
+
+--S 933 of 1000
+--a0:=integrate(t0,x)
+--E 933
+
+--S 934 of 1000
+--m0:=a0-r0
+--E 934
+
+--S 935 of 1000
+--d0:=normalize(D(m0,x))
+--E 935
+
+)clear all
+
+--S 936 of 1000
+t0:=f^(a+b/x^3)*x^11
+--R 
+--R
+--R               3
+--R            a x  + b
+--R            --------
+--R                3
+--R         11    x
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 936
+
+--S 937 of 1000
+--r0:=1/3*b^4*f^a*GAMMA(-4,-b*log(f)/x^3)*log(f)^4
+--E 937
+
+--S 938 of 1000
+--a0:=integrate(t0,x)
+--E 938
+
+--S 939 of 1000
+--m0:=a0-r0
+--E 939
+
+--S 940 of 1000
+--d0:=normalize(D(m0,x))
+--E 940
+
+)clear all
+
+--S 941 of 1000
+t0:=f^(a+b/x^3)*x^8
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R         8    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 941
+
+--S 942 of 1000
+r0:=1/9*f^(a+b/x^3)*x^9+1/18*b*f^(a+b/x^3)*x^6*log(f)+_
+   1/18*b^2*f^(a+b/x^3)*x^3*log(f)^2-1/18*b^3*f^a*Ei(b*log(f)/x^3)*log(f)^3
+--R 
+--R
+--R                                                                        3
+--R                                                                     a x  + b
+--R                                                                     --------
+--R                                                                         3
+--R           3      3 a   b log(f)      2 3      2      6           9     x
+--R        - b log(f) f Ei(--------) + (b x log(f)  + b x log(f) + 2x )f
+--R                            3
+--R                           x
+--R   (2)  ---------------------------------------------------------------------
+--R                                          18
+--R                                                    Type: Expression(Integer)
+--E 942
+
+--S 943 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       3
+--R                 b + %D a
+--R                 --------
+--R           x          3
+--R         ++    8    %D
+--R   (3)   |   %D f        d%D
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 943
+
+--S 944 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        3
+--R                  b + %D a
+--R                  --------
+--R            x          3
+--R          ++    8    %D           3      3 a   b log(f)
+--R       18 |   %D f        d%D  + b log(f) f Ei(--------)
+--R         ++                                        3
+--R                                                  x
+--R     + 
+--R                                             3
+--R                                          a x  + b
+--R                                          --------
+--R                                              3
+--R           2 3      2      6           9     x
+--R       (- b x log(f)  - b x log(f) - 2x )f
+--R  /
+--R     18
+--R                                                    Type: Expression(Integer)
+--E 944
+
+--S 945 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 945
+
+)clear all
+
+--S 946 of 1000
+t0:=f^(a+b/x^3)*x^5
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R         5    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 946
+
+--S 947 of 1000
+r0:=1/6*f^(a+b/x^3)*x^6+1/6*b*f^(a+b/x^3)*x^3*log(f)-_
+   1/6*b^2*f^a*Ei(b*log(f)/x^3)*log(f)^2
+--R 
+--R
+--R                                                         3
+--R                                                      a x  + b
+--R                                                      --------
+--R                                                          3
+--R           2      2 a   b log(f)        3          6     x
+--R        - b log(f) f Ei(--------) + (b x log(f) + x )f
+--R                            3
+--R                           x
+--R   (2)  ------------------------------------------------------
+--R                                   6
+--R                                                    Type: Expression(Integer)
+--E 947
+
+--S 948 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       3
+--R                 b + %D a
+--R                 --------
+--R           x          3
+--R         ++    5    %D
+--R   (3)   |   %D f        d%D
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 948
+
+--S 949 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       3
+--R                 b + %D a
+--R                 --------
+--R           x          3
+--R         ++    5    %D           2      2 a   b log(f)
+--R       6 |   %D f        d%D  + b log(f) f Ei(--------)
+--R        ++                                        3
+--R                                                 x
+--R     + 
+--R                              3
+--R                           a x  + b
+--R                           --------
+--R                               3
+--R             3          6     x
+--R       (- b x log(f) - x )f
+--R  /
+--R     6
+--R                                                    Type: Expression(Integer)
+--E 949
+
+--S 950 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 950
+
+)clear all
+
+--S 951 of 1000
+t0:=f^(a+b/x^3)*x^2
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R         2    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 951
+
+--S 952 of 1000
+r0:=1/3*f^(a+b/x^3)*x^3-1/3*b*f^a*Ei(b*log(f)/x^3)*log(f)
+--R 
+--R
+--R                                         3
+--R                                      a x  + b
+--R                                      --------
+--R                                          3
+--R                   a   b log(f)     3    x
+--R        - b log(f)f Ei(--------) + x f
+--R                           3
+--R                          x
+--R   (2)  --------------------------------------
+--R                           3
+--R                                                    Type: Expression(Integer)
+--E 952
+
+--S 953 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       3
+--R                 b + %D a
+--R                 --------
+--R           x          3
+--R         ++    2    %D
+--R   (3)   |   %D f        d%D
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 953
+
+--S 954 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                        3                                       3
+--R                  b + %D a                                   a x  + b
+--R                  --------                                   --------
+--R            x          3                                         3
+--R          ++    2    %D                   a   b log(f)     3    x
+--R        3 |   %D f        d%D  + b log(f)f Ei(--------) - x f
+--R         ++                                       3
+--R                                                 x
+--R   (4)  -------------------------------------------------------------
+--R                                      3
+--R                                                    Type: Expression(Integer)
+--E 954
+
+--S 955 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 955
+
+)clear all
+
+--S 956 of 1000
+t0:=f^(a+b/x^3)/x
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 1000
+r0:=-1/3*f^a*Ei(b*log(f)/x^3)
+--R 
+--R
+--R           a   b log(f)
+--R          f Ei(--------)
+--R                   3
+--R                  x
+--R   (2)  - --------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 957
+
+--S 958 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    3
+--R              b + %D a
+--R              --------
+--R                   3
+--R           x     %D
+--R         ++  f
+--R   (3)   |   --------- d%D
+--R        ++       %D
+--R                                         Type: Union(Expression(Integer),...)
+--E 958
+
+--S 959 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                     3
+--R               b + %D a
+--R               --------
+--R                    3
+--R            x     %D
+--R          ++  f                 a   b log(f)
+--R        3 |   --------- d%D  + f Ei(--------)
+--R         ++       %D                    3
+--R                                       x
+--R   (4)  -------------------------------------
+--R                          3
+--R                                                    Type: Expression(Integer)
+--E 959
+
+--S 960 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 960
+
+)clear all
+
+--S 961 of 1000
+t0:=f^(a+b/x^3)/x^4
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R             4
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 961
+
+--S 962 of 1000
+r0:=-1/3*f^(a+b/x^3)/(b*log(f))
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R              x
+--R          f
+--R   (2)  - ---------
+--R          3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3
+--R            (a x  + b)log(f)
+--R            ----------------
+--R                    3
+--R                   x
+--R          %e
+--R   (3)  - ------------------
+--R               3b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 963
+
+--S 964 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                3                  3
+--R            (a x  + b)log(f)    a x  + b
+--R            ----------------    --------
+--R                    3               3
+--R                   x               x
+--R        - %e                 + f
+--R   (4)  --------------------------------
+--R                    3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 964
+
+--S 965 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 965
+
+)clear all
+
+--S 966 of 1000
+t0:=f^(a+b/x^3)/x^7
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R             7
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 966
+
+--S 967 of 1000
+r0:=1/3*f^(a+b/x^3)/(b^2*log(f)^2)-1/3*f^(a+b/x^3)/(b*x^3*log(f))
+--R 
+--R
+--R                             3
+--R                          a x  + b
+--R                          --------
+--R                              3
+--R                       3     x
+--R        (- b log(f) + x )f
+--R   (2)  --------------------------
+--R                 2 3      2
+--R               3b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 967
+
+--S 968 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               3
+--R                           (a x  + b)log(f)
+--R                           ----------------
+--R                                   3
+--R                       3          x
+--R        (- b log(f) + x )%e
+--R   (3)  -----------------------------------
+--R                      2 3      2
+--R                    3b x log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 968
+
+--S 969 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                               3                                 3
+--R                           (a x  + b)log(f)                   a x  + b
+--R                           ----------------                   --------
+--R                                   3                              3
+--R                       3          x                        3     x
+--R        (- b log(f) + x )%e                 + (b log(f) - x )f
+--R   (4)  --------------------------------------------------------------
+--R                                   2 3      2
+--R                                 3b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 969
+
+--S 970 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 970
+
+)clear all
+
+--S 971 of 1000
+t0:=f^(a+b/x^3)/x^10
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R            10
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 971
+
+--S 972 of 1000
+r0:=-2/3*f^(a+b/x^3)/(b^3*log(f)^3)+2/3*f^(a+b/x^3)/(b^2*x^3*log(f)^2)-_
+   1/3*f^(a+b/x^3)/(b*x^6*log(f))
+--R 
+--R
+--R                                             3
+--R                                          a x  + b
+--R                                          --------
+--R                                              3
+--R            2      2       3           6     x
+--R        (- b log(f)  + 2b x log(f) - 2x )f
+--R   (2)  ------------------------------------------
+--R                         3 6      3
+--R                       3b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 972
+
+--S 973 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                               3
+--R                                           (a x  + b)log(f)
+--R                                           ----------------
+--R                                                   3
+--R            2      2       3           6          x
+--R        (- b log(f)  + 2b x log(f) - 2x )%e
+--R   (3)  ---------------------------------------------------
+--R                              3 6      3
+--R                            3b x log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 973
+
+--S 974 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              3
+--R                                          (a x  + b)log(f)
+--R                                          ----------------
+--R                                                  3
+--R           2      2       3           6          x
+--R       (- b log(f)  + 2b x log(f) - 2x )%e
+--R     + 
+--R                                          3
+--R                                       a x  + b
+--R                                       --------
+--R                                           3
+--R         2      2       3           6     x
+--R       (b log(f)  - 2b x log(f) + 2x )f
+--R  /
+--R       3 6      3
+--R     3b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 974
+
+--S 975 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 975
+
+)clear all
+
+--S 976 of 1000
+t0:=f^(a+b/x^3)/x^13
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R            13
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 976
+
+--S 977 of 1000
+r0:=2*f^(a+b/x^3)/(b^4*log(f)^4)-2*f^(a+b/x^3)/(b^3*x^3*log(f)^3)+_
+   f^(a+b/x^3)/(b^2*x^6*log(f)^2)-1/3*f^(a+b/x^3)/(b*x^9*log(f))
+--R 
+--R
+--R                                                            3
+--R                                                         a x  + b
+--R                                                         --------
+--R                                                             3
+--R            3      3     2 3      2       6           9     x
+--R        (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )f
+--R   (2)  ---------------------------------------------------------
+--R                                 4 9      4
+--R                               3b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                              3
+--R                                                          (a x  + b)log(f)
+--R                                                          ----------------
+--R                                                                  3
+--R            3      3     2 3      2       6           9          x
+--R        (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )%e
+--R   (3)  ------------------------------------------------------------------
+--R                                     4 9      4
+--R                                   3b x log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 978
+
+--S 979 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                             3
+--R                                                         (a x  + b)log(f)
+--R                                                         ----------------
+--R                                                                 3
+--R           3      3     2 3      2       6           9          x
+--R       (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )%e
+--R     + 
+--R                                                         3
+--R                                                      a x  + b
+--R                                                      --------
+--R                                                          3
+--R         3      3     2 3      2       6           9     x
+--R       (b log(f)  - 3b x log(f)  + 6b x log(f) - 6x )f
+--R  /
+--R       4 9      4
+--R     3b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 979
+
+--S 980 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 980
+
+)clear all
+
+--S 981 of 1000
+t0:=f^(a+b/x^3)/x^16
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R            16
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 981
+
+--S 982 of 1000
+--r0:=-1/3*f^a*GAMMA(5,-b*log(f)/x^3)/(b^5*log(f)^5)
+--E 982
+
+--S 983 of 1000
+--a0:=integrate(t0,x)
+--E 983
+
+--S 984 of 1000
+--m0:=a0-r0
+--E 984
+
+--S 985 of 1000
+--d0:=normalize(D(m0,x))
+--E 985
+
+)clear all
+
+--S 986 of 1000
+t0:=f^(a+b/x^3)/x^19
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R            19
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 986
+
+--S 987 of 1000
+--r0:=1/3*f^a*GAMMA(6,-b*log(f)/x^3)/(b^6*log(f)^6)
+--E 987
+
+--S 988 of 1000
+--a0:=integrate(t0,x)
+--E 988
+
+--S 989 of 1000
+--m0:=a0-r0
+--E 989
+
+--S 990 of 1000
+--d0:=normalize(D(m0,x))
+--E 990
+
+)clear all
+
+--S 991 of 1000
+t0:=f^(a+b/x^3)*x^4
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R         4    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 991
+
+--S 992 of 1000
+--r0:=1/3*f^a*x^5*GAMMA(-5/3,-b*log(f)/x^3)*(-b*log(f)/x^3)^(5/3)
+--E 992
+
+--S 993 of 1000
+--a0:=integrate(t0,x)
+--E 993
+
+--S 994 of 1000
+--m0:=a0-r0
+--E 994
+
+--S 995 of 1000
+--d0:=normalize(D(m0,x))
+--E 995
+
+)clear all
+
+--S 996 of 1000
+t0:=f^(a+b/x^3)*x^3
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R         3    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 996
+
+--S 997 of 1000
+--r0:=1/3*f^a*x^4*GAMMA(-4/3,-b*log(f)/x^3)*(-b*log(f)/x^3)^(4/3)
+--E 997
+
+--S 998 of 1000
+--a0:=integrate(t0,x)
+--E 998
+
+--S 999 of 1000
+--m0:=a0-r0
+--E 999
+
+--S 1000 of 1000
+--d0:=normalize(D(m0,x))
+--E 1000
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich24b.input.pamphlet b/src/input/rich24b.input.pamphlet
new file mode 100644
index 0000000..f2e51f4
--- /dev/null
+++ b/src/input/rich24b.input.pamphlet
@@ -0,0 +1,8884 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich24b.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Exponential Functions
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich24b.output
+)spool rich24b.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1000
+t0:=f^(a+b/x^3)*x
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R              x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1000
+--r0:=1/3*f^a*x^2*GAMMA(-2/3,-b*log(f)/x^3)*(-b*log(f)/x^3)^(2/3)
+--E 2
+
+--S 3 of 1000
+--a0:=integrate(t0,x)
+--E 3
+
+--S 4 of 1000
+--m0:=a0-r0
+--E 4
+
+--S 5 of 1000
+--d0:=normalize(D(m0,x))
+--E 5
+
+)clear all
+
+--S 6 of 1000
+t0:=f^(a+b/x^3)
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 1000
+--r0:=1/3*f^a*x*GAMMA(-1/3,-b*log(f)/x^3)*(-b*log(f)/x^3)^(1/3)
+--E 7
+
+--S 8 of 1000
+--a0:=integrate(t0,x)
+--E 8
+
+--S 9 of 1000
+--m0:=a0-r0
+--E 9
+
+--S 10 of 1000
+--d0:=normalize(D(m0,x))
+--E 10
+
+)clear all
+
+--S 11 of 1000
+t0:=f^(a+b/x^3)/x^2
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1000
+--r0:=1/3*f^a*GAMMA(1/3,-b*log(f)/x^3)/(x*(-b*log(f)/x^3)^(1/3))
+--E 12
+
+--S 13 of 1000
+--a0:=integrate(t0,x)
+--E 13
+
+--S 14 of 1000
+--m0:=a0-r0
+--E 14
+
+--S 15 of 1000
+--d0:=normalize(D(m0,x))
+--E 15
+
+)clear all
+
+--S 16 of 1000
+t0:=f^(a+b/x^3)/x^3
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1000
+--r0:=1/3*f^a*GAMMA(2/3,-b*log(f)/x^3)/(x^2*(-b*log(f)/x^3)^(2/3))
+--E 17
+
+--S 18 of 1000
+--a0:=integrate(t0,x)
+--E 18
+
+--S 19 of 1000
+--m0:=a0-r0
+--E 19
+
+--S 20 of 1000
+--d0:=normalize(D(m0,x))
+--E 20
+
+)clear all
+
+--S 21 of 1000
+t0:=f^(a+b/x^3)/x^5
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R             5
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 1000
+--r0:=1/3*f^a*GAMMA(4/3,-b*log(f)/x^3)/(x^4*(-b*log(f)/x^3)^(4/3))
+--E 22
+
+--S 23 of 1000
+--a0:=integrate(t0,x)
+--E 23
+
+--S 24 of 1000
+--m0:=a0-r0
+--E 24
+
+--S 25 of 1000
+--d0:=normalize(D(m0,x))
+--E 25
+
+)clear all
+
+--S 26 of 1000
+t0:=f^(a+b*x^n)*x^m
+--R 
+--R
+--R              n
+--R         m b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1000
+--r0:=-f^a*x^(1+m)*GAMMA((1+m)/n,-b*x^n*log(f))/(n*(-b*x^n*log(f))^((1+m)/n))
+--E 27
+
+--S 28 of 1000
+--a0:=integrate(t0,x)
+--E 28
+
+--S 29 of 1000
+--m0:=a0-r0
+--E 29
+
+--S 30 of 1000
+--d0:=normalize(D(m0,x))
+--E 30
+
+)clear all
+
+--S 31 of 1000
+t0:=f^(a+b*x^n)*x^3
+--R 
+--R
+--R              n
+--R         3 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 1000
+--r0:=-f^a*x^4*GAMMA(4/n,-b*x^n*log(f))/(n*(-b*x^n*log(f))^(4/n))
+--E 32
+
+--S 33 of 1000
+--a0:=integrate(t0,x)
+--E 33
+
+--S 34 of 1000
+--m0:=a0-r0
+--E 34
+
+--S 35 of 1000
+--d0:=normalize(D(m0,x))
+--E 35
+
+)clear all
+
+--S 36 of 1000
+t0:=f^(a+b*x^n)*x^2
+--R 
+--R
+--R              n
+--R         2 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 1000
+--r0:=-f^a*x^3*GAMMA(3/n,-b*x^n*log(f))/(n*(-b*x^n*log(f))^(3/n))
+--E 37
+
+--S 38 of 1000
+--a0:=integrate(t0,x)
+--E 38
+
+--S 39 of 1000
+--m0:=a0-r0
+--E 39
+
+--S 40 of 1000
+--d0:=normalize(D(m0,x))
+--E 40
+
+)clear all
+
+--S 41 of 1000
+t0:=f^(a+b*x^n)*x
+--R 
+--R
+--R              n
+--R           b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 1000
+--r0:=-f^a*x^2*GAMMA(2/n,-b*x^n*log(f))/(n*(-b*x^n*log(f))^(2/n))
+--E 42
+
+--S 43 of 1000
+--a0:=integrate(t0,x)
+--E 43
+
+--S 44 of 1000
+--m0:=a0-r0
+--E 44
+
+--S 45 of 1000
+--d0:=normalize(D(m0,x))
+--E 45
+
+)clear all
+
+--S 46 of 1000
+t0:=f^(a+b*x^n)
+--R 
+--R
+--R            n
+--R         b x  + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 1000
+--r0:=-f^a*x*GAMMA(1/n,-b*x^n*log(f))/(n*(-b*x^n*log(f))^(1/n))
+--E 47
+
+--S 48 of 1000
+--a0:=integrate(t0,x)
+--E 48
+
+--S 49 of 1000
+--m0:=a0-r0
+--E 49
+
+--S 50 of 1000
+--d0:=normalize(D(m0,x))
+--E 50
+
+)clear all
+
+--S 51 of 1000
+t0:=f^(a+b*x^n)/x
+--R 
+--R
+--R            n
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 1000
+r0:=f^a*Ei(b*x^n*log(f))/n
+--R 
+--R
+--R         a            n
+--R        f Ei(b log(f)x )
+--R   (2)  ----------------
+--R                n
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  n
+--R           x  b %A  + a
+--R         ++  f
+--R   (3)   |   ---------- d%A
+--R        ++       %A
+--R                                         Type: Union(Expression(Integer),...)
+--E 53
+
+--S 54 of 1000
+--m0:=a0-r0
+--E 54
+
+--S 55 of 1000
+--d0:=normalize(D(m0,x))
+--E 55
+
+)clear all
+
+--S 56 of 1000
+t0:=f^(a+b*x^n)/x^2
+--R 
+--R
+--R            n
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1000
+--r0:=-f^a*GAMMA((-1)/n,-b*x^n*log(f))*(-b*x^n*log(f))^(1/n)/(n*x)
+--E 57
+
+--S 58 of 1000
+--a0:=integrate(t0,x)
+--E 58
+
+--S 59 of 1000
+--m0:=a0-r0
+--E 59
+
+--S 60 of 1000
+--d0:=normalize(D(m0,x))
+--E 60
+
+)clear all
+
+--S 61 of 1000
+t0:=f^(a+b*x^n)/x^3
+--R 
+--R
+--R            n
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 1000
+--r0:=-f^a*GAMMA((-2)/n,-b*x^n*log(f))*(-b*x^n*log(f))^(2/n)/(n*x^2)
+--E 62
+
+--S 63 of 1000
+--a0:=integrate(t0,x)
+--E 63
+
+--S 64 of 1000
+--m0:=a0-r0
+--E 64
+
+--S 65 of 1000
+--d0:=normalize(D(m0,x))
+--E 65
+
+)clear all
+
+--S 66 of 1000
+t0:=f^(a+b*x^n)/x^4
+--R 
+--R
+--R            n
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             4
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 1000
+--r0:=-f^a*GAMMA((-3)/n,-b*x^n*log(f))*(-b*x^n*log(f))^(3/n)/(n*x^3)
+--E 67
+
+--S 68 of 1000
+--a0:=integrate(t0,x)
+--E 68
+
+--S 69 of 1000
+--m0:=a0-r0
+--E 69
+
+--S 70 of 1000
+--d0:=normalize(D(m0,x))
+--E 70
+
+)clear all
+
+--S 71 of 1000
+t0:=f^(a+b*x^n)*x^(-1+3*n)
+--R 
+--R
+--R                   n
+--R         3n - 1 b x  + a
+--R   (1)  x      f
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1000
+r0:=2*f^(a+b*x^n)/(b^3*n*log(f)^3)-2*f^(a+b*x^n)*x^n/(b^2*n*log(f)^2)+_
+   f^(a+b*x^n)*x^(2*n)/(b*n*log(f))
+--R 
+--R
+--R                                            n
+--R          2      2 2n             n      b x  + a
+--R        (b log(f) x   - 2b log(f)x  + 2)f
+--R   (2)  -----------------------------------------
+--R                        3        3
+--R                       b n log(f)
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2      2   n log(x) 2              n log(x)
+--R       (b log(f) (%e        )  - 2b log(f)%e         + 2)
+--R    *
+--R                   n log(x)
+--R         b log(f)%e         + a log(f)
+--R       %e
+--R  /
+--R      3        3
+--R     b n log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 73
+
+--S 74 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2      2   n log(x) 2              n log(x)
+--R         (b log(f) (%e        )  - 2b log(f)%e         + 2)
+--R      *
+--R                     n log(x)
+--R           b log(f)%e         + a log(f)
+--R         %e
+--R     + 
+--R                                             n
+--R           2      2 2n             n      b x  + a
+--R       (- b log(f) x   + 2b log(f)x  - 2)f
+--R  /
+--R      3        3
+--R     b n log(f)
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 1000
+t0:=f^(a+b*x^n)*x^(-1+2*n)
+--R 
+--R
+--R                   n
+--R         2n - 1 b x  + a
+--R   (1)  x      f
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 1000
+r0:=-f^(a+b*x^n)/(b^2*n*log(f)^2)+f^(a+b*x^n)*x^n/(b*n*log(f))
+--R 
+--R
+--R                            n
+--R                  n      b x  + a
+--R        (b log(f)x  - 1)f
+--R   (2)  -------------------------
+--R                2        2
+--R               b n log(f)
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                            n log(x)
+--R                   n log(x)       b log(f)%e         + a log(f)
+--R        (b log(f)%e         - 1)%e
+--R   (3)  -------------------------------------------------------
+--R                               2        2
+--R                              b n log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 78
+
+--S 79 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                           n log(x)
+--R                  n log(x)       b log(f)%e         + a log(f)
+--R       (b log(f)%e         - 1)%e
+--R     + 
+--R                             n
+--R                   n      b x  + a
+--R       (- b log(f)x  + 1)f
+--R  /
+--R      2        2
+--R     b n log(f)
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 80
+
+)clear all
+
+--S 81 of 1000
+t0:=f^(a+b*x^n)*x^(-1+n)
+--R 
+--R
+--R                  n
+--R         n - 1 b x  + a
+--R   (1)  x     f
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 1000
+r0:=f^(a+b*x^n)/(b*n*log(f))
+--R 
+--R
+--R             n
+--R          b x  + a
+--R         f
+--R   (2)  ----------
+--R        b n log(f)
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    n log(x)
+--R          b log(f)%e         + a log(f)
+--R        %e
+--R   (3)  -------------------------------
+--R                   b n log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 83
+
+--S 84 of 1000
+m0:=a0-r0
+--R 
+--R
+--R                    n log(x)                  n
+--R          b log(f)%e         + a log(f)    b x  + a
+--R        %e                              - f
+--R   (4)  -------------------------------------------
+--R                         b n log(f)
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 1000
+t0:=f^(a+b*x^n)/x
+--R 
+--R
+--R            n
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 1000
+r0:=f^a*Ei(b*x^n*log(f))/n
+--R 
+--R
+--R         a            n
+--R        f Ei(b log(f)x )
+--R   (2)  ----------------
+--R                n
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  n
+--R           x  b %A  + a
+--R         ++  f
+--R   (3)   |   ---------- d%A
+--R        ++       %A
+--R                                         Type: Union(Expression(Integer),...)
+--E 88
+
+--S 89 of 1000
+--m0:=a0-r0
+--E 89
+
+--S 90 of 1000
+--d0:=normalize(D(m0,x))
+--E 90
+
+)clear all
+
+--S 91 of 1000
+t0:=f^(a+b*x^n)*x^(-1-n)
+--R 
+--R
+--R                    n
+--R         - n - 1 b x  + a
+--R   (1)  x       f
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1000
+r0:=-f^(a+b*x^n)/(n*x^n)+b*f^a*Ei(b*x^n*log(f))*log(f)/n
+--R 
+--R
+--R              n
+--R           b x  + a            a n            n
+--R        - f         + b log(f)f x Ei(b log(f)x )
+--R   (2)  ----------------------------------------
+--R                             n
+--R                          n x
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x               n
+--R         ++    - n - 1 b %A  + a
+--R   (3)   |   %A       f         d%A
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 93
+
+--S 94 of 1000
+--m0:=a0-r0
+--E 94
+
+--S 95 of 1000
+--d0:=normalize(D(m0,x))
+--E 95
+
+)clear all
+
+--S 96 of 1000
+t0:=f^(a+b*x^n)*x^(-1-2*n)
+--R 
+--R
+--R                     n
+--R         - 2n - 1 b x  + a
+--R   (1)  x        f
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 1000
+r0:=-1/2*f^(a+b*x^n)/(n*x^(2*n))-1/2*b*f^(a+b*x^n)*log(f)/(n*x^n)+_
+   1/2*b^2*f^a*Ei(b*x^n*log(f))*log(f)^2/n
+--R 
+--R
+--R                                n
+--R                    2n    n  b x  + a    2      2 a n 2n            n
+--R        (- b log(f)x   - x )f         + b log(f) f x x  Ei(b log(f)x )
+--R   (2)  --------------------------------------------------------------
+--R                                       n 2n
+--R                                   2n x x
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x                n
+--R         ++    - 2n - 1 b %A  + a
+--R   (3)   |   %A        f         d%A
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 98
+
+--S 99 of 1000
+--m0:=a0-r0
+--E 99
+
+--S 100 of 1000
+--d0:=normalize(D(m0,x))
+--E 100
+
+)clear all
+
+--S 101 of 1000
+t0:=f^(a+b*x^n)*x^(-1+5/2*n)
+--R 
+--R
+--R         5n - 2
+--R         ------    n
+--R            2   b x  + a
+--R   (1)  x      f
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1000
+--r0:=-3/2*f^(a+b*x^n)*x^(1/2*n)/(b^2*n*log(f)^2)+f^(a+b*x^n)*_
+--  x^(3/2*n)/(b*n*log(f))+3/4*f^a*erfi(x^(1/2*n)*sqrt(b)*sqrt(log(f)))*_
+--  sqrt(%pi)/(b^(5/2)*n*log(f)^(5/2))
+--E 102
+
+--S 103 of 1000
+--a0:=integrate(t0,x)
+--E 103
+
+--S 104 of 1000
+--m0:=a0-r0
+--E 104
+
+--S 105 of 1000
+--d0:=normalize(D(m0,x))
+--E 105
+
+)clear all
+
+--S 106 of 1000
+t0:=f^(a+b*x^n)*x^(-1+3/2*n)
+--R 
+--R
+--R         3n - 2
+--R         ------    n
+--R            2   b x  + a
+--R   (1)  x      f
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 1000
+--r0:=f^(a+b*x^n)*x^(1/2*n)/(b*n*log(f))-1/2*f^a*erfi(x^(1/2*n)*sqrt(b)*_
+--  sqrt(log(f)))*sqrt(%pi)/(b^(3/2)*n*log(f)^(3/2))
+--E 107
+
+--S 108 of 1000
+--a0:=integrate(t0,x)
+--E 108
+
+--S 109 of 1000
+--m0:=a0-r0
+--E 109
+
+--S 110 of 1000
+--d0:=normalize(D(m0,x))
+--E 110
+
+)clear all
+
+--S 111 of 1000
+t0:=f^(a+b*x^n)*x^(-1+1/2*n)
+--R 
+--R
+--R         n - 2
+--R         -----    n
+--R           2   b x  + a
+--R   (1)  x     f
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 1000
+--r0:=f^a*erfi(x^(1/2*n)*sqrt(b)*sqrt(log(f)))*sqrt(%pi)/(n*sqrt(b)*_
+--  sqrt(log(f)))
+--E 112
+
+--S 113 of 1000
+--a0:=integrate(t0,x)
+--E 113
+
+--S 114 of 1000
+--m0:=a0-r0
+--E 114
+
+--S 115 of 1000
+--d0:=normalize(D(m0,x))
+--E 115
+
+)clear all
+
+--S 116 of 1000
+t0:=f^(a+b*x^n)*x^(-1-1/2*n)
+--R 
+--R
+--R         - n - 2
+--R         -------    n
+--R            2    b x  + a
+--R   (1)  x       f
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1000
+--r0:=-2*f^(a+b*x^n)/(n*x^(1/2*n))+2*f^a*erfi(x^(1/2*n)*sqrt(b)*_
+--  sqrt(log(f)))*sqrt(%pi)*sqrt(b)*sqrt(log(f))/n
+--E 117
+
+--S 118 of 1000
+--a0:=integrate(t0,x)
+--E 118
+
+--S 119 of 1000
+--m0:=a0-r0
+--E 119
+
+--S 120 of 1000
+--d0:=normalize(D(m0,x))
+--E 120
+
+)clear all
+
+--S 121 of 1000
+t0:=f^(a+b*x^n)*x^(-1-3/2*n)
+--R 
+--R
+--R         - 3n - 2
+--R         --------    n
+--R             2    b x  + a
+--R   (1)  x        f
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1000
+--r0:=-2/3*f^(a+b*x^n)/(n*x^(3/2*n))-4/3*b*f^(a+b*x^n)*log(f)/(n*x^(1/2*n))+_
+--  4/3*b^(3/2)*f^a*erfi(x^(1/2*n)*sqrt(b)*sqrt(log(f)))*_
+--  log(f)^(3/2)*sqrt(%pi)/n
+--E 122
+
+--S 123 of 1000
+--a0:=integrate(t0,x)
+--E 123
+
+--S 124 of 1000
+--m0:=a0-r0
+--E 124
+
+--S 125 of 1000
+--d0:=normalize(D(m0,x))
+--E 125
+
+)clear all
+
+--S 126 of 1000
+t0:=%e^((-0.1)*x)*x
+--R 
+--R
+--R                                - 0.1 x
+--R   (1)  x 2.7182818284 590452354
+--R                                                      Type: Expression(Float)
+--E 126
+
+--S 127 of 1000
+--r0:=(-100.)*%e^((-0.1)*x)+(-10.)*%e^((-0.1)*x)*x
+--E 127
+
+--S 128 of 1000
+--a0:=integrate(t0,x)
+--E 128
+
+--S 129 of 1000
+--m0:=a0-r0
+--E 129
+
+--S 130 of 1000
+--d0:=normalize(D(m0,x))
+--E 130
+
+)clear all
+
+--S 131 of 1000
+t0:=f^(c*(a+b*x)^2)*x^m
+--R 
+--R
+--R          2   2               2
+--R         b c x  + 2a b c x + a c m
+--R   (1)  f                       x
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 1000
+--r0:=Int(f^(a^2*c+2*a*b*c*x+b^2*c*x^2)*x^m,x)
+--E 132
+
+--S 133 of 1000
+--a0:=integrate(t0,x)
+--E 133
+
+--S 134 of 1000
+--m0:=a0-r0
+--E 134
+
+--S 135 of 1000
+--d0:=normalize(D(m0,x))
+--E 135
+
+)clear all
+
+--S 136 of 1000
+t0:=f^(c*(a+b*x)^2)*x^3
+--R 
+--R
+--R            2   2               2
+--R         3 b c x  + 2a b c x + a c
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 1000
+--r0:=-1/2*f^(c*(a+b*x)^2)/(b^4*c^2*log(f)^2)+3/2*a^2*f^(c*(a+b*x)^2)/_
+--  (b^4*c*log(f))-3/2*a*f^(c*(a+b*x)^2)*(a+b*x)/(b^4*c*log(f))+_
+--  1/2*f^(c*(a+b*x)^2)*(a+b*x)^2/(b^4*c*log(f))+3/4*a*erfi((a+b*x)*_
+--  sqrt(c)*sqrt(log(f)))*sqrt(%pi)/(b^4*c^(3/2)*log(f)^(3/2))-_
+--  1/2*a^3*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*sqrt(%pi)/(b^4*sqrt(c)*_
+--  sqrt(log(f)))
+--E 137
+
+--S 138 of 1000
+--a0:=integrate(t0,x)
+--E 138
+
+--S 139 of 1000
+--m0:=a0-r0
+--E 139
+
+--S 140 of 1000
+--d0:=normalize(D(m0,x))
+--E 140
+
+)clear all
+
+--S 141 of 1000
+t0:=f^(c*(a+b*x)^2)*x^2
+--R 
+--R
+--R            2   2               2
+--R         2 b c x  + 2a b c x + a c
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 1000
+--r0:=-a*f^(c*(a+b*x)^2)/(b^3*c*log(f))+1/2*f^(c*(a+b*x)^2)*(a+b*x)/_
+--  (b^3*c*log(f))-1/4*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*sqrt(%pi)/_
+--  (b^3*c^(3/2)*log(f)^(3/2))+1/2*a^2*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*_
+--  sqrt(%pi)/(b^3*sqrt(c)*sqrt(log(f)))
+--E 142
+
+--S 143 of 1000
+--a0:=integrate(t0,x)
+--E 143
+
+--S 144 of 1000
+--m0:=a0-r0
+--E 144
+
+--S 145 of 1000
+--d0:=normalize(D(m0,x))
+--E 145
+
+)clear all
+
+--S 146 of 1000
+t0:=f^(c*(a+b*x)^2)*x
+--R 
+--R
+--R            2   2               2
+--R           b c x  + 2a b c x + a c
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 1000
+--r0:=1/2*f^(c*(a+b*x)^2)/(b^2*c*log(f))-1/2*a*erfi((a+b*x)*sqrt(c)*_
+--  sqrt(log(f)))*sqrt(%pi)/(b^2*sqrt(c)*sqrt(log(f)))
+--E 147
+
+--S 148 of 1000
+--a0:=integrate(t0,x)
+--E 148
+
+--S 149 of 1000
+--m0:=a0-r0
+--E 149
+
+--S 150 of 1000
+--d0:=normalize(D(m0,x))
+--E 150
+
+)clear all
+
+--S 151 of 1000
+t0:=f^(c*(a+b*x)^2)
+--R 
+--R
+--R          2   2               2
+--R         b c x  + 2a b c x + a c
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 1000
+--r0:=1/2*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*sqrt(%pi)/(b*sqrt(c)*sqrt(log(f)))
+--E 152
+
+--S 153 of 1000
+--a0:=integrate(t0,x)
+--E 153
+
+--S 154 of 1000
+--m0:=a0-r0
+--E 154
+
+--S 155 of 1000
+--d0:=normalize(D(m0,x))
+--E 155
+
+)clear all
+
+--S 156 of 1000
+t0:=f^(c*(a+b*x)^2)/x
+--R 
+--R
+--R          2   2               2
+--R         b c x  + 2a b c x + a c
+--R        f
+--R   (1)  ------------------------
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 1000
+--r0:=Int(f^(c*(a+b*x)^2)/x,x)
+--E 157
+
+--S 158 of 1000
+--a0:=integrate(t0,x)
+--E 158
+
+--S 159 of 1000
+--m0:=a0-r0
+--E 159
+
+--S 160 of 1000
+--d0:=normalize(D(m0,x))
+--E 160
+
+)clear all
+
+--S 161 of 1000
+t0:=f^(c*(a+b*x)^2)/x^2
+--R 
+--R
+--R          2   2               2
+--R         b c x  + 2a b c x + a c
+--R        f
+--R   (1)  ------------------------
+--R                    2
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 1000
+--r0:=-f^(c*(a+b*x)^2)/x+2*a*b*c*Int(f^(c*(a+b*x)^2)/x,x)*log(f)+_
+--  b*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*sqrt(%pi)*sqrt(c)*sqrt(log(f))
+--E 162
+
+--S 163 of 1000
+--a0:=integrate(t0,x)
+--E 163
+
+--S 164 of 1000
+--m0:=a0-r0
+--E 164
+
+--S 165 of 1000
+--d0:=normalize(D(m0,x))
+--E 165
+
+)clear all
+
+--S 166 of 1000
+t0:=f^(c*(a+b*x)^2)/x^3
+--R 
+--R
+--R          2   2               2
+--R         b c x  + 2a b c x + a c
+--R        f
+--R   (1)  ------------------------
+--R                    3
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 1000
+--r0:=-1/2*f^(c*(a+b*x)^2)/x^2-a*b*c*f^(c*(a+b*x)^2)*log(f)/x+b^2*c*_
+--  Int(f^(c*(a+b*x)^2)/x,x)*log(f)+2*a^2*b^2*c^2*Int(f^(c*(a+b*x)^2)/x,x)*_
+--  log(f)^2+a*b^2*c^(3/2)*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*_
+--  log(f)^(3/2)*sqrt(%pi)
+--E 167
+
+--S 168 of 1000
+--a0:=integrate(t0,x)
+--E 168
+
+--S 169 of 1000
+--m0:=a0-r0
+--E 169
+
+--S 170 of 1000
+--d0:=normalize(D(m0,x))
+--E 170
+
+)clear all
+
+--S 171 of 1000
+t0:=f^(c*(a+b*x)^3)*x^m
+--R 
+--R
+--R          3   3       2   2     2         3
+--R         b c x  + 3a b c x  + 3a b c x + a c m
+--R   (1)  f                                   x
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 1000
+--r0:=Int(f^(c*(a+b*x)^3)*x^m,x)
+--E 172
+
+--S 173 of 1000
+--a0:=integrate(t0,x)
+--E 173
+
+--S 174 of 1000
+--m0:=a0-r0
+--E 174
+
+--S 175 of 1000
+--d0:=normalize(D(m0,x))
+--E 175
+
+)clear all
+
+--S 176 of 1000
+t0:=f^(c*(a+b*x)^3)*x^2
+--R 
+--R
+--R            3   3       2   2     2         3
+--R         2 b c x  + 3a b c x  + 3a b c x + a c
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 1000
+--r0:=1/3*f^(c*(a+b*x)^3)/(b^3*c*log(f))+2/3*a*(a+b*x)^2*_
+--  GAMMA(2/3,-c*(a+b*x)^3*log(f))/(b^3*(-c*(a+b*x)^3*log(f))^(2/3))-_
+--  1/3*a^2*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*log(f))/(b^3*(-c*(a+b*x)^3*_
+--  log(f))^(1/3))
+--E 177
+
+--S 178 of 1000
+--a0:=integrate(t0,x)
+--E 178
+
+--S 179 of 1000
+--m0:=a0-r0
+--E 179
+
+--S 180 of 1000
+--d0:=normalize(D(m0,x))
+--E 180
+
+)clear all
+
+--S 181 of 1000
+t0:=f^(c*(a+b*x)^3)*x
+--R 
+--R
+--R            3   3       2   2     2         3
+--R           b c x  + 3a b c x  + 3a b c x + a c
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1000
+--r0:=-1/3*(a+b*x)^2*GAMMA(2/3,-c*(a+b*x)^3*log(f))/(b^2*(-c*(a+b*x)^3*_
+--  log(f))^(2/3))+1/3*a*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*log(f))/_
+--  (b^2*(-c*(a+b*x)^3*log(f))^(1/3))
+--E 182
+
+--S 183 of 1000
+--a0:=integrate(t0,x)
+--E 183
+
+--S 184 of 1000
+--m0:=a0-r0
+--E 184
+
+--S 185 of 1000
+--d0:=normalize(D(m0,x))
+--E 185
+
+)clear all
+
+--S 186 of 1000
+t0:=f^(c*(a+b*x)^3)
+--R 
+--R
+--R          3   3       2   2     2         3
+--R         b c x  + 3a b c x  + 3a b c x + a c
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 1000
+--r0:=-1/3*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*log(f))/(b*(-c*(a+b*x)^3*_
+--  log(f))^(1/3))
+--E 187
+
+--S 188 of 1000
+--a0:=integrate(t0,x)
+--E 188
+
+--S 189 of 1000
+--m0:=a0-r0
+--E 189
+
+--S 190 of 1000
+--d0:=normalize(D(m0,x))
+--E 190
+
+)clear all
+
+--S 191 of 1000
+t0:=f^(c*(a+b*x)^3)/x
+--R 
+--R
+--R          3   3       2   2     2         3
+--R         b c x  + 3a b c x  + 3a b c x + a c
+--R        f
+--R   (1)  ------------------------------------
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1000
+--r0:=Int(f^(c*(a+b*x)^3)/x,x)
+--E 192
+
+--S 193 of 1000
+--a0:=integrate(t0,x)
+--E 193
+
+--S 194 of 1000
+--m0:=a0-r0
+--E 194
+
+--S 195 of 1000
+--d0:=normalize(D(m0,x))
+--E 195
+
+)clear all
+
+--S 196 of 1000
+t0:=f^(c*(a+b*x)^3)/x^2
+--R 
+--R
+--R          3   3       2   2     2         3
+--R         b c x  + 3a b c x  + 3a b c x + a c
+--R        f
+--R   (1)  ------------------------------------
+--R                          2
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1000
+--r0:=-f^(c*(a+b*x)^3)/x+3*a^2*b*c*Int(f^(c*(a+b*x)^3)/x,x)*log(f)-_
+--  b*c*(a+b*x)^2*GAMMA(2/3,-c*(a+b*x)^3*log(f))*log(f)/(-c*(a+b*x)^3*_
+--  log(f))^(2/3)-a*b*c*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*log(f))*log(f)/_
+--  (-c*(a+b*x)^3*log(f))^(1/3)
+--E 197
+
+--S 198 of 1000
+--a0:=integrate(t0,x)
+--E 198
+
+--S 199 of 1000
+--m0:=a0-r0
+--E 199
+
+--S 200 of 1000
+--d0:=normalize(D(m0,x))
+--E 200
+
+)clear all
+
+--S 201 of 1000
+t0:=f^(c*(a+b*x)^3)/x^3
+--R 
+--R
+--R          3   3       2   2     2         3
+--R         b c x  + 3a b c x  + 3a b c x + a c
+--R        f
+--R   (1)  ------------------------------------
+--R                          3
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 1000
+--r0:=-1/2*f^(c*(a+b*x)^3)/x^2-3/2*a^2*b*c*f^(c*(a+b*x)^3)*log(f)/x+_
+--  3*a*b^2*c*Int(f^(c*(a+b*x)^3)/x,x)*log(f)+9/2*a^4*b^2*c^2*_
+--  Int(f^(c*(a+b*x)^3)/x,x)*log(f)^2-3/2*a^2*b^2*c^2*(a+b*x)^2*_
+--  GAMMA(2/3,-c*(a+b*x)^3*log(f))*log(f)^2/(-c*(a+b*x)^3*log(f))^(2/3)-_
+--  1/2*b^2*c*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*log(f))*log(f)/(-c*(a+b*x)^3*_
+--  log(f))^(1/3)-3/2*a^3*b^2*c^2*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*_
+--  log(f))*log(f)^2/(-c*(a+b*x)^3*log(f))^(1/3)
+--E 202
+
+--S 203 of 1000
+--a0:=integrate(t0,x)
+--E 203
+
+--S 204 of 1000
+--m0:=a0-r0
+--E 204
+
+--S 205 of 1000
+--d0:=normalize(D(m0,x))
+--E 205
+
+)clear all
+
+--S 206 of 1000
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x^m
+--R 
+--R
+--R           3 3       2 2     2       3
+--R          b x  + 3a b x  + 3a b x + a  m
+--R   (1)  %e                            x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 1000
+--r0:=Int(%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x^m,x)
+--E 207
+
+--S 208 of 1000
+--a0:=integrate(t0,x)
+--E 208
+
+--S 209 of 1000
+--m0:=a0-r0
+--E 209
+
+--S 210 of 1000
+--d0:=normalize(D(m0,x))
+--E 210
+
+)clear all
+
+--S 211 of 1000
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x^4
+--R 
+--R
+--R             3 3       2 2     2       3
+--R         4  b x  + 3a b x  + 3a b x + a
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 1000
+--r0:=2*%e^((a+b*x)^3)*a^2/b^5-1/3*a^4*(a+b*x)*GAMMA(1/3,-(a+b*x)^3)/_
+--  (b^5*(-(a+b*x)^3)^(1/3))+4/3*a^3*(a+b*x)^2*GAMMA(2/3,-(a+b*x)^3)/_
+--  (b^5*(-(a+b*x)^3)^(2/3))+4/3*a*(a+b*x)^4*GAMMA(4/3,-(a+b*x)^3)/_
+--  (b^5*(-(a+b*x)^3)^(4/3))-1/3*(a+b*x)^5*GAMMA(5/3,-(a+b*x)^3)/_
+--  (b^5*(-(a+b*x)^3)^(5/3))
+--E 212
+
+--S 213 of 1000
+--a0:=integrate(t0,x)
+--E 213
+
+--S 214 of 1000
+--m0:=a0-r0
+--E 214
+
+--S 215 of 1000
+--d0:=normalize(D(m0,x))
+--E 215
+
+)clear all
+
+--S 216 of 1000
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x^3
+--R 
+--R
+--R             3 3       2 2     2       3
+--R         3  b x  + 3a b x  + 3a b x + a
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 1000
+--r0:=-%e^((a+b*x)^3)*a/b^4+1/3*a^3*(a+b*x)*GAMMA(1/3,-(a+b*x)^3)/_
+--  (b^4*(-(a+b*x)^3)^(1/3))-a^2*(a+b*x)^2*GAMMA(2/3,-(a+b*x)^3)/_
+--  (b^4*(-(a+b*x)^3)^(2/3))-1/3*(a+b*x)^4*GAMMA(4/3,-(a+b*x)^3)/_
+--  (b^4*(-(a+b*x)^3)^(4/3))
+--E 217
+
+--S 218 of 1000
+--a0:=integrate(t0,x)
+--E 218
+
+--S 219 of 1000
+--m0:=a0-r0
+--E 219
+
+--S 220 of 1000
+--d0:=normalize(D(m0,x))
+--E 220
+
+)clear all
+
+--S 221 of 1000
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x^2
+--R 
+--R
+--R             3 3       2 2     2       3
+--R         2  b x  + 3a b x  + 3a b x + a
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1000
+--r0:=1/3*%e^((a+b*x)^3)/b^3-1/3*a^2*(a+b*x)*GAMMA(1/3,-(a+b*x)^3)/_
+--  (b^3*(-(a+b*x)^3)^(1/3))+2/3*a*(a+b*x)^2*GAMMA(2/3,-(a+b*x)^3)/_
+--  (b^3*(-(a+b*x)^3)^(2/3))
+--E 222
+
+--S 223 of 1000
+--a0:=integrate(t0,x)
+--E 223
+
+--S 224 of 1000
+--m0:=a0-r0
+--E 224
+
+--S 225 of 1000
+--d0:=normalize(D(m0,x))
+--E 225
+
+)clear all
+
+--S 226 of 1000
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x
+--R 
+--R
+--R             3 3       2 2     2       3
+--R            b x  + 3a b x  + 3a b x + a
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 1000
+--r0:=1/3*a*(a+b*x)*GAMMA(1/3,-(a+b*x)^3)/(b^2*(-(a+b*x)^3)^(1/3))-_
+--  1/3*(a+b*x)^2*GAMMA(2/3,-(a+b*x)^3)/(b^2*(-(a+b*x)^3)^(2/3))
+--E 227
+
+--S 228 of 1000
+--a0:=integrate(t0,x)
+--E 228
+
+--S 229 of 1000
+--m0:=a0-r0
+--E 229
+
+--S 230 of 1000
+--d0:=normalize(D(m0,x))
+--E 230
+
+)clear all
+
+--S 231 of 1000
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)
+--R 
+--R
+--R           3 3       2 2     2       3
+--R          b x  + 3a b x  + 3a b x + a
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 1000
+--r0:=-1/3*(a+b*x)*GAMMA(1/3,-(a+b*x)^3)/(b*(-(a+b*x)^3)^(1/3))
+--E 232
+
+--S 233 of 1000
+--a0:=integrate(t0,x)
+--E 233
+
+--S 234 of 1000
+--m0:=a0-r0
+--E 234
+
+--S 235 of 1000
+--d0:=normalize(D(m0,x))
+--E 235
+
+)clear all
+
+--S 236 of 1000
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)/x
+--R 
+--R
+--R           3 3       2 2     2       3
+--R          b x  + 3a b x  + 3a b x + a
+--R        %e
+--R   (1)  ------------------------------
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 1000
+--r0:=Int(%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)/x,x)
+--E 237
+
+--S 238 of 1000
+--a0:=integrate(t0,x)
+--E 238
+
+--S 239 of 1000
+--m0:=a0-r0
+--E 239
+
+--S 240 of 1000
+--d0:=normalize(D(m0,x))
+--E 240
+
+)clear all
+
+--S 241 of 1000
+t0:=%e^sqrt(5+3*x)
+--R 
+--R
+--R           +------+
+--R          \|3x + 5
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 1000
+r0:=-2/3*%e^sqrt(5+3*x)+2/3*%e^sqrt(5+3*x)*sqrt(5+3*x)
+--R 
+--R
+--R                           +------+
+--R           +------+       \|3x + 5
+--R        (2\|3x + 5  - 2)%e
+--R   (2)  ---------------------------
+--R                     3
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           +------+
+--R           +------+       \|3x + 5
+--R        (2\|3x + 5  - 2)%e
+--R   (3)  ---------------------------
+--R                     3
+--R                                         Type: Union(Expression(Integer),...)
+--E 243
+
+--S 244 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 245
+
+)clear all
+
+--S 246 of 1000
+t0:=f^(c/(a+b*x))*x^m
+--R 
+--R
+--R            c
+--R         -------
+--R         b x + a m
+--R   (1)  f       x
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 1000
+--r0:=Int(f^(c/(a+b*x))*x^m,x)
+--E 247
+
+--S 248 of 1000
+--a0:=integrate(t0,x)
+--E 248
+
+--S 249 of 1000
+--m0:=a0-r0
+--E 249
+
+--S 250 of 1000
+--d0:=normalize(D(m0,x))
+--E 250
+
+)clear all
+
+--S 251 of 1000
+t0:=f^(c/(a+b*x))*x^4
+--R 
+--R
+--R              c
+--R           -------
+--R         4 b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 1000
+--r0:=a^4*f^(c/(a+b*x))*(a+b*x)/b^5-2*a^3*f^(c/(a+b*x))*(a+b*x)^2/b^5+_
+--  2*a^2*f^(c/(a+b*x))*(a+b*x)^3/b^5-2*a^3*c*f^(c/(a+b*x))*(a+b*x)*_
+--  log(f)/b^5+a^2*c*f^(c/(a+b*x))*(a+b*x)^2*log(f)/b^5-a^4*c*Ei(c*_
+--  log(f)/(a+b*x))*log(f)/b^5+a^2*c^2*f^(c/(a+b*x))*(a+b*x)*log(f)^2/_
+--  b^5+2*a^3*c^2*Ei(c*log(f)/(a+b*x))*log(f)^2/b^5-a^2*c^3*Ei(c*_
+--  log(f)/(a+b*x))*log(f)^3/b^5-4*a*c^4*GAMMA(-4,-c*log(f)/(a+b*x))*_
+--  log(f)^4/b^5-c^5*GAMMA(-5,-c*log(f)/(a+b*x))*log(f)^5/b^5
+--E 252
+
+--S 253 of 1000
+--a0:=integrate(t0,x)
+--E 253
+
+--S 254 of 1000
+--m0:=a0-r0
+--E 254
+
+--S 255 of 1000
+--d0:=normalize(D(m0,x))
+--E 255
+
+)clear all
+
+--S 256 of 1000
+t0:=f^(c/(a+b*x))*x^3
+--R 
+--R
+--R              c
+--R           -------
+--R         3 b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 1000
+--r0:=-a^3*f^(c/(a+b*x))*(a+b*x)/b^4+3/2*a^2*f^(c/(a+b*x))*(a+b*x)^2/b^4-_
+--  a*f^(c/(a+b*x))*(a+b*x)^3/b^4+3/2*a^2*c*f^(c/(a+b*x))*(a+b*x)*_
+--  log(f)/b^4-1/2*a*c*f^(c/(a+b*x))*(a+b*x)^2*log(f)/b^4+a^3*c*Ei(c*_
+--  log(f)/(a+b*x))*log(f)/b^4-1/2*a*c^2*f^(c/(a+b*x))*(a+b*x)*log(f)^2/_
+--  b^4-3/2*a^2*c^2*Ei(c*log(f)/(a+b*x))*log(f)^2/b^4+1/2*a*c^3*_
+--  Ei(c*log(f)/(a+b*x))*log(f)^3/b^4+c^4*GAMMA(-4,-c*log(f)/(a+b*x))*_
+--  log(f)^4/b^4
+--E 257
+
+--S 258 of 1000
+--a0:=integrate(t0,x)
+--E 258
+
+--S 259 of 1000
+--m0:=a0-r0
+--E 259
+
+--S 260 of 1000
+--d0:=normalize(D(m0,x))
+--E 260
+
+)clear all
+
+--S 261 of 1000
+t0:=f^(c/(a+b*x))*x^2
+--R 
+--R
+--R              c
+--R           -------
+--R         2 b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 1000
+r0:=a^2*f^(c/(a+b*x))*(a+b*x)/b^3-a*f^(c/(a+b*x))*(a+b*x)^2/b^3+_
+  1/3*f^(c/(a+b*x))*(a+b*x)^3/b^3-a*c*f^(c/(a+b*x))*(a+b*x)*_
+  log(f)/b^3+1/6*c*f^(c/(a+b*x))*(a+b*x)^2*log(f)/b^3-a^2*c*_
+  Ei(c*log(f)/(a+b*x))*log(f)/b^3+1/6*c^2*f^(c/(a+b*x))*(a+b*x)*_
+  log(f)^2/b^3+a*c^2*Ei(c*log(f)/(a+b*x))*log(f)^2/b^3-1/6*c^3*_
+  Ei(c*log(f)/(a+b*x))*log(f)^3/b^3
+--R 
+--R
+--R   (2)
+--R           3      3       2      2     2            c log(f)
+--R       (- c log(f)  + 6a c log(f)  - 6a c log(f))Ei(--------)
+--R                                                     b x + a
+--R     + 
+--R                 2       2       2     2   2                2             3 3
+--R             (b c x + a c )log(f)  + (b c x  - 4a b c x - 5a c)log(f) + 2b x
+--R           + 
+--R               3
+--R             2a
+--R      *
+--R             c
+--R          -------
+--R          b x + a
+--R         f
+--R  /
+--R       3
+--R     6b
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     c
+--R           x     --------
+--R         ++    2 %A b + a
+--R   (3)   |   %A f        d%A
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 263
+
+--S 264 of 1000
+--m0:=a0-r0
+--E 264
+
+--S 265 of 1000
+--d0:=normalize(D(m0,x))
+--E 265
+
+)clear all
+
+--S 266 of 1000
+t0:=f^(c/(a+b*x))*x
+--R 
+--R
+--R              c
+--R           -------
+--R           b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1000
+r0:=-a*f^(c/(a+b*x))*(a+b*x)/b^2+1/2*f^(c/(a+b*x))*(a+b*x)^2/b^2+_
+  1/2*c*f^(c/(a+b*x))*(a+b*x)*log(f)/b^2+a*c*Ei(c*log(f)/(a+b*x))*_
+  log(f)/b^2-1/2*c^2*Ei(c*log(f)/(a+b*x))*log(f)^2/b^2
+--R 
+--R
+--R   (2)
+--R           2      2                  c log(f)
+--R       (- c log(f)  + 2a c log(f))Ei(--------)
+--R                                      b x + a
+--R     + 
+--R                                            c
+--R                                         -------
+--R                               2 2    2  b x + a
+--R       ((b c x + a c)log(f) + b x  - a )f
+--R  /
+--R       2
+--R     2b
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     c
+--R           x     --------
+--R         ++      %A b + a
+--R   (3)   |   %A f        d%A
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 268
+
+--S 269 of 1000
+--m0:=a0-r0
+--E 269
+
+--S 270 of 1000
+--d0:=normalize(D(m0,x))
+--E 270
+
+)clear all
+
+--S 271 of 1000
+t0:=f^(c/(a+b*x))
+--R 
+--R
+--R            c
+--R         -------
+--R         b x + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 1000
+r0:=f^(c/(a+b*x))*(a+b*x)/b-c*Ei(c*log(f)/(a+b*x))*log(f)/b
+--R 
+--R
+--R                                              c
+--R                                           -------
+--R                     c log(f)              b x + a
+--R        - c log(f)Ei(--------) + (b x + a)f
+--R                      b x + a
+--R   (2)  ------------------------------------------
+--R                             b
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  c
+--R           x  --------
+--R         ++   %A b + a
+--R   (3)   |   f        d%A
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 273
+
+--S 274 of 1000
+--m0:=a0-r0
+--E 274
+
+--S 275 of 1000
+--d0:=normalize(D(m0,x))
+--E 275
+
+)clear all
+
+--S 276 of 1000
+t0:=f^(c/(a+b*x))/x
+--R 
+--R
+--R            c
+--R         -------
+--R         b x + a
+--R        f
+--R   (1)  --------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 1000
+r0:=-Ei(c*log(f)/(a+b*x))+f^(c/a)*Ei(-b*c*x*log(f)/(a*(a+b*x)))
+--R 
+--R
+--R                          c
+--R                          -
+--R             c log(f)     a     b c x log(f)
+--R   (2)  - Ei(--------) + f Ei(- ------------)
+--R              b x + a                     2
+--R                                 a b x + a
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  c
+--R              --------
+--R           x  %A b + a
+--R         ++  f
+--R   (3)   |   --------- d%A
+--R        ++       %A
+--R                                         Type: Union(Expression(Integer),...)
+--E 278
+
+--S 279 of 1000
+--m0:=a0-r0
+--E 279
+
+--S 280 of 1000
+--d0:=normalize(D(m0,x))
+--E 280
+
+)clear all
+
+--S 281 of 1000
+t0:=f^(c/(a+b*x))/x^2
+--R 
+--R
+--R            c
+--R         -------
+--R         b x + a
+--R        f
+--R   (1)  --------
+--R            2
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 1000
+r0:=-b*f^(c/(a+b*x))/a-f^(c/(a+b*x))/x-b*c*f^(c/a)*Ei(-b*c*x*log(f)/_
+  (a*(a+b*x)))*log(f)/a^2
+--R 
+--R
+--R                       c                                       c
+--R                       -                                    -------
+--R                       a     b c x log(f)                2  b x + a
+--R        - b c x log(f)f Ei(- ------------) + (- a b x - a )f
+--R                                       2
+--R                              a b x + a
+--R   (2)  -----------------------------------------------------------
+--R                                     2
+--R                                    a x
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  c
+--R              --------
+--R           x  %A b + a
+--R         ++  f
+--R   (3)   |   --------- d%A
+--R        ++        2
+--R                %A
+--R                                         Type: Union(Expression(Integer),...)
+--E 283
+
+--S 284 of 1000
+--m0:=a0-r0
+--E 284
+
+--S 285 of 1000
+--d0:=normalize(D(m0,x))
+--E 285
+
+)clear all
+
+--S 286 of 1000
+t0:=f^(c/(a+b*x))/x^3
+--R 
+--R
+--R            c
+--R         -------
+--R         b x + a
+--R        f
+--R   (1)  --------
+--R            3
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 1000
+r0:=1/2*b^2*f^(c/(a+b*x))/a^2-1/2*f^(c/(a+b*x))/x^2+1/2*b^2*c*f^(c/(a+b*x))*_
+   log(f)/a^3+1/2*b*c*f^(c/(a+b*x))*log(f)/(a^2*x)+b^2*c*f^(c/a)*_
+   Ei(-b*c*x*log(f)/(a*(a+b*x)))*log(f)/a^3+1/2*b^2*c^2*f^(c/a)*_
+   Ei(-b*c*x*log(f)/(a*(a+b*x)))*log(f)^2/a^4
+--R 
+--R
+--R   (2)
+--R                                         c
+--R                                         -
+--R         2 2 2      2       2   2        a     b c x log(f)
+--R       (b c x log(f)  + 2a b c x log(f))f Ei(- ------------)
+--R                                                         2
+--R                                                a b x + a
+--R     + 
+--R                                                     c
+--R                                                  -------
+--R            2   2    2                2 2 2    4  b x + a
+--R       ((a b c x  + a b c x)log(f) + a b x  - a )f
+--R  /
+--R       4 2
+--R     2a x
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 1000
+--a0:=integrate(t0,x)
+--E 288
+
+--S 289 of 1000
+--m0:=a0-r0
+--E 289
+
+--S 290 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 290
+
+)clear all
+
+--S 291 of 1000
+t0:=f^(c/(a+b*x)^2)*x^m
+--R 
+--R
+--R                  c
+--R         ------------------
+--R          2 2             2
+--R         b x  + 2a b x + a  m
+--R   (1)  f                  x
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 1000
+--r0:=Int(f^(c/(a+b*x)^2)*x^m,x)
+--E 292
+
+--S 293 of 1000
+--a0:=integrate(t0,x)
+--E 293
+
+--S 294 of 1000
+--m0:=a0-r0
+--E 294
+
+--S 295 of 1000
+--d0:=normalize(D(m0,x))
+--E 295
+
+)clear all
+
+--S 296 of 1000
+t0:=f^(c/(a+b*x)^2)*x^4
+--R 
+--R
+--R                    c
+--R           ------------------
+--R            2 2             2
+--R         4 b x  + 2a b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1000
+--r0:=a^4*f^(c/(a+b*x)^2)*(a+b*x)/b^5-2*a^3*f^(c/(a+b*x)^2)*(a+b*x)^2/b^5+_
+--  2*a^2*f^(c/(a+b*x)^2)*(a+b*x)^3/b^5-a*f^(c/(a+b*x)^2)*(a+b*x)^4/b^5+_
+--  1/5*f^(c/(a+b*x)^2)*(a+b*x)^5/b^5+4*a^2*c*f^(c/(a+b*x)^2)*(a+b*x)*_
+--  log(f)/b^5-a*c*f^(c/(a+b*x)^2)*(a+b*x)^2*log(f)/b^5+2/15*c*_
+--  f^(c/(a+b*x)^2)*(a+b*x)^3*log(f)/b^5+2*a^3*c*Ei(c*log(f)/(a+b*x)^2)*_
+--  log(f)/b^5+4/15*c^2*f^(c/(a+b*x)^2)*(a+b*x)*log(f)^2/b^5+a*c^2*_
+--  Ei(c*log(f)/(a+b*x)^2)*log(f)^2/b^5-4*a^2*c^(3/2)*erfi(sqrt(c)*_
+--  sqrt(log(f))/(a+b*x))*log(f)^(3/2)*sqrt(%pi)/b^5-4/15*c^(5/2)*_
+--  erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*log(f)^(5/2)*sqrt(%pi)/b^5-_
+--  a^4*erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*sqrt(%pi)*sqrt(c)*sqrt(log(f))/b^5
+--E 297
+
+--S 298 of 1000
+--a0:=integrate(t0,x)
+--E 298
+
+--S 299 of 1000
+--m0:=a0-r0
+--E 299
+
+--S 300 of 1000
+--d0:=normalize(D(m0,x))
+--E 300
+
+)clear all
+
+--S 301 of 1000
+t0:=f^(c/(a+b*x)^2)*x^3
+--R 
+--R
+--R                    c
+--R           ------------------
+--R            2 2             2
+--R         3 b x  + 2a b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1000
+--r0:=-a^3*f^(c/(a+b*x)^2)*(a+b*x)/b^4+3/2*a^2*f^(c/(a+b*x)^2)*(a+b*x)^2/_
+--  b^4-a*f^(c/(a+b*x)^2)*(a+b*x)^3/b^4+1/4*f^(c/(a+b*x)^2)*(a+b*x)^4/_
+--  b^4-2*a*c*f^(c/(a+b*x)^2)*(a+b*x)*log(f)/b^4+1/4*c*f^(c/(a+b*x)^2)*_
+--  (a+b*x)^2*log(f)/b^4-3/2*a^2*c*Ei(c*log(f)/(a+b*x)^2)*log(f)/b^4-_
+--  1/4*c^2*Ei(c*log(f)/(a+b*x)^2)*log(f)^2/b^4+2*a*c^(3/2)*_
+--  erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*log(f)^(3/2)*sqrt(%pi)/b^4+_
+--  a^3*erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*sqrt(%pi)*sqrt(c)*sqrt(log(f))/b^4
+--E 302
+
+--S 303 of 1000
+--a0:=integrate(t0,x)
+--E 303
+
+--S 304 of 1000
+--m0:=a0-r0
+--E 304
+
+--S 305 of 1000
+--d0:=normalize(D(m0,x))
+--E 305
+
+)clear all
+
+--S 306 of 1000
+t0:=f^(c/(a+b*x)^2)*x^2
+--R 
+--R
+--R                    c
+--R           ------------------
+--R            2 2             2
+--R         2 b x  + 2a b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 1000
+--r0:=a^2*f^(c/(a+b*x)^2)*(a+b*x)/b^3-a*f^(c/(a+b*x)^2)*(a+b*x)^2/b^3+_
+--  1/3*f^(c/(a+b*x)^2)*(a+b*x)^3/b^3+2/3*c*f^(c/(a+b*x)^2)*(a+b*x)*_
+--  log(f)/b^3+a*c*Ei(c*log(f)/(a+b*x)^2)*log(f)/b^3-2/3*c^(3/2)*_
+--  erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*log(f)^(3/2)*sqrt(%pi)/b^3-_
+--  a^2*erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*sqrt(%pi)*sqrt(c)*sqrt(log(f))/b^3
+--E 307
+
+--S 308 of 1000
+--a0:=integrate(t0,x)
+--E 308
+
+--S 309 of 1000
+--m0:=a0-r0
+--E 309
+
+--S 310 of 1000
+--d0:=normalize(D(m0,x))
+--E 310
+
+)clear all
+
+--S 311 of 1000
+t0:=f^(c/(a+b*x)^2)*x
+--R 
+--R
+--R                    c
+--R           ------------------
+--R            2 2             2
+--R           b x  + 2a b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 1000
+--r0:=-a*f^(c/(a+b*x)^2)*(a+b*x)/b^2+1/2*f^(c/(a+b*x)^2)*(a+b*x)^2/b^2-_
+--  1/2*c*Ei(c*log(f)/(a+b*x)^2)*log(f)/b^2+a*erfi(sqrt(c)*sqrt(log(f))/_
+--  (a+b*x))*sqrt(%pi)*sqrt(c)*sqrt(log(f))/b^2
+--E 312
+
+--S 313 of 1000
+--a0:=integrate(t0,x)
+--E 313
+
+--S 314 of 1000
+--m0:=a0-r0
+--E 314
+
+--S 315 of 1000
+--d0:=normalize(D(m0,x))
+--E 315
+
+)clear all
+
+--S 316 of 1000
+t0:=f^(c/(a+b*x)^2)
+--R 
+--R
+--R                  c
+--R         ------------------
+--R          2 2             2
+--R         b x  + 2a b x + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 1000
+--r0:=f^(c/(a+b*x)^2)*(a+b*x)/b-erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*_
+--  sqrt(%pi)*sqrt(c)*sqrt(log(f))/b
+--E 317
+
+--S 318 of 1000
+--a0:=integrate(t0,x)
+--E 318
+
+--S 319 of 1000
+--m0:=a0-r0
+--E 319
+
+--S 320 of 1000
+--d0:=normalize(D(m0,x))
+--E 320
+
+)clear all
+
+--S 321 of 1000
+t0:=f^(c/(a+b*x)^2)/x
+--R 
+--R
+--R                  c
+--R         ------------------
+--R          2 2             2
+--R         b x  + 2a b x + a
+--R        f
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 1000
+--r0:=Int(f^(c/(a+b*x)^2)/x,x)
+--E 322
+
+--S 323 of 1000
+--a0:=integrate(t0,x)
+--E 323
+
+--S 324 of 1000
+--m0:=a0-r0
+--E 324
+
+--S 325 of 1000
+--d0:=normalize(D(m0,x))
+--E 325
+
+)clear all
+
+--S 326 of 1000
+t0:=f^(c/(a+b*x)^2)/x^2
+--R 
+--R
+--R                  c
+--R         ------------------
+--R          2 2             2
+--R         b x  + 2a b x + a
+--R        f
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 1000
+--r0:=Int(f^(c/(a+b*x)^2)/x^2,x)
+--E 327
+
+--S 328 of 1000
+--a0:=integrate(t0,x)
+--E 328
+
+--S 329 of 1000
+--m0:=a0-r0
+--E 329
+
+--S 330 of 1000
+--d0:=normalize(D(m0,x))
+--E 330
+
+)clear all
+
+--S 331 of 1000
+t0:=f^(c/(a+b*x)^2)/x^3
+--R 
+--R
+--R                  c
+--R         ------------------
+--R          2 2             2
+--R         b x  + 2a b x + a
+--R        f
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 1000
+--r0:=Int(f^(c/(a+b*x)^2)/x^3,x)
+--E 332
+
+--S 333 of 1000
+--a0:=integrate(t0,x)
+--E 333
+
+--S 334 of 1000
+--m0:=a0-r0
+--E 334
+
+--S 335 of 1000
+--d0:=normalize(D(m0,x))
+--E 335
+
+)clear all
+
+--S 336 of 1000
+t0:=f^(c/(a+b*x)^3)*x^m
+--R 
+--R
+--R                       c
+--R         ----------------------------
+--R          3 3       2 2     2       3
+--R         b x  + 3a b x  + 3a b x + a  m
+--R   (1)  f                            x
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 1000
+--r0:=Int(f^(c/(a+b*x)^3)*x^m,x)
+--E 337
+
+--S 338 of 1000
+--a0:=integrate(t0,x)
+--E 338
+
+--S 339 of 1000
+--m0:=a0-r0
+--E 339
+
+--S 340 of 1000
+--d0:=normalize(D(m0,x))
+--E 340
+
+)clear all
+
+--S 341 of 1000
+t0:=f^(c/(a+b*x)^3)*x^4
+--R 
+--R
+--R                         c
+--R           ----------------------------
+--R            3 3       2 2     2       3
+--R         4 b x  + 3a b x  + 3a b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 1000
+--r0:=2*a^2*f^(c/(a+b*x)^3)*(a+b*x)^3/b^5-2*a^2*c*Ei(c*log(f)/(a+b*x)^3)*_
+--  log(f)/b^5+1/3*a^4*(a+b*x)*GAMMA(-1/3,-c*log(f)/(a+b*x)^3)*(-c*log(f)/_
+--  (a+b*x)^3)^(1/3)/b^5-4/3*a^3*(a+b*x)^2*GAMMA(-2/3,-c*log(f)/(a+b*x)^3)*_
+--  (-c*log(f)/(a+b*x)^3)^(2/3)/b^5-4/3*a*(a+b*x)^4*GAMMA(-4/3,-c*log(f)/_
+--  (a+b*x)^3)*(-c*log(f)/(a+b*x)^3)^(4/3)/b^5+1/3*(a+b*x)^5*_
+--  GAMMA(-5/3,-c*log(f)/(a+b*x)^3)*(-c*log(f)/(a+b*x)^3)^(5/3)/b^5
+--E 342
+
+--S 343 of 1000
+--a0:=integrate(t0,x)
+--E 343
+
+--S 344 of 1000
+--m0:=a0-r0
+--E 344
+
+--S 345 of 1000
+--d0:=normalize(D(m0,x))
+--E 345
+
+)clear all
+
+--S 346 of 1000
+t0:=f^(c/(a+b*x)^3)*x^3
+--R 
+--R
+--R                         c
+--R           ----------------------------
+--R            3 3       2 2     2       3
+--R         3 b x  + 3a b x  + 3a b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 1000
+--r0:=-a*f^(c/(a+b*x)^3)*(a+b*x)^3/b^4+a*c*Ei(c*log(f)/(a+b*x)^3)*log(f)/_
+--  b^4-1/3*a^3*(a+b*x)*GAMMA(-1/3,-c*log(f)/(a+b*x)^3)*(-c*log(f)/_
+--  (a+b*x)^3)^(1/3)/b^4+a^2*(a+b*x)^2*GAMMA(-2/3,-c*log(f)/(a+b*x)^3)*_
+--  (-c*log(f)/(a+b*x)^3)^(2/3)/b^4+1/3*(a+b*x)^4*GAMMA(-4/3,-c*log(f)/_
+--  (a+b*x)^3)*(-c*log(f)/(a+b*x)^3)^(4/3)/b^4
+--E 347
+
+--S 348 of 1000
+--a0:=integrate(t0,x)
+--E 348
+
+--S 349 of 1000
+--m0:=a0-r0
+--E 349
+
+--S 350 of 1000
+--d0:=normalize(D(m0,x))
+--E 350
+
+)clear all
+
+--S 351 of 1000
+t0:=f^(c/(a+b*x)^3)*x^2
+--R 
+--R
+--R                         c
+--R           ----------------------------
+--R            3 3       2 2     2       3
+--R         2 b x  + 3a b x  + 3a b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 1000
+--r0:=1/3*f^(c/(a+b*x)^3)*(a+b*x)^3/b^3-1/3*c*Ei(c*log(f)/(a+b*x)^3)*_
+--  log(f)/b^3+1/3*a^2*(a+b*x)*GAMMA(-1/3,-c*log(f)/(a+b*x)^3)*(-c*_
+--  log(f)/(a+b*x)^3)^(1/3)/b^3-2/3*a*(a+b*x)^2*GAMMA(-2/3,-c*log(f)/_
+--  (a+b*x)^3)*(-c*log(f)/(a+b*x)^3)^(2/3)/b^3
+--E 352
+
+--S 353 of 1000
+--a0:=integrate(t0,x)
+--E 353
+
+--S 354 of 1000
+--m0:=a0-r0
+--E 354
+
+--S 355 of 1000
+--d0:=normalize(D(m0,x))
+--E 355
+
+)clear all
+
+--S 356 of 1000
+t0:=f^(c/(a+b*x)^3)*x
+--R 
+--R
+--R                         c
+--R           ----------------------------
+--R            3 3       2 2     2       3
+--R           b x  + 3a b x  + 3a b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 1000
+--r0:=-1/3*a*(a+b*x)*GAMMA(-1/3,-c*log(f)/(a+b*x)^3)*(-c*log(f)/_
+--  (a+b*x)^3)^(1/3)/b^2+1/3*(a+b*x)^2*GAMMA(-2/3,-c*log(f)/(a+b*x)^3)*_
+--  (-c*log(f)/(a+b*x)^3)^(2/3)/b^2
+--E 357
+
+--S 358 of 1000
+--a0:=integrate(t0,x)
+--E 358
+
+--S 359 of 1000
+--m0:=a0-r0
+--E 359
+
+--S 360 of 1000
+--d0:=normalize(D(m0,x))
+--E 360
+
+)clear all
+
+--S 361 of 1000
+t0:=f^(c/(a+b*x)^3)
+--R 
+--R
+--R                       c
+--R         ----------------------------
+--R          3 3       2 2     2       3
+--R         b x  + 3a b x  + 3a b x + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 1000
+--r0:=1/3*(a+b*x)*GAMMA(-1/3,-c*log(f)/(a+b*x)^3)*(-c*log(f)/(a+b*x)^3)^(1/3)/b
+--E 362
+
+--S 363 of 1000
+--a0:=integrate(t0,x)
+--E 363
+
+--S 364 of 1000
+--m0:=a0-r0
+--E 364
+
+--S 365 of 1000
+--d0:=normalize(D(m0,x))
+--E 365
+
+)clear all
+
+--S 366 of 1000
+t0:=f^(c/(a+b*x)^3)/x
+--R 
+--R
+--R                       c
+--R         ----------------------------
+--R          3 3       2 2     2       3
+--R         b x  + 3a b x  + 3a b x + a
+--R        f
+--R   (1)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 1000
+--r0:=Int(f^(c/(a+b*x)^3)/x,x)
+--E 367
+
+--S 368 of 1000
+--a0:=integrate(t0,x)
+--E 368
+
+--S 369 of 1000
+--m0:=a0-r0
+--E 369
+
+--S 370 of 1000
+--d0:=normalize(D(m0,x))
+--E 370
+
+)clear all
+
+--S 371 of 1000
+t0:=f^(c/(a+b*x)^3)/x^2
+--R 
+--R
+--R                       c
+--R         ----------------------------
+--R          3 3       2 2     2       3
+--R         b x  + 3a b x  + 3a b x + a
+--R        f
+--R   (1)  -----------------------------
+--R                       2
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1000
+--r0:=Int(f^(c/(a+b*x)^3)/x^2,x)
+--E 372
+
+--S 373 of 1000
+--a0:=integrate(t0,x)
+--E 373
+
+--S 374 of 1000
+--m0:=a0-r0
+--E 374
+
+--S 375 of 1000
+--d0:=normalize(D(m0,x))
+--E 375
+
+)clear all
+
+--S 376 of 1000
+t0:=f^(c/(a+b*x)^3)/x^3
+--R 
+--R
+--R                       c
+--R         ----------------------------
+--R          3 3       2 2     2       3
+--R         b x  + 3a b x  + 3a b x + a
+--R        f
+--R   (1)  -----------------------------
+--R                       3
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1000
+--r0:=Int(f^(c/(a+b*x)^3)/x^3,x)
+--E 377
+
+--S 378 of 1000
+--a0:=integrate(t0,x)
+--E 378
+
+--S 379 of 1000
+--m0:=a0-r0
+--E 379
+
+--S 380 of 1000
+--d0:=normalize(D(m0,x))
+--E 380
+
+)clear all
+
+--S 381 of 1000
+t0:=f^(c*(a+b*x)^n)*x^m
+--R 
+--R
+--R                      n
+--R         m c (b x + a)
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 1000
+--r0:=Int(f^(c*(a+b*x)^n)*x^m,x)
+--E 382
+
+--S 383 of 1000
+--a0:=integrate(t0,x)
+--E 383
+
+--S 384 of 1000
+--m0:=a0-r0
+--E 384
+
+--S 385 of 1000
+--d0:=normalize(D(m0,x))
+--E 385
+
+)clear all
+
+--S 386 of 1000
+t0:=f^(c*(a+b*x)^n)*x^3
+--R 
+--R
+--R                      n
+--R         3 c (b x + a)
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 1000
+--r0:=-(a+b*x)^4*GAMMA(4/n,-c*(a+b*x)^n*log(f))/(b^4*n*(-c*(a+b*x)^n*_
+--  log(f))^(4/n))+3*a*(a+b*x)^3*GAMMA(3/n,-c*(a+b*x)^n*log(f))/(b^4*n*_
+--  (-c*(a+b*x)^n*log(f))^(3/n))-3*a^2*(a+b*x)^2*GAMMA(2/n,-c*(a+b*x)^n*_
+--  log(f))/(b^4*n*(-c*(a+b*x)^n*log(f))^(2/n))+a^3*(a+b*x)*_
+--  GAMMA(1/n,-c*(a+b*x)^n*log(f))/(b^4*n*(-c*(a+b*x)^n*log(f))^(1/n))
+--E 387
+
+--S 388 of 1000
+--a0:=integrate(t0,x)
+--E 388
+
+--S 389 of 1000
+--m0:=a0-r0
+--E 389
+
+--S 390 of 1000
+--d0:=normalize(D(m0,x))
+--E 390
+
+)clear all
+
+--S 391 of 1000
+t0:=f^(c*(a+b*x)^n)*x^2
+--R 
+--R
+--R                      n
+--R         2 c (b x + a)
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1000
+--r0:=-(a+b*x)^3*GAMMA(3/n,-c*(a+b*x)^n*log(f))/(b^3*n*(-c*(a+b*x)^n*_
+--  log(f))^(3/n))+2*a*(a+b*x)^2*GAMMA(2/n,-c*(a+b*x)^n*log(f))/(b^3*n*_
+--  (-c*(a+b*x)^n*log(f))^(2/n))-a^2*(a+b*x)*GAMMA(1/n,-c*(a+b*x)^n*_
+--  log(f))/(b^3*n*(-c*(a+b*x)^n*log(f))^(1/n))
+--E 392
+
+--S 393 of 1000
+--a0:=integrate(t0,x)
+--E 393
+
+--S 394 of 1000
+--m0:=a0-r0
+--E 394
+
+--S 395 of 1000
+--d0:=normalize(D(m0,x))
+--E 395
+
+)clear all
+
+--S 396 of 1000
+t0:=f^(c*(a+b*x)^n)*x
+--R 
+--R
+--R                      n
+--R           c (b x + a)
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 396
+
+--S 397 of 1000
+--r0:=-(a+b*x)^2*GAMMA(2/n,-c*(a+b*x)^n*log(f))/(b^2*n*(-c*(a+b*x)^n*_
+--  log(f))^(2/n))+a*(a+b*x)*GAMMA(1/n,-c*(a+b*x)^n*log(f))/(b^2*n*_
+--  (-c*(a+b*x)^n*log(f))^(1/n))
+--E 397
+
+--S 398 of 1000
+--a0:=integrate(t0,x)
+--E 398
+
+--S 399 of 1000
+--m0:=a0-r0
+--E 399
+
+--S 400 of 1000
+--d0:=normalize(D(m0,x))
+--E 400
+
+)clear all
+
+--S 401 of 1000
+t0:=f^(c*(a+b*x)^n)
+--R 
+--R
+--R                    n
+--R         c (b x + a)
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 1000
+--r0:=-(a+b*x)*GAMMA(1/n,-c*(a+b*x)^n*log(f))/(b*n*(-c*(a+b*x)^n*log(f))^(1/n))
+--E 402
+
+--S 403 of 1000
+--a0:=integrate(t0,x)
+--E 403
+
+--S 404 of 1000
+--m0:=a0-r0
+--E 404
+
+--S 405 of 1000
+--d0:=normalize(D(m0,x))
+--E 405
+
+)clear all
+
+--S 406 of 1000
+t0:=f^(c*(a+b*x)^n)/x
+--R 
+--R
+--R                    n
+--R         c (b x + a)
+--R        f
+--R   (1)  -------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 1000
+--r0:=Int(f^(c*(a+b*x)^n)/x,x)
+--E 407
+
+--S 408 of 1000
+--a0:=integrate(t0,x)
+--E 408
+
+--S 409 of 1000
+--m0:=a0-r0
+--E 409
+
+--S 410 of 1000
+--d0:=normalize(D(m0,x))
+--E 410
+
+)clear all
+
+--S 411 of 1000
+t0:=f^(c*(a+b*x)^n)/x^2
+--R 
+--R
+--R                    n
+--R         c (b x + a)
+--R        f
+--R   (1)  -------------
+--R               2
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 1000
+--r0:=Int(f^(c*(a+b*x)^n)/x^2,x)
+--E 412
+
+--S 413 of 1000
+--a0:=integrate(t0,x)
+--E 413
+
+--S 414 of 1000
+--m0:=a0-r0
+--E 414
+
+--S 415 of 1000
+--d0:=normalize(D(m0,x))
+--E 415
+
+)clear all
+
+--S 416 of 1000
+t0:=f^(c*(a+b*x)^n)/x^3
+--R 
+--R
+--R                    n
+--R         c (b x + a)
+--R        f
+--R   (1)  -------------
+--R               3
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 1000
+--r0:=Int(f^(c*(a+b*x)^n)/x^3,x)
+--E 417
+
+--S 418 of 1000
+--a0:=integrate(t0,x)
+--E 418
+
+--S 419 of 1000
+--m0:=a0-r0
+--E 419
+
+--S 420 of 1000
+--d0:=normalize(D(m0,x))
+--E 420
+
+)clear all
+
+--S 421 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^m
+--R 
+--R
+--R            2 2                 2
+--R         b d x  + 2b c d x + b c  + a         m
+--R   (1)  F                            (d x + c)
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 1000
+--r0:=-1/2*F^a*(c+d*x)^(1+m)*GAMMA(1/2*(1+m),-b*(c+d*x)^2*log(F))*_
+--  (-b*(c+d*x)^2*log(F))^(1/2*(-1-m))/d
+--E 422
+
+--S 423 of 1000
+--a0:=integrate(t0,x)
+--E 423
+
+--S 424 of 1000
+--m0:=a0-r0
+--E 424
+
+--S 425 of 1000
+--d0:=normalize(D(m0,x))
+--E 425
+
+)clear all
+
+--S 426 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^11
+--R 
+--R
+--R   (1)
+--R        11 11        10 10      2 9 9       3 8 8       4 7 7       5 6 6
+--R       d  x   + 11c d  x   + 55c d x  + 165c d x  + 330c d x  + 462c d x
+--R     + 
+--R           6 5 5       7 4 4       8 3 3      9 2 2      10       11
+--R       462c d x  + 330c d x  + 165c d x  + 55c d x  + 11c  d x + c
+--R  *
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 1000
+--r0:=-1/2*F^a*GAMMA(6,-b*(c+d*x)^2*log(F))/(b^6*d*log(F)^6)
+--E 427
+
+--S 428 of 1000
+--a0:=integrate(t0,x)
+--E 428
+
+--S 429 of 1000
+--m0:=a0-r0
+--E 429
+
+--S 430 of 1000
+--d0:=normalize(D(m0,x))
+--E 430
+
+)clear all
+
+--S 431 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^9
+--R 
+--R
+--R   (1)
+--R        9 9       8 8      2 7 7      3 6 6       4 5 5       5 4 4      6 3 3
+--R       d x  + 9c d x  + 36c d x  + 84c d x  + 126c d x  + 126c d x  + 84c d x
+--R     + 
+--R          7 2 2     8       9
+--R       36c d x  + 9c d x + c
+--R  *
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1000
+--r0:=1/2*F^a*GAMMA(5,-b*(c+d*x)^2*log(F))/(b^5*d*log(F)^5)
+--E 432
+
+--S 433 of 1000
+--a0:=integrate(t0,x)
+--E 433
+
+--S 434 of 1000
+--m0:=a0-r0
+--E 434
+
+--S 435 of 1000
+--d0:=normalize(D(m0,x))
+--E 435
+
+)clear all
+
+--S 436 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^7
+--R 
+--R
+--R   (1)
+--R       7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R     (d x  + 7c d x  + 21c d x  + 35c d x  + 35c d x  + 21c d x  + 7c d x + c )
+--R  *
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 1000
+r0:=-3*F^(a+b*(c+d*x)^2)/(b^4*d*log(F)^4)+3*F^(a+b*(c+d*x)^2)*_
+  (c+d*x)^2/(b^3*d*log(F)^3)-3/2*F^(a+b*(c+d*x)^2)*(c+d*x)^4/_
+  (b^2*d*log(F)^2)+1/2*F^(a+b*(c+d*x)^2)*(c+d*x)^6/(b*d*log(F))
+--R 
+--R
+--R   (2)
+--R              3 6 6     3   5 5      3 2 4 4      3 3 3 3      3 4 2 2
+--R             b d x  + 6b c d x  + 15b c d x  + 20b c d x  + 15b c d x
+--R           + 
+--R               3 5       3 6
+--R             6b c d x + b c
+--R        *
+--R                 3
+--R           log(F)
+--R       + 
+--R              2 4 4      2   3 3      2 2 2 2      2 3        2 4       2
+--R         (- 3b d x  - 12b c d x  - 18b c d x  - 12b c d x - 3b c )log(F)
+--R       + 
+--R              2 2                   2
+--R         (6b d x  + 12b c d x + 6b c )log(F) - 6
+--R    *
+--R           2 2                 2
+--R        b d x  + 2b c d x + b c  + a
+--R       F
+--R  /
+--R       4        4
+--R     2b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 6 6     3   5 5      3 2 4 4      3 3 3 3      3 4 2 2
+--R             b d x  + 6b c d x  + 15b c d x  + 20b c d x  + 15b c d x
+--R           + 
+--R               3 5       3 6
+--R             6b c d x + b c
+--R        *
+--R                 3
+--R           log(F)
+--R       + 
+--R              2 4 4      2   3 3      2 2 2 2      2 3        2 4       2
+--R         (- 3b d x  - 12b c d x  - 18b c d x  - 12b c d x - 3b c )log(F)
+--R       + 
+--R              2 2                   2
+--R         (6b d x  + 12b c d x + 6b c )log(F) - 6
+--R    *
+--R             2 2                 2
+--R         (b d x  + 2b c d x + b c  + a)log(F)
+--R       %e
+--R  /
+--R       4        4
+--R     2b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 438
+
+--S 439 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                3 6 6     3   5 5      3 2 4 4      3 3 3 3      3 4 2 2
+--R               b d x  + 6b c d x  + 15b c d x  + 20b c d x  + 15b c d x
+--R             + 
+--R                 3 5       3 6
+--R               6b c d x + b c
+--R          *
+--R                   3
+--R             log(F)
+--R         + 
+--R                2 4 4      2   3 3      2 2 2 2      2 3        2 4       2
+--R           (- 3b d x  - 12b c d x  - 18b c d x  - 12b c d x - 3b c )log(F)
+--R         + 
+--R                2 2                   2
+--R           (6b d x  + 12b c d x + 6b c )log(F) - 6
+--R      *
+--R               2 2                 2
+--R           (b d x  + 2b c d x + b c  + a)log(F)
+--R         %e
+--R     + 
+--R                  3 6 6     3   5 5      3 2 4 4      3 3 3 3      3 4 2 2
+--R               - b d x  - 6b c d x  - 15b c d x  - 20b c d x  - 15b c d x
+--R             + 
+--R                   3 5       3 6
+--R               - 6b c d x - b c
+--R          *
+--R                   3
+--R             log(F)
+--R         + 
+--R              2 4 4      2   3 3      2 2 2 2      2 3        2 4       2
+--R           (3b d x  + 12b c d x  + 18b c d x  + 12b c d x + 3b c )log(F)
+--R         + 
+--R                  2 2                   2
+--R           (- 6b d x  - 12b c d x - 6b c )log(F) + 6
+--R      *
+--R             2 2                 2
+--R          b d x  + 2b c d x + b c  + a
+--R         F
+--R  /
+--R       4        4
+--R     2b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 440
+
+)clear all
+
+--S 441 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^5
+--R 
+--R
+--R   (1)
+--R       5 5       4 4      2 3 3      3 2 2     4       5
+--R     (d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c )
+--R  *
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 1000
+r0:=F^(a+b*(c+d*x)^2)/(b^3*d*log(F)^3)-F^(a+b*(c+d*x)^2)*(c+d*x)^2/_
+  (b^2*d*log(F)^2)+1/2*F^(a+b*(c+d*x)^2)*(c+d*x)^4/(b*d*log(F))
+--R 
+--R
+--R   (2)
+--R           2 4 4     2   3 3     2 2 2 2     2 3       2 4       2
+--R         (b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c )log(F)
+--R       + 
+--R                2 2                  2
+--R         (- 2b d x  - 4b c d x - 2b c )log(F) + 2
+--R    *
+--R           2 2                 2
+--R        b d x  + 2b c d x + b c  + a
+--R       F
+--R  /
+--R       3        3
+--R     2b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 4 4     2   3 3     2 2 2 2     2 3       2 4       2
+--R         (b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c )log(F)
+--R       + 
+--R                2 2                  2
+--R         (- 2b d x  - 4b c d x - 2b c )log(F) + 2
+--R    *
+--R             2 2                 2
+--R         (b d x  + 2b c d x + b c  + a)log(F)
+--R       %e
+--R  /
+--R       3        3
+--R     2b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 443
+
+--S 444 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2 4 4     2   3 3     2 2 2 2     2 3       2 4       2
+--R           (b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c )log(F)
+--R         + 
+--R                  2 2                  2
+--R           (- 2b d x  - 4b c d x - 2b c )log(F) + 2
+--R      *
+--R               2 2                 2
+--R           (b d x  + 2b c d x + b c  + a)log(F)
+--R         %e
+--R     + 
+--R               2 4 4     2   3 3     2 2 2 2     2 3       2 4       2
+--R           (- b d x  - 4b c d x  - 6b c d x  - 4b c d x - b c )log(F)
+--R         + 
+--R                2 2                  2
+--R           (2b d x  + 4b c d x + 2b c )log(F) - 2
+--R      *
+--R             2 2                 2
+--R          b d x  + 2b c d x + b c  + a
+--R         F
+--R  /
+--R       3        3
+--R     2b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 445
+
+)clear all
+
+--S 446 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^3
+--R 
+--R
+--R                                          2 2                 2
+--R          3 3       2 2     2       3  b d x  + 2b c d x + b c  + a
+--R   (1)  (d x  + 3c d x  + 3c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1000
+r0:=-1/2*F^(a+b*(c+d*x)^2)/(b^2*d*log(F)^2)+1/2*F^(a+b*(c+d*x)^2)*_
+  (c+d*x)^2/(b*d*log(F))
+--R 
+--R
+--R                                                  2 2                 2
+--R             2 2                 2             b d x  + 2b c d x + b c  + a
+--R        ((b d x  + 2b c d x + b c )log(F) - 1)F
+--R   (2)  -------------------------------------------------------------------
+--R                                      2        2
+--R                                    2b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                               2 2                 2
+--R        2 2                 2              (b d x  + 2b c d x + b c  + a)log(F)
+--R   ((b d x  + 2b c d x + b c )log(F) - 1)%e
+--R   ----------------------------------------------------------------------------
+--R                                     2        2
+--R                                   2b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 448
+
+--S 449 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2 2                 2
+--R         ((b d x  + 2b c d x + b c )log(F) - 1)
+--R      *
+--R               2 2                 2
+--R           (b d x  + 2b c d x + b c  + a)log(F)
+--R         %e
+--R     + 
+--R                                                   2 2                 2
+--R              2 2                 2             b d x  + 2b c d x + b c  + a
+--R       ((- b d x  - 2b c d x - b c )log(F) + 1)F
+--R  /
+--R       2        2
+--R     2b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)
+--R 
+--R
+--R                     2 2                 2
+--R                  b d x  + 2b c d x + b c  + a
+--R   (1)  (d x + c)F
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 1000
+r0:=1/2*F^(a+b*(c+d*x)^2)/(b*d*log(F))
+--R 
+--R
+--R            2 2                 2
+--R         b d x  + 2b c d x + b c  + a
+--R        F
+--R   (2)  -----------------------------
+--R                 2b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2 2                 2
+--R          (b d x  + 2b c d x + b c  + a)log(F)
+--R        %e
+--R   (3)  --------------------------------------
+--R                      2b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 453
+
+--S 454 of 1000
+m0:=a0-r0
+--R 
+--R
+--R              2 2                 2                  2 2                 2
+--R          (b d x  + 2b c d x + b c  + a)log(F)    b d x  + 2b c d x + b c  + a
+--R        %e                                     - F
+--R   (4)  ----------------------------------------------------------------------
+--R                                      2b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 455
+
+)clear all
+
+--S 456 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)
+--R 
+--R
+--R            2 2                 2
+--R         b d x  + 2b c d x + b c  + a
+--R        F
+--R   (1)  -----------------------------
+--R                   d x + c
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 1000
+r0:=1/2*F^a*Ei(b*(c+d*x)^2*log(F))/d
+--R 
+--R
+--R         a       2 2                 2
+--R        F Ei((b d x  + 2b c d x + b c )log(F))
+--R   (2)  --------------------------------------
+--R                          2d
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2   2                  2
+--R           x  %A b d  + 2%A b c d + b c  + a
+--R         ++  F
+--R   (3)   |   ------------------------------- d%A
+--R        ++               %A d + c
+--R                                         Type: Union(Expression(Integer),...)
+--E 458
+
+--S 459 of 1000
+--m0:=a0-r0
+--E 459
+
+--S 460 of 1000
+--d0:=normalize(D(m0,x))
+--E 460
+
+)clear all
+
+--S 461 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^3
+--R 
+--R
+--R            2 2                 2
+--R         b d x  + 2b c d x + b c  + a
+--R        F
+--R   (1)  -----------------------------
+--R          3 3       2 2     2       3
+--R         d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 1000
+r0:=-1/2*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^2)+1/2*b*F^a*Ei(b*(c+d*x)^2*log(F))*_
+  log(F)/d
+--R 
+--R
+--R   (2)
+--R           2 2                 2        a       2 2                 2
+--R       (b d x  + 2b c d x + b c )log(F)F Ei((b d x  + 2b c d x + b c )log(F))
+--R     + 
+--R             2 2                 2
+--R          b d x  + 2b c d x + b c  + a
+--R       - F
+--R  /
+--R       3 2       2      2
+--R     2d x  + 4c d x + 2c d
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2   2                  2
+--R           x  %A b d  + 2%A b c d + b c  + a
+--R         ++  F
+--R   (3)   |   ------------------------------- d%A
+--R        ++     3 3      2   2        2     3
+--R             %A d  + 3%A c d  + 3%A c d + c
+--R                                         Type: Union(Expression(Integer),...)
+--E 463
+
+--S 464 of 1000
+--m0:=a0-r0
+--E 464
+
+--S 465 of 1000
+--d0:=normalize(D(m0,x))
+--E 465
+
+)clear all
+
+--S 466 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^5
+--R 
+--R
+--R                       2 2                 2
+--R                    b d x  + 2b c d x + b c  + a
+--R                   F
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 1000
+r0:=-1/4*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^4)-1/4*b*F^(a+b*(c+d*x)^2)*log(F)/_
+  (d*(c+d*x)^2)+1/4*b^2*F^a*Ei(b*(c+d*x)^2*log(F))*log(F)^2/d
+--R 
+--R
+--R   (2)
+--R           2 4 4     2   3 3     2 2 2 2     2 3       2 4       2 a
+--R         (b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c )log(F) F
+--R      *
+--R                2 2                 2
+--R         Ei((b d x  + 2b c d x + b c )log(F))
+--R     + 
+--R                                                   2 2                 2
+--R              2 2                 2             b d x  + 2b c d x + b c  + a
+--R       ((- b d x  - 2b c d x - b c )log(F) - 1)F
+--R  /
+--R       5 4        4 3      2 3 2      3 2      4
+--R     4d x  + 16c d x  + 24c d x  + 16c d x + 4c d
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            2   2                  2
+--R           x              %A b d  + 2%A b c d + b c  + a
+--R         ++              F
+--R   (3)   |   ------------------------------------------------------- d%A
+--R        ++     5 5      4   4       3 2 3       2 3 2        4     5
+--R             %A d  + 5%A c d  + 10%A c d  + 10%A c d  + 5%A c d + c
+--R                                         Type: Union(Expression(Integer),...)
+--E 468
+
+--S 469 of 1000
+--m0:=a0-r0
+--E 469
+
+--S 470 of 1000
+--d0:=normalize(D(m0,x))
+--E 470
+
+)clear all
+
+--S 471 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^7
+--R 
+--R
+--R   (1)
+--R                             2 2                 2
+--R                          b d x  + 2b c d x + b c  + a
+--R                         F
+--R   ------------------------------------------------------------------------
+--R    7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R   d x  + 7c d x  + 21c d x  + 35c d x  + 35c d x  + 21c d x  + 7c d x + c
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 1000
+r0:=-1/6*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^6)-1/12*b*F^(a+b*(c+d*x)^2)*log(F)/_
+  (d*(c+d*x)^4)-1/12*b^2*F^(a+b*(c+d*x)^2)*log(F)^2/(d*(c+d*x)^2)+_
+  1/12*b^3*F^a*Ei(b*(c+d*x)^2*log(F))*log(F)^3/d
+--R 
+--R
+--R   (2)
+--R            3 6 6     3   5 5      3 2 4 4      3 3 3 3      3 4 2 2     3 5
+--R           b d x  + 6b c d x  + 15b c d x  + 20b c d x  + 15b c d x  + 6b c d x
+--R         + 
+--R            3 6
+--R           b c
+--R      *
+--R               3 a       2 2                 2
+--R         log(F) F Ei((b d x  + 2b c d x + b c )log(F))
+--R     + 
+--R               2 4 4     2   3 3     2 2 2 2     2 3       2 4       2
+--R           (- b d x  - 4b c d x  - 6b c d x  - 4b c d x - b c )log(F)
+--R         + 
+--R                 2 2                 2
+--R           (- b d x  - 2b c d x - b c )log(F) - 2
+--R      *
+--R             2 2                 2
+--R          b d x  + 2b c d x + b c  + a
+--R         F
+--R  /
+--R        7 6        6 5       2 5 4       3 4 3       4 3 2      5 2       6
+--R     12d x  + 72c d x  + 180c d x  + 240c d x  + 180c d x  + 72c d x + 12c d
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   INTSIGN
+--R  ,
+--R      x
+--R  ,
+--R             2   2                  2
+--R           %A b d  + 2%A b c d + b c  + a
+--R          F
+--R       /
+--R              7 7      6   6       5 2 5       4 3 4       3 4 3       2 5 2
+--R            %A d  + 7%A c d  + 21%A c d  + 35%A c d  + 35%A c d  + 21%A c d
+--R          + 
+--R                 6     7
+--R            7%A c d + c
+--R     *
+--R        d%A
+--R                                         Type: Union(Expression(Integer),...)
+--E 473
+
+--S 474 of 1000
+--m0:=a0-r0
+--E 474
+
+--S 475 of 1000
+--d0:=normalize(D(m0,x))
+--E 475
+
+)clear all
+
+--S 476 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^9
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R  /
+--R        9 9       8 8      2 7 7      3 6 6       4 5 5       5 4 4      6 3 3
+--R       d x  + 9c d x  + 36c d x  + 84c d x  + 126c d x  + 126c d x  + 84c d x
+--R     + 
+--R          7 2 2     8       9
+--R       36c d x  + 9c d x + c
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 1000
+--r0:=-1/2*b^4*F^a*GAMMA(-4,-b*(c+d*x)^2*log(F))*log(F)^4/d
+--E 477
+
+--S 478 of 1000
+--a0:=integrate(t0,x)
+--E 478
+
+--S 479 of 1000
+--m0:=a0-r0
+--E 479
+
+--S 480 of 1000
+--d0:=normalize(D(m0,x))
+--E 480
+
+)clear all
+
+--S 481 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^11
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R  /
+--R        11 11        10 10      2 9 9       3 8 8       4 7 7       5 6 6
+--R       d  x   + 11c d  x   + 55c d x  + 165c d x  + 330c d x  + 462c d x
+--R     + 
+--R           6 5 5       7 4 4       8 3 3      9 2 2      10       11
+--R       462c d x  + 330c d x  + 165c d x  + 55c d x  + 11c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 1000
+--r0:=1/2*b^5*F^a*GAMMA(-5,-b*(c+d*x)^2*log(F))*log(F)^5/d
+--E 482
+
+--S 483 of 1000
+--a0:=integrate(t0,x)
+--E 483
+
+--S 484 of 1000
+--m0:=a0-r0
+--E 484
+
+--S 485 of 1000
+--d0:=normalize(D(m0,x))
+--E 485
+
+)clear all
+
+--S 486 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^12
+--R 
+--R
+--R   (1)
+--R        12 12        11 11      2 10 10       3 9 9       4 8 8       5 7 7
+--R       d  x   + 12c d  x   + 66c d  x   + 220c d x  + 495c d x  + 792c d x
+--R     + 
+--R         6 6 6       7 5 5       8 4 4       9 3 3      10 2 2      11       12
+--R     924c d x  + 792c d x  + 495c d x  + 220c d x  + 66c  d x  + 12c  d x + c
+--R  *
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 1000
+--r0:=-1/2*F^a*(c+d*x)^13*GAMMA(13/2,-b*(c+d*x)^2*log(F))/(d*(-b*(c+d*x)^2*_
+--  log(F))^(13/2))
+--E 487
+
+--S 488 of 1000
+--a0:=integrate(t0,x)
+--E 488
+
+--S 489 of 1000
+--m0:=a0-r0
+--E 489
+
+--S 490 of 1000
+--d0:=normalize(D(m0,x))
+--E 490
+
+)clear all
+
+--S 491 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^10
+--R 
+--R
+--R   (1)
+--R        10 10        9 9      2 8 8       3 7 7       4 6 6       5 5 5
+--R       d  x   + 10c d x  + 45c d x  + 120c d x  + 210c d x  + 252c d x
+--R     + 
+--R           6 4 4       7 3 3      8 2 2      9       10
+--R       210c d x  + 120c d x  + 45c d x  + 10c d x + c
+--R  *
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 1000
+--r0:=-1/2*F^a*(c+d*x)^11*GAMMA(11/2,-b*(c+d*x)^2*log(F))/_
+--  (d*(-b*(c+d*x)^2*log(F))^(11/2))
+--E 492
+
+--S 493 of 1000
+--a0:=integrate(t0,x)
+--E 493
+
+--S 494 of 1000
+--m0:=a0-r0
+--E 494
+
+--S 495 of 1000
+--d0:=normalize(D(m0,x))
+--E 495
+
+)clear all
+
+--S 496 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^8
+--R 
+--R
+--R   (1)
+--R        8 8       7 7      2 6 6      3 5 5      4 4 4      5 3 3      6 2 2
+--R       d x  + 8c d x  + 28c d x  + 56c d x  + 70c d x  + 56c d x  + 28c d x
+--R     + 
+--R         7       8
+--R       8c d x + c
+--R  *
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 1000
+--r0:=-105/16*F^(a+b*(c+d*x)^2)*(c+d*x)/(b^4*d*log(F)^4)+_
+--  35/8*F^(a+b*(c+d*x)^2)*(c+d*x)^3/(b^3*d*log(F)^3)-_
+--  7/4*F^(a+b*(c+d*x)^2)*(c+d*x)^5/(b^2*d*log(F)^2)+_
+--  1/2*F^(a+b*(c+d*x)^2)*(c+d*x)^7/(b*d*log(F))+_
+--  105/32*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/_
+--  (b^(9/2)*d*log(F)^(9/2))
+--E 497
+
+--S 498 of 1000
+--a0:=integrate(t0,x)
+--E 498
+
+--S 499 of 1000
+--m0:=a0-r0
+--E 499
+
+--S 500 of 1000
+--d0:=normalize(D(m0,x))
+--E 500
+
+)clear all
+
+--S 501 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^6
+--R 
+--R
+--R   (1)
+--R       6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R     (d x  + 6c d x  + 15c d x  + 20c d x  + 15c d x  + 6c d x + c )
+--R  *
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 1000
+--r0:=15/8*F^(a+b*(c+d*x)^2)*(c+d*x)/(b^3*d*log(F)^3)-_
+--  5/4*F^(a+b*(c+d*x)^2)*(c+d*x)^3/(b^2*d*log(F)^2)+_
+--  1/2*F^(a+b*(c+d*x)^2)*(c+d*x)^5/(b*d*log(F))-_
+--  15/16*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(b^(7/2)*d*_
+--  log(F)^(7/2))
+--E 502
+
+--S 503 of 1000
+--a0:=integrate(t0,x)
+--E 503
+
+--S 504 of 1000
+--m0:=a0-r0
+--E 504
+
+--S 505 of 1000
+--d0:=normalize(D(m0,x))
+--E 505
+
+)clear all
+
+--S 506 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^4
+--R 
+--R
+--R                                                    2 2                 2
+--R          4 4       3 3     2 2 2     3       4  b d x  + 2b c d x + b c  + a
+--R   (1)  (d x  + 4c d x  + 6c d x  + 4c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 1000
+--r0:=-3/4*F^(a+b*(c+d*x)^2)*(c+d*x)/(b^2*d*log(F)^2)+1/2*F^(a+b*(c+d*x)^2)*_
+--  (c+d*x)^3/(b*d*log(F))+3/8*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*_
+--  sqrt(%pi)/(b^(5/2)*d*log(F)^(5/2))
+--E 507
+
+--S 508 of 1000
+--a0:=integrate(t0,x)
+--E 508
+
+--S 509 of 1000
+--m0:=a0-r0
+--E 509
+
+--S 510 of 1000
+--d0:=normalize(D(m0,x))
+--E 510
+
+)clear all
+
+--S 511 of 1000
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^2
+--R 
+--R
+--R                                2 2                 2
+--R          2 2             2  b d x  + 2b c d x + b c  + a
+--R   (1)  (d x  + 2c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 1000
+--r0:=1/2*F^(a+b*(c+d*x)^2)*(c+d*x)/(b*d*log(F))-1/4*F^a*erfi((c+d*x)*_
+--  sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(b^(3/2)*d*log(F)^(3/2))
+--E 512
+
+--S 513 of 1000
+--a0:=integrate(t0,x)
+--E 513
+
+--S 514 of 1000
+--m0:=a0-r0
+--E 514
+
+--S 515 of 1000
+--d0:=normalize(D(m0,x))
+--E 515
+
+)clear all
+
+--S 516 of 1000
+t0:=F^(a+b*(c+d*x)^2)
+--R 
+--R
+--R            2 2                 2
+--R         b d x  + 2b c d x + b c  + a
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 1000
+--r0:=1/2*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/_
+--  (d*sqrt(b)*sqrt(log(F)))
+--E 517
+
+--S 518 of 1000
+--a0:=integrate(t0,x)
+--E 518
+
+--S 519 of 1000
+--m0:=a0-r0
+--E 519
+
+--S 520 of 1000
+--d0:=normalize(D(m0,x))
+--E 520
+
+)clear all
+
+--S 521 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^2
+--R 
+--R
+--R            2 2                 2
+--R         b d x  + 2b c d x + b c  + a
+--R        F
+--R   (1)  -----------------------------
+--R               2 2             2
+--R              d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 1000
+--r0:=-F^(a+b*(c+d*x)^2)/(d*(c+d*x))+F^a*erfi((c+d*x)*sqrt(b)*_
+--  sqrt(log(F)))*sqrt(%pi)*sqrt(b)*sqrt(log(F))/d
+--E 522
+
+--S 523 of 1000
+--a0:=integrate(t0,x)
+--E 523
+
+--S 524 of 1000
+--m0:=a0-r0
+--E 524
+
+--S 525 of 1000
+--d0:=normalize(D(m0,x))
+--E 525
+
+)clear all
+
+--S 526 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^4
+--R 
+--R
+--R                 2 2                 2
+--R              b d x  + 2b c d x + b c  + a
+--R             F
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        d x  + 4c d x  + 6c d x  + 4c d x + c
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 1000
+--r0:=-1/3*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^3)-2/3*b*F^(a+b*(c+d*x)^2)*_
+--  log(F)/(d*(c+d*x))+2/3*b^(3/2)*F^a*erfi((c+d*x)*sqrt(b)*_
+--  sqrt(log(F)))*log(F)^(3/2)*sqrt(%pi)/d
+--E 527
+
+--S 528 of 1000
+--a0:=integrate(t0,x)
+--E 528
+
+--S 529 of 1000
+--m0:=a0-r0
+--E 529
+
+--S 530 of 1000
+--d0:=normalize(D(m0,x))
+--E 530
+
+)clear all
+
+--S 531 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^6
+--R 
+--R
+--R                            2 2                 2
+--R                         b d x  + 2b c d x + b c  + a
+--R                        F
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        d x  + 6c d x  + 15c d x  + 20c d x  + 15c d x  + 6c d x + c
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 1000
+--r0:=-1/5*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^5)-2/15*b*F^(a+b*(c+d*x)^2)*_
+--  log(F)/(d*(c+d*x)^3)-4/15*b^2*F^(a+b*(c+d*x)^2)*log(F)^2/(d*(c+d*x))+_
+--  4/15*b^(5/2)*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*log(F)^(5/2)*_
+--  sqrt(%pi)/d
+--E 532
+
+--S 533 of 1000
+--a0:=integrate(t0,x)
+--E 533
+
+--S 534 of 1000
+--m0:=a0-r0
+--E 534
+
+--S 535 of 1000
+--d0:=normalize(D(m0,x))
+--E 535
+
+)clear all
+
+--S 536 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^8
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R  /
+--R        8 8       7 7      2 6 6      3 5 5      4 4 4      5 3 3      6 2 2
+--R       d x  + 8c d x  + 28c d x  + 56c d x  + 70c d x  + 56c d x  + 28c d x
+--R     + 
+--R         7       8
+--R       8c d x + c
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1000
+--r0:=-1/7*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^7)-2/35*b*F^(a+b*(c+d*x)^2)*_
+--  log(F)/(d*(c+d*x)^5)-4/105*b^2*F^(a+b*(c+d*x)^2)*log(F)^2/(d*(c+d*x)^3)-_
+--  8/105*b^3*F^(a+b*(c+d*x)^2)*log(F)^3/(d*(c+d*x))+8/105*b^(7/2)*F^a*_
+--  erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*log(F)^(7/2)*sqrt(%pi)/d
+--E 537
+
+--S 538 of 1000
+--a0:=integrate(t0,x)
+--E 538
+
+--S 539 of 1000
+--m0:=a0-r0
+--E 539
+
+--S 540 of 1000
+--d0:=normalize(D(m0,x))
+--E 540
+
+)clear all
+
+--S 541 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^10
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R  /
+--R        10 10        9 9      2 8 8       3 7 7       4 6 6       5 5 5
+--R       d  x   + 10c d x  + 45c d x  + 120c d x  + 210c d x  + 252c d x
+--R     + 
+--R           6 4 4       7 3 3      8 2 2      9       10
+--R       210c d x  + 120c d x  + 45c d x  + 10c d x + c
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 1000
+--r0:=-1/2*F^a*GAMMA(-9/2,-b*(c+d*x)^2*log(F))*(-b*(c+d*x)^2*_
+--  log(F))^(9/2)/(d*(c+d*x)^9)
+--E 542
+
+--S 543 of 1000
+--a0:=integrate(t0,x)
+--E 543
+
+--S 544 of 1000
+--m0:=a0-r0
+--E 544
+
+--S 545 of 1000
+--d0:=normalize(D(m0,x))
+--E 545
+
+)clear all
+
+--S 546 of 1000
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^12
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R  /
+--R        12 12        11 11      2 10 10       3 9 9       4 8 8       5 7 7
+--R       d  x   + 12c d  x   + 66c d  x   + 220c d x  + 495c d x  + 792c d x
+--R     + 
+--R         6 6 6       7 5 5       8 4 4       9 3 3      10 2 2      11       12
+--R     924c d x  + 792c d x  + 495c d x  + 220c d x  + 66c  d x  + 12c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 1000
+--r0:=-1/2*F^a*GAMMA(-11/2,-b*(c+d*x)^2*log(F))*(-b*(c+d*x)^2*_
+--  log(F))^(11/2)/(d*(c+d*x)^11)
+--E 547
+
+--S 548 of 1000
+--a0:=integrate(t0,x)
+--E 548
+
+--S 549 of 1000
+--m0:=a0-r0
+--E 549
+
+--S 550 of 1000
+--d0:=normalize(D(m0,x))
+--E 550
+
+)clear all
+
+--S 551 of 1000
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^m
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         b d x  + 3b c d x  + 3b c d x + b c  + a         m
+--R   (1)  F                                        (d x + c)
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 1000
+--r0:=-1/3*F^a*(c+d*x)^(1+m)*GAMMA(1/3*(1+m),-b*(c+d*x)^3*log(F))*_
+--  (-b*(c+d*x)^3*log(F))^(1/3*(-1-m))/d
+--E 552
+
+--S 553 of 1000
+--a0:=integrate(t0,x)
+--E 553
+
+--S 554 of 1000
+--m0:=a0-r0
+--E 554
+
+--S 555 of 1000
+--d0:=normalize(D(m0,x))
+--E 555
+
+)clear all
+
+--S 556 of 1000
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^17
+--R 
+--R
+--R   (1)
+--R        17 17        16 16       2 15 15       3 14 14        4 13 13
+--R       d  x   + 17c d  x   + 136c d  x   + 680c d  x   + 2380c d  x
+--R     + 
+--R            5 12 12         6 11 11         7 10 10         8 9 9         9 8 8
+--R       6188c d  x   + 12376c d  x   + 19448c d  x   + 24310c d x  + 24310c d x
+--R     + 
+--R             10 7 7         11 6 6        12 5 5        13 4 4       14 3 3
+--R       19448c  d x  + 12376c  d x  + 6188c  d x  + 2380c  d x  + 680c  d x
+--R     + 
+--R           15 2 2      16       17
+--R       136c  d x  + 17c  d x + c
+--R  *
+--R         3 3         2 2       2         3
+--R      b d x  + 3b c d x  + 3b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 1000
+--r0:=-1/3*F^a*GAMMA(6,-b*(c+d*x)^3*log(F))/(b^6*d*log(F)^6)
+--E 557
+
+--S 558 of 1000
+--a0:=integrate(t0,x)
+--E 558
+
+--S 559 of 1000
+--m0:=a0-r0
+--E 559
+
+--S 560 of 1000
+--d0:=normalize(D(m0,x))
+--E 560
+
+)clear all
+
+--S 561 of 1000
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^14
+--R 
+--R
+--R   (1)
+--R        14 14        13 13      2 12 12       3 11 11        4 10 10
+--R       d  x   + 14c d  x   + 91c d  x   + 364c d  x   + 1001c d  x
+--R     + 
+--R            5 9 9        6 8 8        7 7 7        8 6 6        9 5 5
+--R       2002c d x  + 3003c d x  + 3432c d x  + 3003c d x  + 2002c d x
+--R     + 
+--R            10 4 4       11 3 3      12 2 2      13       14
+--R       1001c  d x  + 364c  d x  + 91c  d x  + 14c  d x + c
+--R  *
+--R         3 3         2 2       2         3
+--R      b d x  + 3b c d x  + 3b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 1000
+--r0:=1/3*F^a*GAMMA(5,-b*(c+d*x)^3*log(F))/(b^5*d*log(F)^5)
+--E 562
+
+--S 563 of 1000
+--a0:=integrate(t0,x)
+--E 563
+
+--S 564 of 1000
+--m0:=a0-r0
+--E 564
+
+--S 565 of 1000
+--d0:=normalize(D(m0,x))
+--E 565
+
+)clear all
+
+--S 566 of 1000
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^11
+--R 
+--R
+--R   (1)
+--R        11 11        10 10      2 9 9       3 8 8       4 7 7       5 6 6
+--R       d  x   + 11c d  x   + 55c d x  + 165c d x  + 330c d x  + 462c d x
+--R     + 
+--R           6 5 5       7 4 4       8 3 3      9 2 2      10       11
+--R       462c d x  + 330c d x  + 165c d x  + 55c d x  + 11c  d x + c
+--R  *
+--R         3 3         2 2       2         3
+--R      b d x  + 3b c d x  + 3b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1000
+r0:=-2*F^(a+b*(c+d*x)^3)/(b^4*d*log(F)^4)+2*F^(a+b*(c+d*x)^3)*(c+d*x)^3/_
+  (b^3*d*log(F)^3)-F^(a+b*(c+d*x)^3)*(c+d*x)^6/(b^2*d*log(F)^2)+_
+  1/3*F^(a+b*(c+d*x)^3)*(c+d*x)^9/(b*d*log(F))
+--R 
+--R
+--R   (2)
+--R              3 9 9     3   8 8      3 2 7 7      3 3 6 6       3 4 5 5
+--R             b d x  + 9b c d x  + 36b c d x  + 84b c d x  + 126b c d x
+--R           + 
+--R                 3 5 4 4      3 6 3 3      3 7 2 2     3 8       3 9
+--R             126b c d x  + 84b c d x  + 36b c d x  + 9b c d x + b c
+--R        *
+--R                 3
+--R           log(F)
+--R       + 
+--R                 2 6 6      2   5 5      2 2 4 4      2 3 3 3      2 4 2 2
+--R             - 3b d x  - 18b c d x  - 45b c d x  - 60b c d x  - 45b c d x
+--R           + 
+--R                  2 5        2 6
+--R             - 18b c d x - 3b c
+--R        *
+--R                 2
+--R           log(F)
+--R       + 
+--R              3 3          2 2        2          3
+--R         (6b d x  + 18b c d x  + 18b c d x + 6b c )log(F) - 6
+--R    *
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R       F
+--R  /
+--R       4        4
+--R     3b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 9 9     3   8 8      3 2 7 7      3 3 6 6       3 4 5 5
+--R             b d x  + 9b c d x  + 36b c d x  + 84b c d x  + 126b c d x
+--R           + 
+--R                 3 5 4 4      3 6 3 3      3 7 2 2     3 8       3 9
+--R             126b c d x  + 84b c d x  + 36b c d x  + 9b c d x + b c
+--R        *
+--R                 3
+--R           log(F)
+--R       + 
+--R                 2 6 6      2   5 5      2 2 4 4      2 3 3 3      2 4 2 2
+--R             - 3b d x  - 18b c d x  - 45b c d x  - 60b c d x  - 45b c d x
+--R           + 
+--R                  2 5        2 6
+--R             - 18b c d x - 3b c
+--R        *
+--R                 2
+--R           log(F)
+--R       + 
+--R              3 3          2 2        2          3
+--R         (6b d x  + 18b c d x  + 18b c d x + 6b c )log(F) - 6
+--R    *
+--R             3 3         2 2       2         3
+--R         (b d x  + 3b c d x  + 3b c d x + b c  + a)log(F)
+--R       %e
+--R  /
+--R       4        4
+--R     3b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 568
+
+--S 569 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                3 9 9     3   8 8      3 2 7 7      3 3 6 6       3 4 5 5
+--R               b d x  + 9b c d x  + 36b c d x  + 84b c d x  + 126b c d x
+--R             + 
+--R                   3 5 4 4      3 6 3 3      3 7 2 2     3 8       3 9
+--R               126b c d x  + 84b c d x  + 36b c d x  + 9b c d x + b c
+--R          *
+--R                   3
+--R             log(F)
+--R         + 
+--R                   2 6 6      2   5 5      2 2 4 4      2 3 3 3      2 4 2 2
+--R               - 3b d x  - 18b c d x  - 45b c d x  - 60b c d x  - 45b c d x
+--R             + 
+--R                    2 5        2 6
+--R               - 18b c d x - 3b c
+--R          *
+--R                   2
+--R             log(F)
+--R         + 
+--R                3 3          2 2        2          3
+--R           (6b d x  + 18b c d x  + 18b c d x + 6b c )log(F) - 6
+--R      *
+--R               3 3         2 2       2         3
+--R           (b d x  + 3b c d x  + 3b c d x + b c  + a)log(F)
+--R         %e
+--R     + 
+--R                  3 9 9     3   8 8      3 2 7 7      3 3 6 6       3 4 5 5
+--R               - b d x  - 9b c d x  - 36b c d x  - 84b c d x  - 126b c d x
+--R             + 
+--R                     3 5 4 4      3 6 3 3      3 7 2 2     3 8       3 9
+--R               - 126b c d x  - 84b c d x  - 36b c d x  - 9b c d x - b c
+--R          *
+--R                   3
+--R             log(F)
+--R         + 
+--R                 2 6 6      2   5 5      2 2 4 4      2 3 3 3      2 4 2 2
+--R               3b d x  + 18b c d x  + 45b c d x  + 60b c d x  + 45b c d x
+--R             + 
+--R                  2 5        2 6
+--R               18b c d x + 3b c
+--R          *
+--R                   2
+--R             log(F)
+--R         + 
+--R                  3 3          2 2        2          3
+--R           (- 6b d x  - 18b c d x  - 18b c d x - 6b c )log(F) + 6
+--R      *
+--R             3 3         2 2       2         3
+--R          b d x  + 3b c d x  + 3b c d x + b c  + a
+--R         F
+--R  /
+--R       4        4
+--R     3b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 1000
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^8
+--R 
+--R
+--R   (1)
+--R        8 8       7 7      2 6 6      3 5 5      4 4 4      5 3 3      6 2 2
+--R       d x  + 8c d x  + 28c d x  + 56c d x  + 70c d x  + 56c d x  + 28c d x
+--R     + 
+--R         7       8
+--R       8c d x + c
+--R  *
+--R         3 3         2 2       2         3
+--R      b d x  + 3b c d x  + 3b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 1000
+r0:=2/3*F^(a+b*(c+d*x)^3)/(b^3*d*log(F)^3)-2/3*F^(a+b*(c+d*x)^3)*_
+  (c+d*x)^3/(b^2*d*log(F)^2)+1/3*F^(a+b*(c+d*x)^3)*(c+d*x)^6/(b*d*log(F))
+--R 
+--R
+--R   (2)
+--R              2 6 6     2   5 5      2 2 4 4      2 3 3 3      2 4 2 2
+--R             b d x  + 6b c d x  + 15b c d x  + 20b c d x  + 15b c d x
+--R           + 
+--R               2 5       2 6
+--R             6b c d x + b c
+--R        *
+--R                 2
+--R           log(F)
+--R       + 
+--R                3 3         2 2       2          3
+--R         (- 2b d x  - 6b c d x  - 6b c d x - 2b c )log(F) + 2
+--R    *
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R       F
+--R  /
+--R       3        3
+--R     3b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 6 6     2   5 5      2 2 4 4      2 3 3 3      2 4 2 2
+--R             b d x  + 6b c d x  + 15b c d x  + 20b c d x  + 15b c d x
+--R           + 
+--R               2 5       2 6
+--R             6b c d x + b c
+--R        *
+--R                 2
+--R           log(F)
+--R       + 
+--R                3 3         2 2       2          3
+--R         (- 2b d x  - 6b c d x  - 6b c d x - 2b c )log(F) + 2
+--R    *
+--R             3 3         2 2       2         3
+--R         (b d x  + 3b c d x  + 3b c d x + b c  + a)log(F)
+--R       %e
+--R  /
+--R       3        3
+--R     3b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 573
+
+--S 574 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2 6 6     2   5 5      2 2 4 4      2 3 3 3      2 4 2 2
+--R               b d x  + 6b c d x  + 15b c d x  + 20b c d x  + 15b c d x
+--R             + 
+--R                 2 5       2 6
+--R               6b c d x + b c
+--R          *
+--R                   2
+--R             log(F)
+--R         + 
+--R                  3 3         2 2       2          3
+--R           (- 2b d x  - 6b c d x  - 6b c d x - 2b c )log(F) + 2
+--R      *
+--R               3 3         2 2       2         3
+--R           (b d x  + 3b c d x  + 3b c d x + b c  + a)log(F)
+--R         %e
+--R     + 
+--R                  2 6 6     2   5 5      2 2 4 4      2 3 3 3      2 4 2 2
+--R               - b d x  - 6b c d x  - 15b c d x  - 20b c d x  - 15b c d x
+--R             + 
+--R                   2 5       2 6
+--R               - 6b c d x - b c
+--R          *
+--R                   2
+--R             log(F)
+--R         + 
+--R                3 3         2 2       2          3
+--R           (2b d x  + 6b c d x  + 6b c d x + 2b c )log(F) - 2
+--R      *
+--R             3 3         2 2       2         3
+--R          b d x  + 3b c d x  + 3b c d x + b c  + a
+--R         F
+--R  /
+--R       3        3
+--R     3b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 575
+
+)clear all
+
+--S 576 of 1000
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^5
+--R 
+--R
+--R   (1)
+--R       5 5       4 4      2 3 3      3 2 2     4       5
+--R     (d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c )
+--R  *
+--R         3 3         2 2       2         3
+--R      b d x  + 3b c d x  + 3b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 1000
+r0:=-1/3*F^(a+b*(c+d*x)^3)/(b^2*d*log(F)^2)+1/3*F^(a+b*(c+d*x)^3)*_
+   (c+d*x)^3/(b*d*log(F))
+--R 
+--R
+--R   (2)
+--R            3 3         2 2       2         3
+--R       ((b d x  + 3b c d x  + 3b c d x + b c )log(F) - 1)
+--R    *
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R       F
+--R  /
+--R       2        2
+--R     3b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 3         2 2       2         3
+--R       ((b d x  + 3b c d x  + 3b c d x + b c )log(F) - 1)
+--R    *
+--R             3 3         2 2       2         3
+--R         (b d x  + 3b c d x  + 3b c d x + b c  + a)log(F)
+--R       %e
+--R  /
+--R       2        2
+--R     3b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 578
+
+--S 579 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3 3         2 2       2         3
+--R         ((b d x  + 3b c d x  + 3b c d x + b c )log(F) - 1)
+--R      *
+--R               3 3         2 2       2         3
+--R           (b d x  + 3b c d x  + 3b c d x + b c  + a)log(F)
+--R         %e
+--R     + 
+--R                3 3         2 2       2         3
+--R         ((- b d x  - 3b c d x  - 3b c d x - b c )log(F) + 1)
+--R      *
+--R             3 3         2 2       2         3
+--R          b d x  + 3b c d x  + 3b c d x + b c  + a
+--R         F
+--R  /
+--R       2        2
+--R     3b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 580
+
+)clear all
+
+--S 581 of 1000
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^2
+--R 
+--R
+--R                                3 3         2 2       2         3
+--R          2 2             2  b d x  + 3b c d x  + 3b c d x + b c  + a
+--R   (1)  (d x  + 2c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1000
+r0:=1/3*F^(a+b*(c+d*x)^3)/(b*d*log(F))
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         b d x  + 3b c d x  + 3b c d x + b c  + a
+--R        F
+--R   (2)  -----------------------------------------
+--R                       3b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3 3         2 2       2         3
+--R          (b d x  + 3b c d x  + 3b c d x + b c  + a)log(F)
+--R        %e
+--R   (3)  --------------------------------------------------
+--R                            3b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 583
+
+--S 584 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3 3         2 2       2         3
+--R         (b d x  + 3b c d x  + 3b c d x + b c  + a)log(F)
+--R       %e
+--R     + 
+--R             3 3         2 2       2         3
+--R          b d x  + 3b c d x  + 3b c d x + b c  + a
+--R       - F
+--R  /
+--R     3b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 1000
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         b d x  + 3b c d x  + 3b c d x + b c  + a
+--R        F
+--R   (1)  -----------------------------------------
+--R                         d x + c
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 1000
+r0:=1/3*F^a*Ei(b*(c+d*x)^3*log(F))/d
+--R 
+--R
+--R         a       3 3         2 2       2         3
+--R        F Ei((b d x  + 3b c d x  + 3b c d x + b c )log(F))
+--R   (2)  --------------------------------------------------
+--R                                3d
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3   3      2     2          2       3
+--R           x  %A b d  + 3%A b c d  + 3%A b c d + b c  + a
+--R         ++  F
+--R   (3)   |   -------------------------------------------- d%A
+--R        ++                     %A d + c
+--R                                         Type: Union(Expression(Integer),...)
+--E 588
+
+--S 589 of 1000
+--m0:=a0-r0
+--E 589
+
+--S 590 of 1000
+--d0:=normalize(D(m0,x))
+--E 590
+
+)clear all
+
+--S 591 of 1000
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^4
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         b d x  + 3b c d x  + 3b c d x + b c  + a
+--R        F
+--R   (1)  -----------------------------------------
+--R           4 4       3 3     2 2 2     3       4
+--R          d x  + 4c d x  + 6c d x  + 4c d x + c
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 1000
+r0:=-1/3*F^(a+b*(c+d*x)^3)/(d*(c+d*x)^3)+1/3*b*F^a*Ei(b*(c+d*x)^3*_
+   log(F))*log(F)/d
+--R 
+--R
+--R   (2)
+--R             3 3         2 2       2         3        a
+--R         (b d x  + 3b c d x  + 3b c d x + b c )log(F)F
+--R      *
+--R                3 3         2 2       2         3
+--R         Ei((b d x  + 3b c d x  + 3b c d x + b c )log(F))
+--R     + 
+--R             3 3         2 2       2         3
+--R          b d x  + 3b c d x  + 3b c d x + b c  + a
+--R       - F
+--R  /
+--R       4 3       3 2     2 2      3
+--R     3d x  + 9c d x  + 9c d x + 3c d
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3   3      2     2          2       3
+--R           x  %A b d  + 3%A b c d  + 3%A b c d + b c  + a
+--R         ++  F
+--R   (3)   |   -------------------------------------------- d%A
+--R        ++      4 4      3   3      2 2 2        3     4
+--R              %A d  + 4%A c d  + 6%A c d  + 4%A c d + c
+--R                                         Type: Union(Expression(Integer),...)
+--E 593
+
+--S 594 of 1000
+--m0:=a0-r0
+--E 594
+
+--S 595 of 1000
+--d0:=normalize(D(m0,x))
+--E 595
+
+)clear all
+
+--S 596 of 1000
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^7
+--R 
+--R
+--R   (1)
+--R                       3 3         2 2       2         3
+--R                    b d x  + 3b c d x  + 3b c d x + b c  + a
+--R                   F
+--R   ------------------------------------------------------------------------
+--R    7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R   d x  + 7c d x  + 21c d x  + 35c d x  + 35c d x  + 21c d x  + 7c d x + c
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1000
+r0:=-1/6*F^(a+b*(c+d*x)^3)/(d*(c+d*x)^6)-1/6*b*F^(a+b*(c+d*x)^3)*_
+   log(F)/(d*(c+d*x)^3)+1/6*b^2*F^a*Ei(b*(c+d*x)^3*log(F))*log(F)^2/d
+--R 
+--R
+--R   (2)
+--R            2 6 6     2   5 5      2 2 4 4      2 3 3 3      2 4 2 2     2 5
+--R           b d x  + 6b c d x  + 15b c d x  + 20b c d x  + 15b c d x  + 6b c d x
+--R         + 
+--R            2 6
+--R           b c
+--R      *
+--R               2 a       3 3         2 2       2         3
+--R         log(F) F Ei((b d x  + 3b c d x  + 3b c d x + b c )log(F))
+--R     + 
+--R                3 3         2 2       2         3
+--R         ((- b d x  - 3b c d x  - 3b c d x - b c )log(F) - 1)
+--R      *
+--R             3 3         2 2       2         3
+--R          b d x  + 3b c d x  + 3b c d x + b c  + a
+--R         F
+--R  /
+--R       7 6        6 5      2 5 4       3 4 3      4 3 2      5 2      6
+--R     6d x  + 36c d x  + 90c d x  + 120c d x  + 90c d x  + 36c d x + 6c d
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   INTSIGN
+--R  ,
+--R      x
+--R  ,
+--R             3   3      2     2          2       3
+--R           %A b d  + 3%A b c d  + 3%A b c d + b c  + a
+--R          F
+--R       /
+--R              7 7      6   6       5 2 5       4 3 4       3 4 3       2 5 2
+--R            %A d  + 7%A c d  + 21%A c d  + 35%A c d  + 35%A c d  + 21%A c d
+--R          + 
+--R                 6     7
+--R            7%A c d + c
+--R     *
+--R        d%A
+--R                                         Type: Union(Expression(Integer),...)
+--E 598
+
+--S 599 of 1000
+--m0:=a0-r0
+--E 599
+
+--S 600 of 1000
+--d0:=normalize(D(m0,x))
+--E 600
+
+)clear all
+
+--S 601 of 1000
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^10
+--R 
+--R
+--R   (1)
+--R         3 3         2 2       2         3
+--R      b d x  + 3b c d x  + 3b c d x + b c  + a
+--R     F
+--R  /
+--R        10 10        9 9      2 8 8       3 7 7       4 6 6       5 5 5
+--R       d  x   + 10c d x  + 45c d x  + 120c d x  + 210c d x  + 252c d x
+--R     + 
+--R           6 4 4       7 3 3      8 2 2      9       10
+--R       210c d x  + 120c d x  + 45c d x  + 10c d x + c
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 1000
+r0:=-1/9*F^(a+b*(c+d*x)^3)/(d*(c+d*x)^9)-1/18*b*F^(a+b*(c+d*x)^3)*_
+   log(F)/(d*(c+d*x)^6)-1/18*b^2*F^(a+b*(c+d*x)^3)*log(F)^2/(d*(c+d*x)^3)+_
+   1/18*b^3*F^a*Ei(b*(c+d*x)^3*log(F))*log(F)^3/d
+--R 
+--R
+--R   (2)
+--R            3 9 9     3   8 8      3 2 7 7      3 3 6 6       3 4 5 5
+--R           b d x  + 9b c d x  + 36b c d x  + 84b c d x  + 126b c d x
+--R         + 
+--R               3 5 4 4      3 6 3 3      3 7 2 2     3 8       3 9
+--R           126b c d x  + 84b c d x  + 36b c d x  + 9b c d x + b c
+--R      *
+--R               3 a       3 3         2 2       2         3
+--R         log(F) F Ei((b d x  + 3b c d x  + 3b c d x + b c )log(F))
+--R     + 
+--R                  2 6 6     2   5 5      2 2 4 4      2 3 3 3      2 4 2 2
+--R               - b d x  - 6b c d x  - 15b c d x  - 20b c d x  - 15b c d x
+--R             + 
+--R                   2 5       2 6
+--R               - 6b c d x - b c
+--R          *
+--R                   2
+--R             log(F)
+--R         + 
+--R                 3 3         2 2       2         3
+--R           (- b d x  - 3b c d x  - 3b c d x - b c )log(F) - 2
+--R      *
+--R             3 3         2 2       2         3
+--R          b d x  + 3b c d x  + 3b c d x + b c  + a
+--R         F
+--R  /
+--R          10 9         9 8       2 8 7        3 7 6        4 6 5        5 5 4
+--R       18d  x  + 162c d x  + 648c d x  + 1512c d x  + 2268c d x  + 2268c d x
+--R     + 
+--R            6 4 3       7 3 2       8 2       9
+--R       1512c d x  + 648c d x  + 162c d x + 18c d
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   INTSIGN
+--R  ,
+--R      x
+--R  ,
+--R             3   3      2     2          2       3
+--R           %A b d  + 3%A b c d  + 3%A b c d + b c  + a
+--R          F
+--R       /
+--R              10 10       9   9       8 2 8        7 3 7        6 4 6
+--R            %A  d   + 10%A c d  + 45%A c d  + 120%A c d  + 210%A c d
+--R          + 
+--R                 5 5 5        4 6 4        3 7 3       2 8 2         9     10
+--R            252%A c d  + 210%A c d  + 120%A c d  + 45%A c d  + 10%A c d + c
+--R     *
+--R        d%A
+--R                                         Type: Union(Expression(Integer),...)
+--E 603
+
+--S 604 of 1000
+--m0:=a0-r0
+--E 604
+
+--S 605 of 1000
+--d0:=normalize(D(m0,x))
+--E 605
+
+)clear all
+
+--S 606 of 1000
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^13
+--R 
+--R
+--R   (1)
+--R         3 3         2 2       2         3
+--R      b d x  + 3b c d x  + 3b c d x + b c  + a
+--R     F
+--R  /
+--R        13 13        12 12      2 11 11       3 10 10       4 9 9        5 8 8
+--R       d  x   + 13c d  x   + 78c d  x   + 286c d  x   + 715c d x  + 1287c d x
+--R     + 
+--R            6 7 7        7 6 6        8 5 5       9 4 4       10 3 3      11 2 2
+--R       1716c d x  + 1716c d x  + 1287c d x  + 715c d x  + 286c  d x  + 78c  d x
+--R     + 
+--R          12       13
+--R       13c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 1000
+--r0:=-1/3*b^4*F^a*GAMMA(-4,-b*(c+d*x)^3*log(F))*log(F)^4/d
+--E 607
+
+--S 608 of 1000
+--a0:=integrate(t0,x)
+--E 608
+
+--S 609 of 1000
+--m0:=a0-r0
+--E 609
+
+--S 610 of 1000
+--d0:=normalize(D(m0,x))
+--E 610
+
+)clear all
+
+--S 611 of 1000
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^16
+--R 
+--R
+--R   (1)
+--R         3 3         2 2       2         3
+--R      b d x  + 3b c d x  + 3b c d x + b c  + a
+--R     F
+--R  /
+--R        16 16        15 15       2 14 14       3 13 13        4 12 12
+--R       d  x   + 16c d  x   + 120c d  x   + 560c d  x   + 1820c d  x
+--R     + 
+--R            5 11 11        6 10 10         7 9 9         8 8 8         9 7 7
+--R       4368c d  x   + 8008c d  x   + 11440c d x  + 12870c d x  + 11440c d x
+--R     + 
+--R            10 6 6        11 5 5        12 4 4       13 3 3       14 2 2
+--R       8008c  d x  + 4368c  d x  + 1820c  d x  + 560c  d x  + 120c  d x
+--R     + 
+--R          15       16
+--R       16c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 1000
+--r0:=1/3*b^5*F^a*GAMMA(-5,-b*(c+d*x)^3*log(F))*log(F)^5/d
+--E 612
+
+--S 613 of 1000
+--a0:=integrate(t0,x)
+--E 613
+
+--S 614 of 1000
+--m0:=a0-r0
+--E 614
+
+--S 615 of 1000
+--d0:=normalize(D(m0,x))
+--E 615
+
+)clear all
+
+--S 616 of 1000
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^3
+--R 
+--R
+--R   (1)
+--R                                     3 3         2 2       2         3
+--R     3 3       2 2     2       3  b d x  + 3b c d x  + 3b c d x + b c  + a
+--R   (d x  + 3c d x  + 3c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 1000
+--r0:=-1/3*F^a*(c+d*x)^4*GAMMA(4/3,-b*(c+d*x)^3*log(F))/(d*(-b*(c+d*x)^3*_
+--  log(F))^(4/3))
+--E 617
+
+--S 618 of 1000
+--a0:=integrate(t0,x)
+--E 618
+
+--S 619 of 1000
+--m0:=a0-r0
+--E 619
+
+--S 620 of 1000
+--d0:=normalize(D(m0,x))
+--E 620
+
+)clear all
+
+--S 621 of 1000
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)
+--R 
+--R
+--R                     3 3         2 2       2         3
+--R                  b d x  + 3b c d x  + 3b c d x + b c  + a
+--R   (1)  (d x + c)F
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 1000
+--r0:=-1/3*F^a*(c+d*x)^2*GAMMA(2/3,-b*(c+d*x)^3*log(F))/(d*(-b*(c+d*x)^3*_
+--  log(F))^(2/3))
+--E 622
+
+--S 623 of 1000
+--a0:=integrate(t0,x)
+--E 623
+
+--S 624 of 1000
+--m0:=a0-r0
+--E 624
+
+--S 625 of 1000
+--d0:=normalize(D(m0,x))
+--E 625
+
+)clear all
+
+--S 626 of 1000
+t0:=F^(a+b*(c+d*x)^3)
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         b d x  + 3b c d x  + 3b c d x + b c  + a
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 1000
+--r0:=-1/3*F^a*(c+d*x)*GAMMA(1/3,-b*(c+d*x)^3*log(F))/(d*(-b*(c+d*x)^3*_
+--  log(F))^(1/3))
+--E 627
+
+--S 628 of 1000
+--a0:=integrate(t0,x)
+--E 628
+
+--S 629 of 1000
+--m0:=a0-r0
+--E 629
+
+--S 630 of 1000
+--d0:=normalize(D(m0,x))
+--E 630
+
+)clear all
+
+--S 631 of 1000
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^2
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         b d x  + 3b c d x  + 3b c d x + b c  + a
+--R        F
+--R   (1)  -----------------------------------------
+--R                     2 2             2
+--R                    d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 1000
+--r0:=-1/3*F^a*GAMMA(-1/3,-b*(c+d*x)^3*log(F))*(-b*(c+d*x)^3*_
+--  log(F))^(1/3)/(d*(c+d*x))
+--E 632
+
+--S 633 of 1000
+--a0:=integrate(t0,x)
+--E 633
+
+--S 634 of 1000
+--m0:=a0-r0
+--E 634
+
+--S 635 of 1000
+--d0:=normalize(D(m0,x))
+--E 635
+
+)clear all
+
+--S 636 of 1000
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^3
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         b d x  + 3b c d x  + 3b c d x + b c  + a
+--R        F
+--R   (1)  -----------------------------------------
+--R                3 3       2 2     2       3
+--R               d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 1000
+--r0:=-1/3*F^a*GAMMA(-2/3,-b*(c+d*x)^3*log(F))*(-b*(c+d*x)^3*_
+--  log(F))^(2/3)/(d*(c+d*x)^2)
+--E 637
+
+--S 638 of 1000
+--a0:=integrate(t0,x)
+--E 638
+
+--S 639 of 1000
+--m0:=a0-r0
+--E 639
+
+--S 640 of 1000
+--d0:=normalize(D(m0,x))
+--E 640
+
+)clear all
+
+--S 641 of 1000
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^5
+--R 
+--R
+--R                 3 3         2 2       2         3
+--R              b d x  + 3b c d x  + 3b c d x + b c  + a
+--R             F
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 1000
+--r0:=-1/3*F^a*GAMMA(-4/3,-b*(c+d*x)^3*log(F))*(-b*(c+d*x)^3*_
+--  log(F))^(4/3)/(d*(c+d*x)^4)
+--E 642
+
+--S 643 of 1000
+--a0:=integrate(t0,x)
+--E 643
+
+--S 644 of 1000
+--m0:=a0-r0
+--E 644
+
+--S 645 of 1000
+--d0:=normalize(D(m0,x))
+--E 645
+
+)clear all
+
+--S 646 of 1000
+t0:=f^(a+b*(c+d*x)^(1/2))
+--R 
+--R
+--R           +-------+
+--R         b\|d x + c  + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 1000
+r0:=-2*f^(a+b*sqrt(c+d*x))/(b^2*d*log(f)^2)+2*f^(a+b*sqrt(c+d*x))*_
+   sqrt(c+d*x)/(b*d*log(f))
+--R 
+--R
+--R                                    +-------+
+--R                   +-------+      b\|d x + c  + a
+--R        (2b log(f)\|d x + c  - 2)f
+--R   (2)  -----------------------------------------
+--R                        2        2
+--R                       b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                            +-------+
+--R                   +-------+       b log(f)\|d x + c  + a log(f)
+--R        (2b log(f)\|d x + c  - 2)%e
+--R   (3)  --------------------------------------------------------
+--R                                2        2
+--R                               b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 648
+
+--S 649 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     +-------+
+--R                    +-------+      b\|d x + c  + a
+--R       (- 2b log(f)\|d x + c  + 2)f
+--R     + 
+--R                                           +-------+
+--R                  +-------+       b log(f)\|d x + c  + a log(f)
+--R       (2b log(f)\|d x + c  - 2)%e
+--R  /
+--R      2        2
+--R     b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 649
+
+--S 650 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 650
+
+)clear all
+
+--S 651 of 1000
+t0:=f^(a+b*(c+d*x)^(1/3))
+--R 
+--R
+--R          3+-------+
+--R         b\|d x + c  + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 1000
+r0:=6*f^(a+b*(c+d*x)^(1/3))/(b^3*d*log(f)^3)-6*f^(a+b*(c+d*x)^(1/3))*_
+   (c+d*x)^(1/3)/(b^2*d*log(f)^2)+3*f^(a+b*(c+d*x)^(1/3))*(c+d*x)^(2/3)/_
+   (b*d*log(f))
+--R 
+--R
+--R                                                           3+-------+
+--R           2      2 3+-------+2           3+-------+      b\|d x + c  + a
+--R        (3b log(f)  \|d x + c  - 6b log(f)\|d x + c  + 6)f
+--R   (2)  -----------------------------------------------------------------
+--R                                    3        3
+--R                                   b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2      2 3+-------+2           3+-------+
+--R       (3b log(f)  \|d x + c  - 6b log(f)\|d x + c  + 6)
+--R    *
+--R                 3+-------+
+--R         b log(f)\|d x + c  + a log(f)
+--R       %e
+--R  /
+--R      3        3
+--R     b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 653
+
+--S 654 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                            3+-------+
+--R            2      2 3+-------+2           3+-------+      b\|d x + c  + a
+--R       (- 3b log(f)  \|d x + c  + 6b log(f)\|d x + c  - 6)f
+--R     + 
+--R            2      2 3+-------+2           3+-------+
+--R         (3b log(f)  \|d x + c  - 6b log(f)\|d x + c  + 6)
+--R      *
+--R                   3+-------+
+--R           b log(f)\|d x + c  + a log(f)
+--R         %e
+--R  /
+--R      3        3
+--R     b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 654
+
+--S 655 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 655
+
+)clear all
+
+--S 656 of 1000
+t0:=F^(a+b/(c+d*x))*(c+d*x)^m
+--R 
+--R
+--R         a d x + a c + b
+--R         ---------------
+--R             d x + c             m
+--R   (1)  F               (d x + c)
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 1000
+--r0:=F^a*(c+d*x)^(1+m)*GAMMA(-1-m,-b*log(F)/(c+d*x))*_
+--  (-b*log(F)/(c+d*x))^(1+m)/d
+--E 657
+
+--S 658 of 1000
+--a0:=integrate(t0,x)
+--E 658
+
+--S 659 of 1000
+--m0:=a0-r0
+--E 659
+
+--S 660 of 1000
+--d0:=normalize(D(m0,x))
+--E 660
+
+)clear all
+
+--S 661 of 1000
+t0:=F^(a+b/(c+d*x))*(c+d*x)^4
+--R 
+--R
+--R                                                 a d x + a c + b
+--R                                                 ---------------
+--R          4 4       3 3     2 2 2     3       4      d x + c
+--R   (1)  (d x  + 4c d x  + 6c d x  + 4c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 1000
+--r0:=-b^5*F^a*GAMMA(-5,-b*log(F)/(c+d*x))*log(F)^5/d
+--E 662
+
+--S 663 of 1000
+--a0:=integrate(t0,x)
+--E 663
+
+--S 664 of 1000
+--m0:=a0-r0
+--E 664
+
+--S 665 of 1000
+--d0:=normalize(D(m0,x))
+--E 665
+
+)clear all
+
+--S 666 of 1000
+t0:=F^(a+b/(c+d*x))*(c+d*x)^3
+--R 
+--R
+--R                                       a d x + a c + b
+--R                                       ---------------
+--R          3 3       2 2     2       3      d x + c
+--R   (1)  (d x  + 3c d x  + 3c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 1000
+--r0:=b^4*F^a*GAMMA(-4,-b*log(F)/(c+d*x))*log(F)^4/d
+--E 667
+
+--S 668 of 1000
+--a0:=integrate(t0,x)
+--E 668
+
+--S 669 of 1000
+--m0:=a0-r0
+--E 669
+
+--S 670 of 1000
+--d0:=normalize(D(m0,x))
+--E 670
+
+)clear all
+
+--S 671 of 1000
+t0:=F^(a+b/(c+d*x))*(c+d*x)^2
+--R 
+--R
+--R                             a d x + a c + b
+--R                             ---------------
+--R          2 2             2      d x + c
+--R   (1)  (d x  + 2c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 1000
+r0:=1/3*F^(a+b/(c+d*x))*(c+d*x)^3/d+1/6*b*F^(a+b/(c+d*x))*(c+d*x)^2*_
+  log(F)/d+1/6*b^2*F^(a+b/(c+d*x))*(c+d*x)*log(F)^2/d-1/6*b^3*F^a*_
+  Ei(b*log(F)/(c+d*x))*log(F)^3/d
+--R 
+--R
+--R   (2)
+--R          3      3 a   b log(F)
+--R       - b log(F) F Ei(--------)
+--R                        d x + c
+--R     + 
+--R             2       2        2       2 2                 2            3 3
+--R           (b d x + b c)log(F)  + (b d x  + 2b c d x + b c )log(F) + 2d x
+--R         + 
+--R               2 2     2        3
+--R           6c d x  + 6c d x + 2c
+--R      *
+--R          a d x + a c + b
+--R          ---------------
+--R              d x + c
+--R         F
+--R  /
+--R     6d
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                    %A a d + a c + b
+--R           x                        ----------------
+--R         ++     2 2              2      %A d + c
+--R   (3)   |   (%A d  + 2%A c d + c )F                d%A
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 673
+
+--S 674 of 1000
+--m0:=a0-r0
+--E 674
+
+--S 675 of 1000
+--d0:=normalize(D(m0,x))
+--E 675
+
+)clear all
+
+--S 676 of 1000
+t0:=F^(a+b/(c+d*x))*(c+d*x)
+--R 
+--R
+--R                  a d x + a c + b
+--R                  ---------------
+--R                      d x + c
+--R   (1)  (d x + c)F
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 1000
+r0:=1/2*F^(a+b/(c+d*x))*(c+d*x)^2/d+1/2*b*F^(a+b/(c+d*x))*(c+d*x)*log(F)/d-_
+  1/2*b^2*F^a*Ei(b*log(F)/(c+d*x))*log(F)^2/d
+--R 
+--R
+--R   (2)
+--R          2      2 a   b log(F)
+--R       - b log(F) F Ei(--------)
+--R                        d x + c
+--R     + 
+--R                                                  a d x + a c + b
+--R                                                  ---------------
+--R                               2 2             2      d x + c
+--R       ((b d x + b c)log(F) + d x  + 2c d x + c )F
+--R  /
+--R     2d
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        %A a d + a c + b
+--R           x            ----------------
+--R         ++                 %A d + c
+--R   (3)   |   (%A d + c)F                d%A
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 678
+
+--S 679 of 1000
+--m0:=a0-r0
+--E 679
+
+--S 680 of 1000
+--d0:=normalize(D(m0,x))
+--E 680
+
+)clear all
+
+--S 681 of 1000
+t0:=F^(a+b/(c+d*x))
+--R 
+--R
+--R         a d x + a c + b
+--R         ---------------
+--R             d x + c
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 1000
+r0:=F^(a+b/(c+d*x))*(c+d*x)/d-b*F^a*Ei(b*log(F)/(c+d*x))*log(F)/d
+--R 
+--R
+--R                                             a d x + a c + b
+--R                                             ---------------
+--R                   a   b log(F)                  d x + c
+--R        - b log(F)F Ei(--------) + (d x + c)F
+--R                        d x + c
+--R   (2)  ----------------------------------------------------
+--R                                  d
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R              %A a d + a c + b
+--R           x  ----------------
+--R         ++       %A d + c
+--R   (3)   |   F                d%A
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 683
+
+--S 684 of 1000
+--m0:=a0-r0
+--E 684
+
+--S 685 of 1000
+--d0:=normalize(D(m0,x))
+--E 685
+
+)clear all
+
+--S 686 of 1000
+t0:=F^(a+b/(c+d*x))/(c+d*x)
+--R 
+--R
+--R         a d x + a c + b
+--R         ---------------
+--R             d x + c
+--R        F
+--R   (1)  ----------------
+--R             d x + c
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 1000
+r0:=-F^a*Ei(b*log(F)/(c+d*x))/d
+--R 
+--R
+--R           a   b log(F)
+--R          F Ei(--------)
+--R                d x + c
+--R   (2)  - --------------
+--R                 d
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R              %A a d + a c + b
+--R              ----------------
+--R           x      %A d + c
+--R         ++  F
+--R   (3)   |   ----------------- d%A
+--R        ++        %A d + c
+--R                                         Type: Union(Expression(Integer),...)
+--E 688
+
+--S 689 of 1000
+--m0:=a0-r0
+--E 689
+
+--S 690 of 1000
+--d0:=normalize(D(m0,x))
+--E 690
+
+)clear all
+
+--S 691 of 1000
+t0:=F^(a+b/(c+d*x))/(c+d*x)^2
+--R 
+--R
+--R          a d x + a c + b
+--R          ---------------
+--R              d x + c
+--R         F
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 691
+
+--S 692 of 1000
+r0:=-F^(a+b/(c+d*x))/(b*d*log(F))
+--R 
+--R
+--R           a d x + a c + b
+--R           ---------------
+--R               d x + c
+--R          F
+--R   (2)  - ----------------
+--R             b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R            (a d x + a c + b)log(F)
+--R            -----------------------
+--R                    d x + c
+--R          %e
+--R   (3)  - -------------------------
+--R                  b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 693
+
+--S 694 of 1000
+m0:=a0-r0
+--R 
+--R
+--R            (a d x + a c + b)log(F)    a d x + a c + b
+--R            -----------------------    ---------------
+--R                    d x + c                d x + c
+--R        - %e                        + F
+--R   (4)  ----------------------------------------------
+--R                          b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 694
+
+--S 695 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 695
+
+)clear all
+
+--S 696 of 1000
+t0:=F^(a+b/(c+d*x))/(c+d*x)^3
+--R 
+--R
+--R               a d x + a c + b
+--R               ---------------
+--R                   d x + c
+--R              F
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 1000
+r0:=F^(a+b/(c+d*x))/(b^2*d*log(F)^2)-F^(a+b/(c+d*x))/(b*d*(c+d*x)*log(F))
+--R 
+--R
+--R                               a d x + a c + b
+--R                               ---------------
+--R                                   d x + c
+--R        (- b log(F) + d x + c)F
+--R   (2)  --------------------------------------
+--R                  2 2     2          2
+--R                (b d x + b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                (a d x + a c + b)log(F)
+--R                                -----------------------
+--R                                        d x + c
+--R        (- b log(F) + d x + c)%e
+--R   (3)  -----------------------------------------------
+--R                       2 2     2          2
+--R                     (b d x + b c d)log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 698
+
+--S 699 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                               (a d x + a c + b)log(F)
+--R                               -----------------------
+--R                                       d x + c
+--R       (- b log(F) + d x + c)%e
+--R     + 
+--R                            a d x + a c + b
+--R                            ---------------
+--R                                d x + c
+--R       (b log(F) - d x - c)F
+--R  /
+--R       2 2     2          2
+--R     (b d x + b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 699
+
+--S 700 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 700
+
+)clear all
+
+--S 701 of 1000
+t0:=F^(a+b/(c+d*x))/(c+d*x)^4
+--R 
+--R
+--R                    a d x + a c + b
+--R                    ---------------
+--R                        d x + c
+--R                   F
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        d x  + 4c d x  + 6c d x  + 4c d x + c
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 1000
+r0:=-2*F^(a+b/(c+d*x))/(b^3*d*log(F)^3)+2*F^(a+b/(c+d*x))/(b^2*d*(c+d*x)*_
+  log(F)^2)-F^(a+b/(c+d*x))/(b*d*(c+d*x)^2*log(F))
+--R 
+--R
+--R   (2)
+--R                                                                a d x + a c + b
+--R                                                                ---------------
+--R       2      2                             2 2              2      d x + c
+--R   (- b log(F)  + (2b d x + 2b c)log(F) - 2d x  - 4c d x - 2c )F
+--R   ----------------------------------------------------------------------------
+--R                          3 3 2     3   2     3 2        3
+--R                        (b d x  + 2b c d x + b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2      2                             2 2              2
+--R       (- b log(F)  + (2b d x + 2b c)log(F) - 2d x  - 4c d x - 2c )
+--R    *
+--R         (a d x + a c + b)log(F)
+--R         -----------------------
+--R                 d x + c
+--R       %e
+--R  /
+--R       3 3 2     3   2     3 2        3
+--R     (b d x  + 2b c d x + b c d)log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 703
+
+--S 704 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2      2                             2 2              2
+--R         (- b log(F)  + (2b d x + 2b c)log(F) - 2d x  - 4c d x - 2c )
+--R      *
+--R           (a d x + a c + b)log(F)
+--R           -----------------------
+--R                   d x + c
+--R         %e
+--R     + 
+--R           2      2                               2 2              2
+--R         (b log(F)  + (- 2b d x - 2b c)log(F) + 2d x  + 4c d x + 2c )
+--R      *
+--R          a d x + a c + b
+--R          ---------------
+--R              d x + c
+--R         F
+--R  /
+--R       3 3 2     3   2     3 2        3
+--R     (b d x  + 2b c d x + b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 705
+
+)clear all
+
+--S 706 of 1000
+t0:=F^(a+b/(c+d*x))/(c+d*x)^5
+--R 
+--R
+--R                          a d x + a c + b
+--R                          ---------------
+--R                              d x + c
+--R                         F
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 1000
+r0:=6*F^(a+b/(c+d*x))/(b^4*d*log(F)^4)-6*F^(a+b/(c+d*x))/(b^3*d*(c+d*x)*_
+  log(F)^3)+3*F^(a+b/(c+d*x))/(b^2*d*(c+d*x)^2*log(F)^2)-_
+  F^(a+b/(c+d*x))/(b*d*(c+d*x)^3*log(F))
+--R 
+--R
+--R   (2)
+--R            3      3      2        2        2
+--R         - b log(F)  + (3b d x + 3b c)log(F)
+--R       + 
+--R              2 2                   2            3 3        2 2      2        3
+--R       (- 6b d x  - 12b c d x - 6b c )log(F) + 6d x  + 18c d x  + 18c d x + 6c
+--R    *
+--R        a d x + a c + b
+--R        ---------------
+--R            d x + c
+--R       F
+--R  /
+--R       4 4 3     4   3 2     4 2 2     4 3        4
+--R     (b d x  + 3b c d x  + 3b c d x + b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3      3      2        2        2
+--R         - b log(F)  + (3b d x + 3b c)log(F)
+--R       + 
+--R              2 2                   2            3 3        2 2      2        3
+--R       (- 6b d x  - 12b c d x - 6b c )log(F) + 6d x  + 18c d x  + 18c d x + 6c
+--R    *
+--R         (a d x + a c + b)log(F)
+--R         -----------------------
+--R                 d x + c
+--R       %e
+--R  /
+--R       4 4 3     4   3 2     4 2 2     4 3        4
+--R     (b d x  + 3b c d x  + 3b c d x + b c d)log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 708
+
+--S 709 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3      3      2        2        2
+--R           - b log(F)  + (3b d x + 3b c)log(F)
+--R         + 
+--R                  2 2                   2            3 3        2 2      2
+--R           (- 6b d x  - 12b c d x - 6b c )log(F) + 6d x  + 18c d x  + 18c d x
+--R         + 
+--R             3
+--R           6c
+--R      *
+--R           (a d x + a c + b)log(F)
+--R           -----------------------
+--R                   d x + c
+--R         %e
+--R     + 
+--R            3      3        2        2        2
+--R           b log(F)  + (- 3b d x - 3b c)log(F)
+--R         + 
+--R              2 2                   2            3 3        2 2      2        3
+--R         (6b d x  + 12b c d x + 6b c )log(F) - 6d x  - 18c d x  - 18c d x - 6c
+--R      *
+--R          a d x + a c + b
+--R          ---------------
+--R              d x + c
+--R         F
+--R  /
+--R       4 4 3     4   3 2     4 2 2     4 3        4
+--R     (b d x  + 3b c d x  + 3b c d x + b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 710
+
+)clear all
+
+--S 711 of 1000
+t0:=F^(a+b/(c+d*x))/(c+d*x)^6
+--R 
+--R
+--R                                a d x + a c + b
+--R                                ---------------
+--R                                    d x + c
+--R                               F
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        d x  + 6c d x  + 15c d x  + 20c d x  + 15c d x  + 6c d x + c
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 1000
+--r0:=-F^a*GAMMA(5,-b*log(F)/(c+d*x))/(b^5*d*log(F)^5)
+--E 712
+
+--S 713 of 1000
+--a0:=integrate(t0,x)
+--E 713
+
+--S 714 of 1000
+--m0:=a0-r0
+--E 714
+
+--S 715 of 1000
+--d0:=normalize(D(m0,x))
+--E 715
+
+)clear all
+
+--S 716 of 1000
+t0:=F^(a+b/(c+d*x))/(c+d*x)^7
+--R 
+--R
+--R   (1)
+--R                                a d x + a c + b
+--R                                ---------------
+--R                                    d x + c
+--R                               F
+--R   ------------------------------------------------------------------------
+--R    7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R   d x  + 7c d x  + 21c d x  + 35c d x  + 35c d x  + 21c d x  + 7c d x + c
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1000
+--r0:=F^a*GAMMA(6,-b*log(F)/(c+d*x))/(b^6*d*log(F)^6)
+--E 717
+
+--S 718 of 1000
+--a0:=integrate(t0,x)
+--E 718
+
+--S 719 of 1000
+--m0:=a0-r0
+--E 719
+
+--S 720 of 1000
+--d0:=normalize(D(m0,x))
+--E 720
+
+)clear all
+
+--S 721 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^m
+--R 
+--R
+--R            2 2                 2
+--R         a d x  + 2a c d x + a c  + b
+--R         ----------------------------
+--R               2 2             2
+--R              d x  + 2c d x + c               m
+--R   (1)  F                            (d x + c)
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 1000
+--r0:=1/2*F^a*(c+d*x)^(1+m)*GAMMA(1/2*(-1-m),-b*log(F)/(c+d*x)^2)*_
+--  (-b*log(F)/(c+d*x)^2)^(1/2*(1+m))/d
+--E 722
+
+--S 723 of 1000
+--a0:=integrate(t0,x)
+--E 723
+
+--S 724 of 1000
+--m0:=a0-r0
+--E 724
+
+--S 725 of 1000
+--d0:=normalize(D(m0,x))
+--E 725
+
+)clear all
+
+--S 726 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^9
+--R 
+--R
+--R   (1)
+--R        9 9       8 8      2 7 7      3 6 6       4 5 5       5 4 4      6 3 3
+--R       d x  + 9c d x  + 36c d x  + 84c d x  + 126c d x  + 126c d x  + 84c d x
+--R     + 
+--R          7 2 2     8       9
+--R       36c d x  + 9c d x + c
+--R  *
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 726
+
+--S 727 of 1000
+--r0:=-1/2*b^5*F^a*GAMMA(-5,-b*log(F)/(c+d*x)^2)*log(F)^5/d
+--E 727
+
+--S 728 of 1000
+--a0:=integrate(t0,x)
+--E 728
+
+--S 729 of 1000
+--m0:=a0-r0
+--E 729
+
+--S 730 of 1000
+--d0:=normalize(D(m0,x))
+--E 730
+
+)clear all
+
+--S 731 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^7
+--R 
+--R
+--R   (1)
+--R       7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R     (d x  + 7c d x  + 21c d x  + 35c d x  + 35c d x  + 21c d x  + 7c d x + c )
+--R  *
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 1000
+--r0:=1/2*b^4*F^a*GAMMA(-4,-b*log(F)/(c+d*x)^2)*log(F)^4/d
+--E 732
+
+--S 733 of 1000
+--a0:=integrate(t0,x)
+--E 733
+
+--S 734 of 1000
+--m0:=a0-r0
+--E 734
+
+--S 735 of 1000
+--d0:=normalize(D(m0,x))
+--E 735
+
+)clear all
+
+--S 736 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^5
+--R 
+--R
+--R   (1)
+--R       5 5       4 4      2 3 3      3 2 2     4       5
+--R     (d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c )
+--R  *
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 736
+
+--S 737 of 1000
+r0:=1/6*F^(a+b/(c+d*x)^2)*(c+d*x)^6/d+1/12*b*F^(a+b/(c+d*x)^2)*(c+d*x)^4*_
+   log(F)/d+1/12*b^2*F^(a+b/(c+d*x)^2)*(c+d*x)^2*log(F)^2/d-1/12*b^3*F^a*_
+   Ei(b*log(F)/(c+d*x)^2)*log(F)^3/d
+--R 
+--R
+--R   (2)
+--R          3      3 a        b log(F)
+--R       - b log(F) F Ei(------------------)
+--R                        2 2             2
+--R                       d x  + 2c d x + c
+--R     + 
+--R             2 2 2     2         2 2       2
+--R           (b d x  + 2b c d x + b c )log(F)
+--R         + 
+--R               4 4         3 3       2 2 2       3         4            6 6
+--R           (b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c )log(F) + 2d x
+--R         + 
+--R                5 5      2 4 4      3 3 3      4 2 2      5        6
+--R           12c d x  + 30c d x  + 40c d x  + 30c d x  + 12c d x + 2c
+--R      *
+--R             2 2                 2
+--R          a d x  + 2a c d x + a c  + b
+--R          ----------------------------
+--R                2 2             2
+--R               d x  + 2c d x + c
+--R         F
+--R  /
+--R     12d
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   INTSIGN
+--R  ,
+--R      x
+--R  ,
+--R           5 5      4   4       3 2 3       2 3 2        4     5
+--R        (%A d  + 5%A c d  + 10%A c d  + 10%A c d  + 5%A c d + c )
+--R     *
+--R           2   2                  2
+--R         %A a d  + 2%A a c d + a c  + b
+--R         ------------------------------
+--R                2 2              2
+--R              %A d  + 2%A c d + c
+--R        F                              d%A
+--R                                         Type: Union(Expression(Integer),...)
+--E 738
+
+--S 739 of 1000
+--m0:=a0-r0
+--E 739
+
+--S 740 of 1000
+--d0:=normalize(D(m0,x))
+--E 740
+
+)clear all
+
+--S 741 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^3
+--R 
+--R
+--R                                          2 2                 2
+--R                                       a d x  + 2a c d x + a c  + b
+--R                                       ----------------------------
+--R                                             2 2             2
+--R          3 3       2 2     2       3       d x  + 2c d x + c
+--R   (1)  (d x  + 3c d x  + 3c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 741
+
+--S 742 of 1000
+r0:=1/4*F^(a+b/(c+d*x)^2)*(c+d*x)^4/d+1/4*b*F^(a+b/(c+d*x)^2)*(c+d*x)^2*_
+   log(F)/d-1/4*b^2*F^a*Ei(b*log(F)/(c+d*x)^2)*log(F)^2/d
+--R 
+--R
+--R   (2)
+--R          2      2 a        b log(F)
+--R       - b log(F) F Ei(------------------)
+--R                        2 2             2
+--R                       d x  + 2c d x + c
+--R     + 
+--R               2 2                 2           4 4       3 3     2 2 2     3
+--R           (b d x  + 2b c d x + b c )log(F) + d x  + 4c d x  + 6c d x  + 4c d x
+--R         + 
+--R            4
+--R           c
+--R      *
+--R             2 2                 2
+--R          a d x  + 2a c d x + a c  + b
+--R          ----------------------------
+--R                2 2             2
+--R               d x  + 2c d x + c
+--R         F
+--R  /
+--R     4d
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                            2   2                  2
+--R                                          %A a d  + 2%A a c d + a c  + b
+--R                                          ------------------------------
+--R      x                                          2 2              2
+--R    ++     3 3      2   2        2     3       %A d  + 2%A c d + c
+--R    |   (%A d  + 3%A c d  + 3%A c d + c )F                              d%A
+--R   ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 743
+
+--S 744 of 1000
+--m0:=a0-r0
+--E 744
+
+--S 745 of 1000
+--d0:=normalize(D(m0,x))
+--E 745
+
+)clear all
+
+--S 746 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)
+--R 
+--R
+--R                     2 2                 2
+--R                  a d x  + 2a c d x + a c  + b
+--R                  ----------------------------
+--R                        2 2             2
+--R                       d x  + 2c d x + c
+--R   (1)  (d x + c)F
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 1000
+r0:=1/2*F^(a+b/(c+d*x)^2)*(c+d*x)^2/d-1/2*b*F^a*Ei(b*log(F)/(c+d*x)^2)*log(F)/d
+--R 
+--R
+--R   (2)
+--R                  a        b log(F)
+--R       - b log(F)F Ei(------------------)
+--R                       2 2             2
+--R                      d x  + 2c d x + c
+--R     + 
+--R                               2 2                 2
+--R                            a d x  + 2a c d x + a c  + b
+--R                            ----------------------------
+--R                                  2 2             2
+--R         2 2             2       d x  + 2c d x + c
+--R       (d x  + 2c d x + c )F
+--R  /
+--R     2d
+--R                                                    Type: Expression(Integer)
+--E 747
+
+--S 748 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          2   2                  2
+--R                        %A a d  + 2%A a c d + a c  + b
+--R                        ------------------------------
+--R           x                   2 2              2
+--R         ++                  %A d  + 2%A c d + c
+--R   (3)   |   (%A d + c)F                              d%A
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 748
+
+--S 749 of 1000
+--m0:=a0-r0
+--E 749
+
+--S 750 of 1000
+--d0:=normalize(D(m0,x))
+--E 750
+
+)clear all
+
+--S 751 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)
+--R 
+--R
+--R            2 2                 2
+--R         a d x  + 2a c d x + a c  + b
+--R         ----------------------------
+--R               2 2             2
+--R              d x  + 2c d x + c
+--R        F
+--R   (1)  -----------------------------
+--R                   d x + c
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 1000
+r0:=-1/2*F^a*Ei(b*log(F)/(c+d*x)^2)/d
+--R 
+--R
+--R           a        b log(F)
+--R          F Ei(------------------)
+--R                2 2             2
+--R               d x  + 2c d x + c
+--R   (2)  - ------------------------
+--R                     2d
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2   2                  2
+--R              %A a d  + 2%A a c d + a c  + b
+--R              ------------------------------
+--R                     2 2              2
+--R           x       %A d  + 2%A c d + c
+--R         ++  F
+--R   (3)   |   ------------------------------- d%A
+--R        ++               %A d + c
+--R                                         Type: Union(Expression(Integer),...)
+--E 753
+
+--S 754 of 1000
+--m0:=a0-r0
+--E 754
+
+--S 755 of 1000
+--d0:=normalize(D(m0,x))
+--E 755
+
+)clear all
+
+--S 756 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^3
+--R 
+--R
+--R            2 2                 2
+--R         a d x  + 2a c d x + a c  + b
+--R         ----------------------------
+--R               2 2             2
+--R              d x  + 2c d x + c
+--R        F
+--R   (1)  -----------------------------
+--R          3 3       2 2     2       3
+--R         d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 1000
+r0:=-1/2*F^(a+b/(c+d*x)^2)/(b*d*log(F))
+--R 
+--R
+--R              2 2                 2
+--R           a d x  + 2a c d x + a c  + b
+--R           ----------------------------
+--R                 2 2             2
+--R                d x  + 2c d x + c
+--R          F
+--R   (2)  - -----------------------------
+--R                   2b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2 2                 2
+--R            (a d x  + 2a c d x + a c  + b)log(F)
+--R            ------------------------------------
+--R                      2 2             2
+--R                     d x  + 2c d x + c
+--R          %e
+--R   (3)  - --------------------------------------
+--R                        2b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 758
+
+--S 759 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2 2                 2                  2 2                 2
+--R       (a d x  + 2a c d x + a c  + b)log(F)    a d x  + 2a c d x + a c  + b
+--R       ------------------------------------    ----------------------------
+--R                 2 2             2                   2 2             2
+--R                d x  + 2c d x + c                   d x  + 2c d x + c
+--R   - %e                                     + F
+--R   ------------------------------------------------------------------------
+--R                                  2b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 760
+
+)clear all
+
+--S 761 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^5
+--R 
+--R
+--R                       2 2                 2
+--R                    a d x  + 2a c d x + a c  + b
+--R                    ----------------------------
+--R                          2 2             2
+--R                         d x  + 2c d x + c
+--R                   F
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 1000
+r0:=1/2*F^(a+b/(c+d*x)^2)/(b^2*d*log(F)^2)-1/2*F^(a+b/(c+d*x)^2)/_
+   (b*d*(c+d*x)^2*log(F))
+--R 
+--R
+--R                                             2 2                 2
+--R                                          a d x  + 2a c d x + a c  + b
+--R                                          ----------------------------
+--R                                                2 2             2
+--R                       2 2             2       d x  + 2c d x + c
+--R        (- b log(F) + d x  + 2c d x + c )F
+--R   (2)  --------------------------------------------------------------
+--R                        2 3 2     2   2      2 2        2
+--R                     (2b d x  + 4b c d x + 2b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                          2 2                 2
+--R                                      (a d x  + 2a c d x + a c  + b)log(F)
+--R                                      ------------------------------------
+--R                                                2 2             2
+--R                  2 2             2            d x  + 2c d x + c
+--R   (- b log(F) + d x  + 2c d x + c )%e
+--R   -----------------------------------------------------------------------
+--R                        2 3 2     2   2      2 2        2
+--R                     (2b d x  + 4b c d x + 2b c d)log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 763
+
+--S 764 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                              2 2                 2
+--R                                          (a d x  + 2a c d x + a c  + b)log(F)
+--R                                          ------------------------------------
+--R                                                    2 2             2
+--R                      2 2             2            d x  + 2c d x + c
+--R       (- b log(F) + d x  + 2c d x + c )%e
+--R     + 
+--R                                          2 2                 2
+--R                                       a d x  + 2a c d x + a c  + b
+--R                                       ----------------------------
+--R                                             2 2             2
+--R                    2 2             2       d x  + 2c d x + c
+--R       (b log(F) - d x  - 2c d x - c )F
+--R  /
+--R        2 3 2     2   2      2 2        2
+--R     (2b d x  + 4b c d x + 2b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 765
+
+)clear all
+
+--S 766 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^7
+--R 
+--R
+--R   (1)
+--R                             2 2                 2
+--R                          a d x  + 2a c d x + a c  + b
+--R                          ----------------------------
+--R                                2 2             2
+--R                               d x  + 2c d x + c
+--R                         F
+--R   ------------------------------------------------------------------------
+--R    7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R   d x  + 7c d x  + 21c d x  + 35c d x  + 35c d x  + 21c d x  + 7c d x + c
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 1000
+r0:=-F^(a+b/(c+d*x)^2)/(b^3*d*log(F)^3)+F^(a+b/(c+d*x)^2)/(b^2*d*(c+d*x)^2*_
+   log(F)^2)-1/2*F^(a+b/(c+d*x)^2)/(b*d*(c+d*x)^4*log(F))
+--R 
+--R
+--R   (2)
+--R            2      2        2 2                  2            4 4       3 3
+--R         - b log(F)  + (2b d x  + 4b c d x + 2b c )log(F) - 2d x  - 8c d x
+--R       + 
+--R              2 2 2     3        4
+--R         - 12c d x  - 8c d x - 2c
+--R    *
+--R           2 2                 2
+--R        a d x  + 2a c d x + a c  + b
+--R        ----------------------------
+--R              2 2             2
+--R             d x  + 2c d x + c
+--R       F
+--R  /
+--R        3 5 4     3   4 3      3 2 3 2     3 3 2      3 4        3
+--R     (2b d x  + 8b c d x  + 12b c d x  + 8b c d x + 2b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2      2        2 2                  2            4 4       3 3
+--R         - b log(F)  + (2b d x  + 4b c d x + 2b c )log(F) - 2d x  - 8c d x
+--R       + 
+--R              2 2 2     3        4
+--R         - 12c d x  - 8c d x - 2c
+--R    *
+--R             2 2                 2
+--R         (a d x  + 2a c d x + a c  + b)log(F)
+--R         ------------------------------------
+--R                   2 2             2
+--R                  d x  + 2c d x + c
+--R       %e
+--R  /
+--R        3 5 4     3   4 3      3 2 3 2     3 3 2      3 4        3
+--R     (2b d x  + 8b c d x  + 12b c d x  + 8b c d x + 2b c d)log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 768
+
+--S 769 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2      2        2 2                  2            4 4       3 3
+--R           - b log(F)  + (2b d x  + 4b c d x + 2b c )log(F) - 2d x  - 8c d x
+--R         + 
+--R                2 2 2     3        4
+--R           - 12c d x  - 8c d x - 2c
+--R      *
+--R               2 2                 2
+--R           (a d x  + 2a c d x + a c  + b)log(F)
+--R           ------------------------------------
+--R                     2 2             2
+--R                    d x  + 2c d x + c
+--R         %e
+--R     + 
+--R            2      2          2 2                  2            4 4       3 3
+--R           b log(F)  + (- 2b d x  - 4b c d x - 2b c )log(F) + 2d x  + 8c d x
+--R         + 
+--R              2 2 2     3        4
+--R           12c d x  + 8c d x + 2c
+--R      *
+--R             2 2                 2
+--R          a d x  + 2a c d x + a c  + b
+--R          ----------------------------
+--R                2 2             2
+--R               d x  + 2c d x + c
+--R         F
+--R  /
+--R        3 5 4     3   4 3      3 2 3 2     3 3 2      3 4        3
+--R     (2b d x  + 8b c d x  + 12b c d x  + 8b c d x + 2b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 770
+
+)clear all
+
+--S 771 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^9
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R  /
+--R        9 9       8 8      2 7 7      3 6 6       4 5 5       5 4 4      6 3 3
+--R       d x  + 9c d x  + 36c d x  + 84c d x  + 126c d x  + 126c d x  + 84c d x
+--R     + 
+--R          7 2 2     8       9
+--R       36c d x  + 9c d x + c
+--R                                                    Type: Expression(Integer)
+--E 771
+
+--S 772 of 1000
+r0:=3*F^(a+b/(c+d*x)^2)/(b^4*d*log(F)^4)-3*F^(a+b/(c+d*x)^2)/(b^3*d*_
+   (c+d*x)^2*log(F)^3)+3/2*F^(a+b/(c+d*x)^2)/(b^2*d*(c+d*x)^4*log(F)^2)-_
+   1/2*F^(a+b/(c+d*x)^2)/(b*d*(c+d*x)^6*log(F))
+--R 
+--R
+--R   (2)
+--R            3      3      2 2 2     2          2 2       2
+--R         - b log(F)  + (3b d x  + 6b c d x + 3b c )log(F)
+--R       + 
+--R                4 4          3 3        2 2 2        3          4            6 6
+--R         (- 6b d x  - 24b c d x  - 36b c d x  - 24b c d x - 6b c )log(F) + 6d x
+--R       + 
+--R              5 5      2 4 4       3 3 3      4 2 2      5        6
+--R         36c d x  + 90c d x  + 120c d x  + 90c d x  + 36c d x + 6c
+--R    *
+--R           2 2                 2
+--R        a d x  + 2a c d x + a c  + b
+--R        ----------------------------
+--R              2 2             2
+--R             d x  + 2c d x + c
+--R       F
+--R  /
+--R           4 7 6      4   6 5      4 2 5 4      4 3 4 3      4 4 3 2      4 5 2
+--R         2b d x  + 12b c d x  + 30b c d x  + 40b c d x  + 30b c d x  + 12b c d x
+--R       + 
+--R           4 6
+--R         2b c d
+--R    *
+--R             4
+--R       log(F)
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3      3      2 2 2     2          2 2       2
+--R         - b log(F)  + (3b d x  + 6b c d x + 3b c )log(F)
+--R       + 
+--R                4 4          3 3        2 2 2        3          4            6 6
+--R         (- 6b d x  - 24b c d x  - 36b c d x  - 24b c d x - 6b c )log(F) + 6d x
+--R       + 
+--R              5 5      2 4 4       3 3 3      4 2 2      5        6
+--R         36c d x  + 90c d x  + 120c d x  + 90c d x  + 36c d x + 6c
+--R    *
+--R             2 2                 2
+--R         (a d x  + 2a c d x + a c  + b)log(F)
+--R         ------------------------------------
+--R                   2 2             2
+--R                  d x  + 2c d x + c
+--R       %e
+--R  /
+--R           4 7 6      4   6 5      4 2 5 4      4 3 4 3      4 4 3 2      4 5 2
+--R         2b d x  + 12b c d x  + 30b c d x  + 40b c d x  + 30b c d x  + 12b c d x
+--R       + 
+--R           4 6
+--R         2b c d
+--R    *
+--R             4
+--R       log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 773
+
+--S 774 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3      3      2 2 2     2          2 2       2
+--R           - b log(F)  + (3b d x  + 6b c d x + 3b c )log(F)
+--R         + 
+--R                  4 4          3 3        2 2 2        3          4
+--R           (- 6b d x  - 24b c d x  - 36b c d x  - 24b c d x - 6b c )log(F)
+--R         + 
+--R             6 6        5 5      2 4 4       3 3 3      4 2 2      5        6
+--R           6d x  + 36c d x  + 90c d x  + 120c d x  + 90c d x  + 36c d x + 6c
+--R      *
+--R               2 2                 2
+--R           (a d x  + 2a c d x + a c  + b)log(F)
+--R           ------------------------------------
+--R                     2 2             2
+--R                    d x  + 2c d x + c
+--R         %e
+--R     + 
+--R            3      3        2 2 2     2          2 2       2
+--R           b log(F)  + (- 3b d x  - 6b c d x - 3b c )log(F)
+--R         + 
+--R                4 4          3 3        2 2 2        3          4            6 6
+--R           (6b d x  + 24b c d x  + 36b c d x  + 24b c d x + 6b c )log(F) - 6d x
+--R         + 
+--R                  5 5      2 4 4       3 3 3      4 2 2      5        6
+--R           - 36c d x  - 90c d x  - 120c d x  - 90c d x  - 36c d x - 6c
+--R      *
+--R             2 2                 2
+--R          a d x  + 2a c d x + a c  + b
+--R          ----------------------------
+--R                2 2             2
+--R               d x  + 2c d x + c
+--R         F
+--R  /
+--R           4 7 6      4   6 5      4 2 5 4      4 3 4 3      4 4 3 2      4 5 2
+--R         2b d x  + 12b c d x  + 30b c d x  + 40b c d x  + 30b c d x  + 12b c d x
+--R       + 
+--R           4 6
+--R         2b c d
+--R    *
+--R             4
+--R       log(F)
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 775
+
+)clear all
+
+--S 776 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^11
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R  /
+--R        11 11        10 10      2 9 9       3 8 8       4 7 7       5 6 6
+--R       d  x   + 11c d  x   + 55c d x  + 165c d x  + 330c d x  + 462c d x
+--R     + 
+--R           6 5 5       7 4 4       8 3 3      9 2 2      10       11
+--R       462c d x  + 330c d x  + 165c d x  + 55c d x  + 11c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 1000
+--r0:=-1/2*F^a*GAMMA(5,-b*log(F)/(c+d*x)^2)/(b^5*d*log(F)^5)
+--E 777
+
+--S 778 of 1000
+--a0:=integrate(t0,x)
+--E 778
+
+--S 779 of 1000
+--m0:=a0-r0
+--E 779
+
+--S 780 of 1000
+--d0:=normalize(D(m0,x))
+--E 780
+
+)clear all
+
+--S 781 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^13
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R  /
+--R        13 13        12 12      2 11 11       3 10 10       4 9 9        5 8 8
+--R       d  x   + 13c d  x   + 78c d  x   + 286c d  x   + 715c d x  + 1287c d x
+--R     + 
+--R            6 7 7        7 6 6        8 5 5       9 4 4       10 3 3      11 2 2
+--R       1716c d x  + 1716c d x  + 1287c d x  + 715c d x  + 286c  d x  + 78c  d x
+--R     + 
+--R          12       13
+--R       13c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 781
+
+--S 782 of 1000
+--r0:=1/2*F^a*GAMMA(6,-b*log(F)/(c+d*x)^2)/(b^6*d*log(F)^6)
+--E 782
+
+--S 783 of 1000
+--a0:=integrate(t0,x)
+--E 783
+
+--S 784 of 1000
+--m0:=a0-r0
+--E 784
+
+--S 785 of 1000
+--d0:=normalize(D(m0,x))
+--E 785
+
+)clear all
+
+--S 786 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^10
+--R 
+--R
+--R   (1)
+--R        10 10        9 9      2 8 8       3 7 7       4 6 6       5 5 5
+--R       d  x   + 10c d x  + 45c d x  + 120c d x  + 210c d x  + 252c d x
+--R     + 
+--R           6 4 4       7 3 3      8 2 2      9       10
+--R       210c d x  + 120c d x  + 45c d x  + 10c d x + c
+--R  *
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 1000
+--r0:=1/2*F^a*(c+d*x)^11*GAMMA(-11/2,-b*log(F)/(c+d*x)^2)*_
+--  (-b*log(F)/(c+d*x)^2)^(11/2)/d
+--E 787
+
+--S 788 of 1000
+--a0:=integrate(t0,x)
+--E 788
+
+--S 789 of 1000
+--m0:=a0-r0
+--E 789
+
+--S 790 of 1000
+--d0:=normalize(D(m0,x))
+--E 790
+
+)clear all
+
+--S 791 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^8
+--R 
+--R
+--R   (1)
+--R        8 8       7 7      2 6 6      3 5 5      4 4 4      5 3 3      6 2 2
+--R       d x  + 8c d x  + 28c d x  + 56c d x  + 70c d x  + 56c d x  + 28c d x
+--R     + 
+--R         7       8
+--R       8c d x + c
+--R  *
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 1000
+--r0:=1/2*F^a*(c+d*x)^9*GAMMA(-9/2,-b*log(F)/(c+d*x)^2)*_
+--  (-b*log(F)/(c+d*x)^2)^(9/2)/d
+--E 792
+
+--S 793 of 1000
+--a0:=integrate(t0,x)
+--E 793
+
+--S 794 of 1000
+--m0:=a0-r0
+--E 794
+
+--S 795 of 1000
+--d0:=normalize(D(m0,x))
+--E 795
+
+)clear all
+
+--S 796 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^6
+--R 
+--R
+--R   (1)
+--R       6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R     (d x  + 6c d x  + 15c d x  + 20c d x  + 15c d x  + 6c d x + c )
+--R  *
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 1000
+--r0:=1/7*F^(a+b/(c+d*x)^2)*(c+d*x)^7/d+2/35*b*F^(a+b/(c+d*x)^2)*(c+d*x)^5*_
+--  log(F)/d+4/105*b^2*F^(a+b/(c+d*x)^2)*(c+d*x)^3*log(F)^2/d+8/105*b^3*_
+--  F^(a+b/(c+d*x)^2)*(c+d*x)*log(F)^3/d-8/105*b^(7/2)*F^a*_
+--  erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*log(F)^(7/2)*sqrt(%pi)/d
+--E 797
+
+--S 798 of 1000
+--a0:=integrate(t0,x)
+--E 798
+
+--S 799 of 1000
+--m0:=a0-r0
+--E 799
+
+--S 800 of 1000
+--d0:=normalize(D(m0,x))
+--E 800
+
+)clear all
+
+--S 801 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^4
+--R 
+--R
+--R                                                    2 2                 2
+--R                                                 a d x  + 2a c d x + a c  + b
+--R                                                 ----------------------------
+--R                                                       2 2             2
+--R          4 4       3 3     2 2 2     3       4       d x  + 2c d x + c
+--R   (1)  (d x  + 4c d x  + 6c d x  + 4c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 801
+
+--S 802 of 1000
+--r0:=1/5*F^(a+b/(c+d*x)^2)*(c+d*x)^5/d+2/15*b*F^(a+b/(c+d*x)^2)*(c+d*x)^3*_
+--  log(F)/d+4/15*b^2*F^(a+b/(c+d*x)^2)*(c+d*x)*log(F)^2/d-4/15*b^(5/2)*_
+--  F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*log(F)^(5/2)*sqrt(%pi)/d
+--E 802
+
+--S 803 of 1000
+--a0:=integrate(t0,x)
+--E 803
+
+--S 804 of 1000
+--m0:=a0-r0
+--E 804
+
+--S 805 of 1000
+--d0:=normalize(D(m0,x))
+--E 805
+
+)clear all
+
+--S 806 of 1000
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^2
+--R 
+--R
+--R                                2 2                 2
+--R                             a d x  + 2a c d x + a c  + b
+--R                             ----------------------------
+--R                                   2 2             2
+--R          2 2             2       d x  + 2c d x + c
+--R   (1)  (d x  + 2c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 1000
+--r0:=1/3*F^(a+b/(c+d*x)^2)*(c+d*x)^3/d+2/3*b*F^(a+b/(c+d*x)^2)*(c+d*x)*_
+--  log(F)/d-2/3*b^(3/2)*F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*_
+--  log(F)^(3/2)*sqrt(%pi)/d
+--E 807
+
+--S 808 of 1000
+--a0:=integrate(t0,x)
+--E 808
+
+--S 809 of 1000
+--m0:=a0-r0
+--E 809
+
+--S 810 of 1000
+--d0:=normalize(D(m0,x))
+--E 810
+
+)clear all
+
+--S 811 of 1000
+t0:=F^(a+b/(c+d*x)^2)
+--R 
+--R
+--R            2 2                 2
+--R         a d x  + 2a c d x + a c  + b
+--R         ----------------------------
+--R               2 2             2
+--R              d x  + 2c d x + c
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 1000
+--r0:=F^(a+b/(c+d*x)^2)*(c+d*x)/d-F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*_
+--  sqrt(%pi)*sqrt(b)*sqrt(log(F))/d
+--E 812
+
+--S 813 of 1000
+--a0:=integrate(t0,x)
+--E 813
+
+--S 814 of 1000
+--m0:=a0-r0
+--E 814
+
+--S 815 of 1000
+--d0:=normalize(D(m0,x))
+--E 815
+
+)clear all
+
+--S 816 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^2
+--R 
+--R
+--R            2 2                 2
+--R         a d x  + 2a c d x + a c  + b
+--R         ----------------------------
+--R               2 2             2
+--R              d x  + 2c d x + c
+--R        F
+--R   (1)  -----------------------------
+--R               2 2             2
+--R              d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 1000
+--r0:=-1/2*F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*sqrt(%pi)/(d*sqrt(b)*_
+--  sqrt(log(F)))
+--E 817
+
+--S 818 of 1000
+--a0:=integrate(t0,x)
+--E 818
+
+--S 819 of 1000
+--m0:=a0-r0
+--E 819
+
+--S 820 of 1000
+--d0:=normalize(D(m0,x))
+--E 820
+
+)clear all
+
+--S 821 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^4
+--R 
+--R
+--R                 2 2                 2
+--R              a d x  + 2a c d x + a c  + b
+--R              ----------------------------
+--R                    2 2             2
+--R                   d x  + 2c d x + c
+--R             F
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        d x  + 4c d x  + 6c d x  + 4c d x + c
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 1000
+--r0:=-1/2*F^(a+b/(c+d*x)^2)/(b*d*(c+d*x)*log(F))+1/4*F^a*erfi(sqrt(b)*_
+--  sqrt(log(F))/(c+d*x))*sqrt(%pi)/(b^(3/2)*d*log(F)^(3/2))
+--E 822
+
+--S 823 of 1000
+--a0:=integrate(t0,x)
+--E 823
+
+--S 824 of 1000
+--m0:=a0-r0
+--E 824
+
+--S 825 of 1000
+--d0:=normalize(D(m0,x))
+--E 825
+
+)clear all
+
+--S 826 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^6
+--R 
+--R
+--R                            2 2                 2
+--R                         a d x  + 2a c d x + a c  + b
+--R                         ----------------------------
+--R                               2 2             2
+--R                              d x  + 2c d x + c
+--R                        F
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        d x  + 6c d x  + 15c d x  + 20c d x  + 15c d x  + 6c d x + c
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 1000
+--r0:=3/4*F^(a+b/(c+d*x)^2)/(b^2*d*(c+d*x)*log(F)^2)-1/2*F^(a+b/(c+d*x)^2)/_
+--  (b*d*(c+d*x)^3*log(F))-3/8*F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*_
+--  sqrt(%pi)/(b^(5/2)*d*log(F)^(5/2))
+--E 827
+
+--S 828 of 1000
+--a0:=integrate(t0,x)
+--E 828
+
+--S 829 of 1000
+--m0:=a0-r0
+--E 829
+
+--S 830 of 1000
+--d0:=normalize(D(m0,x))
+--E 830
+
+)clear all
+
+--S 831 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^8
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R  /
+--R        8 8       7 7      2 6 6      3 5 5      4 4 4      5 3 3      6 2 2
+--R       d x  + 8c d x  + 28c d x  + 56c d x  + 70c d x  + 56c d x  + 28c d x
+--R     + 
+--R         7       8
+--R       8c d x + c
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 1000
+--r0:=-15/8*F^(a+b/(c+d*x)^2)/(b^3*d*(c+d*x)*log(F)^3)+5/4*_
+--  F^(a+b/(c+d*x)^2)/(b^2*d*(c+d*x)^3*log(F)^2)-1/2*F^(a+b/(c+d*x)^2)/_
+--  (b*d*(c+d*x)^5*log(F))+15/16*F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*_
+--  sqrt(%pi)/(b^(7/2)*d*log(F)^(7/2))
+--E 832
+
+--S 833 of 1000
+--a0:=integrate(t0,x)
+--E 833
+
+--S 834 of 1000
+--m0:=a0-r0
+--E 834
+
+--S 835 of 1000
+--d0:=normalize(D(m0,x))
+--E 835
+
+)clear all
+
+--S 836 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^10
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R  /
+--R        10 10        9 9      2 8 8       3 7 7       4 6 6       5 5 5
+--R       d  x   + 10c d x  + 45c d x  + 120c d x  + 210c d x  + 252c d x
+--R     + 
+--R           6 4 4       7 3 3      8 2 2      9       10
+--R       210c d x  + 120c d x  + 45c d x  + 10c d x + c
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 1000
+--r0:=105/16*F^(a+b/(c+d*x)^2)/(b^4*d*(c+d*x)*log(F)^4)-35/8*_
+--  F^(a+b/(c+d*x)^2)/(b^3*d*(c+d*x)^3*log(F)^3)+7/4*F^(a+b/(c+d*x)^2)/_
+--  (b^2*d*(c+d*x)^5*log(F)^2)-1/2*F^(a+b/(c+d*x)^2)/(b*d*(c+d*x)^7*_
+--  log(F))-105/32*F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*sqrt(%pi)/_
+--  (b^(9/2)*d*log(F)^(9/2))
+--E 837
+
+--S 838 of 1000
+--a0:=integrate(t0,x)
+--E 838
+
+--S 839 of 1000
+--m0:=a0-r0
+--E 839
+
+--S 840 of 1000
+--d0:=normalize(D(m0,x))
+--E 840
+
+)clear all
+
+--S 841 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^12
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R  /
+--R        12 12        11 11      2 10 10       3 9 9       4 8 8       5 7 7
+--R       d  x   + 12c d  x   + 66c d  x   + 220c d x  + 495c d x  + 792c d x
+--R     + 
+--R         6 6 6       7 5 5       8 4 4       9 3 3      10 2 2      11       12
+--R     924c d x  + 792c d x  + 495c d x  + 220c d x  + 66c  d x  + 12c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 841
+
+--S 842 of 1000
+--r0:=1/2*F^a*GAMMA(11/2,-b*log(F)/(c+d*x)^2)/(d*(c+d*x)^11*_
+--  (-b*log(F)/(c+d*x)^2)^(11/2))
+--E 842
+
+--S 843 of 1000
+--a0:=integrate(t0,x)
+--E 843
+
+--S 844 of 1000
+--m0:=a0-r0
+--E 844
+
+--S 845 of 1000
+--d0:=normalize(D(m0,x))
+--E 845
+
+)clear all
+
+--S 846 of 1000
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^14
+--R 
+--R
+--R   (1)
+--R         2 2                 2
+--R      a d x  + 2a c d x + a c  + b
+--R      ----------------------------
+--R            2 2             2
+--R           d x  + 2c d x + c
+--R     F
+--R  /
+--R        14 14        13 13      2 12 12       3 11 11        4 10 10
+--R       d  x   + 14c d  x   + 91c d  x   + 364c d  x   + 1001c d  x
+--R     + 
+--R            5 9 9        6 8 8        7 7 7        8 6 6        9 5 5
+--R       2002c d x  + 3003c d x  + 3432c d x  + 3003c d x  + 2002c d x
+--R     + 
+--R            10 4 4       11 3 3      12 2 2      13       14
+--R       1001c  d x  + 364c  d x  + 91c  d x  + 14c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 846
+
+--S 847 of 1000
+--r0:=1/2*F^a*GAMMA(13/2,-b*log(F)/(c+d*x)^2)/(d*(c+d*x)^13*_
+--  (-b*log(F)/(c+d*x)^2)^(13/2))
+--E 847
+
+--S 848 of 1000
+--a0:=integrate(t0,x)
+--E 848
+
+--S 849 of 1000
+--m0:=a0-r0
+--E 849
+
+--S 850 of 1000
+--d0:=normalize(D(m0,x))
+--E 850
+
+)clear all
+
+--S 851 of 1000
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^m
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         a d x  + 3a c d x  + 3a c d x + a c  + b
+--R         ----------------------------------------
+--R                3 3       2 2     2       3
+--R               d x  + 3c d x  + 3c d x + c                m
+--R   (1)  F                                        (d x + c)
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 1000
+--r0:=1/3*F^a*(c+d*x)^(1+m)*GAMMA(1/3*(-1-m),-b*log(F)/(c+d*x)^3)*_
+--  (-b*log(F)/(c+d*x)^3)^(1/3*(1+m))/d
+--E 852
+
+--S 853 of 1000
+--a0:=integrate(t0,x)
+--E 853
+
+--S 854 of 1000
+--m0:=a0-r0
+--E 854
+
+--S 855 of 1000
+--d0:=normalize(D(m0,x))
+--E 855
+
+)clear all
+
+--S 856 of 1000
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^14
+--R 
+--R
+--R   (1)
+--R        14 14        13 13      2 12 12       3 11 11        4 10 10
+--R       d  x   + 14c d  x   + 91c d  x   + 364c d  x   + 1001c d  x
+--R     + 
+--R            5 9 9        6 8 8        7 7 7        8 6 6        9 5 5
+--R       2002c d x  + 3003c d x  + 3432c d x  + 3003c d x  + 2002c d x
+--R     + 
+--R            10 4 4       11 3 3      12 2 2      13       14
+--R       1001c  d x  + 364c  d x  + 91c  d x  + 14c  d x + c
+--R  *
+--R         3 3         2 2       2         3
+--R      a d x  + 3a c d x  + 3a c d x + a c  + b
+--R      ----------------------------------------
+--R             3 3       2 2     2       3
+--R            d x  + 3c d x  + 3c d x + c
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 856
+
+--S 857 of 1000
+--r0:=-1/3*b^5*F^a*GAMMA(-5,-b*log(F)/(c+d*x)^3)*log(F)^5/d
+--E 857
+
+--S 858 of 1000
+--a0:=integrate(t0,x)
+--E 858
+
+--S 859 of 1000
+--m0:=a0-r0
+--E 859
+
+--S 860 of 1000
+--d0:=normalize(D(m0,x))
+--E 860
+
+)clear all
+
+--S 861 of 1000
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^11
+--R 
+--R
+--R   (1)
+--R        11 11        10 10      2 9 9       3 8 8       4 7 7       5 6 6
+--R       d  x   + 11c d  x   + 55c d x  + 165c d x  + 330c d x  + 462c d x
+--R     + 
+--R           6 5 5       7 4 4       8 3 3      9 2 2      10       11
+--R       462c d x  + 330c d x  + 165c d x  + 55c d x  + 11c  d x + c
+--R  *
+--R         3 3         2 2       2         3
+--R      a d x  + 3a c d x  + 3a c d x + a c  + b
+--R      ----------------------------------------
+--R             3 3       2 2     2       3
+--R            d x  + 3c d x  + 3c d x + c
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 861
+
+--S 862 of 1000
+--r0:=1/3*b^4*F^a*GAMMA(-4,-b*log(F)/(c+d*x)^3)*log(F)^4/d
+--E 862
+
+--S 863 of 1000
+--a0:=integrate(t0,x)
+--E 863
+
+--S 864 of 1000
+--m0:=a0-r0
+--E 864
+
+--S 865 of 1000
+--d0:=normalize(D(m0,x))
+--E 865
+
+)clear all
+
+--S 866 of 1000
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^8
+--R 
+--R
+--R   (1)
+--R        8 8       7 7      2 6 6      3 5 5      4 4 4      5 3 3      6 2 2
+--R       d x  + 8c d x  + 28c d x  + 56c d x  + 70c d x  + 56c d x  + 28c d x
+--R     + 
+--R         7       8
+--R       8c d x + c
+--R  *
+--R         3 3         2 2       2         3
+--R      a d x  + 3a c d x  + 3a c d x + a c  + b
+--R      ----------------------------------------
+--R             3 3       2 2     2       3
+--R            d x  + 3c d x  + 3c d x + c
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 1000
+r0:=1/9*F^(a+b/(c+d*x)^3)*(c+d*x)^9/d+1/18*b*F^(a+b/(c+d*x)^3)*(c+d*x)^6*_
+   log(F)/d+1/18*b^2*F^(a+b/(c+d*x)^3)*(c+d*x)^3*log(F)^2/d-1/18*b^3*F^a*_
+   Ei(b*log(F)/(c+d*x)^3)*log(F)^3/d
+--R 
+--R
+--R   (2)
+--R          3      3 a             b log(F)
+--R       - b log(F) F Ei(----------------------------)
+--R                        3 3       2 2     2       3
+--R                       d x  + 3c d x  + 3c d x + c
+--R     + 
+--R             2 3 3     2   2 2     2 2       2 3       2
+--R           (b d x  + 3b c d x  + 3b c d x + b c )log(F)
+--R         + 
+--R                  6 6         5 5        2 4 4        3 3 3        4 2 2
+--R               b d x  + 6b c d x  + 15b c d x  + 20b c d x  + 15b c d x
+--R             + 
+--R                   5         6
+--R               6b c d x + b c
+--R          *
+--R             log(F)
+--R         + 
+--R             9 9        8 8      2 7 7       3 6 6       4 5 5       5 4 4
+--R           2d x  + 18c d x  + 72c d x  + 168c d x  + 252c d x  + 252c d x
+--R         + 
+--R               6 3 3      7 2 2      8        9
+--R           168c d x  + 72c d x  + 18c d x + 2c
+--R      *
+--R             3 3         2 2       2         3
+--R          a d x  + 3a c d x  + 3a c d x + a c  + b
+--R          ----------------------------------------
+--R                 3 3       2 2     2       3
+--R                d x  + 3c d x  + 3c d x + c
+--R         F
+--R  /
+--R     18d
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   INTSIGN
+--R  ,
+--R      x
+--R  ,
+--R            8 8      7   7       6 2 6       5 3 5       4 4 4       3 5 3
+--R          %A d  + 8%A c d  + 28%A c d  + 56%A c d  + 70%A c d  + 56%A c d
+--R        + 
+--R              2 6 2        7     8
+--R          28%A c d  + 8%A c d + c
+--R     *
+--R           3   3      2     2          2       3
+--R         %A a d  + 3%A a c d  + 3%A a c d + a c  + b
+--R         -------------------------------------------
+--R                 3 3      2   2        2     3
+--R               %A d  + 3%A c d  + 3%A c d + c
+--R        F                                           d%A
+--R                                         Type: Union(Expression(Integer),...)
+--E 868
+
+--S 869 of 1000
+--m0:=a0-r0
+--E 869
+
+--S 870 of 1000
+--d0:=normalize(D(m0,x))
+--E 870
+
+)clear all
+
+--S 871 of 1000
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^5
+--R 
+--R
+--R   (1)
+--R       5 5       4 4      2 3 3      3 2 2     4       5
+--R     (d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c )
+--R  *
+--R         3 3         2 2       2         3
+--R      a d x  + 3a c d x  + 3a c d x + a c  + b
+--R      ----------------------------------------
+--R             3 3       2 2     2       3
+--R            d x  + 3c d x  + 3c d x + c
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 871
+
+--S 872 of 1000
+r0:=1/6*F^(a+b/(c+d*x)^3)*(c+d*x)^6/d+1/6*b*F^(a+b/(c+d*x)^3)*(c+d*x)^3*_
+    log(F)/d-1/6*b^2*F^a*Ei(b*log(F)/(c+d*x)^3)*log(F)^2/d
+--R 
+--R
+--R   (2)
+--R          2      2 a             b log(F)
+--R       - b log(F) F Ei(----------------------------)
+--R                        3 3       2 2     2       3
+--R                       d x  + 3c d x  + 3c d x + c
+--R     + 
+--R               3 3         2 2       2         3           6 6       5 5
+--R           (b d x  + 3b c d x  + 3b c d x + b c )log(F) + d x  + 6c d x
+--R         + 
+--R              2 4 4      3 3 3      4 2 2     5       6
+--R           15c d x  + 20c d x  + 15c d x  + 6c d x + c
+--R      *
+--R             3 3         2 2       2         3
+--R          a d x  + 3a c d x  + 3a c d x + a c  + b
+--R          ----------------------------------------
+--R                 3 3       2 2     2       3
+--R                d x  + 3c d x  + 3c d x + c
+--R         F
+--R  /
+--R     6d
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   INTSIGN
+--R  ,
+--R      x
+--R  ,
+--R           5 5      4   4       3 2 3       2 3 2        4     5
+--R        (%A d  + 5%A c d  + 10%A c d  + 10%A c d  + 5%A c d + c )
+--R     *
+--R           3   3      2     2          2       3
+--R         %A a d  + 3%A a c d  + 3%A a c d + a c  + b
+--R         -------------------------------------------
+--R                 3 3      2   2        2     3
+--R               %A d  + 3%A c d  + 3%A c d + c
+--R        F                                           d%A
+--R                                         Type: Union(Expression(Integer),...)
+--E 873
+
+--S 874 of 1000
+--m0:=a0-r0
+--E 874
+
+--S 875 of 1000
+--d0:=normalize(D(m0,x))
+--E 875
+
+)clear all
+
+--S 876 of 1000
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^2
+--R 
+--R
+--R                                3 3         2 2       2         3
+--R                             a d x  + 3a c d x  + 3a c d x + a c  + b
+--R                             ----------------------------------------
+--R                                    3 3       2 2     2       3
+--R          2 2             2        d x  + 3c d x  + 3c d x + c
+--R   (1)  (d x  + 2c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 876
+
+--S 877 of 1000
+r0:=1/3*F^(a+b/(c+d*x)^3)*(c+d*x)^3/d-1/3*b*F^a*Ei(b*log(F)/(c+d*x)^3)*log(F)/d
+--R 
+--R
+--R   (2)
+--R                  a             b log(F)
+--R       - b log(F)F Ei(----------------------------)
+--R                       3 3       2 2     2       3
+--R                      d x  + 3c d x  + 3c d x + c
+--R     + 
+--R                                         3 3         2 2       2         3
+--R                                      a d x  + 3a c d x  + 3a c d x + a c  + b
+--R                                      ----------------------------------------
+--R                                             3 3       2 2     2       3
+--R         3 3       2 2     2       3        d x  + 3c d x  + 3c d x + c
+--R       (d x  + 3c d x  + 3c d x + c )F
+--R  /
+--R     3d
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--S 878 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                 3   3      2     2          2       3
+--R                               %A a d  + 3%A a c d  + 3%A a c d + a c  + b
+--R                               -------------------------------------------
+--R      x                                3 3      2   2        2     3
+--R    ++     2 2              2        %A d  + 3%A c d  + 3%A c d + c
+--R    |   (%A d  + 2%A c d + c )F                                           d%A
+--R   ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 878
+
+--S 879 of 1000
+--m0:=a0-r0
+--E 879
+
+--S 880 of 1000
+--d0:=normalize(D(m0,x))
+--E 880
+
+)clear all
+
+--S 881 of 1000
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         a d x  + 3a c d x  + 3a c d x + a c  + b
+--R         ----------------------------------------
+--R                3 3       2 2     2       3
+--R               d x  + 3c d x  + 3c d x + c
+--R        F
+--R   (1)  -----------------------------------------
+--R                         d x + c
+--R                                                    Type: Expression(Integer)
+--E 881
+
+--S 882 of 1000
+r0:=-1/3*F^a*Ei(b*log(F)/(c+d*x)^3)/d
+--R 
+--R
+--R           a             b log(F)
+--R          F Ei(----------------------------)
+--R                3 3       2 2     2       3
+--R               d x  + 3c d x  + 3c d x + c
+--R   (2)  - ----------------------------------
+--R                          3d
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3   3      2     2          2       3
+--R              %A a d  + 3%A a c d  + 3%A a c d + a c  + b
+--R              -------------------------------------------
+--R                      3 3      2   2        2     3
+--R           x        %A d  + 3%A c d  + 3%A c d + c
+--R         ++  F
+--R   (3)   |   -------------------------------------------- d%A
+--R        ++                     %A d + c
+--R                                         Type: Union(Expression(Integer),...)
+--E 883
+
+--S 884 of 1000
+--m0:=a0-r0
+--E 884
+
+--S 885 of 1000
+--d0:=normalize(D(m0,x))
+--E 885
+
+)clear all
+
+--S 886 of 1000
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^4
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         a d x  + 3a c d x  + 3a c d x + a c  + b
+--R         ----------------------------------------
+--R                3 3       2 2     2       3
+--R               d x  + 3c d x  + 3c d x + c
+--R        F
+--R   (1)  -----------------------------------------
+--R           4 4       3 3     2 2 2     3       4
+--R          d x  + 4c d x  + 6c d x  + 4c d x + c
+--R                                                    Type: Expression(Integer)
+--E 886
+
+--S 887 of 1000
+r0:=-1/3*F^(a+b/(c+d*x)^3)/(b*d*log(F))
+--R 
+--R
+--R              3 3         2 2       2         3
+--R           a d x  + 3a c d x  + 3a c d x + a c  + b
+--R           ----------------------------------------
+--R                  3 3       2 2     2       3
+--R                 d x  + 3c d x  + 3c d x + c
+--R          F
+--R   (2)  - -----------------------------------------
+--R                         3b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3 3         2 2       2         3
+--R            (a d x  + 3a c d x  + 3a c d x + a c  + b)log(F)
+--R            ------------------------------------------------
+--R                       3 3       2 2     2       3
+--R                      d x  + 3c d x  + 3c d x + c
+--R          %e
+--R   (3)  - --------------------------------------------------
+--R                              3b d log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 888
+
+--S 889 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               3 3         2 2       2         3
+--R           (a d x  + 3a c d x  + 3a c d x + a c  + b)log(F)
+--R           ------------------------------------------------
+--R                      3 3       2 2     2       3
+--R                     d x  + 3c d x  + 3c d x + c
+--R       - %e
+--R     + 
+--R           3 3         2 2       2         3
+--R        a d x  + 3a c d x  + 3a c d x + a c  + b
+--R        ----------------------------------------
+--R               3 3       2 2     2       3
+--R              d x  + 3c d x  + 3c d x + c
+--R       F
+--R  /
+--R     3b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 889
+
+--S 890 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 890
+
+)clear all
+
+--S 891 of 1000
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^7
+--R 
+--R
+--R   (1)
+--R                       3 3         2 2       2         3
+--R                    a d x  + 3a c d x  + 3a c d x + a c  + b
+--R                    ----------------------------------------
+--R                           3 3       2 2     2       3
+--R                          d x  + 3c d x  + 3c d x + c
+--R                   F
+--R   ------------------------------------------------------------------------
+--R    7 7       6 6      2 5 5      3 4 4      4 3 3      5 2 2     6       7
+--R   d x  + 7c d x  + 21c d x  + 35c d x  + 35c d x  + 21c d x  + 7c d x + c
+--R                                                    Type: Expression(Integer)
+--E 891
+
+--S 892 of 1000
+r0:=1/3*F^(a+b/(c+d*x)^3)/(b^2*d*log(F)^2)-1/3*F^(a+b/(c+d*x)^3)/_
+   (b*d*(c+d*x)^3*log(F))
+--R 
+--R
+--R   (2)
+--R                      3 3       2 2     2       3
+--R       (- b log(F) + d x  + 3c d x  + 3c d x + c )
+--R    *
+--R           3 3         2 2       2         3
+--R        a d x  + 3a c d x  + 3a c d x + a c  + b
+--R        ----------------------------------------
+--R               3 3       2 2     2       3
+--R              d x  + 3c d x  + 3c d x + c
+--R       F
+--R  /
+--R        2 4 3     2   3 2     2 2 2      2 3        2
+--R     (3b d x  + 9b c d x  + 9b c d x + 3b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 892
+
+--S 893 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      3 3       2 2     2       3
+--R       (- b log(F) + d x  + 3c d x  + 3c d x + c )
+--R    *
+--R             3 3         2 2       2         3
+--R         (a d x  + 3a c d x  + 3a c d x + a c  + b)log(F)
+--R         ------------------------------------------------
+--R                    3 3       2 2     2       3
+--R                   d x  + 3c d x  + 3c d x + c
+--R       %e
+--R  /
+--R        2 4 3     2   3 2     2 2 2      2 3        2
+--R     (3b d x  + 9b c d x  + 9b c d x + 3b c d)log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 893
+
+--S 894 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        3 3       2 2     2       3
+--R         (- b log(F) + d x  + 3c d x  + 3c d x + c )
+--R      *
+--R               3 3         2 2       2         3
+--R           (a d x  + 3a c d x  + 3a c d x + a c  + b)log(F)
+--R           ------------------------------------------------
+--R                      3 3       2 2     2       3
+--R                     d x  + 3c d x  + 3c d x + c
+--R         %e
+--R     + 
+--R                      3 3       2 2     2       3
+--R         (b log(F) - d x  - 3c d x  - 3c d x - c )
+--R      *
+--R             3 3         2 2       2         3
+--R          a d x  + 3a c d x  + 3a c d x + a c  + b
+--R          ----------------------------------------
+--R                 3 3       2 2     2       3
+--R                d x  + 3c d x  + 3c d x + c
+--R         F
+--R  /
+--R        2 4 3     2   3 2     2 2 2      2 3        2
+--R     (3b d x  + 9b c d x  + 9b c d x + 3b c d)log(F)
+--R                                                    Type: Expression(Integer)
+--E 894
+
+--S 895 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 895
+
+)clear all
+
+--S 896 of 1000
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^10
+--R 
+--R
+--R   (1)
+--R         3 3         2 2       2         3
+--R      a d x  + 3a c d x  + 3a c d x + a c  + b
+--R      ----------------------------------------
+--R             3 3       2 2     2       3
+--R            d x  + 3c d x  + 3c d x + c
+--R     F
+--R  /
+--R        10 10        9 9      2 8 8       3 7 7       4 6 6       5 5 5
+--R       d  x   + 10c d x  + 45c d x  + 120c d x  + 210c d x  + 252c d x
+--R     + 
+--R           6 4 4       7 3 3      8 2 2      9       10
+--R       210c d x  + 120c d x  + 45c d x  + 10c d x + c
+--R                                                    Type: Expression(Integer)
+--E 896
+
+--S 897 of 1000
+r0:=-2/3*F^(a+b/(c+d*x)^3)/(b^3*d*log(F)^3)+2/3*F^(a+b/(c+d*x)^3)/(b^2*d*_
+   (c+d*x)^3*log(F)^2)-1/3*F^(a+b/(c+d*x)^3)/(b*d*(c+d*x)^6*log(F))
+--R 
+--R
+--R   (2)
+--R            2      2        3 3         2 2       2          3            6 6
+--R         - b log(F)  + (2b d x  + 6b c d x  + 6b c d x + 2b c )log(F) - 2d x
+--R       + 
+--R                5 5      2 4 4      3 3 3      4 2 2      5        6
+--R         - 12c d x  - 30c d x  - 40c d x  - 30c d x  - 12c d x - 2c
+--R    *
+--R           3 3         2 2       2         3
+--R        a d x  + 3a c d x  + 3a c d x + a c  + b
+--R        ----------------------------------------
+--R               3 3       2 2     2       3
+--R              d x  + 3c d x  + 3c d x + c
+--R       F
+--R  /
+--R           3 7 6      3   6 5      3 2 5 4      3 3 4 3      3 4 3 2      3 5 2
+--R         3b d x  + 18b c d x  + 45b c d x  + 60b c d x  + 45b c d x  + 18b c d x
+--R       + 
+--R           3 6
+--R         3b c d
+--R    *
+--R             3
+--R       log(F)
+--R                                                    Type: Expression(Integer)
+--E 897
+
+--S 898 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2      2        3 3         2 2       2          3            6 6
+--R         - b log(F)  + (2b d x  + 6b c d x  + 6b c d x + 2b c )log(F) - 2d x
+--R       + 
+--R                5 5      2 4 4      3 3 3      4 2 2      5        6
+--R         - 12c d x  - 30c d x  - 40c d x  - 30c d x  - 12c d x - 2c
+--R    *
+--R             3 3         2 2       2         3
+--R         (a d x  + 3a c d x  + 3a c d x + a c  + b)log(F)
+--R         ------------------------------------------------
+--R                    3 3       2 2     2       3
+--R                   d x  + 3c d x  + 3c d x + c
+--R       %e
+--R  /
+--R           3 7 6      3   6 5      3 2 5 4      3 3 4 3      3 4 3 2      3 5 2
+--R         3b d x  + 18b c d x  + 45b c d x  + 60b c d x  + 45b c d x  + 18b c d x
+--R       + 
+--R           3 6
+--R         3b c d
+--R    *
+--R             3
+--R       log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 898
+
+--S 899 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2      2        3 3         2 2       2          3            6 6
+--R           - b log(F)  + (2b d x  + 6b c d x  + 6b c d x + 2b c )log(F) - 2d x
+--R         + 
+--R                  5 5      2 4 4      3 3 3      4 2 2      5        6
+--R           - 12c d x  - 30c d x  - 40c d x  - 30c d x  - 12c d x - 2c
+--R      *
+--R               3 3         2 2       2         3
+--R           (a d x  + 3a c d x  + 3a c d x + a c  + b)log(F)
+--R           ------------------------------------------------
+--R                      3 3       2 2     2       3
+--R                     d x  + 3c d x  + 3c d x + c
+--R         %e
+--R     + 
+--R            2      2          3 3         2 2       2          3            6 6
+--R           b log(F)  + (- 2b d x  - 6b c d x  - 6b c d x - 2b c )log(F) + 2d x
+--R         + 
+--R                5 5      2 4 4      3 3 3      4 2 2      5        6
+--R           12c d x  + 30c d x  + 40c d x  + 30c d x  + 12c d x + 2c
+--R      *
+--R             3 3         2 2       2         3
+--R          a d x  + 3a c d x  + 3a c d x + a c  + b
+--R          ----------------------------------------
+--R                 3 3       2 2     2       3
+--R                d x  + 3c d x  + 3c d x + c
+--R         F
+--R  /
+--R           3 7 6      3   6 5      3 2 5 4      3 3 4 3      3 4 3 2      3 5 2
+--R         3b d x  + 18b c d x  + 45b c d x  + 60b c d x  + 45b c d x  + 18b c d x
+--R       + 
+--R           3 6
+--R         3b c d
+--R    *
+--R             3
+--R       log(F)
+--R                                                    Type: Expression(Integer)
+--E 899
+
+--S 900 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 900
+
+)clear all
+
+--S 901 of 1000
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^13
+--R 
+--R
+--R   (1)
+--R         3 3         2 2       2         3
+--R      a d x  + 3a c d x  + 3a c d x + a c  + b
+--R      ----------------------------------------
+--R             3 3       2 2     2       3
+--R            d x  + 3c d x  + 3c d x + c
+--R     F
+--R  /
+--R        13 13        12 12      2 11 11       3 10 10       4 9 9        5 8 8
+--R       d  x   + 13c d  x   + 78c d  x   + 286c d  x   + 715c d x  + 1287c d x
+--R     + 
+--R            6 7 7        7 6 6        8 5 5       9 4 4       10 3 3      11 2 2
+--R       1716c d x  + 1716c d x  + 1287c d x  + 715c d x  + 286c  d x  + 78c  d x
+--R     + 
+--R          12       13
+--R       13c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 1000
+r0:=2*F^(a+b/(c+d*x)^3)/(b^4*d*log(F)^4)-2*F^(a+b/(c+d*x)^3)/(b^3*d*_
+   (c+d*x)^3*log(F)^3)+F^(a+b/(c+d*x)^3)/(b^2*d*(c+d*x)^6*log(F)^2)-_
+   1/3*F^(a+b/(c+d*x)^3)/(b*d*(c+d*x)^9*log(F))
+--R 
+--R
+--R   (2)
+--R            3      3      2 3 3     2   2 2     2 2        2 3       2
+--R         - b log(F)  + (3b d x  + 9b c d x  + 9b c d x + 3b c )log(F)
+--R       + 
+--R                   6 6          5 5        2 4 4         3 3 3        4 2 2
+--R             - 6b d x  - 36b c d x  - 90b c d x  - 120b c d x  - 90b c d x
+--R           + 
+--R                    5          6
+--R             - 36b c d x - 6b c
+--R        *
+--R           log(F)
+--R       + 
+--R           9 9        8 8       2 7 7       3 6 6       4 5 5       5 4 4
+--R         6d x  + 54c d x  + 216c d x  + 504c d x  + 756c d x  + 756c d x
+--R       + 
+--R             6 3 3       7 2 2      8        9
+--R         504c d x  + 216c d x  + 54c d x + 6c
+--R    *
+--R           3 3         2 2       2         3
+--R        a d x  + 3a c d x  + 3a c d x + a c  + b
+--R        ----------------------------------------
+--R               3 3       2 2     2       3
+--R              d x  + 3c d x  + 3c d x + c
+--R       F
+--R  /
+--R           4 10 9      4   9 8       4 2 8 7       4 3 7 6       4 4 6 5
+--R         3b d  x  + 27b c d x  + 108b c d x  + 252b c d x  + 378b c d x
+--R       + 
+--R             4 5 5 4       4 6 4 3       4 7 3 2      4 8 2      4 9
+--R         378b c d x  + 252b c d x  + 108b c d x  + 27b c d x + 3b c d
+--R    *
+--R             4
+--R       log(F)
+--R                                                    Type: Expression(Integer)
+--E 902
+
+--S 903 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3      3      2 3 3     2   2 2     2 2        2 3       2
+--R         - b log(F)  + (3b d x  + 9b c d x  + 9b c d x + 3b c )log(F)
+--R       + 
+--R                   6 6          5 5        2 4 4         3 3 3        4 2 2
+--R             - 6b d x  - 36b c d x  - 90b c d x  - 120b c d x  - 90b c d x
+--R           + 
+--R                    5          6
+--R             - 36b c d x - 6b c
+--R        *
+--R           log(F)
+--R       + 
+--R           9 9        8 8       2 7 7       3 6 6       4 5 5       5 4 4
+--R         6d x  + 54c d x  + 216c d x  + 504c d x  + 756c d x  + 756c d x
+--R       + 
+--R             6 3 3       7 2 2      8        9
+--R         504c d x  + 216c d x  + 54c d x + 6c
+--R    *
+--R             3 3         2 2       2         3
+--R         (a d x  + 3a c d x  + 3a c d x + a c  + b)log(F)
+--R         ------------------------------------------------
+--R                    3 3       2 2     2       3
+--R                   d x  + 3c d x  + 3c d x + c
+--R       %e
+--R  /
+--R           4 10 9      4   9 8       4 2 8 7       4 3 7 6       4 4 6 5
+--R         3b d  x  + 27b c d x  + 108b c d x  + 252b c d x  + 378b c d x
+--R       + 
+--R             4 5 5 4       4 6 4 3       4 7 3 2      4 8 2      4 9
+--R         378b c d x  + 252b c d x  + 108b c d x  + 27b c d x + 3b c d
+--R    *
+--R             4
+--R       log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 903
+
+--S 904 of 1000
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3      3      2 3 3     2   2 2     2 2        2 3       2
+--R           - b log(F)  + (3b d x  + 9b c d x  + 9b c d x + 3b c )log(F)
+--R         + 
+--R                     6 6          5 5        2 4 4         3 3 3        4 2 2
+--R               - 6b d x  - 36b c d x  - 90b c d x  - 120b c d x  - 90b c d x
+--R             + 
+--R                      5          6
+--R               - 36b c d x - 6b c
+--R          *
+--R             log(F)
+--R         + 
+--R             9 9        8 8       2 7 7       3 6 6       4 5 5       5 4 4
+--R           6d x  + 54c d x  + 216c d x  + 504c d x  + 756c d x  + 756c d x
+--R         + 
+--R               6 3 3       7 2 2      8        9
+--R           504c d x  + 216c d x  + 54c d x + 6c
+--R      *
+--R               3 3         2 2       2         3
+--R           (a d x  + 3a c d x  + 3a c d x + a c  + b)log(F)
+--R           ------------------------------------------------
+--R                      3 3       2 2     2       3
+--R                     d x  + 3c d x  + 3c d x + c
+--R         %e
+--R     + 
+--R            3      3        2 3 3     2   2 2     2 2        2 3       2
+--R           b log(F)  + (- 3b d x  - 9b c d x  - 9b c d x - 3b c )log(F)
+--R         + 
+--R                   6 6          5 5        2 4 4         3 3 3        4 2 2
+--R               6b d x  + 36b c d x  + 90b c d x  + 120b c d x  + 90b c d x
+--R             + 
+--R                    5          6
+--R               36b c d x + 6b c
+--R          *
+--R             log(F)
+--R         + 
+--R               9 9        8 8       2 7 7       3 6 6       4 5 5       5 4 4
+--R           - 6d x  - 54c d x  - 216c d x  - 504c d x  - 756c d x  - 756c d x
+--R         + 
+--R                 6 3 3       7 2 2      8        9
+--R           - 504c d x  - 216c d x  - 54c d x - 6c
+--R      *
+--R             3 3         2 2       2         3
+--R          a d x  + 3a c d x  + 3a c d x + a c  + b
+--R          ----------------------------------------
+--R                 3 3       2 2     2       3
+--R                d x  + 3c d x  + 3c d x + c
+--R         F
+--R  /
+--R           4 10 9      4   9 8       4 2 8 7       4 3 7 6       4 4 6 5
+--R         3b d  x  + 27b c d x  + 108b c d x  + 252b c d x  + 378b c d x
+--R       + 
+--R             4 5 5 4       4 6 4 3       4 7 3 2      4 8 2      4 9
+--R         378b c d x  + 252b c d x  + 108b c d x  + 27b c d x + 3b c d
+--R    *
+--R             4
+--R       log(F)
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 1000
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 905
+
+)clear all
+
+--S 906 of 1000
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^16
+--R 
+--R
+--R   (1)
+--R         3 3         2 2       2         3
+--R      a d x  + 3a c d x  + 3a c d x + a c  + b
+--R      ----------------------------------------
+--R             3 3       2 2     2       3
+--R            d x  + 3c d x  + 3c d x + c
+--R     F
+--R  /
+--R        16 16        15 15       2 14 14       3 13 13        4 12 12
+--R       d  x   + 16c d  x   + 120c d  x   + 560c d  x   + 1820c d  x
+--R     + 
+--R            5 11 11        6 10 10         7 9 9         8 8 8         9 7 7
+--R       4368c d  x   + 8008c d  x   + 11440c d x  + 12870c d x  + 11440c d x
+--R     + 
+--R            10 6 6        11 5 5        12 4 4       13 3 3       14 2 2
+--R       8008c  d x  + 4368c  d x  + 1820c  d x  + 560c  d x  + 120c  d x
+--R     + 
+--R          15       16
+--R       16c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 906
+
+--S 907 of 1000
+--r0:=-1/3*F^a*GAMMA(5,-b*log(F)/(c+d*x)^3)/(b^5*d*log(F)^5)
+--E 907
+
+--S 908 of 1000
+--a0:=integrate(t0,x)
+--E 908
+
+--S 909 of 1000
+--m0:=a0-r0
+--E 909
+
+--S 910 of 1000
+--d0:=normalize(D(m0,x))
+--E 910
+
+)clear all
+
+--S 911 of 1000
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^19
+--R 
+--R
+--R   (1)
+--R         3 3         2 2       2         3
+--R      a d x  + 3a c d x  + 3a c d x + a c  + b
+--R      ----------------------------------------
+--R             3 3       2 2     2       3
+--R            d x  + 3c d x  + 3c d x + c
+--R     F
+--R  /
+--R        19 19        18 18       2 17 17       3 16 16        4 15 15
+--R       d  x   + 19c d  x   + 171c d  x   + 969c d  x   + 3876c d  x
+--R     + 
+--R             5 14 14         6 13 13         7 12 12         8 11 11
+--R       11628c d  x   + 27132c d  x   + 50388c d  x   + 75582c d  x
+--R     + 
+--R             9 10 10         10 9 9         11 8 8         12 7 7         13 6 6
+--R       92378c d  x   + 92378c  d x  + 75582c  d x  + 50388c  d x  + 27132c  d x
+--R     + 
+--R             14 5 5        15 4 4       16 3 3       17 2 2      18       19
+--R       11628c  d x  + 3876c  d x  + 969c  d x  + 171c  d x  + 19c  d x + c
+--R                                                    Type: Expression(Integer)
+--E 911
+
+--S 912 of 1000
+--r0:=1/3*F^a*GAMMA(6,-b*log(F)/(c+d*x)^3)/(b^6*d*log(F)^6)
+--E 912
+
+--S 913 of 1000
+--a0:=integrate(t0,x)
+--E 913
+
+--S 914 of 1000
+--m0:=a0-r0
+--E 914
+
+--S 915 of 1000
+--d0:=normalize(D(m0,x))
+--E 915
+
+)clear all
+
+--S 916 of 1000
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^3
+--R 
+--R
+--R   (1)
+--R                                     3 3         2 2       2         3
+--R                                  a d x  + 3a c d x  + 3a c d x + a c  + b
+--R                                  ----------------------------------------
+--R                                         3 3       2 2     2       3
+--R     3 3       2 2     2       3        d x  + 3c d x  + 3c d x + c
+--R   (d x  + 3c d x  + 3c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 916
+
+--S 917 of 1000
+--r0:=1/3*F^a*(c+d*x)^4*GAMMA(-4/3,-b*log(F)/(c+d*x)^3)*(-b*log(F)/_
+--  (c+d*x)^3)^(4/3)/d
+--E 917
+
+--S 918 of 1000
+--a0:=integrate(t0,x)
+--E 918
+
+--S 919 of 1000
+--m0:=a0-r0
+--E 919
+
+--S 920 of 1000
+--d0:=normalize(D(m0,x))
+--E 920
+
+)clear all
+
+--S 921 of 1000
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)
+--R 
+--R
+--R                     3 3         2 2       2         3
+--R                  a d x  + 3a c d x  + 3a c d x + a c  + b
+--R                  ----------------------------------------
+--R                         3 3       2 2     2       3
+--R                        d x  + 3c d x  + 3c d x + c
+--R   (1)  (d x + c)F
+--R                                                    Type: Expression(Integer)
+--E 921
+
+--S 922 of 1000
+--r0:=1/3*F^a*(c+d*x)^2*GAMMA(-2/3,-b*log(F)/(c+d*x)^3)*(-b*log(F)/_
+--  (c+d*x)^3)^(2/3)/d
+--E 922
+
+--S 923 of 1000
+--a0:=integrate(t0,x)
+--E 923
+
+--S 924 of 1000
+--m0:=a0-r0
+--E 924
+
+--S 925 of 1000
+--d0:=normalize(D(m0,x))
+--E 925
+
+)clear all
+
+--S 926 of 1000
+t0:=F^(a+b/(c+d*x)^3)
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         a d x  + 3a c d x  + 3a c d x + a c  + b
+--R         ----------------------------------------
+--R                3 3       2 2     2       3
+--R               d x  + 3c d x  + 3c d x + c
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 926
+
+--S 927 of 1000
+--r0:=1/3*F^a*(c+d*x)*GAMMA(-1/3,-b*log(F)/(c+d*x)^3)*(-b*log(F)/_
+--  (c+d*x)^3)^(1/3)/d
+--E 927
+
+--S 928 of 1000
+--a0:=integrate(t0,x)
+--E 928
+
+--S 929 of 1000
+--m0:=a0-r0
+--E 929
+
+--S 930 of 1000
+--d0:=normalize(D(m0,x))
+--E 930
+
+)clear all
+
+--S 931 of 1000
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^2
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         a d x  + 3a c d x  + 3a c d x + a c  + b
+--R         ----------------------------------------
+--R                3 3       2 2     2       3
+--R               d x  + 3c d x  + 3c d x + c
+--R        F
+--R   (1)  -----------------------------------------
+--R                     2 2             2
+--R                    d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 931
+
+--S 932 of 1000
+--r0:=1/3*F^a*GAMMA(1/3,-b*log(F)/(c+d*x)^3)/(d*(c+d*x)*(-b*log(F)/_
+--  (c+d*x)^3)^(1/3))
+--E 932
+
+--S 933 of 1000
+--a0:=integrate(t0,x)
+--E 933
+
+--S 934 of 1000
+--m0:=a0-r0
+--E 934
+
+--S 935 of 1000
+--d0:=normalize(D(m0,x))
+--E 935
+
+)clear all
+
+--S 936 of 1000
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^3
+--R 
+--R
+--R            3 3         2 2       2         3
+--R         a d x  + 3a c d x  + 3a c d x + a c  + b
+--R         ----------------------------------------
+--R                3 3       2 2     2       3
+--R               d x  + 3c d x  + 3c d x + c
+--R        F
+--R   (1)  -----------------------------------------
+--R                3 3       2 2     2       3
+--R               d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 936
+
+--S 937 of 1000
+--r0:=1/3*F^a*GAMMA(2/3,-b*log(F)/(c+d*x)^3)/(d*(c+d*x)^2*(-b*log(F)/_
+--  (c+d*x)^3)^(2/3))
+--E 937
+
+--S 938 of 1000
+--a0:=integrate(t0,x)
+--E 938
+
+--S 939 of 1000
+--m0:=a0-r0
+--E 939
+
+--S 940 of 1000
+--d0:=normalize(D(m0,x))
+--E 940
+
+)clear all
+
+--S 941 of 1000
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^5
+--R 
+--R
+--R                 3 3         2 2       2         3
+--R              a d x  + 3a c d x  + 3a c d x + a c  + b
+--R              ----------------------------------------
+--R                     3 3       2 2     2       3
+--R                    d x  + 3c d x  + 3c d x + c
+--R             F
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c
+--R                                                    Type: Expression(Integer)
+--E 941
+
+--S 942 of 1000
+--r0:=1/3*F^a*GAMMA(4/3,-b*log(F)/(c+d*x)^3)/(d*(c+d*x)^4*(-b*log(F)/_
+--  (c+d*x)^3)^(4/3))
+--E 942
+
+--S 943 of 1000
+--a0:=integrate(t0,x)
+--E 943
+
+--S 944 of 1000
+--m0:=a0-r0
+--E 944
+
+--S 945 of 1000
+--d0:=normalize(D(m0,x))
+--E 945
+
+)clear all
+
+--S 946 of 1000
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^m
+--R 
+--R
+--R                              n
+--R                 m b (d x + c)  + a
+--R   (1)  (d x + c) F
+--R                                                    Type: Expression(Integer)
+--E 946
+
+--S 947 of 1000
+--r0:=-F^a*(c+d*x)^(1+m)*GAMMA((1+m)/n,-b*(c+d*x)^n*log(F))/_
+--  (d*n*(-b*(c+d*x)^n*log(F))^((1+m)/n))
+--E 947
+
+--S 948 of 1000
+--a0:=integrate(t0,x)
+--E 948
+
+--S 949 of 1000
+--m0:=a0-r0
+--E 949
+
+--S 950 of 1000
+--d0:=normalize(D(m0,x))
+--E 950
+
+)clear all
+
+--S 951 of 1000
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^3
+--R 
+--R
+--R                                                  n
+--R          3 3       2 2     2       3  b (d x + c)  + a
+--R   (1)  (d x  + 3c d x  + 3c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 951
+
+--S 952 of 1000
+--r0:=-F^a*(c+d*x)^4*GAMMA(4/n,-b*(c+d*x)^n*log(F))/_
+--  (d*n*(-b*(c+d*x)^n*log(F))^(4/n))
+--E 952
+
+--S 953 of 1000
+--a0:=integrate(t0,x)
+--E 953
+
+--S 954 of 1000
+--m0:=a0-r0
+--E 954
+
+--S 955 of 1000
+--d0:=normalize(D(m0,x))
+--E 955
+
+)clear all
+
+--S 956 of 1000
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^2
+--R 
+--R
+--R                                        n
+--R          2 2             2  b (d x + c)  + a
+--R   (1)  (d x  + 2c d x + c )F
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 1000
+--r0:=-F^a*(c+d*x)^3*GAMMA(3/n,-b*(c+d*x)^n*log(F))/_
+--  (d*n*(-b*(c+d*x)^n*log(F))^(3/n))
+--E 957
+
+--S 958 of 1000
+--a0:=integrate(t0,x)
+--E 958
+
+--S 959 of 1000
+--m0:=a0-r0
+--E 959
+
+--S 960 of 1000
+--d0:=normalize(D(m0,x))
+--E 960
+
+)clear all
+
+--S 961 of 1000
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)
+--R 
+--R
+--R                             n
+--R                  b (d x + c)  + a
+--R   (1)  (d x + c)F
+--R                                                    Type: Expression(Integer)
+--E 961
+
+--S 962 of 1000
+--r0:=-F^a*(c+d*x)^2*GAMMA(2/n,-b*(c+d*x)^n*log(F))/_
+--  (d*n*(-b*(c+d*x)^n*log(F))^(2/n))
+--E 962
+
+--S 963 of 1000
+--a0:=integrate(t0,x)
+--E 963
+
+--S 964 of 1000
+--m0:=a0-r0
+--E 964
+
+--S 965 of 1000
+--d0:=normalize(D(m0,x))
+--E 965
+
+)clear all
+
+--S 966 of 1000
+t0:=F^(a+b*(c+d*x)^n)
+--R 
+--R
+--R                    n
+--R         b (d x + c)  + a
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 966
+
+--S 967 of 1000
+--r0:=-F^a*(c+d*x)*GAMMA(1/n,-b*(c+d*x)^n*log(F))/_
+--  (d*n*(-b*(c+d*x)^n*log(F))^(1/n))
+--E 967
+
+--S 968 of 1000
+--a0:=integrate(t0,x)
+--E 968
+
+--S 969 of 1000
+--m0:=a0-r0
+--E 969
+
+--S 970 of 1000
+--d0:=normalize(D(m0,x))
+--E 970
+
+)clear all
+
+--S 971 of 1000
+t0:=F^(a+b*(c+d*x)^n)/(c+d*x)
+--R 
+--R
+--R                    n
+--R         b (d x + c)  + a
+--R        F
+--R   (1)  -----------------
+--R             d x + c
+--R                                                    Type: Expression(Integer)
+--E 971
+
+--S 972 of 1000
+r0:=F^a*Ei(b*(c+d*x)^n*log(F))/(d*n)
+--R 
+--R
+--R         a                    n
+--R        F Ei(b log(F)(d x + c) )
+--R   (2)  ------------------------
+--R                   d n
+--R                                                    Type: Expression(Integer)
+--E 972
+
+--S 973 of 1000
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          n
+--R           x  b (%A d + c)  + a
+--R         ++  F
+--R   (3)   |   ------------------ d%A
+--R        ++        %A d + c
+--R                                         Type: Union(Expression(Integer),...)
+--E 973
+
+--S 974 of 1000
+--m0:=a0-r0
+--E 974
+
+--S 975 of 1000
+--d0:=normalize(D(m0,x))
+--E 975
+
+)clear all
+
+--S 976 of 1000
+t0:=F^(a+b*(c+d*x)^n)/(c+d*x)^2
+--R 
+--R
+--R                     n
+--R          b (d x + c)  + a
+--R         F
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 976
+
+--S 977 of 1000
+--r0:=-F^a*GAMMA((-1)/n,-b*(c+d*x)^n*log(F))*(-b*(c+d*x)^n*_
+--  log(F))^(1/n)/(d*n*(c+d*x))
+--E 977
+
+--S 978 of 1000
+--a0:=integrate(t0,x)
+--E 978
+
+--S 979 of 1000
+--m0:=a0-r0
+--E 979
+
+--S 980 of 1000
+--d0:=normalize(D(m0,x))
+--E 980
+
+)clear all
+
+--S 981 of 1000
+t0:=F^(a+b*(c+d*x)^n)/(c+d*x)^3
+--R 
+--R
+--R                          n
+--R               b (d x + c)  + a
+--R              F
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 981
+
+--S 982 of 1000
+--r0:=-F^a*GAMMA((-2)/n,-b*(c+d*x)^n*log(F))*(-b*(c+d*x)^n*_
+--  log(F))^(2/n)/(d*n*(c+d*x)^2)
+--E 982
+
+--S 983 of 1000
+--a0:=integrate(t0,x)
+--E 983
+
+--S 984 of 1000
+--m0:=a0-r0
+--E 984
+
+--S 985 of 1000
+--d0:=normalize(D(m0,x))
+--E 985
+
+)clear all
+
+--S 986 of 1000
+t0:=F^(a+b*(c+d*x)^n)/(c+d*x)^4
+--R 
+--R
+--R                               n
+--R                    b (d x + c)  + a
+--R                   F
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        d x  + 4c d x  + 6c d x  + 4c d x + c
+--R                                                    Type: Expression(Integer)
+--E 986
+
+--S 987 of 1000
+--r0:=-F^a*GAMMA((-3)/n,-b*(c+d*x)^n*log(F))*(-b*(c+d*x)^n*_
+--  log(F))^(3/n)/(d*n*(c+d*x)^3)
+--E 987
+
+--S 988 of 1000
+--a0:=integrate(t0,x)
+--E 988
+
+--S 989 of 1000
+--m0:=a0-r0
+--E 989
+
+--S 990 of 1000
+--d0:=normalize(D(m0,x))
+--E 990
+
+)clear all
+
+--S 991 of 1000
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+6*n)
+--R 
+--R
+--R                                   n
+--R                 6n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)      F
+--R                                                    Type: Expression(Integer)
+--E 991
+
+--S 992 of 1000
+--r0:=-F^a*GAMMA(6,-b*(c+d*x)^n*log(F))/(b^6*d*n*log(F)^6)
+--E 992
+
+--S 993 of 1000
+--a0:=integrate(t0,x)
+--E 993
+
+--S 994 of 1000
+--m0:=a0-r0
+--E 994
+
+--S 995 of 1000
+--d0:=normalize(D(m0,x))
+--E 995
+
+)clear all
+
+--S 996 of 1000
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+5*n)
+--R 
+--R
+--R                                   n
+--R                 5n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)      F
+--R                                                    Type: Expression(Integer)
+--E 996
+
+--S 997 of 1000
+--r0:=F^a*GAMMA(5,-b*(c+d*x)^n*log(F))/(b^5*d*n*log(F)^5)
+--E 997
+
+--S 998 of 1000
+--a0:=integrate(t0,x)
+--E 998
+
+--S 999 of 1000
+--m0:=a0-r0
+--E 999
+
+--S 1000 of 1000
+--d0:=normalize(D(m0,x))
+--E 1000
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich24c.input.pamphlet b/src/input/rich24c.input.pamphlet
new file mode 100644
index 0000000..efdcee3
--- /dev/null
+++ b/src/input/rich24c.input.pamphlet
@@ -0,0 +1,9737 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich24c.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Exponential Functions
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich24c.output
+)spool rich24c.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1018
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+4*n)
+--R 
+--R
+--R                                   n
+--R                 4n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)      F
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1018
+r0:=-6*F^(a+b*(c+d*x)^n)/(b^4*d*n*log(F)^4)+6*F^(a+b*(c+d*x)^n)*_
+   (c+d*x)^n/(b^3*d*n*log(F)^3)-3*F^(a+b*(c+d*x)^n)*(c+d*x)^(2*n)/_
+   (b^2*d*n*log(F)^2)+F^(a+b*(c+d*x)^n)*(c+d*x)^(3*n)/(b*d*n*log(F))
+--R 
+--R
+--R   (2)
+--R         3      3         3n     2      2         2n                     n
+--R       (b log(F) (d x + c)   - 3b log(F) (d x + c)   + 6b log(F)(d x + c)  - 6)
+--R    *
+--R                   n
+--R        b (d x + c)  + a
+--R       F
+--R  /
+--R      4          4
+--R     b d n log(F)
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3      3   n log(d x + c) 3     2      2   n log(d x + c) 2
+--R         b log(F) (%e              )  - 3b log(F) (%e              )
+--R       + 
+--R                    n log(d x + c)
+--R         6b log(F)%e               - 6
+--R    *
+--R                   n log(d x + c)
+--R         b log(F)%e               + a log(F)
+--R       %e
+--R  /
+--R      4          4
+--R     b d n log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3      3   n log(d x + c) 3     2      2   n log(d x + c) 2
+--R           b log(F) (%e              )  - 3b log(F) (%e              )
+--R         + 
+--R                      n log(d x + c)
+--R           6b log(F)%e               - 6
+--R      *
+--R                     n log(d x + c)
+--R           b log(F)%e               + a log(F)
+--R         %e
+--R     + 
+--R              3      3         3n     2      2         2n                     n
+--R           - b log(F) (d x + c)   + 3b log(F) (d x + c)   - 6b log(F)(d x + c)
+--R         + 
+--R           6
+--R      *
+--R                     n
+--R          b (d x + c)  + a
+--R         F
+--R  /
+--R      4          4
+--R     b d n log(F)
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 1018
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+3*n)
+--R 
+--R
+--R                                   n
+--R                 3n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)      F
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 1018
+r0:=2*F^(a+b*(c+d*x)^n)/(b^3*d*n*log(F)^3)-2*F^(a+b*(c+d*x)^n)*(c+d*x)^n/_
+   (b^2*d*n*log(F)^2)+F^(a+b*(c+d*x)^n)*(c+d*x)^(2*n)/(b*d*n*log(F))
+--R 
+--R
+--R                                                                    n
+--R          2      2         2n                     n      b (d x + c)  + a
+--R        (b log(F) (d x + c)   - 2b log(F)(d x + c)  + 2)F
+--R   (2)  -----------------------------------------------------------------
+--R                                   3          3
+--R                                  b d n log(F)
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2      2   n log(d x + c) 2              n log(d x + c)
+--R       (b log(F) (%e              )  - 2b log(F)%e               + 2)
+--R    *
+--R                   n log(d x + c)
+--R         b log(F)%e               + a log(F)
+--R       %e
+--R  /
+--R      3          3
+--R     b d n log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2      2   n log(d x + c) 2              n log(d x + c)
+--R         (b log(F) (%e              )  - 2b log(F)%e               + 2)
+--R      *
+--R                     n log(d x + c)
+--R           b log(F)%e               + a log(F)
+--R         %e
+--R     + 
+--R                                                                     n
+--R           2      2         2n                     n      b (d x + c)  + a
+--R       (- b log(F) (d x + c)   + 2b log(F)(d x + c)  - 2)F
+--R  /
+--R      3          3
+--R     b d n log(F)
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 1018
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+2*n)
+--R 
+--R
+--R                                   n
+--R                 2n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)      F
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1018
+r0:=-F^(a+b*(c+d*x)^n)/(b^2*d*n*log(F)^2)+F^(a+b*(c+d*x)^n)*(c+d*x)^n/_
+   (b*d*n*log(F))
+--R 
+--R
+--R                                            n
+--R                          n      b (d x + c)  + a
+--R        (b log(F)(d x + c)  - 1)F
+--R   (2)  -----------------------------------------
+--R                       2          2
+--R                      b d n log(F)
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                  n log(d x + c)
+--R                   n log(d x + c)       b log(F)%e               + a log(F)
+--R        (b log(F)%e               - 1)%e
+--R   (3)  -------------------------------------------------------------------
+--R                                    2          2
+--R                                   b d n log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 13
+
+--S 14 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 n log(d x + c)
+--R                  n log(d x + c)       b log(F)%e               + a log(F)
+--R       (b log(F)%e               - 1)%e
+--R     + 
+--R                                             n
+--R                           n      b (d x + c)  + a
+--R       (- b log(F)(d x + c)  + 1)F
+--R  /
+--R      2          2
+--R     b d n log(F)
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 1018
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+n)
+--R 
+--R
+--R                                  n
+--R                 n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)     F
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1018
+r0:=F^(a+b*(c+d*x)^n)/(b*d*n*log(F))
+--R 
+--R
+--R                    n
+--R         b (d x + c)  + a
+--R        F
+--R   (2)  -----------------
+--R           b d n log(F)
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    n log(d x + c)
+--R          b log(F)%e               + a log(F)
+--R        %e
+--R   (3)  -------------------------------------
+--R                     b d n log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                    n log(d x + c)                          n
+--R          b log(F)%e               + a log(F)    b (d x + c)  + a
+--R        %e                                    - F
+--R   (4)  ---------------------------------------------------------
+--R                               b d n log(F)
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 1018
+t0:=F^(a+b*(c+d*x)^n)/(c+d*x)
+--R 
+--R
+--R                    n
+--R         b (d x + c)  + a
+--R        F
+--R   (1)  -----------------
+--R             d x + c
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 1018
+--r0:=F^a*Ei(b*(c+d*x)^n*log(F))/(d*n)
+--E 22
+
+--S 23 of 1018
+--a0:=integrate(t0,x)
+--E 23
+
+--S 24 of 1018
+--m0:=a0-r0
+--E 24
+
+--S 25 of 1018
+--d0:=normalize(D(m0,x))
+--E 25
+
+)clear all
+
+--S 26 of 1018
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1-n)
+--R 
+--R
+--R                                    n
+--R                 - n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)       F
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1018
+--r0:=-F^(a+b*(c+d*x)^n)/(d*n*(c+d*x)^n)+b*F^a*Ei(b*(c+d*x)^n*log(F))*_
+--   log(F)/(d*n)
+--E 27
+
+--S 28 of 1018
+--a0:=integrate(t0,x)
+--E 28
+
+--S 29 of 1018
+--m0:=a0-r0
+--E 29
+
+--S 30 of 1018
+--d0:=normalize(D(m0,x))
+--E 30
+
+)clear all
+
+--S 31 of 1018
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1-2*n)
+--R 
+--R
+--R                                     n
+--R                 - 2n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)        F
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 1018
+--r0:=-1/2*F^(a+b*(c+d*x)^n)/(d*n*(c+d*x)^(2*n))-1/2*b*F^(a+b*(c+d*x)^n)*_
+--   log(F)/(d*n*(c+d*x)^n)+1/2*b^2*F^a*Ei(b*(c+d*x)^n*log(F))*log(F)^2/(d*n)
+--E 32
+
+--S 33 of 1018
+--a0:=integrate(t0,x)
+--E 33
+
+--S 34 of 1018
+--m0:=a0-r0
+--E 34
+
+--S 35 of 1018
+--d0:=normalize(D(m0,x))
+--E 35
+
+)clear all
+
+--S 36 of 1018
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1-3*n)
+--R 
+--R
+--R                                     n
+--R                 - 3n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)        F
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 1018
+--r0:=-1/3*F^(a+b*(c+d*x)^n)/(d*n*(c+d*x)^(3*n))-1/6*b*F^(a+b*(c+d*x)^n)*_
+--   log(F)/(d*n*(c+d*x)^(2*n))-1/6*b^2*F^(a+b*(c+d*x)^n)*log(F)^2/_
+--   (d*n*(c+d*x)^n)+1/6*b^3*F^a*Ei(b*(c+d*x)^n*log(F))*log(F)^3/(d*n)
+--E 37
+
+--S 38 of 1018
+--a0:=integrate(t0,x)
+--E 38
+
+--S 39 of 1018
+--m0:=a0-r0
+--E 39
+
+--S 40 of 1018
+--d0:=normalize(D(m0,x))
+--E 40
+
+)clear all
+
+--S 41 of 1018
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1-4*n)
+--R 
+--R
+--R                                     n
+--R                 - 4n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)        F
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 1018
+--r0:=-b^4*F^a*GAMMA(-4,-b*(c+d*x)^n*log(F))*log(F)^4/(d*n)
+--E 42
+
+--S 43 of 1018
+--a0:=integrate(t0,x)
+--E 43
+
+--S 44 of 1018
+--m0:=a0-r0
+--E 44
+
+--S 45 of 1018
+--d0:=normalize(D(m0,x))
+--E 45
+
+)clear all
+
+--S 46 of 1018
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1-5*n)
+--R 
+--R
+--R                                     n
+--R                 - 5n - 1 b (d x + c)  + a
+--R   (1)  (d x + c)        F
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 1018
+--r0:=b^5*F^a*GAMMA(-5,-b*(c+d*x)^n*log(F))*log(F)^5/(d*n)
+--E 47
+
+--S 48 of 1018
+--a0:=integrate(t0,x)
+--E 48
+
+--S 49 of 1018
+--m0:=a0-r0
+--E 49
+
+--S 50 of 1018
+--d0:=normalize(D(m0,x))
+--E 50
+
+)clear all
+
+--S 51 of 1018
+t0:=F^(c*(a+b*x)^n)*(a+b*x)^(-1+1/2*n)
+--R 
+--R
+--R                 n - 2
+--R                 -----            n
+--R                   2   c (b x + a)
+--R   (1)  (b x + a)     F
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 1018
+--r0:=erfi((a+b*x)^(1/2*n)*sqrt(c)*sqrt(log(F)))*sqrt(%pi)/(b*n*sqrt(c)*_
+--   sqrt(log(F)))
+--E 52
+
+--S 53 of 1018
+--a0:=integrate(t0,x)
+--E 53
+
+--S 54 of 1018
+--m0:=a0-r0
+--E 54
+
+--S 55 of 1018
+--d0:=normalize(D(m0,x))
+--E 55
+
+)clear all
+
+--S 56 of 1018
+t0:=(a+b*x)^(-1+1/2*n)/F^(c*(a+b*x)^n)
+--R 
+--R
+--R                 n - 2
+--R                 -----
+--R                   2
+--R        (b x + a)
+--R   (1)  --------------
+--R                     n
+--R          c (b x + a)
+--R         F
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1018
+--r0:=erf((a+b*x)^(1/2*n)*sqrt(c)*sqrt(log(F)))*sqrt(%pi)/(b*n*sqrt(c)*_
+--   sqrt(log(F)))
+--E 57
+
+--S 58 of 1018
+--a0:=integrate(t0,x)
+--E 58
+
+--S 59 of 1018
+--m0:=a0-r0
+--E 59
+
+--S 60 of 1018
+--d0:=normalize(D(m0,x))
+--E 60
+
+)clear all
+
+--S 61 of 1018
+t0:=F^(a+b*(c+d*x)^2)*(e+f*x)^5
+--R 
+--R
+--R   (1)
+--R       5 5       4 4      2 3 3      3 2 2     4       5
+--R     (f x  + 5e f x  + 10e f x  + 10e f x  + 5e f x + e )
+--R  *
+--R         2 2                 2
+--R      b d x  + 2b c d x + b c  + a
+--R     F
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 1018
+--r0:=f^5*F^(a+b*(c+d*x)^2)/(b^3*d^6*log(F)^3)-5*f^3*(d*e-c*f)^2*F^(a+b*_
+--   (c+d*x)^2)/(b^2*d^6*log(F)^2)-15/4*f^4*(d*e-c*f)*F^(a+b*(c+d*x)^2)*_
+--   (c+d*x)/(b^2*d^6*log(F)^2)-f^5*F^(a+b*(c+d*x)^2)*(c+d*x)^2/(b^2*d^6*_
+--   log(F)^2)+5/2*f*(d*e-c*f)^4*F^(a+b*(c+d*x)^2)/(b*d^6*log(F))+5*f^2*_
+--   (d*e-c*f)^3*F^(a+b*(c+d*x)^2)*(c+d*x)/(b*d^6*log(F))+5*f^3*_
+--   (d*e-c*f)^2*F^(a+b*(c+d*x)^2)*(c+d*x)^2/(b*d^6*log(F))+5/2*f^4*_
+--   (d*e-c*f)*F^(a+b*(c+d*x)^2)*(c+d*x)^3/(b*d^6*log(F))+1/2*f^5*F^(a+_
+--   b*(c+d*x)^2)*(c+d*x)^4/(b*d^6*log(F))+15/8*f^4*(d*e-c*f)*F^a*_
+--   erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(b^(5/2)*d^6*_
+--   log(F)^(5/2))-5/2*f^2*(d*e-c*f)^3*F^a*erfi((c+d*x)*sqrt(b)*_
+--   sqrt(log(F)))*sqrt(%pi)/(b^(3/2)*d^6*log(F)^(3/2))+1/2*(d*e-c*f)^5*_
+--   F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(d^6*sqrt(b)*_
+--   sqrt(log(F)))
+--E 62
+
+--S 63 of 1018
+--a0:=integrate(t0,x)
+--E 63
+
+--S 64 of 1018
+--m0:=a0-r0
+--E 64
+
+--S 65 of 1018
+--d0:=normalize(D(m0,x))
+--E 65
+
+)clear all
+
+--S 66 of 1018
+t0:=F^(a+b*(c+d*x)^2)*(e+f*x)^4
+--R 
+--R
+--R                                                    2 2                 2
+--R          4 4       3 3     2 2 2     3       4  b d x  + 2b c d x + b c  + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 1018
+--r0:=-2*f^3*(d*e-c*f)*F^(a+b*(c+d*x)^2)/(b^2*d^5*log(F)^2)-3/4*f^4*_
+--   F^(a+b*(c+d*x)^2)*(c+d*x)/(b^2*d^5*log(F)^2)+2*f*(d*e-c*f)^3*_
+--   F^(a+b*(c+d*x)^2)/(b*d^5*log(F))+3*f^2*(d*e-c*f)^2*F^(a+b*(c+d*_
+--   x)^2)*(c+d*x)/(b*d^5*log(F))+2*f^3*(d*e-c*f)*F^(a+b*(c+d*x)^2)*_
+--   (c+d*x)^2/(b*d^5*log(F))+1/2*f^4*F^(a+b*(c+d*x)^2)*(c+d*x)^3/_
+--   (b*d^5*log(F))+3/8*f^4*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*_
+--   sqrt(%pi)/(b^(5/2)*d^5*log(F)^(5/2))-3/2*f^2*(d*e-c*f)^2*F^a*_
+--   erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(b^(3/2)*d^5*_
+--   log(F)^(3/2))+1/2*(d*e-c*f)^4*F^a*erfi((c+d*x)*sqrt(b)*_
+--   sqrt(log(F)))*sqrt(%pi)/(d^5*sqrt(b)*sqrt(log(F)))
+--E 67
+
+--S 68 of 1018
+--a0:=integrate(t0,x)
+--E 68
+
+--S 69 of 1018
+--m0:=a0-r0
+--E 69
+
+--S 70 of 1018
+--d0:=normalize(D(m0,x))
+--E 70
+
+)clear all
+
+--S 71 of 1018
+t0:=F^(a+b*(c+d*x)^2)*(e+f*x)^3
+--R 
+--R
+--R                                          2 2                 2
+--R          3 3       2 2     2       3  b d x  + 2b c d x + b c  + a
+--R   (1)  (f x  + 3e f x  + 3e f x + e )F
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1018
+--r0:=-1/2*f^3*F^(a+b*(c+d*x)^2)/(b^2*d^4*log(F)^2)+3/2*f*(d*e-c*f)^2*_
+--   F^(a+b*(c+d*x)^2)/(b*d^4*log(F))+3/2*f^2*(d*e-c*f)*F^(a+b*(c+d*x)^2)*_
+--   (c+d*x)/(b*d^4*log(F))+1/2*f^3*F^(a+b*(c+d*x)^2)*(c+d*x)^2/(b*d^4*_
+--   log(F))-3/4*f^2*(d*e-c*f)*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*_
+--   sqrt(%pi)/(b^(3/2)*d^4*log(F)^(3/2))+1/2*(d*e-c*f)^3*F^a*_
+--   erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(d^4*sqrt(b)*sqrt(log(F)))
+--E 72
+
+--S 73 of 1018
+--a0:=integrate(t0,x)
+--E 73
+
+--S 74 of 1018
+--m0:=a0-r0
+--E 74
+
+--S 75 of 1018
+--d0:=normalize(D(m0,x))
+--E 75
+
+)clear all
+
+--S 76 of 1018
+t0:=F^(a+b*(c+d*x)^2)*(e+f*x)^2
+--R 
+--R
+--R                                2 2                 2
+--R          2 2             2  b d x  + 2b c d x + b c  + a
+--R   (1)  (f x  + 2e f x + e )F
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 1018
+--r0:=f*(d*e-c*f)*F^(a+b*(c+d*x)^2)/(b*d^3*log(F))+1/2*f^2*F^(a+b*(c+_
+--   d*x)^2)*(c+d*x)/(b*d^3*log(F))-1/4*f^2*F^a*erfi((c+d*x)*sqrt(b)*_
+--   sqrt(log(F)))*sqrt(%pi)/(b^(3/2)*d^3*log(F)^(3/2))+1/2*(d*e-c*f)^2*_
+--   F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(d^3*sqrt(b)*_
+--   sqrt(log(F)))
+--E 77
+
+--S 78 of 1018
+--a0:=integrate(t0,x)
+--E 78
+
+--S 79 of 1018
+--m0:=a0-r0
+--E 79
+
+--S 80 of 1018
+--d0:=normalize(D(m0,x))
+--E 80
+
+)clear all
+
+--S 81 of 1018
+t0:=F^(a+b*(c+d*x)^2)*(e+f*x)
+--R 
+--R
+--R                     2 2                 2
+--R                  b d x  + 2b c d x + b c  + a
+--R   (1)  (f x + e)F
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 1018
+--r0:=1/2*f*F^(a+b*(c+d*x)^2)/(b*d^2*log(F))+1/2*(d*e-c*f)*F^a*_
+--   erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(d^2*sqrt(b)*sqrt(log(F)))
+--E 82
+
+--S 83 of 1018
+--a0:=integrate(t0,x)
+--E 83
+
+--S 84 of 1018
+--m0:=a0-r0
+--E 84
+
+--S 85 of 1018
+--d0:=normalize(D(m0,x))
+--E 85
+
+)clear all
+
+--S 86 of 1018
+t0:=F^(a+b*(c+d*x)^2)
+--R 
+--R
+--R            2 2                 2
+--R         b d x  + 2b c d x + b c  + a
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 1018
+--r0:=1/2*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(d*sqrt(b)*_
+--   sqrt(log(F)))
+--E 87
+
+--S 88 of 1018
+--a0:=integrate(t0,x)
+--E 88
+
+--S 89 of 1018
+--m0:=a0-r0
+--E 89
+
+--S 90 of 1018
+--d0:=normalize(D(m0,x))
+--E 90
+
+)clear all
+
+--S 91 of 1018
+t0:=F^(a+b*(c+d*x)^2)/(e+f*x)
+--R 
+--R
+--R            2 2                 2
+--R         b d x  + 2b c d x + b c  + a
+--R        F
+--R   (1)  -----------------------------
+--R                   f x + e
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1018
+--r0:=Int(F^(a+b*(c+d*x)^2)/(e+f*x),x)
+--E 92
+
+--S 93 of 1018
+--a0:=integrate(t0,x)
+--E 93
+
+--S 94 of 1018
+--m0:=a0-r0
+--E 94
+
+--S 95 of 1018
+--d0:=normalize(D(m0,x))
+--E 95
+
+)clear all
+
+--S 96 of 1018
+t0:=F^(a+b*(c+d*x)^2)/(e+f*x)^2
+--R 
+--R
+--R            2 2                 2
+--R         b d x  + 2b c d x + b c  + a
+--R        F
+--R   (1)  -----------------------------
+--R               2 2             2
+--R              f x  + 2e f x + e
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 1018
+--r0:=-F^(a+b*(c+d*x)^2)/(f*(e+f*x))+d*F^a*erfi((c+d*x)*sqrt(b)*_
+--   sqrt(log(F)))*sqrt(%pi)*sqrt(b)*sqrt(log(F))/f^2-2*b*d*(d*e-c*f)*_
+--   log(F)*Int(F^(a+b*(c+d*x)^2)/(e+f*x),x)/f^2
+--E 97
+
+--S 98 of 1018
+--a0:=integrate(t0,x)
+--E 98
+
+--S 99 of 1018
+--m0:=a0-r0
+--E 99
+
+--S 100 of 1018
+--d0:=normalize(D(m0,x))
+--E 100
+
+)clear all
+
+--S 101 of 1018
+t0:=F^(a+b*(c+d*x)^2)/(e+f*x)^3
+--R 
+--R
+--R            2 2                 2
+--R         b d x  + 2b c d x + b c  + a
+--R        F
+--R   (1)  -----------------------------
+--R          3 3       2 2     2       3
+--R         f x  + 3e f x  + 3e f x + e
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1018
+--r0:=-1/2*F^(a+b*(c+d*x)^2)/(f*(e+f*x)^2)+b*d*(d*e-c*f)*F^(a+b*(c+d*x)^2)*_
+--   log(F)/(f^3*(e+f*x))-b^(3/2)*d^2*(d*e-c*f)*F^a*erfi((c+d*x)*sqrt(b)*_
+--   sqrt(log(F)))*log(F)^(3/2)*sqrt(%pi)/f^4+b*d^2*log(F)*Int(F^(a+b*_
+--   (c+d*x)^2)/(e+f*x),x)/f^2+2*b^2*d^2*(d*e-c*f)^2*log(F)^2*Int(F^(a+_
+--   b*(c+d*x)^2)/(e+f*x),x)/f^4
+--E 102
+
+--S 103 of 1018
+--a0:=integrate(t0,x)
+--E 103
+
+--S 104 of 1018
+--m0:=a0-r0
+--E 104
+
+--S 105 of 1018
+--d0:=normalize(D(m0,x))
+--E 105
+
+)clear all
+
+--S 106 of 1018
+t0:=%e^(e*(c+d*x)^3)*(a+b*x)^3
+--R 
+--R
+--R                                         3   3       2   2     2         3
+--R          3 3       2 2     2       3   d e x  + 3c d e x  + 3c d e x + c e
+--R   (1)  (b x  + 3a b x  + 3a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 1018
+--r0:=-%e^(e*(c+d*x)^3)*b^2*(b*c-a*d)/(d^4*e)+1/3*(b*c-a*d)^3*(c+d*x)*_
+--   GAMMA(1/3,-e*(c+d*x)^3)/(d^4*(-e*(c+d*x)^3)^(1/3))-b*(b*c-a*d)^2*_
+--   (c+d*x)^2*GAMMA(2/3,-e*(c+d*x)^3)/(d^4*(-e*(c+d*x)^3)^(2/3))-_
+--   1/3*b^3*(c+d*x)^4*GAMMA(4/3,-e*(c+d*x)^3)/(d^4*(-e*(c+d*x)^3)^(4/3))
+--E 107
+
+--S 108 of 1018
+--a0:=integrate(t0,x)
+--E 108
+
+--S 109 of 1018
+--m0:=a0-r0
+--E 109
+
+--S 110 of 1018
+--d0:=normalize(D(m0,x))
+--E 110
+
+)clear all
+
+--S 111 of 1018
+t0:=%e^(e*(c+d*x)^3)*(a+b*x)^2
+--R 
+--R
+--R                               3   3       2   2     2         3
+--R          2 2             2   d e x  + 3c d e x  + 3c d e x + c e
+--R   (1)  (b x  + 2a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 1018
+--r0:=1/3*%e^(e*(c+d*x)^3)*b^2/(d^3*e)-1/3*(b*c-a*d)^2*(c+d*x)*_
+--   GAMMA(1/3,-e*(c+d*x)^3)/(d^3*(-e*(c+d*x)^3)^(1/3))+2/3*b*(b*c-a*d)*_
+--   (c+d*x)^2*GAMMA(2/3,-e*(c+d*x)^3)/(d^3*(-e*(c+d*x)^3)^(2/3))
+--E 112
+
+--S 113 of 1018
+--a0:=integrate(t0,x)
+--E 113
+
+--S 114 of 1018
+--m0:=a0-r0
+--E 114
+
+--S 115 of 1018
+--d0:=normalize(D(m0,x))
+--E 115
+
+)clear all
+
+--S 116 of 1018
+t0:=%e^(e*(c+d*x)^3)*(a+b*x)
+--R 
+--R
+--R                    3   3       2   2     2         3
+--R                   d e x  + 3c d e x  + 3c d e x + c e
+--R   (1)  (b x + a)%e
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1018
+--r0:=1/3*(b*c-a*d)*(c+d*x)*GAMMA(1/3,-e*(c+d*x)^3)/(d^2*(-e*_
+--   (c+d*x)^3)^(1/3))-1/3*b*(c+d*x)^2*GAMMA(2/3,-e*(c+d*x)^3)/_
+--   (d^2*(-e*(c+d*x)^3)^(2/3))
+--E 117
+
+--S 118 of 1018
+--a0:=integrate(t0,x)
+--E 118
+
+--S 119 of 1018
+--m0:=a0-r0
+--E 119
+
+--S 120 of 1018
+--d0:=normalize(D(m0,x))
+--E 120
+
+)clear all
+
+--S 121 of 1018
+t0:=%e^(e*(c+d*x)^3)
+--R 
+--R
+--R           3   3       2   2     2         3
+--R          d e x  + 3c d e x  + 3c d e x + c e
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1018
+--r0:=-1/3*(c+d*x)*GAMMA(1/3,-e*(c+d*x)^3)/(d*(-e*(c+d*x)^3)^(1/3))
+--E 122
+
+--S 123 of 1018
+--a0:=integrate(t0,x)
+--E 123
+
+--S 124 of 1018
+--m0:=a0-r0
+--E 124
+
+--S 125 of 1018
+--d0:=normalize(D(m0,x))
+--E 125
+
+)clear all
+
+--S 126 of 1018
+t0:=%e^(e*(c+d*x)^3)/(a+b*x)
+--R 
+--R
+--R           3   3       2   2     2         3
+--R          d e x  + 3c d e x  + 3c d e x + c e
+--R        %e
+--R   (1)  -------------------------------------
+--R                       b x + a
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 1018
+--r0:=Int(%e^(e*(c+d*x)^3)/(a+b*x),x)
+--E 127
+
+--S 128 of 1018
+--a0:=integrate(t0,x)
+--E 128
+
+--S 129 of 1018
+--m0:=a0-r0
+--E 129
+
+--S 130 of 1018
+--d0:=normalize(D(m0,x))
+--E 130
+
+)clear all
+
+--S 131 of 1018
+t0:=%e^(e*(c+d*x)^3)/(a+b*x)^2
+--R 
+--R
+--R           3   3       2   2     2         3
+--R          d e x  + 3c d e x  + 3c d e x + c e
+--R        %e
+--R   (1)  -------------------------------------
+--R                   2 2             2
+--R                  b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 1018
+--r0:=-%e^(e*(c+d*x)^3)/(b*(a+b*x))-d*(b*c-a*d)*e*(c+d*x)*GAMMA(1/3,_
+--   -e*(c+d*x)^3)/(b^3*(-e*(c+d*x)^3)^(1/3))-d*e*(c+d*x)^2*GAMMA(2/3,_
+--   -e*(c+d*x)^3)/(b^2*(-e*(c+d*x)^3)^(2/3))+3*d*(b*c-a*d)^2*e*_
+--   Int(%e^(e*(c+d*x)^3)/(a+b*x),x)/b^3
+--E 132
+
+--S 133 of 1018
+--a0:=integrate(t0,x)
+--E 133
+
+--S 134 of 1018
+--m0:=a0-r0
+--E 134
+
+--S 135 of 1018
+--d0:=normalize(D(m0,x))
+--E 135
+
+)clear all
+
+--S 136 of 1018
+t0:=F^(a+b/(c+d*x))/(e+f*x)
+--R 
+--R
+--R         a d x + a c + b
+--R         ---------------
+--R             d x + c
+--R        F
+--R   (1)  ----------------
+--R             f x + e
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 1018
+--r0:=-F^a*Ei(b*log(F)/(c+d*x))/f+F^(a-b*f/(d*e-c*f))*Ei(b*d*(e+f*x)*_
+--   log(F)/((d*e-c*f)*(c+d*x)))/f
+--E 137
+
+--S 138 of 1018
+--a0:=integrate(t0,x)
+--E 138
+
+--S 139 of 1018
+--m0:=a0-r0
+--E 139
+
+--S 140 of 1018
+--d0:=normalize(D(m0,x))
+--E 140
+
+)clear all
+
+--S 141 of 1018
+t0:=F^(a+b/(c+d*x))/(e+f*x)^2
+--R 
+--R
+--R          a d x + a c + b
+--R          ---------------
+--R              d x + c
+--R         F
+--R   (1)  ------------------
+--R         2 2             2
+--R        f x  + 2e f x + e
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 1018
+--r0:=d*F^(a+b/(c+d*x))/(f*(d*e-c*f))-F^(a+b/(c+d*x))/(f*(e+f*x))-_
+--   b*d*F^(a-b*f/(d*e-c*f))*Ei(b*d*(e+f*x)*log(F)/((d*e-c*f)*(c+d*x)))*_
+--   log(F)/(d*e-c*f)^2
+--E 142
+
+--S 143 of 1018
+--a0:=integrate(t0,x)
+--E 143
+
+--S 144 of 1018
+--m0:=a0-r0
+--E 144
+
+--S 145 of 1018
+--d0:=normalize(D(m0,x))
+--E 145
+
+)clear all
+
+--S 146 of 1018
+t0:=F^(a+b/(c+d*x))/(e+f*x)^3
+--R 
+--R
+--R               a d x + a c + b
+--R               ---------------
+--R                   d x + c
+--R              F
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        f x  + 3e f x  + 3e f x + e
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 1018
+--r0:=1/2*d^2*F^(a+b/(c+d*x))/(f*(d*e-c*f)^2)-1/2*F^(a+b/(c+d*x))/_
+--   (f*(e+f*x)^2)-1/2*b*d^2*F^(a+b/(c+d*x))*log(F)/(d*e-c*f)^3+1/2*b*_
+--   d*F^(a+b/(c+d*x))*log(F)/((d*e-c*f)^2*(e+f*x))-b*d^2*F^(a-b*f/_
+--   (d*e-c*f))*Ei(b*d*(e+f*x)*log(F)/((d*e-c*f)*(c+d*x)))*log(F)/_
+--   (d*e-c*f)^3+1/2*b^2*d^2*f*F^(a-b*f/(d*e-c*f))*Ei(b*d*(e+f*x)*_
+--   log(F)/((d*e-c*f)*(c+d*x)))*log(F)^2/(d*e-c*f)^4
+--E 147
+
+--S 148 of 1018
+--a0:=integrate(t0,x)
+--E 148
+
+--S 149 of 1018
+--m0:=a0-r0
+--E 149
+
+--S 150 of 1018
+--d0:=normalize(D(m0,x))
+--E 150
+
+)clear all
+
+--S 151 of 1018
+t0:=F^(a+b/(c+d*x))/(e+f*x)^4
+--R 
+--R
+--R                    a d x + a c + b
+--R                    ---------------
+--R                        d x + c
+--R                   F
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        f x  + 4e f x  + 6e f x  + 4e f x + e
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 1018
+--r0:=1/3*d^3*F^(a+b/(c+d*x))/(f*(d*e-c*f)^3)-1/3*F^(a+b/(c+d*x))/_
+--   (f*(e+f*x)^3)-5/6*b*d^3*F^(a+b/(c+d*x))*log(F)/(d*e-c*f)^4+1/6*b*_
+--   d*F^(a+b/(c+d*x))*log(F)/((d*e-c*f)^2*(e+f*x)^2)+2/3*b*d^2*F^(a+_
+--   b/(c+d*x))*log(F)/((d*e-c*f)^3*(e+f*x))-b*d^3*F^(a-b*f/(d*e-c*f))*_
+--   Ei(b*d*(e+f*x)*log(F)/((d*e-c*f)*(c+d*x)))*log(F)/(d*e-c*f)^4+_
+--   1/6*b^2*d^3*f*F^(a+b/(c+d*x))*log(F)^2/(d*e-c*f)^5-1/6*b^2*d^2*_
+--   f*F^(a+b/(c+d*x))*log(F)^2/((d*e-c*f)^4*(e+f*x))+b^2*d^3*f*F^(a-_
+--   b*f/(d*e-c*f))*Ei(b*d*(e+f*x)*log(F)/((d*e-c*f)*(c+d*x)))*log(F)^2/_
+--   (d*e-c*f)^5-1/6*b^3*d^3*f^2*F^(a-b*f/(d*e-c*f))*Ei(b*d*(e+f*x)*_
+--   log(F)/((d*e-c*f)*(c+d*x)))*log(F)^3/(d*e-c*f)^6
+--E 152
+
+--S 153 of 1018
+--a0:=integrate(t0,x)
+--E 153
+
+--S 154 of 1018
+--m0:=a0-r0
+--E 154
+
+--S 155 of 1018
+--d0:=normalize(D(m0,x))
+--E 155
+
+)clear all
+
+--S 156 of 1018
+t0:=%e^(e/(c+d*x))*(a+b*x)^4
+--R 
+--R
+--R                                                     e
+--R                                                  -------
+--R          4 4       3 3     2 2 2     3       4   d x + c
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 1018
+--r0:=%e^(e/(c+d*x))*(b*c-a*d)^4*(c+d*x)/d^5-2*%e^(e/(c+d*x))*b*_
+--   (b*c-a*d)^3*e*(c+d*x)/d^5+%e^(e/(c+d*x))*b^2*(b*c-a*d)^2*e^2*_
+--   (c+d*x)/d^5-2*%e^(e/(c+d*x))*b*(b*c-a*d)^3*(c+d*x)^2/d^5+%e^(e/_
+--   (c+d*x))*b^2*(b*c-a*d)^2*e*(c+d*x)^2/d^5+2*%e^(e/(c+d*x))*b^2*_
+--   (b*c-a*d)^2*(c+d*x)^3/d^5-(b*c-a*d)^4*e*Ei(e/(c+d*x))/d^5+2*b*_
+--   (b*c-a*d)^3*e^2*Ei(e/(c+d*x))/d^5-b^2*(b*c-a*d)^2*e^3*Ei(e/(c+d*x))/_
+--   d^5-b^4*e^5*GAMMA(-5,-e/(c+d*x))/d^5-4*b^3*(b*c-a*d)*e^4*_
+--   GAMMA(-4,-e/(c+d*x))/d^5
+--E 157
+
+--S 158 of 1018
+--a0:=integrate(t0,x)
+--E 158
+
+--S 159 of 1018
+--m0:=a0-r0
+--E 159
+
+--S 160 of 1018
+--d0:=normalize(D(m0,x))
+--E 160
+
+)clear all
+
+--S 161 of 1018
+t0:=%e^(e/(c+d*x))*(a+b*x)^3
+--R 
+--R
+--R                                           e
+--R                                        -------
+--R          3 3       2 2     2       3   d x + c
+--R   (1)  (b x  + 3a b x  + 3a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 1018
+--r0:=-%e^(e/(c+d*x))*(b*c-a*d)^3*(c+d*x)/d^4+3/2*%e^(e/(c+d*x))*b*_
+--   (b*c-a*d)^2*e*(c+d*x)/d^4-1/2*%e^(e/(c+d*x))*b^2*(b*c-a*d)*e^2*_
+--   (c+d*x)/d^4+3/2*%e^(e/(c+d*x))*b*(b*c-a*d)^2*(c+d*x)^2/d^4-_
+--   1/2*%e^(e/(c+d*x))*b^2*(b*c-a*d)*e*(c+d*x)^2/d^4-%e^(e/(c+d*x))*_
+--   b^2*(b*c-a*d)*(c+d*x)^3/d^4+(b*c-a*d)^3*e*Ei(e/(c+d*x))/d^4-3/2*_
+--   b*(b*c-a*d)^2*e^2*Ei(e/(c+d*x))/d^4+1/2*b^2*(b*c-a*d)*e^3*_
+--   Ei(e/(c+d*x))/d^4+b^3*e^4*GAMMA(-4,-e/(c+d*x))/d^4
+--E 162
+
+--S 163 of 1018
+--a0:=integrate(t0,x)
+--E 163
+
+--S 164 of 1018
+--m0:=a0-r0
+--E 164
+
+--S 165 of 1018
+--d0:=normalize(D(m0,x))
+--E 165
+
+)clear all
+
+--S 166 of 1018
+t0:=%e^(e/(c+d*x))*(a+b*x)^2
+--R 
+--R
+--R                                 e
+--R                              -------
+--R          2 2             2   d x + c
+--R   (1)  (b x  + 2a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 1018
+--r0:=%e^(e/(c+d*x))*(b*c-a*d)^2*(c+d*x)/d^3-%e^(e/(c+d*x))*b*(b*c-a*d)*_
+--   e*(c+d*x)/d^3+1/6*%e^(e/(c+d*x))*b^2*e^2*(c+d*x)/d^3-%e^(e/(c+d*x))*_
+--   b*(b*c-a*d)*(c+d*x)^2/d^3+1/6*%e^(e/(c+d*x))*b^2*e*(c+d*x)^2/d^3+_
+--   1/3*%e^(e/(c+d*x))*b^2*(c+d*x)^3/d^3-(b*c-a*d)^2*e*Ei(e/(c+d*x))/d^3+_
+--   b*(b*c-a*d)*e^2*Ei(e/(c+d*x))/d^3-1/6*b^2*e^3*Ei(e/(c+d*x))/d^3
+--E 167
+
+--S 168 of 1018
+--a0:=integrate(t0,x)
+--E 168
+
+--S 169 of 1018
+--m0:=a0-r0
+--E 169
+
+--S 170 of 1018
+--d0:=normalize(D(m0,x))
+--E 170
+
+)clear all
+
+--S 171 of 1018
+t0:=%e^(e/(c+d*x))*(a+b*x)
+--R 
+--R
+--R                      e
+--R                   -------
+--R                   d x + c
+--R   (1)  (b x + a)%e
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 1018
+--r0:=-%e^(e/(c+d*x))*(b*c-a*d)*(c+d*x)/d^2+1/2*%e^(e/(c+d*x))*b*e*_
+--   (c+d*x)/d^2+1/2*%e^(e/(c+d*x))*b*(c+d*x)^2/d^2+(b*c-a*d)*e*_
+--   Ei(e/(c+d*x))/d^2-1/2*b*e^2*Ei(e/(c+d*x))/d^2
+--E 172
+
+--S 173 of 1018
+--a0:=integrate(t0,x)
+--E 173
+
+--S 174 of 1018
+--m0:=a0-r0
+--E 174
+
+--S 175 of 1018
+--d0:=normalize(D(m0,x))
+--E 175
+
+)clear all
+
+--S 176 of 1018
+t0:=%e^(e/(c+d*x))
+--R 
+--R
+--R             e
+--R          -------
+--R          d x + c
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 1018
+--r0:=%e^(e/(c+d*x))*(c+d*x)/d-e*Ei(e/(c+d*x))/d
+--E 177
+
+--S 178 of 1018
+--a0:=integrate(t0,x)
+--E 178
+
+--S 179 of 1018
+--m0:=a0-r0
+--E 179
+
+--S 180 of 1018
+--d0:=normalize(D(m0,x))
+--E 180
+
+)clear all
+
+--S 181 of 1018
+t0:=%e^(e/(c+d*x))/(a+b*x)
+--R 
+--R
+--R             e
+--R          -------
+--R          d x + c
+--R        %e
+--R   (1)  ---------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1018
+--r0:=-Ei(e/(c+d*x))/b+%e^(b*e/(b*c-a*d))*Ei(-d*e*(a+b*x)/((b*c-a*d)*_
+--   (c+d*x)))/b
+--E 182
+
+--S 183 of 1018
+--a0:=integrate(t0,x)
+--E 183
+
+--S 184 of 1018
+--m0:=a0-r0
+--E 184
+
+--S 185 of 1018
+--d0:=normalize(D(m0,x))
+--E 185
+
+)clear all
+
+--S 186 of 1018
+t0:=%e^(e/(c+d*x))/(a+b*x)^2
+--R 
+--R
+--R                  e
+--R               -------
+--R               d x + c
+--R             %e
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 1018
+--r0:=-%e^(e/(c+d*x))*d/(b*(b*c-a*d))-%e^(e/(c+d*x))/(b*(a+b*x))-%e^(b*_
+--   e/(b*c-a*d))*d*e*Ei(-d*e*(a+b*x)/((b*c-a*d)*(c+d*x)))/(b*c-a*d)^2
+--E 187
+
+--S 188 of 1018
+--a0:=integrate(t0,x)
+--E 188
+
+--S 189 of 1018
+--m0:=a0-r0
+--E 189
+
+--S 190 of 1018
+--d0:=normalize(D(m0,x))
+--E 190
+
+)clear all
+
+--S 191 of 1018
+t0:=%e^(e/(c+d*x))/(a+b*x)^3
+--R 
+--R
+--R                       e
+--R                    -------
+--R                    d x + c
+--R                  %e
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        b x  + 3a b x  + 3a b x + a
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1018
+--r0:=1/2*%e^(e/(c+d*x))*d^2/(b*(b*c-a*d)^2)+1/2*%e^(e/(c+d*x))*d^2*e/_
+--   (b*c-a*d)^3-1/2*%e^(e/(c+d*x))/(b*(a+b*x)^2)+1/2*%e^(e/(c+d*x))*d*e/_
+--   ((b*c-a*d)^2*(a+b*x))+%e^(b*e/(b*c-a*d))*d^2*e*Ei(-d*e*(a+b*x)/_
+--   ((b*c-a*d)*(c+d*x)))/(b*c-a*d)^3+1/2*%e^(b*e/(b*c-a*d))*b*d^2*e^2*_
+--   Ei(-d*e*(a+b*x)/((b*c-a*d)*(c+d*x)))/(b*c-a*d)^4
+--E 192
+
+--S 193 of 1018
+--a0:=integrate(t0,x)
+--E 193
+
+--S 194 of 1018
+--m0:=a0-r0
+--E 194
+
+--S 195 of 1018
+--d0:=normalize(D(m0,x))
+--E 195
+
+)clear all
+
+--S 196 of 1018
+t0:=%e^(e/(c+d*x)^2)*(a+b*x)^3
+--R 
+--R
+--R                                                 e
+--R                                        ------------------
+--R                                         2 2             2
+--R          3 3       2 2     2       3   d x  + 2c d x + c
+--R   (1)  (b x  + 3a b x  + 3a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1018
+--r0:=-%e^(e/(c+d*x)^2)*(b*c-a*d)^3*(c+d*x)/d^4-2*%e^(e/(c+d*x)^2)*b^2*_
+--   (b*c-a*d)*e*(c+d*x)/d^4+3/2*%e^(e/(c+d*x)^2)*b*(b*c-a*d)^2*(c+d*x)^2/_
+--   d^4+1/4*%e^(e/(c+d*x)^2)*b^3*e*(c+d*x)^2/d^4-%e^(e/(c+d*x)^2)*b^2*_
+--   (b*c-a*d)*(c+d*x)^3/d^4+1/4*%e^(e/(c+d*x)^2)*b^3*(c+d*x)^4/d^4-_
+--   3/2*b*(b*c-a*d)^2*e*Ei(e/(c+d*x)^2)/d^4-1/4*b^3*e^2*Ei(e/(c+d*x)^2)/_
+--   d^4+2*b^2*(b*c-a*d)*e^(3/2)*erfi(sqrt(e)/(c+d*x))*sqrt(%pi)/d^4+_
+--   (b*c-a*d)^3*erfi(sqrt(e)/(c+d*x))*sqrt(%pi)*sqrt(e)/d^4
+--E 197
+
+--S 198 of 1018
+--a0:=integrate(t0,x)
+--E 198
+
+--S 199 of 1018
+--m0:=a0-r0
+--E 199
+
+--S 200 of 1018
+--d0:=normalize(D(m0,x))
+--E 200
+
+)clear all
+
+--S 201 of 1018
+t0:=%e^(e/(c+d*x)^2)*(a+b*x)^2
+--R 
+--R
+--R                                       e
+--R                              ------------------
+--R                               2 2             2
+--R          2 2             2   d x  + 2c d x + c
+--R   (1)  (b x  + 2a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 1018
+--r0:=%e^(e/(c+d*x)^2)*(b*c-a*d)^2*(c+d*x)/d^3+2/3*%e^(e/(c+d*x)^2)*b^2*_
+--   e*(c+d*x)/d^3-%e^(e/(c+d*x)^2)*b*(b*c-a*d)*(c+d*x)^2/d^3+_
+--   1/3*%e^(e/(c+d*x)^2)*b^2*(c+d*x)^3/d^3+b*(b*c-a*d)*e*Ei(e/(c+_
+--   d*x)^2)/d^3-2/3*b^2*e^(3/2)*erfi(sqrt(e)/(c+d*x))*sqrt(%pi)/d^3-_
+--   (b*c-a*d)^2*erfi(sqrt(e)/(c+d*x))*sqrt(%pi)*sqrt(e)/d^3
+--E 202
+
+--S 203 of 1018
+--a0:=integrate(t0,x)
+--E 203
+
+--S 204 of 1018
+--m0:=a0-r0
+--E 204
+
+--S 205 of 1018
+--d0:=normalize(D(m0,x))
+--E 205
+
+)clear all
+
+--S 206 of 1018
+t0:=%e^(e/(c+d*x)^2)*(a+b*x)
+--R 
+--R
+--R                            e
+--R                   ------------------
+--R                    2 2             2
+--R                   d x  + 2c d x + c
+--R   (1)  (b x + a)%e
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 1018
+--r0:=-%e^(e/(c+d*x)^2)*(b*c-a*d)*(c+d*x)/d^2+1/2*%e^(e/(c+d*x)^2)*b*_
+--   (c+d*x)^2/d^2-1/2*b*e*Ei(e/(c+d*x)^2)/d^2+(b*c-a*d)*erfi(sqrt(e)/_
+--   (c+d*x))*sqrt(%pi)*sqrt(e)/d^2
+--E 207
+
+--S 208 of 1018
+--a0:=integrate(t0,x)
+--E 208
+
+--S 209 of 1018
+--m0:=a0-r0
+--E 209
+
+--S 210 of 1018
+--d0:=normalize(D(m0,x))
+--E 210
+
+)clear all
+
+--S 211 of 1018
+t0:=%e^(e/(c+d*x)^2)
+--R 
+--R
+--R                   e
+--R          ------------------
+--R           2 2             2
+--R          d x  + 2c d x + c
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 1018
+--r0:=%e^(e/(c+d*x)^2)*(c+d*x)/d-erfi(sqrt(e)/(c+d*x))*sqrt(%pi)*sqrt(e)/d
+--E 212
+
+--S 213 of 1018
+--a0:=integrate(t0,x)
+--E 213
+
+--S 214 of 1018
+--m0:=a0-r0
+--E 214
+
+--S 215 of 1018
+--d0:=normalize(D(m0,x))
+--E 215
+
+)clear all
+
+--S 216 of 1018
+t0:=%e^(e/(c+d*x)^2)/(a+b*x)
+--R 
+--R
+--R                   e
+--R          ------------------
+--R           2 2             2
+--R          d x  + 2c d x + c
+--R        %e
+--R   (1)  --------------------
+--R               b x + a
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 1018
+--r0:=Int(%e^(e/(c+d*x)^2)/(a+b*x),x)
+--E 217
+
+--S 218 of 1018
+--a0:=integrate(t0,x)
+--E 218
+
+--S 219 of 1018
+--m0:=a0-r0
+--E 219
+
+--S 220 of 1018
+--d0:=normalize(D(m0,x))
+--E 220
+
+)clear all
+
+--S 221 of 1018
+t0:=%e^(e/(c+d*x)^2)/(a+b*x)^2
+--R 
+--R
+--R                   e
+--R          ------------------
+--R           2 2             2
+--R          d x  + 2c d x + c
+--R        %e
+--R   (1)  --------------------
+--R          2 2             2
+--R         b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1018
+--r0:=Int(%e^(e/(c+d*x)^2)/(a+b*x)^2,x)
+--E 222
+
+--S 223 of 1018
+--a0:=integrate(t0,x)
+--E 223
+
+--S 224 of 1018
+--m0:=a0-r0
+--E 224
+
+--S 225 of 1018
+--d0:=normalize(D(m0,x))
+--E 225
+
+)clear all
+
+--S 226 of 1018
+t0:=%e^(e/(c+d*x)^2)/(a+b*x)^3
+--R 
+--R
+--R                       e
+--R              ------------------
+--R               2 2             2
+--R              d x  + 2c d x + c
+--R            %e
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        b x  + 3a b x  + 3a b x + a
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 1018
+--r0:=Int(%e^(e/(c+d*x)^2)/(a+b*x)^3,x)
+--E 227
+
+--S 228 of 1018
+--a0:=integrate(t0,x)
+--E 228
+
+--S 229 of 1018
+--m0:=a0-r0
+--E 229
+
+--S 230 of 1018
+--d0:=normalize(D(m0,x))
+--E 230
+
+)clear all
+
+--S 231 of 1018
+t0:=%e^(e/(c+d*x)^3)*(a+b*x)^3
+--R 
+--R
+--R                                                      e
+--R                                        ----------------------------
+--R                                         3 3       2 2     2       3
+--R          3 3       2 2     2       3   d x  + 3c d x  + 3c d x + c
+--R   (1)  (b x  + 3a b x  + 3a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 1018
+--r0:=-%e^(e/(c+d*x)^3)*b^2*(b*c-a*d)*(c+d*x)^3/d^4+b^2*(b*c-a*d)*e*_
+--   Ei(e/(c+d*x)^3)/d^4+1/3*b^3*(-e/(c+d*x)^3)^(4/3)*(c+d*x)^4*_
+--   GAMMA(-4/3,-e/(c+d*x)^3)/d^4+b*(b*c-a*d)^2*(-e/(c+d*x)^3)^(2/3)*_
+--   (c+d*x)^2*GAMMA(-2/3,-e/(c+d*x)^3)/d^4-1/3*(b*c-a*d)^3*(-e/(c+_
+--   d*x)^3)^(1/3)*(c+d*x)*GAMMA(-1/3,-e/(c+d*x)^3)/d^4
+--E 232
+
+--S 233 of 1018
+--a0:=integrate(t0,x)
+--E 233
+
+--S 234 of 1018
+--m0:=a0-r0
+--E 234
+
+--S 235 of 1018
+--d0:=normalize(D(m0,x))
+--E 235
+
+)clear all
+
+--S 236 of 1018
+t0:=%e^(e/(c+d*x)^3)*(a+b*x)^2
+--R 
+--R
+--R                                            e
+--R                              ----------------------------
+--R                               3 3       2 2     2       3
+--R          2 2             2   d x  + 3c d x  + 3c d x + c
+--R   (1)  (b x  + 2a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 1018
+--r0:=1/3*%e^(e/(c+d*x)^3)*b^2*(c+d*x)^3/d^3-1/3*b^2*e*Ei(e/(c+d*x)^3)/d^3-_
+--   2/3*b*(b*c-a*d)*(-e/(c+d*x)^3)^(2/3)*(c+d*x)^2*GAMMA(-2/3,-e/_
+--   (c+d*x)^3)/d^3+1/3*(b*c-a*d)^2*(-e/(c+d*x)^3)^(1/3)*(c+d*x)*_
+--   GAMMA(-1/3,-e/(c+d*x)^3)/d^3
+--E 237
+
+--S 238 of 1018
+--a0:=integrate(t0,x)
+--E 238
+
+--S 239 of 1018
+--m0:=a0-r0
+--E 239
+
+--S 240 of 1018
+--d0:=normalize(D(m0,x))
+--E 240
+
+)clear all
+
+--S 241 of 1018
+t0:=%e^(e/(c+d*x)^3)*(a+b*x)
+--R 
+--R
+--R                                 e
+--R                   ----------------------------
+--R                    3 3       2 2     2       3
+--R                   d x  + 3c d x  + 3c d x + c
+--R   (1)  (b x + a)%e
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 1018
+--r0:=1/3*b*(-e/(c+d*x)^3)^(2/3)*(c+d*x)^2*GAMMA(-2/3,-e/(c+d*x)^3)/d^2-_
+--   1/3*(b*c-a*d)*(-e/(c+d*x)^3)^(1/3)*(c+d*x)*GAMMA(-1/3,-e/(c+d*x)^3)/d^2
+--E 242
+
+--S 243 of 1018
+--a0:=integrate(t0,x)
+--E 243
+
+--S 244 of 1018
+--m0:=a0-r0
+--E 244
+
+--S 245 of 1018
+--d0:=normalize(D(m0,x))
+--E 245
+
+)clear all
+
+--S 246 of 1018
+t0:=%e^(e/(c+d*x)^3)
+--R 
+--R
+--R                        e
+--R          ----------------------------
+--R           3 3       2 2     2       3
+--R          d x  + 3c d x  + 3c d x + c
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 1018
+--r0:=1/3*(-e/(c+d*x)^3)^(1/3)*(c+d*x)*GAMMA(-1/3,-e/(c+d*x)^3)/d
+--E 247
+
+--S 248 of 1018
+--a0:=integrate(t0,x)
+--E 248
+
+--S 249 of 1018
+--m0:=a0-r0
+--E 249
+
+--S 250 of 1018
+--d0:=normalize(D(m0,x))
+--E 250
+
+)clear all
+
+--S 251 of 1018
+t0:=%e^(e/(c+d*x)^3)/(a+b*x)
+--R 
+--R
+--R                        e
+--R          ----------------------------
+--R           3 3       2 2     2       3
+--R          d x  + 3c d x  + 3c d x + c
+--R        %e
+--R   (1)  ------------------------------
+--R                    b x + a
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 1018
+--r0:=Int(%e^(e/(c+d*x)^3)/(a+b*x),x)
+--E 252
+
+--S 253 of 1018
+--a0:=integrate(t0,x)
+--E 253
+
+--S 254 of 1018
+--m0:=a0-r0
+--E 254
+
+--S 255 of 1018
+--d0:=normalize(D(m0,x))
+--E 255
+
+)clear all
+
+--S 256 of 1018
+t0:=%e^(e/(c+d*x)^3)/(a+b*x)^2
+--R 
+--R
+--R                        e
+--R          ----------------------------
+--R           3 3       2 2     2       3
+--R          d x  + 3c d x  + 3c d x + c
+--R        %e
+--R   (1)  ------------------------------
+--R               2 2             2
+--R              b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 1018
+--r0:=Int(%e^(e/(c+d*x)^3)/(a+b*x)^2,x)
+--E 257
+
+--S 258 of 1018
+--a0:=integrate(t0,x)
+--E 258
+
+--S 259 of 1018
+--m0:=a0-r0
+--E 259
+
+--S 260 of 1018
+--d0:=normalize(D(m0,x))
+--E 260
+
+)clear all
+
+--S 261 of 1018
+t0:=F^(e+f*(a+b*x)/(c+d*x))/(g+h*x)
+--R 
+--R
+--R         (b f + d e)x + a f + c e
+--R         ------------------------
+--R                  d x + c
+--R        F
+--R   (1)  -------------------------
+--R                 h x + g
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 1018
+--r0:=-F^(e+b*f/d)*Ei(-(b*c-a*d)*f*log(F)/(d*(c+d*x)))/h+F^(e+f*(b*g-a*h)/_
+--   (d*g-c*h))*Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))/h
+--E 262
+
+--S 263 of 1018
+--a0:=integrate(t0,x)
+--E 263
+
+--S 264 of 1018
+--m0:=a0-r0
+--E 264
+
+--S 265 of 1018
+--d0:=normalize(D(m0,x))
+--E 265
+
+)clear all
+
+--S 266 of 1018
+t0:=F^(e+f*(a+b*x)/(c+d*x))/(g+h*x)^2
+--R 
+--R
+--R         (b f + d e)x + a f + c e
+--R         ------------------------
+--R                  d x + c
+--R        F
+--R   (1)  -------------------------
+--R             2 2             2
+--R            h x  + 2g h x + g
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1018
+--r0:=d*F^(e+b*f/d-(b*c-a*d)*f/(d*(c+d*x)))/(h*(d*g-c*h))-F^(e+f*(a+b*x)/_
+--   (c+d*x))/(h*(g+h*x))+(b*c-a*d)*f*F^(e+f*(b*g-a*h)/(d*g-c*h))*_
+--   Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))*log(F)/(d*g-c*h)^2
+--E 267
+
+--S 268 of 1018
+--a0:=integrate(t0,x)
+--E 268
+
+--S 269 of 1018
+--m0:=a0-r0
+--E 269
+
+--S 270 of 1018
+--d0:=normalize(D(m0,x))
+--E 270
+
+)clear all
+
+--S 271 of 1018
+t0:=F^(e+f*(a+b*x)/(c+d*x))/(g+h*x)^3
+--R 
+--R
+--R           (b f + d e)x + a f + c e
+--R           ------------------------
+--R                    d x + c
+--R          F
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        h x  + 3g h x  + 3g h x + g
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 1018
+--r0:=1/2*d^2*F^(e+b*f/d-(b*c-a*d)*f/(d*(c+d*x)))/(h*(d*g-c*h)^2)-_
+--   1/2*F^(e+f*(a+b*x)/(c+d*x))/(h*(g+h*x)^2)+1/2*d*(b*c-a*d)*f*F^(e+_
+--   b*f/d-(b*c-a*d)*f/(d*(c+d*x)))*log(F)/(d*g-c*h)^3-1/2*(b*c-a*d)*f*_
+--   F^(e+f*(a+b*x)/(c+d*x))*log(F)/((d*g-c*h)^2*(g+h*x))+d*(b*c-a*d)*f*_
+--   F^(e+f*(b*g-a*h)/(d*g-c*h))*Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*_
+--   (c+d*x)))*log(F)/(d*g-c*h)^3+1/2*(b*c-a*d)^2*f^2*F^(e+f*(b*g-a*h)/_
+--   (d*g-c*h))*h*Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))*_
+--   log(F)^2/(d*g-c*h)^4
+--E 272
+
+--S 273 of 1018
+--a0:=integrate(t0,x)
+--E 273
+
+--S 274 of 1018
+--m0:=a0-r0
+--E 274
+
+--S 275 of 1018
+--d0:=normalize(D(m0,x))
+--E 275
+
+)clear all
+
+--S 276 of 1018
+t0:=F^(e+f*(a+b*x)/(c+d*x))/(g+h*x)^4
+--R 
+--R
+--R                (b f + d e)x + a f + c e
+--R                ------------------------
+--R                         d x + c
+--R               F
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        h x  + 4g h x  + 6g h x  + 4g h x + g
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 1018
+--r0:=1/3*d^3*F^(e+b*f/d-(b*c-a*d)*f/(d*(c+d*x)))/(h*(d*g-c*h)^3)-_
+--   1/3*F^(e+f*(a+b*x)/(c+d*x))/(h*(g+h*x)^3)+5/6*d^2*(b*c-a*d)*f*_
+--   F^(e+b*f/d-(b*c-a*d)*f/(d*(c+d*x)))*log(F)/(d*g-c*h)^4-1/6*(b*c-_
+--   a*d)*f*F^(e+f*(a+b*x)/(c+d*x))*log(F)/((d*g-c*h)^2*(g+h*x)^2)-_
+--   2/3*d*(b*c-a*d)*f*F^(e+f*(a+b*x)/(c+d*x))*log(F)/((d*g-c*h)^3*_
+--   (g+h*x))+d^2*(b*c-a*d)*f*F^(e+f*(b*g-a*h)/(d*g-c*h))*Ei(-(b*c-a*d)*_
+--   f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))*log(F)/(d*g-c*h)^4+1/6*d*_
+--   (b*c-a*d)^2*f^2*F^(e+b*f/d-(b*c-a*d)*f/(d*(c+d*x)))*h*log(F)^2/_
+--   (d*g-c*h)^5-1/6*(b*c-a*d)^2*f^2*F^(e+f*(a+b*x)/(c+d*x))*h*log(F)^2/_
+--   ((d*g-c*h)^4*(g+h*x))+d*(b*c-a*d)^2*f^2*F^(e+f*(b*g-a*h)/(d*g-c*h))*_
+--   h*Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))*log(F)^2/_
+--   (d*g-c*h)^5+1/6*(b*c-a*d)^3*f^3*F^(e+f*(b*g-a*h)/(d*g-c*h))*h^2*_
+--   Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))*log(F)^3/(d*g-c*h)^6
+--E 277
+
+--S 278 of 1018
+--a0:=integrate(t0,x)
+--E 278
+
+--S 279 of 1018
+--m0:=a0-r0
+--E 279
+
+--S 280 of 1018
+--d0:=normalize(D(m0,x))
+--E 280
+
+)clear all
+
+--S 281 of 1018
+t0:=f^(a+b*x+c*x^2)*x^3
+--R 
+--R
+--R              2
+--R         3 c x  + b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 1018
+--r0:=-1/2*f^(a+b*x+c*x^2)/(c^2*log(f)^2)+1/8*b^2*f^(a+b*x+c*x^2)/(c^3*_
+--   log(f))-1/4*b*f^(a+b*x+c*x^2)*x/(c^2*log(f))+1/2*f^(a+b*x+c*x^2)*x^2/_
+--   (c*log(f))+3/8*b*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/_
+--   sqrt(c))*sqrt(%pi)/(c^(5/2)*log(f)^(3/2))-1/16*b^3*f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(7/2)*sqrt(log(f)))
+--E 282
+
+--S 283 of 1018
+--a0:=integrate(t0,x)
+--E 283
+
+--S 284 of 1018
+--m0:=a0-r0
+--E 284
+
+--S 285 of 1018
+--d0:=normalize(D(m0,x))
+--E 285
+
+)clear all
+
+--S 286 of 1018
+t0:=f^(a+b*x+c*x^2)*x^2
+--R 
+--R
+--R              2
+--R         2 c x  + b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 1018
+--r0:=-1/4*b*f^(a+b*x+c*x^2)/(c^2*log(f))+1/2*f^(a+b*x+c*x^2)*x/(c*log(f))-_
+--   1/4*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*_
+--   sqrt(%pi)/(c^(3/2)*log(f)^(3/2))+1/8*b^2*f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(5/2)*sqrt(log(f)))
+--E 287
+
+--S 288 of 1018
+--a0:=integrate(t0,x)
+--E 288
+
+--S 289 of 1018
+--m0:=a0-r0
+--E 289
+
+--S 290 of 1018
+--d0:=normalize(D(m0,x))
+--E 290
+
+)clear all
+
+--S 291 of 1018
+t0:=f^(a+b*x+c*x^2)*x
+--R 
+--R
+--R              2
+--R           c x  + b x + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 1018
+--r0:=1/2*f^(a+b*x+c*x^2)/(c*log(f))-1/4*b*f^(a-1/4*b^2/c)*erfi(1/2*_
+--   (b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(3/2)*sqrt(log(f)))
+--E 292
+
+--S 293 of 1018
+--a0:=integrate(t0,x)
+--E 293
+
+--S 294 of 1018
+--m0:=a0-r0
+--E 294
+
+--S 295 of 1018
+--d0:=normalize(D(m0,x))
+--E 295
+
+)clear all
+
+--S 296 of 1018
+t0:=f^(a+b*x+c*x^2)
+--R 
+--R
+--R            2
+--R         c x  + b x + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1018
+--r0:=1/2*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*_
+--   sqrt(%pi)/(sqrt(c)*sqrt(log(f)))
+--E 297
+
+--S 298 of 1018
+--a0:=integrate(t0,x)
+--E 298
+
+--S 299 of 1018
+--m0:=a0-r0
+--E 299
+
+--S 300 of 1018
+--d0:=normalize(D(m0,x))
+--E 300
+
+)clear all
+
+--S 301 of 1018
+t0:=f^(a+b*x+c*x^2)/x
+--R 
+--R
+--R            2
+--R         c x  + b x + a
+--R        f
+--R   (1)  ---------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1018
+--r0:=Int(f^(a+b*x+c*x^2)/x,x)
+--E 302
+
+--S 303 of 1018
+--a0:=integrate(t0,x)
+--E 303
+
+--S 304 of 1018
+--m0:=a0-r0
+--E 304
+
+--S 305 of 1018
+--d0:=normalize(D(m0,x))
+--E 305
+
+)clear all
+
+--S 306 of 1018
+t0:=f^(a+b*x+c*x^2)/x^2
+--R 
+--R
+--R            2
+--R         c x  + b x + a
+--R        f
+--R   (1)  ---------------
+--R                2
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 1018
+--r0:=-f^(a+b*x+c*x^2)/x+b*Int(f^(a+b*x+c*x^2)/x,x)*log(f)+f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)*sqrt(c)*sqrt(log(f))
+--E 307
+
+--S 308 of 1018
+--a0:=integrate(t0,x)
+--E 308
+
+--S 309 of 1018
+--m0:=a0-r0
+--E 309
+
+--S 310 of 1018
+--d0:=normalize(D(m0,x))
+--E 310
+
+)clear all
+
+--S 311 of 1018
+t0:=%e^(a+b*x-c*x^2)*x^3
+--R 
+--R
+--R                 2
+--R         3  - c x  + b x + a
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 1018
+--r0:=-1/8*%e^(a+b*x-c*x^2)*b^2/c^3-1/2*%e^(a+b*x-c*x^2)/c^2-1/4*%e^(a+_
+--   b*x-c*x^2)*b*x/c^2-1/2*%e^(a+b*x-c*x^2)*x^2/c-1/16*%e^(a+1/4*b^2/c)*_
+--   b^3*erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)/c^(7/2)-3/8*%e^(a+1/4*b^2/c)*_
+--   b*erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)/c^(5/2)
+--E 312
+
+--S 313 of 1018
+--a0:=integrate(t0,x)
+--E 313
+
+--S 314 of 1018
+--m0:=a0-r0
+--E 314
+
+--S 315 of 1018
+--d0:=normalize(D(m0,x))
+--E 315
+
+)clear all
+
+--S 316 of 1018
+t0:=%e^(a+b*x-c*x^2)*x^2
+--R 
+--R
+--R                 2
+--R         2  - c x  + b x + a
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 1018
+--r0:=-1/4*%e^(a+b*x-c*x^2)*b/c^2-1/2*%e^(a+b*x-c*x^2)*x/c-1/8*%e^(a+1/4*_
+--   b^2/c)*b^2*erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)/c^(5/2)-1/4*%e^(a+_
+--   1/4*b^2/c)*erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)/c^(3/2)
+--E 317
+
+--S 318 of 1018
+--a0:=integrate(t0,x)
+--E 318
+
+--S 319 of 1018
+--m0:=a0-r0
+--E 319
+
+--S 320 of 1018
+--d0:=normalize(D(m0,x))
+--E 320
+
+)clear all
+
+--S 321 of 1018
+t0:=%e^(a+b*x-c*x^2)*x
+--R 
+--R
+--R                 2
+--R            - c x  + b x + a
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 1018
+--r0:=-1/2*%e^(a+b*x-c*x^2)/c-1/4*%e^(a+1/4*b^2/c)*b*erf(1/2*(b-2*c*x)/_
+--   sqrt(c))*sqrt(%pi)/c^(3/2)
+--E 322
+
+--S 323 of 1018
+--a0:=integrate(t0,x)
+--E 323
+
+--S 324 of 1018
+--m0:=a0-r0
+--E 324
+
+--S 325 of 1018
+--d0:=normalize(D(m0,x))
+--E 325
+
+)clear all
+
+--S 326 of 1018
+t0:=%e^(a+b*x-c*x^2)
+--R 
+--R
+--R               2
+--R          - c x  + b x + a
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 1018
+--r0:=-1/2*%e^(a+1/4*b^2/c)*erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)/sqrt(c)
+--E 327
+
+--S 328 of 1018
+--a0:=integrate(t0,x)
+--E 328
+
+--S 329 of 1018
+--m0:=a0-r0
+--E 329
+
+--S 330 of 1018
+--d0:=normalize(D(m0,x))
+--E 330
+
+)clear all
+
+--S 331 of 1018
+t0:=%e^(a+b*x-c*x^2)/x
+--R 
+--R
+--R               2
+--R          - c x  + b x + a
+--R        %e
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 1018
+--r0:=Int(%e^(a+b*x-c*x^2)/x,x)
+--E 332
+
+--S 333 of 1018
+--a0:=integrate(t0,x)
+--E 333
+
+--S 334 of 1018
+--m0:=a0-r0
+--E 334
+
+--S 335 of 1018
+--d0:=normalize(D(m0,x))
+--E 335
+
+)clear all
+
+--S 336 of 1018
+t0:=%e^(a+b*x-c*x^2)/x^2
+--R 
+--R
+--R               2
+--R          - c x  + b x + a
+--R        %e
+--R   (1)  ------------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 1018
+--r0:=-%e^(a+b*x-c*x^2)/x+b*Int(%e^(a+b*x-c*x^2)/x,x)+%e^(a+1/4*b^2/c)*_
+--   erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)*sqrt(c)
+--E 337
+
+--S 338 of 1018
+--a0:=integrate(t0,x)
+--E 338
+
+--S 339 of 1018
+--m0:=a0-r0
+--E 339
+
+--S 340 of 1018
+--d0:=normalize(D(m0,x))
+--E 340
+
+)clear all
+
+--S 341 of 1018
+t0:=%e^((a+b*x)*(c+d*x))*x^3
+--R 
+--R
+--R                 2
+--R         3  b d x  + (a d + b c)x + a c
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 1018
+--r0:=-1/2*%e^(a*c+(b*c+a*d)*x+b*d*x^2)/(b^2*d^2)+1/8*%e^(a*c+(b*c+a*d)*x+_
+--   b*d*x^2)*(b*c+a*d)^2/(b^3*d^3)-1/4*%e^(a*c+(b*c+a*d)*x+b*d*x^2)*_
+--   (b*c+a*d)*x/(b^2*d^2)+1/2*%e^(a*c+(b*c+a*d)*x+b*d*x^2)*x^2/(b*d)+_
+--   3/8*(b*c+a*d)*erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*_
+--   sqrt(%pi)/(%e^(1/4*(b*c-a*d)^2/(b*d))*b^(5/2)*d^(5/2))-1/16*(b*c+_
+--   a*d)^3*erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*sqrt(%pi)/_
+--   (%e^(1/4*(b*c-a*d)^2/(b*d))*b^(7/2)*d^(7/2))
+--E 342
+
+--S 343 of 1018
+--a0:=integrate(t0,x)
+--E 343
+
+--S 344 of 1018
+--m0:=a0-r0
+--E 344
+
+--S 345 of 1018
+--d0:=normalize(D(m0,x))
+--E 345
+
+)clear all
+
+--S 346 of 1018
+t0:=%e^((a+b*x)*(c+d*x))*x^2
+--R 
+--R
+--R                 2
+--R         2  b d x  + (a d + b c)x + a c
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 1018
+--r0:=-1/4*%e^(a*c+(b*c+a*d)*x+b*d*x^2)*(b*c+a*d)/(b^2*d^2)+1/2*%e^(a*c+_
+--   (b*c+a*d)*x+b*d*x^2)*x/(b*d)-1/4*erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*_
+--   sqrt(d)))*sqrt(%pi)/(%e^(1/4*(b*c-a*d)^2/(b*d))*b^(3/2)*d^(3/2))+_
+--   1/8*(b*c+a*d)^2*erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*_
+--   sqrt(%pi)/(%e^(1/4*(b*c-a*d)^2/(b*d))*b^(5/2)*d^(5/2))
+--E 347
+
+--S 348 of 1018
+--a0:=integrate(t0,x)
+--E 348
+
+--S 349 of 1018
+--m0:=a0-r0
+--E 349
+
+--S 350 of 1018
+--d0:=normalize(D(m0,x))
+--E 350
+
+)clear all
+
+--S 351 of 1018
+t0:=%e^((a+b*x)*(c+d*x))*x
+--R 
+--R
+--R                 2
+--R            b d x  + (a d + b c)x + a c
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 1018
+--r0:=1/2*%e^(a*c+(b*c+a*d)*x+b*d*x^2)/(b*d)-1/4*(b*c+a*d)*erfi(1/2*(b*c+_
+--   a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*sqrt(%pi)/(%e^(1/4*(b*c-a*d)^2/_
+--   (b*d))*b^(3/2)*d^(3/2))
+--E 352
+
+--S 353 of 1018
+--a0:=integrate(t0,x)
+--E 353
+
+--S 354 of 1018
+--m0:=a0-r0
+--E 354
+
+--S 355 of 1018
+--d0:=normalize(D(m0,x))
+--E 355
+
+)clear all
+
+--S 356 of 1018
+t0:=%e^((a+b*x)*(c+d*x))
+--R 
+--R
+--R               2
+--R          b d x  + (a d + b c)x + a c
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 1018
+--r0:=1/2*erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*sqrt(%pi)/_
+--   (%e^(1/4*(b*c-a*d)^2/(b*d))*sqrt(b)*sqrt(d))
+--E 357
+
+--S 358 of 1018
+--a0:=integrate(t0,x)
+--E 358
+
+--S 359 of 1018
+--m0:=a0-r0
+--E 359
+
+--S 360 of 1018
+--d0:=normalize(D(m0,x))
+--E 360
+
+)clear all
+
+--S 361 of 1018
+t0:=%e^((a+b*x)*(c+d*x))/x
+--R 
+--R
+--R               2
+--R          b d x  + (a d + b c)x + a c
+--R        %e
+--R   (1)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 1018
+--r0:=Int(%e^(a*c+(b*c+a*d)*x+b*d*x^2)/x,x)
+--E 362
+
+--S 363 of 1018
+--a0:=integrate(t0,x)
+--E 363
+
+--S 364 of 1018
+--m0:=a0-r0
+--E 364
+
+--S 365 of 1018
+--d0:=normalize(D(m0,x))
+--E 365
+
+)clear all
+
+--S 366 of 1018
+t0:=%e^((a+b*x)*(c+d*x))/x^2
+--R 
+--R
+--R               2
+--R          b d x  + (a d + b c)x + a c
+--R        %e
+--R   (1)  -----------------------------
+--R                       2
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 1018
+--r0:=-%e^(a*c+(b*c+a*d)*x+b*d*x^2)/x+(b*c+a*d)*Int(%e^(a*c+(b*c+a*d)*x+_
+--   b*d*x^2)/x,x)+erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*_
+--   sqrt(%pi)*sqrt(b)*sqrt(d)/%e^(1/4*(b*c-a*d)^2/(b*d))
+--E 367
+
+--S 368 of 1018
+--a0:=integrate(t0,x)
+--E 368
+
+--S 369 of 1018
+--m0:=a0-r0
+--E 369
+
+--S 370 of 1018
+--d0:=normalize(D(m0,x))
+--E 370
+
+)clear all
+
+--S 371 of 1018
+t0:=f^(a+b*x+c*x^2)*(d+e*x)^3
+--R 
+--R
+--R                                          2
+--R          3 3       2 2     2       3  c x  + b x + a
+--R   (1)  (e x  + 3d e x  + 3d e x + d )f
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1018
+--r0:=-1/2*e^3*f^(a+b*x+c*x^2)/(c^2*log(f)^2)+1/8*e*(2*c*d-b*e)^2*f^(a+b*x+_
+--   c*x^2)/(c^3*log(f))+1/4*e*(2*c*d-b*e)*f^(a+b*x+c*x^2)*(d+e*x)/(c^2*_
+--   log(f))+1/2*e*f^(a+b*x+c*x^2)*(d+e*x)^2/(c*log(f))-3/8*e^2*(2*c*d-_
+--   b*e)*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*_
+--   sqrt(%pi)/(c^(5/2)*log(f)^(3/2))+1/16*(2*c*d-b*e)^3*f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(7/2)*sqrt(log(f)))
+--E 372
+
+--S 373 of 1018
+--a0:=integrate(t0,x)
+--E 373
+
+--S 374 of 1018
+--m0:=a0-r0
+--E 374
+
+--S 375 of 1018
+--d0:=normalize(D(m0,x))
+--E 375
+
+)clear all
+
+--S 376 of 1018
+t0:=f^(a+b*x+c*x^2)*(d+e*x)^2
+--R 
+--R
+--R                                2
+--R          2 2             2  c x  + b x + a
+--R   (1)  (e x  + 2d e x + d )f
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1018
+--r0:=1/4*e*(2*c*d-b*e)*f^(a+b*x+c*x^2)/(c^2*log(f))+1/2*e*f^(a+b*x+c*x^2)*_
+--   (d+e*x)/(c*log(f))-1/4*e^2*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*_
+--   sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(3/2)*log(f)^(3/2))+1/8*(2*c*d-_
+--   b*e)^2*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*_
+--   sqrt(%pi)/(c^(5/2)*sqrt(log(f)))
+--E 377
+
+--S 378 of 1018
+--a0:=integrate(t0,x)
+--E 378
+
+--S 379 of 1018
+--m0:=a0-r0
+--E 379
+
+--S 380 of 1018
+--d0:=normalize(D(m0,x))
+--E 380
+
+)clear all
+
+--S 381 of 1018
+t0:=f^(a+b*x+c*x^2)*(d+e*x)
+--R 
+--R
+--R                     2
+--R                  c x  + b x + a
+--R   (1)  (e x + d)f
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 1018
+--r0:=1/2*e*f^(a+b*x+c*x^2)/(c*log(f))+1/4*(2*c*d-b*e)*f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(3/2)*sqrt(log(f)))
+--E 382
+
+--S 383 of 1018
+--a0:=integrate(t0,x)
+--E 383
+
+--S 384 of 1018
+--m0:=a0-r0
+--E 384
+
+--S 385 of 1018
+--d0:=normalize(D(m0,x))
+--E 385
+
+)clear all
+
+--S 386 of 1018
+t0:=f^(a+b*x+c*x^2)/(d+e*x)
+--R 
+--R
+--R            2
+--R         c x  + b x + a
+--R        f
+--R   (1)  ---------------
+--R            e x + d
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 1018
+--r0:=Int(f^(a+b*x+c*x^2)/(d+e*x),x)
+--E 387
+
+--S 388 of 1018
+--a0:=integrate(t0,x)
+--E 388
+
+--S 389 of 1018
+--m0:=a0-r0
+--E 389
+
+--S 390 of 1018
+--d0:=normalize(D(m0,x))
+--E 390
+
+)clear all
+
+--S 391 of 1018
+t0:=f^(a+b*x+c*x^2)/(d+e*x)^2
+--R 
+--R
+--R              2
+--R           c x  + b x + a
+--R          f
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1018
+--r0:=-f^(a+b*x+c*x^2)/(e*(d+e*x))-(2*c*d-b*e)*Int(f^(a+b*x+c*x^2)/_
+--   (d+e*x),x)*log(f)/e^2+f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*_
+--   sqrt(log(f))/sqrt(c))*sqrt(%pi)*sqrt(c)*sqrt(log(f))/e^2
+--E 392
+
+--S 393 of 1018
+--a0:=integrate(t0,x)
+--E 393
+
+--S 394 of 1018
+--m0:=a0-r0
+--E 394
+
+--S 395 of 1018
+--d0:=normalize(D(m0,x))
+--E 395
+
+)clear all
+
+--S 396 of 1018
+t0:=f^(a+b*x+c*x^2)/(d+e*x)^3
+--R 
+--R
+--R                   2
+--R                c x  + b x + a
+--R               f
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 396
+
+--S 397 of 1018
+--r0:=-1/2*f^(a+b*x+c*x^2)/(e*(d+e*x)^2)+1/2*(2*c*d-b*e)*f^(a+b*x+c*x^2)*_
+--   log(f)/(e^3*(d+e*x))+c*Int(f^(a+b*x+c*x^2)/(d+e*x),x)*log(f)/e^2+_
+--   1/2*(2*c*d-b*e)^2*Int(f^(a+b*x+c*x^2)/(d+e*x),x)*log(f)^2/e^4-_
+--   1/2*(2*c*d-b*e)*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/_
+--   sqrt(c))*log(f)^(3/2)*sqrt(%pi)*sqrt(c)/e^4
+--E 397
+
+--S 398 of 1018
+--a0:=integrate(t0,x)
+--E 398
+
+--S 399 of 1018
+--m0:=a0-r0
+--E 399
+
+--S 400 of 1018
+--d0:=normalize(D(m0,x))
+--E 400
+
+)clear all
+
+--S 401 of 1018
+t0:=f^(a+b*x+c*x^2)*(b+2*c*x)^3
+--R 
+--R
+--R                                            2
+--R           3 3        2 2     2       3  c x  + b x + a
+--R   (1)  (8c x  + 12b c x  + 6b c x + b )f
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 1018
+r0:=-4*c*f^(a+b*x+c*x^2)/log(f)^2+f^(a+b*x+c*x^2)*(b+2*c*x)^2/log(f)
+--R 
+--R
+--R                                              2
+--R            2 2             2              c x  + b x + a
+--R        ((4c x  + 4b c x + b )log(f) - 4c)f
+--R   (2)  -------------------------------------------------
+--R                                   2
+--R                             log(f)
+--R                                                    Type: Expression(Integer)
+--E 402
+
+--S 403 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                2
+--R            2 2             2               (c x  + b x + a)log(f)
+--R        ((4c x  + 4b c x + b )log(f) - 4c)%e
+--R   (3)  ----------------------------------------------------------
+--R                                        2
+--R                                  log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 403
+
+--S 404 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               2
+--R           2 2             2               (c x  + b x + a)log(f)
+--R       ((4c x  + 4b c x + b )log(f) - 4c)%e
+--R     + 
+--R                                               2
+--R             2 2             2              c x  + b x + a
+--R       ((- 4c x  - 4b c x - b )log(f) + 4c)f
+--R  /
+--R           2
+--R     log(f)
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 1018
+t0:=f^(a+b*x+c*x^2)*(b+2*c*x)^2
+--R 
+--R
+--R                                 2
+--R           2 2             2  c x  + b x + a
+--R   (1)  (4c x  + 4b c x + b )f
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 1018
+--r0:=f^(a+b*x+c*x^2)*(b+2*c*x)/log(f)-f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*_
+--   sqrt(log(f))/sqrt(c))*sqrt(%pi)*sqrt(c)/log(f)^(3/2)
+--E 407
+
+--S 408 of 1018
+--a0:=integrate(t0,x)
+--E 408
+
+--S 409 of 1018
+--m0:=a0-r0
+--E 409
+
+--S 410 of 1018
+--d0:=normalize(D(m0,x))
+--E 410
+
+)clear all
+
+--S 411 of 1018
+t0:=f^(a+b*x+c*x^2)*(b+2*c*x)
+--R 
+--R
+--R                      2
+--R                   c x  + b x + a
+--R   (1)  (2c x + b)f
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 1018
+r0:=f^(a+b*x+c*x^2)/log(f)
+--R 
+--R
+--R            2
+--R         c x  + b x + a
+--R        f
+--R   (2)  ---------------
+--R             log(f)
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R          (c x  + b x + a)log(f)
+--R        %e
+--R   (3)  ------------------------
+--R                 log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 413
+
+--S 414 of 1018
+m0:=a0-r0
+--R 
+--R
+--R              2                        2
+--R          (c x  + b x + a)log(f)    c x  + b x + a
+--R        %e                       - f
+--R   (4)  ------------------------------------------
+--R                          log(f)
+--R                                                    Type: Expression(Integer)
+--E 414
+
+--S 415 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 415
+
+)clear all
+
+--S 416 of 1018
+t0:=f^(a+b*x+c*x^2)/(b+2*c*x)
+--R 
+--R
+--R            2
+--R         c x  + b x + a
+--R        f
+--R   (1)  ---------------
+--R            2c x + b
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 1018
+--r0:=1/4*f^(a-1/4*b^2/c)*Ei(1/4*(b+2*c*x)^2*log(f)/c)/c
+--E 417
+
+--S 418 of 1018
+--a0:=integrate(t0,x)
+--E 418
+
+--S 419 of 1018
+--m0:=a0-r0
+--E 419
+
+--S 420 of 1018
+--d0:=normalize(D(m0,x))
+--E 420
+
+)clear all
+
+--S 421 of 1018
+t0:=f^(a+b*x+c*x^2)/(b+2*c*x)^2
+--R 
+--R
+--R              2
+--R           c x  + b x + a
+--R          f
+--R   (1)  -------------------
+--R          2 2             2
+--R        4c x  + 4b c x + b
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 1018
+--r0:=-1/2*f^(a+b*x+c*x^2)/(c*(b+2*c*x))+1/4*f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)*sqrt(log(f))/c^(3/2)
+--E 422
+
+--S 423 of 1018
+--a0:=integrate(t0,x)
+--E 423
+
+--S 424 of 1018
+--m0:=a0-r0
+--E 424
+
+--S 425 of 1018
+--d0:=normalize(D(m0,x))
+--E 425
+
+)clear all
+
+--S 426 of 1018
+t0:=f^(a+b*x+c*x^2)/(b+2*c*x)^3
+--R 
+--R
+--R                    2
+--R                 c x  + b x + a
+--R                f
+--R   (1)  ------------------------------
+--R          3 3        2 2     2       3
+--R        8c x  + 12b c x  + 6b c x + b
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 1018
+--r0:=-1/4*f^(a+b*x+c*x^2)/(c*(b+2*c*x)^2)+1/16*f^(a-1/4*b^2/c)*_
+--   Ei(1/4*(b+2*c*x)^2*log(f)/c)*log(f)/c^2
+--E 427
+
+--S 428 of 1018
+--a0:=integrate(t0,x)
+--E 428
+
+--S 429 of 1018
+--m0:=a0-r0
+--E 429
+
+--S 430 of 1018
+--d0:=normalize(D(m0,x))
+--E 430
+
+)clear all
+
+--S 431 of 1018
+t0:=f^(b*x+c*x^2)*(b+2*c*x)^3
+--R 
+--R
+--R                                            2
+--R           3 3        2 2     2       3  c x  + b x
+--R   (1)  (8c x  + 12b c x  + 6b c x + b )f
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1018
+r0:=-4*c*f^(b*x+c*x^2)/log(f)^2+f^(b*x+c*x^2)*(b+2*c*x)^2/log(f)
+--R 
+--R
+--R                                              2
+--R            2 2             2              c x  + b x
+--R        ((4c x  + 4b c x + b )log(f) - 4c)f
+--R   (2)  ---------------------------------------------
+--R                                 2
+--R                           log(f)
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                2
+--R            2 2             2               (c x  + b x)log(f)
+--R        ((4c x  + 4b c x + b )log(f) - 4c)%e
+--R   (3)  ------------------------------------------------------
+--R                                      2
+--R                                log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 433
+
+--S 434 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               2
+--R           2 2             2               (c x  + b x)log(f)
+--R       ((4c x  + 4b c x + b )log(f) - 4c)%e
+--R     + 
+--R                                               2
+--R             2 2             2              c x  + b x
+--R       ((- 4c x  - 4b c x - b )log(f) + 4c)f
+--R  /
+--R           2
+--R     log(f)
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 1018
+t0:=f^(b*x+c*x^2)*(b+2*c*x)^2
+--R 
+--R
+--R                                 2
+--R           2 2             2  c x  + b x
+--R   (1)  (4c x  + 4b c x + b )f
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 1018
+--r0:=f^(b*x+c*x^2)*(b+2*c*x)/log(f)-erfi(1/2*(b+2*c*x)*sqrt(log(f))/_
+--   sqrt(c))*sqrt(%pi)*sqrt(c)/(f^(1/4*b^2/c)*log(f)^(3/2))
+--E 437
+
+--S 438 of 1018
+--a0:=integrate(t0,x)
+--E 438
+
+--S 439 of 1018
+--m0:=a0-r0
+--E 439
+
+--S 440 of 1018
+--d0:=normalize(D(m0,x))
+--E 440
+
+)clear all
+
+--S 441 of 1018
+t0:=f^(b*x+c*x^2)*(b+2*c*x)
+--R 
+--R
+--R                      2
+--R                   c x  + b x
+--R   (1)  (2c x + b)f
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 1018
+r0:=f^(b*x+c*x^2)/log(f)
+--R 
+--R
+--R            2
+--R         c x  + b x
+--R        f
+--R   (2)  -----------
+--R           log(f)
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2
+--R          (c x  + b x)log(f)
+--R        %e
+--R   (3)  --------------------
+--R               log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 443
+
+--S 444 of 1018
+m0:=a0-r0
+--R 
+--R
+--R              2                    2
+--R          (c x  + b x)log(f)    c x  + b x
+--R        %e                   - f
+--R   (4)  ----------------------------------
+--R                      log(f)
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 445
+
+)clear all
+
+--S 446 of 1018
+t0:=f^(b*x+c*x^2)/(b+2*c*x)
+--R 
+--R
+--R            2
+--R         c x  + b x
+--R        f
+--R   (1)  -----------
+--R          2c x + b
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1018
+--r0:=1/4*Ei(1/4*(b+2*c*x)^2*log(f)/c)/(c*f^(1/4*b^2/c))
+--E 447
+
+--S 448 of 1018
+--a0:=integrate(t0,x)
+--E 448
+
+--S 449 of 1018
+--m0:=a0-r0
+--E 449
+
+--S 450 of 1018
+--d0:=normalize(D(m0,x))
+--E 450
+
+)clear all
+
+--S 451 of 1018
+t0:=f^(b*x+c*x^2)/(b+2*c*x)^2
+--R 
+--R
+--R                2
+--R             c x  + b x
+--R            f
+--R   (1)  -------------------
+--R          2 2             2
+--R        4c x  + 4b c x + b
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 1018
+--r0:=-1/2*f^(b*x+c*x^2)/(c*(b+2*c*x))+1/4*erfi(1/2*(b+2*c*x)*_
+--   sqrt(log(f))/sqrt(c))*sqrt(%pi)*sqrt(log(f))/(c^(3/2)*f^(1/4*b^2/c))
+--E 452
+
+--S 453 of 1018
+--a0:=integrate(t0,x)
+--E 453
+
+--S 454 of 1018
+--m0:=a0-r0
+--E 454
+
+--S 455 of 1018
+--d0:=normalize(D(m0,x))
+--E 455
+
+)clear all
+
+--S 456 of 1018
+t0:=f^(b*x+c*x^2)/(b+2*c*x)^3
+--R 
+--R
+--R                      2
+--R                   c x  + b x
+--R                  f
+--R   (1)  ------------------------------
+--R          3 3        2 2     2       3
+--R        8c x  + 12b c x  + 6b c x + b
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 1018
+--r0:=-1/4*f^(b*x+c*x^2)/(c*(b+2*c*x)^2)+1/16*Ei(1/4*(b+2*c*x)^2*_
+--   log(f)/c)*log(f)/(c^2*f^(1/4*b^2/c))
+--E 457
+
+--S 458 of 1018
+--a0:=integrate(t0,x)
+--E 458
+
+--S 459 of 1018
+--m0:=a0-r0
+--E 459
+
+--S 460 of 1018
+--d0:=normalize(D(m0,x))
+--E 460
+
+)clear all
+
+--S 461 of 1018
+t0:=x^3*sqrt(%e^(a+b*x))
+--R 
+--R
+--R           +---------+
+--R         3 |  b x + a
+--R   (1)  x \|%e
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 1018
+r0:=-96*sqrt(%e^(a+b*x))/b^4+48*x*sqrt(%e^(a+b*x))/b^3-12*x^2*_
+   sqrt(%e^(a+b*x))/b^2+2*x^3*sqrt(%e^(a+b*x))/b
+--R 
+--R
+--R                                      +---------+
+--R           3 3      2 2               |  b x + a
+--R        (2b x  - 12b x  + 48b x - 96)\|%e
+--R   (2)  -----------------------------------------
+--R                             4
+--R                            b
+--R                                                    Type: Expression(Integer)
+--E 462
+
+-- integrate: implementation incomplete (constant residues)
+--S 463 of 1018
+--a0:=integrate(t0,x)
+--E 463
+
+--S 464 of 1018
+--m0:=a0-r0
+--E 464
+
+--S 465 of 1018
+--d0:=normalize(D(m0,x))
+--E 465
+
+)clear all
+
+--S 466 of 1018
+t0:=x^2*sqrt(%e^(a+b*x))
+--R 
+--R
+--R           +---------+
+--R         2 |  b x + a
+--R   (1)  x \|%e
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 1018
+r0:=16*sqrt(%e^(a+b*x))/b^3-8*x*sqrt(%e^(a+b*x))/b^2+2*x^2*sqrt(%e^(a+b*x))/b
+--R 
+--R
+--R                            +---------+
+--R           2 2              |  b x + a
+--R        (2b x  - 8b x + 16)\|%e
+--R   (2)  -------------------------------
+--R                        3
+--R                       b
+--R                                                    Type: Expression(Integer)
+--E 467
+
+-- integrate: implementation incomplete (constant residues)
+--S 468 of 1018
+--a0:=integrate(t0,x)
+--E 468
+
+--S 469 of 1018
+--m0:=a0-r0
+--E 469
+
+--S 470 of 1018
+--d0:=normalize(D(m0,x))
+--E 470
+
+)clear all
+
+--S 471 of 1018
+t0:=x*sqrt(%e^(a+b*x))
+--R 
+--R
+--R          +---------+
+--R          |  b x + a
+--R   (1)  x\|%e
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 1018
+r0:=-4*sqrt(%e^(a+b*x))/b^2+2*x*sqrt(%e^(a+b*x))/b
+--R 
+--R
+--R                   +---------+
+--R                   |  b x + a
+--R        (2b x - 4)\|%e
+--R   (2)  ----------------------
+--R                   2
+--R                  b
+--R                                                    Type: Expression(Integer)
+--E 472
+
+-- integrate: implementation incomplete (constant residues)
+--S 473 of 1018
+--a0:=integrate(t0,x)
+--E 473
+
+--S 474 of 1018
+--m0:=a0-r0
+--E 474
+
+--S 475 of 1018
+--d0:=normalize(D(m0,x))
+--E 475
+
+)clear all
+
+--S 476 of 1018
+t0:=sqrt(%e^(a+b*x))
+--R 
+--R
+--R         +---------+
+--R         |  b x + a
+--R   (1)  \|%e
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 1018
+r0:=2*sqrt(%e^(a+b*x))/b
+--R 
+--R
+--R          +---------+
+--R          |  b x + a
+--R        2\|%e
+--R   (2)  -------------
+--R              b
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +---------+
+--R          |  b x + a
+--R        2\|%e
+--R   (3)  -------------
+--R              b
+--R                                         Type: Union(Expression(Integer),...)
+--E 478
+
+--S 479 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 1018
+t0:=sqrt(%e^(a+b*x))/x
+--R 
+--R
+--R         +---------+
+--R         |  b x + a
+--R        \|%e
+--R   (1)  ------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 1018
+--r0:=Ei(1/2*b*x)*sqrt(%e^(a+b*x))/%e^(1/2*b*x)
+--E 482
+
+--S 483 of 1018
+--a0:=integrate(t0,x)
+--E 483
+
+--S 484 of 1018
+--m0:=a0-r0
+--E 484
+
+--S 485 of 1018
+--d0:=normalize(D(m0,x))
+--E 485
+
+)clear all
+
+--S 486 of 1018
+t0:=sqrt(%e^(a+b*x))/x^2
+--R 
+--R
+--R         +---------+
+--R         |  b x + a
+--R        \|%e
+--R   (1)  ------------
+--R              2
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 1018
+--r0:=-sqrt(%e^(a+b*x))/x+1/2*b*Ei(1/2*b*x)*sqrt(%e^(a+b*x))/%e^(1/2*b*x)
+--E 487
+
+--S 488 of 1018
+--a0:=integrate(t0,x)
+--E 488
+
+--S 489 of 1018
+--m0:=a0-r0
+--E 489
+
+--S 490 of 1018
+--d0:=normalize(D(m0,x))
+--E 490
+
+)clear all
+
+--S 491 of 1018
+t0:=sqrt(%e^(a+b*x))/x^3
+--R 
+--R
+--R         +---------+
+--R         |  b x + a
+--R        \|%e
+--R   (1)  ------------
+--R              3
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 1018
+--r0:=-1/2*sqrt(%e^(a+b*x))/x^2-1/4*b*sqrt(%e^(a+b*x))/x+1/8*b^2*_
+--   Ei(1/2*b*x)*sqrt(%e^(a+b*x))/%e^(1/2*b*x)
+--E 492
+
+--S 493 of 1018
+--a0:=integrate(t0,x)
+--E 493
+
+--S 494 of 1018
+--m0:=a0-r0
+--E 494
+
+--S 495 of 1018
+--d0:=normalize(D(m0,x))
+--E 495
+
+)clear all
+
+--S 496 of 1018
+t0:=1/((a+%e^(c+d*x)*b)*x)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R              d x + c
+--R        b x %e        + a x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 1018
+--r0:=Int(1/((a+%e^(c+d*x)*b)*x),x)
+--E 497
+
+--S 498 of 1018
+--a0:=integrate(t0,x)
+--E 498
+
+--S 499 of 1018
+--m0:=a0-r0
+--E 499
+
+--S 500 of 1018
+--d0:=normalize(D(m0,x))
+--E 500
+
+)clear all
+
+--S 501 of 1018
+t0:=1/(a+%e^(c+d*x)*b)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R            d x + c
+--R        b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 1018
+r0:=x/a-log(a+%e^(c+d*x)*b)/(a*d)
+--R 
+--R
+--R                  d x + c
+--R        - log(b %e        + a) + d x
+--R   (2)  ----------------------------
+--R                     a d
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  d x + c
+--R        - log(b %e        + a) + d x
+--R   (3)  ----------------------------
+--R                     a d
+--R                                         Type: Union(Expression(Integer),...)
+--E 503
+
+--S 504 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+--S 505 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 505
+
+)clear all
+
+--S 506 of 1018
+t0:=x/(a+%e^(c+d*x)*b)
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R            d x + c
+--R        b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 1018
+--r0:=1/2*x^2/a-x*log(1+%e^(c+d*x)*b/a)/(a*d)-polylog(2,_
+--   -%e^(c+d*x)*b/a)/(a*d^2)
+--E 507
+
+--S 508 of 1018
+--a0:=integrate(t0,x)
+--E 508
+
+--S 509 of 1018
+--m0:=a0-r0
+--E 509
+
+--S 510 of 1018
+--d0:=normalize(D(m0,x))
+--E 510
+
+)clear all
+
+--S 511 of 1018
+t0:=x^2/(a+%e^(c+d*x)*b)
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R            d x + c
+--R        b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 1018
+--r0:=1/3*x^3/a-x^2*log(1+%e^(c+d*x)*b/a)/(a*d)-2*x*polylog(2,_
+--   -%e^(c+d*x)*b/a)/(a*d^2)+2*polylog(3,-%e^(c+d*x)*b/a)/(a*d^3)
+--E 512
+
+--S 513 of 1018
+--a0:=integrate(t0,x)
+--E 513
+
+--S 514 of 1018
+--m0:=a0-r0
+--E 514
+
+--S 515 of 1018
+--d0:=normalize(D(m0,x))
+--E 515
+
+)clear all
+
+--S 516 of 1018
+t0:=x^3/(a+%e^(c+d*x)*b)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R            d x + c
+--R        b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 1018
+--r0:=1/4*x^4/a-x^3*log(1+%e^(c+d*x)*b/a)/(a*d)-3*x^2*polylog(2,_
+--   -%e^(c+d*x)*b/a)/(a*d^2)+6*x*polylog(3,-%e^(c+d*x)*b/a)/(a*d^3)-_
+--   6*polylog(4,-%e^(c+d*x)*b/a)/(a*d^4)
+--E 517
+
+--S 518 of 1018
+--a0:=integrate(t0,x)
+--E 518
+
+--S 519 of 1018
+--m0:=a0-r0
+--E 519
+
+--S 520 of 1018
+--d0:=normalize(D(m0,x))
+--E 520
+
+)clear all
+
+--S 521 of 1018
+t0:=1/(a+%e^(c-d*x)*b)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R            - d x + c
+--R        b %e          + a
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 1018
+r0:=x/a+log(a+%e^(c-d*x)*b)/(a*d)
+--R 
+--R
+--R                - d x + c
+--R        log(b %e          + a) + d x
+--R   (2)  ----------------------------
+--R                     a d
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                - d x + c
+--R        log(b %e          + a) + d x
+--R   (3)  ----------------------------
+--R                     a d
+--R                                         Type: Union(Expression(Integer),...)
+--E 523
+
+--S 524 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 1018
+t0:=1/(a+%e^(-c-d*x)*b)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R            - d x - c
+--R        b %e          + a
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 1018
+r0:=x/a+log(a+%e^(-c-d*x)*b)/(a*d)
+--R 
+--R
+--R                - d x - c
+--R        log(b %e          + a) + d x
+--R   (2)  ----------------------------
+--R                     a d
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                - d x - c
+--R        log(b %e          + a) + d x
+--R   (3)  ----------------------------
+--R                     a d
+--R                                         Type: Union(Expression(Integer),...)
+--E 528
+
+--S 529 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 530
+
+)clear all
+
+--S 531 of 1018
+t0:=1/((a+%e^(c+d*x)*b)^2*x)
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R         2     d x + c 2            d x + c    2
+--R        b x (%e       )  + 2a b x %e        + a x
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 1018
+--r0:=Int(1/((a+%e^(c+d*x)*b)^2*x),x)
+--E 532
+
+--S 533 of 1018
+--a0:=integrate(t0,x)
+--E 533
+
+--S 534 of 1018
+--m0:=a0-r0
+--E 534
+
+--S 535 of 1018
+--d0:=normalize(D(m0,x))
+--E 535
+
+)clear all
+
+--S 536 of 1018
+t0:=1/(a+%e^(c+d*x)*b)^2
+--R 
+--R
+--R                          1
+--R   (1)  ------------------------------------
+--R         2   d x + c 2          d x + c    2
+--R        b (%e       )  + 2a b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1018
+r0:=1/(a*(a+%e^(c+d*x)*b)*d)+x/a^2-log(a+%e^(c+d*x)*b)/(a^2*d)
+--R 
+--R
+--R               d x + c             d x + c                d x + c
+--R        (- b %e        - a)log(b %e        + a) + b d x %e        + a d x + a
+--R   (2)  ---------------------------------------------------------------------
+--R                                 2      d x + c    3
+--R                                a b d %e        + a d
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R               d x + c             d x + c                d x + c
+--R        (- b %e        - a)log(b %e        + a) + b d x %e        + a d x + a
+--R   (3)  ---------------------------------------------------------------------
+--R                                 2      d x + c    3
+--R                                a b d %e        + a d
+--R                                         Type: Union(Expression(Integer),...)
+--E 538
+
+--S 539 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 1018
+t0:=x/(a+%e^(c+d*x)*b)^2
+--R 
+--R
+--R                          x
+--R   (1)  ------------------------------------
+--R         2   d x + c 2          d x + c    2
+--R        b (%e       )  + 2a b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 1018
+--r0:=-x/(a^2*d)+x/(a*(a+%e^(c+d*x)*b)*d)+1/2*x^2/a^2+log(a+%e^(c+d*x)*b)/_
+--   (a^2*d^2)-x*log(1+%e^(c+d*x)*b/a)/(a^2*d)-polylog(2,-%e^(c+d*x)*_
+--   b/a)/(a^2*d^2)
+--E 542
+
+--S 543 of 1018
+--a0:=integrate(t0,x)
+--E 543
+
+--S 544 of 1018
+--m0:=a0-r0
+--E 544
+
+--S 545 of 1018
+--d0:=normalize(D(m0,x))
+--E 545
+
+)clear all
+
+--S 546 of 1018
+t0:=x^2/(a+%e^(c+d*x)*b)^2
+--R 
+--R
+--R                          2
+--R                         x
+--R   (1)  ------------------------------------
+--R         2   d x + c 2          d x + c    2
+--R        b (%e       )  + 2a b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 1018
+--r0:=-x^2/(a^2*d)+x^2/(a*(a+%e^(c+d*x)*b)*d)+1/3*x^3/a^2+2*x*_
+--   log(1+%e^(c+d*x)*b/a)/(a^2*d^2)-x^2*log(1+%e^(c+d*x)*b/a)/(a^2*d)+_
+--   2*polylog(2,-%e^(c+d*x)*b/a)/(a^2*d^3)-2*x*polylog(2,-%e^(c+d*x)*_
+--   b/a)/(a^2*d^2)+2*polylog(3,-%e^(c+d*x)*b/a)/(a^2*d^3)
+--E 547
+
+--S 548 of 1018
+--a0:=integrate(t0,x)
+--E 548
+
+--S 549 of 1018
+--m0:=a0-r0
+--E 549
+
+--S 550 of 1018
+--d0:=normalize(D(m0,x))
+--E 550
+
+)clear all
+
+--S 551 of 1018
+t0:=x^3/(a+%e^(c+d*x)*b)^2
+--R 
+--R
+--R                          3
+--R                         x
+--R   (1)  ------------------------------------
+--R         2   d x + c 2          d x + c    2
+--R        b (%e       )  + 2a b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 1018
+--r0:=-x^3/(a^2*d)+x^3/(a*(a+%e^(c+d*x)*b)*d)+1/4*x^4/a^2+3*x^2*_
+--   log(1+%e^(c+d*x)*b/a)/(a^2*d^2)-x^3*log(1+%e^(c+d*x)*b/a)/(a^2*d)+_
+--   6*x*polylog(2,-%e^(c+d*x)*b/a)/(a^2*d^3)-3*x^2*polylog(2,_
+--   -%e^(c+d*x)*b/a)/(a^2*d^2)-6*polylog(3,-%e^(c+d*x)*b/a)/(a^2*d^4)+_
+--   6*x*polylog(3,-%e^(c+d*x)*b/a)/(a^2*d^3)-6*polylog(4,-%e^(c+_
+--   d*x)*b/a)/(a^2*d^4)
+--E 552
+
+--S 553 of 1018
+--a0:=integrate(t0,x)
+--E 553
+
+--S 554 of 1018
+--m0:=a0-r0
+--E 554
+
+--S 555 of 1018
+--d0:=normalize(D(m0,x))
+--E 555
+
+)clear all
+
+--S 556 of 1018
+t0:=1/(a+%e^(c-d*x)*b)^2
+--R 
+--R
+--R                            1
+--R   (1)  ----------------------------------------
+--R         2   - d x + c 2          - d x + c    2
+--R        b (%e         )  + 2a b %e          + a
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 1018
+r0:=(-1)/(a*(a+%e^(c-d*x)*b)*d)+x/a^2+log(a+%e^(c-d*x)*b)/(a^2*d)
+--R 
+--R
+--R   (2)
+--R        - d x + c             - d x + c                - d x + c
+--R   (b %e          + a)log(b %e          + a) + b d x %e          + a d x - a
+--R   -------------------------------------------------------------------------
+--R                             2      - d x + c    3
+--R                            a b d %e          + a d
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        - d x + c             - d x + c                - d x + c
+--R   (b %e          + a)log(b %e          + a) + b d x %e          + a d x - a
+--R   -------------------------------------------------------------------------
+--R                             2      - d x + c    3
+--R                            a b d %e          + a d
+--R                                         Type: Union(Expression(Integer),...)
+--E 558
+
+--S 559 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 560
+
+)clear all
+
+--S 561 of 1018
+t0:=1/(a+%e^(-c-d*x)*b)^2
+--R 
+--R
+--R                            1
+--R   (1)  ----------------------------------------
+--R         2   - d x - c 2          - d x - c    2
+--R        b (%e         )  + 2a b %e          + a
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 1018
+r0:=(-1)/(a*(a+%e^(-c-d*x)*b)*d)+x/a^2+log(a+%e^(-c-d*x)*b)/(a^2*d)
+--R 
+--R
+--R   (2)
+--R        - d x - c             - d x - c                - d x - c
+--R   (b %e          + a)log(b %e          + a) + b d x %e          + a d x - a
+--R   -------------------------------------------------------------------------
+--R                             2      - d x - c    3
+--R                            a b d %e          + a d
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        - d x - c             - d x - c                - d x - c
+--R   (b %e          + a)log(b %e          + a) + b d x %e          + a d x - a
+--R   -------------------------------------------------------------------------
+--R                             2      - d x - c    3
+--R                            a b d %e          + a d
+--R                                         Type: Union(Expression(Integer),...)
+--E 563
+
+--S 564 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+--S 565 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 565
+
+)clear all
+
+--S 566 of 1018
+t0:=1/((a+%e^(c+d*x)*b)^3*x)
+--R 
+--R
+--R                                       1
+--R   (1)  ---------------------------------------------------------------
+--R         3     d x + c 3       2     d x + c 2     2      d x + c    3
+--R        b x (%e       )  + 3a b x (%e       )  + 3a b x %e        + a x
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1018
+--r0:=Int(1/((a+%e^(c+d*x)*b)^3*x),x)
+--E 567
+
+--S 568 of 1018
+--a0:=integrate(t0,x)
+--E 568
+
+--S 569 of 1018
+--m0:=a0-r0
+--E 569
+
+--S 570 of 1018
+--d0:=normalize(D(m0,x))
+--E 570
+
+)clear all
+
+--S 571 of 1018
+t0:=1/(a+%e^(c+d*x)*b)^3
+--R 
+--R
+--R                                    1
+--R   (1)  --------------------------------------------------------
+--R         3   d x + c 3       2   d x + c 2     2    d x + c    3
+--R        b (%e       )  + 3a b (%e       )  + 3a b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 1018
+r0:=1/2/(a*(a+%e^(c+d*x)*b)^2*d)+1/(a^2*(a+%e^(c+d*x)*b)*d)+x/a^3-_
+   log(a+%e^(c+d*x)*b)/(a^3*d)
+--R 
+--R
+--R   (2)
+--R            2   d x + c 2          d x + c     2         d x + c
+--R       (- 2b (%e       )  - 4a b %e        - 2a )log(b %e        + a)
+--R     + 
+--R         2       d x + c 2                      d x + c     2        2
+--R       2b d x (%e       )  + (4a b d x + 2a b)%e        + 2a d x + 3a
+--R  /
+--R       3 2     d x + c 2     4      d x + c     5
+--R     2a b d (%e       )  + 4a b d %e        + 2a d
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2   d x + c 2          d x + c     2         d x + c
+--R       (- 2b (%e       )  - 4a b %e        - 2a )log(b %e        + a)
+--R     + 
+--R         2       d x + c 2                      d x + c     2        2
+--R       2b d x (%e       )  + (4a b d x + 2a b)%e        + 2a d x + 3a
+--R  /
+--R       3 2     d x + c 2     4      d x + c     5
+--R     2a b d (%e       )  + 4a b d %e        + 2a d
+--R                                         Type: Union(Expression(Integer),...)
+--E 573
+
+--S 574 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 575
+
+)clear all
+
+--S 576 of 1018
+t0:=x/(a+%e^(c+d*x)*b)^3
+--R 
+--R
+--R                                    x
+--R   (1)  --------------------------------------------------------
+--R         3   d x + c 3       2   d x + c 2     2    d x + c    3
+--R        b (%e       )  + 3a b (%e       )  + 3a b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 1018
+--r0:=(-1/2)/(a^2*(a+%e^(c+d*x)*b)*d^2)-3/2*x/(a^3*d)+1/2*x/(a*(a+_
+--   %e^(c+d*x)*b)^2*d)+x/(a^2*(a+%e^(c+d*x)*b)*d)+1/2*x^2/a^3+3/2*_
+--   log(a+%e^(c+d*x)*b)/(a^3*d^2)-x*log(1+%e^(c+d*x)*b/a)/(a^3*d)-_
+--   polylog(2,-%e^(c+d*x)*b/a)/(a^3*d^2)
+--E 577
+
+--S 578 of 1018
+--a0:=integrate(t0,x)
+--E 578
+
+--S 579 of 1018
+--m0:=a0-r0
+--E 579
+
+--S 580 of 1018
+--d0:=normalize(D(m0,x))
+--E 580
+
+)clear all
+
+--S 581 of 1018
+t0:=x^2/(a+%e^(c+d*x)*b)^3
+--R 
+--R
+--R                                    2
+--R                                   x
+--R   (1)  --------------------------------------------------------
+--R         3   d x + c 3       2   d x + c 2     2    d x + c    3
+--R        b (%e       )  + 3a b (%e       )  + 3a b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1018
+--r0:=x/(a^3*d^2)-x/(a^2*(a+%e^(c+d*x)*b)*d^2)-3/2*x^2/(a^3*d)+1/2*x^2/_
+--   (a*(a+%e^(c+d*x)*b)^2*d)+x^2/(a^2*(a+%e^(c+d*x)*b)*d)+1/3*x^3/a^3-_
+--   log(a+%e^(c+d*x)*b)/(a^3*d^3)+3*x*log(1+%e^(c+d*x)*b/a)/(a^3*d^2)-_
+--   x^2*log(1+%e^(c+d*x)*b/a)/(a^3*d)+3*polylog(2,-%e^(c+d*x)*b/a)/_
+--   (a^3*d^3)-2*x*polylog(2,-%e^(c+d*x)*b/a)/(a^3*d^2)+2*polylog(3,_
+--   -%e^(c+d*x)*b/a)/(a^3*d^3)
+--E 582
+
+--S 583 of 1018
+--a0:=integrate(t0,x)
+--E 583
+
+--S 584 of 1018
+--m0:=a0-r0
+--E 584
+
+--S 585 of 1018
+--d0:=normalize(D(m0,x))
+--E 585
+
+)clear all
+
+--S 586 of 1018
+--t0:=1 + (b*E^(c + d*x))/a])/(a^3*d^3) + (9*x^2*Log[1 + _
+--   (b*E^(c + d*x))/a])/(2*a^3*d^2) - (x^3*Log[1 + (b*E^(c + d*x))/a])/_
+--   (a^3*d) - (3*PolyLog[2
+--E 586
+
+--S 587 of 1018
+--r0:= -((b*E^(c + d*x))/a)
+--E 587
+
+--S 588 of 1018
+--a0:=integrate(t0,x)
+--E 588
+
+--S 589 of 1018
+--m0:=a0-r0
+--E 589
+
+--S 590 of 1018
+--d0:=normalize(D(m0,x))
+--E 590
+
+)clear all
+
+--S 591 of 1018
+t0:=1/(a+%e^(c-d*x)*b)^3
+--R 
+--R
+--R                                       1
+--R   (1)  --------------------------------------------------------------
+--R         3   - d x + c 3       2   - d x + c 2     2    - d x + c    3
+--R        b (%e         )  + 3a b (%e         )  + 3a b %e          + a
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 1018
+r0:=(-1/2)/(a*(a+%e^(c-d*x)*b)^2*d)+(-1)/(a^2*(a+%e^(c-d*x)*b)*d)+x/a^3+_
+   log(a+%e^(c-d*x)*b)/(a^3*d)
+--R 
+--R
+--R   (2)
+--R          2   - d x + c 2          - d x + c     2         - d x + c
+--R       (2b (%e         )  + 4a b %e          + 2a )log(b %e          + a)
+--R     + 
+--R         2       - d x + c 2                      - d x + c     2        2
+--R       2b d x (%e         )  + (4a b d x - 2a b)%e          + 2a d x - 3a
+--R  /
+--R       3 2     - d x + c 2     4      - d x + c     5
+--R     2a b d (%e         )  + 4a b d %e          + 2a d
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2   - d x + c 2          - d x + c     2         - d x + c
+--R       (2b (%e         )  + 4a b %e          + 2a )log(b %e          + a)
+--R     + 
+--R         2       - d x + c 2                      - d x + c     2        2
+--R       2b d x (%e         )  + (4a b d x - 2a b)%e          + 2a d x - 3a
+--R  /
+--R       3 2     - d x + c 2     4      - d x + c     5
+--R     2a b d (%e         )  + 4a b d %e          + 2a d
+--R                                         Type: Union(Expression(Integer),...)
+--E 593
+
+--S 594 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 595
+
+)clear all
+
+--S 596 of 1018
+t0:=1/(a+%e^(-c-d*x)*b)^3
+--R 
+--R
+--R                                       1
+--R   (1)  --------------------------------------------------------------
+--R         3   - d x - c 3       2   - d x - c 2     2    - d x - c    3
+--R        b (%e         )  + 3a b (%e         )  + 3a b %e          + a
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1018
+r0:=(-1/2)/(a*(a+%e^(-c-d*x)*b)^2*d)+(-1)/(a^2*(a+%e^(-c-d*x)*b)*d)+_
+   x/a^3+log(a+%e^(-c-d*x)*b)/(a^3*d)
+--R 
+--R
+--R   (2)
+--R          2   - d x - c 2          - d x - c     2         - d x - c
+--R       (2b (%e         )  + 4a b %e          + 2a )log(b %e          + a)
+--R     + 
+--R         2       - d x - c 2                      - d x - c     2        2
+--R       2b d x (%e         )  + (4a b d x - 2a b)%e          + 2a d x - 3a
+--R  /
+--R       3 2     - d x - c 2     4      - d x - c     5
+--R     2a b d (%e         )  + 4a b d %e          + 2a d
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2   - d x - c 2          - d x - c     2         - d x - c
+--R       (2b (%e         )  + 4a b %e          + 2a )log(b %e          + a)
+--R     + 
+--R         2       - d x - c 2                      - d x - c     2        2
+--R       2b d x (%e         )  + (4a b d x - 2a b)%e          + 2a d x - 3a
+--R  /
+--R       3 2     - d x - c 2     4      - d x - c     5
+--R     2a b d (%e         )  + 4a b d %e          + 2a d
+--R                                         Type: Union(Expression(Integer),...)
+--E 598
+
+--S 599 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)clear all
+
+--S 601 of 1018
+t0:=%e^(a+b*x)/(x^2*(c+d*x^2))
+--R 
+--R
+--R           b x + a
+--R         %e
+--R   (1)  -----------
+--R           4      2
+--R        d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 1018
+--r0:=-%e^(a+b*x)/(c*x)+%e^a*b*Ei(b*x)/c+1/2*%e^(a+b*sqrt(-c)/sqrt(d))*_
+--   Ei(-b*(sqrt(-c)-x*sqrt(d))/sqrt(d))*sqrt(d)/(-c)^(3/2)-_
+--   1/2*%e^(a-b*sqrt(-c)/sqrt(d))*Ei(b*(sqrt(-c)+x*sqrt(d))/sqrt(d))*_
+--   sqrt(d)/(-c)^(3/2)
+--E 602
+
+--S 603 of 1018
+--a0:=integrate(t0,x)
+--E 603
+
+--S 604 of 1018
+--m0:=a0-r0
+--E 604
+
+--S 605 of 1018
+--d0:=normalize(D(m0,x))
+--E 605
+
+)clear all
+
+--S 606 of 1018
+t0:=%e^(a+b*x)/(x*(c+d*x^2))
+--R 
+--R
+--R           b x + a
+--R         %e
+--R   (1)  ----------
+--R           3
+--R        d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 1018
+--r0:=%e^a*Ei(b*x)/c-1/2*%e^(a+b*sqrt(-c)/sqrt(d))*Ei(-b*(sqrt(-c)-_
+--   x*sqrt(d))/sqrt(d))/c-1/2*%e^(a-b*sqrt(-c)/sqrt(d))*Ei(b*_
+--   (sqrt(-c)+x*sqrt(d))/sqrt(d))/c
+--E 607
+
+--S 608 of 1018
+--a0:=integrate(t0,x)
+--E 608
+
+--S 609 of 1018
+--m0:=a0-r0
+--E 609
+
+--S 610 of 1018
+--d0:=normalize(D(m0,x))
+--E 610
+
+)clear all
+
+--S 611 of 1018
+t0:=%e^(a+b*x)/(c+d*x^2)
+--R 
+--R
+--R          b x + a
+--R        %e
+--R   (1)  ---------
+--R            2
+--R         d x  + c
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 1018
+--r0:=1/2*%e^(a+b*sqrt(-c)/sqrt(d))*Ei(-b*(sqrt(-c)-x*sqrt(d))/sqrt(d))/_
+--   (sqrt(-c)*sqrt(d))-1/2*%e^(a-b*sqrt(-c)/sqrt(d))*Ei(b*(sqrt(-c)+_
+--   x*sqrt(d))/sqrt(d))/(sqrt(-c)*sqrt(d))
+--E 612
+
+--S 613 of 1018
+--a0:=integrate(t0,x)
+--E 613
+
+--S 614 of 1018
+--m0:=a0-r0
+--E 614
+
+--S 615 of 1018
+--d0:=normalize(D(m0,x))
+--E 615
+
+)clear all
+
+--S 616 of 1018
+t0:=%e^(a+b*x)*x/(c+d*x^2)
+--R 
+--R
+--R            b x + a
+--R        x %e
+--R   (1)  -----------
+--R             2
+--R          d x  + c
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 1018
+--r0:=1/2*%e^(a+b*sqrt(-c)/sqrt(d))*Ei(-b*(sqrt(-c)-x*sqrt(d))/sqrt(d))/d+_
+--   1/2*%e^(a-b*sqrt(-c)/sqrt(d))*Ei(b*(sqrt(-c)+x*sqrt(d))/sqrt(d))/d
+--E 617
+
+--S 618 of 1018
+--a0:=integrate(t0,x)
+--E 618
+
+--S 619 of 1018
+--m0:=a0-r0
+--E 619
+
+--S 620 of 1018
+--d0:=normalize(D(m0,x))
+--E 620
+
+)clear all
+
+--S 621 of 1018
+t0:=%e^(a+b*x)*x^2/(c+d*x^2)
+--R 
+--R
+--R         2  b x + a
+--R        x %e
+--R   (1)  -----------
+--R             2
+--R          d x  + c
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 1018
+--r0:=%e^(a+b*x)/(b*d)+1/2*%e^(a+b*sqrt(-c)/sqrt(d))*Ei(-b*(sqrt(-c)-_
+--   x*sqrt(d))/sqrt(d))*sqrt(-c)/d^(3/2)-1/2*%e^(a-b*sqrt(-c)/sqrt(d))*_
+--   Ei(b*(sqrt(-c)+x*sqrt(d))/sqrt(d))*sqrt(-c)/d^(3/2)
+--E 622
+
+--S 623 of 1018
+--a0:=integrate(t0,x)
+--E 623
+
+--S 624 of 1018
+--m0:=a0-r0
+--E 624
+
+--S 625 of 1018
+--d0:=normalize(D(m0,x))
+--E 625
+
+)clear all
+
+--S 626 of 1018
+t0:=%e^(d+e*x)/(x^2*(a+b*x+c*x^2))
+--R 
+--R
+--R               e x + d
+--R             %e
+--R   (1)  ------------------
+--R           4      3      2
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 1018
+--r0:=-%e^(d+e*x)/(a*x)-%e^d*b*Ei(e*x)/a^2+%e^d*e*Ei(e*x)/a+1/2*_
+--   %e^(d-1/2*e*(b+sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x+sqrt(b^2-_
+--   4*a*c))/c)*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/a^2+1/2*%e^(d-1/2*_
+--   e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x-sqrt(b^2-4*a*c))/c)*_
+--   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/a^2
+--E 627
+
+--S 628 of 1018
+--a0:=integrate(t0,x)
+--E 628
+
+--S 629 of 1018
+--m0:=a0-r0
+--E 629
+
+--S 630 of 1018
+--d0:=normalize(D(m0,x))
+--E 630
+
+)clear all
+
+--S 631 of 1018
+t0:=%e^(d+e*x)/(x*(a+b*x+c*x^2))
+--R 
+--R
+--R              e x + d
+--R            %e
+--R   (1)  -----------------
+--R           3      2
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 1018
+--r0:=%e^d*Ei(e*x)/a-1/2*%e^(d-1/2*e*(b+sqrt(b^2-4*a*c))/c)*Ei(1/2*e*_
+--   (b+2*c*x+sqrt(b^2-4*a*c))/c)*(1-b/sqrt(b^2-4*a*c))/a-1/2*%e^(d-_
+--   1/2*e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x-sqrt(b^2-4*a*c))/c)*_
+--   (1+b/sqrt(b^2-4*a*c))/a
+--E 632
+
+--S 633 of 1018
+--a0:=integrate(t0,x)
+--E 633
+
+--S 634 of 1018
+--m0:=a0-r0
+--E 634
+
+--S 635 of 1018
+--d0:=normalize(D(m0,x))
+--E 635
+
+)clear all
+
+--S 636 of 1018
+t0:=%e^(d+e*x)/(a+b*x+c*x^2)
+--R 
+--R
+--R             e x + d
+--R           %e
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 1018
+--r0:=%e^(d-1/2*e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x-sqrt(b^2-_
+--   4*a*c))/c)/sqrt(b^2-4*a*c)-%e^(d-1/2*e*(b+sqrt(b^2-4*a*c))/c)*_
+--   Ei(1/2*e*(b+2*c*x+sqrt(b^2-4*a*c))/c)/sqrt(b^2-4*a*c)
+--E 637
+
+--S 638 of 1018
+--a0:=integrate(t0,x)
+--E 638
+
+--S 639 of 1018
+--m0:=a0-r0
+--E 639
+
+--S 640 of 1018
+--d0:=normalize(D(m0,x))
+--E 640
+
+)clear all
+
+--S 641 of 1018
+t0:=%e^(d+e*x)*x/(a+b*x+c*x^2)
+--R 
+--R
+--R              e x + d
+--R          x %e
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 1018
+--r0:=1/2*%e^(d-1/2*e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x-_
+--   sqrt(b^2-4*a*c))/c)*(1-b/sqrt(b^2-4*a*c))/c+1/2*%e^(d-1/2*e*(b+_
+--   sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x+sqrt(b^2-4*a*c))/c)*(1+_
+--   b/sqrt(b^2-4*a*c))/c
+--E 642
+
+--S 643 of 1018
+--a0:=integrate(t0,x)
+--E 643
+
+--S 644 of 1018
+--m0:=a0-r0
+--E 644
+
+--S 645 of 1018
+--d0:=normalize(D(m0,x))
+--E 645
+
+)clear all
+
+--S 646 of 1018
+t0:=%e^(d+e*x)*x^2/(a+b*x+c*x^2)
+--R 
+--R
+--R           2  e x + d
+--R          x %e
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 1018
+--r0:=%e^(d+e*x)/(c*e)-1/2*%e^(d-1/2*e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*_
+--   (b+2*c*x-sqrt(b^2-4*a*c))/c)*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/c^2-_
+--   1/2*%e^(d-1/2*e*(b+sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x+sqrt(b^2-_
+--   4*a*c))/c)*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/c^2
+--E 647
+
+--S 648 of 1018
+--a0:=integrate(t0,x)
+--E 648
+
+--S 649 of 1018
+--m0:=a0-r0
+--E 649
+
+--S 650 of 1018
+--d0:=normalize(D(m0,x))
+--E 650
+
+)clear all
+
+--S 651 of 1018
+t0:=%e^(d+e*x)*x^3/(a+b*x+c*x^2)
+--R 
+--R
+--R           3  e x + d
+--R          x %e
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 1018
+--r0:=-%e^(d+e*x)/(c*e^2)-%e^(d+e*x)*b/(c^2*e)+%e^(d+e*x)*x/(c*e)+_
+--   1/2*%e^(d-1/2*e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x-sqrt(b^2-_
+--   4*a*c))/c)*(b^2-a*c-b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/c^3+1/2*%e^(d-_
+--   1/2*e*(b+sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x+sqrt(b^2-4*a*c))/c)*_
+--   (b^2-a*c+b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/c^3
+--E 652
+
+--S 653 of 1018
+--a0:=integrate(t0,x)
+--E 653
+
+--S 654 of 1018
+--m0:=a0-r0
+--E 654
+
+--S 655 of 1018
+--d0:=normalize(D(m0,x))
+--E 655
+
+)clear all
+
+--S 656 of 1018
+t0:=4^x/(a+2^x*b)
+--R 
+--R
+--R            x
+--R           4
+--R   (1)  --------
+--R           x
+--R        b 2  + a
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 1018
+r0:=2^x/(b*log(2))-a*log(a+2^x*b)/(b^2*log(2))
+--R 
+--R
+--R                   x           x
+--R        - a log(b 2  + a) + b 2
+--R   (2)  ------------------------
+--R                 2
+--R                b log(2)
+--R                                                    Type: Expression(Integer)
+--E 657
+
+--S 658 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x     %M
+--R         ++     4
+--R   (3)   |   --------- d%M
+--R        ++      %M
+--R             b 2   + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 658
+
+--S 659 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                   x     %M
+--R         2       ++     4                      x           x
+--R        b log(2) |   --------- d%M  + a log(b 2  + a) - b 2
+--R                ++      %M
+--R                     b 2   + a
+--R   (4)  ----------------------------------------------------
+--R                               2
+--R                              b log(2)
+--R                                                    Type: Expression(Integer)
+--E 659
+
+--S 660 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          x log(4)      x log(2) 2
+--R        %e         - (%e        )
+--R   (5)  --------------------------
+--R                 x log(2)
+--R             b %e         + a
+--R                                                    Type: Expression(Integer)
+--E 660
+
+)clear all
+
+--S 661 of 1018
+t0:=2^(2*x)/(a+2^x*b)
+--R 
+--R
+--R            2x
+--R           2
+--R   (1)  --------
+--R           x
+--R        b 2  + a
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 1018
+r0:=2^x/(b*log(2))-a*log(a+2^x*b)/(b^2*log(2))
+--R 
+--R
+--R                   x           x
+--R        - a log(b 2  + a) + b 2
+--R   (2)  ------------------------
+--R                 2
+--R                b log(2)
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    x log(2)            x log(2)
+--R        - a log(b %e         + a) + b %e
+--R   (3)  ----------------------------------------
+--R                         2
+--R                        b log(2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 663
+
+--S 664 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                 x                  x log(2)           x       x log(2)
+--R        a log(b 2  + a) - a log(b %e         + a) - b 2  + b %e
+--R   (4)  ---------------------------------------------------------------
+--R                                     2
+--R                                    b log(2)
+--R                                                    Type: Expression(Integer)
+--E 664
+
+--S 665 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 665
+
+)clear all
+
+--S 666 of 1018
+t0:=4^x/(a-2^x*b)
+--R 
+--R
+--R              x
+--R             4
+--R   (1)  - --------
+--R             x
+--R          b 2  - a
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 1018
+r0:=-2^x/(b*log(2))-a*log(a-2^x*b)/(b^2*log(2))
+--R 
+--R
+--R                     x           x
+--R        - a log(- b 2  + a) - b 2
+--R   (2)  --------------------------
+--R                  2
+--R                 b log(2)
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x       %M
+--R         ++       4
+--R   (3)   |   - --------- d%M
+--R        ++        %M
+--R               b 2   - a
+--R                                         Type: Union(Expression(Integer),...)
+--E 668
+
+--S 669 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                   x       %M
+--R         2       ++       4                        x           x
+--R        b log(2) |   - --------- d%M  + a log(- b 2  + a) + b 2
+--R                ++        %M
+--R                       b 2   - a
+--R   (4)  --------------------------------------------------------
+--R                                 2
+--R                                b log(2)
+--R                                                    Type: Expression(Integer)
+--E 669
+
+--S 670 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R            x log(4)      x log(2) 2
+--R        - %e         + (%e        )
+--R   (5)  ----------------------------
+--R                  x log(2)
+--R              b %e         - a
+--R                                                    Type: Expression(Integer)
+--E 670
+
+)clear all
+
+--S 671 of 1018
+t0:=2^(2*x)/(a-2^x*b)
+--R 
+--R
+--R              2x
+--R             2
+--R   (1)  - --------
+--R             x
+--R          b 2  - a
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 1018
+r0:=-2^x/(b*log(2))-a*log(a-2^x*b)/(b^2*log(2))
+--R 
+--R
+--R                     x           x
+--R        - a log(- b 2  + a) - b 2
+--R   (2)  --------------------------
+--R                  2
+--R                 b log(2)
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    x log(2)            x log(2)
+--R        - a log(b %e         - a) - b %e
+--R   (3)  ----------------------------------------
+--R                         2
+--R                        b log(2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 673
+
+--S 674 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                    x log(2)                   x           x       x log(2)
+--R        - a log(b %e         - a) + a log(- b 2  + a) + b 2  - b %e
+--R   (4)  -------------------------------------------------------------------
+--R                                       2
+--R                                      b log(2)
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+)clear all
+
+--S 676 of 1018
+t0:=4^x/(a+b/2^x)
+--R 
+--R
+--R           x x
+--R          2 4
+--R   (1)  --------
+--R           x
+--R        a 2  + b
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 1018
+r0:=2^(-1+2*x)/(a*log(2))-2^x*b/(a^2*log(2))+b^2*log(2^x*a+b)/(a^3*log(2))
+--R 
+--R
+--R         2       x         2 2x - 1        x
+--R        b log(a 2  + b) + a 2       - a b 2
+--R   (2)  ------------------------------------
+--R                       3
+--R                      a log(2)
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x    %M %M
+--R         ++    2  4
+--R   (3)   |   --------- d%M
+--R        ++      %M
+--R             a 2   + b
+--R                                         Type: Union(Expression(Integer),...)
+--E 678
+
+--S 679 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                   x    %M %M
+--R         3       ++    2  4            2       x         2 2x - 1        x
+--R        a log(2) |   --------- d%M  - b log(a 2  + b) - a 2       + a b 2
+--R                ++      %M
+--R                     a 2   + b
+--R   (4)  ------------------------------------------------------------------
+--R                                      3
+--R                                     a log(2)
+--R                                                    Type: Expression(Integer)
+--E 679
+
+--S 680 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          x log(2)  x log(4)      x log(2) 3
+--R        %e        %e         - (%e        )
+--R   (5)  ------------------------------------
+--R                      x log(2)
+--R                  a %e         + b
+--R                                                    Type: Expression(Integer)
+--E 680
+
+)clear all
+
+--S 681 of 1018
+t0:=2^(2*x)/(a+b/2^x)
+--R 
+--R
+--R           x 2x
+--R          2 2
+--R   (1)  --------
+--R           x
+--R        a 2  + b
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 1018
+r0:=2^(-1+2*x)/(a*log(2))-2^x*b/(a^2*log(2))+b^2*log(2^x*a+b)/(a^3*log(2))
+--R 
+--R
+--R         2       x         2 2x - 1        x
+--R        b log(a 2  + b) + a 2       - a b 2
+--R   (2)  ------------------------------------
+--R                       3
+--R                      a log(2)
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2        x log(2)         2   x log(2) 2          x log(2)
+--R        2b log(a %e         + b) + a (%e        )  - 2a b %e
+--R   (3)  ------------------------------------------------------------
+--R                                    3
+--R                                  2a log(2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 683
+
+--S 684 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2       x          2        x log(2)          2 2x - 1         x
+--R       - 2b log(a 2  + b) + 2b log(a %e         + b) - 2a 2       + 2a b 2
+--R     + 
+--R        2   x log(2) 2          x log(2)
+--R       a (%e        )  - 2a b %e
+--R  /
+--R       3
+--R     2a log(2)
+--R                                                    Type: Expression(Integer)
+--E 684
+
+--S 685 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 685
+
+)clear all
+
+--S 686 of 1018
+t0:=4^x/(a-b/2^x)
+--R 
+--R
+--R           x x
+--R          2 4
+--R   (1)  --------
+--R           x
+--R        a 2  - b
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 1018
+r0:=2^(-1+2*x)/(a*log(2))+2^x*b/(a^2*log(2))+b^2*log(2^x*a-b)/(a^3*log(2))
+--R 
+--R
+--R         2       x         2 2x - 1        x
+--R        b log(a 2  - b) + a 2       + a b 2
+--R   (2)  ------------------------------------
+--R                       3
+--R                      a log(2)
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x    %M %M
+--R         ++    2  4
+--R   (3)   |   --------- d%M
+--R        ++      %M
+--R             a 2   - b
+--R                                         Type: Union(Expression(Integer),...)
+--E 688
+
+--S 689 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                   x    %M %M
+--R         3       ++    2  4            2       x         2 2x - 1        x
+--R        a log(2) |   --------- d%M  - b log(a 2  - b) - a 2       - a b 2
+--R                ++      %M
+--R                     a 2   - b
+--R   (4)  ------------------------------------------------------------------
+--R                                      3
+--R                                     a log(2)
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R          x log(2)  x log(4)      x log(2) 3
+--R        %e        %e         - (%e        )
+--R   (5)  ------------------------------------
+--R                      x log(2)
+--R                  a %e         - b
+--R                                                    Type: Expression(Integer)
+--E 690
+
+)clear all
+
+--S 691 of 1018
+t0:=2^(2*x)/(a-b/2^x)
+--R 
+--R
+--R           x 2x
+--R          2 2
+--R   (1)  --------
+--R           x
+--R        a 2  - b
+--R                                                    Type: Expression(Integer)
+--E 691
+
+--S 692 of 1018
+r0:=2^(-1+2*x)/(a*log(2))+2^x*b/(a^2*log(2))+b^2*log(2^x*a-b)/(a^3*log(2))
+--R 
+--R
+--R         2       x         2 2x - 1        x
+--R        b log(a 2  - b) + a 2       + a b 2
+--R   (2)  ------------------------------------
+--R                       3
+--R                      a log(2)
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2        x log(2)         2   x log(2) 2          x log(2)
+--R        2b log(a %e         - b) + a (%e        )  + 2a b %e
+--R   (3)  ------------------------------------------------------------
+--R                                    3
+--R                                  2a log(2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 693
+
+--S 694 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2       x          2        x log(2)          2 2x - 1         x
+--R       - 2b log(a 2  - b) + 2b log(a %e         - b) - 2a 2       - 2a b 2
+--R     + 
+--R        2   x log(2) 2          x log(2)
+--R       a (%e        )  + 2a b %e
+--R  /
+--R       3
+--R     2a log(2)
+--R                                                    Type: Expression(Integer)
+--E 694
+
+--S 695 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 695
+
+)clear all
+
+--S 696 of 1018
+t0:=2^x/(a+4^x*b)
+--R 
+--R
+--R            x
+--R           2
+--R   (1)  --------
+--R           x
+--R        b 4  + a
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 1018
+r0:=atan(2^x*sqrt(b)/sqrt(a))/(log(2)*sqrt(a)*sqrt(b))
+--R 
+--R
+--R               x +-+
+--R              2 \|b
+--R         atan(------)
+--R                +-+
+--R               \|a
+--R   (2)  --------------
+--R               +-+ +-+
+--R        log(2)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x     %M
+--R         ++     2
+--R   (3)   |   --------- d%M
+--R        ++      %M
+--R             b 4   + a
+--R                                         Type: Union(Expression(Integer),...)
+--E 698
+
+--S 699 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                         x     %M                 x +-+
+--R               +-+ +-+ ++     2                  2 \|b
+--R        log(2)\|a \|b  |   --------- d%M  - atan(------)
+--R                      ++      %M                   +-+
+--R                           b 4   + a              \|a
+--R   (4)  ------------------------------------------------
+--R                                +-+ +-+
+--R                         log(2)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 699
+
+--S 700 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      x log(2)  x log(4)        x log(2) 3
+--R                - b %e        %e         + b (%e        )
+--R   (5)  ----------------------------------------------------------
+--R          2   x log(2) 2         x log(4)          x log(2) 2    2
+--R        (b (%e        )  + a b)%e         + a b (%e        )  + a
+--R                                                    Type: Expression(Integer)
+--E 700
+
+)clear all
+
+--S 701 of 1018
+t0:=2^x/(a+2^(2*x)*b)
+--R 
+--R
+--R             x
+--R            2
+--R   (1)  ---------
+--R           2x
+--R        b 2   + a
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 1018
+r0:=atan(2^x*sqrt(b)/sqrt(a))/(log(2)*sqrt(a)*sqrt(b))
+--R 
+--R
+--R               x +-+
+--R              2 \|b
+--R         atan(------)
+--R                +-+
+--R               \|a
+--R   (2)  --------------
+--R               +-+ +-+
+--R        log(2)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              x log(2) 2      +-----+          x log(2)
+--R        (b (%e        )  - a)\|- a b  + 2a b %e                 x log(2) +---+
+--R    log(-----------------------------------------------)      %e        \|a b
+--R                           x log(2) 2                    atan(----------------)
+--R                      b (%e        )  + a                             a
+--R   [----------------------------------------------------,----------------------]
+--R                               +-----+                               +---+
+--R                       2log(2)\|- a b                         log(2)\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 703
+
+--S 704 of 1018
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         x log(2) 2      +-----+          x log(2)
+--R        +-+ +-+    (b (%e        )  - a)\|- a b  + 2a b %e
+--R       \|a \|b log(-----------------------------------------------)
+--R                                      x log(2) 2
+--R                                 b (%e        )  + a
+--R     + 
+--R                        x +-+
+--R           +-----+     2 \|b
+--R       - 2\|- a b atan(------)
+--R                         +-+
+--R                        \|a
+--R  /
+--R             +-----+ +-+ +-+
+--R     2log(2)\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 1018
+d0a:=D(m0a,x)
+--R 
+--R
+--R            x log(2)  x 2           x log(2) 2      x       x log(2)
+--R        b %e        (2 )  + (- b (%e        )  - a)2  + a %e
+--R   (5)  ------------------------------------------------------------
+--R              2   x log(2) 2         x 2          x log(2) 2    2
+--R            (b (%e        )  + a b)(2 )  + a b (%e        )  + a
+--R                                                    Type: Expression(Integer)
+--E 705
+
+--S 706 of 1018
+m0b:=a0.2-r0
+--R 
+--R
+--R                       x log(2) +---+                x +-+
+--R         +-+ +-+     %e        \|a b      +---+     2 \|b
+--R        \|a \|b atan(----------------) - \|a b atan(------)
+--R                             a                        +-+
+--R                                                     \|a
+--R   (6)  ---------------------------------------------------
+--R                               +-+ +-+ +---+
+--R                        log(2)\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 1018
+d0b:=D(m0b,x)
+--R 
+--R
+--R            x log(2)  x 2           x log(2) 2      x       x log(2)
+--R        b %e        (2 )  + (- b (%e        )  - a)2  + a %e
+--R   (7)  ------------------------------------------------------------
+--R              2   x log(2) 2         x 2          x log(2) 2    2
+--R            (b (%e        )  + a b)(2 )  + a b (%e        )  + a
+--R                                                    Type: Expression(Integer)
+--E 707
+
+)clear all
+
+--S 708 of 1018
+t0:=2^x/(a-4^x*b)
+--R 
+--R
+--R              x
+--R             2
+--R   (1)  - --------
+--R             x
+--R          b 4  - a
+--R                                                    Type: Expression(Integer)
+--E 708
+
+--S 709 of 1018
+r0:=atanh(2^x*sqrt(b)/sqrt(a))/(log(2)*sqrt(a)*sqrt(b))
+--R 
+--R
+--R                x +-+
+--R               2 \|b
+--R         atanh(------)
+--R                 +-+
+--R                \|a
+--R   (2)  --------------
+--R               +-+ +-+
+--R        log(2)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x       %M
+--R         ++       2
+--R   (3)   |   - --------- d%M
+--R        ++        %M
+--R               b 4   - a
+--R                                         Type: Union(Expression(Integer),...)
+--E 710
+
+--S 711 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                         x       %M                  x +-+
+--R               +-+ +-+ ++       2                   2 \|b
+--R        log(2)\|a \|b  |   - --------- d%M  - atanh(------)
+--R                      ++        %M                    +-+
+--R                             b 4   - a               \|a
+--R   (4)  ---------------------------------------------------
+--R                                  +-+ +-+
+--R                           log(2)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     x log(2)  x log(4)        x log(2) 3
+--R                 b %e        %e         - b (%e        )
+--R   (5)  ----------------------------------------------------------
+--R          2   x log(2) 2         x log(4)          x log(2) 2    2
+--R        (b (%e        )  - a b)%e         - a b (%e        )  + a
+--R                                                    Type: Expression(Integer)
+--E 712
+
+)clear all
+
+--S 713 of 1018
+t0:=2^x/(a-2^(2*x)*b)
+--R 
+--R
+--R               x
+--R              2
+--R   (1)  - ---------
+--R             2x
+--R          b 2   - a
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 1018
+r0:=atanh(2^x*sqrt(b)/sqrt(a))/(log(2)*sqrt(a)*sqrt(b))
+--R 
+--R
+--R                x +-+
+--R               2 \|b
+--R         atanh(------)
+--R                 +-+
+--R                \|a
+--R   (2)  --------------
+--R               +-+ +-+
+--R        log(2)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 714
+
+--S 715 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              x log(2) 2      +---+          x log(2)
+--R        (b (%e        )  + a)\|a b  + 2a b %e                 x log(2) +-----+
+--R    log(---------------------------------------------)      %e        \|- a b
+--R                          x log(2) 2                   atan(------------------)
+--R                     b (%e        )  - a                             a
+--R   [--------------------------------------------------,------------------------]
+--R                               +---+                               +-----+
+--R                       2log(2)\|a b                         log(2)\|- a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 715
+
+--S 716 of 1018
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         x log(2) 2      +---+          x log(2)
+--R        +-+ +-+    (b (%e        )  + a)\|a b  + 2a b %e
+--R       \|a \|b log(---------------------------------------------)
+--R                                     x log(2) 2
+--R                                b (%e        )  - a
+--R     + 
+--R                       x +-+
+--R           +---+      2 \|b
+--R       - 2\|a b atanh(------)
+--R                        +-+
+--R                       \|a
+--R  /
+--R             +-+ +-+ +---+
+--R     2log(2)\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1018
+d0a:=D(m0a,x)
+--R 
+--R
+--R              x log(2)  x 2         x log(2) 2      x       x log(2)
+--R        - b %e        (2 )  + (b (%e        )  - a)2  + a %e
+--R   (5)  ------------------------------------------------------------
+--R              2   x log(2) 2         x 2          x log(2) 2    2
+--R            (b (%e        )  - a b)(2 )  - a b (%e        )  + a
+--R                                                    Type: Expression(Integer)
+--E 717
+
+--S 718 of 1018
+m0b:=a0.2-r0
+--R 
+--R
+--R                         x +-+                   x log(2) +-----+
+--R           +-----+      2 \|b      +-+ +-+     %e        \|- a b
+--R        - \|- a b atanh(------) + \|a \|b atan(------------------)
+--R                          +-+                           a
+--R                         \|a
+--R   (6)  ----------------------------------------------------------
+--R                                 +-----+ +-+ +-+
+--R                          log(2)\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 1018
+d0b:=D(m0b,x)
+--R 
+--R
+--R              x log(2)  x 2         x log(2) 2      x       x log(2)
+--R        - b %e        (2 )  + (b (%e        )  - a)2  + a %e
+--R   (7)  ------------------------------------------------------------
+--R              2   x log(2) 2         x 2          x log(2) 2    2
+--R            (b (%e        )  - a b)(2 )  - a b (%e        )  + a
+--R                                                    Type: Expression(Integer)
+--E 719
+
+)clear all
+
+--S 720 of 1018
+t0:=2^x/(a+b/4^x)
+--R 
+--R
+--R           x x
+--R          2 4
+--R   (1)  --------
+--R           x
+--R        a 4  + b
+--R                                                    Type: Expression(Integer)
+--E 720
+
+--S 721 of 1018
+r0:=2^x/(a*log(2))-atan(2^x*sqrt(a)/sqrt(b))*sqrt(b)/(a^(3/2)*log(2))
+--R 
+--R
+--R                    x +-+
+--R           +-+     2 \|a      x +-+
+--R        - \|b atan(------) + 2 \|a
+--R                     +-+
+--R                    \|b
+--R   (2)  ---------------------------
+--R                         +-+
+--R                a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x    %M %M
+--R         ++    2  4
+--R   (3)   |   --------- d%M
+--R        ++      %M
+--R             a 4   + b
+--R                                         Type: Union(Expression(Integer),...)
+--E 722
+
+--S 723 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                       x    %M %M                   x +-+
+--R                 +-+ ++    2  4            +-+     2 \|a      x +-+
+--R        a log(2)\|a  |   --------- d%M  + \|b atan(------) - 2 \|a
+--R                    ++      %M                       +-+
+--R                         a 4   + b                  \|b
+--R   (4)  -----------------------------------------------------------
+--R                                         +-+
+--R                                a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 723
+
+--S 724 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                     x log(2)  x log(4)        x log(2) 3
+--R                 b %e        %e         - b (%e        )
+--R   (5)  ----------------------------------------------------------
+--R          2   x log(2) 2         x log(4)          x log(2) 2    2
+--R        (a (%e        )  + a b)%e         + a b (%e        )  + b
+--R                                                    Type: Expression(Integer)
+--E 724
+
+)clear all
+
+--S 725 of 1018
+t0:=2^x/(a+b/2^(2*x))
+--R 
+--R
+--R           x 2x
+--R          2 2
+--R   (1)  ---------
+--R           2x
+--R        a 2   + b
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 1018
+r0:=2^x/(a*log(2))-atan(2^x*sqrt(a)/sqrt(b))*sqrt(b)/(a^(3/2)*log(2))
+--R 
+--R
+--R                    x +-+
+--R           +-+     2 \|a      x +-+
+--R        - \|b atan(------) + 2 \|a
+--R                     +-+
+--R                    \|b
+--R   (2)  ---------------------------
+--R                         +-+
+--R                a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 726
+
+--S 727 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                              +---+
+--R                     x log(2) |  b         x log(2) 2
+--R     +---+    - 2a %e         |- -  + a (%e        )  - b
+--R     |  b                    \|  a                              x log(2)
+--R     |- - log(-------------------------------------------) + 2%e
+--R    \|  a                      x log(2) 2
+--R                          a (%e        )  + b
+--R   [--------------------------------------------------------------------,
+--R                                  2a log(2)
+--R                 +-+
+--R                 |b
+--R     +-+         |-
+--R     |b         \|a          x log(2)
+--R     |- atan(----------) + %e
+--R    \|a        x log(2)
+--R             %e
+--R    ---------------------------------]
+--R                 a log(2)
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 727
+
+--S 728 of 1018
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                     +---+
+--R                            x log(2) |  b         x log(2) 2
+--R        +---+        - 2a %e         |- -  + a (%e        )  - b
+--R        |  b  +-+                   \|  a
+--R        |- - \|a log(-------------------------------------------)
+--R       \|  a                          x log(2) 2
+--R                                 a (%e        )  + b
+--R     + 
+--R                  x +-+
+--R         +-+     2 \|a           x      x log(2)  +-+
+--R       2\|b atan(------) + (- 2 2  + 2%e        )\|a
+--R                   +-+
+--R                  \|b
+--R  /
+--R               +-+
+--R     2a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 728
+
+--S 729 of 1018
+d0a:=D(m0a,x)
+--R 
+--R
+--R                x log(2) 2       x 3        x log(2) 3  x 2        x log(2) 3
+--R        (- a (%e        )  - b)(2 )  + a (%e        ) (2 )  + b (%e        )
+--R   (5)  ---------------------------------------------------------------------
+--R                  2   x log(2) 2         x 2          x log(2) 2    2
+--R                (a (%e        )  + a b)(2 )  + a b (%e        )  + b
+--R                                                    Type: Expression(Integer)
+--E 729
+
+--S 730 of 1018
+m0b:=a0.2-r0
+--R 
+--R
+--R                         +-+
+--R                         |b
+--R             +-+         |-                  x +-+
+--R         +-+ |b         \|a         +-+     2 \|a         x     x log(2)  +-+
+--R        \|a  |- atan(----------) + \|b atan(------) + (- 2  + %e        )\|a
+--R            \|a        x log(2)               +-+
+--R                     %e                      \|b
+--R   (6)  ---------------------------------------------------------------------
+--R                                              +-+
+--R                                     a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 730
+
+--S 731 of 1018
+d0b:=D(m0b,x)
+--R 
+--R
+--R                x log(2) 2       x 3        x log(2) 3  x 2        x log(2) 3
+--R        (- a (%e        )  - b)(2 )  + a (%e        ) (2 )  + b (%e        )
+--R   (7)  ---------------------------------------------------------------------
+--R                  2   x log(2) 2         x 2          x log(2) 2    2
+--R                (a (%e        )  + a b)(2 )  + a b (%e        )  + b
+--R                                                    Type: Expression(Integer)
+--E 731
+
+)clear all
+
+--S 732 of 1018
+t0:=2^x/(a-b/4^x)
+--R 
+--R
+--R           x x
+--R          2 4
+--R   (1)  --------
+--R           x
+--R        a 4  - b
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 1018
+r0:=2^x/(a*log(2))-atanh(2^x*sqrt(a)/sqrt(b))*sqrt(b)/(a^(3/2)*log(2))
+--R 
+--R
+--R                     x +-+
+--R           +-+      2 \|a      x +-+
+--R        - \|b atanh(------) + 2 \|a
+--R                      +-+
+--R                     \|b
+--R   (2)  ----------------------------
+--R                         +-+
+--R                a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 733
+
+--S 734 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x    %M %M
+--R         ++    2  4
+--R   (3)   |   --------- d%M
+--R        ++      %M
+--R             a 4   - b
+--R                                         Type: Union(Expression(Integer),...)
+--E 734
+
+--S 735 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                       x    %M %M                    x +-+
+--R                 +-+ ++    2  4            +-+      2 \|a      x +-+
+--R        a log(2)\|a  |   --------- d%M  + \|b atanh(------) - 2 \|a
+--R                    ++      %M                        +-+
+--R                         a 4   - b                   \|b
+--R   (4)  ------------------------------------------------------------
+--R                                         +-+
+--R                                a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 735
+
+--S 736 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                      x log(2)  x log(4)        x log(2) 3
+--R                - b %e        %e         + b (%e        )
+--R   (5)  ----------------------------------------------------------
+--R          2   x log(2) 2         x log(4)          x log(2) 2    2
+--R        (a (%e        )  - a b)%e         - a b (%e        )  + b
+--R                                                    Type: Expression(Integer)
+--E 736
+
+)clear all
+
+--S 737 of 1018
+t0:=2^x/(a-b/2^(2*x))
+--R 
+--R
+--R           x 2x
+--R          2 2
+--R   (1)  ---------
+--R           2x
+--R        a 2   - b
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 1018
+r0:=2^x/(a*log(2))-atanh(2^x*sqrt(a)/sqrt(b))*sqrt(b)/(a^(3/2)*log(2))
+--R 
+--R
+--R                     x +-+
+--R           +-+      2 \|a      x +-+
+--R        - \|b atanh(------) + 2 \|a
+--R                      +-+
+--R                     \|b
+--R   (2)  ----------------------------
+--R                         +-+
+--R                a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 738
+
+--S 739 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                            +-+
+--R                   x log(2) |b         x log(2) 2
+--R     +-+    - 2a %e         |-  + a (%e        )  + b
+--R     |b                    \|a                              x log(2)
+--R     |- log(-----------------------------------------) + 2%e
+--R    \|a                     x log(2) 2
+--R                       a (%e        )  - b
+--R   [----------------------------------------------------------------,
+--R                                2a log(2)
+--R                  +---+
+--R                  |  b
+--R     +---+        |- -
+--R     |  b        \|  a         x log(2)
+--R     |- - atan(----------) + %e
+--R    \|  a        x log(2)
+--R               %e
+--R    -----------------------------------]
+--R                  a log(2)
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 739
+
+--S 740 of 1018
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                   +-+
+--R                          x log(2) |b         x log(2) 2
+--R            +-+    - 2a %e         |-  + a (%e        )  + b
+--R        +-+ |b                    \|a
+--R       \|a  |- log(-----------------------------------------)
+--R           \|a                     x log(2) 2
+--R                              a (%e        )  - b
+--R     + 
+--R                   x +-+
+--R         +-+      2 \|a           x      x log(2)  +-+
+--R       2\|b atanh(------) + (- 2 2  + 2%e        )\|a
+--R                    +-+
+--R                   \|b
+--R  /
+--R               +-+
+--R     2a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 1018
+d0a:=D(m0a,x)
+--R 
+--R
+--R                x log(2) 2       x 3        x log(2) 3  x 2        x log(2) 3
+--R        (- a (%e        )  + b)(2 )  + a (%e        ) (2 )  - b (%e        )
+--R   (5)  ---------------------------------------------------------------------
+--R                  2   x log(2) 2         x 2          x log(2) 2    2
+--R                (a (%e        )  - a b)(2 )  - a b (%e        )  + b
+--R                                                    Type: Expression(Integer)
+--E 741
+
+--S 742 of 1018
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                         +---+
+--R                                         |  b
+--R              x +-+     +---+            |- -
+--R    +-+      2 \|a      |  b  +-+       \|  a           x     x log(2)  +-+
+--R   \|b atanh(------) +  |- - \|a atan(----------) + (- 2  + %e        )\|a
+--R               +-+     \|  a            x log(2)
+--R              \|b                     %e
+--R   ------------------------------------------------------------------------
+--R                                          +-+
+--R                                 a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 1018
+d0b:=D(m0b,x)
+--R 
+--R
+--R                x log(2) 2       x 3        x log(2) 3  x 2        x log(2) 3
+--R        (- a (%e        )  + b)(2 )  + a (%e        ) (2 )  - b (%e        )
+--R   (7)  ---------------------------------------------------------------------
+--R                  2   x log(2) 2         x 2          x log(2) 2    2
+--R                (a (%e        )  - a b)(2 )  - a b (%e        )  + b
+--R                                                    Type: Expression(Integer)
+--E 743
+
+)clear all
+
+--S 744 of 1018
+t0:=2^x/sqrt(a+4^x*b)
+--R 
+--R
+--R              x
+--R             2
+--R   (1)  -----------
+--R         +--------+
+--R         |   x
+--R        \|b 4  + a
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 1018
+r0:=atanh(2^x*sqrt(b)/sqrt(a+2^(2*x)*b))/(log(2)*sqrt(b))
+--R 
+--R
+--R                  x +-+
+--R                 2 \|b
+--R        atanh(------------)
+--R               +---------+
+--R               |   2x
+--R              \|b 2   + a
+--R   (2)  -------------------
+--R                    +-+
+--R             log(2)\|b
+--R                                                    Type: Expression(Integer)
+--E 745
+
+-- integrate: implementation incomplete (constant residues)
+--S 746 of 1018
+--a0:=integrate(t0,x)
+--E 746
+
+--S 747 of 1018
+--m0:=a0-r0
+--E 747
+
+--S 748 of 1018
+--d0:=normalize(D(m0,x))
+--E 748
+
+)clear all
+
+--S 749 of 1018
+t0:=2^x/sqrt(a+2^(2*x)*b)
+--R 
+--R
+--R              x
+--R             2
+--R   (1)  ------------
+--R         +---------+
+--R         |   2x
+--R        \|b 2   + a
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 1018
+r0:=atanh(2^x*sqrt(b)/sqrt(a+2^(2*x)*b))/(log(2)*sqrt(b))
+--R 
+--R
+--R                  x +-+
+--R                 2 \|b
+--R        atanh(------------)
+--R               +---------+
+--R               |   2x
+--R              \|b 2   + a
+--R   (2)  -------------------
+--R                    +-+
+--R             log(2)\|b
+--R                                                    Type: Expression(Integer)
+--E 750
+
+--S 751 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                        +-------------------+
+--R                +-+ +-+       x log(2)  |     x log(2) 2
+--R              (\|a \|b  - b %e        )\|b (%e        )  + a
+--R            + 
+--R                      x log(2) 2      +-+       x log(2) +-+
+--R              (- b (%e        )  - a)\|b  + b %e        \|a
+--R         /
+--R                 +-------------------+
+--R             +-+ |     x log(2) 2
+--R            \|a \|b (%e        )  + a  - a
+--R    /
+--R              +-+
+--R       log(2)\|b
+--R     ,
+--R                 +-------------------+
+--R           +---+ |     x log(2) 2         +---+ +-+
+--R          \|- b \|b (%e        )  + a  - \|- b \|a
+--R    2atan(-----------------------------------------)
+--R                             x log(2)
+--R                         b %e
+--R    ------------------------------------------------]
+--R                             +---+
+--R                      log(2)\|- b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 751
+
+--S 752 of 1018
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                        +-------------------+
+--R                +-+ +-+       x log(2)  |     x log(2) 2
+--R              (\|a \|b  - b %e        )\|b (%e        )  + a
+--R            + 
+--R                      x log(2) 2      +-+       x log(2) +-+
+--R              (- b (%e        )  - a)\|b  + b %e        \|a
+--R         /
+--R                 +-------------------+
+--R             +-+ |     x log(2) 2
+--R            \|a \|b (%e        )  + a  - a
+--R     + 
+--R                   x +-+
+--R                  2 \|b
+--R       - atanh(------------)
+--R                +---------+
+--R                |   2x
+--R               \|b 2   + a
+--R  /
+--R            +-+
+--R     log(2)\|b
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1018
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        2   x log(2) 3          x log(2)  2x
+--R                   (- 3b (%e        )  - 4a b %e        )2
+--R                 + 
+--R                      2   x log(2) 3          x log(2)   x 2
+--R                   (3b (%e        )  + 4a b %e        )(2 )
+--R                 + 
+--R                             x log(2) 3     2  x log(2)
+--R                   - 3a b (%e        )  - 4a %e
+--R              *
+--R                  +-+ +-+
+--R                 \|a \|b
+--R             + 
+--R                 3   x log(2) 4       2   x log(2) 2  2x
+--R               (b (%e        )  + 4a b (%e        ) )2
+--R             + 
+--R                   3   x log(2) 4       2   x log(2) 2   x 2      2   x log(2) 4
+--R               (- b (%e        )  - 4a b (%e        ) )(2 )  + a b (%e        )
+--R             + 
+--R                 2     x log(2) 2
+--R               4a b (%e        )
+--R          *
+--R              +-------------------+
+--R              |     x log(2) 2
+--R             \|b (%e        )  + a
+--R         + 
+--R                 3   x log(2) 5       2   x log(2) 3     2    x log(2)  2x
+--R               (b (%e        )  + 5a b (%e        )  + 4a b %e        )2
+--R             + 
+--R                   3   x log(2) 5       2   x log(2) 3     2    x log(2)   x 2
+--R               (- b (%e        )  - 5a b (%e        )  - 4a b %e        )(2 )
+--R             + 
+--R                  2   x log(2) 5     2     x log(2) 3     3  x log(2)
+--R               a b (%e        )  + 5a b (%e        )  + 4a %e
+--R          *
+--R              +-+
+--R             \|b
+--R         + 
+--R                    3   x log(2) 4       2   x log(2) 2  2x
+--R               (- 3b (%e        )  - 4a b (%e        ) )2
+--R             + 
+--R                  3   x log(2) 4       2   x log(2) 2   x 2       2   x log(2) 4
+--R               (3b (%e        )  + 4a b (%e        ) )(2 )  - 3a b (%e        )
+--R             + 
+--R                   2     x log(2) 2
+--R               - 4a b (%e        )
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +---------+
+--R          |   2x
+--R         \|b 2   + a
+--R     + 
+--R                 2   x log(2) 4     2     x log(2) 2     3  x +-+
+--R           (- a b (%e        )  - 5a b (%e        )  - 4a )2 \|b
+--R         + 
+--R                2   x log(2) 3     2    x log(2)  x +-+
+--R           (3a b (%e        )  + 4a b %e        )2 \|a
+--R      *
+--R          +-------------------+
+--R          |     x log(2) 2
+--R         \|b (%e        )  + a
+--R     + 
+--R            2   x log(2) 4     2     x log(2) 2     3  x +-+ +-+
+--R       (3a b (%e        )  + 7a b (%e        )  + 4a )2 \|a \|b
+--R     + 
+--R             3   x log(2) 5     2 2   x log(2) 3     3    x log(2)  x
+--R       (- a b (%e        )  - 5a b (%e        )  - 4a b %e        )2
+--R  /
+--R                   3   x log(2) 4       2   x log(2) 2     2   2x
+--R                 (b (%e        )  + 5a b (%e        )  + 4a b)2
+--R               + 
+--R                     3   x log(2) 4       2   x log(2) 2     2    x 2
+--R                 (- b (%e        )  - 5a b (%e        )  - 4a b)(2 )
+--R               + 
+--R                    2   x log(2) 4     2     x log(2) 2     3
+--R                 a b (%e        )  + 5a b (%e        )  + 4a
+--R            *
+--R                +-+
+--R               \|b
+--R           + 
+--R                      3   x log(2) 3       2  x log(2)  2x
+--R                 (- 3b (%e        )  - 4a b %e        )2
+--R               + 
+--R                    3   x log(2) 3       2  x log(2)   x 2       2   x log(2) 3
+--R                 (3b (%e        )  + 4a b %e        )(2 )  - 3a b (%e        )
+--R               + 
+--R                     2    x log(2)
+--R                 - 4a b %e
+--R            *
+--R                +-+
+--R               \|a
+--R        *
+--R            +-------------------+
+--R            |     x log(2) 2
+--R           \|b (%e        )  + a
+--R       + 
+--R                  3   x log(2) 4       2   x log(2) 2     2   2x
+--R             (- 3b (%e        )  - 7a b (%e        )  - 4a b)2
+--R           + 
+--R                3   x log(2) 4       2   x log(2) 2     2    x 2
+--R             (3b (%e        )  + 7a b (%e        )  + 4a b)(2 )
+--R           + 
+--R                   2   x log(2) 4     2     x log(2) 2     3
+--R             - 3a b (%e        )  - 7a b (%e        )  - 4a
+--R        *
+--R            +-+ +-+
+--R           \|a \|b
+--R       + 
+--R           4   x log(2) 5       3   x log(2) 3     2 2  x log(2)  2x
+--R         (b (%e        )  + 5a b (%e        )  + 4a b %e        )2
+--R       + 
+--R             4   x log(2) 5       3   x log(2) 3     2 2  x log(2)   x 2
+--R         (- b (%e        )  - 5a b (%e        )  - 4a b %e        )(2 )
+--R       + 
+--R            3   x log(2) 5     2 2   x log(2) 3     3    x log(2)
+--R         a b (%e        )  + 5a b (%e        )  + 4a b %e
+--R    *
+--R        +---------+
+--R        |   2x
+--R       \|b 2   + a
+--R                                                    Type: Expression(Integer)
+--E 753
+
+--S 754 of 1018
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         x +-+
+--R          +---+         2 \|b
+--R       - \|- b atanh(------------)
+--R                      +---------+
+--R                      |   2x
+--R                     \|b 2   + a
+--R     + 
+--R                        +-------------------+
+--R                  +---+ |     x log(2) 2         +---+ +-+
+--R         +-+     \|- b \|b (%e        )  + a  - \|- b \|a
+--R       2\|b atan(-----------------------------------------)
+--R                                    x log(2)
+--R                                b %e
+--R  /
+--R            +---+ +-+
+--R     log(2)\|- b \|b
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 1018
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                                                            +---------+
+--R            x log(2) 2x       x log(2)  x 2       x log(2)  |   2x
+--R       (b %e        2   - b %e        (2 )  + a %e        )\|b 2   + a
+--R     + 
+--R              +-------------------+
+--R            x |     x log(2) 2
+--R       - a 2 \|b (%e        )  + a
+--R  /
+--R                           +-------------------+ +---------+
+--R         2x       x 2      |     x log(2) 2      |   2x
+--R     (b 2   - b (2 )  + a)\|b (%e        )  + a \|b 2   + a
+--R                                                    Type: Expression(Integer)
+--E 755
+
+)clear all
+
+--S 756 of 1018
+t0:=2^x/sqrt(a-4^x*b)
+--R 
+--R
+--R               x
+--R              2
+--R   (1)  -------------
+--R         +----------+
+--R         |     x
+--R        \|- b 4  + a
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 1018
+r0:=atan(2^x*sqrt(b)/sqrt(a-2^(2*x)*b))/(log(2)*sqrt(b))
+--R 
+--R
+--R                  x +-+
+--R                 2 \|b
+--R        atan(--------------)
+--R              +-----------+
+--R              |     2x
+--R             \|- b 2   + a
+--R   (2)  --------------------
+--R                    +-+
+--R             log(2)\|b
+--R                                                    Type: Expression(Integer)
+--E 757
+
+-- integrate: implementation incomplete (constant residues)
+--S 758 of 1018
+--a0:=integrate(t0,x)
+--E 758
+
+--S 759 of 1018
+--m0:=a0-r0
+--E 759
+
+--S 760 of 1018
+--d0:=normalize(D(m0,x))
+--E 760
+
+)clear all
+
+--S 761 of 1018
+t0:=2^x/sqrt(a-2^(2*x)*b)
+--R 
+--R
+--R               x
+--R              2
+--R   (1)  --------------
+--R         +-----------+
+--R         |     2x
+--R        \|- b 2   + a
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 1018
+r0:=atan(2^x*sqrt(b)/sqrt(a-2^(2*x)*b))/(log(2)*sqrt(b))
+--R 
+--R
+--R                  x +-+
+--R                 2 \|b
+--R        atan(--------------)
+--R              +-----------+
+--R              |     2x
+--R             \|- b 2   + a
+--R   (2)  --------------------
+--R                    +-+
+--R             log(2)\|b
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                          +---------------------+
+--R                +---+ +-+       x log(2)  |       x log(2) 2
+--R              (\|- b \|a  + b %e        )\|- b (%e        )  + a
+--R            + 
+--R                    x log(2) +-+         x log(2) 2      +---+
+--R              - b %e        \|a  + (b (%e        )  - a)\|- b
+--R         /
+--R                 +---------------------+
+--R             +-+ |       x log(2) 2
+--R            \|a \|- b (%e        )  + a  - a
+--R    /
+--R              +---+
+--R       log(2)\|- b
+--R     ,
+--R                 +---------------------+
+--R             +-+ |       x log(2) 2         +-+ +-+
+--R            \|b \|- b (%e        )  + a  - \|a \|b
+--R      2atan(---------------------------------------)
+--R                              x log(2)
+--R                          b %e
+--R    - ----------------------------------------------]
+--R                               +-+
+--R                        log(2)\|b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 763
+
+--S 764 of 1018
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+
+--R         \|b
+--R      *
+--R         log
+--R                                            +---------------------+
+--R                  +---+ +-+       x log(2)  |       x log(2) 2
+--R                (\|- b \|a  + b %e        )\|- b (%e        )  + a
+--R              + 
+--R                      x log(2) +-+         x log(2) 2      +---+
+--R                - b %e        \|a  + (b (%e        )  - a)\|- b
+--R           /
+--R                   +---------------------+
+--R               +-+ |       x log(2) 2
+--R              \|a \|- b (%e        )  + a  - a
+--R     + 
+--R                         x +-+
+--R          +---+         2 \|b
+--R       - \|- b atan(--------------)
+--R                     +-----------+
+--R                     |     2x
+--R                    \|- b 2   + a
+--R  /
+--R            +---+ +-+
+--R     log(2)\|- b \|b
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 1018
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                        2   x log(2) 3          x log(2)  2x
+--R                   (- 3b (%e        )  + 4a b %e        )2
+--R                 + 
+--R                      2   x log(2) 3          x log(2)   x 2
+--R                   (3b (%e        )  - 4a b %e        )(2 )
+--R                 + 
+--R                           x log(2) 3     2  x log(2)
+--R                   3a b (%e        )  - 4a %e
+--R              *
+--R                  +---+ +-+
+--R                 \|- b \|a
+--R             + 
+--R                   3   x log(2) 4       2   x log(2) 2  2x
+--R               (- b (%e        )  + 4a b (%e        ) )2
+--R             + 
+--R                 3   x log(2) 4       2   x log(2) 2   x 2      2   x log(2) 4
+--R               (b (%e        )  - 4a b (%e        ) )(2 )  + a b (%e        )
+--R             + 
+--R                   2     x log(2) 2
+--R               - 4a b (%e        )
+--R          *
+--R              +-----------+
+--R              |     2x
+--R             \|- b 2   + a
+--R         + 
+--R                2   x log(2) 3     2    x log(2)  x +-+
+--R           (3a b (%e        )  - 4a b %e        )2 \|a
+--R         + 
+--R                 2   x log(2) 4     2     x log(2) 2     3  x +---+
+--R           (- a b (%e        )  + 5a b (%e        )  - 4a )2 \|- b
+--R      *
+--R          +---------------------+
+--R          |       x log(2) 2
+--R         \|- b (%e        )  + a
+--R     + 
+--R                  3   x log(2) 4       2   x log(2) 2  2x
+--R               (3b (%e        )  - 4a b (%e        ) )2
+--R             + 
+--R                    3   x log(2) 4       2   x log(2) 2   x 2
+--R               (- 3b (%e        )  + 4a b (%e        ) )(2 )
+--R             + 
+--R                     2   x log(2) 4     2     x log(2) 2
+--R               - 3a b (%e        )  + 4a b (%e        )
+--R          *
+--R              +-+
+--R             \|a
+--R         + 
+--R                   3   x log(2) 5       2   x log(2) 3     2    x log(2)  2x
+--R               (- b (%e        )  + 5a b (%e        )  - 4a b %e        )2
+--R             + 
+--R                 3   x log(2) 5       2   x log(2) 3     2    x log(2)   x 2
+--R               (b (%e        )  - 5a b (%e        )  + 4a b %e        )(2 )
+--R             + 
+--R                  2   x log(2) 5     2     x log(2) 3     3  x log(2)
+--R               a b (%e        )  - 5a b (%e        )  + 4a %e
+--R          *
+--R              +---+
+--R             \|- b
+--R      *
+--R          +-----------+
+--R          |     2x
+--R         \|- b 2   + a
+--R     + 
+--R            2   x log(2) 4     2     x log(2) 2     3  x +---+ +-+
+--R       (3a b (%e        )  - 7a b (%e        )  + 4a )2 \|- b \|a
+--R     + 
+--R           3   x log(2) 5     2 2   x log(2) 3     3    x log(2)  x
+--R       (a b (%e        )  - 5a b (%e        )  + 4a b %e        )2
+--R  /
+--R                  3   x log(2) 3       2  x log(2)  2x
+--R               (3b (%e        )  - 4a b %e        )2
+--R             + 
+--R                    3   x log(2) 3       2  x log(2)   x 2       2   x log(2) 3
+--R               (- 3b (%e        )  + 4a b %e        )(2 )  - 3a b (%e        )
+--R             + 
+--R                 2    x log(2)
+--R               4a b %e
+--R          *
+--R              +-+
+--R             \|a
+--R         + 
+--R                   3   x log(2) 4       2   x log(2) 2     2   2x
+--R               (- b (%e        )  + 5a b (%e        )  - 4a b)2
+--R             + 
+--R                 3   x log(2) 4       2   x log(2) 2     2    x 2
+--R               (b (%e        )  - 5a b (%e        )  + 4a b)(2 )
+--R             + 
+--R                  2   x log(2) 4     2     x log(2) 2     3
+--R               a b (%e        )  - 5a b (%e        )  + 4a
+--R          *
+--R              +---+
+--R             \|- b
+--R      *
+--R          +-----------+ +---------------------+
+--R          |     2x      |       x log(2) 2
+--R         \|- b 2   + a \|- b (%e        )  + a
+--R     + 
+--R                  3   x log(2) 4       2   x log(2) 2     2   2x
+--R               (3b (%e        )  - 7a b (%e        )  + 4a b)2
+--R             + 
+--R                    3   x log(2) 4       2   x log(2) 2     2    x 2
+--R               (- 3b (%e        )  + 7a b (%e        )  - 4a b)(2 )
+--R             + 
+--R                     2   x log(2) 4     2     x log(2) 2     3
+--R               - 3a b (%e        )  + 7a b (%e        )  - 4a
+--R          *
+--R              +---+ +-+
+--R             \|- b \|a
+--R         + 
+--R             4   x log(2) 5       3   x log(2) 3     2 2  x log(2)  2x
+--R           (b (%e        )  - 5a b (%e        )  + 4a b %e        )2
+--R         + 
+--R               4   x log(2) 5       3   x log(2) 3     2 2  x log(2)   x 2
+--R           (- b (%e        )  + 5a b (%e        )  - 4a b %e        )(2 )
+--R         + 
+--R                3   x log(2) 5     2 2   x log(2) 3     3    x log(2)
+--R           - a b (%e        )  + 5a b (%e        )  - 4a b %e
+--R      *
+--R          +-----------+
+--R          |     2x
+--R         \|- b 2   + a
+--R                                                    Type: Expression(Integer)
+--E 765
+
+--S 766 of 1018
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                +---------------------+
+--R            +-+ |       x log(2) 2         +-+ +-+              x +-+
+--R           \|b \|- b (%e        )  + a  - \|a \|b              2 \|b
+--R   - 2atan(---------------------------------------) - atan(--------------)
+--R                             x log(2)                       +-----------+
+--R                         b %e                               |     2x
+--R                                                           \|- b 2   + a
+--R   -----------------------------------------------------------------------
+--R                                         +-+
+--R                                  log(2)\|b
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 1018
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R            +---------------------+
+--R          x |       x log(2) 2
+--R       a 2 \|- b (%e        )  + a
+--R     + 
+--R                                                            +-----------+
+--R            x log(2) 2x       x log(2)  x 2       x log(2)  |     2x
+--R       (b %e        2   - b %e        (2 )  - a %e        )\|- b 2   + a
+--R  /
+--R                           +-----------+ +---------------------+
+--R         2x       x 2      |     2x      |       x log(2) 2
+--R     (b 2   - b (2 )  - a)\|- b 2   + a \|- b (%e        )  + a
+--R                                                    Type: Expression(Integer)
+--E 767
+
+)clear all
+
+--S 768 of 1018
+t0:=2^x/sqrt(a+b/4^x)
+--R 
+--R
+--R              x
+--R             2
+--R   (1)  -----------
+--R         +--------+
+--R         |   x
+--R         |a 4  + b
+--R         |--------
+--R         |    x
+--R        \|   4
+--R                                                    Type: Expression(Integer)
+--E 768
+
+--S 769 of 1018
+r0:=2^x*sqrt(a+b/2^(2*x))/(a*log(2))
+--R 
+--R
+--R           +---------+
+--R           |   2x
+--R         x |a 2   + b
+--R        2  |---------
+--R           |    2x
+--R          \|   2
+--R   (2)  --------------
+--R           a log(2)
+--R                                                    Type: Expression(Integer)
+--E 769
+
+-- integrate: implementation incomplete (constant residues)
+--S 770 of 1018
+--a0:=integrate(t0,x)
+--E 770
+
+--S 771 of 1018
+--m0:=a0-r0
+--E 771
+
+--S 772 of 1018
+--d0:=normalize(D(m0,x))
+--E 772
+
+)clear all
+
+--S 773 of 1018
+t0:=2^x/sqrt(a+b/2^(2*x))
+--R 
+--R
+--R              x
+--R             2
+--R   (1)  ------------
+--R         +---------+
+--R         |   2x
+--R         |a 2   + b
+--R         |---------
+--R         |    2x
+--R        \|   2
+--R                                                    Type: Expression(Integer)
+--E 773
+
+--S 774 of 1018
+r0:=2^x*sqrt(a+b/2^(2*x))/(a*log(2))
+--R 
+--R
+--R           +---------+
+--R           |   2x
+--R         x |a 2   + b
+--R        2  |---------
+--R           |    2x
+--R          \|   2
+--R   (2)  --------------
+--R           a log(2)
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        x log(2) 2 +-+
+--R                     (%e        ) \|b
+--R   (3)  -------------------------------------------
+--R                   +-------------------+
+--R               +-+ |     x log(2) 2
+--R        log(2)\|b \|a (%e        )  + b  - b log(2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 775
+
+--S 776 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +---------+                              +---------+
+--R                |   2x      +-------------------+        |   2x
+--R          x +-+ |a 2   + b  |     x log(2) 2           x |a 2   + b
+--R       - 2 \|b  |--------- \|a (%e        )  + b  + b 2  |---------
+--R                |    2x                                  |    2x
+--R               \|   2                                   \|   2
+--R     + 
+--R            x log(2) 2 +-+
+--R       a (%e        ) \|b
+--R  /
+--R                  +-------------------+
+--R              +-+ |     x log(2) 2
+--R     a log(2)\|b \|a (%e        )  + b  - a b log(2)
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                             +-------------------+
+--R                                             |     x log(2) 2
+--R                   x log(2) 3  2x log(4) +-+ |a (%e        )  + b
+--R           - 2a (%e        ) %e         \|b  |-------------------
+--R                                             |      x log(2) 2
+--R                                            \|   (%e        )
+--R         + 
+--R               2   x log(2) 4           x log(2) 2     2   2x log(4)
+--R           (- a (%e        )  - 3a b (%e        )  - 2b )%e
+--R         + 
+--R                  x log(2) 6     2   x log(2) 4
+--R           a b (%e        )  + 2b (%e        )
+--R      *
+--R          +-------------------+
+--R          |     x log(2) 2
+--R         \|a (%e        )  + b
+--R     + 
+--R                                                         +-------------------+
+--R                                                         |     x log(2) 2
+--R         2   x log(2) 5           x log(2) 3   2x log(4) |a (%e        )  + b
+--R       (a (%e        )  + 2a b (%e        ) )%e          |-------------------
+--R                                                         |      x log(2) 2
+--R                                                        \|   (%e        )
+--R     + 
+--R              2   x log(2) 4           x log(2) 2     2   2x log(4)
+--R           (2a (%e        )  + 4a b (%e        )  + 2b )%e
+--R         + 
+--R                     x log(2) 6     2   x log(2) 4
+--R           - 2a b (%e        )  - 2b (%e        )
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R                                                        +-------------------+
+--R                                                        |     x log(2) 2
+--R           2   x log(2) 3          x log(2)   2x log(4) |a (%e        )  + b
+--R         (a (%e        )  + 2a b %e        )%e          |-------------------
+--R                                                        |      x log(2) 2
+--R                                                       \|   (%e        )
+--R      *
+--R          +-------------------+
+--R          |     x log(2) 2
+--R         \|a (%e        )  + b
+--R     + 
+--R                                                           +-------------------+
+--R                                                           |     x log(2) 2
+--R          2   x log(2) 3          x log(2)   2x log(4) +-+ |a (%e        )  + b
+--R     (- 2a (%e        )  - 2a b %e        )%e         \|b  |-------------------
+--R                                                           |      x log(2) 2
+--R                                                          \|   (%e        )
+--R                                                    Type: Expression(Integer)
+--E 777
+
+)clear all
+
+--S 778 of 1018
+t0:=2^x/sqrt(a-b/4^x)
+--R 
+--R
+--R              x
+--R             2
+--R   (1)  -----------
+--R         +--------+
+--R         |   x
+--R         |a 4  - b
+--R         |--------
+--R         |    x
+--R        \|   4
+--R                                                    Type: Expression(Integer)
+--E 778
+
+--S 779 of 1018
+r0:=2^x*sqrt(a-b/2^(2*x))/(a*log(2))
+--R 
+--R
+--R           +---------+
+--R           |   2x
+--R         x |a 2   - b
+--R        2  |---------
+--R           |    2x
+--R          \|   2
+--R   (2)  --------------
+--R           a log(2)
+--R                                                    Type: Expression(Integer)
+--E 779
+
+-- integrate: implementation incomplete (constant residues)
+--S 780 of 1018
+--a0:=integrate(t0,x)
+--E 780
+
+--S 781 of 1018
+--m0:=a0-r0
+--E 781
+
+--S 782 of 1018
+--d0:=normalize(D(m0,x))
+--E 782
+
+)clear all
+
+--S 783 of 1018
+t0:=2^x/sqrt(a-b/2^(2*x))
+--R 
+--R
+--R              x
+--R             2
+--R   (1)  ------------
+--R         +---------+
+--R         |   2x
+--R         |a 2   - b
+--R         |---------
+--R         |    2x
+--R        \|   2
+--R                                                    Type: Expression(Integer)
+--E 783
+
+--S 784 of 1018
+r0:=2^x*sqrt(a-b/2^(2*x))/(a*log(2))
+--R 
+--R
+--R           +---------+
+--R           |   2x
+--R         x |a 2   - b
+--R        2  |---------
+--R           |    2x
+--R          \|   2
+--R   (2)  --------------
+--R           a log(2)
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        x log(2) 2 +---+
+--R                     (%e        ) \|- b
+--R   (3)  ---------------------------------------------
+--R                     +-------------------+
+--R               +---+ |     x log(2) 2
+--R        log(2)\|- b \|a (%e        )  - b  + b log(2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 785
+
+--S 786 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  +---------+                              +---------+
+--R                  |   2x      +-------------------+        |   2x
+--R          x +---+ |a 2   - b  |     x log(2) 2           x |a 2   - b
+--R       - 2 \|- b  |--------- \|a (%e        )  - b  - b 2  |---------
+--R                  |    2x                                  |    2x
+--R                 \|   2                                   \|   2
+--R     + 
+--R            x log(2) 2 +---+
+--R       a (%e        ) \|- b
+--R  /
+--R                    +-------------------+
+--R              +---+ |     x log(2) 2
+--R     a log(2)\|- b \|a (%e        )  - b  + a b log(2)
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                                               +-------------------+
+--R                                               |     x log(2) 2
+--R                   x log(2) 3  2x log(4) +---+ |a (%e        )  - b
+--R           - 2a (%e        ) %e         \|- b  |-------------------
+--R                                               |      x log(2) 2
+--R                                              \|   (%e        )
+--R         + 
+--R               2   x log(2) 4           x log(2) 2     2   2x log(4)
+--R           (- a (%e        )  + 3a b (%e        )  - 2b )%e
+--R         + 
+--R                    x log(2) 6     2   x log(2) 4
+--R           - a b (%e        )  + 2b (%e        )
+--R      *
+--R          +-------------------+
+--R          |     x log(2) 2
+--R         \|a (%e        )  - b
+--R     + 
+--R                                                         +-------------------+
+--R                                                         |     x log(2) 2
+--R         2   x log(2) 5           x log(2) 3   2x log(4) |a (%e        )  - b
+--R       (a (%e        )  - 2a b (%e        ) )%e          |-------------------
+--R                                                         |      x log(2) 2
+--R                                                        \|   (%e        )
+--R     + 
+--R              2   x log(2) 4           x log(2) 2     2   2x log(4)
+--R           (2a (%e        )  - 4a b (%e        )  + 2b )%e
+--R         + 
+--R                   x log(2) 6     2   x log(2) 4
+--R           2a b (%e        )  - 2b (%e        )
+--R      *
+--R          +---+
+--R         \|- b
+--R  /
+--R                                                        +-------------------+
+--R                                                        |     x log(2) 2
+--R           2   x log(2) 3          x log(2)   2x log(4) |a (%e        )  - b
+--R         (a (%e        )  - 2a b %e        )%e          |-------------------
+--R                                                        |      x log(2) 2
+--R                                                       \|   (%e        )
+--R      *
+--R          +-------------------+
+--R          |     x log(2) 2
+--R         \|a (%e        )  - b
+--R     + 
+--R              2   x log(2) 3          x log(2)   2x log(4) +---+
+--R         (- 2a (%e        )  + 2a b %e        )%e         \|- b
+--R      *
+--R          +-------------------+
+--R          |     x log(2) 2
+--R          |a (%e        )  - b
+--R          |-------------------
+--R          |      x log(2) 2
+--R         \|   (%e        )
+--R                                                    Type: Expression(Integer)
+--E 787
+
+)clear all
+
+--S 788 of 1018
+t0:=4^x/sqrt(a+2^x*b)
+--R 
+--R
+--R              x
+--R             4
+--R   (1)  -----------
+--R         +--------+
+--R         |   x
+--R        \|b 2  + a
+--R                                                    Type: Expression(Integer)
+--E 788
+
+--S 789 of 1018
+r0:=2/3*(a+2^x*b)^(3/2)/(b^2*log(2))-2*a*sqrt(a+2^x*b)/(b^2*log(2))
+--R 
+--R
+--R                     +--------+
+--R             x       |   x
+--R        (2b 2  - 4a)\|b 2  + a
+--R   (2)  -----------------------
+--R                 2
+--R               3b log(2)
+--R                                                    Type: Expression(Integer)
+--E 789
+
+-- integrate: implementation incomplete (constant residues)
+--S 790 of 1018
+--a0:=integrate(t0,x)
+--E 790
+
+--S 791 of 1018
+--m0:=a0-r0
+--E 791
+
+--S 792 of 1018
+--d0:=normalize(D(m0,x))
+--E 792
+
+)clear all
+
+--S 793 of 1018
+t0:=2^(2*x)/sqrt(a+2^x*b)
+--R 
+--R
+--R             2x
+--R            2
+--R   (1)  -----------
+--R         +--------+
+--R         |   x
+--R        \|b 2  + a
+--R                                                    Type: Expression(Integer)
+--E 793
+
+--S 794 of 1018
+r0:=2/3*(a+2^x*b)^(3/2)/(b^2*log(2))-2*a*sqrt(a+2^x*b)/(b^2*log(2))
+--R 
+--R
+--R                     +--------+
+--R             x       |   x
+--R        (2b 2  - 4a)\|b 2  + a
+--R   (2)  -----------------------
+--R                 2
+--R               3b log(2)
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             +----------------+
+--R              x log(2)       |    x log(2)
+--R        (2b %e         - 4a)\|b %e         + a
+--R   (3)  ---------------------------------------
+--R                         2
+--R                       3b log(2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 795
+
+--S 796 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                       +--------+                        +----------------+
+--R               x       |   x              x log(2)       |    x log(2)
+--R        (- 2b 2  + 4a)\|b 2  + a  + (2b %e         - 4a)\|b %e         + a
+--R   (4)  -------------------------------------------------------------------
+--R                                       2
+--R                                     3b log(2)
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 797
+
+)clear all
+
+--S 798 of 1018
+t0:=4^x/sqrt(a-2^x*b)
+--R 
+--R
+--R               x
+--R              4
+--R   (1)  -------------
+--R         +----------+
+--R         |     x
+--R        \|- b 2  + a
+--R                                                    Type: Expression(Integer)
+--E 798
+
+--S 799 of 1018
+r0:=2/3*(a-2^x*b)^(3/2)/(b^2*log(2))-2*a*sqrt(a-2^x*b)/(b^2*log(2))
+--R 
+--R
+--R                       +----------+
+--R               x       |     x
+--R        (- 2b 2  - 4a)\|- b 2  + a
+--R   (2)  ---------------------------
+--R                   2
+--R                 3b log(2)
+--R                                                    Type: Expression(Integer)
+--E 799
+
+-- integrate: implementation incomplete (constant residues)
+--S 800 of 1018
+--a0:=integrate(t0,x)
+--E 800
+
+--S 801 of 1018
+--m0:=a0-r0
+--E 801
+
+--S 802 of 1018
+--d0:=normalize(D(m0,x))
+--E 802
+
+)clear all
+
+--S 803 of 1018
+t0:=2^(2*x)/sqrt(a-2^x*b)
+--R 
+--R
+--R              2x
+--R             2
+--R   (1)  -------------
+--R         +----------+
+--R         |     x
+--R        \|- b 2  + a
+--R                                                    Type: Expression(Integer)
+--E 803
+
+--S 804 of 1018
+r0:=2/3*(a-2^x*b)^(3/2)/(b^2*log(2))-2*a*sqrt(a-2^x*b)/(b^2*log(2))
+--R 
+--R
+--R                       +----------+
+--R               x       |     x
+--R        (- 2b 2  - 4a)\|- b 2  + a
+--R   (2)  ---------------------------
+--R                   2
+--R                 3b log(2)
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               +------------------+
+--R                x log(2)       |      x log(2)
+--R        (- 2b %e         - 4a)\|- b %e         + a
+--R   (3)  -------------------------------------------
+--R                           2
+--R                         3b log(2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 805
+
+--S 806 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                          +------------------+                +----------+
+--R           x log(2)       |      x log(2)             x       |     x
+--R   (- 2b %e         - 4a)\|- b %e         + a  + (2b 2  + 4a)\|- b 2  + a
+--R   -----------------------------------------------------------------------
+--R                                    2
+--R                                  3b log(2)
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 807
+
+)clear all
+
+--S 808 of 1018
+t0:=4^x/sqrt(a+b/2^x)
+--R 
+--R
+--R              x
+--R             4
+--R   (1)  -----------
+--R         +--------+
+--R         |   x
+--R         |a 2  + b
+--R         |--------
+--R         |    x
+--R        \|   2
+--R                                                    Type: Expression(Integer)
+--E 808
+
+--S 809 of 1018
+r0:=3/4*b^2*atanh(sqrt(a+b/2^x)/sqrt(a))/(a^(5/2)*log(2))+2^(-1+2*x)*_
+   sqrt(a+b/2^x)/(a*log(2))-3*2^(-2+x)*b*sqrt(a+b/2^x)/(a^2*log(2))
+--R 
+--R
+--R                  +--------+
+--R                  |   x
+--R                  |a 2  + b
+--R                  |--------                                   +--------+
+--R                  |    x                                      |   x
+--R          2      \|   2              2x - 1        x - 2  +-+ |a 2  + b
+--R        3b atanh(-----------) + (4a 2       - 12b 2     )\|a  |--------
+--R                      +-+                                     |    x
+--R                     \|a                                     \|   2
+--R   (2)  ----------------------------------------------------------------
+--R                                    2       +-+
+--R                                  4a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 809
+
+-- integrate: implementation incomplete (constant residues)
+--S 810 of 1018
+--a0:=integrate(t0,x)
+--E 810
+
+--S 811 of 1018
+--m0:=a0-r0
+--E 811
+
+--S 812 of 1018
+--d0:=normalize(D(m0,x))
+--E 812
+
+)clear all
+
+--S 813 of 1018
+t0:=2^(2*x)/sqrt(a+b/2^x)
+--R 
+--R
+--R             2x
+--R            2
+--R   (1)  -----------
+--R         +--------+
+--R         |   x
+--R         |a 2  + b
+--R         |--------
+--R         |    x
+--R        \|   2
+--R                                                    Type: Expression(Integer)
+--E 813
+
+--S 814 of 1018
+r0:=3/4*b^2*atanh(sqrt(a+b/2^x)/sqrt(a))/(a^(5/2)*log(2))+2^(-1+2*x)*_
+   sqrt(a+b/2^x)/(a*log(2))-3*2^(-2+x)*b*sqrt(a+b/2^x)/(a^2*log(2))
+--R 
+--R
+--R                  +--------+
+--R                  |   x
+--R                  |a 2  + b
+--R                  |--------                                   +--------+
+--R                  |    x                                      |   x
+--R          2      \|   2              2x - 1        x - 2  +-+ |a 2  + b
+--R        3b atanh(-----------) + (4a 2       - 12b 2     )\|a  |--------
+--R                      +-+                                     |    x
+--R                     \|a                                     \|   2
+--R   (2)  ----------------------------------------------------------------
+--R                                    2       +-+
+--R                                  4a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                              +----------------+
+--R                              |    x log(2)
+--R           2         x log(2) |a %e         + b          x log(2)      +-+
+--R         3b log(2a %e         |----------------  + (2a %e         + b)\|a )
+--R                              |     x log(2)
+--R                             \|   %e
+--R       + 
+--R                                                +----------------+
+--R                                                |    x log(2)
+--R                x log(2) 2        x log(2)  +-+ |a %e         + b
+--R         (4a (%e        )  - 6b %e        )\|a  |----------------
+--R                                                |     x log(2)
+--R                                               \|   %e
+--R    /
+--R         2       +-+
+--R       8a log(2)\|a
+--R     ,
+--R
+--R                        +----------------+
+--R                        |    x log(2)
+--R                  +---+ |a %e         + b
+--R                 \|- a  |----------------
+--R                        |     x log(2)
+--R           2           \|   %e
+--R         3b atan(-------------------------)
+--R                             a
+--R       + 
+--R                                                  +----------------+
+--R                                                  |    x log(2)
+--R                x log(2) 2        x log(2)  +---+ |a %e         + b
+--R         (2a (%e        )  - 3b %e        )\|- a  |----------------
+--R                                                  |     x log(2)
+--R                                                 \|   %e
+--R    /
+--R         2       +---+
+--R       4a log(2)\|- a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 815
+
+--S 816 of 1018
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            +----------------+
+--R                            |    x log(2)
+--R         2         x log(2) |a %e         + b          x log(2)      +-+
+--R       3b log(2a %e         |----------------  + (2a %e         + b)\|a )
+--R                            |     x log(2)
+--R                           \|   %e
+--R     + 
+--R                   +--------+
+--R                   |   x
+--R                   |a 2  + b
+--R                   |--------
+--R                   |    x
+--R           2      \|   2
+--R       - 6b atanh(-----------)
+--R                       +-+
+--R                      \|a
+--R     + 
+--R                                              +----------------+
+--R                                              |    x log(2)
+--R              x log(2) 2        x log(2)  +-+ |a %e         + b
+--R       (4a (%e        )  - 6b %e        )\|a  |----------------
+--R                                              |     x log(2)
+--R                                             \|   %e
+--R     + 
+--R                                       +--------+
+--R                                       |   x
+--R              2x - 1        x - 2  +-+ |a 2  + b
+--R       (- 8a 2       + 24b 2     )\|a  |--------
+--R                                       |    x
+--R                                      \|   2
+--R  /
+--R       2       +-+
+--R     8a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 1018
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                                            +--------+
+--R                                                            |   x
+--R               3   x log(2) 4     2     x log(2) 3  x x +-+ |a 2  + b
+--R           (16a (%e        )  + 8a b (%e        ) )2 4 \|a  |--------
+--R                                                            |    x
+--R                                                           \|   2
+--R         + 
+--R                         4   x log(2) 2      3    x log(2)  x
+--R                   (- 32a (%e        )  - 32a b %e        )2
+--R                 + 
+--R                        3     x log(2) 2      2 2  x log(2)
+--R                   - 32a b (%e        )  - 32a b %e
+--R              *
+--R                  2x - 1
+--R                 2
+--R             + 
+--R                   3     x log(2) 2      2 2  x log(2)  x - 2 x
+--R               (48a b (%e        )  + 48a b %e        )2     2
+--R             + 
+--R                   2 2   x log(2) 2        3  x log(2)  x - 2
+--R               (48a b (%e        )  + 48a b %e        )2
+--R          *
+--R              x
+--R             4
+--R         + 
+--R              3     x log(2) 2     2 2  x log(2)   x 2 2x - 1
+--R           (8a b (%e        )  + 8a b %e        )(2 ) 2
+--R         + 
+--R                2 2   x log(2) 2       3  x log(2)   x 3
+--R           (- 6a b (%e        )  - 6a b %e        )(2 )
+--R         + 
+--R                 2 2   x log(2) 2        3  x log(2)  x - 2  x 2
+--R           (- 24a b (%e        )  - 24a b %e        )2     (2 )
+--R      *
+--R          +----------------+
+--R          |    x log(2)
+--R          |a %e         + b
+--R          |----------------
+--R          |     x log(2)
+--R         \|   %e
+--R     + 
+--R                                                     +--------+
+--R                                                     |   x
+--R           4   x log(2) 4      3     x log(2) 3  x x |a 2  + b
+--R       (16a (%e        )  + 16a b (%e        ) )2 4  |--------
+--R                                                     |    x
+--R                                                    \|   2
+--R     + 
+--R                         4   x log(2) 2      3    x log(2)      2 2  x
+--R                   (- 32a (%e        )  - 48a b %e         - 16a b )2
+--R                 + 
+--R                        3     x log(2) 2      2 2  x log(2)        3
+--R                   - 32a b (%e        )  - 48a b %e         - 16a b
+--R              *
+--R                  2x - 1
+--R                 2
+--R             + 
+--R                   3     x log(2) 2      2 2  x log(2)        3  x - 2 x
+--R               (48a b (%e        )  + 72a b %e         + 24a b )2     2
+--R             + 
+--R                   2 2   x log(2) 2        3  x log(2)      4  x - 2
+--R               (48a b (%e        )  + 72a b %e         + 24b )2
+--R          *
+--R              x
+--R             4
+--R         + 
+--R              3     x log(2) 2      2 2  x log(2)       3   x 2 2x - 1
+--R           (8a b (%e        )  + 12a b %e         + 4a b )(2 ) 2
+--R         + 
+--R                2 2   x log(2) 2       3  x log(2)     4   x 3
+--R           (- 6a b (%e        )  - 9a b %e         - 3b )(2 )
+--R         + 
+--R                 2 2   x log(2) 2        3  x log(2)      4  x - 2  x 2
+--R           (- 24a b (%e        )  - 36a b %e         - 12b )2     (2 )
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                  +--------+ +----------------+
+--R                                                  |   x      |    x log(2)
+--R           4   x log(2) 2      3    x log(2)  x x |a 2  + b  |a %e         + b
+--R       (16a (%e        )  + 16a b %e        )2 4  |--------  |----------------
+--R                                                  |    x     |     x log(2)
+--R                                                 \|   2     \|   %e
+--R     + 
+--R                                                              +--------+
+--R                                                              |   x
+--R           4   x log(2) 2      3    x log(2)     2 2  x x +-+ |a 2  + b
+--R       (16a (%e        )  + 24a b %e         + 8a b )2 4 \|a  |--------
+--R                                                              |    x
+--R                                                             \|   2
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 1018
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         +--------+                       +----------------+
+--R                         |   x                            |    x log(2)
+--R                         |a 2  + b                  +---+ |a %e         + b
+--R                         |--------                 \|- a  |----------------
+--R                         |    x                           |     x log(2)
+--R           2 +---+      \|   2           2 +-+           \|   %e
+--R       - 3b \|- a atanh(-----------) + 3b \|a atan(-------------------------)
+--R                             +-+                               a
+--R                            \|a
+--R     + 
+--R                                                    +----------------+
+--R                                                    |    x log(2)
+--R              x log(2) 2        x log(2)  +---+ +-+ |a %e         + b
+--R       (2a (%e        )  - 3b %e        )\|- a \|a  |----------------
+--R                                                    |     x log(2)
+--R                                                   \|   %e
+--R     + 
+--R                                             +--------+
+--R                                             |   x
+--R              2x - 1        x - 2  +---+ +-+ |a 2  + b
+--R       (- 4a 2       + 12b 2     )\|- a \|a  |--------
+--R                                             |    x
+--R                                            \|   2
+--R  /
+--R       2       +---+ +-+
+--R     4a log(2)\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 818
+
+--S 819 of 1018
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                  2 x          2x - 1          x - 2 x      2 x - 2  x
+--R           ((- 16a 2  - 16a b)2       + 24a b 2     2  + 24b 2     )4
+--R         + 
+--R                  x 2 2x - 1     2  x 3      2 x - 2  x 2
+--R           4a b (2 ) 2       - 3b (2 )  - 12b 2     (2 )
+--R      *
+--R          +----------------+
+--R          |    x log(2)
+--R          |a %e         + b
+--R          |----------------
+--R          |     x log(2)
+--R         \|   %e
+--R     + 
+--R                            +--------+
+--R                            |   x
+--R         2   x log(2) 2 x x |a 2  + b
+--R       8a (%e        ) 2 4  |--------
+--R                            |    x
+--R                           \|   2
+--R  /
+--R             +--------+ +----------------+
+--R             |   x      |    x log(2)
+--R       2 x x |a 2  + b  |a %e         + b
+--R     8a 2 4  |--------  |----------------
+--R             |    x     |     x log(2)
+--R            \|   2     \|   %e
+--R                                                    Type: Expression(Integer)
+--E 819
+
+)clear all
+
+--S 820 of 1018
+t0:=4^x/sqrt(a-b/2^x)
+--R 
+--R
+--R              x
+--R             4
+--R   (1)  -----------
+--R         +--------+
+--R         |   x
+--R         |a 2  - b
+--R         |--------
+--R         |    x
+--R        \|   2
+--R                                                    Type: Expression(Integer)
+--E 820
+
+--S 821 of 1018
+r0:=3/4*b^2*atanh(sqrt(a-b/2^x)/sqrt(a))/(a^(5/2)*log(2))+2^(-1+2*x)*_
+   sqrt(a-b/2^x)/(a*log(2))+3*2^(-2+x)*b*sqrt(a-b/2^x)/(a^2*log(2))
+--R 
+--R
+--R                  +--------+
+--R                  |   x
+--R                  |a 2  - b
+--R                  |--------                                   +--------+
+--R                  |    x                                      |   x
+--R          2      \|   2              2x - 1        x - 2  +-+ |a 2  - b
+--R        3b atanh(-----------) + (4a 2       + 12b 2     )\|a  |--------
+--R                      +-+                                     |    x
+--R                     \|a                                     \|   2
+--R   (2)  ----------------------------------------------------------------
+--R                                    2       +-+
+--R                                  4a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 821
+
+-- integrate: implementation incomplete (constant residues)
+--S 822 of 1018
+--a0:=integrate(t0,x)
+--E 822
+
+--S 823 of 1018
+--m0:=a0-r0
+--E 823
+
+--S 824 of 1018
+--d0:=normalize(D(m0,x))
+--E 824
+
+)clear all
+
+--S 825 of 1018
+t0:=2^(2*x)/sqrt(a-b/2^x)
+--R 
+--R
+--R             2x
+--R            2
+--R   (1)  -----------
+--R         +--------+
+--R         |   x
+--R         |a 2  - b
+--R         |--------
+--R         |    x
+--R        \|   2
+--R                                                    Type: Expression(Integer)
+--E 825
+
+--S 826 of 1018
+r0:=3/4*b^2*atanh(sqrt(a-b/2^x)/sqrt(a))/(a^(5/2)*log(2))+2^(-1+2*x)*_
+   sqrt(a-b/2^x)/(a*log(2))+3*2^(-2+x)*b*sqrt(a-b/2^x)/(a^2*log(2))
+--R 
+--R
+--R                  +--------+
+--R                  |   x
+--R                  |a 2  - b
+--R                  |--------                                   +--------+
+--R                  |    x                                      |   x
+--R          2      \|   2              2x - 1        x - 2  +-+ |a 2  - b
+--R        3b atanh(-----------) + (4a 2       + 12b 2     )\|a  |--------
+--R                      +-+                                     |    x
+--R                     \|a                                     \|   2
+--R   (2)  ----------------------------------------------------------------
+--R                                    2       +-+
+--R                                  4a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                +----------------+
+--R                                |    x log(2)
+--R           2           x log(2) |a %e         - b            x log(2)      +-+
+--R         3b log(- 2a %e         |----------------  + (- 2a %e         + b)\|a )
+--R                                |     x log(2)
+--R                               \|   %e
+--R       + 
+--R                                                +----------------+
+--R                                                |    x log(2)
+--R                x log(2) 2        x log(2)  +-+ |a %e         - b
+--R         (4a (%e        )  + 6b %e        )\|a  |----------------
+--R                                                |     x log(2)
+--R                                               \|   %e
+--R    /
+--R         2       +-+
+--R       8a log(2)\|a
+--R     ,
+--R
+--R                        +----------------+
+--R                        |    x log(2)
+--R                  +---+ |a %e         - b
+--R                 \|- a  |----------------
+--R                        |     x log(2)
+--R           2           \|   %e
+--R         3b atan(-------------------------)
+--R                             a
+--R       + 
+--R                                                  +----------------+
+--R                                                  |    x log(2)
+--R                x log(2) 2        x log(2)  +---+ |a %e         - b
+--R         (2a (%e        )  + 3b %e        )\|- a  |----------------
+--R                                                  |     x log(2)
+--R                                                 \|   %e
+--R    /
+--R         2       +---+
+--R       4a log(2)\|- a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 827
+
+--S 828 of 1018
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                              +----------------+
+--R                              |    x log(2)
+--R         2           x log(2) |a %e         - b            x log(2)      +-+
+--R       3b log(- 2a %e         |----------------  + (- 2a %e         + b)\|a )
+--R                              |     x log(2)
+--R                             \|   %e
+--R     + 
+--R                   +--------+
+--R                   |   x
+--R                   |a 2  - b
+--R                   |--------                                     +--------+
+--R                   |    x                                        |   x
+--R           2      \|   2                2x - 1        x - 2  +-+ |a 2  - b
+--R       - 6b atanh(-----------) + (- 8a 2       - 24b 2     )\|a  |--------
+--R                       +-+                                       |    x
+--R                      \|a                                       \|   2
+--R     + 
+--R                                              +----------------+
+--R                                              |    x log(2)
+--R              x log(2) 2        x log(2)  +-+ |a %e         - b
+--R       (4a (%e        )  + 6b %e        )\|a  |----------------
+--R                                              |     x log(2)
+--R                                             \|   %e
+--R  /
+--R       2       +-+
+--R     8a log(2)\|a
+--R                                                    Type: Expression(Integer)
+--E 828
+
+--S 829 of 1018
+d0a:=D(m0a,x)
+--R 
+--R
+--R   (5)
+--R                                                            +----------------+
+--R                                                            |    x log(2)
+--R               3   x log(2) 4     2     x log(2) 3  x x +-+ |a %e         - b
+--R           (16a (%e        )  - 8a b (%e        ) )2 4 \|a  |----------------
+--R                                                            |     x log(2)
+--R                                                           \|   %e
+--R         + 
+--R               4   x log(2) 4      3     x log(2) 3  x x
+--R           (16a (%e        )  - 16a b (%e        ) )2 4
+--R      *
+--R          +--------+
+--R          |   x
+--R          |a 2  - b
+--R          |--------
+--R          |    x
+--R         \|   2
+--R     + 
+--R                         4   x log(2) 2      3    x log(2)  x
+--R                   (- 32a (%e        )  + 32a b %e        )2
+--R                 + 
+--R                      3     x log(2) 2      2 2  x log(2)
+--R                   32a b (%e        )  - 32a b %e
+--R              *
+--R                  2x - 1
+--R                 2
+--R             + 
+--R                     3     x log(2) 2      2 2  x log(2)  x - 2 x
+--R               (- 48a b (%e        )  + 48a b %e        )2     2
+--R             + 
+--R                   2 2   x log(2) 2        3  x log(2)  x - 2
+--R               (48a b (%e        )  - 48a b %e        )2
+--R          *
+--R              x
+--R             4
+--R         + 
+--R                3     x log(2) 2     2 2  x log(2)   x 2 2x - 1
+--R           (- 8a b (%e        )  + 8a b %e        )(2 ) 2
+--R         + 
+--R                2 2   x log(2) 2       3  x log(2)   x 3
+--R           (- 6a b (%e        )  + 6a b %e        )(2 )
+--R         + 
+--R                 2 2   x log(2) 2        3  x log(2)  x - 2  x 2
+--R           (- 24a b (%e        )  + 24a b %e        )2     (2 )
+--R      *
+--R          +----------------+
+--R          |    x log(2)
+--R          |a %e         - b
+--R          |----------------
+--R          |     x log(2)
+--R         \|   %e
+--R     + 
+--R                         4   x log(2) 2      3    x log(2)      2 2  x
+--R                   (- 32a (%e        )  + 48a b %e         - 16a b )2
+--R                 + 
+--R                      3     x log(2) 2      2 2  x log(2)        3
+--R                   32a b (%e        )  - 48a b %e         + 16a b
+--R              *
+--R                  2x - 1
+--R                 2
+--R             + 
+--R                     3     x log(2) 2      2 2  x log(2)        3  x - 2 x
+--R               (- 48a b (%e        )  + 72a b %e         - 24a b )2     2
+--R             + 
+--R                   2 2   x log(2) 2        3  x log(2)      4  x - 2
+--R               (48a b (%e        )  - 72a b %e         + 24b )2
+--R          *
+--R              x
+--R             4
+--R         + 
+--R                3     x log(2) 2      2 2  x log(2)       3   x 2 2x - 1
+--R           (- 8a b (%e        )  + 12a b %e         - 4a b )(2 ) 2
+--R         + 
+--R                2 2   x log(2) 2       3  x log(2)     4   x 3
+--R           (- 6a b (%e        )  + 9a b %e         - 3b )(2 )
+--R         + 
+--R                 2 2   x log(2) 2        3  x log(2)      4  x - 2  x 2
+--R           (- 24a b (%e        )  + 36a b %e         - 12b )2     (2 )
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                    +----------------+
+--R                                                    |    x log(2)
+--R             4   x log(2) 2      3    x log(2)  x x |a %e         - b
+--R         (16a (%e        )  - 16a b %e        )2 4  |----------------
+--R                                                    |     x log(2)
+--R                                                   \|   %e
+--R       + 
+--R             4   x log(2) 2      3    x log(2)     2 2  x x +-+
+--R         (16a (%e        )  - 24a b %e         + 8a b )2 4 \|a
+--R    *
+--R        +--------+
+--R        |   x
+--R        |a 2  - b
+--R        |--------
+--R        |    x
+--R       \|   2
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 1018
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         +--------+                       +----------------+
+--R                         |   x                            |    x log(2)
+--R                         |a 2  - b                  +---+ |a %e         - b
+--R                         |--------                 \|- a  |----------------
+--R                         |    x                           |     x log(2)
+--R           2 +---+      \|   2           2 +-+           \|   %e
+--R       - 3b \|- a atanh(-----------) + 3b \|a atan(-------------------------)
+--R                             +-+                               a
+--R                            \|a
+--R     + 
+--R                                             +--------+
+--R                                             |   x
+--R              2x - 1        x - 2  +---+ +-+ |a 2  - b
+--R       (- 4a 2       - 12b 2     )\|- a \|a  |--------
+--R                                             |    x
+--R                                            \|   2
+--R     + 
+--R                                                    +----------------+
+--R                                                    |    x log(2)
+--R              x log(2) 2        x log(2)  +---+ +-+ |a %e         - b
+--R       (2a (%e        )  + 3b %e        )\|- a \|a  |----------------
+--R                                                    |     x log(2)
+--R                                                   \|   %e
+--R  /
+--R       2       +---+ +-+
+--R     4a log(2)\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 830
+
+--S 831 of 1018
+d0b:=D(m0b,x)
+--R 
+--R
+--R   (7)
+--R                            +--------+
+--R                            |   x
+--R         2   x log(2) 2 x x |a 2  - b
+--R       8a (%e        ) 2 4  |--------
+--R                            |    x
+--R                           \|   2
+--R     + 
+--R                  2 x          2x - 1          x - 2 x      2 x - 2  x
+--R           ((- 16a 2  + 16a b)2       - 24a b 2     2  + 24b 2     )4
+--R         + 
+--R                    x 2 2x - 1     2  x 3      2 x - 2  x 2
+--R           - 4a b (2 ) 2       - 3b (2 )  - 12b 2     (2 )
+--R      *
+--R          +----------------+
+--R          |    x log(2)
+--R          |a %e         - b
+--R          |----------------
+--R          |     x log(2)
+--R         \|   %e
+--R  /
+--R             +----------------+ +--------+
+--R             |    x log(2)      |   x
+--R       2 x x |a %e         - b  |a 2  - b
+--R     8a 2 4  |----------------  |--------
+--R             |     x log(2)     |    x
+--R            \|   %e            \|   2
+--R                                                    Type: Expression(Integer)
+--E 831
+
+)clear all
+
+--S 832 of 1018
+t0:=f^(c+d*x)*x^3/(a+b*f^(c+d*x))
+--R 
+--R
+--R           3 d x + c
+--R          x f
+--R   (1)  --------------
+--R           d x + c
+--R        b f        + a
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 1018
+--r0:=x^3*log(1+b*f^(c+d*x)/a)/(b*d*log(f))+3*x^2*polylog(2,-b*f^(c+_
+--   d*x)/a)/(b*d^2*log(f)^2)-6*x*polylog(3,-b*f^(c+d*x)/a)/(b*d^3*_
+--   log(f)^3)+6*polylog(4,-b*f^(c+d*x)/a)/(b*d^4*log(f)^4)
+--E 833
+
+--S 834 of 1018
+--a0:=integrate(t0,x)
+--E 834
+
+--S 835 of 1018
+--m0:=a0-r0
+--E 835
+
+--S 836 of 1018
+--d0:=normalize(D(m0,x))
+--E 836
+
+)clear all
+
+--S 837 of 1018
+t0:=f^(c+d*x)*x^2/(a+b*f^(c+d*x))
+--R 
+--R
+--R           2 d x + c
+--R          x f
+--R   (1)  --------------
+--R           d x + c
+--R        b f        + a
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 1018
+--r0:=x^2*log(1+b*f^(c+d*x)/a)/(b*d*log(f))+2*x*polylog(2,-b*f^(c+_
+--   d*x)/a)/(b*d^2*log(f)^2)-2*polylog(3,-b*f^(c+d*x)/a)/(b*d^3*log(f)^3)
+--E 838
+
+--S 839 of 1018
+--a0:=integrate(t0,x)
+--E 839
+
+--S 840 of 1018
+--m0:=a0-r0
+--E 840
+
+--S 841 of 1018
+--d0:=normalize(D(m0,x))
+--E 841
+
+)clear all
+
+--S 842 of 1018
+t0:=f^(c+d*x)*x/(a+b*f^(c+d*x))
+--R 
+--R
+--R             d x + c
+--R          x f
+--R   (1)  --------------
+--R           d x + c
+--R        b f        + a
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 1018
+--r0:=x*log(1+b*f^(c+d*x)/a)/(b*d*log(f))+polylog(2,-b*f^(c+d*x)/a)/_
+--   (b*d^2*log(f)^2)
+--E 843
+
+--S 844 of 1018
+--a0:=integrate(t0,x)
+--E 844
+
+--S 845 of 1018
+--m0:=a0-r0
+--E 845
+
+--S 846 of 1018
+--d0:=normalize(D(m0,x))
+--E 846
+
+)clear all
+
+--S 847 of 1018
+t0:=f^(c+d*x)/(a+b*f^(c+d*x))
+--R 
+--R
+--R            d x + c
+--R           f
+--R   (1)  --------------
+--R           d x + c
+--R        b f        + a
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1018
+r0:=log(a+b*f^(c+d*x))/(b*d*log(f))
+--R 
+--R
+--R               d x + c
+--R        log(b f        + a)
+--R   (2)  -------------------
+--R             b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 848
+
+--S 849 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                (d x + c)log(f)
+--R        log(b %e                + a)
+--R   (3)  ----------------------------
+--R                 b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 849
+
+--S 850 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                (d x + c)log(f)               d x + c
+--R        log(b %e                + a) - log(b f        + a)
+--R   (4)  --------------------------------------------------
+--R                            b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 850
+
+--S 851 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 851
+
+)clear all
+
+--S 852 of 1018
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))*x)
+--R 
+--R
+--R              d x + c
+--R             f
+--R   (1)  ------------------
+--R             d x + c
+--R        b x f        + a x
+--R                                                    Type: Expression(Integer)
+--E 852
+
+--S 853 of 1018
+--r0:=Int(f^(c+d*x)/((a+b*f^(c+d*x))*x),x)
+--E 853
+
+--S 854 of 1018
+--a0:=integrate(t0,x)
+--E 854
+
+--S 855 of 1018
+--m0:=a0-r0
+--E 855
+
+--S 856 of 1018
+--d0:=normalize(D(m0,x))
+--E 856
+
+)clear all
+
+--S 857 of 1018
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))*x^2)
+--R 
+--R
+--R               d x + c
+--R              f
+--R   (1)  -------------------
+--R           2 d x + c      2
+--R        b x f        + a x
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 1018
+--r0:=Int(f^(c+d*x)/((a+b*f^(c+d*x))*x^2),x)
+--E 858
+
+--S 859 of 1018
+--a0:=integrate(t0,x)
+--E 859
+
+--S 860 of 1018
+--m0:=a0-r0
+--E 860
+
+--S 861 of 1018
+--d0:=normalize(D(m0,x))
+--E 861
+
+)clear all
+
+--S 862 of 1018
+t0:=f^(c+d*x)*x^3/(a+b*f^(c+d*x))^2
+--R 
+--R
+--R                     3 d x + c
+--R                    x f
+--R   (1)  ----------------------------------
+--R         2  d x + c 2         d x + c    2
+--R        b (f       )  + 2a b f        + a
+--R                                                    Type: Expression(Integer)
+--E 862
+
+--S 863 of 1018
+--r0:=x^3/(a*b*d*log(f))-x^3/(b*d*(a+b*f^(c+d*x))*log(f))-3*x^2*log(1+b*_
+--   f^(c+d*x)/a)/(a*b*d^2*log(f)^2)-6*x*polylog(2,-b*f^(c+d*x)/a)/_
+--   (a*b*d^3*log(f)^3)+6*polylog(3,-b*f^(c+d*x)/a)/(a*b*d^4*log(f)^4)
+--E 863
+
+--S 864 of 1018
+--a0:=integrate(t0,x)
+--E 864
+
+--S 865 of 1018
+--m0:=a0-r0
+--E 865
+
+--S 866 of 1018
+--d0:=normalize(D(m0,x))
+--E 866
+
+)clear all
+
+--S 867 of 1018
+t0:=f^(c+d*x)*x^2/(a+b*f^(c+d*x))^2
+--R 
+--R
+--R                     2 d x + c
+--R                    x f
+--R   (1)  ----------------------------------
+--R         2  d x + c 2         d x + c    2
+--R        b (f       )  + 2a b f        + a
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 1018
+--r0:=x^2/(a*b*d*log(f))-x^2/(b*d*(a+b*f^(c+d*x))*log(f))-2*x*log(1+_
+--   b*f^(c+d*x)/a)/(a*b*d^2*log(f)^2)-2*polylog(2,-b*f^(c+d*x)/a)/_
+--   (a*b*d^3*log(f)^3)
+--E 868
+
+--S 869 of 1018
+--a0:=integrate(t0,x)
+--E 869
+
+--S 870 of 1018
+--m0:=a0-r0
+--E 870
+
+--S 871 of 1018
+--d0:=normalize(D(m0,x))
+--E 871
+
+)clear all
+
+--S 872 of 1018
+t0:=f^(c+d*x)*x/(a+b*f^(c+d*x))^2
+--R 
+--R
+--R                       d x + c
+--R                    x f
+--R   (1)  ----------------------------------
+--R         2  d x + c 2         d x + c    2
+--R        b (f       )  + 2a b f        + a
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 1018
+r0:=x/(a*b*d*log(f))-x/(b*d*(a+b*f^(c+d*x))*log(f))-log(a+b*f^(c+d*x))/_
+   (a*b*d^2*log(f)^2)
+--R 
+--R
+--R              d x + c            d x + c                     d x + c
+--R        (- b f        - a)log(b f        + a) + b d x log(f)f
+--R   (2)  ------------------------------------------------------------
+--R                       2 2      2 d x + c    2   2      2
+--R                    a b d log(f) f        + a b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 873
+
+--S 874 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              (d x + c)log(f)             (d x + c)log(f)
+--R       (- b %e                - a)log(b %e                + a)
+--R     + 
+--R                     (d x + c)log(f)
+--R       b d x log(f)%e
+--R  /
+--R        2 2      2  (d x + c)log(f)    2   2      2
+--R     a b d log(f) %e                + a b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 874
+
+--S 875 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2 d x + c         (d x + c)log(f)        d x + c    2
+--R         ((- b f        - a b)%e                - a b f        - a )
+--R      *
+--R                 (d x + c)log(f)
+--R         log(b %e                + a)
+--R     + 
+--R            2 d x + c         (d x + c)log(f)        d x + c    2
+--R         ((b f        + a b)%e                + a b f        + a )
+--R      *
+--R                d x + c
+--R         log(b f        + a)
+--R     + 
+--R                       (d x + c)log(f)                  d x + c
+--R       a b d x log(f)%e                - a b d x log(f)f
+--R  /
+--R           3 2      2 d x + c    2 2 2      2   (d x + c)log(f)
+--R       (a b d log(f) f        + a b d log(f) )%e
+--R     + 
+--R        2 2 2      2 d x + c    3   2      2
+--R       a b d log(f) f        + a b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 875
+
+--S 876 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 876
+
+)clear all
+
+--S 877 of 1018
+t0:=f^(c+d*x)/(a+b*f^(c+d*x))^2
+--R 
+--R
+--R                      d x + c
+--R                     f
+--R   (1)  ----------------------------------
+--R         2  d x + c 2         d x + c    2
+--R        b (f       )  + 2a b f        + a
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--S 878 of 1018
+r0:=(-1)/(b*d*(a+b*f^(c+d*x))*log(f))
+--R 
+--R
+--R                          1
+--R   (2)  - ---------------------------------
+--R           2         d x + c
+--R          b d log(f)f        + a b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 878
+
+--S 879 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               1
+--R   (3)  - ------------------------------------------
+--R           2          (d x + c)log(f)
+--R          b d log(f)%e                + a b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 879
+
+--S 880 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       (d x + c)log(f)    d x + c
+--R     %e                - f
+--R  /
+--R         2         d x + c                  (d x + c)log(f)
+--R       (b d log(f)f        + a b d log(f))%e
+--R     + 
+--R                    d x + c    2
+--R       a b d log(f)f        + a d log(f)
+--R                                                    Type: Expression(Integer)
+--E 880
+
+--S 881 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 881
+
+)clear all
+
+--S 882 of 1018
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))^2*x)
+--R 
+--R
+--R                         d x + c
+--R                        f
+--R   (1)  ---------------------------------------
+--R         2    d x + c 2           d x + c    2
+--R        b x (f       )  + 2a b x f        + a x
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 1018
+--r0:=(-1)/(b*d*(a+b*f^(c+d*x))*x*log(f))-Int(1/((a+b*f^(c+d*x))*x^2),x)/_
+--   (b*d*log(f))
+--E 883
+
+--S 884 of 1018
+--a0:=integrate(t0,x)
+--E 884
+
+--S 885 of 1018
+--m0:=a0-r0
+--E 885
+
+--S 886 of 1018
+--d0:=normalize(D(m0,x))
+--E 886
+
+)clear all
+
+--S 887 of 1018
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))^2*x^2)
+--R 
+--R
+--R                         d x + c
+--R                        f
+--R   (1)  ----------------------------------------
+--R         2 2  d x + c 2         2 d x + c    2 2
+--R        b x (f       )  + 2a b x f        + a x
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 1018
+--r0:=(-1)/(b*d*(a+b*f^(c+d*x))*x^2*log(f))-2*Int(1/((a+b*f^(c+d*x))*_
+--   x^3),x)/(b*d*log(f))
+--E 888
+
+--S 889 of 1018
+--a0:=integrate(t0,x)
+--E 889
+
+--S 890 of 1018
+--m0:=a0-r0
+--E 890
+
+--S 891 of 1018
+--d0:=normalize(D(m0,x))
+--E 891
+
+)clear all
+
+--S 892 of 1018
+t0:=f^(c+d*x)*x^3/(a+b*f^(c+d*x))^3
+--R 
+--R
+--R                               3 d x + c
+--R                              x f
+--R   (1)  -----------------------------------------------------
+--R         3  d x + c 3       2  d x + c 2     2   d x + c    3
+--R        b (f       )  + 3a b (f       )  + 3a b f        + a
+--R                                                    Type: Expression(Integer)
+--E 892
+
+--S 893 of 1018
+--r0:=-3/2*x^2/(a^2*b*d^2*log(f)^2)+3/2*x^2/(a*b*d^2*(a+b*f^(c+d*x))*_
+--   log(f)^2)+1/2*x^3/(a^2*b*d*log(f))-1/2*x^3/(b*d*(a+b*f^(c+d*x))^2*_
+--   log(f))+3*x*log(1+b*f^(c+d*x)/a)/(a^2*b*d^3*log(f)^3)-3/2*x^2*_
+--   log(1+b*f^(c+d*x)/a)/(a^2*b*d^2*log(f)^2)+3*polylog(2,-b*f^(c+_
+--   d*x)/a)/(a^2*b*d^4*log(f)^4)-3*x*polylog(2,-b*f^(c+d*x)/a)/(a^2*b*_
+--   d^3*log(f)^3)+3*polylog(3,-b*f^(c+d*x)/a)/(a^2*b*d^4*log(f)^4)
+--E 893
+
+--S 894 of 1018
+--a0:=integrate(t0,x)
+--E 894
+
+--S 895 of 1018
+--m0:=a0-r0
+--E 895
+
+--S 896 of 1018
+--d0:=normalize(D(m0,x))
+--E 896
+
+)clear all
+
+--S 897 of 1018
+t0:=f^(c+d*x)*x^2/(a+b*f^(c+d*x))^3
+--R 
+--R
+--R                               2 d x + c
+--R                              x f
+--R   (1)  -----------------------------------------------------
+--R         3  d x + c 3       2  d x + c 2     2   d x + c    3
+--R        b (f       )  + 3a b (f       )  + 3a b f        + a
+--R                                                    Type: Expression(Integer)
+--E 897
+
+--S 898 of 1018
+--r0:=-x/(a^2*b*d^2*log(f)^2)+x/(a*b*d^2*(a+b*f^(c+d*x))*log(f)^2)+1/2*x^2/_
+--   (a^2*b*d*log(f))-1/2*x^2/(b*d*(a+b*f^(c+d*x))^2*log(f))+log(a+b*_
+--   f^(c+d*x))/(a^2*b*d^3*log(f)^3)-x*log(1+b*f^(c+d*x)/a)/(a^2*b*d^2*_
+--   log(f)^2)-polylog(2,-b*f^(c+d*x)/a)/(a^2*b*d^3*log(f)^3)
+--E 898
+
+--S 899 of 1018
+--a0:=integrate(t0,x)
+--E 899
+
+--S 900 of 1018
+--m0:=a0-r0
+--E 900
+
+--S 901 of 1018
+--d0:=normalize(D(m0,x))
+--E 901
+
+)clear all
+
+--S 902 of 1018
+t0:=f^(c+d*x)*x/(a+b*f^(c+d*x))^3
+--R 
+--R
+--R                                 d x + c
+--R                              x f
+--R   (1)  -----------------------------------------------------
+--R         3  d x + c 3       2  d x + c 2     2   d x + c    3
+--R        b (f       )  + 3a b (f       )  + 3a b f        + a
+--R                                                    Type: Expression(Integer)
+--E 902
+
+--S 903 of 1018
+r0:=1/2/(a*b*d^2*(a+b*f^(c+d*x))*log(f)^2)+1/2*x/(a^2*b*d*log(f))-1/2*x/_
+   (b*d*(a+b*f^(c+d*x))^2*log(f))-1/2*log(a+b*f^(c+d*x))/(a^2*b*d^2*log(f)^2)
+--R 
+--R
+--R   (2)
+--R           2  d x + c 2         d x + c    2        d x + c
+--R       (- b (f       )  - 2a b f        - a )log(b f        + a)
+--R     + 
+--R        2            d x + c 2                           d x + c    2
+--R       b d x log(f)(f       )  + (2a b d x log(f) + a b)f        + a
+--R  /
+--R       2 3 2      2  d x + c 2     3 2 2      2 d x + c     4   2      2
+--R     2a b d log(f) (f       )  + 4a b d log(f) f        + 2a b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 903
+
+--S 904 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2   (d x + c)log(f) 2          (d x + c)log(f)    2
+--R         (- b (%e               )  - 2a b %e                - a )
+--R      *
+--R                 (d x + c)log(f)
+--R         log(b %e                + a)
+--R     + 
+--R        2             (d x + c)log(f) 2
+--R       b d x log(f)(%e               )
+--R     + 
+--R                                (d x + c)log(f)    2
+--R       (2a b d x log(f) + a b)%e                + a
+--R  /
+--R         2 3 2      2   (d x + c)log(f) 2     3 2 2      2  (d x + c)log(f)
+--R       2a b d log(f) (%e               )  + 4a b d log(f) %e
+--R     + 
+--R         4   2      2
+--R       2a b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 904
+
+--S 905 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               4  d x + c 2       3 d x + c    2 2    (d x + c)log(f) 2
+--R           (- b (f       )  - 2a b f        - a b )(%e               )
+--R         + 
+--R                  3  d x + c 2     2 2 d x + c     3    (d x + c)log(f)
+--R           (- 2a b (f       )  - 4a b f        - 2a b)%e
+--R         + 
+--R              2 2  d x + c 2     3   d x + c    4
+--R           - a b (f       )  - 2a b f        - a
+--R      *
+--R                 (d x + c)log(f)
+--R         log(b %e                + a)
+--R     + 
+--R             4  d x + c 2       3 d x + c    2 2    (d x + c)log(f) 2
+--R           (b (f       )  + 2a b f        + a b )(%e               )
+--R         + 
+--R                3  d x + c 2     2 2 d x + c     3    (d x + c)log(f)
+--R           (2a b (f       )  + 4a b f        + 2a b)%e
+--R         + 
+--R            2 2  d x + c 2     3   d x + c    4
+--R           a b (f       )  + 2a b f        + a
+--R      *
+--R                d x + c
+--R         log(b f        + a)
+--R     + 
+--R             3 d x + c    2 2              2 2    (d x + c)log(f) 2
+--R       (- a b f        + a b d x log(f) - a b )(%e               )
+--R     + 
+--R           3  d x + c 2     3                3    (d x + c)log(f)
+--R       (a b (f       )  + 2a b d x log(f) - a b)%e
+--R     + 
+--R           2 2              2 2   d x + c 2        3                3   d x + c
+--R       (- a b d x log(f) + a b )(f       )  + (- 2a b d x log(f) + a b)f
+--R  /
+--R            2 5 2      2  d x + c 2     3 4 2      2 d x + c     4 3 2      2
+--R         (2a b d log(f) (f       )  + 4a b d log(f) f        + 2a b d log(f) )
+--R      *
+--R            (d x + c)log(f) 2
+--R         (%e               )
+--R     + 
+--R            3 4 2      2  d x + c 2     4 3 2      2 d x + c     5 2 2      2
+--R         (4a b d log(f) (f       )  + 8a b d log(f) f        + 4a b d log(f) )
+--R      *
+--R           (d x + c)log(f)
+--R         %e
+--R     + 
+--R         4 3 2      2  d x + c 2     5 2 2      2 d x + c     6   2      2
+--R       2a b d log(f) (f       )  + 4a b d log(f) f        + 2a b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 905
+
+--S 906 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 906
+
+)clear all
+
+--S 907 of 1018
+t0:=f^(c+d*x)/(a+b*f^(c+d*x))^3
+--R 
+--R
+--R                                d x + c
+--R                               f
+--R   (1)  -----------------------------------------------------
+--R         3  d x + c 3       2  d x + c 2     2   d x + c    3
+--R        b (f       )  + 3a b (f       )  + 3a b f        + a
+--R                                                    Type: Expression(Integer)
+--E 907
+
+--S 908 of 1018
+r0:=(-1/2)/(b*d*(a+b*f^(c+d*x))^2*log(f))
+--R 
+--R
+--R                                         1
+--R   (2)  - --------------------------------------------------------------
+--R            3          d x + c 2       2         d x + c     2
+--R          2b d log(f)(f       )  + 4a b d log(f)f        + 2a b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 908
+
+--S 909 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   -
+--R        1
+--R     /
+--R            3           (d x + c)log(f) 2       2          (d x + c)log(f)
+--R          2b d log(f)(%e               )  + 4a b d log(f)%e
+--R        + 
+--R            2
+--R          2a b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 909
+
+--S 910 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          (d x + c)log(f) 2        (d x + c)log(f)       d x + c 2       d x + c
+--R     b (%e               )  + 2a %e                - b (f       )  - 2a f
+--R  /
+--R            4          d x + c 2       3         d x + c     2 2
+--R         (2b d log(f)(f       )  + 4a b d log(f)f        + 2a b d log(f))
+--R      *
+--R            (d x + c)log(f) 2
+--R         (%e               )
+--R     + 
+--R              3          d x + c 2     2 2         d x + c     3
+--R         (4a b d log(f)(f       )  + 8a b d log(f)f        + 4a b d log(f))
+--R      *
+--R           (d x + c)log(f)
+--R         %e
+--R     + 
+--R         2 2          d x + c 2     3           d x + c     4
+--R       2a b d log(f)(f       )  + 4a b d log(f)f        + 2a d log(f)
+--R                                                    Type: Expression(Integer)
+--E 910
+
+--S 911 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 911
+
+)clear all
+
+--S 912 of 1018
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))^3*x)
+--R 
+--R
+--R                                   d x + c
+--R                                  f
+--R   (1)  ------------------------------------------------------------
+--R         3    d x + c 3       2    d x + c 2     2     d x + c    3
+--R        b x (f       )  + 3a b x (f       )  + 3a b x f        + a x
+--R                                                    Type: Expression(Integer)
+--E 912
+
+--S 913 of 1018
+--r0:=(-1/2)/(b*d*(a+b*f^(c+d*x))^2*x*log(f))-1/2*Int(1/((a+b*f^(c+d*x))^2*_
+--   x^2),x)/(b*d*log(f))
+--E 913
+
+--S 914 of 1018
+--a0:=integrate(t0,x)
+--E 914
+
+--S 915 of 1018
+--m0:=a0-r0
+--E 915
+
+--S 916 of 1018
+--d0:=normalize(D(m0,x))
+--E 916
+
+)clear all
+
+--S 917 of 1018
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))^3*x^2)
+--R 
+--R
+--R                                    d x + c
+--R                                   f
+--R   (1)  -------------------------------------------------------------
+--R         3 2  d x + c 3       2 2  d x + c 2     2   2 d x + c    3 2
+--R        b x (f       )  + 3a b x (f       )  + 3a b x f        + a x
+--R                                                    Type: Expression(Integer)
+--E 917
+
+--S 918 of 1018
+--r0:=(-1/2)/(b*d*(a+b*f^(c+d*x))^2*x^2*log(f))-Int(1/((a+b*f^(c+d*x))^2*_
+--   x^3),x)/(b*d*log(f))
+--E 918
+
+--S 919 of 1018
+--a0:=integrate(t0,x)
+--E 919
+
+--S 920 of 1018
+--m0:=a0-r0
+--E 920
+
+--S 921 of 1018
+--d0:=normalize(D(m0,x))
+--E 921
+
+)clear all
+
+--S 922 of 1018
+t0:=%e^x/(4+6*%e^x)
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R           x
+--R        6%e  + 4
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 1018
+r0:=1/6*log(2+3*%e^x)
+--R 
+--R
+--R               x
+--R        log(3%e  + 2)
+--R   (2)  -------------
+--R              6
+--R                                                    Type: Expression(Integer)
+--E 923
+
+--S 924 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R               x
+--R        log(3%e  + 2)
+--R   (3)  -------------
+--R              6
+--R                                         Type: Union(Expression(Integer),...)
+--E 924
+
+--S 925 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 925
+
+--S 926 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 926
+
+)clear all
+
+--S 927 of 1018
+t0:=%e^x/(a+%e^x*b)
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  ---------
+--R            x
+--R        b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 927
+
+--S 928 of 1018
+r0:=log(a+%e^x*b)/b
+--R 
+--R
+--R                x
+--R        log(b %e  + a)
+--R   (2)  --------------
+--R               b
+--R                                                    Type: Expression(Integer)
+--E 928
+
+--S 929 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                x
+--R        log(b %e  + a)
+--R   (3)  --------------
+--R               b
+--R                                         Type: Union(Expression(Integer),...)
+--E 929
+
+--S 930 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 930
+
+--S 931 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 931
+
+)clear all
+
+--S 932 of 1018
+t0:=%e^(d*x)/(a+%e^(c+d*x)*b)
+--R 
+--R
+--R               d x
+--R             %e
+--R   (1)  ---------------
+--R            d x + c
+--R        b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 932
+
+--S 933 of 1018
+r0:=log(a+%e^(c+d*x)*b)/(%e^c*b*d)
+--R 
+--R
+--R                d x + c
+--R        log(b %e        + a)
+--R   (2)  --------------------
+--R                     c
+--R               b d %e
+--R                                                    Type: Expression(Integer)
+--E 933
+
+--S 934 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R          - c        d x + c
+--R        %e   log(b %e        + a)
+--R   (3)  -------------------------
+--R                   b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 934
+
+--S 935 of 1018
+m0:=a0-r0
+--R 
+--R
+--R           - c  c             d x + c
+--R        (%e   %e  - 1)log(b %e        + a)
+--R   (4)  ----------------------------------
+--R                            c
+--R                      b d %e
+--R                                                    Type: Expression(Integer)
+--E 935
+
+--S 936 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 936
+
+)clear all
+
+--S 937 of 1018
+t0:=%e^(c+d*x)/(a+%e^(c+d*x)*b)
+--R 
+--R
+--R             d x + c
+--R           %e
+--R   (1)  ---------------
+--R            d x + c
+--R        b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 937
+
+--S 938 of 1018
+r0:=log(a+%e^(c+d*x)*b)/(b*d)
+--R 
+--R
+--R                d x + c
+--R        log(b %e        + a)
+--R   (2)  --------------------
+--R                 b d
+--R                                                    Type: Expression(Integer)
+--E 938
+
+--S 939 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                d x + c
+--R        log(b %e        + a)
+--R   (3)  --------------------
+--R                 b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 939
+
+--S 940 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 940
+
+--S 941 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 941
+
+)clear all
+
+--S 942 of 1018
+t0:=%e^x*(a+%e^x*b)^n
+--R 
+--R
+--R          x     x     n
+--R   (1)  %e (b %e  + a)
+--R                                                    Type: Expression(Integer)
+--E 942
+
+--S 943 of 1018
+r0:=(a+%e^x*b)^(1+n)/(b*(1+n))
+--R 
+--R
+--R             x     n + 1
+--R        (b %e  + a)
+--R   (2)  ----------------
+--R             b n + b
+--R                                                    Type: Expression(Integer)
+--E 943
+
+--S 944 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               x
+--R             x       n log(b %e  + a)
+--R        (b %e  + a)%e
+--R   (3)  -----------------------------
+--R                   b n + b
+--R                                         Type: Union(Expression(Integer),...)
+--E 944
+
+--S 945 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                               x
+--R             x       n log(b %e  + a)        x     n + 1
+--R        (b %e  + a)%e                 - (b %e  + a)
+--R   (4)  ------------------------------------------------
+--R                             b n + b
+--R                                                    Type: Expression(Integer)
+--E 945
+
+--S 946 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 946
+
+)clear all
+
+--S 947 of 1018
+t0:=%e^(d*x)*(a+%e^(c+d*x)*b)^n
+--R 
+--R
+--R          d x     d x + c     n
+--R   (1)  %e   (b %e        + a)
+--R                                                    Type: Expression(Integer)
+--E 947
+
+--S 948 of 1018
+r0:=(a+%e^(c+d*x)*b)^(1+n)/(%e^c*b*d*(1+n))
+--R 
+--R
+--R             d x + c     n + 1
+--R        (b %e        + a)
+--R   (2)  ----------------------
+--R                          c
+--R           (b d n + b d)%e
+--R                                                    Type: Expression(Integer)
+--E 948
+
+--S 949 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                d x + c
+--R             - c  d x + c       - c   n log(b %e        + a)
+--R        (b %e   %e        + a %e   )%e
+--R   (3)  ----------------------------------------------------
+--R                             b d n + b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 949
+
+--S 950 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                     d x + c
+--R            - c  c  d x + c       - c  c   n log(b %e        + a)
+--R       (b %e   %e %e        + a %e   %e )%e
+--R     + 
+--R              d x + c     n + 1
+--R       - (b %e        + a)
+--R  /
+--R                    c
+--R     (b d n + b d)%e
+--R                                                    Type: Expression(Integer)
+--E 950
+
+--S 951 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 951
+
+)clear all
+
+--S 952 of 1018
+t0:=%e^(c+d*x)*(a+%e^(c+d*x)*b)^n
+--R 
+--R
+--R          d x + c     d x + c     n
+--R   (1)  %e       (b %e        + a)
+--R                                                    Type: Expression(Integer)
+--E 952
+
+--S 953 of 1018
+r0:=(a+%e^(c+d*x)*b)^(1+n)/(b*d*(1+n))
+--R 
+--R
+--R             d x + c     n + 1
+--R        (b %e        + a)
+--R   (2)  ----------------------
+--R              b d n + b d
+--R                                                    Type: Expression(Integer)
+--E 953
+
+--S 954 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                     d x + c
+--R             d x + c       n log(b %e        + a)
+--R        (b %e        + a)%e
+--R   (3)  -----------------------------------------
+--R                       b d n + b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 954
+
+--S 955 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                                     d x + c
+--R             d x + c       n log(b %e        + a)        d x + c     n + 1
+--R        (b %e        + a)%e                       - (b %e        + a)
+--R   (4)  ------------------------------------------------------------------
+--R                                    b d n + b d
+--R                                                    Type: Expression(Integer)
+--E 955
+
+--S 956 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 956
+
+)clear all
+
+--S 957 of 1018
+t0:=f^x/(a+b*f^x)
+--R 
+--R
+--R            x
+--R           f
+--R   (1)  --------
+--R           x
+--R        b f  + a
+--R                                                    Type: Expression(Integer)
+--E 957
+
+--S 958 of 1018
+r0:=log(a+b*f^x)/(b*log(f))
+--R 
+--R
+--R               x
+--R        log(b f  + a)
+--R   (2)  -------------
+--R           b log(f)
+--R                                                    Type: Expression(Integer)
+--E 958
+
+--S 959 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                x log(f)
+--R        log(b %e         + a)
+--R   (3)  ---------------------
+--R               b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 959
+
+--S 960 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                x log(f)               x
+--R        log(b %e         + a) - log(b f  + a)
+--R   (4)  -------------------------------------
+--R                       b log(f)
+--R                                                    Type: Expression(Integer)
+--E 960
+
+--S 961 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 961
+
+)clear all
+
+--S 962 of 1018
+t0:=f^(d*x)/(a+b*f^(c+d*x))
+--R 
+--R
+--R              d x
+--R             f
+--R   (1)  --------------
+--R           d x + c
+--R        b f        + a
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 1018
+r0:=log(a+b*f^(c+d*x))/(b*d*f^c*log(f))
+--R 
+--R
+--R               d x + c
+--R        log(b f        + a)
+--R   (2)  -------------------
+--R                       c
+--R            b d log(f)f
+--R                                                    Type: Expression(Integer)
+--E 963
+
+--S 964 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R          - c log(f)        (d x + c)log(f)
+--R        %e          log(b %e                + a)
+--R   (3)  ----------------------------------------
+--R                       b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 964
+
+--S 965 of 1018
+m0:=a0-r0
+--R 
+--R
+--R         c  - c log(f)        (d x + c)log(f)               d x + c
+--R        f %e          log(b %e                + a) - log(b f        + a)
+--R   (4)  ----------------------------------------------------------------
+--R                                             c
+--R                                  b d log(f)f
+--R                                                    Type: Expression(Integer)
+--E 965
+
+--S 966 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 966
+
+)clear all
+
+--S 967 of 1018
+t0:=f^(c+d*x)/(a+b*f^(c+d*x))
+--R 
+--R
+--R            d x + c
+--R           f
+--R   (1)  --------------
+--R           d x + c
+--R        b f        + a
+--R                                                    Type: Expression(Integer)
+--E 967
+
+--S 968 of 1018
+r0:=log(a+b*f^(c+d*x))/(b*d*log(f))
+--R 
+--R
+--R               d x + c
+--R        log(b f        + a)
+--R   (2)  -------------------
+--R             b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 968
+
+--S 969 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                (d x + c)log(f)
+--R        log(b %e                + a)
+--R   (3)  ----------------------------
+--R                 b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 969
+
+--S 970 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                (d x + c)log(f)               d x + c
+--R        log(b %e                + a) - log(b f        + a)
+--R   (4)  --------------------------------------------------
+--R                            b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 970
+
+--S 971 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 971
+
+)clear all
+
+--S 972 of 1018
+t0:=f^x*(a+b*f^x)^n
+--R 
+--R
+--R         x    x     n
+--R   (1)  f (b f  + a)
+--R                                                    Type: Expression(Integer)
+--E 972
+
+--S 973 of 1018
+r0:=(a+b*f^x)^(1+n)/(b*(1+n)*log(f))
+--R 
+--R
+--R            x     n + 1
+--R        (b f  + a)
+--R   (2)  ---------------
+--R        (b n + b)log(f)
+--R                                                    Type: Expression(Integer)
+--E 973
+
+--S 974 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                      x log(f)
+--R             x log(f)       n log(b %e         + a)
+--R        (b %e         + a)%e
+--R   (3)  -------------------------------------------
+--R                      (b n + b)log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 974
+
+--S 975 of 1018
+m0:=a0-r0
+--R 
+--R
+--R                                      x log(f)
+--R             x log(f)       n log(b %e         + a)       x     n + 1
+--R        (b %e         + a)%e                        - (b f  + a)
+--R   (4)  -------------------------------------------------------------
+--R                               (b n + b)log(f)
+--R                                                    Type: Expression(Integer)
+--E 975
+
+--S 976 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 976
+
+)clear all
+
+--S 977 of 1018
+t0:=f^(d*x)*(a+b*f^(c+d*x))^n
+--R 
+--R
+--R         d x    d x + c     n
+--R   (1)  f   (b f        + a)
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 1018
+r0:=(a+b*f^(c+d*x))^(1+n)/(b*d*f^c*(1+n)*log(f))
+--R 
+--R
+--R            d x + c     n + 1
+--R        (b f        + a)
+--R   (2)  ---------------------
+--R                            c
+--R        (b d n + b d)log(f)f
+--R                                                    Type: Expression(Integer)
+--E 978
+
+--S 979 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            - c log(f)  (d x + c)log(f)       - c log(f)
+--R       (b %e          %e                + a %e          )
+--R    *
+--R                   (d x + c)log(f)
+--R         n log(b %e                + a)
+--R       %e
+--R  /
+--R     (b d n + b d)log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 979
+
+--S 980 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             c  - c log(f)  (d x + c)log(f)      c  - c log(f)
+--R         (b f %e          %e                + a f %e          )
+--R      *
+--R                     (d x + c)log(f)
+--R           n log(b %e                + a)
+--R         %e
+--R     + 
+--R             d x + c     n + 1
+--R       - (b f        + a)
+--R  /
+--R                         c
+--R     (b d n + b d)log(f)f
+--R                                                    Type: Expression(Integer)
+--E 980
+
+--S 981 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 981
+
+)clear all
+
+--S 982 of 1018
+t0:=f^(c+d*x)*(a+b*f^(c+d*x))^n
+--R 
+--R
+--R         d x + c    d x + c     n
+--R   (1)  f       (b f        + a)
+--R                                                    Type: Expression(Integer)
+--E 982
+
+--S 983 of 1018
+r0:=(a+b*f^(c+d*x))^(1+n)/(b*d*(1+n)*log(f))
+--R 
+--R
+--R            d x + c     n + 1
+--R        (b f        + a)
+--R   (2)  ---------------------
+--R         (b d n + b d)log(f)
+--R                                                    Type: Expression(Integer)
+--E 983
+
+--S 984 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                             (d x + c)log(f)
+--R             (d x + c)log(f)       n log(b %e                + a)
+--R        (b %e                + a)%e
+--R   (3)  ---------------------------------------------------------
+--R                           (b d n + b d)log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 984
+
+--S 985 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                            (d x + c)log(f)
+--R            (d x + c)log(f)       n log(b %e                + a)
+--R       (b %e                + a)%e
+--R     + 
+--R             d x + c     n + 1
+--R       - (b f        + a)
+--R  /
+--R     (b d n + b d)log(f)
+--R                                                    Type: Expression(Integer)
+--E 985
+
+--S 986 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 986
+
+)clear all
+
+--S 987 of 1018
+t0:=1/(1+2*%e^x+%e^(2*x))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 987
+
+--S 988 of 1018
+r0:=1/(1+%e^x)+x-log(1+%e^x)
+--R 
+--R
+--R             x           x            x
+--R        (- %e  - 1)log(%e  + 1) + x %e  + x + 1
+--R   (2)  ---------------------------------------
+--R                          x
+--R                        %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 988
+
+--S 989 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R             x           x            x
+--R        (- %e  - 1)log(%e  + 1) + x %e  + x + 1
+--R   (3)  ---------------------------------------
+--R                          x
+--R                        %e  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 989
+
+--S 990 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 990
+
+--S 991 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 991
+
+)clear all
+
+--S 992 of 1018
+t0:=1/(2+3*%e^x+%e^(2*x))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 2
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 1018
+r0:=1/2*x-log(1+%e^x)+1/2*log(2+%e^x)
+--R 
+--R
+--R              x               x
+--R        log(%e  + 2) - 2log(%e  + 1) + x
+--R   (2)  --------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 993
+
+--S 994 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R              x               x
+--R        log(%e  + 2) - 2log(%e  + 1) + x
+--R   (3)  --------------------------------
+--R                        2
+--R                                         Type: Union(Expression(Integer),...)
+--E 994
+
+--S 995 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 995
+
+--S 996 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 996
+
+)clear all
+
+--S 997 of 1018
+t0:=1/(-1+%e^x+%e^(2*x))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R          2x     x
+--R        %e   + %e  - 1
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 1018
+r0:=-x+1/10*log(1+2*%e^x+sqrt(5))*(5-sqrt(5))+1/10*log(1+2*%e^x-sqrt(5))*_
+   (5+sqrt(5))
+--R 
+--R
+--R   (2)
+--R       +-+            x    +-+          +-+            x    +-+
+--R   (- \|5  + 5)log(2%e  + \|5  + 1) + (\|5  + 5)log(2%e  - \|5  + 1) - 10x
+--R   -----------------------------------------------------------------------
+--R                                      10
+--R                                                    Type: Expression(Integer)
+--E 998
+
+--S 999 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        +-+       x 2     x
+--R       \|5 log((%e )  + %e  - 1)
+--R     + 
+--R             +-+   x 2      +-+        x     +-+
+--R           2\|5 (%e )  + (2\|5  - 10)%e  + 3\|5  - 5       +-+
+--R       log(-----------------------------------------) - 2x\|5
+--R                           x 2     x
+--R                        (%e )  + %e  - 1
+--R  /
+--R       +-+
+--R     2\|5
+--R                                         Type: Union(Expression(Integer),...)
+--E 999
+
+--S 1000 of 1018
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        +-+       x 2     x            +-+            x    +-+
+--R       \|5 log((%e )  + %e  - 1) + (- \|5  + 1)log(2%e  + \|5  + 1)
+--R     + 
+--R           +-+            x    +-+
+--R       (- \|5  - 1)log(2%e  - \|5  + 1)
+--R     + 
+--R             +-+   x 2      +-+        x     +-+
+--R           2\|5 (%e )  + (2\|5  - 10)%e  + 3\|5  - 5
+--R       log(-----------------------------------------)
+--R                           x 2     x
+--R                        (%e )  + %e  - 1
+--R  /
+--R       +-+
+--R     2\|5
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+--S 1001 of 1018
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1001
+
+)clear all
+
+--S 1002 of 1018
+t0:=1/(3+3*%e^x+%e^(2*x))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 3
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+--S 1003 of 1018
+--r0:=1/3*x-1/6*log(3+3*%e^x+%e^(2*x))-atan((3+2*%e^x)/sqrt(3))/sqrt(3)
+--E 1003
+
+--S 1004 of 1018
+--a0:=integrate(t0,x)
+--E 1004
+
+--S 1005 of 1018
+--m0:=a0-r0
+--E 1005
+
+--S 1006 of 1018
+--d0:=normalize(D(m0,x))
+--E 1006
+
+)clear all
+
+--S 1007 of 1018
+t0:=1/(a+%e^x*b+%e^(2*x)*c)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R            2x       x
+--R        c %e   + b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 1007
+
+--S 1008 of 1018
+r0:=x/a-1/2*log(a+%e^x*b+%e^(2*x)*c)/a+b*atanh((b+2*%e^x*c)/sqrt(b^2-_
+   4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +-----------+                                          x
+--R          |          2         2x       x                   2c %e  + b
+--R       - \|- 4a c + b  log(c %e   + b %e  + a) + 2b atanh(--------------)
+--R                                                           +-----------+
+--R                                                           |          2
+--R                                                          \|- 4a c + b
+--R     + 
+--R          +-----------+
+--R          |          2
+--R       2x\|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     2a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1008
+
+--S 1009 of 1018
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R           b
+--R        *
+--R           log
+--R                                                     +-----------+
+--R                     2   x 2          x           2  |          2
+--R                  (2c (%e )  + 2b c %e  - 2a c + b )\|- 4a c + b
+--R                + 
+--R                         2     2    x             3
+--R                  (- 8a c  + 2b c)%e  - 4a b c + b
+--R             /
+--R                     x 2       x
+--R                c (%e )  + b %e  + a
+--R       + 
+--R            +-----------+                               +-----------+
+--R            |          2          x 2       x           |          2
+--R         - \|- 4a c + b  log(c (%e )  + b %e  + a) + 2x\|- 4a c + b
+--R    /
+--R          +-----------+
+--R          |          2
+--R       2a\|- 4a c + b
+--R     ,
+--R
+--R            +---------+
+--R            |        2          x 2       x
+--R         - \|4a c - b  log(c (%e )  + b %e  + a)
+--R       + 
+--R                                +---------+
+--R                         x      |        2        +---------+
+--R                   (2c %e  + b)\|4a c - b         |        2
+--R         - 2b atan(------------------------) + 2x\|4a c - b
+--R                                   2
+--R                           4a c - b
+--R    /
+--R          +---------+
+--R          |        2
+--R       2a\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1009
+
+--S 1010 of 1018
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         b
+--R      *
+--R         log
+--R                                                   +-----------+
+--R                   2   x 2          x           2  |          2
+--R                (2c (%e )  + 2b c %e  - 2a c + b )\|- 4a c + b
+--R              + 
+--R                       2     2    x             3
+--R                (- 8a c  + 2b c)%e  - 4a b c + b
+--R           /
+--R                   x 2       x
+--R              c (%e )  + b %e  + a
+--R     + 
+--R        +-----------+
+--R        |          2         2x       x
+--R       \|- 4a c + b  log(c %e   + b %e  + a)
+--R     + 
+--R          +-----------+                                            x
+--R          |          2          x 2       x                   2c %e  + b
+--R       - \|- 4a c + b  log(c (%e )  + b %e  + a) - 2b atanh(--------------)
+--R                                                             +-----------+
+--R                                                             |          2
+--R                                                            \|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     2a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1010
+
+--S 1011 of 1018
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1011
+
+--S 1012 of 1018
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        +-----------+ +---------+
+--R        |          2  |        2         2x       x
+--R       \|- 4a c + b  \|4a c - b  log(c %e   + b %e  + a)
+--R     + 
+--R          +-----------+ +---------+
+--R          |          2  |        2          x 2       x
+--R       - \|- 4a c + b  \|4a c - b  log(c (%e )  + b %e  + a)
+--R     + 
+--R            +---------+             x
+--R            |        2         2c %e  + b
+--R       - 2b\|4a c - b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                           +---------+
+--R            +-----------+           x      |        2
+--R            |          2      (2c %e  + b)\|4a c - b
+--R       - 2b\|- 4a c + b  atan(------------------------)
+--R                                              2
+--R                                      4a c - b
+--R  /
+--R        +-----------+ +---------+
+--R        |          2  |        2
+--R     2a\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 1012
+
+--S 1013 of 1018
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1013
+
+)clear all
+
+--S 1014 of 1018
+t0:=x/(1+2*%e^x+%e^(2*x))
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 1014
+
+--S 1015 of 1018
+--r0:=-x+x/(1+%e^x)+1/2*x^2+log(1+%e^x)-x*log(1+%e^x)-polylog(2,-%e^x)
+--E 1015
+
+--S 1016 of 1018
+--a0:=integrate(t0,x)
+--E 1016
+
+--S 1017 of 1018
+--m0:=a0-r0
+--E 1017
+
+--S 1018 of 1018
+--d0:=normalize(D(m0,x))
+--E 1018
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich24d.input.pamphlet b/src/input/rich24d.input.pamphlet
new file mode 100644
index 0000000..5f2958e
--- /dev/null
+++ b/src/input/rich24d.input.pamphlet
@@ -0,0 +1,11835 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich24d.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Exponential Functions
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich24d.output
+)spool rich24d.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1034
+t0:=x/(2+3*%e^x+%e^(2*x))
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 2
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1034
+--r0:=1/4*x^2+1/2*x*log(1+1/2*%e^x)-x*log(1+%e^x)-polylog(2,-%e^x)+_
+--  1/2*polylog(2,-1/2*%e^x)
+--E 2
+
+--S 3 of 1034
+--a0:=integrate(t0,x)
+--E 3
+
+--S 4 of 1034
+--m0:=a0-r0
+--E 4
+
+--S 5 of 1034
+--d0:=normalize(D(m0,x))
+--E 5
+
+)clear all
+
+--S 6 of 1034
+t0:=x/(-1+%e^x+%e^(2*x))
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R          2x     x
+--R        %e   + %e  - 1
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 1034
+--r0:=x^2/((1-sqrt(5))*sqrt(5))-2*x*log(1+2*%e^x/(1-sqrt(5)))/((1-sqrt(5))*_
+--  sqrt(5))-2*polylog(2,-2*%e^x/(1-sqrt(5)))/((1-sqrt(5))*sqrt(5))-_
+--  x^2/(sqrt(5)*(1+sqrt(5)))+2*x*log(1+2*%e^x/(1+sqrt(5)))/(sqrt(5)*_
+--  (1+sqrt(5)))+2*polylog(2,-2*%e^x/(1+sqrt(5)))/(sqrt(5)*(1+sqrt(5)))
+--E 7
+
+--S 8 of 1034
+--a0:=integrate(t0,x)
+--E 8
+
+--S 9 of 1034
+--m0:=a0-r0
+--E 9
+
+--S 10 of 1034
+--d0:=normalize(D(m0,x))
+--E 10
+
+)clear all
+
+--S 11 of 1034
+t0:=x/(3+3*%e^x+%e^(2*x))
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 3
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1034
+--r0:=-x^2/((3*%i-sqrt(3))*sqrt(3))+2*x*log(1+2*%e^x/(3+%i*sqrt(3)))/_
+--  ((3*%i-sqrt(3))*sqrt(3))+2*polylog(2,-2*%e^x/(3+%i*sqrt(3)))/_
+--  ((3*%i-sqrt(3))*sqrt(3))+x^2/(sqrt(3)*(3*%i+sqrt(3)))-_
+--  2*x*log(1+2*%e^x/(3-%i*sqrt(3)))/(sqrt(3)*(3*%i+sqrt(3)))-_
+--  2*polylog(2,-2*%e^x/(3-%i*sqrt(3)))/(sqrt(3)*(3*%i+sqrt(3)))
+--E 12
+
+--S 13 of 1034
+--a0:=integrate(t0,x)
+--E 13
+
+--S 14 of 1034
+--m0:=a0-r0
+--E 14
+
+--S 15 of 1034
+--d0:=normalize(D(m0,x))
+--E 15
+
+)clear all
+
+--S 16 of 1034
+t0:=x/(a+%e^x*b+%e^(2*x)*c)
+--R 
+--R
+--R                 x
+--R   (1)  ------------------
+--R            2x       x
+--R        c %e   + b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1034
+--r0:=-c*x^2/(b^2-4*a*c-b*sqrt(b^2-4*a*c))+2*c*x*log(1+2*%e^x*c/(b-_
+--  sqrt(b^2-4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-4*a*c))+2*c*polylog(2,_
+--  -2*%e^x*c/(b-sqrt(b^2-4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-4*a*c))-_
+--  c*x^2/(b^2-4*a*c+b*sqrt(b^2-4*a*c))+2*c*x*log(1+2*%e^x*c/(b+_
+--  sqrt(b^2-4*a*c)))/(b^2-4*a*c+b*sqrt(b^2-4*a*c))+2*c*_
+--  polylog(2,-2*%e^x*c/(b+sqrt(b^2-4*a*c)))/(b^2-4*a*c+b*sqrt(b^2-4*a*c))
+--E 17
+
+--S 18 of 1034
+--a0:=integrate(t0,x)
+--E 18
+
+--S 19 of 1034
+--m0:=a0-r0
+--E 19
+
+--S 20 of 1034
+--d0:=normalize(D(m0,x))
+--E 20
+
+)clear all
+
+--S 21 of 1034
+t0:=x^2/(1+2*%e^x+%e^(2*x))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 1034
+--r0:=-x^2+x^2/(1+%e^x)+1/3*x^3+2*x*log(1+%e^x)-x^2*log(1+%e^x)+_
+--  2*polylog(2,-%e^x)-2*x*polylog(2,-%e^x)+2*polylog(3,-%e^x)
+--E 22
+
+--S 23 of 1034
+--a0:=integrate(t0,x)
+--E 23
+
+--S 24 of 1034
+--m0:=a0-r0
+--E 24
+
+--S 25 of 1034
+--d0:=normalize(D(m0,x))
+--E 25
+
+)clear all
+
+--S 26 of 1034
+t0:=x^2/(2+3*%e^x+%e^(2*x))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 2
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1034
+--r0:=1/6*x^3+1/2*x^2*log(1+1/2*%e^x)-x^2*log(1+%e^x)-2*x*polylog(2,-%e^x)+_
+--  x*polylog(2,-1/2*%e^x)+2*polylog(3,-%e^x)-polylog(3,-1/2*%e^x)
+--E 27
+
+--S 28 of 1034
+--a0:=integrate(t0,x)
+--E 28
+
+--S 29 of 1034
+--m0:=a0-r0
+--E 29
+
+--S 30 of 1034
+--d0:=normalize(D(m0,x))
+--E 30
+
+)clear all
+
+--S 31 of 1034
+t0:=x^2/(-1+%e^x+%e^(2*x))
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R          2x     x
+--R        %e   + %e  - 1
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 1034
+--r0:=2/3*x^3/((1-sqrt(5))*sqrt(5))-2*x^2*log(1+2*%e^x/(1-sqrt(5)))/_
+--  ((1-sqrt(5))*sqrt(5))-4*x*polylog(2,-2*%e^x/(1-sqrt(5)))/((1-sqrt(5))*_
+--  sqrt(5))+4*polylog(3,-2*%e^x/(1-sqrt(5)))/((1-sqrt(5))*sqrt(5))-_
+--  2/3*x^3/(sqrt(5)*(1+sqrt(5)))+2*x^2*log(1+2*%e^x/(1+sqrt(5)))/_
+--  (sqrt(5)*(1+sqrt(5)))+4*x*polylog(2,-2*%e^x/(1+sqrt(5)))/_
+--  (sqrt(5)*(1+sqrt(5)))-4*polylog(3,-2*%e^x/(1+sqrt(5)))/_
+--  (sqrt(5)*(1+sqrt(5)))
+--E 32
+
+--S 33 of 1034
+--a0:=integrate(t0,x)
+--E 33
+
+--S 34 of 1034
+--m0:=a0-r0
+--E 34
+
+--S 35 of 1034
+--d0:=normalize(D(m0,x))
+--E 35
+
+)clear all
+
+--S 36 of 1034
+t0:=x^2/(3+3*%e^x+%e^(2*x))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 3
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 1034
+--r0:=-2/3*x^3/((3*%i-sqrt(3))*sqrt(3))+2*x^2*log(1+2*%e^x/(3+%i*sqrt(3)))/_
+--  ((3*%i-sqrt(3))*sqrt(3))+4*x*polylog(2,-2*%e^x/(3+%i*sqrt(3)))/_
+--  ((3*%i-sqrt(3))*sqrt(3))-4*polylog(3,-2*%e^x/(3+%i*sqrt(3)))/_
+--  ((3*%i-sqrt(3))*sqrt(3))+2/3*x^3/(sqrt(3)*(3*%i+sqrt(3)))-2*x^2*_
+--  log(1+2*%e^x/(3-%i*sqrt(3)))/(sqrt(3)*(3*%i+sqrt(3)))-4*x*_
+--  polylog(2,-2*%e^x/(3-%i*sqrt(3)))/(sqrt(3)*(3*%i+sqrt(3)))+4*_
+--  polylog(3,-2*%e^x/(3-%i*sqrt(3)))/(sqrt(3)*(3*%i+sqrt(3)))
+--E 37
+
+--S 38 of 1034
+--a0:=integrate(t0,x)
+--E 38
+
+--S 39 of 1034
+--m0:=a0-r0
+--E 39
+
+--S 40 of 1034
+--d0:=normalize(D(m0,x))
+--E 40
+
+)clear all
+
+--S 41 of 1034
+t0:=x^2/(a+%e^x*b+%e^(2*x)*c)
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  ------------------
+--R            2x       x
+--R        c %e   + b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 1034
+--r0:=-2/3*c*x^3/(b^2-4*a*c-b*sqrt(b^2-4*a*c))+2*c*x^2*log(1+2*%e^x*c/(b-_
+--  sqrt(b^2-4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-4*a*c))+4*c*x*polylog(2,_
+--  -2*%e^x*c/(b-sqrt(b^2-4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-4*a*c))-4*c*_
+--  polylog(3,-2*%e^x*c/(b-sqrt(b^2-4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-_
+--  4*a*c))-2/3*c*x^3/(b^2-4*a*c+b*sqrt(b^2-4*a*c))+2*c*x^2*log(1+_
+--  2*%e^x*c/(b+sqrt(b^2-4*a*c)))/(b^2-4*a*c+b*sqrt(b^2-4*a*c))+_
+--  4*c*x*polylog(2,-2*%e^x*c/(b+sqrt(b^2-4*a*c)))/(b^2-4*a*c+b*_
+--  sqrt(b^2-4*a*c))-4*c*polylog(3,-2*%e^x*c/(b+sqrt(b^2-4*a*c)))/_
+--  (b^2-4*a*c+b*sqrt(b^2-4*a*c))
+--E 42
+
+--S 43 of 1034
+--a0:=integrate(t0,x)
+--E 43
+
+--S 44 of 1034
+--m0:=a0-r0
+--E 44
+
+--S 45 of 1034
+--d0:=normalize(D(m0,x))
+--E 45
+
+)clear all
+
+--S 46 of 1034
+t0:=1/(1+2*f^(c+d*x)+f^(2*c+2*d*x))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R         2d x + 2c     d x + c
+--R        f          + 2f        + 1
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 1034
+r0:=x+1/(d*(1+f^(c+d*x))*log(f))-log(1+f^(c+d*x))/(d*log(f))
+--R 
+--R
+--R   (2)
+--R       d x + c          d x + c                   d x + c
+--R   (- f        - 1)log(f        + 1) + d x log(f)f        + d x log(f) + 1
+--R   -----------------------------------------------------------------------
+--R                                  d x + c
+--R                         d log(f)f        + d log(f)
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            (d x + c)log(f)           (d x + c)log(f)
+--R       (- %e                - 1)log(%e                + 1)
+--R     + 
+--R                   (d x + c)log(f)
+--R       d x log(f)%e                + d x log(f) + 1
+--R  /
+--R               (d x + c)log(f)
+--R     d log(f)%e                + d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              d x + c       (d x + c)log(f)    d x + c
+--R         ((- f        - 1)%e                - f        - 1)
+--R      *
+--R               (d x + c)log(f)
+--R         log(%e                + 1)
+--R     + 
+--R          d x + c       (d x + c)log(f)    d x + c          d x + c
+--R       ((f        + 1)%e                + f        + 1)log(f        + 1)
+--R     + 
+--R           (d x + c)log(f)    d x + c
+--R       - %e                + f
+--R  /
+--R                 d x + c              (d x + c)log(f)            d x + c
+--R       (d log(f)f        + d log(f))%e                + d log(f)f
+--R     + 
+--R       d log(f)
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 1034
+t0:=1/(a+b*f^(c+d*x)+c*f^(2*c+2*d*x))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R           2d x + 2c      d x + c
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 1034
+r0:=x/a-1/2*log(a+b*f^(c+d*x)+c*f^(2*c+2*d*x))/(a*d*log(f))+b*_
+   atanh((b+2*c*f^(c+d*x))/sqrt(b^2-4*a*c))/(a*d*log(f)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +-----------+
+--R          |          2        2d x + 2c      d x + c
+--R       - \|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                    d x + c                    +-----------+
+--R                2c f        + b                |          2
+--R       2b atanh(---------------) + 2d x log(f)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a d log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R            +-----------+
+--R            |          2          (d x + c)log(f) 2       (d x + c)log(f)
+--R         - \|- 4a c + b  log(c (%e               )  + b %e                + a)
+--R       + 
+--R           b
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    (d x + c)log(f) 2
+--R                  2c \|- 4a c + b  (%e               )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    (d x + c)log(f)
+--R                  (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R             /
+--R                     (d x + c)log(f) 2       (d x + c)log(f)
+--R                c (%e               )  + b %e                + a
+--R       + 
+--R                     +-----------+
+--R                     |          2
+--R         2d x log(f)\|- 4a c + b
+--R    /
+--R                   +-----------+
+--R                   |          2
+--R       2a d log(f)\|- 4a c + b
+--R     ,
+--R
+--R            +---------+
+--R            |        2          (d x + c)log(f) 2       (d x + c)log(f)
+--R         - \|4a c - b  log(c (%e               )  + b %e                + a)
+--R       + 
+--R                      +---------+                      +---------+
+--R                      |        2   (d x + c)log(f)     |        2
+--R                   2c\|4a c - b  %e                + b\|4a c - b
+--R         - 2b atan(-----------------------------------------------)
+--R                                              2
+--R                                      4a c - b
+--R       + 
+--R                     +---------+
+--R                     |        2
+--R         2d x log(f)\|4a c - b
+--R    /
+--R                   +---------+
+--R                   |        2
+--R       2a d log(f)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 53
+
+--S 54 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-----------+
+--R          |          2          (d x + c)log(f) 2       (d x + c)log(f)
+--R       - \|- 4a c + b  log(c (%e               )  + b %e                + a)
+--R     + 
+--R         b
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    (d x + c)log(f) 2
+--R                2c \|- 4a c + b  (%e               )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    (d x + c)log(f)
+--R                (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R           /
+--R                   (d x + c)log(f) 2       (d x + c)log(f)
+--R              c (%e               )  + b %e                + a
+--R     + 
+--R        +-----------+
+--R        |          2        2d x + 2c      d x + c
+--R       \|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                      d x + c
+--R                  2c f        + b
+--R       - 2b atanh(---------------)
+--R                    +-----------+
+--R                    |          2
+--R                   \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a d log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       -
+--R             +-----------+ +---------+
+--R             |          2  |        2
+--R            \|- 4a c + b  \|4a c - b
+--R         *
+--R                     (d x + c)log(f) 2       (d x + c)log(f)
+--R            log(c (%e               )  + b %e                + a)
+--R     + 
+--R                                 +---------+                      +---------+
+--R            +-----------+        |        2   (d x + c)log(f)     |        2
+--R            |          2      2c\|4a c - b  %e                + b\|4a c - b
+--R       - 2b\|- 4a c + b  atan(-----------------------------------------------)
+--R                                                         2
+--R                                                 4a c - b
+--R     + 
+--R        +-----------+ +---------+
+--R        |          2  |        2        2d x + 2c      d x + c
+--R       \|- 4a c + b  \|4a c - b  log(c f          + b f        + a)
+--R     + 
+--R            +---------+          d x + c
+--R            |        2       2c f        + b
+--R       - 2b\|4a c - b  atanh(---------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                 +-----------+ +---------+
+--R                 |          2  |        2
+--R     2a d log(f)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 1034
+t0:=1/(a+b*f^(g+h*x)+c*f^(2*(g+h*x)))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R           2h x + 2g      h x + g
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 1034
+r0:=x/a-1/2*log(a+b*f^(g+h*x)+c*f^(2*g+2*h*x))/(a*h*log(f))+_
+   b*atanh((b+2*c*f^(g+h*x))/sqrt(b^2-4*a*c))/(a*h*log(f)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +-----------+
+--R          |          2        2h x + 2g      h x + g
+--R       - \|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                    h x + g                    +-----------+
+--R                2c f        + b                |          2
+--R       2b atanh(---------------) + 2h x log(f)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a h log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R            +-----------+
+--R            |          2          (h x + g)log(f) 2       (h x + g)log(f)
+--R         - \|- 4a c + b  log(c (%e               )  + b %e                + a)
+--R       + 
+--R           b
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    (h x + g)log(f) 2
+--R                  2c \|- 4a c + b  (%e               )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    (h x + g)log(f)
+--R                  (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R             /
+--R                     (h x + g)log(f) 2       (h x + g)log(f)
+--R                c (%e               )  + b %e                + a
+--R       + 
+--R                     +-----------+
+--R                     |          2
+--R         2h x log(f)\|- 4a c + b
+--R    /
+--R                   +-----------+
+--R                   |          2
+--R       2a h log(f)\|- 4a c + b
+--R     ,
+--R
+--R            +---------+
+--R            |        2          (h x + g)log(f) 2       (h x + g)log(f)
+--R         - \|4a c - b  log(c (%e               )  + b %e                + a)
+--R       + 
+--R                      +---------+                      +---------+
+--R                      |        2   (h x + g)log(f)     |        2
+--R                   2c\|4a c - b  %e                + b\|4a c - b
+--R         - 2b atan(-----------------------------------------------)
+--R                                              2
+--R                                      4a c - b
+--R       + 
+--R                     +---------+
+--R                     |        2
+--R         2h x log(f)\|4a c - b
+--R    /
+--R                   +---------+
+--R                   |        2
+--R       2a h log(f)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 60
+
+--S 54 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-----------+
+--R          |          2          (h x + g)log(f) 2       (h x + g)log(f)
+--R       - \|- 4a c + b  log(c (%e               )  + b %e                + a)
+--R     + 
+--R         b
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    (h x + g)log(f) 2
+--R                2c \|- 4a c + b  (%e               )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    (h x + g)log(f)
+--R                (2b c\|- 4a c + b   - 8a c  + 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   - 4a b c + b
+--R           /
+--R                   (h x + g)log(f) 2       (h x + g)log(f)
+--R              c (%e               )  + b %e                + a
+--R     + 
+--R        +-----------+
+--R        |          2        2h x + 2g      h x + g
+--R       \|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                      h x + g
+--R                  2c f        + b
+--R       - 2b atanh(---------------)
+--R                    +-----------+
+--R                    |          2
+--R                   \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a h log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       -
+--R             +-----------+ +---------+
+--R             |          2  |        2
+--R            \|- 4a c + b  \|4a c - b
+--R         *
+--R                     (h x + g)log(f) 2       (h x + g)log(f)
+--R            log(c (%e               )  + b %e                + a)
+--R     + 
+--R                                 +---------+                      +---------+
+--R            +-----------+        |        2   (h x + g)log(f)     |        2
+--R            |          2      2c\|4a c - b  %e                + b\|4a c - b
+--R       - 2b\|- 4a c + b  atan(-----------------------------------------------)
+--R                                                         2
+--R                                                 4a c - b
+--R     + 
+--R        +-----------+ +---------+
+--R        |          2  |        2        2h x + 2g      h x + g
+--R       \|- 4a c + b  \|4a c - b  log(c f          + b f        + a)
+--R     + 
+--R            +---------+          h x + g
+--R            |        2       2c f        + b
+--R       - 2b\|4a c - b  atanh(---------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R  /
+--R                 +-----------+ +---------+
+--R                 |          2  |        2
+--R     2a h log(f)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 63 of 1034
+t0:=x/(1+2*f^(c+d*x)+f^(2*c+2*d*x))
+--R 
+--R
+--R                     x
+--R   (1)  --------------------------
+--R         2d x + 2c     d x + c
+--R        f          + 2f        + 1
+--R                                                    Type: Expression(Integer)
+--E 63
+
+--S 64 of 1034
+--r0:=1/2*x^2-x/(d*log(f))+x/(d*(1+f^(c+d*x))*log(f))+log(1+f^(c+d*x))/_
+--  (d^2*log(f)^2)-x*log(1+f^(c+d*x))/(d*log(f))-_
+--  polylog(2,-f^(c+d*x))/(d^2*log(f)^2)
+--E 64
+
+--S 65 of 1034
+--a0:=integrate(t0,x)
+--E 65
+
+--S 66 of 1034
+--m0:=a0-r0
+--E 66
+
+--S 67 of 1034
+--d0:=normalize(D(m0,x))
+--E 67
+
+)clear all
+
+--S 68 of 1034
+t0:=x/(a+b*f^(c+d*x)+c*f^(2*c+2*d*x))
+--R 
+--R
+--R                      x
+--R   (1)  -----------------------------
+--R           2d x + 2c      d x + c
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 1034
+--r0:=-2*c*x*log(1+2*c*f^(c+d*x)/(b-sqrt(b^2-4*a*c)))/(d*log(f)*_
+--  (b-sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))-2*c*polylog(2,-2*c*f^(c+d*x)/_
+--  (b-sqrt(b^2-4*a*c)))/(d^2*log(f)^2*(b-sqrt(b^2-4*a*c))*_
+--  sqrt(b^2-4*a*c))+2*c*x*log(1+2*c*f^(c+d*x)/(b+sqrt(b^2-4*a*c)))/_
+--  (d*log(f)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))+2*c*_
+--  polylog(2,-2*c*f^(c+d*x)/(b+sqrt(b^2-4*a*c)))/(d^2*log(f)^2*_
+--  sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))-c*x^2/(b^2-4*a*c-_
+--  b*sqrt(b^2-4*a*c))-c*x^2/(b^2-4*a*c+b*sqrt(b^2-4*a*c))
+--E 69
+
+--S 70 of 1034
+--a0:=integrate(t0,x)
+--E 70
+
+--S 71 of 1034
+--m0:=a0-r0
+--E 71
+
+--S 72 of 1034
+--d0:=normalize(D(m0,x))
+--E 72
+
+)clear all
+
+--S 73 of 1034
+t0:=x^2/(1+2*f^(c+d*x)+f^(2*c+2*d*x))
+--R 
+--R
+--R                     2
+--R                    x
+--R   (1)  --------------------------
+--R         2d x + 2c     d x + c
+--R        f          + 2f        + 1
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 1034
+--r0:=1/3*x^3-x^2/(d*log(f))+x^2/(d*(1+f^(c+d*x))*log(f))+2*x*_
+--  log(1+f^(c+d*x))/(d^2*log(f)^2)-x^2*log(1+f^(c+d*x))/(d*log(f))+_
+--  2*polylog(2,-f^(c+d*x))/(d^3*log(f)^3)-2*x*polylog(2,-f^(c+d*x))/_
+--  (d^2*log(f)^2)+2*polylog(3,-f^(c+d*x))/(d^3*log(f)^3)
+--E 74
+
+--S 75 of 1034
+--a0:=integrate(t0,x)
+--E 75
+
+--S 76 of 1034
+--m0:=a0-r0
+--E 76
+
+--S 77 of 1034
+--d0:=normalize(D(m0,x))
+--E 77
+
+)clear all
+
+--S 78 of 1034
+t0:=x^2/(a+b*f^(c+d*x)+c*f^(2*c+2*d*x))
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R           2d x + 2c      d x + c
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 78
+
+--S 79 of 1034
+--r0:=-2*c*x^2*log(1+2*c*f^(c+d*x)/(b-sqrt(b^2-4*a*c)))/(d*log(f)*_
+--  (b-sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))-4*c*x*polylog(2,-2*c*f^(c+d*x)/_
+--  (b-sqrt(b^2-4*a*c)))/(d^2*log(f)^2*(b-sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))+_
+--  4*c*polylog(3,-2*c*f^(c+d*x)/(b-sqrt(b^2-4*a*c)))/(d^3*log(f)^3*(b-_
+--  sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))+2*c*x^2*log(1+2*c*f^(c+d*x)/(b+_
+--  sqrt(b^2-4*a*c)))/(d*log(f)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))+_
+--  4*c*x*polylog(2,-2*c*f^(c+d*x)/(b+sqrt(b^2-4*a*c)))/(d^2*log(f)^2*_
+--  sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))-4*c*polylog(3,-2*c*f^(c+d*x)/_
+--  (b+sqrt(b^2-4*a*c)))/(d^3*log(f)^3*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))-_
+--  2/3*c*x^3/(b^2-4*a*c-b*sqrt(b^2-4*a*c))-2/3*c*x^3/(b^2-4*a*c+_
+--  b*sqrt(b^2-4*a*c))
+--E 79
+
+--S 80 of 1034
+--a0:=integrate(t0,x)
+--E 80
+
+--S 81 of 1034
+--m0:=a0-r0
+--E 81
+
+--S 82 of 1034
+--d0:=normalize(D(m0,x))
+--E 82
+
+)clear all
+
+--S 83 of 1034
+t0:=(d+e*f^(g+h*x))/(a+b*f^(g+h*x)+c*f^(2*g+2*h*x))
+--R 
+--R
+--R                   h x + g
+--R                e f        + d
+--R   (1)  -----------------------------
+--R           2h x + 2g      h x + g
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 1034
+r0:=d*x/a-1/2*d*log(a+b*f^(g+h*x)+c*f^(2*g+2*h*x))/(a*h*log(f))+_
+   (b*d-2*a*e)*atanh((b+2*c*f^(g+h*x))/sqrt(b^2-4*a*c))/(a*h*log(f)*_
+   sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R           +-----------+
+--R           |          2        2h x + 2g      h x + g
+--R       - d\|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                                h x + g                      +-----------+
+--R                            2c f        + b                  |          2
+--R       (- 4a e + 2b d)atanh(---------------) + 2d h x log(f)\|- 4a c + b
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a h log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R             +-----------+
+--R             |          2          (h x + g)log(f) 2       (h x + g)log(f)
+--R         - d\|- 4a c + b  log(c (%e               )  + b %e                + a)
+--R       + 
+--R           (2a e - b d)
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    (h x + g)log(f) 2
+--R                  2c \|- 4a c + b  (%e               )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    (h x + g)log(f)
+--R                  (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R             /
+--R                     (h x + g)log(f) 2       (h x + g)log(f)
+--R                c (%e               )  + b %e                + a
+--R       + 
+--R                       +-----------+
+--R                       |          2
+--R         2d h x log(f)\|- 4a c + b
+--R    /
+--R                   +-----------+
+--R                   |          2
+--R       2a h log(f)\|- 4a c + b
+--R     ,
+--R
+--R             +---------+
+--R             |        2          (h x + g)log(f) 2       (h x + g)log(f)
+--R         - d\|4a c - b  log(c (%e               )  + b %e                + a)
+--R       + 
+--R                              +---------+                      +---------+
+--R                              |        2   (h x + g)log(f)     |        2
+--R                           2c\|4a c - b  %e                + b\|4a c - b
+--R         (4a e - 2b d)atan(-----------------------------------------------)
+--R                                                      2
+--R                                              4a c - b
+--R       + 
+--R                       +---------+
+--R                       |        2
+--R         2d h x log(f)\|4a c - b
+--R    /
+--R                   +---------+
+--R                   |        2
+--R       2a h log(f)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 85
+
+--S 86 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           +-----------+
+--R           |          2          (h x + g)log(f) 2       (h x + g)log(f)
+--R       - d\|- 4a c + b  log(c (%e               )  + b %e                + a)
+--R     + 
+--R         (2a e - b d)
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    (h x + g)log(f) 2
+--R                2c \|- 4a c + b  (%e               )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    (h x + g)log(f)
+--R                (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R           /
+--R                   (h x + g)log(f) 2       (h x + g)log(f)
+--R              c (%e               )  + b %e                + a
+--R     + 
+--R         +-----------+
+--R         |          2        2h x + 2g      h x + g
+--R       d\|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                              h x + g
+--R                          2c f        + b
+--R       (4a e - 2b d)atanh(---------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a h log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       -
+--R              +-----------+ +---------+
+--R              |          2  |        2
+--R            d\|- 4a c + b  \|4a c - b
+--R         *
+--R                     (h x + g)log(f) 2       (h x + g)log(f)
+--R            log(c (%e               )  + b %e                + a)
+--R     + 
+--R                       +-----------+
+--R                       |          2
+--R         (4a e - 2b d)\|- 4a c + b
+--R      *
+--R                 +---------+                      +---------+
+--R                 |        2   (h x + g)log(f)     |        2
+--R              2c\|4a c - b  %e                + b\|4a c - b
+--R         atan(-----------------------------------------------)
+--R                                         2
+--R                                 4a c - b
+--R     + 
+--R         +-----------+ +---------+
+--R         |          2  |        2        2h x + 2g      h x + g
+--R       d\|- 4a c + b  \|4a c - b  log(c f          + b f        + a)
+--R     + 
+--R                     +---------+          h x + g
+--R                     |        2       2c f        + b
+--R       (4a e - 2b d)\|4a c - b  atanh(---------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R                 +-----------+ +---------+
+--R                 |          2  |        2
+--R     2a h log(f)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 89
+
+)clear all
+
+--S 90 of 1034
+t0:=(d+e*f^(g+h*x))/(a+b*f^(g+h*x)+c*f^(2*(g+h*x)))
+--R 
+--R
+--R                   h x + g
+--R                e f        + d
+--R   (1)  -----------------------------
+--R           2h x + 2g      h x + g
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 90
+
+--S 91 of 1034
+r0:=d*x/a-1/2*d*log(a+b*f^(g+h*x)+c*f^(2*g+2*h*x))/(a*h*log(f))+(b*d-_
+   2*a*e)*atanh((b+2*c*f^(g+h*x))/sqrt(b^2-4*a*c))/(a*h*log(f)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R           +-----------+
+--R           |          2        2h x + 2g      h x + g
+--R       - d\|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                                h x + g                      +-----------+
+--R                            2c f        + b                  |          2
+--R       (- 4a e + 2b d)atanh(---------------) + 2d h x log(f)\|- 4a c + b
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a h log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R             +-----------+
+--R             |          2          (h x + g)log(f) 2       (h x + g)log(f)
+--R         - d\|- 4a c + b  log(c (%e               )  + b %e                + a)
+--R       + 
+--R           (2a e - b d)
+--R        *
+--R           log
+--R                      +-----------+
+--R                    2 |          2    (h x + g)log(f) 2
+--R                  2c \|- 4a c + b  (%e               )
+--R                + 
+--R                        +-----------+
+--R                        |          2        2     2    (h x + g)log(f)
+--R                  (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R                + 
+--R                                +-----------+
+--R                             2  |          2              3
+--R                  (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R             /
+--R                     (h x + g)log(f) 2       (h x + g)log(f)
+--R                c (%e               )  + b %e                + a
+--R       + 
+--R                       +-----------+
+--R                       |          2
+--R         2d h x log(f)\|- 4a c + b
+--R    /
+--R                   +-----------+
+--R                   |          2
+--R       2a h log(f)\|- 4a c + b
+--R     ,
+--R
+--R             +---------+
+--R             |        2          (h x + g)log(f) 2       (h x + g)log(f)
+--R         - d\|4a c - b  log(c (%e               )  + b %e                + a)
+--R       + 
+--R                              +---------+                      +---------+
+--R                              |        2   (h x + g)log(f)     |        2
+--R                           2c\|4a c - b  %e                + b\|4a c - b
+--R         (4a e - 2b d)atan(-----------------------------------------------)
+--R                                                      2
+--R                                              4a c - b
+--R       + 
+--R                       +---------+
+--R                       |        2
+--R         2d h x log(f)\|4a c - b
+--R    /
+--R                   +---------+
+--R                   |        2
+--R       2a h log(f)\|4a c - b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 92
+
+--S 93 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           +-----------+
+--R           |          2          (h x + g)log(f) 2       (h x + g)log(f)
+--R       - d\|- 4a c + b  log(c (%e               )  + b %e                + a)
+--R     + 
+--R         (2a e - b d)
+--R      *
+--R         log
+--R                    +-----------+
+--R                  2 |          2    (h x + g)log(f) 2
+--R                2c \|- 4a c + b  (%e               )
+--R              + 
+--R                      +-----------+
+--R                      |          2        2     2    (h x + g)log(f)
+--R                (2b c\|- 4a c + b   + 8a c  - 2b c)%e
+--R              + 
+--R                              +-----------+
+--R                           2  |          2              3
+--R                (- 2a c + b )\|- 4a c + b   + 4a b c - b
+--R           /
+--R                   (h x + g)log(f) 2       (h x + g)log(f)
+--R              c (%e               )  + b %e                + a
+--R     + 
+--R         +-----------+
+--R         |          2        2h x + 2g      h x + g
+--R       d\|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                              h x + g
+--R                          2c f        + b
+--R       (4a e - 2b d)atanh(---------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a h log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 93
+
+--S 94 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R       -
+--R              +-----------+ +---------+
+--R              |          2  |        2
+--R            d\|- 4a c + b  \|4a c - b
+--R         *
+--R                     (h x + g)log(f) 2       (h x + g)log(f)
+--R            log(c (%e               )  + b %e                + a)
+--R     + 
+--R                       +-----------+
+--R                       |          2
+--R         (4a e - 2b d)\|- 4a c + b
+--R      *
+--R                 +---------+                      +---------+
+--R                 |        2   (h x + g)log(f)     |        2
+--R              2c\|4a c - b  %e                + b\|4a c - b
+--R         atan(-----------------------------------------------)
+--R                                         2
+--R                                 4a c - b
+--R     + 
+--R         +-----------+ +---------+
+--R         |          2  |        2        2h x + 2g      h x + g
+--R       d\|- 4a c + b  \|4a c - b  log(c f          + b f        + a)
+--R     + 
+--R                     +---------+          h x + g
+--R                     |        2       2c f        + b
+--R       (4a e - 2b d)\|4a c - b  atanh(---------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R  /
+--R                 +-----------+ +---------+
+--R                 |          2  |        2
+--R     2a h log(f)\|- 4a c + b  \|4a c - b
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 1034
+t0:=1/(2+1/%e^x+%e^x)
+--R 
+--R
+--R                 x
+--R               %e
+--R   (1)  -----------------
+--R           x 2      x
+--R        (%e )  + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 1034
+r0:=(-1)/(1+%e^x)
+--R 
+--R
+--R             1
+--R   (2)  - -------
+--R            x
+--R          %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            x
+--R          %e  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 99
+
+--S 100 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 101
+
+)clear all
+
+--S 102 of 1034
+t0:=x/(2+1/%e^x+%e^x)
+--R 
+--R
+--R                  x
+--R              x %e
+--R   (1)  -----------------
+--R           x 2      x
+--R        (%e )  + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 1034
+r0:=x-x/(1+%e^x)-log(1+%e^x)
+--R 
+--R
+--R             x           x            x
+--R        (- %e  - 1)log(%e  + 1) + x %e
+--R   (2)  -------------------------------
+--R                      x
+--R                    %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             x           x            x
+--R        (- %e  - 1)log(%e  + 1) + x %e
+--R   (3)  -------------------------------
+--R                      x
+--R                    %e  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 104
+
+--S 105 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+--S 106 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 106
+
+)clear all
+
+--S 107 of 1034
+t0:=x^2/(2+1/%e^x+%e^x)
+--R 
+--R
+--R               2  x
+--R              x %e
+--R   (1)  -----------------
+--R           x 2      x
+--R        (%e )  + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 1034
+--r0:=x^2-x^2/(1+%e^x)-2*x*log(1+%e^x)-2*polylog(2,-%e^x)
+--E 108
+
+--S 109 of 1034
+--a0:=integrate(t0,x)
+--E 109
+
+--S 110 of 1034
+--m0:=a0-r0
+--E 110
+
+--S 111 of 1034
+--d0:=normalize(D(m0,x))
+--E 111
+
+)clear all
+
+--S 112 of 1034
+t0:=1/(2+f^(-c-d*x)+f^(c+d*x))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R         d x + c    - d x - c
+--R        f        + f          + 2
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 1034
+r0:=(-1)/(d*(1+f^(c+d*x))*log(f))
+--R 
+--R
+--R                       1
+--R   (2)  - ---------------------------
+--R                   d x + c
+--R          d log(f)f        + d log(f)
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            1
+--R   (3)  - ------------------------------------
+--R                    (d x + c)log(f)
+--R          d log(f)%e                + d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 114
+
+--S 115 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             (d x + c)log(f)    d x + c
+--R                           %e                - f
+--R   ----------------------------------------------------------------------------
+--R             d x + c              (d x + c)log(f)            d x + c
+--R   (d log(f)f        + d log(f))%e                + d log(f)f        + d log(f)
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 116
+
+)clear all
+
+--S 117 of 1034
+t0:=x/(2+f^(-c-d*x)+f^(c+d*x))
+--R 
+--R
+--R                    x
+--R   (1)  -------------------------
+--R         d x + c    - d x - c
+--R        f        + f          + 2
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 1034
+r0:=x/(d*log(f))-x/(d*(1+f^(c+d*x))*log(f))-log(1+f^(c+d*x))/(d^2*log(f)^2)
+--R 
+--R
+--R            d x + c          d x + c                   d x + c
+--R        (- f        - 1)log(f        + 1) + d x log(f)f
+--R   (2)  ------------------------------------------------------
+--R                      2      2 d x + c    2      2
+--R                     d log(f) f        + d log(f)
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            (d x + c)log(f)           (d x + c)log(f)
+--R       (- %e                - 1)log(%e                + 1)
+--R     + 
+--R                   (d x + c)log(f)
+--R       d x log(f)%e
+--R  /
+--R      2      2  (d x + c)log(f)    2      2
+--R     d log(f) %e                + d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 119
+
+--S 120 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              d x + c       (d x + c)log(f)    d x + c
+--R         ((- f        - 1)%e                - f        - 1)
+--R      *
+--R               (d x + c)log(f)
+--R         log(%e                + 1)
+--R     + 
+--R          d x + c       (d x + c)log(f)    d x + c          d x + c
+--R       ((f        + 1)%e                + f        + 1)log(f        + 1)
+--R     + 
+--R                   (d x + c)log(f)              d x + c
+--R       d x log(f)%e                - d x log(f)f
+--R  /
+--R         2      2 d x + c    2      2   (d x + c)log(f)    2      2 d x + c
+--R       (d log(f) f        + d log(f) )%e                + d log(f) f
+--R     + 
+--R        2      2
+--R       d log(f)
+--R                                                    Type: Expression(Integer)
+--E 120
+
+--S 121 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 121
+
+)clear all
+
+--S 122 of 1034
+t0:=x^2/(2+f^(-c-d*x)+f^(c+d*x))
+--R 
+--R
+--R                     2
+--R                    x
+--R   (1)  -------------------------
+--R         d x + c    - d x - c
+--R        f        + f          + 2
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 1034
+--r0:=x^2/(d*log(f))-x^2/(d*(1+f^(c+d*x))*log(f))-2*x*log(1+f^(c+d*x))/_
+--  (d^2*log(f)^2)-2*polylog(2,-f^(c+d*x))/(d^3*log(f)^3)
+--E 123
+
+--S 124 of 1034
+--a0:=integrate(t0,x)
+--E 124
+
+--S 125 of 1034
+--m0:=a0-r0
+--E 125
+
+--S 126 of 1034
+--d0:=normalize(D(m0,x))
+--E 126
+
+)clear all
+
+--S 127 of 1034
+t0:=1/(2+1/3^x+3^x)
+--R 
+--R
+--R                x
+--R               3
+--R   (1)  ----------------
+--R          x 2      x
+--R        (3 )  + 2 3  + 1
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 1034
+r0:=(-1)/((1+3^x)*log(3))
+--R 
+--R
+--R                  1
+--R   (2)  - -----------------
+--R                 x
+--R          log(3)3  + log(3)
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      1
+--R   (3)  - -------------------------
+--R                  x log(3)
+--R          log(3)%e         + log(3)
+--R                                         Type: Union(Expression(Integer),...)
+--E 129
+
+--S 130 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                               x     x log(3)
+--R                            - 3  + %e
+--R   (4)  ---------------------------------------------------------
+--R                 x log(3)           x           x log(3)
+--R        (log(3)%e         + log(3))3  + log(3)%e         + log(3)
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 131
+
+)clear all
+
+--S 132 of 1034
+t0:=1/(1+(-1)/%e^x+2*%e^x)
+--R 
+--R
+--R                 x
+--R               %e
+--R   (1)  -----------------
+--R            x 2     x
+--R        2(%e )  + %e  - 1
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 1034
+r0:=1/3*log(1-2*%e^x)-1/3*log(1+%e^x)
+--R 
+--R
+--R                x                 x
+--R        - log(%e  + 1) + log(- 2%e  + 1)
+--R   (2)  --------------------------------
+--R                        3
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               x              x
+--R        log(2%e  - 1) - log(%e  + 1)
+--R   (3)  ----------------------------
+--R                      3
+--R                                         Type: Union(Expression(Integer),...)
+--E 134
+
+--S 135 of 1034
+m0:=a0-r0
+--R 
+--R
+--R               x                 x
+--R        log(2%e  - 1) - log(- 2%e  + 1)
+--R   (4)  -------------------------------
+--R                       3
+--R                                                    Type: Expression(Integer)
+--E 135
+
+--S 136 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 136
+
+)clear all
+
+--S 137 of 1034
+t0:=1/(a+b/%e^x+%e^x*c)
+--R 
+--R
+--R                   x
+--R                 %e
+--R   (1)  --------------------
+--R             x 2       x
+--R        c (%e )  + a %e  + b
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 1034
+r0:=-2*atanh((a+2*%e^x*c)/sqrt(a^2-4*b*c))/sqrt(a^2-4*b*c)
+--R 
+--R
+--R                        x
+--R                   2c %e  + a
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4b c + a
+--R   (2)  - ----------------------
+--R               +-----------+
+--R               |          2
+--R              \|- 4b c + a
+--R                                                    Type: Expression(Integer)
+--E 138
+
+--S 139 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                                                 +-----------+
+--R                 2   x 2          x           2  |          2
+--R              (2c (%e )  + 2a c %e  - 2b c + a )\|- 4b c + a
+--R            + 
+--R                   2     2    x             3
+--R              (8b c  - 2a c)%e  + 4a b c - a
+--R         /
+--R                 x 2       x
+--R            c (%e )  + a %e  + b
+--R    /
+--R        +-----------+
+--R        |          2
+--R       \|- 4b c + a
+--R     ,
+--R                       +---------+
+--R                x      |        2
+--R          (2c %e  + a)\|4b c - a
+--R    2atan(------------------------)
+--R                          2
+--R                  4b c - a
+--R    -------------------------------]
+--R               +---------+
+--R               |        2
+--R              \|4b c - a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 139
+
+--S 140 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                                                 +-----------+
+--R                 2   x 2          x           2  |          2
+--R              (2c (%e )  + 2a c %e  - 2b c + a )\|- 4b c + a
+--R            + 
+--R                   2     2    x             3
+--R              (8b c  - 2a c)%e  + 4a b c - a
+--R         /
+--R                 x 2       x
+--R            c (%e )  + a %e  + b
+--R     + 
+--R                     x
+--R                2c %e  + a
+--R       2atanh(--------------)
+--R               +-----------+
+--R               |          2
+--R              \|- 4b c + a
+--R  /
+--R      +-----------+
+--R      |          2
+--R     \|- 4b c + a
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R         +---------+             x
+--R         |        2         2c %e  + a
+--R       2\|4b c - a  atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4b c + a
+--R     + 
+--R                                        +---------+
+--R         +-----------+           x      |        2
+--R         |          2      (2c %e  + a)\|4b c - a
+--R       2\|- 4b c + a  atan(------------------------)
+--R                                           2
+--R                                   4b c - a
+--R  /
+--R      +-----------+ +---------+
+--R      |          2  |        2
+--R     \|- 4b c + a  \|4b c - a
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 143
+
+)clear all
+
+--S 144 of 1034
+t0:=x/(a+b/%e^x+%e^x*c)
+--R 
+--R
+--R                    x
+--R                x %e
+--R   (1)  --------------------
+--R             x 2       x
+--R        c (%e )  + a %e  + b
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 1034
+--r0:=x*log(1+2*%e^x*c/(a-sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)-x*_
+--  log(1+2*%e^x*c/(a+sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)+_
+--  polylog(2,-2*%e^x*c/(a-sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)-_
+--  polylog(2,-2*%e^x*c/(a+sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)
+--E 145
+
+--S 146 of 1034
+--a0:=integrate(t0,x)
+--E 146
+
+--S 147 of 1034
+--m0:=a0-r0
+--E 147
+
+--S 148 of 1034
+--d0:=normalize(D(m0,x))
+--E 148
+
+)clear all
+
+--S 149 of 1034
+t0:=x^2/(a+b/%e^x+%e^x*c)
+--R 
+--R
+--R                 2  x
+--R                x %e
+--R   (1)  --------------------
+--R             x 2       x
+--R        c (%e )  + a %e  + b
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 1034
+--r0:=x^2*log(1+2*%e^x*c/(a-sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)-x^2*_
+--  log(1+2*%e^x*c/(a+sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)+2*x*_
+--  polylog(2,-2*%e^x*c/(a-sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)-2*x*_
+--  polylog(2,-2*%e^x*c/(a+sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)-2*_
+--  polylog(3,-2*%e^x*c/(a-sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)+2*_
+--  polylog(3,-2*%e^x*c/(a+sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)
+--E 150
+
+--S 151 of 1034
+--a0:=integrate(t0,x)
+--E 151
+
+--S 152 of 1034
+--m0:=a0-r0
+--E 152
+
+--S 153 of 1034
+--d0:=normalize(D(m0,x))
+--E 153
+
+)clear all
+
+--S 154 of 1034
+t0:=1/(a+b*f^(-c-d*x)+c*f^(c+d*x))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R           d x + c      - d x - c
+--R        c f        + b f          + a
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 1034
+r0:=-2*atanh((a+2*c*f^(c+d*x))/sqrt(a^2-4*b*c))/(d*log(f)*sqrt(a^2-4*b*c))
+--R 
+--R
+--R                     d x + c
+--R                 2c f        + a
+--R          2atanh(---------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4b c + a
+--R   (2)  - -----------------------
+--R                    +-----------+
+--R                    |          2
+--R           d log(f)\|- 4b c + a
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                  +-----------+
+--R                2 |          2    (d x + c)log(f) 2
+--R              2c \|- 4b c + a  (%e               )
+--R            + 
+--R                    +-----------+
+--R                    |          2        2     2    (d x + c)log(f)
+--R              (2a c\|- 4b c + a   + 8b c  - 2a c)%e
+--R            + 
+--R                            +-----------+
+--R                         2  |          2              3
+--R              (- 2b c + a )\|- 4b c + a   + 4a b c - a
+--R         /
+--R                 (d x + c)log(f) 2       (d x + c)log(f)
+--R            c (%e               )  + a %e                + b
+--R    /
+--R                +-----------+
+--R                |          2
+--R       d log(f)\|- 4b c + a
+--R     ,
+--R             +---------+                      +---------+
+--R             |        2   (d x + c)log(f)     |        2
+--R          2c\|4b c - a  %e                + a\|4b c - a
+--R    2atan(-----------------------------------------------)
+--R                                     2
+--R                             4b c - a
+--R    ------------------------------------------------------]
+--R                              +---------+
+--R                              |        2
+--R                     d log(f)\|4b c - a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 156
+
+--S 157 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R       log
+--R                  +-----------+
+--R                2 |          2    (d x + c)log(f) 2
+--R              2c \|- 4b c + a  (%e               )
+--R            + 
+--R                    +-----------+
+--R                    |          2        2     2    (d x + c)log(f)
+--R              (2a c\|- 4b c + a   + 8b c  - 2a c)%e
+--R            + 
+--R                            +-----------+
+--R                         2  |          2              3
+--R              (- 2b c + a )\|- 4b c + a   + 4a b c - a
+--R         /
+--R                 (d x + c)log(f) 2       (d x + c)log(f)
+--R            c (%e               )  + a %e                + b
+--R     + 
+--R                  d x + c
+--R              2c f        + a
+--R       2atanh(---------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4b c + a
+--R  /
+--R              +-----------+
+--R              |          2
+--R     d log(f)\|- 4b c + a
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                              +---------+                      +---------+
+--R         +-----------+        |        2   (d x + c)log(f)     |        2
+--R         |          2      2c\|4b c - a  %e                + a\|4b c - a
+--R       2\|- 4b c + a  atan(-----------------------------------------------)
+--R                                                      2
+--R                                              4b c - a
+--R     + 
+--R         +---------+          d x + c
+--R         |        2       2c f        + a
+--R       2\|4b c - a  atanh(---------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4b c + a
+--R  /
+--R              +-----------+ +---------+
+--R              |          2  |        2
+--R     d log(f)\|- 4b c + a  \|4b c - a
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 160
+
+)clear all
+
+--S 161 of 1034
+t0:=x/(a+b*f^(-c-d*x)+c*f^(c+d*x))
+--R 
+--R
+--R                      x
+--R   (1)  -----------------------------
+--R           d x + c      - d x - c
+--R        c f        + b f          + a
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 1034
+--r0:=x*log(1+2*c*f^(c+d*x)/(a-sqrt(a^2-4*b*c)))/(d*log(f)*sqrt(a^2-4*b*c))-_
+--  x*log(1+2*c*f^(c+d*x)/(a+sqrt(a^2-4*b*c)))/(d*log(f)*sqrt(a^2-4*b*c))+_
+--  polylog(2,-2*c*f^(c+d*x)/(a-sqrt(a^2-4*b*c)))/(d^2*log(f)^2*_
+--  sqrt(a^2-4*b*c))-polylog(2,-2*c*f^(c+d*x)/(a+sqrt(a^2-4*b*c)))/_
+--  (d^2*log(f)^2*sqrt(a^2-4*b*c))
+--E 162
+
+--S 163 of 1034
+--a0:=integrate(t0,x)
+--E 163
+
+--S 164 of 1034
+--m0:=a0-r0
+--E 164
+
+--S 165 of 1034
+--d0:=normalize(D(m0,x))
+--E 165
+
+)clear all
+
+--S 166 of 1034
+t0:=x^2/(a+b*f^(-c-d*x)+c*f^(c+d*x))
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R           d x + c      - d x - c
+--R        c f        + b f          + a
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 1034
+--r0:=x^2*log(1+2*c*f^(c+d*x)/(a-sqrt(a^2-4*b*c)))/(d*log(f)*sqrt(a^2-_
+--  4*b*c))-x^2*log(1+2*c*f^(c+d*x)/(a+sqrt(a^2-4*b*c)))/(d*log(f)*_
+--  sqrt(a^2-4*b*c))+2*x*polylog(2,-2*c*f^(c+d*x)/(a-sqrt(a^2-4*b*c)))/_
+--  (d^2*log(f)^2*sqrt(a^2-4*b*c))-2*x*polylog(2,-2*c*f^(c+d*x)/(a+_
+--  sqrt(a^2-4*b*c)))/(d^2*log(f)^2*sqrt(a^2-4*b*c))-2*_
+--  polylog(3,-2*c*f^(c+d*x)/(a-sqrt(a^2-4*b*c)))/(d^3*log(f)^3*_
+--  sqrt(a^2-4*b*c))+2*polylog(3,-2*c*f^(c+d*x)/(a+sqrt(a^2-4*b*c)))/_
+--  (d^3*log(f)^3*sqrt(a^2-4*b*c))
+--E 167
+
+--S 168 of 1034
+--a0:=integrate(t0,x)
+--E 168
+
+--S 169 of 1034
+--m0:=a0-r0
+--E 169
+
+--S 170 of 1034
+--d0:=normalize(D(m0,x))
+--E 170
+
+)clear all
+
+--S 171 of 1034
+t0:=a^x*b^x*x^2
+--R 
+--R
+--R         2 x x
+--R   (1)  x a b
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 1034
+r0:=2*a^x*b^x/(log(a)+log(b))^3-2*a^x*b^x*x/(log(a)+log(b))^2+_
+   a^x*b^x*x^2/(log(a)+log(b))
+--R 
+--R
+--R          2      2      2                      2      2                  x x
+--R        (x log(b)  + (2x log(a) - 2x)log(b) + x log(a)  - 2x log(a) + 2)a b
+--R   (2)  --------------------------------------------------------------------
+--R                       3                2          2               3
+--R                 log(b)  + 3log(a)log(b)  + 3log(a) log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2      2      2                      2      2
+--R       (x log(b)  + (2x log(a) - 2x)log(b) + x log(a)  - 2x log(a) + 2)
+--R    *
+--R         x log(a)  x log(b)
+--R       %e        %e
+--R  /
+--R           3                2          2               3
+--R     log(b)  + 3log(a)log(b)  + 3log(a) log(b) + log(a)
+--R                                         Type: Union(Expression(Integer),...)
+--E 173
+
+--S 174 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2      2      2                      2      2
+--R         (x log(b)  + (2x log(a) - 2x)log(b) + x log(a)  - 2x log(a) + 2)
+--R      *
+--R           x log(a)  x log(b)
+--R         %e        %e
+--R     + 
+--R           2      2        2                      2      2                  x x
+--R       (- x log(b)  + (- 2x log(a) + 2x)log(b) - x log(a)  + 2x log(a) - 2)a b
+--R  /
+--R           3                2          2               3
+--R     log(b)  + 3log(a)log(b)  + 3log(a) log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 175
+
+)clear all
+
+--S 176 of 1034
+t0:=a^x*b^x*x
+--R 
+--R
+--R           x x
+--R   (1)  x a b
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 1034
+r0:=-a^x*b^x/(log(a)+log(b))^2+a^x*b^x*x/(log(a)+log(b))
+--R 
+--R
+--R                                    x x
+--R          (x log(b) + x log(a) - 1)a b
+--R   (2)  ---------------------------------
+--R              2                         2
+--R        log(b)  + 2log(a)log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   x log(a)  x log(b)
+--R        (x log(b) + x log(a) - 1)%e        %e
+--R   (3)  ---------------------------------------------
+--R                    2                         2
+--R              log(b)  + 2log(a)log(b) + log(a)
+--R                                         Type: Union(Expression(Integer),...)
+--E 178
+
+--S 179 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  x log(a)  x log(b)
+--R       (x log(b) + x log(a) - 1)%e        %e
+--R     + 
+--R                                   x x
+--R       (- x log(b) - x log(a) + 1)a b
+--R  /
+--R           2                         2
+--R     log(b)  + 2log(a)log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 1034
+t0:=a^x*b^x
+--R 
+--R
+--R         x x
+--R   (1)  a b
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1034
+r0:=a^x*b^x/(log(a)+log(b))
+--R 
+--R
+--R               x x
+--R              a b
+--R   (2)  ---------------
+--R        log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R          x log(a)  x log(b)
+--R        %e        %e
+--R   (3)  --------------------
+--R           log(b) + log(a)
+--R                                         Type: Union(Expression(Integer),...)
+--E 183
+
+--S 184 of 1034
+m0:=a0-r0
+--R 
+--R
+--R          x log(a)  x log(b)    x x
+--R        %e        %e         - a b
+--R   (4)  ---------------------------
+--R              log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 185
+
+)clear all
+
+--S 186 of 1034
+t0:=a^x*b^x/x
+--R 
+--R
+--R         x x
+--R        a b
+--R   (1)  ----
+--R          x
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 1034
+--r0:=Ei(x*(log(a)+log(b)))
+--E 187
+
+--S 188 of 1034
+--a0:=integrate(t0,x)
+--E 188
+
+--S 189 of 1034
+--m0:=a0-r0
+--E 189
+
+--S 190 of 1034
+--d0:=normalize(D(m0,x))
+--E 190
+
+)clear all
+
+--S 191 of 1034
+t0:=a^x*b^x/x^2
+--R 
+--R
+--R         x x
+--R        a b
+--R   (1)  ----
+--R          2
+--R         x
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1034
+--r0:=-a^x*b^x/x+Ei(x*(log(a)+log(b)))*(log(a)+log(b))
+--E 192
+
+--S 193 of 1034
+--a0:=integrate(t0,x)
+--E 193
+
+--S 194 of 1034
+--m0:=a0-r0
+--E 194
+
+--S 195 of 1034
+--d0:=normalize(D(m0,x))
+--E 195
+
+)clear all
+
+--S 196 of 1034
+t0:=a^x*b^x/x^3
+--R 
+--R
+--R         x x
+--R        a b
+--R   (1)  ----
+--R          3
+--R         x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1034
+--r0:=-1/2*a^x*b^x/x^2-1/2*a^x*b^x*(log(a)+log(b))/x+1/2*Ei(x*(log(a)+_
+--  log(b)))*(log(a)+log(b))^2
+--E 197
+
+--S 198 of 1034
+--a0:=integrate(t0,x)
+--E 198
+
+--S 199 of 1034
+--m0:=a0-r0
+--E 199
+
+--S 200 of 1034
+--d0:=normalize(D(m0,x))
+--E 200
+
+)clear all
+
+--S 201 of 1034
+t0:=a^x*b^x*c^x
+--R 
+--R
+--R         x x x
+--R   (1)  a b c
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 1034
+r0:=a^x*b^x*c^x/(log(a)+log(b)+log(c))
+--R 
+--R
+--R                  x x x
+--R                 a b c
+--R   (2)  ------------------------
+--R        log(c) + log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R          x log(a)  x log(b)  x log(c)
+--R        %e        %e        %e
+--R   (3)  ------------------------------
+--R           log(c) + log(b) + log(a)
+--R                                         Type: Union(Expression(Integer),...)
+--E 203
+
+--S 204 of 1034
+m0:=a0-r0
+--R 
+--R
+--R          x log(a)  x log(b)  x log(c)    x x x
+--R        %e        %e        %e         - a b c
+--R   (4)  ---------------------------------------
+--R                log(c) + log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 205
+
+)clear all
+
+--S 206 of 1034
+t0:=a^x/b^x
+--R 
+--R
+--R         x
+--R        a
+--R   (1)  --
+--R         x
+--R        b
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 1034
+r0:=a^x/(b^x*(log(a)-log(b)))
+--R 
+--R
+--R                    x
+--R                   a
+--R   (2)  - -------------------
+--R                            x
+--R          (log(b) - log(a))b
+--R                                                    Type: Expression(Integer)
+--E 207
+
+--S 208 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     x log(a)
+--R                   %e
+--R   (3)  - ---------------------------
+--R                             x log(b)
+--R          (log(b) - log(a))%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 208
+
+--S 209 of 1034
+m0:=a0-r0
+--R 
+--R
+--R          x  x log(b)    x  x log(a)
+--R         a %e         - b %e
+--R   (4)  -----------------------------
+--R                          x  x log(b)
+--R        (log(b) - log(a))b %e
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 1034
+t0:=a^x*x^2/b^x
+--R 
+--R
+--R         2 x
+--R        x a
+--R   (1)  ----
+--R          x
+--R         b
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 1034
+r0:=2*a^x/(b^x*(log(a)-log(b))^3)-2*a^x*x/(b^x*(log(a)-log(b))^2)+_
+   a^x*x^2/(b^x*(log(a)-log(b)))
+--R 
+--R
+--R            2      2      2                      2      2                  x
+--R        (- x log(b)  + (2x log(a) - 2x)log(b) - x log(a)  + 2x log(a) - 2)a
+--R   (2)  --------------------------------------------------------------------
+--R                      3                2          2               3  x
+--R               (log(b)  - 3log(a)log(b)  + 3log(a) log(b) - log(a) )b
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       2      2      2                      2      2                   x log(a)
+--R   (- x log(b)  + (2x log(a) - 2x)log(b) - x log(a)  + 2x log(a) - 2)%e
+--R   ----------------------------------------------------------------------------
+--R                 3                2          2               3   x log(b)
+--R          (log(b)  - 3log(a)log(b)  + 3log(a) log(b) - log(a) )%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 213
+
+--S 214 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2      2        2                      2      2                  x
+--R         (x log(b)  + (- 2x log(a) + 2x)log(b) + x log(a)  - 2x log(a) + 2)a
+--R      *
+--R           x log(b)
+--R         %e
+--R     + 
+--R             2      2      2                      2      2                  x
+--R         (- x log(b)  + (2x log(a) - 2x)log(b) - x log(a)  + 2x log(a) - 2)b
+--R      *
+--R           x log(a)
+--R         %e
+--R  /
+--R            3                2          2               3  x  x log(b)
+--R     (log(b)  - 3log(a)log(b)  + 3log(a) log(b) - log(a) )b %e
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 215
+
+)clear all
+
+--S 216 of 1034
+t0:=%e^(2*x)/(a+%e^x*b)
+--R 
+--R
+--R             2x
+--R           %e
+--R   (1)  ---------
+--R            x
+--R        b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 1034
+r0:=%e^x/b-a*log(a+%e^x*b)/b^2
+--R 
+--R
+--R                    x            x
+--R        - a log(b %e  + a) + b %e
+--R   (2)  --------------------------
+--R                     2
+--R                    b
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    x            x
+--R        - a log(b %e  + a) + b %e
+--R   (3)  --------------------------
+--R                     2
+--R                    b
+--R                                         Type: Union(Expression(Integer),...)
+--E 218
+
+--S 219 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 220
+
+)clear all
+
+--S 221 of 1034
+t0:=%e^(2*x)/(a+%e^x*b)^2
+--R 
+--R
+--R                    2x
+--R                  %e
+--R   (1)  ------------------------
+--R         2   x 2          x    2
+--R        b (%e )  + 2a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1034
+r0:=a/(b^2*(a+%e^x*b))+log(a+%e^x*b)/b^2
+--R 
+--R
+--R             x             x
+--R        (b %e  + a)log(b %e  + a) + a
+--R   (2)  -----------------------------
+--R                  3  x      2
+--R                 b %e  + a b
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             x             x
+--R        (b %e  + a)log(b %e  + a) + a
+--R   (3)  -----------------------------
+--R                  3  x      2
+--R                 b %e  + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 223
+
+--S 224 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 1034
+t0:=%e^(2*x)/(a+%e^x*b)^3
+--R 
+--R
+--R                           2x
+--R                         %e
+--R   (1)  --------------------------------------
+--R         3   x 3       2   x 2     2    x    3
+--R        b (%e )  + 3a b (%e )  + 3a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 1034
+r0:=1/2*%e^(2*x)/(a*(a+%e^x*b)^2)
+--R 
+--R
+--R                      2x
+--R                    %e
+--R   (2)  ----------------------------
+--R            2   x 2     2    x     3
+--R        2a b (%e )  + 4a b %e  + 2a
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       x
+--R                - 2b %e  - a
+--R   (3)  ----------------------------
+--R          4   x 2       3  x     2 2
+--R        2b (%e )  + 4a b %e  + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 228
+
+--S 229 of 1034
+m0:=a0-r0
+--R 
+--R
+--R              2  2x          x    2
+--R           - b %e   - 2a b %e  - a
+--R   (4)  ------------------------------
+--R            4   x 2     2 3  x     3 2
+--R        2a b (%e )  + 4a b %e  + 2a b
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 230
+
+)clear all
+
+--S 231 of 1034
+t0:=%e^(2*x)/(a+%e^x*b)^4
+--R 
+--R
+--R                                  2x
+--R                                %e
+--R   (1)  ----------------------------------------------------
+--R         4   x 4       3   x 3     2 2   x 2     3    x    4
+--R        b (%e )  + 4a b (%e )  + 6a b (%e )  + 4a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 1034
+r0:=1/3*a/(b^2*(a+%e^x*b)^3)+(-1/2)/(b^2*(a+%e^x*b)^2)
+--R 
+--R
+--R                               x
+--R                        - 3b %e  - a
+--R   (2)  --------------------------------------------
+--R          5   x 3        4   x 2      2 3  x     3 2
+--R        6b (%e )  + 18a b (%e )  + 18a b %e  + 6a b
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               x
+--R                        - 3b %e  - a
+--R   (3)  --------------------------------------------
+--R          5   x 3        4   x 2      2 3  x     3 2
+--R        6b (%e )  + 18a b (%e )  + 18a b %e  + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 233
+
+--S 234 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 235
+
+)clear all
+
+--S 236 of 1034
+t0:=%e^(4*x)/(a+%e^(2*x)*b)
+--R 
+--R
+--R             4x
+--R           %e
+--R   (1)  ----------
+--R            2x
+--R        b %e   + a
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 1034
+r0:=1/2*%e^(2*x)/b-1/2*a*log(a+%e^(2*x)*b)/b^2
+--R 
+--R
+--R                    2x            2x
+--R        - a log(b %e   + a) + b %e
+--R   (2)  ----------------------------
+--R                       2
+--R                     2b
+--R                                                    Type: Expression(Integer)
+--E 237
+
+--S 238 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    2x            2x
+--R        - a log(b %e   + a) + b %e
+--R   (3)  ----------------------------
+--R                       2
+--R                     2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 238
+
+--S 239 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 1034
+t0:=%e^(4*x)/(a+%e^(2*x)*b)^2
+--R 
+--R
+--R                     4x
+--R                   %e
+--R   (1)  --------------------------
+--R         2   2x 2          2x    2
+--R        b (%e  )  + 2a b %e   + a
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 1034
+r0:=1/2*a/(b^2*(a+%e^(2*x)*b))+1/2*log(a+%e^(2*x)*b)/b^2
+--R 
+--R
+--R             2x             2x
+--R        (b %e   + a)log(b %e   + a) + a
+--R   (2)  -------------------------------
+--R                  3  2x       2
+--R                2b %e   + 2a b
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2x             2x
+--R        (b %e   + a)log(b %e   + a) + a
+--R   (3)  -------------------------------
+--R                  3  2x       2
+--R                2b %e   + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 243
+
+--S 244 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 245
+
+)clear all
+
+--S 246 of 1034
+t0:=%e^(4*x)/(a+%e^(2*x)*b)^3
+--R 
+--R
+--R                             4x
+--R                           %e
+--R   (1)  -----------------------------------------
+--R         3   2x 3       2   2x 2     2    2x    3
+--R        b (%e  )  + 3a b (%e  )  + 3a b %e   + a
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 1034
+r0:=1/4*%e^(4*x)/(a*(a+%e^(2*x)*b)^2)
+--R 
+--R
+--R                       4x
+--R                     %e
+--R   (2)  ------------------------------
+--R            2   2x 2     2    2x     3
+--R        4a b (%e  )  + 8a b %e   + 4a
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        2x
+--R                 - 2b %e   - a
+--R   (3)  ------------------------------
+--R          4   2x 2       3  2x     2 2
+--R        4b (%e  )  + 8a b %e   + 4a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 248
+
+--S 249 of 1034
+m0:=a0-r0
+--R 
+--R
+--R               2  4x          2x    2
+--R            - b %e   - 2a b %e   - a
+--R   (4)  --------------------------------
+--R            4   2x 2     2 3  2x     3 2
+--R        4a b (%e  )  + 8a b %e   + 4a b
+--R                                                    Type: Expression(Integer)
+--E 249
+
+--S 250 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 250
+
+)clear all
+
+--S 251 of 1034
+t0:=%e^(4*x)/(a+%e^(2*x)*b)^4
+--R 
+--R
+--R                                    4x
+--R                                  %e
+--R   (1)  --------------------------------------------------------
+--R         4   2x 4       3   2x 3     2 2   2x 2     3    2x    4
+--R        b (%e  )  + 4a b (%e  )  + 6a b (%e  )  + 4a b %e   + a
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 1034
+r0:=1/6*a/(b^2*(a+%e^(2*x)*b)^3)+(-1/4)/(b^2*(a+%e^(2*x)*b)^2)
+--R 
+--R
+--R                                 2x
+--R                          - 3b %e   - a
+--R   (2)  -------------------------------------------------
+--R           5   2x 3        4   2x 2      2 3  2x      3 2
+--R        12b (%e  )  + 36a b (%e  )  + 36a b %e   + 12a b
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                 2x
+--R                          - 3b %e   - a
+--R   (3)  -------------------------------------------------
+--R           5   2x 3        4   2x 2      2 3  2x      3 2
+--R        12b (%e  )  + 36a b (%e  )  + 36a b %e   + 12a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 253
+
+--S 254 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 1034
+t0:=%e^(4*x)/(a+%e^(2*x)*b)^(2/3)
+--R 
+--R
+--R               4x
+--R             %e
+--R   (1)  --------------
+--R         +----------+2
+--R        3|    2x
+--R        \|b %e   + a
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 1034
+r0:=-3/2*a*(a+%e^(2*x)*b)^(1/3)/b^2+3/8*(a+%e^(2*x)*b)^(4/3)/b^2
+--R 
+--R
+--R                       +----------+
+--R              2x      3|    2x
+--R        (3b %e   - 9a)\|b %e   + a
+--R   (2)  ---------------------------
+--R                      2
+--R                    8b
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       +----------+
+--R              2x      3|    2x
+--R        (3b %e   - 9a)\|b %e   + a
+--R   (3)  ---------------------------
+--R                      2
+--R                    8b
+--R                                         Type: Union(Expression(Integer),...)
+--E 258
+
+--S 259 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 260
+
+)clear all
+
+--S 261 of 1034
+t0:=(a+%e^(n*x)*b)/%e^(n*x)
+--R 
+--R
+--R            n x
+--R        b %e    + a
+--R   (1)  -----------
+--R             n x
+--R           %e
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 1034
+r0:=-a/(%e^(n*x)*n)+b*x
+--R 
+--R
+--R                n x
+--R        b n x %e    - a
+--R   (2)  ---------------
+--R                n x
+--R            n %e
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                n x
+--R        b n x %e    - a
+--R   (3)  ---------------
+--R                n x
+--R            n %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 263
+
+--S 264 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 265
+
+)clear all
+
+--S 266 of 1034
+t0:=(a+%e^(n*x)*b)^2/%e^(n*x)
+--R 
+--R
+--R         2   n x 2          n x    2
+--R        b (%e   )  + 2a b %e    + a
+--R   (1)  ----------------------------
+--R                      n x
+--R                    %e
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1034
+r0:=-a^2/(%e^(n*x)*n)+%e^(n*x)*b^2/n+2*a*b*x
+--R 
+--R
+--R         2   n x 2              n x    2
+--R        b (%e   )  + 2a b n x %e    - a
+--R   (2)  --------------------------------
+--R                         n x
+--R                     n %e
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2   n x 2              n x    2
+--R        b (%e   )  + 2a b n x %e    - a
+--R   (3)  --------------------------------
+--R                         n x
+--R                     n %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 268
+
+--S 269 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 1034
+t0:=(a+%e^(n*x)*b)^3/%e^(n*x)
+--R 
+--R
+--R         3   n x 3       2   n x 2     2    n x    3
+--R        b (%e   )  + 3a b (%e   )  + 3a b %e    + a
+--R   (1)  --------------------------------------------
+--R                              n x
+--R                            %e
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 1034
+r0:=-a^3/(%e^(n*x)*n)+3*%e^(n*x)*a*b^2/n+1/2*%e^(2*n*x)*b^3/n+3*a^2*b*x
+--R 
+--R
+--R         3  n x  2n x       2   n x 2     2        n x     3
+--R        b %e   %e     + 6a b (%e   )  + 6a b n x %e    - 2a
+--R   (2)  ----------------------------------------------------
+--R                                   n x
+--R                              2n %e
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3   n x 3       2   n x 2     2        n x     3
+--R        b (%e   )  + 6a b (%e   )  + 6a b n x %e    - 2a
+--R   (3)  -------------------------------------------------
+--R                                  n x
+--R                             2n %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 273
+
+--S 274 of 1034
+m0:=a0-r0
+--R 
+--R
+--R           3  2n x    3   n x 2
+--R        - b %e     + b (%e   )
+--R   (4)  -----------------------
+--R                   2n
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 275
+
+)clear all
+
+--S 276 of 1034
+t0:=1/(%e^(n*x)*(a+%e^(n*x)*b))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R             n x 2       n x
+--R        b (%e   )  + a %e
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 1034
+r0:=(-1)/(%e^(n*x)*a*n)-b*x/a^2+b*log(a+%e^(n*x)*b)/(a^2*n)
+--R 
+--R
+--R            n x        n x                n x
+--R        b %e   log(b %e    + a) - b n x %e    - a
+--R   (2)  -----------------------------------------
+--R                         2    n x
+--R                        a n %e
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R            n x        n x                n x
+--R        b %e   log(b %e    + a) - b n x %e    - a
+--R   (3)  -----------------------------------------
+--R                         2    n x
+--R                        a n %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 278
+
+--S 279 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 1034
+t0:=1/(%e^(n*x)*(a+%e^(n*x)*b)^2)
+--R 
+--R
+--R                          1
+--R   (1)  ------------------------------------
+--R         2   n x 3           n x 2    2  n x
+--R        b (%e   )  + 2a b (%e   )  + a %e
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 1034
+r0:=(-1)/(%e^(n*x)*a^2*n)-b/(a^2*(a+%e^(n*x)*b)*n)-2*b*x/a^3+_
+   2*b*log(a+%e^(n*x)*b)/(a^3*n)
+--R 
+--R
+--R   (2)
+--R          2   n x 2          n x         n x          2       n x 2
+--R       (2b (%e   )  + 2a b %e   )log(b %e    + a) - 2b n x (%e   )
+--R     + 
+--R                            n x    2
+--R       (- 2a b n x - 2a b)%e    - a
+--R  /
+--R      3       n x 2    4    n x
+--R     a b n (%e   )  + a n %e
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2   n x 2          n x         n x          2       n x 2
+--R       (2b (%e   )  + 2a b %e   )log(b %e    + a) - 2b n x (%e   )
+--R     + 
+--R                            n x    2
+--R       (- 2a b n x - 2a b)%e    - a
+--R  /
+--R      3       n x 2    4    n x
+--R     a b n (%e   )  + a n %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 283
+
+--S 284 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 1034
+t0:=1/(%e^(n*x)*(a+%e^(n*x)*b)^3)
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R         3   n x 4       2   n x 3     2     n x 2    3  n x
+--R        b (%e   )  + 3a b (%e   )  + 3a b (%e   )  + a %e
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 1034
+r0:=(-1)/(%e^(n*x)*a^3*n)-1/2*b/(a^2*(a+%e^(n*x)*b)^2*n)-_
+   2*b/(a^3*(a+%e^(n*x)*b)*n)-3*b*x/a^4+3*b*log(a+%e^(n*x)*b)/(a^4*n)
+--R 
+--R
+--R   (2)
+--R          3   n x 3        2   n x 2     2    n x         n x
+--R       (6b (%e   )  + 12a b (%e   )  + 6a b %e   )log(b %e    + a)
+--R     + 
+--R           3       n x 3           2          2    n x 2
+--R       - 6b n x (%e   )  + (- 12a b n x - 6a b )(%e   )
+--R     + 
+--R            2          2    n x     3
+--R       (- 6a b n x - 9a b)%e    - 2a
+--R  /
+--R       4 2     n x 3     5       n x 2     6    n x
+--R     2a b n (%e   )  + 4a b n (%e   )  + 2a n %e
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3   n x 3        2   n x 2     2    n x         n x
+--R       (6b (%e   )  + 12a b (%e   )  + 6a b %e   )log(b %e    + a)
+--R     + 
+--R           3       n x 3           2          2    n x 2
+--R       - 6b n x (%e   )  + (- 12a b n x - 6a b )(%e   )
+--R     + 
+--R            2          2    n x     3
+--R       (- 6a b n x - 9a b)%e    - 2a
+--R  /
+--R       4 2     n x 3     5       n x 2     6    n x
+--R     2a b n (%e   )  + 4a b n (%e   )  + 2a n %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 288
+
+--S 289 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 290
+
+)clear all
+
+--S 291 of 1034
+t0:=f^(a+b*x)/(c+d*f^(e+2*b*x))
+--R 
+--R
+--R             b x + a
+--R            f
+--R   (1)  ---------------
+--R           2b x + e
+--R        d f         + c
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 1034
+r0:=f^a*atan(f^(b*x)*sqrt(d)/(sqrt(c)*sqrt(1/f^e)))*sqrt(1/f^e)/(b*log(f)*_
+   sqrt(c)*sqrt(d))
+--R 
+--R
+--R           +--+       b x +-+
+--R         a | 1       f   \|d
+--R        f  |-- atan(---------)
+--R           | e           +--+
+--R          \|f        +-+ | 1
+--R                    \|c  |--
+--R                         | e
+--R                        \|f
+--R   (2)  ----------------------
+--R                    +-+ +-+
+--R           b log(f)\|c \|d
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                     (e - 2a)log(f)   (b x + a)log(f) 2
+--R                (d %e              (%e               )  - c)
+--R             *
+--R                 +----------------------+
+--R                 |        (e - 2a)log(f)
+--R                \|- c d %e
+--R            + 
+--R                     (e - 2a)log(f)  (b x + a)log(f)
+--R              2c d %e              %e
+--R         /
+--R                (e - 2a)log(f)   (b x + a)log(f) 2
+--R            d %e              (%e               )  + c
+--R    /
+--R                 +----------------------+
+--R                 |        (e - 2a)log(f)
+--R       2b log(f)\|- c d %e
+--R     ,
+--R                           +--------------------+
+--R           (b x + a)log(f) |      (e - 2a)log(f)
+--R         %e               \|c d %e
+--R    atan(----------------------------------------)
+--R                             c
+--R    ----------------------------------------------]
+--R                     +--------------------+
+--R                     |      (e - 2a)log(f)
+--R            b log(f)\|c d %e
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 293
+
+--S 294 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R          +-+ +-+
+--R         \|c \|d
+--R      *
+--R         log
+--R                       (e - 2a)log(f)   (b x + a)log(f) 2
+--R                  (d %e              (%e               )  - c)
+--R               *
+--R                   +----------------------+
+--R                   |        (e - 2a)log(f)
+--R                  \|- c d %e
+--R              + 
+--R                       (e - 2a)log(f)  (b x + a)log(f)
+--R                2c d %e              %e
+--R           /
+--R                  (e - 2a)log(f)   (b x + a)log(f) 2
+--R              d %e              (%e               )  + c
+--R     + 
+--R             +--+       b x +-+  +----------------------+
+--R           a | 1       f   \|d   |        (e - 2a)log(f)
+--R       - 2f  |-- atan(---------)\|- c d %e
+--R             | e           +--+
+--R            \|f        +-+ | 1
+--R                      \|c  |--
+--R                           | e
+--R                          \|f
+--R  /
+--R                       +----------------------+
+--R               +-+ +-+ |        (e - 2a)log(f)
+--R     2b log(f)\|c \|d \|- c d %e
+--R                                                    Type: Expression(Integer)
+--E 294
+
+--S 295 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                      +--------------------+
+--R                      (b x + a)log(f) |      (e - 2a)log(f)
+--R        +-+ +-+     %e               \|c d %e
+--R       \|c \|d atan(----------------------------------------)
+--R                                        c
+--R     + 
+--R            +--+       b x +-+  +--------------------+
+--R          a | 1       f   \|d   |      (e - 2a)log(f)
+--R       - f  |-- atan(---------)\|c d %e
+--R            | e           +--+
+--R           \|f        +-+ | 1
+--R                     \|c  |--
+--R                          | e
+--R                         \|f
+--R  /
+--R                      +--------------------+
+--R              +-+ +-+ |      (e - 2a)log(f)
+--R     b log(f)\|c \|d \|c d %e
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 1034
+t0:=f^(a+2*b*x)/(c+d*f^(e+2*b*x))
+--R 
+--R
+--R            2b x + a
+--R           f
+--R   (1)  ---------------
+--R           2b x + e
+--R        d f         + c
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 1034
+r0:=1/2*f^(a-e)*log(c+d*f^(e+2*b*x))/(b*d*log(f))
+--R 
+--R
+--R         - e + a       2b x + e
+--R        f       log(d f         + c)
+--R   (2)  ----------------------------
+--R                 2b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R          (- e + a)log(f)        (2b x + e)log(f)
+--R        %e               log(d %e                 + c)
+--R   (3)  ----------------------------------------------
+--R                          2b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 300
+
+--S 301 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R     (- e + a)log(f)        (2b x + e)log(f)         - e + a       2b x + e
+--R   %e               log(d %e                 + c) - f       log(d f         + c)
+--R   -----------------------------------------------------------------------------
+--R                                    2b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 302
+
+)clear all
+
+--S 303 of 1034
+t0:=f^(a+3*b*x)/(c+d*f^(e+2*b*x))
+--R 
+--R
+--R            3b x + a
+--R           f
+--R   (1)  ---------------
+--R           2b x + e
+--R        d f         + c
+--R                                                    Type: Expression(Integer)
+--E 303
+
+--S 304 of 1034
+r0:=f^(a-e+b*x)/(b*d*log(f))-f^a*(1/f^e)^(3/2)*atan(f^(b*x)*sqrt(d)/(sqrt(c)*_
+   sqrt(1/f^e)))*sqrt(c)/(b*d^(3/2)*log(f))
+--R 
+--R
+--R                 +--+       b x +-+
+--R           a +-+ | 1       f   \|d      e b x - e + a +-+
+--R        - f \|c  |-- atan(---------) + f f           \|d
+--R                 | e           +--+
+--R                \|f        +-+ | 1
+--R                          \|c  |--
+--R                               | e
+--R                              \|f
+--R   (2)  -------------------------------------------------
+--R                                    e +-+
+--R                         b d log(f)f \|d
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                   (- 3e + 2a)log(f)
+--R            +---+  -----------------
+--R            |  c           2
+--R            |- - %e
+--R           \|  d
+--R        *
+--R                    (2b x + e)log(f) 2             (2b x + e)log(f)
+--R                    ----------------        +---+  ----------------
+--R                            2               |  c           2
+--R               d (%e                )  - 2d |- - %e                 - c
+--R                                           \|  d
+--R           log(--------------------------------------------------------)
+--R                                   (2b x + e)log(f) 2
+--R                                   ----------------
+--R                                           2
+--R                              d (%e                )  + c
+--R       + 
+--R            (- 3e + 2a)log(f)  (2b x + e)log(f)
+--R            -----------------  ----------------
+--R                    2                  2
+--R         2%e                 %e
+--R    /
+--R       2b d log(f)
+--R     ,
+--R
+--R                                         (2b x + e)log(f)
+--R                 (- 3e + 2a)log(f)       ----------------
+--R            +-+  -----------------               2
+--R            |c           2             %e
+--R         -  |- %e                 atan(------------------)
+--R           \|d                                 +-+
+--R                                               |c
+--R                                               |-
+--R                                              \|d
+--R       + 
+--R           (- 3e + 2a)log(f)  (2b x + e)log(f)
+--R           -----------------  ----------------
+--R                   2                  2
+--R         %e                 %e
+--R    /
+--R       b d log(f)
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 305
+
+--S 306 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       (- 3e + 2a)log(f)
+--R            +---+      -----------------
+--R          e |  c  +-+          2
+--R         f  |- - \|d %e
+--R           \|  d
+--R      *
+--R                  (2b x + e)log(f) 2             (2b x + e)log(f)
+--R                  ----------------        +---+  ----------------
+--R                          2               |  c           2
+--R             d (%e                )  - 2d |- - %e                 - c
+--R                                         \|  d
+--R         log(--------------------------------------------------------)
+--R                                 (2b x + e)log(f) 2
+--R                                 ----------------
+--R                                         2
+--R                            d (%e                )  + c
+--R     + 
+--R               +--+       b x +-+
+--R         a +-+ | 1       f   \|d
+--R       2f \|c  |-- atan(---------)
+--R               | e           +--+
+--R              \|f        +-+ | 1
+--R                        \|c  |--
+--R                             | e
+--R                            \|f
+--R     + 
+--R                (- 3e + 2a)log(f)  (2b x + e)log(f)
+--R                -----------------  ----------------
+--R         e +-+          2                  2            e b x - e + a +-+
+--R       2f \|d %e                 %e                 - 2f f           \|d
+--R  /
+--R                 e +-+
+--R     2b d log(f)f \|d
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                             (2b x + e)log(f)
+--R                     (- 3e + 2a)log(f)       ----------------
+--R            +-+      -----------------               2
+--R          e |c  +-+          2             %e
+--R       - f  |- \|d %e                 atan(------------------)
+--R           \|d                                     +-+
+--R                                                   |c
+--R                                                   |-
+--R                                                  \|d
+--R     + 
+--R                                            (- 3e + 2a)log(f)  (2b x + e)log(f)
+--R              +--+       b x +-+            -----------------  ----------------
+--R        a +-+ | 1       f   \|d      e +-+          2                  2
+--R       f \|c  |-- atan(---------) + f \|d %e                 %e
+--R              | e           +--+
+--R             \|f        +-+ | 1
+--R                       \|c  |--
+--R                            | e
+--R                           \|f
+--R     + 
+--R          e b x - e + a +-+
+--R       - f f           \|d
+--R  /
+--R                e +-+
+--R     b d log(f)f \|d
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 1034
+t0:=f^(a+4*b*x)/(c+d*f^(e+2*b*x))
+--R 
+--R
+--R            4b x + a
+--R           f
+--R   (1)  ---------------
+--R           2b x + e
+--R        d f         + c
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 1034
+r0:=1/2*f^(a-e+2*b*x)/(b*d*log(f))-1/2*c*f^(a-2*e)*log(c+d*f^(e+2*b*x))/_
+   (b*d^2*log(f))
+--R 
+--R
+--R             - 2e + a       2b x + e           2b x - e + a
+--R        - c f        log(d f         + c) + d f
+--R   (2)  ---------------------------------------------------
+--R                                2
+--R                            2b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             (- 2e + a)log(f)        (2b x + e)log(f)
+--R       - c %e                log(d %e                 + c)
+--R     + 
+--R           (- 2e + a)log(f)  (2b x + e)log(f)
+--R       d %e                %e
+--R  /
+--R         2
+--R     2b d log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 312
+
+--S 313 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             (- 2e + a)log(f)        (2b x + e)log(f)
+--R       - c %e                log(d %e                 + c)
+--R     + 
+--R          - 2e + a       2b x + e            (- 2e + a)log(f)  (2b x + e)log(f)
+--R       c f        log(d f         + c) + d %e                %e
+--R     + 
+--R            2b x - e + a
+--R       - d f
+--R  /
+--R         2
+--R     2b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 314
+
+)clear all
+
+--S 315 of 1034
+t0:=f^(a+5*b*x)/(c+d*f^(e+2*b*x))
+--R 
+--R
+--R            5b x + a
+--R           f
+--R   (1)  ---------------
+--R           2b x + e
+--R        d f         + c
+--R                                                    Type: Expression(Integer)
+--E 315
+
+--S 316 of 1034
+r0:=-c*f^(a-2*e+b*x)/(b*d^2*log(f))+1/3*f^(a-e+3*b*x)/(b*d*log(f))+c^(3/2)*_
+   f^(a-2*e)*atan(f^(b*x)*sqrt(d)/(sqrt(c)*sqrt(1/f^e)))*sqrt(1/f^e)/_
+   (b*d^(5/2)*log(f))
+--R 
+--R
+--R   (2)
+--R                        +--+       b x +-+
+--R           - 2e + a +-+ | 1       f   \|d
+--R       3c f        \|c  |-- atan(---------)
+--R                        | e           +--+
+--R                       \|f        +-+ | 1
+--R                                 \|c  |--
+--R                                      | e
+--R                                     \|f
+--R     + 
+--R           3b x - e + a       b x - 2e + a  +-+
+--R       (d f             - 3c f            )\|d
+--R  /
+--R         2       +-+
+--R     3b d log(f)\|d
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                     (- 5e + 2a)log(f)
+--R              +---+  -----------------
+--R              |  c           2
+--R           3c |- - %e
+--R             \|  d
+--R        *
+--R                    (2b x + e)log(f) 2             (2b x + e)log(f)
+--R                    ----------------        +---+  ----------------
+--R                            2               |  c           2
+--R               d (%e                )  + 2d |- - %e                 - c
+--R                                           \|  d
+--R           log(--------------------------------------------------------)
+--R                                   (2b x + e)log(f) 2
+--R                                   ----------------
+--R                                           2
+--R                              d (%e                )  + c
+--R       + 
+--R              (- 5e + 2a)log(f)   (2b x + e)log(f) 3
+--R              -----------------   ----------------
+--R                      2                   2
+--R         2d %e                 (%e                )
+--R       + 
+--R                (- 5e + 2a)log(f)  (2b x + e)log(f)
+--R                -----------------  ----------------
+--R                        2                  2
+--R         - 6c %e                 %e
+--R    /
+--R           2
+--R       6b d log(f)
+--R     ,
+--R
+--R                                         (2b x + e)log(f)
+--R                 (- 5e + 2a)log(f)       ----------------
+--R            +-+  -----------------               2
+--R            |c           2             %e
+--R         3c |- %e                 atan(------------------)
+--R           \|d                                 +-+
+--R                                               |c
+--R                                               |-
+--R                                              \|d
+--R       + 
+--R             (- 5e + 2a)log(f)   (2b x + e)log(f) 3
+--R             -----------------   ----------------
+--R                     2                   2
+--R         d %e                 (%e                )
+--R       + 
+--R                (- 5e + 2a)log(f)  (2b x + e)log(f)
+--R                -----------------  ----------------
+--R                        2                  2
+--R         - 3c %e                 %e
+--R    /
+--R           2
+--R       3b d log(f)
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 317
+
+--S 318 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       (- 5e + 2a)log(f)
+--R            +---+      -----------------
+--R            |  c  +-+          2
+--R         3c |- - \|d %e
+--R           \|  d
+--R      *
+--R                  (2b x + e)log(f) 2             (2b x + e)log(f)
+--R                  ----------------        +---+  ----------------
+--R                          2               |  c           2
+--R             d (%e                )  + 2d |- - %e                 - c
+--R                                         \|  d
+--R         log(--------------------------------------------------------)
+--R                                 (2b x + e)log(f) 2
+--R                                 ----------------
+--R                                         2
+--R                            d (%e                )  + c
+--R     + 
+--R                          +--+       b x +-+
+--R             - 2e + a +-+ | 1       f   \|d
+--R       - 6c f        \|c  |-- atan(---------)
+--R                          | e           +--+
+--R                         \|f        +-+ | 1
+--R                                   \|c  |--
+--R                                        | e
+--R                                       \|f
+--R     + 
+--R               (- 5e + 2a)log(f)   (2b x + e)log(f) 3
+--R               -----------------   ----------------
+--R          +-+          2                   2
+--R       2d\|d %e                 (%e                )
+--R     + 
+--R                 (- 5e + 2a)log(f)  (2b x + e)log(f)
+--R                 -----------------  ----------------
+--R            +-+          2                  2
+--R       - 6c\|d %e                 %e
+--R     + 
+--R              3b x - e + a       b x - 2e + a  +-+
+--R       (- 2d f             + 6c f            )\|d
+--R  /
+--R         2       +-+
+--R     6b d log(f)\|d
+--R                                                    Type: Expression(Integer)
+--E 318
+
+--S 319 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                           (2b x + e)log(f)
+--R                   (- 5e + 2a)log(f)       ----------------
+--R          +-+      -----------------               2
+--R          |c  +-+          2             %e
+--R       3c |- \|d %e                 atan(------------------)
+--R         \|d                                     +-+
+--R                                                 |c
+--R                                                 |-
+--R                                                \|d
+--R     + 
+--R                          +--+       b x +-+
+--R             - 2e + a +-+ | 1       f   \|d
+--R       - 3c f        \|c  |-- atan(---------)
+--R                          | e           +--+
+--R                         \|f        +-+ | 1
+--R                                   \|c  |--
+--R                                        | e
+--R                                       \|f
+--R     + 
+--R              (- 5e + 2a)log(f)   (2b x + e)log(f) 3
+--R              -----------------   ----------------
+--R         +-+          2                   2
+--R       d\|d %e                 (%e                )
+--R     + 
+--R                 (- 5e + 2a)log(f)  (2b x + e)log(f)
+--R                 -----------------  ----------------
+--R            +-+          2                  2
+--R       - 3c\|d %e                 %e
+--R     + 
+--R             3b x - e + a       b x - 2e + a  +-+
+--R       (- d f             + 3c f            )\|d
+--R  /
+--R         2       +-+
+--R     3b d log(f)\|d
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 1034
+t0:=%e^x/(1-%e^(2*x))
+--R 
+--R
+--R               x
+--R             %e
+--R   (1)  - --------
+--R            2x
+--R          %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 1034
+r0:=atanh(%e^x)
+--R 
+--R
+--R                x
+--R   (2)  atanh(%e )
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R              x              x
+--R        log(%e  + 1) - log(%e  - 1)
+--R   (3)  ---------------------------
+--R                     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 324
+
+--S 325 of 1034
+m0:=a0-r0
+--R 
+--R
+--R              x              x                 x
+--R        log(%e  + 1) - log(%e  - 1) - 2atanh(%e )
+--R   (4)  -----------------------------------------
+--R                            2
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 326
+
+)clear all
+
+--S 327 of 1034
+t0:=%e^x*x/(1-%e^(2*x))
+--R 
+--R
+--R                x
+--R            x %e
+--R   (1)  - --------
+--R            2x
+--R          %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 1034
+--r0:=x*atanh(%e^x)+1/2*polylog(2,-%e^x)-1/2*polylog(2,%e^x)
+--E 328
+
+--S 329 of 1034
+--a0:=integrate(t0,x)
+--E 329
+
+--S 330 of 1034
+--m0:=a0-r0
+--E 330
+
+--S 331 of 1034
+--d0:=normalize(D(m0,x))
+--E 331
+
+)clear all
+
+--S 332 of 1034
+t0:=%e^x*x^2/(1-%e^(2*x))
+--R 
+--R
+--R             2  x
+--R            x %e
+--R   (1)  - --------
+--R            2x
+--R          %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 1034
+--r0:=x^2*atanh(%e^x)+x*polylog(2,-%e^x)-x*polylog(2,%e^x)-_
+--  polylog(3,-%e^x)+polylog(3,%e^x)
+--E 333
+
+--S 334 of 1034
+--a0:=integrate(t0,x)
+--E 334
+
+--S 335 of 1034
+--m0:=a0-r0
+--E 335
+
+--S 336 of 1034
+--d0:=normalize(D(m0,x))
+--E 336
+
+)clear all
+
+--S 337 of 1034
+t0:=%e^x*x^3/(1-%e^(2*x))
+--R 
+--R
+--R             3  x
+--R            x %e
+--R   (1)  - --------
+--R            2x
+--R          %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 1034
+--r0:=x^3*atanh(%e^x)+3/2*x^2*polylog(2,-%e^x)-3/2*x^2*polylog(2,%e^x)-_
+--  3*x*polylog(3,-%e^x)+3*x*polylog(3,%e^x)+3*polylog(4,-%e^x)-_
+--  3*polylog(4,%e^x)
+--E 338
+
+--S 339 of 1034
+--a0:=integrate(t0,x)
+--E 339
+
+--S 340 of 1034
+--m0:=a0-r0
+--E 340
+
+--S 341 of 1034
+--d0:=normalize(D(m0,x))
+--E 341
+
+)clear all
+
+--S 342 of 1034
+t0:=f^x/(a+b*f^(2*x))
+--R 
+--R
+--R             x
+--R            f
+--R   (1)  ---------
+--R           2x
+--R        b f   + a
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 1034
+r0:=atan(f^x*sqrt(b)/sqrt(a))/(log(f)*sqrt(a)*sqrt(b))
+--R 
+--R
+--R               x +-+
+--R              f \|b
+--R         atan(------)
+--R                +-+
+--R               \|a
+--R   (2)  --------------
+--R               +-+ +-+
+--R        log(f)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-----+   x log(f) 2          x log(f)     +-----+
+--R        b\|- a b (%e        )  + 2a b %e         - a\|- a b
+--R    log(----------------------------------------------------)
+--R                              x log(f) 2
+--R                         b (%e        )  + a
+--R   [---------------------------------------------------------,
+--R                                 +-----+
+--R                         2log(f)\|- a b
+--R          +---+  x log(f)
+--R         \|a b %e
+--R    atan(----------------)
+--R                 a
+--R    ----------------------]
+--R                +---+
+--R         log(f)\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 344
+
+--S 345 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     +-----+   x log(f) 2          x log(f)     +-----+
+--R        +-+ +-+    b\|- a b (%e        )  + 2a b %e         - a\|- a b
+--R       \|a \|b log(----------------------------------------------------)
+--R                                         x log(f) 2
+--R                                    b (%e        )  + a
+--R     + 
+--R                        x +-+
+--R           +-----+     f \|b
+--R       - 2\|- a b atan(------)
+--R                         +-+
+--R                        \|a
+--R  /
+--R             +-----+ +-+ +-+
+--R     2log(f)\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 345
+
+--S 346 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R                      +---+  x log(f)                x +-+
+--R         +-+ +-+     \|a b %e             +---+     f \|b
+--R        \|a \|b atan(----------------) - \|a b atan(------)
+--R                             a                        +-+
+--R                                                     \|a
+--R   (6)  ---------------------------------------------------
+--R                               +-+ +-+ +---+
+--R                        log(f)\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 1034
+t0:=f^x*x/(a+b*f^(2*x))
+--R 
+--R
+--R              x
+--R           x f
+--R   (1)  ---------
+--R           2x
+--R        b f   + a
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 1034
+--r0:=x*atan(f^x*sqrt(b)/sqrt(a))/(log(f)*sqrt(a)*sqrt(b))-1/2*%i*_
+--  polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*sqrt(b))+_
+--  1/2*%i*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*sqrt(b))
+--E 350
+
+--S 351 of 1034
+--a0:=integrate(t0,x)
+--E 351
+
+--S 352 of 1034
+--m0:=a0-r0
+--E 352
+
+--S 353 of 1034
+--d0:=normalize(D(m0,x))
+--E 353
+
+)clear all
+
+--S 354 of 1034
+t0:=f^x*x^2/(a+b*f^(2*x))
+--R 
+--R
+--R            2 x
+--R           x f
+--R   (1)  ---------
+--R           2x
+--R        b f   + a
+--R                                                    Type: Expression(Integer)
+--E 354
+
+--S 355 of 1034
+--r0:=x^2*atan(f^x*sqrt(b)/sqrt(a))/(log(f)*sqrt(a)*sqrt(b))-%i*x*_
+--  polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*sqrt(b))+%i*x*_
+--  polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*sqrt(b))+%i*_
+--  polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^3*sqrt(a)*sqrt(b))-%i*_
+--  polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^3*sqrt(a)*sqrt(b))
+--E 355
+
+--S 356 of 1034
+--a0:=integrate(t0,x)
+--E 356
+
+--S 357 of 1034
+--m0:=a0-r0
+--E 357
+
+--S 358 of 1034
+--d0:=normalize(D(m0,x))
+--E 358
+
+)clear all
+
+--S 359 of 1034
+t0:=f^x*x^3/(a+b*f^(2*x))
+--R 
+--R
+--R            3 x
+--R           x f
+--R   (1)  ---------
+--R           2x
+--R        b f   + a
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 1034
+--r0:=x^3*atan(f^x*sqrt(b)/sqrt(a))/(log(f)*sqrt(a)*sqrt(b))-3/2*%i*x^2*_
+--  polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*sqrt(b))+_
+--  3/2*%i*x^2*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*_
+--  sqrt(b))+3*%i*x*polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^3*sqrt(a)*_
+--  sqrt(b))-3*%i*x*polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^3*sqrt(a)*_
+--  sqrt(b))-3*%i*polylog(4,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^4*sqrt(a)*_
+--  sqrt(b))+3*%i*polylog(4,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^4*sqrt(a)*sqrt(b))
+--E 360
+
+--S 361 of 1034
+--a0:=integrate(t0,x)
+--E 361
+
+--S 362 of 1034
+--m0:=a0-r0
+--E 362
+
+--S 363 of 1034
+--d0:=normalize(D(m0,x))
+--E 363
+
+)clear all
+
+--S 364 of 1034
+t0:=f^x/(a+b*f^(2*x))^2
+--R 
+--R
+--R                    x
+--R                   f
+--R   (1)  ------------------------
+--R         2  2x 2         2x    2
+--R        b (f  )  + 2a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 1034
+r0:=1/2*f^x/(a*(a+b*f^(2*x))*log(f))+1/2*atan(f^x*sqrt(b)/sqrt(a))/_
+   (a^(3/2)*log(f)*sqrt(b))
+--R 
+--R
+--R                         x +-+
+--R            2x          f \|b      x +-+ +-+
+--R        (b f   + a)atan(------) + f \|a \|b
+--R                          +-+
+--R                         \|a
+--R   (2)  ------------------------------------
+--R                     2x     2        +-+ +-+
+--R        (2a b log(f)f   + 2a log(f))\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 x log(f) 2
+--R           (b (%e        )  + a)
+--R        *
+--R                 +-----+   x log(f) 2          x log(f)     +-----+
+--R               b\|- a b (%e        )  + 2a b %e         - a\|- a b
+--R           log(----------------------------------------------------)
+--R                                     x log(f) 2
+--R                                b (%e        )  + a
+--R       + 
+--R           +-----+  x log(f)
+--R         2\|- a b %e
+--R    /
+--R                   +-----+   x log(f) 2     2       +-----+
+--R       4a b log(f)\|- a b (%e        )  + 4a log(f)\|- a b
+--R     ,
+--R                               +---+  x log(f)
+--R          x log(f) 2          \|a b %e             +---+  x log(f)
+--R    (b (%e        )  + a)atan(----------------) + \|a b %e
+--R                                      a
+--R    --------------------------------------------------------------]
+--R                       +---+   x log(f) 2     2       +---+
+--R           2a b log(f)\|a b (%e        )  + 2a log(f)\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 366
+
+--S 367 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2x        +-+ +-+   x log(f) 2         2x    2  +-+ +-+
+--R         ((b f   + a b)\|a \|b (%e        )  + (a b f   + a )\|a \|b )
+--R      *
+--R               +-----+   x log(f) 2          x log(f)     +-----+
+--R             b\|- a b (%e        )  + 2a b %e         - a\|- a b
+--R         log(----------------------------------------------------)
+--R                                   x log(f) 2
+--R                              b (%e        )  + a
+--R     + 
+--R                                         x +-+
+--R               2 2x         +-----+     f \|b         x +-----+ +-+ +-+
+--R         ((- 2b f   - 2a b)\|- a b atan(------) - 2b f \|- a b \|a \|b )
+--R                                          +-+
+--R                                         \|a
+--R      *
+--R            x log(f) 2
+--R         (%e        )
+--R     + 
+--R            2x       +-----+ +-+ +-+  x log(f)
+--R       (2b f   + 2a)\|- a b \|a \|b %e
+--R     + 
+--R                                       x +-+
+--R                2x     2  +-----+     f \|b         x +-----+ +-+ +-+
+--R       (- 2a b f   - 2a )\|- a b atan(------) - 2a f \|- a b \|a \|b
+--R                                        +-+
+--R                                       \|a
+--R  /
+--R            2       2x     2          +-----+ +-+ +-+   x log(f) 2
+--R       (4a b log(f)f   + 4a b log(f))\|- a b \|a \|b (%e        )
+--R     + 
+--R          2         2x     3        +-----+ +-+ +-+
+--R       (4a b log(f)f   + 4a log(f))\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            2 2x        +-+ +-+   x log(f) 2         2x    2  +-+ +-+
+--R         ((b f   + a b)\|a \|b (%e        )  + (a b f   + a )\|a \|b )
+--R      *
+--R               +---+  x log(f)
+--R              \|a b %e
+--R         atan(----------------)
+--R                      a
+--R     + 
+--R                                   x +-+
+--R            2 2x        +---+     f \|b        x +-+ +-+ +---+    x log(f) 2
+--R       ((- b f   - a b)\|a b atan(------) - b f \|a \|b \|a b )(%e        )
+--R                                    +-+
+--R                                   \|a
+--R     + 
+--R                                                                         x +-+
+--R           2x      +-+ +-+ +---+  x log(f)           2x    2  +---+     f \|b
+--R       (b f   + a)\|a \|b \|a b %e         + (- a b f   - a )\|a b atan(------)
+--R                                                                          +-+
+--R                                                                         \|a
+--R     + 
+--R            x +-+ +-+ +---+
+--R       - a f \|a \|b \|a b
+--R  /
+--R            2       2x     2          +-+ +-+ +---+   x log(f) 2
+--R       (2a b log(f)f   + 2a b log(f))\|a \|b \|a b (%e        )
+--R     + 
+--R          2         2x     3        +-+ +-+ +---+
+--R       (2a b log(f)f   + 2a log(f))\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 369
+
+--S 370 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 370
+
+)clear all
+
+--S 371 of 1034
+t0:=f^x*x/(a+b*f^(2*x))^2
+--R 
+--R
+--R                     x
+--R                  x f
+--R   (1)  ------------------------
+--R         2  2x 2         2x    2
+--R        b (f  )  + 2a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1034
+--r0:=1/2*f^x*x/(a*(a+b*f^(2*x))*log(f))-1/2*atan(f^x*sqrt(b)/sqrt(a))/_
+--  (a^(3/2)*log(f)^2*sqrt(b))+1/2*x*atan(f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)*sqrt(b))-1/4*%i*polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^2*sqrt(b))+1/4*%i*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^2*sqrt(b))
+--E 372
+
+--S 373 of 1034
+--a0:=integrate(t0,x)
+--E 373
+
+--S 374 of 1034
+--m0:=a0-r0
+--E 374
+
+--S 375 of 1034
+--d0:=normalize(D(m0,x))
+--E 375
+
+)clear all
+
+--S 376 of 1034
+t0:=f^x*x^2/(a+b*f^(2*x))^2
+--R 
+--R
+--R                   2 x
+--R                  x f
+--R   (1)  ------------------------
+--R         2  2x 2         2x    2
+--R        b (f  )  + 2a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1034
+--r0:=1/2*f^x*x^2/(a*(a+b*f^(2*x))*log(f))-x*atan(f^x*sqrt(b)/sqrt(a))/_
+--  (a^(3/2)*log(f)^2*sqrt(b))+1/2*x^2*atan(f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)*sqrt(b))+1/2*%i*polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^3*sqrt(b))-1/2*%i*x*polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^2*sqrt(b))-1/2*%i*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^3*sqrt(b))+1/2*%i*x*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^2*sqrt(b))+1/2*%i*polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^3*sqrt(b))-1/2*%i*polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^3*sqrt(b))
+--E 377
+
+--S 378 of 1034
+--a0:=integrate(t0,x)
+--E 378
+
+--S 379 of 1034
+--m0:=a0-r0
+--E 379
+
+--S 380 of 1034
+--d0:=normalize(D(m0,x))
+--E 380
+
+)clear all
+
+--S 381 of 1034
+t0:=f^x*x^3/(a+b*f^(2*x))^2
+--R 
+--R
+--R                   3 x
+--R                  x f
+--R   (1)  ------------------------
+--R         2  2x 2         2x    2
+--R        b (f  )  + 2a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 1034
+--r0:=1/2*f^x*x^3/(a*(a+b*f^(2*x))*log(f))-3/2*x^2*atan(f^x*sqrt(b)/_
+--  sqrt(a))/(a^(3/2)*log(f)^2*sqrt(b))+1/2*x^3*atan(f^x*sqrt(b)/_
+--  sqrt(a))/(a^(3/2)*log(f)*sqrt(b))+3/2*%i*x*polylog(2,-%i*f^x*sqrt(b)/_
+--  sqrt(a))/(a^(3/2)*log(f)^3*sqrt(b))-3/4*%i*x^2*polylog(2,-%i*f^x*_
+--  sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^2*sqrt(b))-3/2*%i*x*polylog(2,%i*f^x*_
+--  sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^3*sqrt(b))+3/4*%i*x^2*_
+--  polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^2*sqrt(b))-3/2*%i*_
+--  polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^4*sqrt(b))+_
+--  3/2*%i*x*polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^3*_
+--  sqrt(b))+3/2*%i*polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^4*_
+--  sqrt(b))-3/2*%i*x*polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^3*_
+--  sqrt(b))-3/2*%i*polylog(4,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^4*_
+--  sqrt(b))+3/2*%i*polylog(4,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^4*_
+--  sqrt(b))
+--E 382
+
+--S 383 of 1034
+--a0:=integrate(t0,x)
+--E 383
+
+--S 384 of 1034
+--m0:=a0-r0
+--E 384
+
+--S 385 of 1034
+--d0:=normalize(D(m0,x))
+--E 385
+
+)clear all
+
+--S 386 of 1034
+t0:=f^x/(a+b*f^(2*x))^3
+--R 
+--R
+--R                           x
+--R                          f
+--R   (1)  --------------------------------------
+--R         3  2x 3       2  2x 2     2   2x    3
+--R        b (f  )  + 3a b (f  )  + 3a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 1034
+r0:=1/4*f^x/(a*(a+b*f^(2*x))^2*log(f))+3/8*f^x/(a^2*(a+b*f^(2*x))*log(f))+_
+   3/8*atan(f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)*sqrt(b))
+--R 
+--R
+--R                                          x +-+
+--R           2  2x 2         2x     2      f \|b          x 2x       x  +-+ +-+
+--R        (3b (f  )  + 6a b f   + 3a )atan(------) + (3b f f   + 5a f )\|a \|b
+--R                                           +-+
+--R                                          \|a
+--R   (2)  ---------------------------------------------------------------------
+--R                 2 2        2x 2      3         2x     4        +-+ +-+
+--R              (8a b log(f)(f  )  + 16a b log(f)f   + 8a log(f))\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 387
+
+--S 388 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R              2   x log(f) 4           x log(f) 2     2
+--R           (3b (%e        )  + 6a b (%e        )  + 3a )
+--R        *
+--R                 +-----+   x log(f) 2          x log(f)     +-----+
+--R               b\|- a b (%e        )  + 2a b %e         - a\|- a b
+--R           log(----------------------------------------------------)
+--R                                     x log(f) 2
+--R                                b (%e        )  + a
+--R       + 
+--R            +-----+   x log(f) 3       +-----+  x log(f)
+--R         6b\|- a b (%e        )  + 10a\|- a b %e
+--R    /
+--R            2 2       +-----+   x log(f) 4      3         +-----+   x log(f) 2
+--R         16a b log(f)\|- a b (%e        )  + 32a b log(f)\|- a b (%e        )
+--R       + 
+--R            4       +-----+
+--R         16a log(f)\|- a b
+--R     ,
+--R
+--R                                                            +---+  x log(f)
+--R            2   x log(f) 4           x log(f) 2     2      \|a b %e
+--R         (3b (%e        )  + 6a b (%e        )  + 3a )atan(----------------)
+--R                                                                   a
+--R       + 
+--R            +---+   x log(f) 3      +---+  x log(f)
+--R         3b\|a b (%e        )  + 5a\|a b %e
+--R    /
+--R           2 2       +---+   x log(f) 4      3         +---+   x log(f) 2
+--R         8a b log(f)\|a b (%e        )  + 16a b log(f)\|a b (%e        )
+--R       + 
+--R           4       +---+
+--R         8a log(f)\|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 388
+
+--S 389 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              4  2x 2       3 2x     2 2  +-+ +-+   x log(f) 4
+--R           (3b (f  )  + 6a b f   + 3a b )\|a \|b (%e        )
+--R         + 
+--R                3  2x 2      2 2 2x     3   +-+ +-+   x log(f) 2
+--R           (6a b (f  )  + 12a b f   + 6a b)\|a \|b (%e        )
+--R         + 
+--R              2 2  2x 2     3   2x     4  +-+ +-+
+--R           (3a b (f  )  + 6a b f   + 3a )\|a \|b
+--R      *
+--R               +-----+   x log(f) 2          x log(f)     +-----+
+--R             b\|- a b (%e        )  + 2a b %e         - a\|- a b
+--R         log(----------------------------------------------------)
+--R                                   x log(f) 2
+--R                              b (%e        )  + a
+--R     + 
+--R                                                          x +-+
+--R                4  2x 2        3 2x     2 2  +-----+     f \|b
+--R           (- 6b (f  )  - 12a b f   - 6a b )\|- a b atan(------)
+--R                                                           +-+
+--R                                                          \|a
+--R         + 
+--R                3 x 2x        2 x  +-----+ +-+ +-+
+--R           (- 6b f f   - 10a b f )\|- a b \|a \|b
+--R      *
+--R            x log(f) 4
+--R         (%e        )
+--R     + 
+--R          3  2x 2        2 2x     2   +-----+ +-+ +-+   x log(f) 3
+--R       (6b (f  )  + 12a b f   + 6a b)\|- a b \|a \|b (%e        )
+--R     + 
+--R                                                             x +-+
+--R                   3  2x 2      2 2 2x      3   +-----+     f \|b
+--R           (- 12a b (f  )  - 24a b f   - 12a b)\|- a b atan(------)
+--R                                                              +-+
+--R                                                             \|a
+--R         + 
+--R                   2 x 2x      2   x  +-----+ +-+ +-+
+--R           (- 12a b f f   - 20a b f )\|- a b \|a \|b
+--R      *
+--R            x log(f) 2
+--R         (%e        )
+--R     + 
+--R             2  2x 2      2   2x      3  +-----+ +-+ +-+  x log(f)
+--R       (10a b (f  )  + 20a b f   + 10a )\|- a b \|a \|b %e
+--R     + 
+--R                                                      x +-+
+--R            2 2  2x 2      3   2x     4  +-----+     f \|b
+--R       (- 6a b (f  )  - 12a b f   - 6a )\|- a b atan(------)
+--R                                                       +-+
+--R                                                      \|a
+--R     + 
+--R            2   x 2x      3 x  +-----+ +-+ +-+
+--R       (- 6a b f f   - 10a f )\|- a b \|a \|b
+--R  /
+--R             2 4        2x 2      3 3       2x      4 2        +-----+ +-+ +-+
+--R         (16a b log(f)(f  )  + 32a b log(f)f   + 16a b log(f))\|- a b \|a \|b
+--R      *
+--R            x log(f) 4
+--R         (%e        )
+--R     + 
+--R             3 3        2x 2      4 2       2x      5          +-----+ +-+ +-+
+--R         (32a b log(f)(f  )  + 64a b log(f)f   + 32a b log(f))\|- a b \|a \|b
+--R      *
+--R            x log(f) 2
+--R         (%e        )
+--R     + 
+--R           4 2        2x 2      5         2x      6        +-----+ +-+ +-+
+--R       (16a b log(f)(f  )  + 32a b log(f)f   + 16a log(f))\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 390
+
+--S 391 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              4  2x 2       3 2x     2 2  +-+ +-+   x log(f) 4
+--R           (3b (f  )  + 6a b f   + 3a b )\|a \|b (%e        )
+--R         + 
+--R                3  2x 2      2 2 2x     3   +-+ +-+   x log(f) 2
+--R           (6a b (f  )  + 12a b f   + 6a b)\|a \|b (%e        )
+--R         + 
+--R              2 2  2x 2     3   2x     4  +-+ +-+
+--R           (3a b (f  )  + 6a b f   + 3a )\|a \|b
+--R      *
+--R               +---+  x log(f)
+--R              \|a b %e
+--R         atan(----------------)
+--R                      a
+--R     + 
+--R                                                       x +-+
+--R                4  2x 2       3 2x     2 2  +---+     f \|b
+--R           (- 3b (f  )  - 6a b f   - 3a b )\|a b atan(------)
+--R                                                        +-+
+--R                                                       \|a
+--R         + 
+--R                3 x 2x       2 x  +-+ +-+ +---+
+--R           (- 3b f f   - 5a b f )\|a \|b \|a b
+--R      *
+--R            x log(f) 4
+--R         (%e        )
+--R     + 
+--R          3  2x 2       2 2x     2   +-+ +-+ +---+   x log(f) 3
+--R       (3b (f  )  + 6a b f   + 3a b)\|a \|b \|a b (%e        )
+--R     + 
+--R                                                         x +-+
+--R                  3  2x 2      2 2 2x     3   +---+     f \|b
+--R           (- 6a b (f  )  - 12a b f   - 6a b)\|a b atan(------)
+--R                                                          +-+
+--R                                                         \|a
+--R         + 
+--R                  2 x 2x      2   x  +-+ +-+ +---+
+--R           (- 6a b f f   - 10a b f )\|a \|b \|a b
+--R      *
+--R            x log(f) 2
+--R         (%e        )
+--R     + 
+--R            2  2x 2      2   2x     3  +-+ +-+ +---+  x log(f)
+--R       (5a b (f  )  + 10a b f   + 5a )\|a \|b \|a b %e
+--R     + 
+--R                                                   x +-+
+--R            2 2  2x 2     3   2x     4  +---+     f \|b
+--R       (- 3a b (f  )  - 6a b f   - 3a )\|a b atan(------)
+--R                                                    +-+
+--R                                                   \|a
+--R     + 
+--R            2   x 2x     3 x  +-+ +-+ +---+
+--R       (- 3a b f f   - 5a f )\|a \|b \|a b
+--R  /
+--R            2 4        2x 2      3 3       2x     4 2        +-+ +-+ +---+
+--R         (8a b log(f)(f  )  + 16a b log(f)f   + 8a b log(f))\|a \|b \|a b
+--R      *
+--R            x log(f) 4
+--R         (%e        )
+--R     + 
+--R             3 3        2x 2      4 2       2x      5          +-+ +-+ +---+
+--R         (16a b log(f)(f  )  + 32a b log(f)f   + 16a b log(f))\|a \|b \|a b
+--R      *
+--R            x log(f) 2
+--R         (%e        )
+--R     + 
+--R          4 2        2x 2      5         2x     6        +-+ +-+ +---+
+--R       (8a b log(f)(f  )  + 16a b log(f)f   + 8a log(f))\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 392
+
+)clear all
+
+--S 393 of 1034
+t0:=f^x*x/(a+b*f^(2*x))^3
+--R 
+--R
+--R                            x
+--R                         x f
+--R   (1)  --------------------------------------
+--R         3  2x 3       2  2x 2     2   2x    3
+--R        b (f  )  + 3a b (f  )  + 3a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 393
+
+--S 394 of 1034
+--r0:=-1/8*f^x/(a^2*(a+b*f^(2*x))*log(f)^2)+1/4*f^x*x/(a*(a+b*f^(2*x))^2*_
+--  log(f))+3/8*f^x*x/(a^2*(a+b*f^(2*x))*log(f))-1/2*atan(f^x*sqrt(b)/_
+--  sqrt(a))/(a^(5/2)*log(f)^2*sqrt(b))+3/8*x*atan(f^x*sqrt(b)/sqrt(a))/_
+--  (a^(5/2)*log(f)*sqrt(b))-3/16*%i*polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/_
+--  (a^(5/2)*log(f)^2*sqrt(b))+3/16*%i*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/_
+--  (a^(5/2)*log(f)^2*sqrt(b))
+--E 394
+
+--S 395 of 1034
+--a0:=integrate(t0,x)
+--E 395
+
+--S 396 of 1034
+--m0:=a0-r0
+--E 396
+
+--S 397 of 1034
+--d0:=normalize(D(m0,x))
+--E 397
+
+)clear all
+
+--S 398 of 1034
+t0:=f^x*x^2/(a+b*f^(2*x))^3
+--R 
+--R
+--R                          2 x
+--R                         x f
+--R   (1)  --------------------------------------
+--R         3  2x 3       2  2x 2     2   2x    3
+--R        b (f  )  + 3a b (f  )  + 3a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 1034
+--r0:=-1/4*f^x*x/(a^2*(a+b*f^(2*x))*log(f)^2)+1/4*f^x*x^2/(a*(a+_
+--  b*f^(2*x))^2*log(f))+3/8*f^x*x^2/(a^2*(a+b*f^(2*x))*log(f))+_
+--  1/4*atan(f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)^3*sqrt(b))-_
+--  x*atan(f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)^2*sqrt(b))+3/8*x^2*_
+--  atan(f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)*sqrt(b))+1/2*%i*_
+--  polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)^3*sqrt(b))-_
+--  3/8*%i*x*polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)^2*_
+--  sqrt(b))-1/2*%i*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)^3*_
+--  sqrt(b))+3/8*%i*x*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*_
+--  log(f)^2*sqrt(b))+3/8*%i*polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*_
+--  log(f)^3*sqrt(b))-3/8*%i*polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*_
+--  log(f)^3*sqrt(b))
+--E 399
+
+--S 400 of 1034
+--a0:=integrate(t0,x)
+--E 400
+
+--S 401 of 1034
+--m0:=a0-r0
+--E 401
+
+--S 402 of 1034
+--d0:=normalize(D(m0,x))
+--E 402
+
+)clear all
+
+--S 403 of 1034
+t0:=1/(b/f^x+a*f^x)
+--R 
+--R
+--R              x
+--R             f
+--R   (1)  -----------
+--R            x 2
+--R        a (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 1034
+r0:=atan(f^x*sqrt(a)/sqrt(b))/(log(f)*sqrt(a)*sqrt(b))
+--R 
+--R
+--R               x +-+
+--R              f \|a
+--R         atan(------)
+--R                +-+
+--R               \|b
+--R   (2)  --------------
+--R               +-+ +-+
+--R        log(f)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-----+   x log(f) 2          x log(f)     +-----+
+--R        a\|- a b (%e        )  + 2a b %e         - b\|- a b
+--R    log(----------------------------------------------------)
+--R                              x log(f) 2
+--R                         a (%e        )  + b
+--R   [---------------------------------------------------------,
+--R                                 +-----+
+--R                         2log(f)\|- a b
+--R          +---+  x log(f)
+--R         \|a b %e
+--R    atan(----------------)
+--R                 b
+--R    ----------------------]
+--R                +---+
+--R         log(f)\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 405
+
+--S 406 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     +-----+   x log(f) 2          x log(f)     +-----+
+--R        +-+ +-+    a\|- a b (%e        )  + 2a b %e         - b\|- a b
+--R       \|a \|b log(----------------------------------------------------)
+--R                                         x log(f) 2
+--R                                    a (%e        )  + b
+--R     + 
+--R                        x +-+
+--R           +-----+     f \|a
+--R       - 2\|- a b atan(------)
+--R                         +-+
+--R                        \|b
+--R  /
+--R             +-----+ +-+ +-+
+--R     2log(f)\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R                      +---+  x log(f)                x +-+
+--R         +-+ +-+     \|a b %e             +---+     f \|a
+--R        \|a \|b atan(----------------) - \|a b atan(------)
+--R                             b                        +-+
+--R                                                     \|b
+--R   (6)  ---------------------------------------------------
+--R                               +-+ +-+ +---+
+--R                        log(f)\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 408
+
+--S 409 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 409
+
+)clear all
+
+--S 410 of 1034
+t0:=x/(b/f^x+a*f^x)
+--R 
+--R
+--R               x
+--R            x f
+--R   (1)  -----------
+--R            x 2
+--R        a (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 1034
+--r0:=x*atan(f^x*sqrt(a)/sqrt(b))/(log(f)*sqrt(a)*sqrt(b))-1/2*%i*_
+--  polylog(2,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*sqrt(b))+1/2*%i*_
+--  polylog(2,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*sqrt(b))
+--E 411
+
+--S 412 of 1034
+--a0:=integrate(t0,x)
+--E 412
+
+--S 413 of 1034
+--m0:=a0-r0
+--E 413
+
+--S 414 of 1034
+--d0:=normalize(D(m0,x))
+--E 414
+
+)clear all
+
+--S 415 of 1034
+t0:=x^2/(b/f^x+a*f^x)
+--R 
+--R
+--R             2 x
+--R            x f
+--R   (1)  -----------
+--R            x 2
+--R        a (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 1034
+--r0:=x^2*atan(f^x*sqrt(a)/sqrt(b))/(log(f)*sqrt(a)*sqrt(b))-%i*x*_
+--  polylog(2,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*sqrt(b))+%i*x*_
+--  polylog(2,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*sqrt(b))+%i*_
+--  polylog(3,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^3*sqrt(a)*sqrt(b))-%i*_
+--  polylog(3,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^3*sqrt(a)*sqrt(b))
+--E 416
+
+--S 417 of 1034
+--a0:=integrate(t0,x)
+--E 417
+
+--S 418 of 1034
+--m0:=a0-r0
+--E 418
+
+--S 419 of 1034
+--d0:=normalize(D(m0,x))
+--E 419
+
+)clear all
+
+--S 420 of 1034
+t0:=x^3/(b/f^x+a*f^x)
+--R 
+--R
+--R             3 x
+--R            x f
+--R   (1)  -----------
+--R            x 2
+--R        a (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 420
+
+--S 421 of 1034
+--r0:=x^3*atan(f^x*sqrt(a)/sqrt(b))/(log(f)*sqrt(a)*sqrt(b))-3/2*%i*x^2*_
+--  polylog(2,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*sqrt(b))+_
+--  3/2*%i*x^2*polylog(2,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*_
+--  sqrt(b))+3*%i*x*polylog(3,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^3*sqrt(a)*_
+--  sqrt(b))-3*%i*x*polylog(3,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^3*sqrt(a)*_
+--  sqrt(b))-3*%i*polylog(4,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^4*sqrt(a)*_
+--  sqrt(b))+3*%i*polylog(4,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^4*sqrt(a)*sqrt(b))
+--E 421
+
+--S 422 of 1034
+--a0:=integrate(t0,x)
+--E 422
+
+--S 423 of 1034
+--m0:=a0-r0
+--E 423
+
+--S 424 of 1034
+--d0:=normalize(D(m0,x))
+--E 424
+
+)clear all
+
+--S 425 of 1034
+t0:=1/(b/f^x+a*f^x)^2
+--R 
+--R
+--R                    2x
+--R                   f
+--R   (1)  -------------------------
+--R         2  x 4          x 2    2
+--R        a (f )  + 2a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 1034
+r0:=(-1/2)/(a*(b+a*f^(2*x))*log(f))
+--R 
+--R
+--R                       1
+--R   (2)  - --------------------------
+--R            2       2x
+--R          2a log(f)f   + 2a b log(f)
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            1
+--R   (3)  - ------------------------------------
+--R            2         x log(f) 2
+--R          2a log(f)(%e        )  + 2a b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 427
+
+--S 428 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                                     x log(f) 2    2x
+--R                                  (%e        )  - f
+--R   (4)  ----------------------------------------------------------------------
+--R           2       2x                  x log(f) 2               2x     2
+--R        (2a log(f)f   + 2a b log(f))(%e        )  + 2a b log(f)f   + 2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 1034
+t0:=x/(b/f^x+a*f^x)^2
+--R 
+--R
+--R                     2x
+--R                  x f
+--R   (1)  -------------------------
+--R         2  x 4          x 2    2
+--R        a (f )  + 2a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 1034
+r0:=1/2*x/(a*b*log(f))-1/2*x/(a*(b+a*f^(2*x))*log(f))-1/4*log(b+a*f^(2*x))/_
+   (a*b*log(f)^2)
+--R 
+--R
+--R              2x            2x                    2x
+--R        (- a f   - b)log(a f   + b) + 2a x log(f)f
+--R   (2)  --------------------------------------------
+--R                 2        2 2x       2      2
+--R               4a b log(f) f   + 4a b log(f)
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           x log(f) 2              x log(f) 2                      x log(f) 2
+--R   (- a (%e        )  - b)log(a (%e        )  + b) + 2a x log(f)(%e        )
+--R   --------------------------------------------------------------------------
+--R                      2        2   x log(f) 2       2      2
+--R                    4a b log(f) (%e        )  + 4a b log(f)
+--R                                         Type: Union(Expression(Integer),...)
+--E 432
+
+--S 433 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            2 2x          x log(f) 2        2x    2          x log(f) 2
+--R       ((- a f   - a b)(%e        )  - a b f   - b )log(a (%e        )  + b)
+--R     + 
+--R          2 2x          x log(f) 2        2x    2        2x
+--R       ((a f   + a b)(%e        )  + a b f   + b )log(a f   + b)
+--R     + 
+--R                       x log(f) 2                 2x
+--R       2a b x log(f)(%e        )  - 2a b x log(f)f
+--R  /
+--R          3        2 2x     2 2      2    x log(f) 2     2 2      2 2x
+--R       (4a b log(f) f   + 4a b log(f) )(%e        )  + 4a b log(f) f
+--R     + 
+--R           3      2
+--R       4a b log(f)
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 434
+
+)clear all
+
+--S 435 of 1034
+t0:=x^2/(b/f^x+a*f^x)^2
+--R 
+--R
+--R                   2 2x
+--R                  x f
+--R   (1)  -------------------------
+--R         2  x 4          x 2    2
+--R        a (f )  + 2a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 435
+
+--S 436 of 1034
+--r0:=1/2*x^2/(a*b*log(f))-1/2*x^2/(a*(b+a*f^(2*x))*log(f))-_
+--  1/2*x*log(1+a*f^(2*x)/b)/(a*b*log(f)^2)-1/4*polylog(2,-a*f^(2*x)/b)/_
+--  (a*b*log(f)^3)
+--E 436
+
+--S 437 of 1034
+--a0:=integrate(t0,x)
+--E 437
+
+--S 438 of 1034
+--m0:=a0-r0
+--E 438
+
+--S 439 of 1034
+--d0:=normalize(D(m0,x))
+--E 439
+
+)clear all
+
+--S 440 of 1034
+t0:=x^3/(b/f^x+a*f^x)^2
+--R 
+--R
+--R                   3 2x
+--R                  x f
+--R   (1)  -------------------------
+--R         2  x 4          x 2    2
+--R        a (f )  + 2a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 1034
+--r0:=1/2*x^3/(a*b*log(f))-1/2*x^3/(a*(b+a*f^(2*x))*log(f))-3/4*x^2*_
+--  log(1+a*f^(2*x)/b)/(a*b*log(f)^2)-3/4*x*polylog(2,-a*f^(2*x)/b)/_
+--  (a*b*log(f)^3)+3/8*polylog(3,-a*f^(2*x)/b)/(a*b*log(f)^4)
+--E 441
+
+--S 442 of 1034
+--a0:=integrate(t0,x)
+--E 442
+
+--S 443 of 1034
+--m0:=a0-r0
+--E 443
+
+--S 444 of 1034
+--d0:=normalize(D(m0,x))
+--E 444
+
+)clear all
+
+--S 445 of 1034
+t0:=1/(b/f^x+a*f^x)^3
+--R 
+--R
+--R                           3x
+--R                          f
+--R   (1)  --------------------------------------
+--R         3  x 6     2    x 4       2  x 2    3
+--R        a (f )  + 3a b (f )  + 3a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 1034
+r0:=-1/4*f^x/(a*(b+a*f^(2*x))^2*log(f))+1/8*f^x/(a*b*(b+a*f^(2*x))*log(f))+_
+   1/8*atan(f^x*sqrt(a)/sqrt(b))/(a^(3/2)*b^(3/2)*log(f))
+--R 
+--R
+--R                                        x +-+
+--R          2  2x 2         2x    2      f \|a         x 2x      x  +-+ +-+
+--R        (a (f  )  + 2a b f   + b )atan(------) + (a f f   - b f )\|a \|b
+--R                                         +-+
+--R                                        \|b
+--R   (2)  -----------------------------------------------------------------
+--R              3          2x 2      2 2       2x       3        +-+ +-+
+--R           (8a b log(f)(f  )  + 16a b log(f)f   + 8a b log(f))\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R             2   x log(f) 4           x log(f) 2    2
+--R           (a (%e        )  + 2a b (%e        )  + b )
+--R        *
+--R                 +-----+   x log(f) 2          x log(f)     +-----+
+--R               a\|- a b (%e        )  + 2a b %e         - b\|- a b
+--R           log(----------------------------------------------------)
+--R                                     x log(f) 2
+--R                                a (%e        )  + b
+--R       + 
+--R            +-----+   x log(f) 3      +-----+  x log(f)
+--R         2a\|- a b (%e        )  - 2b\|- a b %e
+--R    /
+--R            3         +-----+   x log(f) 4      2 2       +-----+   x log(f) 2
+--R         16a b log(f)\|- a b (%e        )  + 32a b log(f)\|- a b (%e        )
+--R       + 
+--R              3       +-----+
+--R         16a b log(f)\|- a b
+--R     ,
+--R
+--R                                                          +---+  x log(f)
+--R           2   x log(f) 4           x log(f) 2    2      \|a b %e
+--R         (a (%e        )  + 2a b (%e        )  + b )atan(----------------)
+--R                                                                 b
+--R       + 
+--R           +---+   x log(f) 3     +---+  x log(f)
+--R         a\|a b (%e        )  - b\|a b %e
+--R    /
+--R           3         +---+   x log(f) 4      2 2       +---+   x log(f) 2
+--R         8a b log(f)\|a b (%e        )  + 16a b log(f)\|a b (%e        )
+--R       + 
+--R             3       +---+
+--R         8a b log(f)\|a b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 447
+
+--S 448 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             4  2x 2     3   2x    2 2  +-+ +-+   x log(f) 4
+--R           (a (f  )  + 2a b f   + a b )\|a \|b (%e        )
+--R         + 
+--R              3    2x 2     2 2 2x       3  +-+ +-+   x log(f) 2
+--R           (2a b (f  )  + 4a b f   + 2a b )\|a \|b (%e        )
+--R         + 
+--R             2 2  2x 2       3 2x    4  +-+ +-+
+--R           (a b (f  )  + 2a b f   + b )\|a \|b
+--R      *
+--R               +-----+   x log(f) 2          x log(f)     +-----+
+--R             a\|- a b (%e        )  + 2a b %e         - b\|- a b
+--R         log(----------------------------------------------------)
+--R                                   x log(f) 2
+--R                              a (%e        )  + b
+--R     + 
+--R                                                         x +-+
+--R                4  2x 2     3   2x     2 2  +-----+     f \|a
+--R           (- 2a (f  )  - 4a b f   - 2a b )\|- a b atan(------)
+--R                                                          +-+
+--R                                                         \|b
+--R         + 
+--R                3 x 2x     2   x  +-----+ +-+ +-+
+--R           (- 2a f f   + 2a b f )\|- a b \|a \|b
+--R      *
+--R            x log(f) 4
+--R         (%e        )
+--R     + 
+--R          3  2x 2     2   2x       2  +-----+ +-+ +-+   x log(f) 3
+--R       (2a (f  )  + 4a b f   + 2a b )\|- a b \|a \|b (%e        )
+--R     + 
+--R                                                           x +-+
+--R                3    2x 2     2 2 2x       3  +-----+     f \|a
+--R           (- 4a b (f  )  - 8a b f   - 4a b )\|- a b atan(------)
+--R                                                            +-+
+--R                                                           \|b
+--R         + 
+--R                2   x 2x       2 x  +-----+ +-+ +-+
+--R           (- 4a b f f   + 4a b f )\|- a b \|a \|b
+--R      *
+--R            x log(f) 2
+--R         (%e        )
+--R     + 
+--R            2    2x 2       2 2x     3  +-----+ +-+ +-+  x log(f)
+--R       (- 2a b (f  )  - 4a b f   - 2b )\|- a b \|a \|b %e
+--R     + 
+--R                                                     x +-+
+--R            2 2  2x 2       3 2x     4  +-----+     f \|a
+--R       (- 2a b (f  )  - 4a b f   - 2b )\|- a b atan(------)
+--R                                                      +-+
+--R                                                     \|b
+--R     + 
+--R              2 x 2x     3 x  +-----+ +-+ +-+
+--R       (- 2a b f f   + 2b f )\|- a b \|a \|b
+--R  /
+--R             5          2x 2      4 2       2x      3 3        +-----+ +-+ +-+
+--R         (16a b log(f)(f  )  + 32a b log(f)f   + 16a b log(f))\|- a b \|a \|b
+--R      *
+--R            x log(f) 4
+--R         (%e        )
+--R     + 
+--R             4 2        2x 2      3 3       2x      2 4        +-----+ +-+ +-+
+--R         (32a b log(f)(f  )  + 64a b log(f)f   + 32a b log(f))\|- a b \|a \|b
+--R      *
+--R            x log(f) 2
+--R         (%e        )
+--R     + 
+--R           3 3        2x 2      2 4       2x        5        +-----+ +-+ +-+
+--R       (16a b log(f)(f  )  + 32a b log(f)f   + 16a b log(f))\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             4  2x 2     3   2x    2 2  +-+ +-+   x log(f) 4
+--R           (a (f  )  + 2a b f   + a b )\|a \|b (%e        )
+--R         + 
+--R              3    2x 2     2 2 2x       3  +-+ +-+   x log(f) 2
+--R           (2a b (f  )  + 4a b f   + 2a b )\|a \|b (%e        )
+--R         + 
+--R             2 2  2x 2       3 2x    4  +-+ +-+
+--R           (a b (f  )  + 2a b f   + b )\|a \|b
+--R      *
+--R               +---+  x log(f)
+--R              \|a b %e
+--R         atan(----------------)
+--R                      b
+--R     + 
+--R                                                     x +-+
+--R               4  2x 2     3   2x    2 2  +---+     f \|a
+--R           (- a (f  )  - 2a b f   - a b )\|a b atan(------)
+--R                                                      +-+
+--R                                                     \|b
+--R         + 
+--R               3 x 2x    2   x  +-+ +-+ +---+
+--R           (- a f f   + a b f )\|a \|b \|a b
+--R      *
+--R            x log(f) 4
+--R         (%e        )
+--R     + 
+--R         3  2x 2     2   2x      2  +-+ +-+ +---+   x log(f) 3
+--R       (a (f  )  + 2a b f   + a b )\|a \|b \|a b (%e        )
+--R     + 
+--R                                                         x +-+
+--R                3    2x 2     2 2 2x       3  +---+     f \|a
+--R           (- 2a b (f  )  - 4a b f   - 2a b )\|a b atan(------)
+--R                                                          +-+
+--R                                                         \|b
+--R         + 
+--R                2   x 2x       2 x  +-+ +-+ +---+
+--R           (- 2a b f f   + 2a b f )\|a \|b \|a b
+--R      *
+--R            x log(f) 2
+--R         (%e        )
+--R     + 
+--R           2    2x 2       2 2x    3  +-+ +-+ +---+  x log(f)
+--R       (- a b (f  )  - 2a b f   - b )\|a \|b \|a b %e
+--R     + 
+--R                                                 x +-+
+--R           2 2  2x 2       3 2x    4  +---+     f \|a
+--R       (- a b (f  )  - 2a b f   - b )\|a b atan(------)
+--R                                                  +-+
+--R                                                 \|b
+--R     + 
+--R             2 x 2x    3 x  +-+ +-+ +---+
+--R       (- a b f f   + b f )\|a \|b \|a b
+--R  /
+--R            5          2x 2      4 2       2x     3 3        +-+ +-+ +---+
+--R         (8a b log(f)(f  )  + 16a b log(f)f   + 8a b log(f))\|a \|b \|a b
+--R      *
+--R            x log(f) 4
+--R         (%e        )
+--R     + 
+--R             4 2        2x 2      3 3       2x      2 4        +-+ +-+ +---+
+--R         (16a b log(f)(f  )  + 32a b log(f)f   + 16a b log(f))\|a \|b \|a b
+--R      *
+--R            x log(f) 2
+--R         (%e        )
+--R     + 
+--R          3 3        2x 2      2 4       2x       5        +-+ +-+ +---+
+--R       (8a b log(f)(f  )  + 16a b log(f)f   + 8a b log(f))\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 450
+
+--S 451 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 451
+
+)clear all
+
+--S 452 of 1034
+t0:=x/(b/f^x+a*f^x)^3
+--R 
+--R
+--R                            3x
+--R                         x f
+--R   (1)  --------------------------------------
+--R         3  x 6     2    x 4       2  x 2    3
+--R        a (f )  + 3a b (f )  + 3a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 1034
+--r0:=1/8*f^x/(a*b*(b+a*f^(2*x))*log(f)^2)-1/4*f^x*x/(a*(b+a*f^(2*x))^2*_
+--  log(f))+1/8*f^x*x/(a*b*(b+a*f^(2*x))*log(f))+1/8*x*atan(f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f))-1/16*%i*polylog(2,-%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^2)+1/16*%i*polylog(2,%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^2)
+--E 453
+
+--S 454 of 1034
+--a0:=integrate(t0,x)
+--E 454
+
+--S 455 of 1034
+--m0:=a0-r0
+--E 455
+
+--S 456 of 1034
+--d0:=normalize(D(m0,x))
+--E 456
+
+)clear all
+
+--S 457 of 1034
+t0:=x^2/(b/f^x+a*f^x)^3
+--R 
+--R
+--R                          2 3x
+--R                         x f
+--R   (1)  --------------------------------------
+--R         3  x 6     2    x 4       2  x 2    3
+--R        a (f )  + 3a b (f )  + 3a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 1034
+--r0:=-1/4*atan(f^x*sqrt(a)/sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^3)+1/4*f^x*x/_
+--  (a*b*(b+a*f^(2*x))*log(f)^2)-1/4*f^x*x^2/(a*(b+a*f^(2*x))^2*log(f))+_
+--  1/8*f^x*x^2/(a*b*(b+a*f^(2*x))*log(f))+1/8*x^2*atan(f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f))-1/8*%i*x*polylog(2,-%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^2)+1/8*%i*x*polylog(2,%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^2)+1/8*%i*polylog(3,-%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^3)-1/8*%i*polylog(3,%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^3)
+--E 458
+
+--S 459 of 1034
+--a0:=integrate(t0,x)
+--E 459
+
+--S 460 of 1034
+--m0:=a0-r0
+--E 460
+
+--S 461 of 1034
+--d0:=normalize(D(m0,x))
+--E 461
+
+)clear all
+
+--S 462 of 1034
+t0:=f^(a+b*x+c*x^2)*g^(d+e*x+f*x^2)
+--R 
+--R
+--R            2              2
+--R         c x  + b x + a f x  + e x + d
+--R   (1)  f              g
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 1034
+--r0:=1/2*f^a*g^d*erfi(1/2*(b*log(f)+e*log(g)+2*x*(c*log(f)+f*log(g)))/_
+--  sqrt(c*log(f)+f*log(g)))*sqrt(%pi)/(%e^(1/4*(b*log(f)+e*log(g))^2/_
+--  (c*log(f)+f*log(g)))*sqrt(c*log(f)+f*log(g)))
+--E 463
+
+--S 464 of 1034
+--a0:=integrate(t0,x)
+--E 464
+
+--S 465 of 1034
+--m0:=a0-r0
+--E 465
+
+--S 466 of 1034
+--d0:=normalize(D(m0,x))
+--E 466
+
+)clear all
+
+--S 467 of 1034
+t0:=F^(e*(c+d*x))*(a+b*G^(h*(f+g*x)))^n
+--R 
+--R
+--R         d e x + c e    g h x + f h     n
+--R   (1)  F           (b G            + a)
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 1034
+--r0:=F^(e*(c+d*x))*(a+b*G^(h*(f+g*x)))^n*hypergeometric(-n,d*e*log(F)/_
+--  (g*h*log(G)),1+d*e*log(F)/(g*h*log(G)),-b*G^(h*(f+g*x))/a)/_
+--  (d*e*((a+b*G^(h*(f+g*x)))/a)^n*log(F))
+--E 468
+
+--S 469 of 1034
+--a0:=integrate(t0,x)
+--E 469
+
+--S 470 of 1034
+--m0:=a0-r0
+--E 470
+
+--S 471 of 1034
+--d0:=normalize(D(m0,x))
+--E 471
+
+)clear all
+
+--S 472 of 1034
+t0:=F^(a+b*x+c*x^3)*(b+3*c*x^2)
+--R 
+--R
+--R                       3
+--R             2      c x  + b x + a
+--R   (1)  (3c x  + b)F
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 1034
+r0:=F^(a+b*x+c*x^3)/log(F)
+--R 
+--R
+--R            3
+--R         c x  + b x + a
+--R        F
+--R   (2)  ---------------
+--R             log(F)
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3
+--R          (c x  + b x + a)log(F)
+--R        %e
+--R   (3)  ------------------------
+--R                 log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 474
+
+--S 475 of 1034
+m0:=a0-r0
+--R 
+--R
+--R              3                        3
+--R          (c x  + b x + a)log(F)    c x  + b x + a
+--R        %e                       - F
+--R   (4)  ------------------------------------------
+--R                          log(F)
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 476
+
+)clear all
+
+--S 477 of 1034
+t0:=F^(1/(a+b*x+c*x^2))*(b+2*c*x)/(a+b*x+c*x^2)^2
+--R 
+--R
+--R                                    1
+--R                             --------------
+--R                                2
+--R                             c x  + b x + a
+--R                  (2c x + b)F
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 1034
+r0:=-F^(1/(a+b*x+c*x^2))/log(F)
+--R 
+--R
+--R                  1
+--R           --------------
+--R              2
+--R           c x  + b x + a
+--R          F
+--R   (2)  - ---------------
+--R               log(F)
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                log(F)
+--R            --------------
+--R               2
+--R            c x  + b x + a
+--R          %e
+--R   (3)  - ----------------
+--R               log(F)
+--R                                         Type: Union(Expression(Integer),...)
+--E 479
+
+--S 480 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                log(F)               1
+--R            --------------    --------------
+--R               2                 2
+--R            c x  + b x + a    c x  + b x + a
+--R        - %e               + F
+--R   (4)  ------------------------------------
+--R                       log(F)
+--R                                                    Type: Expression(Integer)
+--E 480
+
+--S 481 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 481
+
+)clear all
+
+--S 482 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^m
+--R 
+--R
+--R                       2
+--R                    c x  + b x + a    2           m
+--R   (1)  (2c x + b)%e              (c x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 1034
+--r0:=(a+b*x+c*x^2)^m*GAMMA(1+m,-a-b*x-c*x^2)/(-a-b*x-c*x^2)^m
+--E 483
+
+--S 484 of 1034
+--a0:=integrate(t0,x)
+--E 484
+
+--S 485 of 1034
+--m0:=a0-r0
+--E 485
+
+--S 486 of 1034
+--d0:=normalize(D(m0,x))
+--E 486
+
+)clear all
+
+--S 487 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R         4 7       3 6        3     2 2  5           2     3   4
+--R       2c x  + 7b c x  + (6a c  + 9b c )x  + (15a b c  + 5b c)x
+--R     + 
+--R          2 2        2     4  3      2          3  2      3      2 2      3
+--R       (6a c  + 12a b c + b )x  + (9a b c + 3a b )x  + (2a c + 3a b )x + a b
+--R  *
+--R          2
+--R       c x  + b x + a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 1034
+r0:=-6*%e^(a+b*x+c*x^2)+6*%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)-3*%e^(a+b*x+c*x^2)*_
+   (a+b*x+c*x^2)^2+%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)^3
+--R 
+--R
+--R   (2)
+--R        3 6       2 5             2     2   4                   3  3
+--R       c x  + 3b c x  + ((3a - 3)c  + 3b c)x  + ((6a - 6)b c + b )x
+--R     + 
+--R           2                       2  2      2                 3     2
+--R       ((3a  - 6a + 6)c + (3a - 3)b )x  + (3a  - 6a + 6)b x + a  - 3a  + 6a - 6
+--R  *
+--R          2
+--R       c x  + b x + a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        3 6       2 5             2     2   4                   3  3
+--R       c x  + 3b c x  + ((3a - 3)c  + 3b c)x  + ((6a - 6)b c + b )x
+--R     + 
+--R           2                       2  2      2                 3     2
+--R       ((3a  - 6a + 6)c + (3a - 3)b )x  + (3a  - 6a + 6)b x + a  - 3a  + 6a - 6
+--R  *
+--R          2
+--R       c x  + b x + a
+--R     %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 489
+
+--S 490 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 491
+
+)clear all
+
+--S 492 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R         3 5       2 4        2     2   3              3  2      2        2
+--R       2c x  + 5b c x  + (4a c  + 4b c)x  + (6a b c + b )x  + (2a c + 2a b )x
+--R     + 
+--R        2
+--R       a b
+--R  *
+--R          2
+--R       c x  + b x + a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 492
+
+--S 493 of 1034
+r0:=2*%e^(a+b*x+c*x^2)-2*%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)+%e^(a+b*x+c*x^2)*_
+   (a+b*x+c*x^2)^2
+--R 
+--R
+--R   (2)
+--R       2 4         3                 2  2                  2
+--R     (c x  + 2b c x  + ((2a - 2)c + b )x  + (2a - 2)b x + a  - 2a + 2)
+--R  *
+--R          2
+--R       c x  + b x + a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       2 4         3                 2  2                  2
+--R     (c x  + 2b c x  + ((2a - 2)c + b )x  + (2a - 2)b x + a  - 2a + 2)
+--R  *
+--R          2
+--R       c x  + b x + a
+--R     %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 494
+
+--S 495 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+--S 496 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 496
+
+)clear all
+
+--S 497 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)
+--R 
+--R
+--R                                                   2
+--R           2 3         2            2           c x  + b x + a
+--R   (1)  (2c x  + 3b c x  + (2a c + b )x + a b)%e
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 1034
+r0:=-%e^(a+b*x+c*x^2)+%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)
+--R 
+--R
+--R                                 2
+--R            2                 c x  + b x + a
+--R   (2)  (c x  + b x + a - 1)%e
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                 2
+--R            2                 c x  + b x + a
+--R   (3)  (c x  + b x + a - 1)%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 499
+
+--S 500 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)
+--R 
+--R
+--R                       2
+--R                    c x  + b x + a
+--R   (1)  (2c x + b)%e
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 1034
+r0:=%e^(a+b*x+c*x^2)
+--R 
+--R
+--R             2
+--R          c x  + b x + a
+--R   (2)  %e
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2
+--R          c x  + b x + a
+--R   (3)  %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 504
+
+--S 505 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 506
+
+)clear all
+
+--S 507 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)
+--R 
+--R
+--R                       2
+--R                    c x  + b x + a
+--R        (2c x + b)%e
+--R   (1)  --------------------------
+--R                 2
+--R              c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 1034
+--r0:=Ei(a+b*x+c*x^2)
+--E 508
+
+--S 509 of 1034
+--a0:=integrate(t0,x)
+--E 509
+
+--S 510 of 1034
+--m0:=a0-r0
+--E 510
+
+--S 511 of 1034
+--d0:=normalize(D(m0,x))
+--E 511
+
+)clear all
+
+--S 512 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)^2
+--R 
+--R
+--R                                2
+--R                             c x  + b x + a
+--R                 (2c x + b)%e
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 1034
+--r0:=-%e^(a+b*x+c*x^2)/(a+b*x+c*x^2)+Ei(a+b*x+c*x^2)
+--E 513
+
+--S 514 of 1034
+--a0:=integrate(t0,x)
+--E 514
+
+--S 515 of 1034
+--m0:=a0-r0
+--E 515
+
+--S 516 of 1034
+--d0:=normalize(D(m0,x))
+--E 516
+
+)clear all
+
+--S 517 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R                    2
+--R                 c x  + b x + a
+--R     (2c x + b)%e
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 1034
+--r0:=-1/2*%e^(a+b*x+c*x^2)/(a+b*x+c*x^2)^2-1/2*%e^(a+b*x+c*x^2)/_
+--  (a+b*x+c*x^2)+1/2*Ei(a+b*x+c*x^2)
+--E 518
+
+--S 519 of 1034
+--a0:=integrate(t0,x)
+--E 519
+
+--S 520 of 1034
+--m0:=a0-r0
+--E 520
+
+--S 521 of 1034
+--d0:=normalize(D(m0,x))
+--E 521
+
+)clear all
+
+--S 522 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^(5/2)
+--R 
+--R
+--R   (1)
+--R         3 5       2 4        2     2   3              3  2      2        2
+--R       2c x  + 5b c x  + (4a c  + 4b c)x  + (6a b c + b )x  + (2a c + 2a b )x
+--R     + 
+--R        2
+--R       a b
+--R  *
+--R          2           +--------------+
+--R       c x  + b x + a |   2
+--R     %e              \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 1034
+--r0:=-5/2*%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)^(3/2)+%e^(a+b*x+c*x^2)*_
+--  (a+b*x+c*x^2)^(5/2)-15/8*erfi(sqrt(a+b*x+c*x^2))*sqrt(%pi)+_
+--  15/4*%e^(a+b*x+c*x^2)*sqrt(a+b*x+c*x^2)
+--E 523
+
+--S 524 of 1034
+--a0:=integrate(t0,x)
+--E 524
+
+--S 525 of 1034
+--m0:=a0-r0
+--E 525
+
+--S 526 of 1034
+--d0:=normalize(D(m0,x))
+--E 526
+
+)clear all
+
+--S 527 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^(3/2)
+--R 
+--R
+--R   (1)
+--R                                              2           +--------------+
+--R      2 3         2            2           c x  + b x + a |   2
+--R   (2c x  + 3b c x  + (2a c + b )x + a b)%e              \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 1034
+--r0:=%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)^(3/2)+3/4*erfi(sqrt(a+b*x+c*x^2))*_
+--  sqrt(%pi)-3/2*%e^(a+b*x+c*x^2)*sqrt(a+b*x+c*x^2)
+--E 528
+
+--S 529 of 1034
+--a0:=integrate(t0,x)
+--E 529
+
+--S 530 of 1034
+--m0:=a0-r0
+--E 530
+
+--S 531 of 1034
+--d0:=normalize(D(m0,x))
+--E 531
+
+)clear all
+
+--S 532 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^(1/2)
+--R 
+--R
+--R                       2           +--------------+
+--R                    c x  + b x + a |   2
+--R   (1)  (2c x + b)%e              \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 1034
+--r0:=-1/2*erfi(sqrt(a+b*x+c*x^2))*sqrt(%pi)+%e^(a+b*x+c*x^2)*sqrt(a+b*x+c*x^2)
+--E 533
+
+--S 534 of 1034
+--a0:=integrate(t0,x)
+--E 534
+
+--S 535 of 1034
+--m0:=a0-r0
+--E 535
+
+--S 536 of 1034
+--d0:=normalize(D(m0,x))
+--E 536
+
+)clear all
+
+--S 537 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)^(1/2)
+--R 
+--R
+--R                       2
+--R                    c x  + b x + a
+--R        (2c x + b)%e
+--R   (1)  --------------------------
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 1034
+--r0:=erfi(sqrt(a+b*x+c*x^2))*sqrt(%pi)
+--E 538
+
+--S 539 of 1034
+--a0:=integrate(t0,x)
+--E 539
+
+--S 540 of 1034
+--m0:=a0-r0
+--E 540
+
+--S 541 of 1034
+--d0:=normalize(D(m0,x))
+--E 541
+
+)clear all
+
+--S 542 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)^(3/2)
+--R 
+--R
+--R                           2
+--R                        c x  + b x + a
+--R            (2c x + b)%e
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 1034
+--r0:=2*erfi(sqrt(a+b*x+c*x^2))*sqrt(%pi)-2*%e^(a+b*x+c*x^2)/sqrt(a+b*x+c*x^2)
+--E 543
+
+--S 544 of 1034
+--a0:=integrate(t0,x)
+--E 544
+
+--S 545 of 1034
+--m0:=a0-r0
+--E 545
+
+--S 546 of 1034
+--d0:=normalize(D(m0,x))
+--E 546
+
+)clear all
+
+--S 547 of 1034
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)^(5/2)
+--R 
+--R
+--R                                          2
+--R                                       c x  + b x + a
+--R                           (2c x + b)%e
+--R   (1)  ---------------------------------------------------------------
+--R                                                       +--------------+
+--R          2 4         3            2  2             2  |   2
+--R        (c x  + 2b c x  + (2a c + b )x  + 2a b x + a )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 1034
+--r0:=-2/3*%e^(a+b*x+c*x^2)/(a+b*x+c*x^2)^(3/2)+4/3*erfi(sqrt(a+b*x+c*x^2))*_
+--  sqrt(%pi)-4/3*%e^(a+b*x+c*x^2)/sqrt(a+b*x+c*x^2)
+--E 548
+
+--S 549 of 1034
+--a0:=integrate(t0,x)
+--E 549
+
+--S 550 of 1034
+--m0:=a0-r0
+--E 550
+
+--S 551 of 1034
+--d0:=normalize(D(m0,x))
+--E 551
+
+)clear all
+
+--S 552 of 1034
+t0:=%e^(x/(2+x^2))*(2-x^2)/(2*x+x^3)
+--R 
+--R
+--R                       x
+--R                    ------
+--R                     2
+--R            2       x  + 2
+--R        (- x  + 2)%e
+--R   (1)  ------------------
+--R               3
+--R              x  + 2x
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 1034
+--r0:=Ei(x/(2+x^2))
+--E 553
+
+--S 554 of 1034
+--a0:=integrate(t0,x)
+--E 554
+
+--S 555 of 1034
+--m0:=a0-r0
+--E 555
+
+--S 556 of 1034
+--d0:=normalize(D(m0,x))
+--E 556
+
+)clear all
+
+--S 557 of 1034
+t0:=%e^(x/(2+x^2))*(2+2*x+3*x^2-x^3+2*x^4)/(2*x+x^3)
+--R 
+--R
+--R                                      x
+--R                                   ------
+--R                                    2
+--R           4    3     2            x  + 2
+--R        (2x  - x  + 3x  + 2x + 2)%e
+--R   (1)  ---------------------------------
+--R                      3
+--R                     x  + 2x
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 1034
+--r0:=%e^(x/(2+x^2))*(2+x^2)+Ei(x/(2+x^2))
+--E 558
+
+--S 559 of 1034
+--a0:=integrate(t0,x)
+--E 559
+
+--S 560 of 1034
+--m0:=a0-r0
+--E 560
+
+--S 561 of 1034
+--d0:=normalize(D(m0,x))
+--E 561
+
+)clear all
+
+--S 562 of 1034
+t0:=%e^(%e^x+x)*(1+%e^x)/(%e^x+x)
+--R 
+--R
+--R                     x
+--R           x       %e  + x
+--R        (%e  + 1)%e
+--R   (1)  ------------------
+--R                x
+--R              %e  + x
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 1034
+--r0:=Ei(%e^x+x)
+--E 563
+
+--S 564 of 1034
+--a0:=integrate(t0,x)
+--E 564
+
+--S 565 of 1034
+--m0:=a0-r0
+--E 565
+
+--S 566 of 1034
+--d0:=normalize(D(m0,x))
+--E 566
+
+)clear all
+
+--S 567 of 1034
+t0:=%e^(1/(-1+x^2))*(1-3*x-x^2+x^3)/(1-x-x^2+x^3)
+--R 
+--R
+--R                               1
+--R                            ------
+--R                             2
+--R          3    2            x  - 1
+--R        (x  - x  - 3x + 1)%e
+--R   (1)  --------------------------
+--R               3    2
+--R              x  - x  - x + 1
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 1034
+r0:=%e^(1/(-1+x^2))*(1+x)
+--R 
+--R
+--R                    1
+--R                 ------
+--R                  2
+--R                 x  - 1
+--R   (2)  (x + 1)%e
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    1
+--R                 ------
+--R                  2
+--R                 x  - 1
+--R   (3)  (x + 1)%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 569
+
+--S 570 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 571
+
+)clear all
+
+--S 572 of 1034
+t0:=%e^(1+1/log(x))*(-1+log(x)^2)/log(x)^2
+--R 
+--R
+--R                       log(x) + 1
+--R                       ----------
+--R               2         log(x)
+--R        (log(x)  - 1)%e
+--R   (1)  -------------------------
+--R                       2
+--R                 log(x)
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 1034
+r0:=%e^(1+1/log(x))*x
+--R 
+--R
+--R            log(x) + 1
+--R            ----------
+--R              log(x)
+--R   (2)  x %e
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R            log(x) + 1
+--R            ----------
+--R              log(x)
+--R   (3)  x %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 574
+
+--S 575 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 1034
+t0:=1/(%e^x*sqrt(1+(-1)/%e^(2*x)))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R            +--------+
+--R            |  2x
+--R          x |%e   - 1
+--R        %e  |--------
+--R            |    2x
+--R           \|  %e
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 1034
+r0:=-asin(1/%e^x)
+--R 
+--R
+--R                1
+--R   (2)  - asin(---)
+--R                 x
+--R               %e
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +----------+
+--R               |   x 2          x
+--R   (3)  2atan(\|(%e )  - 1  - %e )
+--R                                         Type: Union(Expression(Integer),...)
+--E 579
+
+--S 580 of 1034
+m0:=a0-r0
+--R 
+--R
+--R               +----------+
+--R               |   x 2          x          1
+--R   (4)  2atan(\|(%e )  - 1  - %e ) + asin(---)
+--R                                            x
+--R                                          %e
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R                              +----------+
+--R           +----------+       |   x 2
+--R           |   x 2          x |(%e )  - 1
+--R        - \|(%e )  - 1  + %e  |----------
+--R                              |     x 2
+--R                             \|  (%e )
+--R   (5)  ----------------------------------
+--R               +----------+
+--R               |   x 2      +----------+
+--R             x |(%e )  - 1  |   x 2
+--R           %e  |---------- \|(%e )  - 1
+--R               |     x 2
+--R              \|  (%e )
+--R                                                    Type: Expression(Integer)
+--E 581
+
+)clear all
+
+--S 582 of 1034
+t0:=%e^x/(4+%e^(2*x))
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R          2x
+--R        %e   + 4
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 1034
+r0:=1/2*atan(1/2*%e^x)
+--R 
+--R
+--R               x
+--R             %e
+--R        atan(---)
+--R              2
+--R   (2)  ---------
+--R            2
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               x
+--R             %e
+--R        atan(---)
+--R              2
+--R   (3)  ---------
+--R            2
+--R                                         Type: Union(Expression(Integer),...)
+--E 584
+
+--S 585 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+--S 586 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 586
+
+)clear all
+
+--S 587 of 1034
+t0:=%e^x/(1-%e^(2*x))
+--R 
+--R
+--R               x
+--R             %e
+--R   (1)  - --------
+--R            2x
+--R          %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 1034
+r0:=atanh(%e^x)
+--R 
+--R
+--R                x
+--R   (2)  atanh(%e )
+--R                                                    Type: Expression(Integer)
+--E 588
+
+--S 589 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R              x              x
+--R        log(%e  + 1) - log(%e  - 1)
+--R   (3)  ---------------------------
+--R                     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 589
+
+--S 590 of 1034
+m0:=a0-r0
+--R 
+--R
+--R              x              x                 x
+--R        log(%e  + 1) - log(%e  - 1) - 2atanh(%e )
+--R   (4)  -----------------------------------------
+--R                            2
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 591
+
+)clear all
+
+--S 592 of 1034
+t0:=%e^x/(3-4*%e^(2*x))
+--R 
+--R
+--R               x
+--R             %e
+--R   (1)  - ---------
+--R             2x
+--R          4%e   - 3
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 1034
+r0:=1/2*atanh(2*%e^x/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                 x
+--R              2%e
+--R        atanh(----)
+--R               +-+
+--R              \|3
+--R   (2)  -----------
+--R             +-+
+--R           2\|3
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +-+   x 2       x     +-+
+--R            4\|3 (%e )  + 12%e  + 3\|3
+--R        log(---------------------------)
+--R                        x 2
+--R                    4(%e )  - 3
+--R   (3)  --------------------------------
+--R                        +-+
+--R                      4\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 594
+
+--S 595 of 1034
+m0:=a0-r0
+--R 
+--R
+--R              +-+   x 2       x     +-+              x
+--R            4\|3 (%e )  + 12%e  + 3\|3            2%e
+--R        log(---------------------------) - 2atanh(----)
+--R                        x 2                        +-+
+--R                    4(%e )  - 3                   \|3
+--R   (4)  -----------------------------------------------
+--R                               +-+
+--R                             4\|3
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 596
+
+)clear all
+
+--S 597 of 1034
+t0:=%e^x*sqrt(3-4*%e^(2*x))
+--R 
+--R
+--R            +-----------+
+--R          x |     2x
+--R   (1)  %e \|- 4%e   + 3
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 1034
+r0:=3/4*asin(2*%e^x/sqrt(3))+1/2*%e^x*sqrt(3-4*%e^(2*x))
+--R 
+--R
+--R             +-----------+            x
+--R           x |     2x              2%e
+--R        2%e \|- 4%e   + 3  + 3asin(----)
+--R                                    +-+
+--R                                   \|3
+--R   (2)  --------------------------------
+--R                        4
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                    +-------------+
+--R                +-------------+                     |      x 2         +-+
+--R            +-+ |      x 2            x 2          \|- 4(%e )  + 3  - \|3
+--R       (- 3\|3 \|- 4(%e )  + 3  - 6(%e )  + 9)atan(-----------------------)
+--R                                                                x
+--R                                                             2%e
+--R     + 
+--R                        +-------------+
+--R            x 3      x  |      x 2          +-+   x 3     +-+  x
+--R       (2(%e )  - 3%e )\|- 4(%e )  + 3  - 4\|3 (%e )  + 3\|3 %e
+--R  /
+--R           +-------------+
+--R       +-+ |      x 2            x 2
+--R     2\|3 \|- 4(%e )  + 3  + 4(%e )  - 6
+--R                                         Type: Union(Expression(Integer),...)
+--E 599
+
+--S 600 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                      +-------------+
+--R                +-------------+                       |      x 2         +-+
+--R            +-+ |      x 2             x 2           \|- 4(%e )  + 3  - \|3
+--R       (- 6\|3 \|- 4(%e )  + 3  - 12(%e )  + 18)atan(-----------------------)
+--R                                                                  x
+--R                                                               2%e
+--R     + 
+--R                     +-----------+                x
+--R              +-+  x |     2x          +-+     2%e         x 3      x
+--R         (- 2\|3 %e \|- 4%e   + 3  - 3\|3 asin(----) + 4(%e )  - 6%e )
+--R                                                +-+
+--R                                               \|3
+--R      *
+--R          +-------------+
+--R          |      x 2
+--R         \|- 4(%e )  + 3
+--R     + 
+--R                          +-----------+                          x
+--R              x 3      x  |     2x               x 2          2%e
+--R       (- 4(%e )  + 6%e )\|- 4%e   + 3  + (- 6(%e )  + 9)asin(----)
+--R                                                               +-+
+--R                                                              \|3
+--R     + 
+--R           +-+   x 3     +-+  x
+--R       - 8\|3 (%e )  + 6\|3 %e
+--R  /
+--R           +-------------+
+--R       +-+ |      x 2            x 2
+--R     4\|3 \|- 4(%e )  + 3  + 8(%e )  - 12
+--R                                                    Type: Expression(Integer)
+--E 600
+
+--S 601 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 601
+
+)clear all
+
+--S 602 of 1034
+t0:=%e^(x^2)*x^3
+--R 
+--R
+--R             2
+--R         3  x
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 1034
+r0:=-1/2*%e^(x^2)+1/2*%e^(x^2)*x^2
+--R 
+--R
+--R                   2
+--R          2       x
+--R        (x  - 1)%e
+--R   (2)  ------------
+--R              2
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   2
+--R          2       x
+--R        (x  - 1)%e
+--R   (3)  ------------
+--R              2
+--R                                         Type: Union(Expression(Integer),...)
+--E 604
+
+--S 605 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 606
+
+)clear all
+
+--S 607 of 1034
+t0:=%e^x*sqrt(1-%e^(2*x))
+--R 
+--R
+--R            +----------+
+--R          x |    2x
+--R   (1)  %e \|- %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 1034
+r0:=1/2*asin(%e^x)+1/2*%e^x*sqrt(1-%e^(2*x))
+--R 
+--R
+--R            +----------+
+--R          x |    2x               x
+--R        %e \|- %e   + 1  + asin(%e )
+--R   (2)  ----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                               +------------+
+--R            +------------+                     |     x 2
+--R            |     x 2            x 2          \|- (%e )  + 1  - 1
+--R       (- 4\|- (%e )  + 1  - 2(%e )  + 4)atan(-------------------)
+--R                                                        x
+--R                                                      %e
+--R     + 
+--R                       +------------+
+--R           x 3      x  |     x 2            x 3      x
+--R       ((%e )  - 2%e )\|- (%e )  + 1  - 2(%e )  + 2%e
+--R  /
+--R       +------------+
+--R       |     x 2            x 2
+--R     4\|- (%e )  + 1  + 2(%e )  - 4
+--R                                         Type: Union(Expression(Integer),...)
+--E 609
+
+--S 610 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                               +------------+
+--R            +------------+                     |     x 2
+--R            |     x 2            x 2          \|- (%e )  + 1  - 1
+--R       (- 4\|- (%e )  + 1  - 2(%e )  + 4)atan(-------------------)
+--R                                                        x
+--R                                                      %e
+--R     + 
+--R               +----------+                               +------------+
+--R             x |    2x                x       x 3      x  |     x 2
+--R       (- 2%e \|- %e   + 1  - 2asin(%e ) + (%e )  - 2%e )\|- (%e )  + 1
+--R     + 
+--R                       +----------+
+--R           x 3      x  |    2x              x 2            x        x 3      x
+--R     (- (%e )  + 2%e )\|- %e   + 1  + (- (%e )  + 2)asin(%e ) - 2(%e )  + 2%e
+--R  /
+--R       +------------+
+--R       |     x 2            x 2
+--R     4\|- (%e )  + 1  + 2(%e )  - 4
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 611
+
+)clear all
+
+--S 612 of 1034
+t0:=%e^x/sqrt(1+%e^x+%e^(2*x))
+--R 
+--R
+--R                 x
+--R               %e
+--R   (1)  -----------------
+--R         +--------------+
+--R         |  2x     x
+--R        \|%e   + %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 612
+
+--S 613 of 1034
+r0:=asinh((1+2*%e^x)/sqrt(3))
+--R 
+--R
+--R                 x
+--R              2%e  + 1
+--R   (2)  asinh(--------)
+--R                 +-+
+--R                \|3
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +----------------+
+--R                |   x 2     x           x
+--R   (3)  - log(2\|(%e )  + %e  + 1  - 2%e  - 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 614
+
+--S 615 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                +----------------+                        x
+--R                |   x 2     x           x              2%e  + 1
+--R   (4)  - log(2\|(%e )  + %e  + 1  - 2%e  - 1) - asinh(--------)
+--R                                                          +-+
+--R                                                         \|3
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R            +------------------+        +----------------+
+--R          x |    x 2      x           x |   x 2     x
+--R        %e \|4(%e )  + 4%e  + 4  - 2%e \|(%e )  + %e  + 1
+--R   (5)  --------------------------------------------------
+--R              +----------------+ +------------------+
+--R              |   x 2     x      |    x 2      x
+--R             \|(%e )  + %e  + 1 \|4(%e )  + 4%e  + 4
+--R                                                    Type: Expression(Integer)
+--E 616
+
+)clear all
+
+--S 617 of 1034
+t0:=%e^x/(-4+%e^(2*x))
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R          2x
+--R        %e   - 4
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 1034
+r0:=-1/2*atanh(1/2*%e^x)
+--R 
+--R
+--R                  x
+--R                %e
+--R          atanh(---)
+--R                 2
+--R   (2)  - ----------
+--R               2
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                x              x
+--R        - log(%e  + 2) + log(%e  - 2)
+--R   (3)  -----------------------------
+--R                      4
+--R                                         Type: Union(Expression(Integer),...)
+--E 619
+
+--S 620 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                                                 x
+--R                x              x               %e
+--R        - log(%e  + 2) + log(%e  - 2) + 2atanh(---)
+--R                                                2
+--R   (4)  -------------------------------------------
+--R                             4
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 621
+
+)clear all
+
+--S 622 of 1034
+t0:=%e^sqrt(x)
+--R 
+--R
+--R           +-+
+--R          \|x
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 1034
+r0:=-2*%e^sqrt(x)+2*%e^sqrt(x)*sqrt(x)
+--R 
+--R
+--R                      +-+
+--R           +-+       \|x
+--R   (2)  (2\|x  - 2)%e
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +-+
+--R           +-+       \|x
+--R   (3)  (2\|x  - 2)%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 624
+
+--S 625 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 626
+
+)clear all
+
+--S 627 of 1034
+t0:=%e^x/(1+%e^(2*x))
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R          2x
+--R        %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 1034
+r0:=atan(%e^x)
+--R 
+--R
+--R               x
+--R   (2)  atan(%e )
+--R                                                    Type: Expression(Integer)
+--E 628
+
+--S 629 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               x
+--R   (3)  atan(%e )
+--R                                         Type: Union(Expression(Integer),...)
+--E 629
+
+--S 630 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 631
+
+)clear all
+
+--S 632 of 1034
+t0:=%e^(2-x^2)*x
+--R 
+--R
+--R               2
+--R            - x  + 2
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 1034
+r0:=-1/2*%e^(2-x^2)
+--R 
+--R
+--R               2
+--R            - x  + 2
+--R          %e
+--R   (2)  - ----------
+--R               2
+--R                                                    Type: Expression(Integer)
+--E 633
+
+--S 634 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2
+--R            - x  + 2
+--R          %e
+--R   (3)  - ----------
+--R               2
+--R                                         Type: Union(Expression(Integer),...)
+--E 634
+
+--S 635 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 636
+
+)clear all
+
+--S 637 of 1034
+t0:=%e^x-x^%e
+--R 
+--R
+--R           %e     x
+--R   (1)  - x   + %e
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 1034
+r0:=%e^x-x^(1+%e)/(1+%e)
+--R 
+--R
+--R           %e + 1             x
+--R        - x       + (%e + 1)%e
+--R   (2)  -----------------------
+--R                 %e + 1
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R              %e log(x)             x
+--R        - x %e          + (%e + 1)%e
+--R   (3)  -----------------------------
+--R                    %e + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 639
+
+--S 640 of 1034
+m0:=a0-r0
+--R 
+--R
+--R              %e log(x)    %e + 1
+--R        - x %e          + x
+--R   (4)  -------------------------
+--R                  %e + 1
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 641
+
+)clear all
+
+--S 642 of 1034
+t0:=(-1+%e^(2*x))/(3+%e^(2*x))
+--R 
+--R
+--R          2x
+--R        %e   - 1
+--R   (1)  --------
+--R          2x
+--R        %e   + 3
+--R                                                    Type: Expression(Integer)
+--E 642
+
+--S 643 of 1034
+r0:=-1/3*x+2/3*log(3+%e^(2*x))
+--R 
+--R
+--R               2x
+--R        2log(%e   + 3) - x
+--R   (2)  ------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2x
+--R        2log(%e   + 3) - x
+--R   (3)  ------------------
+--R                 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 644
+
+--S 645 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 645
+
+--S 646 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 646
+
+)clear all
+
+--S 647 of 1034
+t0:=%e^x/sqrt(1-%e^(2*x))
+--R 
+--R
+--R               x
+--R             %e
+--R   (1)  -------------
+--R         +----------+
+--R         |    2x
+--R        \|- %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 1034
+r0:=asin(%e^x)
+--R 
+--R
+--R               x
+--R   (2)  asin(%e )
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +------------+
+--R                 |     x 2
+--R                \|- (%e )  + 1  - 1
+--R   (3)  - 2atan(-------------------)
+--R                          x
+--R                        %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 649
+
+--S 650 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                 +------------+
+--R                 |     x 2
+--R                \|- (%e )  + 1  - 1           x
+--R   (4)  - 2atan(-------------------) - asin(%e )
+--R                          x
+--R                        %e
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 651
+
+)clear all
+
+--S 652 of 1034
+t0:=%e^(2*x)/(1+%e^(4*x))
+--R 
+--R
+--R            2x
+--R          %e
+--R   (1)  --------
+--R          4x
+--R        %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 1034
+r0:=1/2*atan(%e^(2*x))
+--R 
+--R
+--R               2x
+--R        atan(%e  )
+--R   (2)  ----------
+--R             2
+--R                                                    Type: Expression(Integer)
+--E 653
+
+--S 654 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2x
+--R        atan(%e  )
+--R   (3)  ----------
+--R             2
+--R                                         Type: Union(Expression(Integer),...)
+--E 654
+
+--S 655 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 656
+
+)clear all
+
+--S 657 of 1034
+t0:=1/(-3*%e^x+%e^(2*x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R          2x      x
+--R        %e   - 3%e
+--R                                                    Type: Expression(Integer)
+--E 657
+
+--S 658 of 1034
+r0:=1/3/%e^x-1/9*x+1/9*log(3-%e^x)
+--R 
+--R
+--R          x        x            x
+--R        %e log(- %e  + 3) - x %e  + 3
+--R   (2)  -----------------------------
+--R                        x
+--R                     9%e
+--R                                                    Type: Expression(Integer)
+--E 658
+
+--S 659 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R          x      x            x
+--R        %e log(%e  - 3) - x %e  + 3
+--R   (3)  ---------------------------
+--R                       x
+--R                    9%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 659
+
+--S 660 of 1034
+m0:=a0-r0
+--R 
+--R
+--R              x                x
+--R        log(%e  - 3) - log(- %e  + 3)
+--R   (4)  -----------------------------
+--R                      9
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 661
+
+)clear all
+
+--S 662 of 1034
+t0:=%e^x*(-2+%e^x)/(1+%e^x)
+--R 
+--R
+--R           x 2      x
+--R        (%e )  - 2%e
+--R   (1)  -------------
+--R             x
+--R           %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 1034
+r0:=%e^x-3*log(1+%e^x)
+--R 
+--R
+--R                 x          x
+--R   (2)  - 3log(%e  + 1) + %e
+--R                                                    Type: Expression(Integer)
+--E 663
+
+--S 664 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 x          x
+--R   (3)  - 3log(%e  + 1) + %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 664
+
+--S 665 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 666
+
+)clear all
+
+--S 667 of 1034
+t0:=%e^x/(-1+%e^(2*x))
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R          2x
+--R        %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 1034
+r0:=-atanh(%e^x)
+--R 
+--R
+--R                  x
+--R   (2)  - atanh(%e )
+--R                                                    Type: Expression(Integer)
+--E 668
+
+--S 669 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                x              x
+--R        - log(%e  + 1) + log(%e  - 1)
+--R   (3)  -----------------------------
+--R                      2
+--R                                         Type: Union(Expression(Integer),...)
+--E 669
+
+--S 670 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                x              x                 x
+--R        - log(%e  + 1) + log(%e  - 1) + 2atanh(%e )
+--R   (4)  -------------------------------------------
+--R                             2
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 671
+
+)clear all
+
+--S 672 of 1034
+t0:=%e^x/(1+%e^(2*x))
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R          2x
+--R        %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 1034
+r0:=atan(%e^x)
+--R 
+--R
+--R               x
+--R   (2)  atan(%e )
+--R                                                    Type: Expression(Integer)
+--E 673
+
+--S 674 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               x
+--R   (3)  atan(%e )
+--R                                         Type: Union(Expression(Integer),...)
+--E 674
+
+--S 675 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 676
+
+)clear all
+
+--S 677 of 1034
+t0:=(1/%e^x+%e^x)/((-1)/%e^x+%e^x)
+--R 
+--R
+--R           x 2
+--R        (%e )  + 1
+--R   (1)  ----------
+--R           x 2
+--R        (%e )  - 1
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 1034
+r0:=log(1/%e^x-%e^x),-x+log(1-%e^(2*x))
+--R 
+--R
+--R                  x 2
+--R             - (%e )  + 1          2x
+--R   (2)  [log(------------),log(- %e   + 1) - x]
+--R                    x
+--R                  %e
+--R                                             Type: Tuple(Expression(Integer))
+--E 678
+
+--S 679 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               x 2
+--R   (3)  log((%e )  - 1) - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 679
+
+--S 680 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                                   x 2
+--R               x 2            - (%e )  + 1
+--R   (4)  log((%e )  - 1) - log(------------) - x
+--R                                     x
+--R                                   %e
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 681
+
+)clear all
+
+--S 682 of 1034
+t0:=((-1)/%e^x+%e^x)/(1/%e^x+%e^x)
+--R 
+--R
+--R           x 2
+--R        (%e )  - 1
+--R   (1)  ----------
+--R           x 2
+--R        (%e )  + 1
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1034
+r0:=log(1/%e^x+%e^x),-x+log(1+%e^(2*x))
+--R 
+--R
+--R                x 2
+--R             (%e )  + 1        2x
+--R   (2)  [log(----------),log(%e   + 1) - x]
+--R                   x
+--R                 %e
+--R                                             Type: Tuple(Expression(Integer))
+--E 683
+
+--S 684 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               x 2
+--R   (3)  log((%e )  + 1) - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 684
+
+--S 685 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                                 x 2
+--R               x 2            (%e )  + 1
+--R   (4)  log((%e )  + 1) - log(----------) - x
+--R                                    x
+--R                                  %e
+--R                                                    Type: Expression(Integer)
+--E 685
+
+--S 686 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 686
+
+)clear all
+
+--S 687 of 1034
+t0:=(1/%e^(2*x)+%e^(2*x))/((-1)/%e^(2*x)+%e^(2*x))
+--R 
+--R
+--R           2x 2
+--R        (%e  )  + 1
+--R   (1)  -----------
+--R           2x 2
+--R        (%e  )  - 1
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 1034
+r0:=-x+1/2*log(1-%e^(4*x))
+--R 
+--R
+--R                4x
+--R        log(- %e   + 1) - 2x
+--R   (2)  --------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 688
+
+--S 689 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2x 2
+--R        log((%e  )  - 1) - 2x
+--R   (3)  ---------------------
+--R                  2
+--R                                         Type: Union(Expression(Integer),...)
+--E 689
+
+--S 690 of 1034
+m0:=a0-r0
+--R 
+--R
+--R               2x 2                4x
+--R        log((%e  )  - 1) - log(- %e   + 1)
+--R   (4)  ----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 690
+
+--S 691 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 691
+
+)clear all
+
+--S 692 of 1034
+t0:=%e^x/sqrt(1+%e^(2*x))
+--R 
+--R
+--R              x
+--R            %e
+--R   (1)  -----------
+--R         +--------+
+--R         |  2x
+--R        \|%e   + 1
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 1034
+r0:=asinh(%e^x)
+--R 
+--R
+--R                x
+--R   (2)  asinh(%e )
+--R                                                    Type: Expression(Integer)
+--E 693
+
+--S 694 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +----------+
+--R               |   x 2          x
+--R   (3)  - log(\|(%e )  + 1  - %e )
+--R                                         Type: Union(Expression(Integer),...)
+--E 694
+
+--S 695 of 1034
+m0:=a0-r0
+--R 
+--R
+--R               +----------+
+--R               |   x 2          x            x
+--R   (4)  - log(\|(%e )  + 1  - %e ) - asinh(%e )
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 696
+
+)clear all
+
+--S 697 of 1034
+t0:=%e^sqrt(4+x)/sqrt(4+x)
+--R 
+--R
+--R           +-----+
+--R          \|x + 4
+--R        %e
+--R   (1)  ----------
+--R          +-----+
+--R         \|x + 4
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 1034
+r0:=2*%e^sqrt(4+x)
+--R 
+--R
+--R            +-----+
+--R           \|x + 4
+--R   (2)  2%e
+--R                                                    Type: Expression(Integer)
+--E 698
+
+--S 699 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +-----+
+--R           \|x + 4
+--R   (3)  2%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 699
+
+--S 700 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 700
+
+--S 701 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 701
+
+)clear all
+
+--S 702 of 1034
+t0:=x/sqrt(-1+%e^(2*x^2))
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         +---------+
+--R         |    2
+--R         |  2x
+--R        \|%e    - 1
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 1034
+r0:=1/2*atan(sqrt(-1+%e^(2*x^2)))
+--R 
+--R
+--R              +---------+
+--R              |    2
+--R              |  2x
+--R        atan(\|%e    - 1 )
+--R   (2)  ------------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 703
+
+--S 704 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +---------+
+--R              |    2
+--R              |  2x
+--R        atan(\|%e    - 1 )
+--R   (3)  ------------------
+--R                 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 704
+
+--S 705 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 705
+
+--S 706 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 706
+
+)clear all
+
+--S 707 of 1034
+t0:=%e^x*sqrt(9+%e^(2*x))
+--R 
+--R
+--R            +--------+
+--R          x |  2x
+--R   (1)  %e \|%e   + 9
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 1034
+r0:=9/2*asinh(1/3*%e^x)+1/2*%e^x*sqrt(9+%e^(2*x))
+--R 
+--R
+--R            +--------+            x
+--R          x |  2x               %e
+--R        %e \|%e   + 9  + 9asinh(---)
+--R                                 3
+--R   (2)  ----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 708
+
+--S 709 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                +----------+                      +----------+
+--R              x |   x 2             x 2           |   x 2          x
+--R       (- 18%e \|(%e )  + 9  + 18(%e )  + 81)log(\|(%e )  + 9  - %e )
+--R     + 
+--R                          +----------+
+--R              x 3      x  |   x 2            x 4        x 2
+--R       (- 2(%e )  - 9%e )\|(%e )  + 9  + 2(%e )  + 18(%e )
+--R  /
+--R          +----------+
+--R        x |   x 2            x 2
+--R     4%e \|(%e )  + 9  - 4(%e )  - 18
+--R                                         Type: Union(Expression(Integer),...)
+--E 709
+
+--S 710 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                +----------+                      +----------+
+--R              x |   x 2             x 2           |   x 2          x
+--R       (- 18%e \|(%e )  + 9  + 18(%e )  + 81)log(\|(%e )  + 9  - %e )
+--R     + 
+--R                  +----------+                   +--------+
+--R              x 2 |   x 2            x 3      x  |  2x
+--R       (- 2(%e ) \|(%e )  + 9  + 2(%e )  + 9%e )\|%e   + 9
+--R     + 
+--R                       x                    +----------+
+--R              x      %e         x 3      x  |   x 2
+--R       (- 18%e asinh(---) - 2(%e )  - 9%e )\|(%e )  + 9
+--R                      3
+--R     + 
+--R                              x
+--R             x 2            %e         x 4        x 2
+--R       (18(%e )  + 81)asinh(---) + 2(%e )  + 18(%e )
+--R                             3
+--R  /
+--R          +----------+
+--R        x |   x 2            x 2
+--R     4%e \|(%e )  + 9  - 4(%e )  - 18
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 711
+
+)clear all
+
+--S 712 of 1034
+t0:=%e^x*sqrt(1+%e^(2*x))
+--R 
+--R
+--R            +--------+
+--R          x |  2x
+--R   (1)  %e \|%e   + 1
+--R                                                    Type: Expression(Integer)
+--E 712
+
+--S 713 of 1034
+r0:=1/2*asinh(%e^x)+1/2*%e^x*sqrt(1+%e^(2*x))
+--R 
+--R
+--R            +--------+
+--R          x |  2x                x
+--R        %e \|%e   + 1  + asinh(%e )
+--R   (2)  ---------------------------
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +----------+                    +----------+
+--R             x |   x 2            x 2          |   x 2          x
+--R       (- 2%e \|(%e )  + 1  + 2(%e )  + 1)log(\|(%e )  + 1  - %e )
+--R     + 
+--R                         +----------+
+--R              x 3     x  |   x 2            x 4       x 2
+--R       (- 2(%e )  - %e )\|(%e )  + 1  + 2(%e )  + 2(%e )
+--R  /
+--R          +----------+
+--R        x |   x 2            x 2
+--R     4%e \|(%e )  + 1  - 4(%e )  - 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 714
+
+--S 715 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               +----------+                    +----------+
+--R             x |   x 2            x 2          |   x 2          x
+--R       (- 2%e \|(%e )  + 1  + 2(%e )  + 1)log(\|(%e )  + 1  - %e )
+--R     + 
+--R                  +----------+                  +--------+
+--R              x 2 |   x 2            x 3     x  |  2x
+--R       (- 2(%e ) \|(%e )  + 1  + 2(%e )  + %e )\|%e   + 1
+--R     + 
+--R                                          +----------+
+--R             x        x        x 3     x  |   x 2             x 2             x
+--R       (- 2%e asinh(%e ) - 2(%e )  - %e )\|(%e )  + 1  + (2(%e )  + 1)asinh(%e )
+--R     + 
+--R           x 4       x 2
+--R       2(%e )  + 2(%e )
+--R  /
+--R          +----------+
+--R        x |   x 2            x 2
+--R     4%e \|(%e )  + 1  - 4(%e )  - 2
+--R                                                    Type: Expression(Integer)
+--E 715
+
+--S 716 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 716
+
+)clear all
+
+--S 717 of 1034
+t0:=%e^(x^2)*x/(1+%e^(2*x^2))
+--R 
+--R
+--R               2
+--R              x
+--R          x %e
+--R   (1)  ---------
+--R            2
+--R          2x
+--R        %e    + 1
+--R                                                    Type: Expression(Integer)
+--E 717
+
+--S 718 of 1034
+r0:=1/2*atan(%e^(x^2))
+--R 
+--R
+--R                2
+--R               x
+--R        atan(%e  )
+--R   (2)  ----------
+--R             2
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2
+--R               x
+--R        atan(%e  )
+--R   (3)  ----------
+--R             2
+--R                                         Type: Union(Expression(Integer),...)
+--E 719
+
+--S 720 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 720
+
+--S 721 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 721
+
+)clear all
+
+--S 722 of 1034
+t0:=%e^(x^(3/2))*x^2
+--R 
+--R
+--R              +-+
+--R         2  x\|x
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 722
+
+--S 723 of 1034
+r0:=-2/3*%e^(x^(3/2))+2/3*%e^(x^(3/2))*x^(3/2)
+--R 
+--R
+--R                        +-+
+--R            +-+       x\|x
+--R        (2x\|x  - 2)%e
+--R   (2)  -------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 723
+
+--S 724 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        +-+
+--R            +-+       x\|x
+--R        (2x\|x  - 2)%e
+--R   (3)  -------------------
+--R                 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 724
+
+--S 725 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 726
+
+)clear all
+
+--S 727 of 1034
+t0:=%e^x/sqrt(-3+%e^(2*x))
+--R 
+--R
+--R              x
+--R            %e
+--R   (1)  -----------
+--R         +--------+
+--R         |  2x
+--R        \|%e   - 3
+--R                                                    Type: Expression(Integer)
+--E 727
+
+--S 728 of 1034
+r0:=atanh(%e^x/sqrt(-3+%e^(2*x)))
+--R 
+--R
+--R                    x
+--R                  %e
+--R   (2)  atanh(-----------)
+--R               +--------+
+--R               |  2x
+--R              \|%e   - 3
+--R                                                    Type: Expression(Integer)
+--E 728
+
+--S 729 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +----------+
+--R               |   x 2          x
+--R   (3)  - log(\|(%e )  - 3  - %e )
+--R                                         Type: Union(Expression(Integer),...)
+--E 729
+
+--S 730 of 1034
+m0:=a0-r0
+--R 
+--R
+--R               +----------+                      x
+--R               |   x 2          x              %e
+--R   (4)  - log(\|(%e )  - 3  - %e ) - atanh(-----------)
+--R                                            +--------+
+--R                                            |  2x
+--R                                           \|%e   - 3
+--R                                                    Type: Expression(Integer)
+--E 730
+
+--S 731 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 731
+
+)clear all
+
+--S 732 of 1034
+t0:=%e^x/(16-%e^(2*x))
+--R 
+--R
+--R               x
+--R             %e
+--R   (1)  - ---------
+--R            2x
+--R          %e   - 16
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 1034
+r0:=1/4*atanh(1/4*%e^x)
+--R 
+--R
+--R                x
+--R              %e
+--R        atanh(---)
+--R               4
+--R   (2)  ----------
+--R             4
+--R                                                    Type: Expression(Integer)
+--E 733
+
+--S 734 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R              x              x
+--R        log(%e  + 4) - log(%e  - 4)
+--R   (3)  ---------------------------
+--R                     8
+--R                                         Type: Union(Expression(Integer),...)
+--E 734
+
+--S 735 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                                               x
+--R              x              x               %e
+--R        log(%e  + 4) - log(%e  - 4) - 2atanh(---)
+--R                                              4
+--R   (4)  -----------------------------------------
+--R                            8
+--R                                                    Type: Expression(Integer)
+--E 735
+
+--S 736 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 736
+
+)clear all
+
+--S 737 of 1034
+t0:=%e^(5*x)/(1+%e^(10*x))
+--R 
+--R
+--R             5x
+--R           %e
+--R   (1)  ---------
+--R          10x
+--R        %e    + 1
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 1034
+r0:=1/5*atan(%e^(5*x))
+--R 
+--R
+--R               5x
+--R        atan(%e  )
+--R   (2)  ----------
+--R             5
+--R                                                    Type: Expression(Integer)
+--E 738
+
+--S 739 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               5x
+--R        atan(%e  )
+--R   (3)  ----------
+--R             5
+--R                                         Type: Union(Expression(Integer),...)
+--E 739
+
+--S 740 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 741
+
+)clear all
+
+--S 742 of 1034
+t0:=%e^(4*x)/sqrt(16+%e^(8*x))
+--R 
+--R
+--R              4x
+--R            %e
+--R   (1)  ------------
+--R         +---------+
+--R         |  8x
+--R        \|%e   + 16
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 1034
+r0:=1/4*asinh(1/4*%e^(4*x))
+--R 
+--R
+--R                4x
+--R              %e
+--R        asinh(----)
+--R                4
+--R   (2)  -----------
+--R             4
+--R                                                    Type: Expression(Integer)
+--E 743
+
+--S 744 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +------------+
+--R               |   4x 2           4x
+--R          log(\|(%e  )  + 16  - %e  )
+--R   (3)  - ---------------------------
+--R                       4
+--R                                         Type: Union(Expression(Integer),...)
+--E 744
+
+--S 745 of 1034
+m0:=a0-r0
+--R 
+--R
+--R               +------------+                   4x
+--R               |   4x 2           4x          %e
+--R        - log(\|(%e  )  + 16  - %e  ) - asinh(----)
+--R                                                4
+--R   (4)  -------------------------------------------
+--R                             4
+--R                                                    Type: Expression(Integer)
+--E 745
+
+--S 746 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 746
+
+)clear all
+
+--S 747 of 1034
+t0:=%e^(4*x^3)*x^2*cos(7*x^3)
+--R 
+--R
+--R                      3
+--R         2      3   4x
+--R   (1)  x cos(7x )%e
+--R                                                    Type: Expression(Integer)
+--E 747
+
+--S 748 of 1034
+r0:=4/195*%e^(4*x^3)*cos(7*x^3)+7/195*%e^(4*x^3)*sin(7*x^3)
+--R 
+--R
+--R             3                        3
+--R           4x       3           3   4x
+--R        7%e   sin(7x ) + 4cos(7x )%e
+--R   (2)  -------------------------------
+--R                      195
+--R                                                    Type: Expression(Integer)
+--E 748
+
+--S 749 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3                        3
+--R           4x       3           3   4x
+--R        7%e   sin(7x ) + 4cos(7x )%e
+--R   (3)  -------------------------------
+--R                      195
+--R                                         Type: Union(Expression(Integer),...)
+--E 749
+
+--S 750 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 750
+
+--S 751 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 751
+
+)clear all
+
+--S 752 of 1034
+t0:=%e^(1+x^2)*x
+--R 
+--R
+--R             2
+--R            x  + 1
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1034
+r0:=1/2*%e^(1+x^2)
+--R 
+--R
+--R           2
+--R          x  + 1
+--R        %e
+--R   (2)  --------
+--R            2
+--R                                                    Type: Expression(Integer)
+--E 753
+
+--S 754 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R          x  + 1
+--R        %e
+--R   (3)  --------
+--R            2
+--R                                         Type: Union(Expression(Integer),...)
+--E 754
+
+--S 755 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 755
+
+--S 756 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 756
+
+)clear all
+
+--S 757 of 1034
+t0:=%e^(1+x^3)*x^2
+--R 
+--R
+--R             3
+--R         2  x  + 1
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 1034
+r0:=1/3*%e^(1+x^3)
+--R 
+--R
+--R           3
+--R          x  + 1
+--R        %e
+--R   (2)  --------
+--R            3
+--R                                                    Type: Expression(Integer)
+--E 758
+
+--S 759 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3
+--R          x  + 1
+--R        %e
+--R   (3)  --------
+--R            3
+--R                                         Type: Union(Expression(Integer),...)
+--E 759
+
+--S 760 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 760
+
+--S 761 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 761
+
+)clear all
+
+--S 762 of 1034
+t0:=%e^sqrt(x)/sqrt(x)
+--R 
+--R
+--R           +-+
+--R          \|x
+--R        %e
+--R   (1)  ------
+--R          +-+
+--R         \|x
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 1034
+r0:=2*%e^sqrt(x)
+--R 
+--R
+--R            +-+
+--R           \|x
+--R   (2)  2%e
+--R                                                    Type: Expression(Integer)
+--E 763
+
+--S 764 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +-+
+--R           \|x
+--R   (3)  2%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 764
+
+--S 765 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 765
+
+--S 766 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 766
+
+)clear all
+
+--S 767 of 1034
+t0:=%e^(x^(1/3))/x^(2/3)
+--R 
+--R
+--R          3+-+
+--R          \|x
+--R        %e
+--R   (1)  ------
+--R         3+-+2
+--R         \|x
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 1034
+r0:=3*%e^(x^(1/3))
+--R 
+--R
+--R           3+-+
+--R           \|x
+--R   (2)  3%e
+--R                                                    Type: Expression(Integer)
+--E 768
+
+--S 769 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3+-+
+--R           \|x
+--R   (3)  3%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 769
+
+--S 770 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 770
+
+--S 771 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 771
+
+)clear all
+
+--S 772 of 1034
+t0:=%e^(3*x)*(-8+2*x^3+x^5)
+--R 
+--R
+--R          5     3       3x
+--R   (1)  (x  + 2x  - 8)%e
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1034
+--r0:=-76/27*%e^(3*x)+4/9*%e^(3*x)*x-2/3*%e^(3*x)*x^2+2/3*%e^(3*x)*x^3-_
+--  1/729*GAMMA(6,-3*x)
+--E 773
+
+--S 774 of 1034
+--a0:=integrate(t0,x)
+--E 774
+
+--S 775 of 1034
+--m0:=a0-r0
+--E 775
+
+--S 776 of 1034
+--d0:=normalize(D(m0,x))
+--E 776
+
+)clear all
+
+--S 777 of 1034
+t0:=(%e^x+x)^2
+--R 
+--R
+--R           x 2        x    2
+--R   (1)  (%e )  + 2x %e  + x
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 1034
+r0:=-2*%e^x+1/2*%e^(2*x)+2*%e^x*x+1/3*x^3
+--R 
+--R
+--R           2x               x     3
+--R        3%e   + (12x - 12)%e  + 2x
+--R   (2)  ---------------------------
+--R                     6
+--R                                                    Type: Expression(Integer)
+--E 778
+
+--S 779 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R            x 2               x     3
+--R        3(%e )  + (12x - 12)%e  + 2x
+--R   (3)  -----------------------------
+--R                      6
+--R                                         Type: Union(Expression(Integer),...)
+--E 779
+
+--S 780 of 1034
+m0:=a0-r0
+--R 
+--R
+--R            2x      x 2
+--R        - %e   + (%e )
+--R   (4)  ---------------
+--R               2
+--R                                                    Type: Expression(Integer)
+--E 780
+
+--S 781 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 781
+
+)clear all
+
+--S 782 of 1034
+t0:=(%e^x+%e^(2*x)+%e^(3*x))/%e^(4*x)
+--R 
+--R
+--R          3x     2x     x
+--R        %e   + %e   + %e
+--R   (1)  -----------------
+--R                 4x
+--R               %e
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 1034
+r0:=(-1/3)/%e^(3*x)+(-1/2)/%e^(2*x)+(-1)/%e^x
+--R 
+--R
+--R              2x      x   3x      x  2x
+--R        (- 6%e   - 3%e )%e   - 2%e %e
+--R   (2)  -------------------------------
+--R                     x  2x  3x
+--R                  6%e %e  %e
+--R                                                    Type: Expression(Integer)
+--E 783
+
+--S 784 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R              x 2      x
+--R        - 6(%e )  - 3%e  - 2
+--R   (3)  --------------------
+--R                   x 3
+--R               6(%e )
+--R                                         Type: Union(Expression(Integer),...)
+--E 784
+
+--S 785 of 1034
+m0:=a0-r0
+--R 
+--R
+--R               x       2x       x 3   3x       x 3  2x
+--R        ((- 3%e  - 2)%e   + 3(%e ) )%e   + 2(%e ) %e
+--R   (4)  ----------------------------------------------
+--R                            x 3  2x  3x
+--R                        6(%e ) %e  %e
+--R                                                    Type: Expression(Integer)
+--E 785
+
+--S 786 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 786
+
+)clear all
+
+--S 787 of 1034
+t0:=%e^x/(1+2*%e^x+%e^(2*x))
+--R 
+--R
+--R                x
+--R              %e
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 1034
+r0:=(-1)/(1+%e^x)
+--R 
+--R
+--R             1
+--R   (2)  - -------
+--R            x
+--R          %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 788
+
+--S 789 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (3)  - -------
+--R            x
+--R          %e  + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 789
+
+--S 790 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 790
+
+--S 791 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 791
+
+)clear all
+
+--S 792 of 1034
+t0:=cos(3*x)/%e^x
+--R 
+--R
+--R        cos(3x)
+--R   (1)  -------
+--R            x
+--R          %e
+--R                                                    Type: Expression(Integer)
+--E 792
+
+--S 793 of 1034
+r0:=-1/10*cos(3*x)/%e^x+3/10*sin(3*x)/%e^x
+--R 
+--R
+--R        3sin(3x) - cos(3x)
+--R   (2)  ------------------
+--R                   x
+--R               10%e
+--R                                                    Type: Expression(Integer)
+--E 793
+
+--S 794 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R        3sin(3x) - cos(3x)
+--R   (3)  ------------------
+--R                   x
+--R               10%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 794
+
+--S 795 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 795
+
+--S 796 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 796
+
+)clear all
+
+--S 797 of 1034
+t0:=%e^(2*x)/(2+3*%e^x+%e^(2*x))
+--R 
+--R
+--R                2x
+--R              %e
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 2
+--R                                                    Type: Expression(Integer)
+--E 797
+
+--S 798 of 1034
+r0:=-log(1+%e^x)+2*log(2+%e^x)
+--R 
+--R
+--R               x              x
+--R   (2)  2log(%e  + 2) - log(%e  + 1)
+--R                                                    Type: Expression(Integer)
+--E 798
+
+--S 799 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               x              x
+--R   (3)  2log(%e  + 2) - log(%e  + 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 799
+
+--S 800 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 800
+
+--S 801 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 801
+
+)clear all
+
+--S 802 of 1034
+t0:=%e^(2*x)/(1+%e^x)
+--R 
+--R
+--R            2x
+--R          %e
+--R   (1)  -------
+--R          x
+--R        %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 802
+
+--S 803 of 1034
+r0:=%e^x-log(1+%e^x)
+--R 
+--R
+--R                x          x
+--R   (2)  - log(%e  + 1) + %e
+--R                                                    Type: Expression(Integer)
+--E 803
+
+--S 804 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                x          x
+--R   (3)  - log(%e  + 1) + %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 804
+
+--S 805 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 805
+
+--S 806 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 806
+
+)clear all
+
+--S 807 of 1034
+t0:=%e^(3*x)*cos(5*x)
+--R 
+--R
+--R                 3x
+--R   (1)  cos(5x)%e
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 1034
+r0:=3/34*%e^(3*x)*cos(5*x)+5/34*%e^(3*x)*sin(5*x)
+--R 
+--R
+--R           3x                    3x
+--R        5%e  sin(5x) + 3cos(5x)%e
+--R   (2)  ---------------------------
+--R                     34
+--R                                                    Type: Expression(Integer)
+--E 808
+
+--S 809 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3x                    3x
+--R        5%e  sin(5x) + 3cos(5x)%e
+--R   (3)  ---------------------------
+--R                     34
+--R                                         Type: Union(Expression(Integer),...)
+--E 809
+
+--S 810 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 810
+
+--S 811 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 811
+
+)clear all
+
+--S 812 of 1034
+t0:=%e^x*sech(%e^x)
+--R 
+--R
+--R          x       x
+--R   (1)  %e sech(%e )
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 1034
+r0:=atan(sinh(%e^x))
+--R 
+--R
+--R                    x
+--R   (2)  atan(sinh(%e ))
+--R                                                    Type: Expression(Integer)
+--E 813
+
+--S 814 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  2atan(sinh(sinh(x) + cosh(x)) + cosh(sinh(x) + cosh(x)))
+--R                                         Type: Union(Expression(Integer),...)
+--E 814
+
+--S 815 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                                          x
+--R   2atan(sinh(sinh(x) + cosh(x)) + cosh(sinh(x) + cosh(x))) - atan(sinh(%e ))
+--R                                                    Type: Expression(Integer)
+--E 815
+
+--S 816 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 816
+
+)clear all
+
+--S 817 of 1034
+t0:=1/(%e^x*(1+2*%e^x))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R            x 2     x
+--R        2(%e )  + %e
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 1034
+r0:=(-1)/%e^x-2*x+2*log(1+2*%e^x)
+--R 
+--R
+--R           x       x             x
+--R        2%e log(2%e  + 1) - 2x %e  - 1
+--R   (2)  ------------------------------
+--R                        x
+--R                      %e
+--R                                                    Type: Expression(Integer)
+--E 818
+
+--S 819 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x       x             x
+--R        2%e log(2%e  + 1) - 2x %e  - 1
+--R   (3)  ------------------------------
+--R                        x
+--R                      %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 819
+
+--S 820 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 820
+
+--S 821 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 821
+
+)clear all
+
+--S 822 of 1034
+t0:=%e^x*cos(4+3*x)
+--R 
+--R
+--R                     x
+--R   (1)  cos(3x + 4)%e
+--R                                                    Type: Expression(Integer)
+--E 822
+
+--S 823 of 1034
+r0:=1/10*%e^x*cos(4+3*x)+3/10*%e^x*sin(4+3*x)
+--R 
+--R
+--R           x                           x
+--R        3%e sin(3x + 4) + cos(3x + 4)%e
+--R   (2)  --------------------------------
+--R                       10
+--R                                                    Type: Expression(Integer)
+--E 823
+
+--S 824 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x                           x
+--R        3%e sin(3x + 4) + cos(3x + 4)%e
+--R   (3)  --------------------------------
+--R                       10
+--R                                         Type: Union(Expression(Integer),...)
+--E 824
+
+--S 825 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 825
+
+--S 826 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 826
+
+)clear all
+
+--S 827 of 1034
+t0:=%e^x*sec(1-%e^x)^3
+--R 
+--R
+--R          x      x     3
+--R   (1)  %e sec(%e  - 1)
+--R                                                    Type: Expression(Integer)
+--E 827
+
+--S 828 of 1034
+r0:=-1/2*atanh(sin(1-%e^x))-1/2*sec(1-%e^x)*tan(1-%e^x)
+--R 
+--R
+--R                    x               x           x
+--R        atanh(sin(%e  - 1)) + sec(%e  - 1)tan(%e  - 1)
+--R   (2)  ----------------------------------------------
+--R                               2
+--R                                                    Type: Expression(Integer)
+--E 828
+
+--S 829 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             x     2          x                   x     2          x
+--R       cos(%e  - 1) log(sin(%e  - 1) + 1) - cos(%e  - 1) log(sin(%e  - 1) - 1)
+--R     + 
+--R              x
+--R       2sin(%e  - 1)
+--R  /
+--R            x     2
+--R     4cos(%e  - 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 829
+
+--S 830 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             x     2          x                   x     2          x
+--R       cos(%e  - 1) log(sin(%e  - 1) + 1) - cos(%e  - 1) log(sin(%e  - 1) - 1)
+--R     + 
+--R                x     2            x
+--R       - 2cos(%e  - 1) atanh(sin(%e  - 1))
+--R     + 
+--R                x     2      x           x               x
+--R       - 2cos(%e  - 1) sec(%e  - 1)tan(%e  - 1) + 2sin(%e  - 1)
+--R  /
+--R            x     2
+--R     4cos(%e  - 1)
+--R                                                    Type: Expression(Integer)
+--E 830
+
+--S 831 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 831
+
+)clear all
+
+--S 832 of 1034
+t0:=(1/%e^x+%e^x)*x
+--R 
+--R
+--R             x 2
+--R        x (%e )  + x
+--R   (1)  ------------
+--R               x
+--R             %e
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 1034
+r0:=(-1)/%e^x-%e^x-x/%e^x+%e^x*x
+--R 
+--R
+--R                  x 2
+--R        (x - 1)(%e )  - x - 1
+--R   (2)  ---------------------
+--R                   x
+--R                 %e
+--R                                                    Type: Expression(Integer)
+--E 833
+
+--S 834 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  x 2
+--R        (x - 1)(%e )  - x - 1
+--R   (3)  ---------------------
+--R                   x
+--R                 %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 834
+
+--S 835 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 835
+
+--S 836 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 836
+
+)clear all
+
+--S 837 of 1034
+t0:=%e^x/(2+3*%e^x+%e^(2*x))
+--R 
+--R
+--R                x
+--R              %e
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 2
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 1034
+r0:=-2*atanh(3+2*%e^x)
+--R 
+--R
+--R                    x
+--R   (2)  - 2atanh(2%e  + 3)
+--R                                                    Type: Expression(Integer)
+--E 838
+
+--S 839 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                x              x
+--R   (3)  - log(%e  + 2) + log(%e  + 1)
+--R                                         Type: Union(Expression(Integer),...)
+--E 839
+
+--S 840 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                x              x                  x
+--R   (4)  - log(%e  + 2) + log(%e  + 1) + 2atanh(2%e  + 3)
+--R                                                    Type: Expression(Integer)
+--E 840
+
+--S 841 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 841
+
+)clear all
+
+--S 842 of 1034
+t0:=%e^(2*x)/(1+%e^x)^(1/3)
+--R 
+--R
+--R             2x
+--R           %e
+--R   (1)  ----------
+--R         +-------+
+--R        3|  x
+--R        \|%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 1034
+r0:=-3/2*(1+%e^x)^(2/3)+3/5*(1+%e^x)^(5/3)
+--R 
+--R
+--R                   +-------+2
+--R            x     3|  x
+--R        (6%e  - 9)\|%e  + 1
+--R   (2)  ---------------------
+--R                  10
+--R                                                    Type: Expression(Integer)
+--E 843
+
+--S 844 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   +-------+2
+--R            x     3|  x
+--R        (6%e  - 9)\|%e  + 1
+--R   (3)  ---------------------
+--R                  10
+--R                                         Type: Union(Expression(Integer),...)
+--E 844
+
+--S 845 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 845
+
+--S 846 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 846
+
+)clear all
+
+--S 847 of 1034
+t0:=%e^(2*x)/(1+%e^x)^(1/4)
+--R 
+--R
+--R             2x
+--R           %e
+--R   (1)  ----------
+--R         +-------+
+--R        4|  x
+--R        \|%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1034
+r0:=-4/3*(1+%e^x)^(3/4)+4/7*(1+%e^x)^(7/4)
+--R 
+--R
+--R                     +-------+3
+--R             x      4|  x
+--R        (12%e  - 16)\|%e  + 1
+--R   (2)  -----------------------
+--R                   21
+--R                                                    Type: Expression(Integer)
+--E 848
+
+--S 849 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     +-------+3
+--R             x      4|  x
+--R        (12%e  - 16)\|%e  + 1
+--R   (3)  -----------------------
+--R                   21
+--R                                         Type: Union(Expression(Integer),...)
+--E 849
+
+--S 850 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 850
+
+--S 851 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 851
+
+)clear all
+
+--S 852 of 1034
+t0:=(-%e^x+2*%e^(2*x))/sqrt(-1-6*%e^x+3*%e^(2*x))
+--R 
+--R
+--R               2x     x
+--R            2%e   - %e
+--R   (1)  -------------------
+--R         +----------------+
+--R         |   2x      x
+--R        \|3%e   - 6%e  - 1
+--R                                                    Type: Expression(Integer)
+--E 852
+
+--S 853 of 1034
+r0:=-atanh((1-%e^x)*sqrt(3)/sqrt(-1-6*%e^x+3*%e^(2*x)))/sqrt(3)+_
+   2/3*sqrt(-1-6*%e^x+3*%e^(2*x))
+--R 
+--R
+--R                   +-+  x    +-+            +----------------+
+--R                  \|3 %e  - \|3         +-+ |   2x      x
+--R        3atanh(-------------------) + 2\|3 \|3%e   - 6%e  - 1
+--R                +----------------+
+--R                |   2x      x
+--R               \|3%e   - 6%e  - 1
+--R   (2)  ------------------------------------------------------
+--R                                   +-+
+--R                                 3\|3
+--R                                                    Type: Expression(Integer)
+--E 853
+
+--S 854 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                +------------------+
+--R        +-+      +-+  x    +-+  |    x 2      x            x 2      x
+--R       \|3 log((\|3 %e  - \|3 )\|3(%e )  - 6%e  - 1  + 3(%e )  - 6%e  + 1)
+--R     + 
+--R         +------------------+
+--R         |    x 2      x
+--R       4\|3(%e )  - 6%e  - 1
+--R  /
+--R     6
+--R                                         Type: Union(Expression(Integer),...)
+--E 854
+
+--S 855 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                             +------------------+
+--R              +-+  x    +-+  |    x 2      x            x 2      x
+--R       3log((\|3 %e  - \|3 )\|3(%e )  - 6%e  - 1  + 3(%e )  - 6%e  + 1)
+--R     + 
+--R                    +-+  x    +-+            +----------------+
+--R                   \|3 %e  - \|3         +-+ |   2x      x
+--R       - 6atanh(-------------------) - 4\|3 \|3%e   - 6%e  - 1
+--R                 +----------------+
+--R                 |   2x      x
+--R                \|3%e   - 6%e  - 1
+--R     + 
+--R             +------------------+
+--R         +-+ |    x 2      x
+--R       4\|3 \|3(%e )  - 6%e  - 1
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 855
+
+--S 856 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 856
+
+)clear all
+
+--S 857 of 1034
+t0:=%e^x*(-5*x+x^2)
+--R 
+--R
+--R          2        x
+--R   (1)  (x  - 5x)%e
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 1034
+r0:=7*%e^x-7*%e^x*x+%e^x*x^2,-3*%e^x-3*%e^x*(5-x)+%e^x*(5-x)^2
+--R 
+--R
+--R           2            x   2            x
+--R   (2)  [(x  - 7x + 7)%e ,(x  - 7x + 7)%e ]
+--R                                             Type: Tuple(Expression(Integer))
+--E 858
+
+--S 859 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2            x
+--R   (3)  (x  - 7x + 7)%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 859
+
+--S 860 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 860
+
+--S 861 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 861
+
+)clear all
+
+--S 862 of 1034
+t0:=%e^(3*x)*(-x+x^2)
+--R 
+--R
+--R          2       3x
+--R   (1)  (x  - x)%e
+--R                                                    Type: Expression(Integer)
+--E 862
+
+--S 863 of 1034
+r0:=-1/27*%e^(3*x)-1/9*%e^(3*x)*(1-x)+1/3*%e^(3*x)*(1-x)^2
+--R 
+--R
+--R           2             3x
+--R        (9x  - 15x + 5)%e
+--R   (2)  -------------------
+--R                 27
+--R                                                    Type: Expression(Integer)
+--E 863
+
+--S 864 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2             3x
+--R        (9x  - 15x + 5)%e
+--R   (3)  -------------------
+--R                 27
+--R                                         Type: Union(Expression(Integer),...)
+--E 864
+
+--S 865 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 865
+
+--S 866 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 866
+
+)clear all
+
+--S 867 of 1034
+t0:=%e^(x^x)*x^(2*x)*(1+log(x))
+--R 
+--R
+--R                          x
+--R                     2x  x
+--R   (1)  (log(x) + 1)x  %e
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 1034
+r0:=%e^(x^x)*(-1+x^x)
+--R 
+--R
+--R                   x
+--R          x       x
+--R   (2)  (x  - 1)%e
+--R                                                    Type: Expression(Integer)
+--E 868
+
+--S 869 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                            x log(x)
+--R           x log(x)       %e
+--R   (3)  (%e         - 1)%e
+--R                                         Type: Union(Expression(Integer),...)
+--E 869
+
+--S 870 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                            x log(x)                x
+--R           x log(x)       %e               x       x
+--R   (4)  (%e         - 1)%e           + (- x  + 1)%e
+--R                                                    Type: Expression(Integer)
+--E 870
+
+--S 871 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 871
+
+)clear all
+
+--S 872 of 1034
+t0:=(%e^(5*x)+%e^(7*x))/(1/%e^x+%e^x)
+--R 
+--R
+--R          x  7x     x  5x
+--R        %e %e   + %e %e
+--R   (1)  -----------------
+--R               x 2
+--R            (%e )  + 1
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 1034
+r0:=1/6*%e^(6*x)
+--R 
+--R
+--R          6x
+--R        %e
+--R   (2)  ----
+--R          6
+--R                                                    Type: Expression(Integer)
+--E 873
+
+--S 874 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x 6
+--R        (%e )
+--R   (3)  ------
+--R           6
+--R                                         Type: Union(Expression(Integer),...)
+--E 874
+
+--S 875 of 1034
+m0:=a0-r0
+--R 
+--R
+--R            6x      x 6
+--R        - %e   + (%e )
+--R   (4)  ---------------
+--R               6
+--R                                                    Type: Expression(Integer)
+--E 875
+
+--S 876 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 876
+
+)clear all
+
+--S 877 of 1034
+t0:=x^(-2+(-1)/x)*(1-log(x))
+--R 
+--R
+--R                       - 2x - 1
+--R                       --------
+--R                           x
+--R   (1)  (- log(x) + 1)x
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--S 878 of 1034
+r0:=(-1)/x^(1/x)
+--R 
+--R
+--R           1
+--R   (2)  - --
+--R           1
+--R           -
+--R           x
+--R          x
+--R                                                    Type: Expression(Integer)
+--E 878
+
+--S 879 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R              (- 2x - 1)log(x)
+--R              ----------------
+--R           2          x
+--R   (3)  - x %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 879
+
+--S 880 of 1034
+m0:=a0-r0
+--R 
+--R
+--R             1  (- 2x - 1)log(x)
+--R             -  ----------------
+--R           2 x          x
+--R        - x x %e                 + 1
+--R   (4)  ----------------------------
+--R                      1
+--R                      -
+--R                      x
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 880
+
+-- Error detected within library code: Cannot happen
+-- d0:=normalize(D(m0,x))
+--S 881 of 1034
+d0:=D(m0,x)
+--R 
+--R
+--R                           1 2  (- 2x - 1)log(x)          1      - x + 1
+--R                           -    ----------------          -      -------
+--R            2          2   x            x                 x         x
+--R        (- x log(x) + x )(x ) %e                 + log(x)x  - x x
+--R   (5)  ----------------------------------------------------------------
+--R                                         2
+--R                                         -
+--R                                       2 x
+--R                                      x x
+--R                                                    Type: Expression(Integer)
+--E 881
+
+)clear all
+
+--S 882 of 1034
+t0:=(a+%e^x*b)^2
+--R 
+--R
+--R         2   x 2          x    2
+--R   (1)  b (%e )  + 2a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 1034
+r0:=2*%e^x*a*b+1/2*%e^(2*x)*b^2+a^2*x
+--R 
+--R
+--R         2  2x          x     2
+--R        b %e   + 4a b %e  + 2a x
+--R   (2)  ------------------------
+--R                    2
+--R                                                    Type: Expression(Integer)
+--E 883
+
+--S 884 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2   x 2          x     2
+--R        b (%e )  + 4a b %e  + 2a x
+--R   (3)  --------------------------
+--R                     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 884
+
+--S 885 of 1034
+m0:=a0-r0
+--R 
+--R
+--R           2  2x    2   x 2
+--R        - b %e   + b (%e )
+--R   (4)  -------------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 885
+
+--S 886 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 886
+
+)clear all
+
+--S 887 of 1034
+t0:=(a+%e^x*b)^3
+--R 
+--R
+--R         3   x 3       2   x 2     2    x    3
+--R   (1)  b (%e )  + 3a b (%e )  + 3a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 887
+
+--S 888 of 1034
+r0:=3*%e^x*a^2*b+3/2*%e^(2*x)*a*b^2+1/3*%e^(3*x)*b^3+a^3*x
+--R 
+--R
+--R          3  3x       2  2x      2    x     3
+--R        2b %e   + 9a b %e   + 18a b %e  + 6a x
+--R   (2)  --------------------------------------
+--R                           6
+--R                                                    Type: Expression(Integer)
+--E 888
+
+--S 889 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3   x 3       2   x 2      2    x     3
+--R        2b (%e )  + 9a b (%e )  + 18a b %e  + 6a x
+--R   (3)  ------------------------------------------
+--R                             6
+--R                                         Type: Union(Expression(Integer),...)
+--E 889
+
+--S 890 of 1034
+m0:=a0-r0
+--R 
+--R
+--R            3  3x       2  2x     3   x 3       2   x 2
+--R        - 2b %e   - 9a b %e   + 2b (%e )  + 9a b (%e )
+--R   (4)  -----------------------------------------------
+--R                               6
+--R                                                    Type: Expression(Integer)
+--E 890
+
+--S 891 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 891
+
+)clear all
+
+--S 892 of 1034
+t0:=(a+%e^x*b)^4
+--R 
+--R
+--R         4   x 4       3   x 3     2 2   x 2     3    x    4
+--R   (1)  b (%e )  + 4a b (%e )  + 6a b (%e )  + 4a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 892
+
+--S 893 of 1034
+r0:=4*%e^x*a^3*b+3*%e^(2*x)*a^2*b^2+4/3*%e^(3*x)*a*b^3+1/4*%e^(4*x)*b^4+a^4*x
+--R 
+--R
+--R          4  4x        3  3x      2 2  2x      3    x      4
+--R        3b %e   + 16a b %e   + 36a b %e   + 48a b %e  + 12a x
+--R   (2)  -----------------------------------------------------
+--R                                  12
+--R                                                    Type: Expression(Integer)
+--E 893
+
+--S 894 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4   x 4        3   x 3      2 2   x 2      3    x      4
+--R        3b (%e )  + 16a b (%e )  + 36a b (%e )  + 48a b %e  + 12a x
+--R   (3)  -----------------------------------------------------------
+--R                                     12
+--R                                         Type: Union(Expression(Integer),...)
+--E 894
+
+--S 895 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       4  4x        3  3x      2 2  2x     4   x 4        3   x 3      2 2   x 2
+--R   - 3b %e   - 16a b %e   - 36a b %e   + 3b (%e )  + 16a b (%e )  + 36a b (%e )
+--R   -----------------------------------------------------------------------------
+--R                                         12
+--R                                                    Type: Expression(Integer)
+--E 895
+
+--S 896 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 896
+
+)clear all
+
+--S 897 of 1034
+t0:=1/sqrt(a+%e^(c+d*x)*b)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         |    d x + c
+--R        \|b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 897
+
+--S 898 of 1034
+r0:=-2*atanh(sqrt(a+%e^(c+d*x)*b)/sqrt(a))/(d*sqrt(a))
+--R 
+--R
+--R                  +---------------+
+--R                  |    d x + c
+--R                 \|b %e        + a
+--R          2atanh(------------------)
+--R                         +-+
+--R                        \|a
+--R   (2)  - --------------------------
+--R                       +-+
+--R                     d\|a
+--R                                                    Type: Expression(Integer)
+--E 898
+
+--S 899 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +---------------+
+--R             |    d x + c             d x + c       +-+
+--R        - 2a\|b %e        + a  + (b %e        + 2a)\|a
+--R    log(-----------------------------------------------)
+--R                             d x + c
+--R                           %e
+--R   [----------------------------------------------------,
+--R                              +-+
+--R                            d\|a
+--R                   +---------------+
+--R             +---+ |    d x + c
+--R            \|- a \|b %e        + a
+--R      2atan(------------------------)
+--R                        a
+--R    - -------------------------------]
+--R                    +---+
+--R                  d\|- a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 899
+
+--S 900 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                +---------------+
+--R                |    d x + c             d x + c       +-+
+--R           - 2a\|b %e        + a  + (b %e        + 2a)\|a
+--R       log(-----------------------------------------------)
+--R                                d x + c
+--R                              %e
+--R     + 
+--R               +---------------+
+--R               |    d x + c
+--R              \|b %e        + a
+--R       2atanh(------------------)
+--R                      +-+
+--R                     \|a
+--R  /
+--R       +-+
+--R     d\|a
+--R                                                    Type: Expression(Integer)
+--E 900
+
+--S 901 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R                      +---------------+                     +---------------+
+--R                      |    d x + c                    +---+ |    d x + c
+--R          +---+      \|b %e        + a       +-+     \|- a \|b %e        + a
+--R        2\|- a atanh(------------------) - 2\|a atan(------------------------)
+--R                             +-+                                 a
+--R                            \|a
+--R   (6)  ----------------------------------------------------------------------
+--R                                        +---+ +-+
+--R                                      d\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 902
+
+--S 903 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 903
+
+)clear all
+
+--S 904 of 1034
+t0:=1/sqrt(-a+%e^(c+d*x)*b)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         |    d x + c
+--R        \|b %e        - a
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 1034
+r0:=2*atan(sqrt(-a+%e^(c+d*x)*b)/sqrt(a))/(d*sqrt(a))
+--R 
+--R
+--R               +---------------+
+--R               |    d x + c
+--R              \|b %e        - a
+--R        2atan(------------------)
+--R                      +-+
+--R                     \|a
+--R   (2)  -------------------------
+--R                    +-+
+--R                  d\|a
+--R                                                    Type: Expression(Integer)
+--E 905
+
+--S 906 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +---------------+
+--R           |    d x + c             d x + c       +---+
+--R        2a\|b %e        - a  + (b %e        - 2a)\|- a
+--R    log(-----------------------------------------------)
+--R                             d x + c
+--R                           %e
+--R   [----------------------------------------------------,
+--R                             +---+
+--R                           d\|- a
+--R               +---------------+
+--R           +-+ |    d x + c
+--R          \|a \|b %e        - a
+--R    2atan(----------------------)
+--R                     a
+--R    -----------------------------]
+--R                  +-+
+--R                d\|a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 906
+
+--S 907 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  +---------------+
+--R                  |    d x + c             d x + c       +---+
+--R        +-+    2a\|b %e        - a  + (b %e        - 2a)\|- a
+--R       \|a log(-----------------------------------------------)
+--R                                    d x + c
+--R                                  %e
+--R     + 
+--R                      +---------------+
+--R                      |    d x + c
+--R           +---+     \|b %e        - a
+--R       - 2\|- a atan(------------------)
+--R                             +-+
+--R                            \|a
+--R  /
+--R       +---+ +-+
+--R     d\|- a \|a
+--R                                                    Type: Expression(Integer)
+--E 907
+
+--S 908 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 908
+
+--S 909 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R                   +---------------+           +---------------+
+--R               +-+ |    d x + c                |    d x + c
+--R              \|a \|b %e        - a           \|b %e        - a
+--R        2atan(----------------------) - 2atan(------------------)
+--R                         a                            +-+
+--R                                                     \|a
+--R   (6)  ---------------------------------------------------------
+--R                                    +-+
+--R                                  d\|a
+--R                                                    Type: Expression(Integer)
+--E 909
+
+--S 910 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 910
+
+)clear all
+
+--S 911 of 1034
+t0:=sqrt(a+%e^(c+d*x)*b)
+--R 
+--R
+--R         +---------------+
+--R         |    d x + c
+--R   (1)  \|b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 911
+
+--S 912 of 1034
+r0:=-2*atanh(sqrt(a+%e^(c+d*x)*b)/sqrt(a))*sqrt(a)/d+2*sqrt(a+%e^(c+d*x)*b)/d
+--R 
+--R
+--R                      +---------------+
+--R                      |    d x + c           +---------------+
+--R            +-+      \|b %e        + a       |    d x + c
+--R        - 2\|a atanh(------------------) + 2\|b %e        + a
+--R                             +-+
+--R                            \|a
+--R   (2)  ------------------------------------------------------
+--R                                   d
+--R                                                    Type: Expression(Integer)
+--E 912
+
+--S 913 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +---------------+
+--R                +-+ |    d x + c            d x + c           +---------------+
+--R     +-+    - 2\|a \|b %e        + a  + b %e        + 2a      |    d x + c
+--R    \|a log(--------------------------------------------) + 2\|b %e        + a
+--R                                d x + c
+--R                              %e
+--R   [---------------------------------------------------------------------------,
+--R                                         d
+--R                   +---------------+
+--R                   |    d x + c           +---------------+
+--R        +---+     \|b %e        + a       |    d x + c
+--R    - 2\|- a atan(------------------) + 2\|b %e        + a
+--R                         +---+
+--R                        \|- a
+--R    -------------------------------------------------------]
+--R                               d
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 913
+
+--S 914 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       +---------------+
+--R                   +-+ |    d x + c            d x + c
+--R        +-+    - 2\|a \|b %e        + a  + b %e        + 2a
+--R       \|a log(--------------------------------------------)
+--R                                   d x + c
+--R                                 %e
+--R     + 
+--R                   +---------------+
+--R                   |    d x + c
+--R         +-+      \|b %e        + a
+--R       2\|a atanh(------------------)
+--R                          +-+
+--R                         \|a
+--R  /
+--R     d
+--R                                                    Type: Expression(Integer)
+--E 914
+
+--S 915 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 915
+
+--S 916 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R                    +---------------+                 +---------------+
+--R                    |    d x + c                      |    d x + c
+--R          +-+      \|b %e        + a       +---+     \|b %e        + a
+--R        2\|a atanh(------------------) - 2\|- a atan(------------------)
+--R                           +-+                              +---+
+--R                          \|a                              \|- a
+--R   (6)  ----------------------------------------------------------------
+--R                                        d
+--R                                                    Type: Expression(Integer)
+--E 916
+
+--S 917 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 917
+
+)clear all
+
+--S 918 of 1034
+t0:=sqrt(-a+%e^(c+d*x)*b)
+--R 
+--R
+--R         +---------------+
+--R         |    d x + c
+--R   (1)  \|b %e        - a
+--R                                                    Type: Expression(Integer)
+--E 918
+
+--S 919 of 1034
+r0:=-2*atan(sqrt(-a+%e^(c+d*x)*b)/sqrt(a))*sqrt(a)/d+2*sqrt(-a+%e^(c+d*x)*b)/d
+--R 
+--R
+--R                     +---------------+
+--R                     |    d x + c           +---------------+
+--R            +-+     \|b %e        - a       |    d x + c
+--R        - 2\|a atan(------------------) + 2\|b %e        - a
+--R                            +-+
+--R                           \|a
+--R   (2)  -----------------------------------------------------
+--R                                  d
+--R                                                    Type: Expression(Integer)
+--E 919
+
+--S 920 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             +---------------+
+--R                       +---+ |    d x + c            d x + c
+--R          +---+    - 2\|- a \|b %e        - a  + b %e        - 2a
+--R         \|- a log(----------------------------------------------)
+--R                                        d x + c
+--R                                      %e
+--R       + 
+--R           +---------------+
+--R           |    d x + c
+--R         2\|b %e        - a
+--R    /
+--R       d
+--R     ,
+--R                 +---------------+
+--R                 |    d x + c           +---------------+
+--R        +-+     \|b %e        - a       |    d x + c
+--R    - 2\|a atan(------------------) + 2\|b %e        - a
+--R                        +-+
+--R                       \|a
+--R    -----------------------------------------------------]
+--R                              d
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 920
+
+--S 921 of 1034
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           +---------------+
+--R                     +---+ |    d x + c            d x + c
+--R        +---+    - 2\|- a \|b %e        - a  + b %e        - 2a
+--R       \|- a log(----------------------------------------------)
+--R                                      d x + c
+--R                                    %e
+--R     + 
+--R                  +---------------+
+--R                  |    d x + c
+--R         +-+     \|b %e        - a
+--R       2\|a atan(------------------)
+--R                         +-+
+--R                        \|a
+--R  /
+--R     d
+--R                                                    Type: Expression(Integer)
+--E 921
+
+--S 922 of 1034
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 1034
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Expression(Integer)
+--E 923
+
+--S 924 of 1034
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 924
+
+)clear all
+
+--S 925 of 1034
+t0:=f^(a+b*x)*x^(3/2)
+--R 
+--R
+--R           b x + a +-+
+--R   (1)  x f       \|x
+--R                                                    Type: Expression(Integer)
+--E 925
+
+--S 926 of 1034
+--r0:=f^(a+b*x)*x^(3/2)/(b*log(f))+3/4*f^a*erfi(sqrt(b)*sqrt(x)*_
+--  sqrt(log(f)))*sqrt(%pi)/(b^(5/2)*log(f)^(5/2))-3/2*f^(a+b*x)*_
+--  sqrt(x)/(b^2*log(f)^2)
+--E 926
+
+--S 927 of 1034
+--a0:=integrate(t0,x)
+--E 927
+
+--S 928 of 1034
+--m0:=a0-r0
+--E 928
+
+--S 929 of 1034
+--d0:=normalize(D(m0,x))
+--E 929
+
+)clear all
+
+--S 930 of 1034
+t0:=f^(a+b*x)*x^(1/2)
+--R 
+--R
+--R         b x + a +-+
+--R   (1)  f       \|x
+--R                                                    Type: Expression(Integer)
+--E 930
+
+--S 931 of 1034
+--r0:=-1/2*f^a*erfi(sqrt(b)*sqrt(x)*sqrt(log(f)))*sqrt(%pi)/(b^(3/2)*_
+--  log(f)^(3/2))+f^(a+b*x)*sqrt(x)/(b*log(f))
+--E 931
+
+--S 932 of 1034
+--a0:=integrate(t0,x)
+--E 932
+
+--S 933 of 1034
+--m0:=a0-r0
+--E 933
+
+--S 934 of 1034
+--d0:=normalize(D(m0,x))
+--E 934
+
+)clear all
+
+--S 935 of 1034
+t0:=f^(a+b*x)/x^(1/2)
+--R 
+--R
+--R         b x + a
+--R        f
+--R   (1)  --------
+--R           +-+
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 935
+
+--S 936 of 1034
+--r0:=f^a*erfi(sqrt(b)*sqrt(x)*sqrt(log(f)))*sqrt(%pi)/(sqrt(b)*sqrt(log(f)))
+--E 936
+
+--S 937 of 1034
+--a0:=integrate(t0,x)
+--E 937
+
+--S 938 of 1034
+--m0:=a0-r0
+--E 938
+
+--S 939 of 1034
+--d0:=normalize(D(m0,x))
+--E 939
+
+)clear all
+
+--S 940 of 1034
+t0:=f^(a+b*x)/x^(3/2)
+--R 
+--R
+--R         b x + a
+--R        f
+--R   (1)  --------
+--R            +-+
+--R          x\|x
+--R                                                    Type: Expression(Integer)
+--E 940
+
+--S 941 of 1034
+--r0:=-2*f^(a+b*x)/sqrt(x)+2*f^a*erfi(sqrt(b)*sqrt(x)*sqrt(log(f)))*_
+--  sqrt(%pi)*sqrt(b)*sqrt(log(f))
+--E 941
+
+--S 942 of 1034
+--a0:=integrate(t0,x)
+--E 942
+
+--S 943 of 1034
+--m0:=a0-r0
+--E 943
+
+--S 944 of 1034
+--d0:=normalize(D(m0,x))
+--E 944
+
+)clear all
+
+--S 945 of 1034
+t0:=1/((-5)/%e^(m*x)+2*%e^(m*x))
+--R 
+--R
+--R              m x
+--R            %e
+--R   (1)  -------------
+--R            m x 2
+--R        2(%e   )  - 5
+--R                                                    Type: Expression(Integer)
+--E 945
+
+--S 946 of 1034
+r0:=-atanh(%e^(m*x)*sqrt(2/5))/(m*sqrt(10))
+--R 
+--R
+--R                 +-+  m x
+--R                \|2 %e
+--R          atanh(---------)
+--R                    +-+
+--R                   \|5
+--R   (2)  - ----------------
+--R                 +--+
+--R               m\|10
+--R                                                    Type: Expression(Integer)
+--E 946
+
+--S 947 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R              +--+   m x 2       m x     +--+
+--R            2\|10 (%e   )  - 20%e    + 5\|10
+--R        log(---------------------------------)
+--R                          m x 2
+--R                      2(%e   )  - 5
+--R   (3)  --------------------------------------
+--R                           +--+
+--R                        2m\|10
+--R                                         Type: Union(Expression(Integer),...)
+--E 947
+
+--S 948 of 1034
+m0:=a0-r0
+--R 
+--R
+--R              +--+   m x 2       m x     +--+            +-+  m x
+--R            2\|10 (%e   )  - 20%e    + 5\|10            \|2 %e
+--R        log(---------------------------------) + 2atanh(---------)
+--R                          m x 2                             +-+
+--R                      2(%e   )  - 5                        \|5
+--R   (4)  ----------------------------------------------------------
+--R                                     +--+
+--R                                  2m\|10
+--R                                                    Type: Expression(Integer)
+--E 948
+
+--S 949 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R          +--+     +-+ +-+    m x 3      +-+ +-+ +--+         m x 2
+--R       (2\|10  - 2\|2 \|5 )(%e   )  + (2\|2 \|5 \|10  - 20)(%e   )
+--R     + 
+--R          +--+     +-+ +-+   m x
+--R       (5\|10  - 5\|2 \|5 )%e
+--R  /
+--R       +--+   m x 4        m x 3        m x      +--+
+--R     4\|10 (%e   )  - 40(%e   )  + 100%e    - 25\|10
+--R                                                    Type: Expression(Integer)
+--E 949
+
+)clear all
+
+--S 950 of 1034
+t0:=%e^(6*x)*sin(3*x)
+--R 
+--R
+--R          6x
+--R   (1)  %e  sin(3x)
+--R                                                    Type: Expression(Integer)
+--E 950
+
+--S 951 of 1034
+r0:=-1/15*%e^(6*x)*cos(3*x)+2/15*%e^(6*x)*sin(3*x)
+--R 
+--R
+--R           6x                   6x
+--R        2%e  sin(3x) - cos(3x)%e
+--R   (2)  --------------------------
+--R                    15
+--R                                                    Type: Expression(Integer)
+--E 951
+
+--S 952 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R           6x                   6x
+--R        2%e  sin(3x) - cos(3x)%e
+--R   (3)  --------------------------
+--R                    15
+--R                                         Type: Union(Expression(Integer),...)
+--E 952
+
+--S 953 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 953
+
+--S 954 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 954
+
+)clear all
+
+--S 955 of 1034
+t0:=%e^(3*x)/(1+%e^(2*x))
+--R 
+--R
+--R            3x
+--R          %e
+--R   (1)  --------
+--R          2x
+--R        %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 955
+
+--S 956 of 1034
+r0:=%e^x-atan(%e^x)
+--R 
+--R
+--R                 x      x
+--R   (2)  - atan(%e ) + %e
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 x      x
+--R   (3)  - atan(%e ) + %e
+--R                                         Type: Union(Expression(Integer),...)
+--E 957
+
+--S 958 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 958
+
+--S 959 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 959
+
+)clear all
+
+--S 960 of 1034
+t0:=%e^(3*x)/(-1+%e^(2*x))
+--R 
+--R
+--R            3x
+--R          %e
+--R   (1)  --------
+--R          2x
+--R        %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 960
+
+--S 961 of 1034
+r0:=%e^x-atanh(%e^x)
+--R 
+--R
+--R                  x      x
+--R   (2)  - atanh(%e ) + %e
+--R                                                    Type: Expression(Integer)
+--E 961
+
+--S 962 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                x              x           x
+--R        - log(%e  + 1) + log(%e  - 1) + 2%e
+--R   (3)  ------------------------------------
+--R                          2
+--R                                         Type: Union(Expression(Integer),...)
+--E 962
+
+--S 963 of 1034
+m0:=a0-r0
+--R 
+--R
+--R                x              x                 x
+--R        - log(%e  + 1) + log(%e  - 1) + 2atanh(%e )
+--R   (4)  -------------------------------------------
+--R                             2
+--R                                                    Type: Expression(Integer)
+--E 963
+
+--S 964 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 964
+
+)clear all
+
+--S 965 of 1034
+t0:=1/(%e^x*sqrt(1+%e^(2*x)))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R            +--------+
+--R          x |  2x
+--R        %e \|%e   + 1
+--R                                                    Type: Expression(Integer)
+--E 965
+
+--S 966 of 1034
+r0:=-sqrt(1+%e^(2*x))/%e^x
+--R 
+--R
+--R           +--------+
+--R           |  2x
+--R          \|%e   + 1
+--R   (2)  - -----------
+--R                x
+--R              %e
+--R                                                    Type: Expression(Integer)
+--E 966
+
+--S 967 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      1
+--R   (3)  - -------------------------
+--R              +----------+
+--R            x |   x 2           x 2
+--R          %e \|(%e )  + 1  - (%e )
+--R                                         Type: Union(Expression(Integer),...)
+--E 967
+
+--S 968 of 1034
+m0:=a0-r0
+--R 
+--R
+--R          +----------+        +--------+
+--R          |   x 2          x  |  2x
+--R        (\|(%e )  + 1  - %e )\|%e   + 1  - 1
+--R   (4)  ------------------------------------
+--R                  +----------+
+--R                x |   x 2           x 2
+--R              %e \|(%e )  + 1  - (%e )
+--R                                                    Type: Expression(Integer)
+--E 968
+
+--S 969 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 969
+
+)clear all
+
+--S 970 of 1034
+t0:=%e^x/(-1-8*%e^x+%e^(2*x))
+--R 
+--R
+--R                x
+--R              %e
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   - 8%e  - 1
+--R                                                    Type: Expression(Integer)
+--E 970
+
+--S 971 of 1034
+r0:=atanh((4-%e^x)/sqrt(17))/sqrt(17)
+--R 
+--R
+--R                  x
+--R                %e  - 4
+--R          atanh(-------)
+--R                  +--+
+--R                 \|17
+--R   (2)  - --------------
+--R                +--+
+--R               \|17
+--R                                                    Type: Expression(Integer)
+--E 971
+
+--S 972 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             +--+   x 2        +--+        x      +--+
+--R            \|17 (%e )  + (- 8\|17  - 34)%e  + 33\|17  + 136
+--R        log(------------------------------------------------)
+--R                               x 2      x
+--R                            (%e )  - 8%e  - 1
+--R   (3)  -----------------------------------------------------
+--R                                  +--+
+--R                                2\|17
+--R                                         Type: Union(Expression(Integer),...)
+--E 972
+
+--S 973 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        +--+   x 2        +--+        x      +--+                   x
+--R       \|17 (%e )  + (- 8\|17  - 34)%e  + 33\|17  + 136           %e  - 4
+--R   log(------------------------------------------------) + 2atanh(-------)
+--R                          x 2      x                                +--+
+--R                       (%e )  - 8%e  - 1                           \|17
+--R   -----------------------------------------------------------------------
+--R                                      +--+
+--R                                    2\|17
+--R                                                    Type: Expression(Integer)
+--E 973
+
+--S 974 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 974
+
+)clear all
+
+--S 975 of 1034
+t0:=%e^(7*x)*x^3
+--R 
+--R
+--R         3  7x
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 975
+
+--S 976 of 1034
+r0:=-6/2401*%e^(7*x)+6/343*%e^(7*x)*x-3/49*%e^(7*x)*x^2+1/7*%e^(7*x)*x^3
+--R 
+--R
+--R             3       2             7x
+--R        (343x  - 147x  + 42x - 6)%e
+--R   (2)  -----------------------------
+--R                     2401
+--R                                                    Type: Expression(Integer)
+--E 976
+
+--S 977 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3       2             7x
+--R        (343x  - 147x  + 42x - 6)%e
+--R   (3)  -----------------------------
+--R                     2401
+--R                                         Type: Union(Expression(Integer),...)
+--E 977
+
+--S 978 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 978
+
+--S 979 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 979
+
+)clear all
+
+--S 980 of 1034
+t0:=%e^(8-2*x)*x^3
+--R 
+--R
+--R         3  - 2x + 8
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 980
+
+--S 981 of 1034
+r0:=-3/8*%e^(8-2*x)-3/4*%e^(8-2*x)*x-3/4*%e^(8-2*x)*x^2-1/2*%e^(8-2*x)*x^3
+--R 
+--R
+--R             3     2            - 2x + 8
+--R        (- 4x  - 6x  - 6x - 3)%e
+--R   (2)  --------------------------------
+--R                        8
+--R                                                    Type: Expression(Integer)
+--E 981
+
+--S 982 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3     2            - 2x + 8
+--R        (- 4x  - 6x  - 6x - 3)%e
+--R   (3)  --------------------------------
+--R                        8
+--R                                         Type: Union(Expression(Integer),...)
+--E 982
+
+--S 983 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 983
+
+--S 984 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 984
+
+)clear all
+
+--S 985 of 1034
+t0:=%e^x*sqrt(9-%e^(2*x))
+--R 
+--R
+--R            +----------+
+--R          x |    2x
+--R   (1)  %e \|- %e   + 9
+--R                                                    Type: Expression(Integer)
+--E 985
+
+--S 986 of 1034
+r0:=9/2*asin(1/3*%e^x)+1/2*%e^x*sqrt(9-%e^(2*x))
+--R 
+--R
+--R            +----------+           x
+--R          x |    2x              %e
+--R        %e \|- %e   + 9  + 9asin(---)
+--R                                  3
+--R   (2)  -----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 986
+
+--S 987 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                    +------------+
+--R              +------------+                        |     x 2
+--R              |     x 2             x 2            \|- (%e )  + 9  - 3
+--R       (- 108\|- (%e )  + 9  - 18(%e )  + 324)atan(-------------------)
+--R                                                             x
+--R                                                           %e
+--R     + 
+--R                        +------------+
+--R           x 3       x  |     x 2            x 3       x
+--R       ((%e )  - 18%e )\|- (%e )  + 9  - 6(%e )  + 54%e
+--R  /
+--R        +------------+
+--R        |     x 2            x 2
+--R     12\|- (%e )  + 9  + 2(%e )  - 36
+--R                                         Type: Union(Expression(Integer),...)
+--E 987
+
+--S 988 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                    +------------+
+--R              +------------+                        |     x 2
+--R              |     x 2             x 2            \|- (%e )  + 9  - 3
+--R       (- 108\|- (%e )  + 9  - 18(%e )  + 324)atan(-------------------)
+--R                                                             x
+--R                                                           %e
+--R     + 
+--R               +----------+            x                    +------------+
+--R             x |    2x               %e        x 3       x  |     x 2
+--R       (- 6%e \|- %e   + 9  - 54asin(---) + (%e )  - 18%e )\|- (%e )  + 9
+--R                                      3
+--R     + 
+--R                          +----------+                           x
+--R             x 3       x  |    2x               x 2            %e         x 3
+--R       (- (%e )  + 18%e )\|- %e   + 9  + (- 9(%e )  + 162)asin(---) - 6(%e )
+--R                                                                3
+--R     + 
+--R           x
+--R       54%e
+--R  /
+--R        +------------+
+--R        |     x 2            x 2
+--R     12\|- (%e )  + 9  + 2(%e )  - 36
+--R                                                    Type: Expression(Integer)
+--E 988
+
+--S 989 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 989
+
+)clear all
+
+--S 990 of 1034
+t0:=%e^(6*x)*sqrt(9-%e^(2*x))
+--R 
+--R
+--R             +----------+
+--R          6x |    2x
+--R   (1)  %e  \|- %e   + 9
+--R                                                    Type: Expression(Integer)
+--E 990
+
+--S 991 of 1034
+r0:=-27*(9-%e^(2*x))^(3/2)+18/5*(9-%e^(2*x))^(5/2)-1/7*(9-%e^(2*x))^(7/2)
+--R 
+--R
+--R                                               +----------+
+--R             2x 3       2x 2        2x         |    2x
+--R        (5(%e  )  - 9(%e  )  - 108%e   - 1944)\|- %e   + 9
+--R   (2)  ---------------------------------------------------
+--R                                 35
+--R                                                    Type: Expression(Integer)
+--E 991
+
+--S 992 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                               +----------+
+--R             2x 3       2x 2        2x         |    2x
+--R        (5(%e  )  - 9(%e  )  - 108%e   - 1944)\|- %e   + 9
+--R   (3)  ---------------------------------------------------
+--R                                 35
+--R                                         Type: Union(Expression(Integer),...)
+--E 992
+
+--S 993 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 993
+
+--S 994 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 994
+
+)clear all
+
+--S 995 of 1034
+t0:=%e^(6*x)/(9-%e^x)^(5/2)
+--R 
+--R
+--R                         6x
+--R                       %e
+--R   (1)  ---------------------------------
+--R                              +---------+
+--R            x 2       x       |    x
+--R        ((%e )  - 18%e  + 81)\|- %e  + 9
+--R                                                    Type: Expression(Integer)
+--E 995
+
+--S 996 of 1034
+r0:=39366/(9-%e^x)^(3/2)+540*(9-%e^x)^(3/2)-18*(9-%e^x)^(5/2)+_
+   2/7*(9-%e^x)^(7/2)+(-65610)/sqrt(9-%e^x)-14580*sqrt(9-%e^x)
+--R 
+--R
+--R            x 5        x 4         x 3           x 2            x
+--R        2(%e )  + 36(%e )  + 864(%e )  + 46656(%e )  - 1679616%e  + 10077696
+--R   (2)  --------------------------------------------------------------------
+--R                                           +---------+
+--R                                   x       |    x
+--R                               (7%e  - 63)\|- %e  + 9
+--R                                                    Type: Expression(Integer)
+--E 996
+
+--S 997 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R            x 5        x 4         x 3           x 2            x
+--R        2(%e )  + 36(%e )  + 864(%e )  + 46656(%e )  - 1679616%e  + 10077696
+--R   (3)  --------------------------------------------------------------------
+--R                                           +---------+
+--R                                   x       |    x
+--R                               (7%e  - 63)\|- %e  + 9
+--R                                         Type: Union(Expression(Integer),...)
+--E 997
+
+--S 998 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 998
+
+--S 999 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 999
+
+)clear all
+
+--S 1000 of 1034
+t0:=(2-7*%e^(x^4))^5*x^3
+--R 
+--R
+--R   (1)
+--R                  4 5              4 4              4 3             4 2
+--R             3   x            3   x            3   x           3   x
+--R     - 16807x (%e  )  + 24010x (%e  )  - 13720x (%e  )  + 3920x (%e  )
+--R   + 
+--R               4
+--R           3  x       3
+--R     - 560x %e   + 32x
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+--S 1001 of 1034
+r0:=-140*%e^(x^4)+490*%e^(2*x^4)-3430/3*%e^(3*x^4)+12005/8*%e^(4*x^4)-_
+   16807/20*%e^(5*x^4)+8*x^4
+--R 
+--R
+--R   (2)
+--R               4             4             4            4           4
+--R             5x            4x            3x           2x           x        4
+--R   - 100842%e    + 180075%e    - 137200%e    + 58800%e    - 16800%e   + 960x
+--R   --------------------------------------------------------------------------
+--R                                       120
+--R                                                    Type: Expression(Integer)
+--E 1001
+
+--S 1002 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                   4 5             4 4             4 3            4 2
+--R                  x               x               x              x
+--R       - 100842(%e  )  + 180075(%e  )  - 137200(%e  )  + 58800(%e  )
+--R     + 
+--R                 4
+--R                x        4
+--R       - 16800%e   + 960x
+--R  /
+--R     120
+--R                                         Type: Union(Expression(Integer),...)
+--E 1002
+
+--S 1003 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 4             4             4            4             4 5
+--R               5x            4x            3x           2x             x
+--R       100842%e    - 180075%e    + 137200%e    - 58800%e    - 100842(%e  )
+--R     + 
+--R                 4 4             4 3            4 2
+--R                x               x              x
+--R       180075(%e  )  - 137200(%e  )  + 58800(%e  )
+--R  /
+--R     120
+--R                                                    Type: Expression(Integer)
+--E 1003
+
+--S 1004 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1004
+
+)clear all
+
+--S 1005 of 1034
+t0:=%e^(x^2)*x*sqrt(1-%e^(2*x^2))
+--R 
+--R
+--R               +-----------+
+--R             2 |      2
+--R            x  |    2x
+--R   (1)  x %e  \|- %e    + 1
+--R                                                    Type: Expression(Integer)
+--E 1005
+
+--S 1006 of 1034
+r0:=1/4*asin(%e^(x^2))+1/4*%e^(x^2)*sqrt(1-%e^(2*x^2))
+--R 
+--R
+--R             +-----------+
+--R           2 |      2                2
+--R          x  |    2x                x
+--R        %e  \|- %e    + 1  + asin(%e  )
+--R   (2)  -------------------------------
+--R                       4
+--R                                                    Type: Expression(Integer)
+--E 1006
+
+--S 1007 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                 +-------------+
+--R            +-------------+                      |      2 2
+--R            |      2 2             2 2           |     x
+--R            |     x               x             \|- (%e  )  + 1  - 1
+--R       (- 4\|- (%e  )  + 1  - 2(%e  )  + 4)atan(--------------------)
+--R                                                           2
+--R                                                          x
+--R                                                        %e
+--R     + 
+--R                         +-------------+
+--R            2 3       2  |      2 2             2 3       2
+--R           x         x   |     x               x         x
+--R       ((%e  )  - 2%e  )\|- (%e  )  + 1  - 2(%e  )  + 2%e
+--R  /
+--R       +-------------+
+--R       |      2 2             2 2
+--R       |     x               x
+--R     8\|- (%e  )  + 1  + 4(%e  )  - 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 1007
+
+--S 1008 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 +-------------+
+--R            +-------------+                      |      2 2
+--R            |      2 2             2 2           |     x
+--R            |     x               x             \|- (%e  )  + 1  - 1
+--R       (- 4\|- (%e  )  + 1  - 2(%e  )  + 4)atan(--------------------)
+--R                                                           2
+--R                                                          x
+--R                                                        %e
+--R     + 
+--R                +-----------+                                  +-------------+
+--R              2 |      2                 2        2 3       2  |      2 2
+--R             x  |    2x                 x        x         x   |     x
+--R       (- 2%e  \|- %e    + 1  - 2asin(%e  ) + (%e  )  - 2%e  )\|- (%e  )  + 1
+--R     + 
+--R                           +-----------+
+--R              2 3       2  |      2               2 2             2         2 3
+--R             x         x   |    2x               x               x         x
+--R       (- (%e  )  + 2%e  )\|- %e    + 1  + (- (%e  )  + 2)asin(%e  ) - 2(%e  )
+--R     + 
+--R           2
+--R          x
+--R       2%e
+--R  /
+--R       +-------------+
+--R       |      2 2             2 2
+--R       |     x               x
+--R     8\|- (%e  )  + 1  + 4(%e  )  - 8
+--R                                                    Type: Expression(Integer)
+--E 1008
+
+--S 1009 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1009
+
+)clear all
+
+--S 1010 of 1034
+t0:=%e^(x^3)*(1-%e^(4*x^3))^2*x^2
+--R 
+--R
+--R             3     3 2         3    3        3
+--R         2  x    4x        2  x   4x     2  x
+--R   (1)  x %e  (%e   )  - 2x %e  %e    + x %e
+--R                                                    Type: Expression(Integer)
+--E 1010
+
+--S 1011 of 1034
+r0:=1/3*%e^(x^3)-2/15*%e^(5*x^3)+1/27*%e^(9*x^3)
+--R 
+--R
+--R             3         3        3
+--R           9x        5x        x
+--R        5%e    - 18%e    + 45%e
+--R   (2)  -------------------------
+--R                   135
+--R                                                    Type: Expression(Integer)
+--E 1011
+
+--S 1012 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R             3 9         3 5        3
+--R            x           x          x
+--R        5(%e  )  - 18(%e  )  + 45%e
+--R   (3)  -----------------------------
+--R                     135
+--R                                         Type: Union(Expression(Integer),...)
+--E 1012
+
+--S 1013 of 1034
+m0:=a0-r0
+--R 
+--R
+--R               3         3        3 9         3 5
+--R             9x        5x        x           x
+--R        - 5%e    + 18%e    + 5(%e  )  - 18(%e  )
+--R   (4)  -----------------------------------------
+--R                           135
+--R                                                    Type: Expression(Integer)
+--E 1013
+
+--S 1014 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1014
+
+)clear all
+
+--S 1015 of 1034
+t0:=%e^(%e^x+x)
+--R 
+--R
+--R            x
+--R          %e  + x
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 1015
+
+--S 1016 of 1034
+r0:=%e^(%e^x)
+--R 
+--R
+--R            x
+--R          %e
+--R   (2)  %e
+--R                                                    Type: Expression(Integer)
+--E 1016
+
+--S 1017 of 1034
+--a0:=integrate(t0,x)
+--E 1017
+
+--S 1018 of 1034
+--m0:=a0-r0
+--E 1018
+
+--S 1019 of 1034
+--d0:=normalize(D(m0,x))
+--E 1019
+
+)clear all
+
+--S 1020 of 1034
+t0:=%e^(%e^(%e^x)+%e^x+x)
+--R 
+--R
+--R              x
+--R            %e      x
+--R          %e    + %e  + x
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 1020
+
+--S 1021 of 1034
+r0:=%e^(%e^(%e^x))
+--R 
+--R
+--R              x
+--R            %e
+--R          %e
+--R   (2)  %e
+--R                                                    Type: Expression(Integer)
+--E 1021
+
+--S 1022 of 1034
+--a0:=integrate(t0,x)
+--E 1022
+
+--S 1023 of 1034
+--m0:=a0-r0
+--E 1023
+
+--S 1024 of 1034
+--d0:=normalize(D(m0,x))
+--E 1024
+
+)clear all
+
+--S 1025 of 1034
+t0:=(1/%e^x+%e^x)^2
+--R 
+--R
+--R           x 4       x 2
+--R        (%e )  + 2(%e )  + 1
+--R   (1)  --------------------
+--R                  x 2
+--R               (%e )
+--R                                                    Type: Expression(Integer)
+--E 1025
+
+--S 1026 of 1034
+r0:=(-1/2)/%e^(2*x)+1/2*%e^(2*x)+2*x
+--R 
+--R
+--R           2x 2        2x
+--R        (%e  )  + 4x %e   - 1
+--R   (2)  ---------------------
+--R                   2x
+--R                2%e
+--R                                                    Type: Expression(Integer)
+--E 1026
+
+--S 1027 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x 4         x 2
+--R        (%e )  + 4x (%e )  - 1
+--R   (3)  ----------------------
+--R                    x 2
+--R                2(%e )
+--R                                         Type: Union(Expression(Integer),...)
+--E 1027
+
+--S 1028 of 1034
+m0:=a0-r0
+--R 
+--R
+--R             x 2   2x 2       x 4       2x      x 2
+--R        - (%e ) (%e  )  + ((%e )  - 1)%e   + (%e )
+--R   (4)  -------------------------------------------
+--R                            x 2  2x
+--R                        2(%e ) %e
+--R                                                    Type: Expression(Integer)
+--E 1028
+
+--S 1029 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1029
+
+)clear all
+
+--S 1030 of 1034
+t0:=1/(1/%e^x+%e^x)
+--R 
+--R
+--R              x
+--R            %e
+--R   (1)  ----------
+--R           x 2
+--R        (%e )  + 1
+--R                                                    Type: Expression(Integer)
+--E 1030
+
+--S 1031 of 1034
+r0:=atan(%e^x)
+--R 
+--R
+--R               x
+--R   (2)  atan(%e )
+--R                                                    Type: Expression(Integer)
+--E 1031
+
+--S 1032 of 1034
+a0:=integrate(t0,x)
+--R 
+--R
+--R               x
+--R   (3)  atan(%e )
+--R                                         Type: Union(Expression(Integer),...)
+--E 1032
+
+--S 1033 of 1034
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1033
+
+--S 1034 of 1034
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1034
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/rich25.input.pamphlet b/src/input/rich25.input.pamphlet
new file mode 100644
index 0000000..d55a5e6
--- /dev/null
+++ b/src/input/rich25.input.pamphlet
@@ -0,0 +1,59312 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich25.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Logarithm Functions
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f rich25.output
+)spool rich25.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 5341
+t0:=x^m*log(a*x^n)
+--R 
+--R
+--R         m       n
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 5341
+r0:=-n*x^(1+m)/(1+m)^2+x^(1+m)*log(a*x^n)/(1+m)
+--R 
+--R
+--R                m + 1       n       m + 1
+--R        (m + 1)x     log(a x ) - n x
+--R   (2)  ---------------------------------
+--R                    2
+--R                   m  + 2m + 1
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                     m log(x)
+--R        ((m + 1)n x log(x) + (m + 1)x log(a) - n x)%e
+--R   (3)  -----------------------------------------------------
+--R                              2
+--R                             m  + 2m + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 3
+
+--S 4 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 m + 1       n
+--R       (- m - 1)x     log(a x )
+--R     + 
+--R                                                    m log(x)      m + 1
+--R       ((m + 1)n x log(x) + (m + 1)x log(a) - n x)%e         + n x
+--R  /
+--R      2
+--R     m  + 2m + 1
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5
+
+)clear all
+
+--S 6 of 5341
+t0:=x^(-1+n)*log(a*x^n)
+--R 
+--R
+--R         n - 1       n
+--R   (1)  x     log(a x )
+--R                                                    Type: Expression(Integer)
+--E 6
+
+--S 7 of 5341
+r0:=-x^n/n+x^n*log(a*x^n)/n
+--R 
+--R
+--R         n       n     n
+--R        x log(a x ) - x
+--R   (2)  ----------------
+--R                n
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                 n log(x)
+--R        (n log(x) + log(a) - 1)%e
+--R   (3)  ---------------------------------
+--R                        n
+--R                                         Type: Union(Expression(Integer),...)
+--E 8
+
+--S 9 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           n       n                             n log(x)    n
+--R        - x log(a x ) + (n log(x) + log(a) - 1)%e         + x
+--R   (4)  ------------------------------------------------------
+--R                                   n
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 10
+
+)clear all
+
+--S 11 of 5341
+t0:=x^3*log(a*x^n)
+--R 
+--R
+--R         3       n
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 5341
+r0:=-1/16*n*x^4+1/4*x^4*log(a*x^n)
+--R 
+--R
+--R          4       n       4
+--R        4x log(a x ) - n x
+--R   (2)  -------------------
+--R                 16
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R            4           4            4
+--R        4n x log(x) + 4x log(a) - n x
+--R   (3)  ------------------------------
+--R                      16
+--R                                         Type: Union(Expression(Integer),...)
+--E 13
+
+--S 14 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           4       n       4          4
+--R        - x log(a x ) + n x log(x) + x log(a)
+--R   (4)  -------------------------------------
+--R                          4
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 5341
+t0:=x^2*log(a*x^n)
+--R 
+--R
+--R         2       n
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 5341
+r0:=-1/9*n*x^3+1/3*x^3*log(a*x^n)
+--R 
+--R
+--R          3       n       3
+--R        3x log(a x ) - n x
+--R   (2)  -------------------
+--R                 9
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3           3            3
+--R        3n x log(x) + 3x log(a) - n x
+--R   (3)  ------------------------------
+--R                       9
+--R                                         Type: Union(Expression(Integer),...)
+--E 18
+
+--S 19 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           3       n       3          3
+--R        - x log(a x ) + n x log(x) + x log(a)
+--R   (4)  -------------------------------------
+--R                          3
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 5341
+t0:=x*log(a*x^n)
+--R 
+--R
+--R                 n
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 5341
+r0:=-1/4*n*x^2+1/2*x^2*log(a*x^n)
+--R 
+--R
+--R          2       n       2
+--R        2x log(a x ) - n x
+--R   (2)  -------------------
+--R                 4
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2           2            2
+--R        2n x log(x) + 2x log(a) - n x
+--R   (3)  ------------------------------
+--R                       4
+--R                                         Type: Union(Expression(Integer),...)
+--E 23
+
+--S 24 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           2       n       2          2
+--R        - x log(a x ) + n x log(x) + x log(a)
+--R   (4)  -------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 25
+
+)clear all
+
+--S 26 of 5341
+t0:=log(a*x^n)
+--R 
+--R
+--R               n
+--R   (1)  log(a x )
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 5341
+r0:=-n*x+x*log(a*x^n)
+--R 
+--R
+--R                 n
+--R   (2)  x log(a x ) - n x
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  n x log(x) + x log(a) - n x
+--R                                         Type: Union(Expression(Integer),...)
+--E 28
+
+--S 29 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                   n
+--R   (4)  - x log(a x ) + n x log(x) + x log(a)
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 5341
+t0:=log(a*x^n)/x
+--R 
+--R
+--R               n
+--R        log(a x )
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 5341
+r0:=1/2*log(a*x^n)^2/n
+--R 
+--R
+--R               n 2
+--R        log(a x )
+--R   (2)  ----------
+--R            2n
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2
+--R        n log(x)  + 2log(a)log(x)
+--R   (3)  -------------------------
+--R                    2
+--R                                         Type: Union(Expression(Integer),...)
+--E 33
+
+--S 34 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                 n 2    2      2
+--R        - log(a x )  + n log(x)  + 2n log(a)log(x)
+--R   (4)  ------------------------------------------
+--R                            2n
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 35
+
+)clear all
+
+--S 36 of 5341
+t0:=log(a*x^n)/x^2
+--R 
+--R
+--R               n
+--R        log(a x )
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 5341
+r0:=-n/x-log(a*x^n)/x
+--R 
+--R
+--R                 n
+--R        - log(a x ) - n
+--R   (2)  ---------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - n log(x) - log(a) - n
+--R   (3)  -----------------------
+--R                   x
+--R                                         Type: Union(Expression(Integer),...)
+--E 38
+
+--S 39 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               n
+--R        log(a x ) - n log(x) - log(a)
+--R   (4)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 40
+
+)clear all
+
+--S 41 of 5341
+t0:=log(a*x^n)/x^3
+--R 
+--R
+--R               n
+--R        log(a x )
+--R   (1)  ---------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 5341
+r0:=-1/4*n/x^2-1/2*log(a*x^n)/x^2
+--R 
+--R
+--R                  n
+--R        - 2log(a x ) - n
+--R   (2)  ----------------
+--R                 2
+--R               4x
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 2n log(x) - 2log(a) - n
+--R   (3)  -------------------------
+--R                     2
+--R                   4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 43
+
+--S 44 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               n
+--R        log(a x ) - n log(x) - log(a)
+--R   (4)  -----------------------------
+--R                       2
+--R                     2x
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 5341
+t0:=x^m*log(a*x^n)^2
+--R 
+--R
+--R         m       n 2
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 5341
+r0:=2*n^2*x^(1+m)/(1+m)^3-2*n*x^(1+m)*log(a*x^n)/(1+m)^2+x^(1+m)*_
+   log(a*x^n)^2/(1+m)
+--R 
+--R
+--R   (2)
+--R     2           m + 1       n 2                m + 1       n      2 m + 1
+--R   (m  + 2m + 1)x     log(a x )  + (- 2m - 2)n x     log(a x ) + 2n x
+--R   -----------------------------------------------------------------------
+--R                               3     2
+--R                              m  + 3m  + 3m + 1
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2           2        2
+--R         (m  + 2m + 1)n x log(x)
+--R       + 
+--R             2                                  2
+--R         ((2m  + 4m + 2)n x log(a) + (- 2m - 2)n x)log(x)
+--R       + 
+--R           2                  2                            2
+--R         (m  + 2m + 1)x log(a)  + (- 2m - 2)n x log(a) + 2n x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      3     2
+--R     m  + 3m  + 3m + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 48
+
+--S 49 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2           m + 1       n 2              m + 1       n
+--R       (- m  - 2m - 1)x     log(a x )  + (2m + 2)n x     log(a x )
+--R     + 
+--R             2           2        2
+--R           (m  + 2m + 1)n x log(x)
+--R         + 
+--R               2                                  2
+--R           ((2m  + 4m + 2)n x log(a) + (- 2m - 2)n x)log(x)
+--R         + 
+--R             2                  2                            2
+--R           (m  + 2m + 1)x log(a)  + (- 2m - 2)n x log(a) + 2n x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           2 m + 1
+--R       - 2n x
+--R  /
+--R      3     2
+--R     m  + 3m  + 3m + 1
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 50
+
+)clear all
+
+--S 51 of 5341
+t0:=x^(-1+n)*log(a*x^n)^2
+--R 
+--R
+--R         n - 1       n 2
+--R   (1)  x     log(a x )
+--R                                                    Type: Expression(Integer)
+--E 51
+
+--S 52 of 5341
+r0:=2*x^n/n-2*x^n*log(a*x^n)/n+x^n*log(a*x^n)^2/n
+--R 
+--R
+--R         n       n 2     n       n      n
+--R        x log(a x )  - 2x log(a x ) + 2x
+--R   (2)  ---------------------------------
+--R                        n
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2      2                                  2                 n log(x)
+--R        (n log(x)  + (2n log(a) - 2n)log(x) + log(a)  - 2log(a) + 2)%e
+--R   (3)  ----------------------------------------------------------------------
+--R                                           n
+--R                                         Type: Union(Expression(Integer),...)
+--E 53
+
+--S 54 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          n       n 2     n       n
+--R       - x log(a x )  + 2x log(a x )
+--R     + 
+--R         2      2                                  2                 n log(x)
+--R       (n log(x)  + (2n log(a) - 2n)log(x) + log(a)  - 2log(a) + 2)%e
+--R     + 
+--R           n
+--R       - 2x
+--R  /
+--R     n
+--R                                                    Type: Expression(Integer)
+--E 54
+
+--S 55 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 55
+
+)clear all
+
+--S 56 of 5341
+t0:=x^3*log(a*x^n)^2
+--R 
+--R
+--R         3       n 2
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 5341
+r0:=1/32*n^2*x^4-1/8*n*x^4*log(a*x^n)+1/4*x^4*log(a*x^n)^2
+--R 
+--R
+--R          4       n 2       4       n     2 4
+--R        8x log(a x )  - 4n x log(a x ) + n x
+--R   (2)  -------------------------------------
+--R                          32
+--R                                                    Type: Expression(Integer)
+--E 57
+
+--S 58 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     2 4      2         4           2 4            4      2       4          2 4
+--R   8n x log(x)  + (16n x log(a) - 4n x )log(x) + 8x log(a)  - 4n x log(a) + n x
+--R   -----------------------------------------------------------------------------
+--R                                         32
+--R                                         Type: Union(Expression(Integer),...)
+--E 58
+
+--S 59 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           4       n 2      4       n      2 4      2
+--R       - 2x log(a x )  + n x log(a x ) + 2n x log(x)
+--R     + 
+--R            4          2 4            4      2      4
+--R       (4n x log(a) - n x )log(x) + 2x log(a)  - n x log(a)
+--R  /
+--R     8
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 5341
+t0:=x^2*log(a*x^n)^2
+--R 
+--R
+--R         2       n 2
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 5341
+r0:=2/27*n^2*x^3-2/9*n*x^3*log(a*x^n)+1/3*x^3*log(a*x^n)^2
+--R 
+--R
+--R          3       n 2       3       n      2 3
+--R        9x log(a x )  - 6n x log(a x ) + 2n x
+--R   (2)  --------------------------------------
+--R                          27
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2 3      2         3           2 3            3      2       3
+--R       9n x log(x)  + (18n x log(a) - 6n x )log(x) + 9x log(a)  - 6n x log(a)
+--R     + 
+--R         2 3
+--R       2n x
+--R  /
+--R     27
+--R                                         Type: Union(Expression(Integer),...)
+--E 63
+
+--S 64 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3       n 2       3       n      2 3      2
+--R       - 3x log(a x )  + 2n x log(a x ) + 3n x log(x)
+--R     + 
+--R            3           2 3            3      2       3
+--R       (6n x log(a) - 2n x )log(x) + 3x log(a)  - 2n x log(a)
+--R  /
+--R     9
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 65
+
+)clear all
+
+--S 66 of 5341
+t0:=x*log(a*x^n)^2
+--R 
+--R
+--R                 n 2
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 5341
+r0:=1/4*n^2*x^2-1/2*n*x^2*log(a*x^n)+1/2*x^2*log(a*x^n)^2
+--R 
+--R
+--R          2       n 2       2       n     2 2
+--R        2x log(a x )  - 2n x log(a x ) + n x
+--R   (2)  -------------------------------------
+--R                          4
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     2 2      2        2           2 2            2      2       2          2 2
+--R   2n x log(x)  + (4n x log(a) - 2n x )log(x) + 2x log(a)  - 2n x log(a) + n x
+--R   ----------------------------------------------------------------------------
+--R                                         4
+--R                                         Type: Union(Expression(Integer),...)
+--E 68
+
+--S 69 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          2       n 2      2       n     2 2      2        2          2 2
+--R       - x log(a x )  + n x log(a x ) + n x log(x)  + (2n x log(a) - n x )log(x)
+--R     + 
+--R        2      2      2
+--R       x log(a)  - n x log(a)
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 70
+
+)clear all
+
+--S 71 of 5341
+t0:=log(a*x^n)^2
+--R 
+--R
+--R               n 2
+--R   (1)  log(a x )
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 5341
+r0:=2*n^2*x-2*n*x*log(a*x^n)+x*log(a*x^n)^2
+--R 
+--R
+--R                 n 2               n      2
+--R   (2)  x log(a x )  - 2n x log(a x ) + 2n x
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R    2        2                    2                   2                   2
+--R   n x log(x)  + (2n x log(a) - 2n x)log(x) + x log(a)  - 2n x log(a) + 2n x
+--R                                         Type: Union(Expression(Integer),...)
+--E 73
+
+--S 74 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                n 2               n     2        2                    2
+--R     - x log(a x )  + 2n x log(a x ) + n x log(x)  + (2n x log(a) - 2n x)log(x)
+--R   + 
+--R             2
+--R     x log(a)  - 2n x log(a)
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 5341
+t0:=log(a*x^n)^2/x
+--R 
+--R
+--R               n 2
+--R        log(a x )
+--R   (1)  ----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 5341
+r0:=1/3*log(a*x^n)^3/n
+--R 
+--R
+--R               n 3
+--R        log(a x )
+--R   (2)  ----------
+--R            3n
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R         2      3                  2          2
+--R        n log(x)  + 3n log(a)log(x)  + 3log(a) log(x)
+--R   (3)  ---------------------------------------------
+--R                              3
+--R                                         Type: Union(Expression(Integer),...)
+--E 78
+
+--S 79 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                 n 3    3      3     2            2            2
+--R        - log(a x )  + n log(x)  + 3n log(a)log(x)  + 3n log(a) log(x)
+--R   (4)  --------------------------------------------------------------
+--R                                      3n
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 80
+
+)clear all
+
+--S 81 of 5341
+t0:=log(a*x^n)^2/x^2
+--R 
+--R
+--R               n 2
+--R        log(a x )
+--R   (1)  ----------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 5341
+r0:=-2*n^2/x-2*n*log(a*x^n)/x-log(a*x^n)^2/x
+--R 
+--R
+--R                 n 2             n      2
+--R        - log(a x )  - 2n log(a x ) - 2n
+--R   (2)  ---------------------------------
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2      2                    2                2                 2
+--R        - n log(x)  + (- 2n log(a) - 2n )log(x) - log(a)  - 2n log(a) - 2n
+--R   (3)  -------------------------------------------------------------------
+--R                                         x
+--R                                         Type: Union(Expression(Integer),...)
+--E 83
+
+--S 84 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              n 2             n     2      2                    2
+--R       log(a x )  + 2n log(a x ) - n log(x)  + (- 2n log(a) - 2n )log(x)
+--R     + 
+--R               2
+--R       - log(a)  - 2n log(a)
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 5341
+t0:=log(a*x^n)^2/x^3
+--R 
+--R
+--R               n 2
+--R        log(a x )
+--R   (1)  ----------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 5341
+r0:=-1/4*n^2/x^2-1/2*n*log(a*x^n)/x^2-1/2*log(a*x^n)^2/x^2
+--R 
+--R
+--R                  n 2             n     2
+--R        - 2log(a x )  - 2n log(a x ) - n
+--R   (2)  ---------------------------------
+--R                         2
+--R                       4x
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2      2                    2                 2                2
+--R        - 2n log(x)  + (- 4n log(a) - 2n )log(x) - 2log(a)  - 2n log(a) - n
+--R   (3)  --------------------------------------------------------------------
+--R                                           2
+--R                                         4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 88
+
+--S 89 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              n 2            n     2      2                   2                2
+--R       log(a x )  + n log(a x ) - n log(x)  + (- 2n log(a) - n )log(x) - log(a)
+--R     + 
+--R       - n log(a)
+--R  /
+--R       2
+--R     2x
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 5341
+t0:=x^m*log(a*x^n)^3
+--R 
+--R
+--R         m       n 3
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 5341
+r0:=-6*n^3*x^(1+m)/(1+m)^4+6*n^2*x^(1+m)*log(a*x^n)/(1+m)^3-3*n*x^(1+m)*_
+   log(a*x^n)^2/(1+m)^2+x^(1+m)*log(a*x^n)^3/(1+m)
+--R 
+--R
+--R   (2)
+--R         3     2           m + 1       n 3        2             m + 1       n 2
+--R       (m  + 3m  + 3m + 1)x     log(a x )  + (- 3m  - 6m - 3)n x     log(a x )
+--R     + 
+--R                2 m + 1       n      3 m + 1
+--R       (6m + 6)n x     log(a x ) - 6n x
+--R  /
+--R      4     3     2
+--R     m  + 4m  + 6m  + 4m + 1
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3     2           3        3
+--R         (m  + 3m  + 3m + 1)n x log(x)
+--R       + 
+--R             3     2           2                2           3        2
+--R         ((3m  + 9m  + 9m + 3)n x log(a) + (- 3m  - 6m - 3)n x)log(x)
+--R       + 
+--R                3     2                    2        2            2
+--R             (3m  + 9m  + 9m + 3)n x log(a)  + (- 6m  - 12m - 6)n x log(a)
+--R           + 
+--R                      3
+--R             (6m + 6)n x
+--R        *
+--R           log(x)
+--R       + 
+--R           3     2                  3        2                    2
+--R         (m  + 3m  + 3m + 1)x log(a)  + (- 3m  - 6m - 3)n x log(a)
+--R       + 
+--R                  2             3
+--R         (6m + 6)n x log(a) - 6n x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      4     3     2
+--R     m  + 4m  + 6m  + 4m + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 93
+
+--S 94 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3     2           m + 1       n 3      2             m + 1       n 2
+--R       (- m  - 3m  - 3m - 1)x     log(a x )  + (3m  + 6m + 3)n x     log(a x )
+--R     + 
+--R                  2 m + 1       n
+--R       (- 6m - 6)n x     log(a x )
+--R     + 
+--R             3     2           3        3
+--R           (m  + 3m  + 3m + 1)n x log(x)
+--R         + 
+--R               3     2           2                2           3        2
+--R           ((3m  + 9m  + 9m + 3)n x log(a) + (- 3m  - 6m - 3)n x)log(x)
+--R         + 
+--R                  3     2                    2        2            2
+--R               (3m  + 9m  + 9m + 3)n x log(a)  + (- 6m  - 12m - 6)n x log(a)
+--R             + 
+--R                        3
+--R               (6m + 6)n x
+--R          *
+--R             log(x)
+--R         + 
+--R             3     2                  3        2                    2
+--R           (m  + 3m  + 3m + 1)x log(a)  + (- 3m  - 6m - 3)n x log(a)
+--R         + 
+--R                    2             3
+--R           (6m + 6)n x log(a) - 6n x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R         3 m + 1
+--R       6n x
+--R  /
+--R      4     3     2
+--R     m  + 4m  + 6m  + 4m + 1
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 95
+
+)clear all
+
+--S 96 of 5341
+t0:=x^(-1+n)*log(a*x^n)^3
+--R 
+--R
+--R         n - 1       n 3
+--R   (1)  x     log(a x )
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 5341
+r0:=-6*x^n/n+6*x^n*log(a*x^n)/n-3*x^n*log(a*x^n)^2/n+x^n*log(a*x^n)^3/n
+--R 
+--R
+--R         n       n 3     n       n 2     n       n      n
+--R        x log(a x )  - 3x log(a x )  + 6x log(a x ) - 6x
+--R   (2)  -------------------------------------------------
+--R                                n
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3      3      2           2       2
+--R         n log(x)  + (3n log(a) - 3n )log(x)
+--R       + 
+--R                   2                                 3          2
+--R         (3n log(a)  - 6n log(a) + 6n)log(x) + log(a)  - 3log(a)  + 6log(a) - 6
+--R    *
+--R         n log(x)
+--R       %e
+--R  /
+--R     n
+--R                                         Type: Union(Expression(Integer),...)
+--E 98
+
+--S 99 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          n       n 3     n       n 2     n       n
+--R       - x log(a x )  + 3x log(a x )  - 6x log(a x )
+--R     + 
+--R            3      3      2           2       2
+--R           n log(x)  + (3n log(a) - 3n )log(x)
+--R         + 
+--R                   2                                 3          2
+--R         (3n log(a)  - 6n log(a) + 6n)log(x) + log(a)  - 3log(a)  + 6log(a) - 6
+--R      *
+--R           n log(x)
+--R         %e
+--R     + 
+--R         n
+--R       6x
+--R  /
+--R     n
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 100
+
+)clear all
+
+--S 101 of 5341
+t0:=x^3*log(a*x^n)^3
+--R 
+--R
+--R         3       n 3
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 5341
+r0:=-3/128*n^3*x^4+3/32*n^2*x^4*log(a*x^n)-3/16*n*x^4*log(a*x^n)^2+_
+   1/4*x^4*log(a*x^n)^3
+--R 
+--R
+--R           4       n 3        4       n 2      2 4       n      3 4
+--R        32x log(a x )  - 24n x log(a x )  + 12n x log(a x ) - 3n x
+--R   (2)  -----------------------------------------------------------
+--R                                    128
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3 4      3       2 4            3 4       2
+--R       32n x log(x)  + (96n x log(a) - 24n x )log(x)
+--R     + 
+--R             4      2      2 4            3 4             4      3
+--R       (96n x log(a)  - 48n x log(a) + 12n x )log(x) + 32x log(a)
+--R     + 
+--R              4      2      2 4           3 4
+--R       - 24n x log(a)  + 12n x log(a) - 3n x
+--R  /
+--R     128
+--R                                         Type: Union(Expression(Integer),...)
+--E 103
+
+--S 104 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           4       n 3       4       n 2     2 4       n      3 4      3
+--R       - 8x log(a x )  + 6n x log(a x )  - 3n x log(a x ) + 8n x log(x)
+--R     + 
+--R           2 4           3 4       2
+--R       (24n x log(a) - 6n x )log(x)
+--R     + 
+--R             4      2      2 4           3 4            4      3       4      2
+--R       (24n x log(a)  - 12n x log(a) + 3n x )log(x) + 8x log(a)  - 6n x log(a)
+--R     + 
+--R         2 4
+--R       3n x log(a)
+--R  /
+--R     32
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 5341
+t0:=x^2*log(a*x^n)^3
+--R 
+--R
+--R         2       n 3
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 5341
+r0:=-2/27*n^3*x^3+2/9*n^2*x^3*log(a*x^n)-1/3*n*x^3*log(a*x^n)^2+_
+   1/3*x^3*log(a*x^n)^3
+--R 
+--R
+--R          3       n 3       3       n 2     2 3       n      3 3
+--R        9x log(a x )  - 9n x log(a x )  + 6n x log(a x ) - 2n x
+--R   (2)  --------------------------------------------------------
+--R                                   27
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3 3      3       2 3           3 3       2
+--R       9n x log(x)  + (27n x log(a) - 9n x )log(x)
+--R     + 
+--R             3      2      2 3           3 3            3      3       3      2
+--R       (27n x log(a)  - 18n x log(a) + 6n x )log(x) + 9x log(a)  - 9n x log(a)
+--R     + 
+--R         2 3           3 3
+--R       6n x log(a) - 2n x
+--R  /
+--R     27
+--R                                         Type: Union(Expression(Integer),...)
+--E 108
+
+--S 109 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3       n 3       3       n 2     2 3       n      3 3      3
+--R       - 3x log(a x )  + 3n x log(a x )  - 2n x log(a x ) + 3n x log(x)
+--R     + 
+--R          2 3           3 3       2        3      2     2 3           3 3
+--R       (9n x log(a) - 3n x )log(x)  + (9n x log(a)  - 6n x log(a) + 2n x )log(x)
+--R     + 
+--R         3      3       3      2     2 3
+--R       3x log(a)  - 3n x log(a)  + 2n x log(a)
+--R  /
+--R     9
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 110
+
+)clear all
+
+--S 111 of 5341
+t0:=x*log(a*x^n)^3
+--R 
+--R
+--R                 n 3
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 5341
+r0:=-3/8*n^3*x^2+3/4*n^2*x^2*log(a*x^n)-3/4*n*x^2*log(a*x^n)^2+_
+   1/2*x^2*log(a*x^n)^3
+--R 
+--R
+--R          2       n 3       2       n 2     2 2       n      3 2
+--R        4x log(a x )  - 6n x log(a x )  + 6n x log(a x ) - 3n x
+--R   (2)  --------------------------------------------------------
+--R                                    8
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3 2      3       2 2           3 2       2
+--R       4n x log(x)  + (12n x log(a) - 6n x )log(x)
+--R     + 
+--R             2      2      2 2           3 2            2      3       2      2
+--R       (12n x log(a)  - 12n x log(a) + 6n x )log(x) + 4x log(a)  - 6n x log(a)
+--R     + 
+--R         2 2           3 2
+--R       6n x log(a) - 3n x
+--R  /
+--R     8
+--R                                         Type: Union(Expression(Integer),...)
+--E 113
+
+--S 114 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2       n 3       2       n 2     2 2       n      3 2      3
+--R       - 2x log(a x )  + 3n x log(a x )  - 3n x log(a x ) + 2n x log(x)
+--R     + 
+--R          2 2           3 2       2        2      2     2 2           3 2
+--R       (6n x log(a) - 3n x )log(x)  + (6n x log(a)  - 6n x log(a) + 3n x )log(x)
+--R     + 
+--R         2      3       2      2     2 2
+--R       2x log(a)  - 3n x log(a)  + 3n x log(a)
+--R  /
+--R     4
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 115
+
+)clear all
+
+--S 116 of 5341
+t0:=log(a*x^n)^3
+--R 
+--R
+--R               n 3
+--R   (1)  log(a x )
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 5341
+r0:=-6*n^3*x+6*n^2*x*log(a*x^n)-3*n*x*log(a*x^n)^2+x*log(a*x^n)^3
+--R 
+--R
+--R                 n 3               n 2     2         n      3
+--R   (2)  x log(a x )  - 3n x log(a x )  + 6n x log(a x ) - 6n x
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      3        3      2             3        2
+--R     n x log(x)  + (3n x log(a) - 3n x)log(x)
+--R   + 
+--R                 2     2             3                   3              2
+--R     (3n x log(a)  - 6n x log(a) + 6n x)log(x) + x log(a)  - 3n x log(a)
+--R   + 
+--R       2             3
+--R     6n x log(a) - 6n x
+--R                                         Type: Union(Expression(Integer),...)
+--E 118
+
+--S 119 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                n 3               n 2     2         n     3        3
+--R     - x log(a x )  + 3n x log(a x )  - 6n x log(a x ) + n x log(x)
+--R   + 
+--R        2             3        2               2     2             3
+--R     (3n x log(a) - 3n x)log(x)  + (3n x log(a)  - 6n x log(a) + 6n x)log(x)
+--R   + 
+--R             3              2     2
+--R     x log(a)  - 3n x log(a)  + 6n x log(a)
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 5341
+t0:=log(a*x^n)^3/x
+--R 
+--R
+--R               n 3
+--R        log(a x )
+--R   (1)  ----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 5341
+r0:=1/4*log(a*x^n)^4/n
+--R 
+--R
+--R               n 4
+--R        log(a x )
+--R   (2)  ----------
+--R            4n
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R         3      4     2            3            2      2          3
+--R        n log(x)  + 4n log(a)log(x)  + 6n log(a) log(x)  + 4log(a) log(x)
+--R   (3)  -----------------------------------------------------------------
+--R                                        4
+--R                                         Type: Union(Expression(Integer),...)
+--E 123
+
+--S 124 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                n 4    4      4     3            3     2      2      2
+--R       - log(a x )  + n log(x)  + 4n log(a)log(x)  + 6n log(a) log(x)
+--R     + 
+--R                3
+--R       4n log(a) log(x)
+--R  /
+--R     4n
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 125
+
+)clear all
+
+--S 126 of 5341
+t0:=log(a*x^n)^3/x^2
+--R 
+--R
+--R               n 3
+--R        log(a x )
+--R   (1)  ----------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 5341
+r0:=-6*n^3/x-6*n^2*log(a*x^n)/x-3*n*log(a*x^n)^2/x-log(a*x^n)^3/x
+--R 
+--R
+--R                 n 3             n 2     2       n      3
+--R        - log(a x )  - 3n log(a x )  - 6n log(a x ) - 6n
+--R   (2)  -------------------------------------------------
+--R                                x
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3      3        2           3       2
+--R       - n log(x)  + (- 3n log(a) - 3n )log(x)
+--R     + 
+--R                   2     2           3                3            2     2
+--R       (- 3n log(a)  - 6n log(a) - 6n )log(x) - log(a)  - 3n log(a)  - 6n log(a)
+--R     + 
+--R           3
+--R       - 6n
+--R  /
+--R     x
+--R                                         Type: Union(Expression(Integer),...)
+--E 128
+
+--S 129 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              n 3             n 2     2       n     3      3
+--R       log(a x )  + 3n log(a x )  + 6n log(a x ) - n log(x)
+--R     + 
+--R            2           3       2               2     2           3
+--R       (- 3n log(a) - 3n )log(x)  + (- 3n log(a)  - 6n log(a) - 6n )log(x)
+--R     + 
+--R               3            2     2
+--R       - log(a)  - 3n log(a)  - 6n log(a)
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 130
+
+)clear all
+
+--S 131 of 5341
+t0:=log(a*x^n)^3/x^3
+--R 
+--R
+--R               n 3
+--R        log(a x )
+--R   (1)  ----------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 5341
+r0:=-3/8*n^3/x^2-3/4*n^2*log(a*x^n)/x^2-3/4*n*log(a*x^n)^2/x^2-_
+   1/2*log(a*x^n)^3/x^2
+--R 
+--R
+--R                  n 3             n 2     2       n      3
+--R        - 4log(a x )  - 6n log(a x )  - 6n log(a x ) - 3n
+--R   (2)  --------------------------------------------------
+--R                                  2
+--R                                8x
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3      3         2           3       2
+--R       - 4n log(x)  + (- 12n log(a) - 6n )log(x)
+--R     + 
+--R                    2      2           3                 3            2
+--R       (- 12n log(a)  - 12n log(a) - 6n )log(x) - 4log(a)  - 6n log(a)
+--R     + 
+--R           2           3
+--R       - 6n log(a) - 3n
+--R  /
+--R       2
+--R     8x
+--R                                         Type: Union(Expression(Integer),...)
+--E 133
+
+--S 134 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               n 3             n 2     2       n      3      3
+--R       2log(a x )  + 3n log(a x )  + 3n log(a x ) - 2n log(x)
+--R     + 
+--R            2           3       2               2     2           3
+--R       (- 6n log(a) - 3n )log(x)  + (- 6n log(a)  - 6n log(a) - 3n )log(x)
+--R     + 
+--R                3            2     2
+--R       - 2log(a)  - 3n log(a)  - 3n log(a)
+--R  /
+--R       2
+--R     4x
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 5341
+t0:=x^(5/2)*log(a*x)
+--R 
+--R
+--R         2         +-+
+--R   (1)  x log(a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 5341
+r0:=-4/49*x^(7/2)+2/7*x^(7/2)*log(a*x)
+--R 
+--R
+--R            3             3  +-+
+--R        (14x log(a x) - 4x )\|x
+--R   (2)  ------------------------
+--R                   49
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R            3             3  +-+
+--R        (14x log(a x) - 4x )\|x
+--R   (3)  ------------------------
+--R                   49
+--R                                         Type: Union(Expression(Integer),...)
+--E 138
+
+--S 139 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 140
+
+)clear all
+
+--S 141 of 5341
+t0:=x^(3/2)*log(a*x)
+--R 
+--R
+--R                   +-+
+--R   (1)  x log(a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 5341
+r0:=-4/25*x^(5/2)+2/5*x^(5/2)*log(a*x)
+--R 
+--R
+--R            2             2  +-+
+--R        (10x log(a x) - 4x )\|x
+--R   (2)  ------------------------
+--R                   25
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2             2  +-+
+--R        (10x log(a x) - 4x )\|x
+--R   (3)  ------------------------
+--R                   25
+--R                                         Type: Union(Expression(Integer),...)
+--E 143
+
+--S 144 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 145
+
+)clear all
+
+--S 146 of 5341
+t0:=x^(1/2)*log(a*x)
+--R 
+--R
+--R                 +-+
+--R   (1)  log(a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 5341
+r0:=-4/9*x^(3/2)+2/3*x^(3/2)*log(a*x)
+--R 
+--R
+--R                           +-+
+--R        (6x log(a x) - 4x)\|x
+--R   (2)  ----------------------
+--R                   9
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           +-+
+--R        (6x log(a x) - 4x)\|x
+--R   (3)  ----------------------
+--R                   9
+--R                                         Type: Union(Expression(Integer),...)
+--E 148
+
+--S 149 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 5341
+t0:=log(a*x)/x^(1/2)
+--R 
+--R
+--R        log(a x)
+--R   (1)  --------
+--R           +-+
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 5341
+r0:=-4*sqrt(x)+2*log(a*x)*sqrt(x)
+--R 
+--R
+--R                        +-+
+--R   (2)  (2log(a x) - 4)\|x
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        +-+
+--R   (3)  (2log(a x) - 4)\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 153
+
+--S 154 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 155
+
+)clear all
+
+--S 156 of 5341
+t0:=log(a*x)/x^(3/2)
+--R 
+--R
+--R        log(a x)
+--R   (1)  --------
+--R            +-+
+--R          x\|x
+--R                                                    Type: Expression(Integer)
+--E 156
+
+--S 157 of 5341
+r0:=(-4)/sqrt(x)-2*log(a*x)/sqrt(x)
+--R 
+--R
+--R        - 2log(a x) - 4
+--R   (2)  ---------------
+--R               +-+
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 2log(a x) - 4
+--R   (3)  ---------------
+--R               +-+
+--R              \|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 158
+
+--S 159 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 160
+
+)clear all
+
+--S 161 of 5341
+t0:=log(a*x)/x^(5/2)
+--R 
+--R
+--R        log(a x)
+--R   (1)  --------
+--R          2 +-+
+--R         x \|x
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 5341
+r0:=(-4/9)/x^(3/2)-2/3*log(a*x)/x^(3/2)
+--R 
+--R
+--R        - 6log(a x) - 4
+--R   (2)  ---------------
+--R                +-+
+--R             9x\|x
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 6log(a x) - 4
+--R   (3)  ---------------
+--R                +-+
+--R             9x\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 163
+
+--S 164 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 5341
+t0:=x^m/log(a*x^n)
+--R 
+--R
+--R             m
+--R            x
+--R   (1)  ---------
+--R               n
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 5341
+--r0:=x^(1+m)*Ei((1+m)*log(a*x^n)/n)/(n*(a*x^n)^((1+m)/n))
+--E 167
+
+--S 168 of 5341
+--a0:=integrate(t0,x)
+--E 168
+
+--S 169 of 5341
+--m0:=a0-r0
+--E 169
+
+--S 170 of 5341
+--d0:=D(m0,x)
+--E 170
+
+)clear all
+
+--S 171 of 5341
+t0:=x^(-1+n)/log(a*x^n)
+--R 
+--R
+--R           n - 1
+--R          x
+--R   (1)  ---------
+--R               n
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 5341
+--r0:=Li(a*x^n)/(a*n)
+--E 172
+
+--S 173 of 5341
+--a0:=integrate(t0,x)
+--E 173
+
+--S 174 of 5341
+--m0:=a0-r0
+--E 174
+
+--S 175 of 5341
+--d0:=D(m0,x)
+--E 175
+
+)clear all
+
+--S 176 of 5341
+t0:=x^3/log(a*x^n)
+--R 
+--R
+--R             3
+--R            x
+--R   (1)  ---------
+--R               n
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 5341
+--r0:=x^4*Ei(4*log(a*x^n)/n)/(n*(a*x^n)^(4/n))
+--E 177
+
+--S 178 of 5341
+--a0:=integrate(t0,x)
+--E 178
+
+--S 179 of 5341
+--m0:=a0-r0
+--E 179
+
+--S 180 of 5341
+--d0:=D(m0,x)
+--E 180
+
+)clear all
+
+--S 181 of 5341
+t0:=x^2/log(a*x^n)
+--R 
+--R
+--R             2
+--R            x
+--R   (1)  ---------
+--R               n
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 5341
+--r0:=x^3*Ei(3*log(a*x^n)/n)/(n*(a*x^n)^(3/n))
+--E 182
+
+--S 183 of 5341
+--a0:=integrate(t0,x)
+--E 183
+
+--S 184 of 5341
+--m0:=a0-r0
+--E 184
+
+--S 185 of 5341
+--d0:=D(m0,x)
+--E 185
+
+)clear all
+
+--S 186 of 5341
+t0:=x/log(a*x^n)
+--R 
+--R
+--R            x
+--R   (1)  ---------
+--R               n
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 5341
+--r0:=x^2*Ei(2*log(a*x^n)/n)/(n*(a*x^n)^(2/n))
+--E 187
+
+--S 188 of 5341
+--a0:=integrate(t0,x)
+--E 188
+
+--S 189 of 5341
+--m0:=a0-r0
+--E 189
+
+--S 190 of 5341
+--d0:=D(m0,x)
+--E 190
+
+)clear all
+
+--S 191 of 5341
+t0:=1/log(a*x^n)
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R               n
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 5341
+--r0:=x*Ei(log(a*x^n)/n)/(n*(a*x^n)^(1/n))
+--E 192
+
+--S 193 of 5341
+--a0:=integrate(t0,x)
+--E 193
+
+--S 194 of 5341
+--m0:=a0-r0
+--E 194
+
+--S 195 of 5341
+--d0:=D(m0,x)
+--E 195
+
+)clear all
+
+--S 196 of 5341
+t0:=1/(x*log(a*x^n))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R                 n
+--R        x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 5341
+r0:=log(log(a*x^n))/n
+--R 
+--R
+--R                   n
+--R        log(log(a x ))
+--R   (2)  --------------
+--R               n
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(n log(x) + log(a))
+--R   (3)  ----------------------
+--R                   n
+--R                                         Type: Union(Expression(Integer),...)
+--E 198
+
+--S 199 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                     n
+--R        - log(log(a x )) + log(n log(x) + log(a))
+--R   (4)  -----------------------------------------
+--R                            n
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 200
+
+)clear all
+
+--S 201 of 5341
+t0:=1/(x^2*log(a*x^n))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         2       n
+--R        x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 5341
+--r0:=(a*x^n)^(1/n)*Ei(-log(a*x^n)/n)/(n*x)
+--E 202
+
+--S 203 of 5341
+--a0:=integrate(t0,x)
+--E 203
+
+--S 204 of 5341
+--m0:=a0-r0
+--E 204
+
+--S 205 of 5341
+--d0:=D(m0,x)
+--E 205
+
+)clear all
+
+--S 206 of 5341
+t0:=1/(x^3*log(a*x^n))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         3       n
+--R        x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 5341
+--r0:=(a*x^n)^(2/n)*Ei(-2*log(a*x^n)/n)/(n*x^2)
+--E 207
+
+--S 208 of 5341
+--a0:=integrate(t0,x)
+--E 208
+
+--S 209 of 5341
+--m0:=a0-r0
+--E 209
+
+--S 210 of 5341
+--d0:=D(m0,x)
+--E 210
+
+)clear all
+
+--S 211 of 5341
+t0:=x^m/log(a*x^n)^2
+--R 
+--R
+--R             m
+--R            x
+--R   (1)  ----------
+--R               n 2
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 5341
+--r0:=(1+m)*x^(1+m)*Ei((1+m)*log(a*x^n)/n)/(n^2*(a*x^n)^((1+m)/n))-_
+--   x^(1+m)/(n*log(a*x^n))
+--E 212
+
+--S 213 of 5341
+--a0:=integrate(t0,x)
+--E 213
+
+--S 214 of 5341
+--m0:=a0-r0
+--E 214
+
+--S 215 of 5341
+--d0:=D(m0,x)
+--E 215
+
+)clear all
+
+--S 216 of 5341
+t0:=x^(-1+n)/log(a*x^n)^2
+--R 
+--R
+--R           n - 1
+--R          x
+--R   (1)  ----------
+--R               n 2
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 5341
+--r0:=Li(a*x^n)/(a*n)-x^n/(n*log(a*x^n))
+--E 217
+
+--S 218 of 5341
+--a0:=integrate(t0,x)
+--E 218
+
+--S 219 of 5341
+--m0:=a0-r0
+--E 219
+
+--S 220 of 5341
+--d0:=D(m0,x)
+--E 220
+
+)clear all
+
+--S 221 of 5341
+t0:=x^3/log(a*x^n)^2
+--R 
+--R
+--R             3
+--R            x
+--R   (1)  ----------
+--R               n 2
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 5341
+--r0:=4*x^4*Ei(4*log(a*x^n)/n)/(n^2*(a*x^n)^(4/n))-x^4/(n*log(a*x^n))
+--E 222
+
+--S 223 of 5341
+--a0:=integrate(t0,x)
+--E 223
+
+--S 224 of 5341
+--m0:=a0-r0
+--E 224
+
+--S 225 of 5341
+--d0:=D(m0,x)
+--E 225
+
+)clear all
+
+--S 226 of 5341
+t0:=x^2/log(a*x^n)^2
+--R 
+--R
+--R             2
+--R            x
+--R   (1)  ----------
+--R               n 2
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 5341
+--r0:=3*x^3*Ei(3*log(a*x^n)/n)/(n^2*(a*x^n)^(3/n))-x^3/(n*log(a*x^n))
+--E 227
+
+--S 228 of 5341
+--a0:=integrate(t0,x)
+--E 228
+
+--S 229 of 5341
+--m0:=a0-r0
+--E 229
+
+--S 230 of 5341
+--d0:=D(m0,x)
+--E 230
+
+)clear all
+
+--S 231 of 5341
+t0:=x/log(a*x^n)^2
+--R 
+--R
+--R             x
+--R   (1)  ----------
+--R               n 2
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 5341
+--r0:=2*x^2*Ei(2*log(a*x^n)/n)/(n^2*(a*x^n)^(2/n))-x^2/(n*log(a*x^n))
+--E 232
+
+--S 233 of 5341
+--a0:=integrate(t0,x)
+--E 233
+
+--S 234 of 5341
+--m0:=a0-r0
+--E 234
+
+--S 235 of 5341
+--d0:=D(m0,x)
+--E 235
+
+)clear all
+
+--S 236 of 5341
+t0:=1/log(a*x^n)^2
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R               n 2
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 5341
+--r0:=x*Ei(log(a*x^n)/n)/(n^2*(a*x^n)^(1/n))-x/(n*log(a*x^n))
+--E 237
+
+--S 238 of 5341
+--a0:=integrate(t0,x)
+--E 238
+
+--S 239 of 5341
+--m0:=a0-r0
+--E 239
+
+--S 240 of 5341
+--d0:=D(m0,x)
+--E 240
+
+)clear all
+
+--S 241 of 5341
+t0:=1/(x*log(a*x^n)^2)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R                 n 2
+--R        x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 5341
+r0:=(-1)/(n*log(a*x^n))
+--R 
+--R
+--R               1
+--R   (2)  - -----------
+--R                   n
+--R          n log(a x )
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   1
+--R   (3)  - -------------------
+--R           2
+--R          n log(x) + n log(a)
+--R                                         Type: Union(Expression(Integer),...)
+--E 243
+
+--S 244 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                 n
+--R        - log(a x ) + n log(x) + log(a)
+--R   (4)  -------------------------------
+--R           2                         n
+--R         (n log(x) + n log(a))log(a x )
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 245
+
+)clear all
+
+--S 246 of 5341
+t0:=1/(x^2*log(a*x^n)^2)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         2       n 2
+--R        x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 5341
+--r0:=-(a*x^n)^(1/n)*Ei(-log(a*x^n)/n)/(n^2*x)+(-1)/(n*x*log(a*x^n))
+--E 247
+
+--S 248 of 5341
+--a0:=integrate(t0,x)
+--E 248
+
+--S 249 of 5341
+--m0:=a0-r0
+--E 249
+
+--S 250 of 5341
+--d0:=D(m0,x)
+--E 250
+
+)clear all
+
+--S 251 of 5341
+t0:=1/(x^3*log(a*x^n)^2)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         3       n 2
+--R        x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 5341
+--r0:=-2*(a*x^n)^(2/n)*Ei(-2*log(a*x^n)/n)/(n^2*x^2)+(-1)/(n*x^2*log(a*x^n))
+--E 252
+
+--S 253 of 5341
+--a0:=integrate(t0,x)
+--E 253
+
+--S 254 of 5341
+--m0:=a0-r0
+--E 254
+
+--S 255 of 5341
+--d0:=D(m0,x)
+--E 255
+
+)clear all
+
+--S 256 of 5341
+t0:=x^m/log(a*x^n)^3
+--R 
+--R
+--R             m
+--R            x
+--R   (1)  ----------
+--R               n 3
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 5341
+--r0:=1/2*(1+m)^2*x^(1+m)*Ei((1+m)*log(a*x^n)/n)/(n^3*(a*x^n)^((1+m)/n))-_
+--   1/2*x^(1+m)/(n*log(a*x^n)^2)-1/2*(1+m)*x^(1+m)/(n^2*log(a*x^n))
+--E 257
+
+--S 258 of 5341
+--a0:=integrate(t0,x)
+--E 258
+
+--S 259 of 5341
+--m0:=a0-r0
+--E 259
+
+--S 260 of 5341
+--d0:=D(m0,x)
+--E 260
+
+)clear all
+
+--S 261 of 5341
+t0:=x^(-1+n)/log(a*x^n)^3
+--R 
+--R
+--R           n - 1
+--R          x
+--R   (1)  ----------
+--R               n 3
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 5341
+--r0:=1/2*Li(a*x^n)/(a*n)-1/2*x^n/(n*log(a*x^n)^2)-1/2*x^n/(n*log(a*x^n))
+--E 262
+
+--S 263 of 5341
+--a0:=integrate(t0,x)
+--E 263
+
+--S 264 of 5341
+--m0:=a0-r0
+--E 264
+
+--S 265 of 5341
+--d0:=D(m0,x)
+--E 265
+
+)clear all
+
+--S 266 of 5341
+t0:=x^3/log(a*x^n)^3
+--R 
+--R
+--R             3
+--R            x
+--R   (1)  ----------
+--R               n 3
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 5341
+--r0:=8*x^4*Ei(4*log(a*x^n)/n)/(n^3*(a*x^n)^(4/n))-1/2*x^4/(n*log(a*x^n)^2)-_
+--   2*x^4/(n^2*log(a*x^n))
+--E 267
+
+--S 268 of 5341
+--a0:=integrate(t0,x)
+--E 268
+
+--S 269 of 5341
+--m0:=a0-r0
+--E 269
+
+--S 270 of 5341
+--d0:=D(m0,x)
+--E 270
+
+)clear all
+
+--S 271 of 5341
+t0:=x^2/log(a*x^n)^3
+--R 
+--R
+--R             2
+--R            x
+--R   (1)  ----------
+--R               n 3
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 5341
+--r0:=9/2*x^3*Ei(3*log(a*x^n)/n)/(n^3*(a*x^n)^(3/n))-1/2*x^3/(n*_
+--   log(a*x^n)^2)-3/2*x^3/(n^2*log(a*x^n))
+--E 272
+
+--S 273 of 5341
+--a0:=integrate(t0,x)
+--E 273
+
+--S 274 of 5341
+--m0:=a0-r0
+--E 274
+
+--S 275 of 5341
+--d0:=D(m0,x)
+--E 275
+
+)clear all
+
+--S 276 of 5341
+t0:=x/log(a*x^n)^3
+--R 
+--R
+--R             x
+--R   (1)  ----------
+--R               n 3
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 5341
+--r0:=2*x^2*Ei(2*log(a*x^n)/n)/(n^3*(a*x^n)^(2/n))-1/2*x^2/(n*log(a*x^n)^2)-_
+--   x^2/(n^2*log(a*x^n))
+--E 277
+
+--S 278 of 5341
+--a0:=integrate(t0,x)
+--E 278
+
+--S 279 of 5341
+--m0:=a0-r0
+--E 279
+
+--S 280 of 5341
+--d0:=D(m0,x)
+--E 280
+
+)clear all
+
+--S 281 of 5341
+t0:=1/log(a*x^n)^3
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R               n 3
+--R        log(a x )
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 5341
+--r0:=1/2*x*Ei(log(a*x^n)/n)/(n^3*(a*x^n)^(1/n))-1/2*x/(n*log(a*x^n)^2)-_
+--   1/2*x/(n^2*log(a*x^n))
+--E 282
+
+--S 283 of 5341
+--a0:=integrate(t0,x)
+--E 283
+
+--S 284 of 5341
+--m0:=a0-r0
+--E 284
+
+--S 285 of 5341
+--d0:=D(m0,x)
+--E 285
+
+)clear all
+
+--S 286 of 5341
+t0:=1/(x*log(a*x^n)^3)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R                 n 3
+--R        x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 5341
+r0:=(-1/2)/(n*log(a*x^n)^2)
+--R 
+--R
+--R                1
+--R   (2)  - -------------
+--R                    n 2
+--R          2n log(a x )
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                              1
+--R   (3)  - -----------------------------------------
+--R            3      2     2                        2
+--R          2n log(x)  + 4n log(a)log(x) + 2n log(a)
+--R                                         Type: Union(Expression(Integer),...)
+--E 288
+
+--S 289 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  n 2    2      2                           2
+--R         - log(a x )  + n log(x)  + 2n log(a)log(x) + log(a)
+--R   (4)  -----------------------------------------------------
+--R           3      2     2                        2        n 2
+--R        (2n log(x)  + 4n log(a)log(x) + 2n log(a) )log(a x )
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 290
+
+)clear all
+
+--S 291 of 5341
+t0:=1/(x^2*log(a*x^n)^3)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         2       n 3
+--R        x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 5341
+--r0:=1/2*(a*x^n)^(1/n)*Ei(-log(a*x^n)/n)/(n^3*x)+(-1/2)/(n*x*log(a*x^n)^2)+_
+--   1/2/(n^2*x*log(a*x^n))
+--E 292
+
+--S 293 of 5341
+--a0:=integrate(t0,x)
+--E 293
+
+--S 294 of 5341
+--m0:=a0-r0
+--E 294
+
+--S 295 of 5341
+--d0:=D(m0,x)
+--E 295
+
+)clear all
+
+--S 296 of 5341
+t0:=1/(x^3*log(a*x^n)^3)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         3       n 3
+--R        x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 5341
+--r0:=2*(a*x^n)^(2/n)*Ei(-2*log(a*x^n)/n)/(n^3*x^2)+(-1/2)/(n*x^2*_
+--   log(a*x^n)^2)+1/(n^2*x^2*log(a*x^n))
+--E 297
+
+--S 298 of 5341
+--a0:=integrate(t0,x)
+--E 298
+
+--S 299 of 5341
+--m0:=a0-r0
+--E 299
+
+--S 300 of 5341
+--d0:=D(m0,x)
+--E 300
+
+)clear all
+
+--S 301 of 5341
+t0:=x^m/log(a*x)
+--R 
+--R
+--R            m
+--R           x
+--R   (1)  --------
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 5341
+--r0:=x^(1+m)*(a*x)^(-1-m)*Ei((1+m)*log(a*x))
+--E 302
+
+--S 303 of 5341
+--a0:=integrate(t0,x)
+--E 303
+
+--S 304 of 5341
+--m0:=a0-r0
+--E 304
+
+--S 305 of 5341
+--d0:=D(m0,x)
+--E 305
+
+)clear all
+
+--S 306 of 5341
+t0:=x^3/log(a*x)
+--R 
+--R
+--R            3
+--R           x
+--R   (1)  --------
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 5341
+--r0:=Ei(4*log(a*x))/a^4
+--E 307
+
+--S 308 of 5341
+--a0:=integrate(t0,x)
+--E 308
+
+--S 309 of 5341
+--m0:=a0-r0
+--E 309
+
+--S 310 of 5341
+--d0:=D(m0,x)
+--E 310
+
+)clear all
+
+--S 311 of 5341
+t0:=x^2/log(a*x)
+--R 
+--R
+--R            2
+--R           x
+--R   (1)  --------
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 5341
+--r0:=Ei(3*log(a*x))/a^3
+--E 312
+
+--S 313 of 5341
+--a0:=integrate(t0,x)
+--E 313
+
+--S 314 of 5341
+--m0:=a0-r0
+--E 314
+
+--S 315 of 5341
+--d0:=D(m0,x)
+--E 315
+
+)clear all
+
+--S 316 of 5341
+t0:=x/log(a*x)
+--R 
+--R
+--R            x
+--R   (1)  --------
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 5341
+--r0:=Ei(2*log(a*x))/a^2
+--E 317
+
+--S 318 of 5341
+--a0:=integrate(t0,x)
+--E 318
+
+--S 319 of 5341
+--m0:=a0-r0
+--E 319
+
+--S 320 of 5341
+--d0:=D(m0,x)
+--E 320
+
+)clear all
+
+--S 321 of 5341
+t0:=1/log(a*x)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 5341
+--r0:=Li(a*x)/a
+--E 322
+
+--S 323 of 5341
+--a0:=integrate(t0,x)
+--E 323
+
+--S 324 of 5341
+--m0:=a0-r0
+--E 324
+
+--S 325 of 5341
+--d0:=D(m0,x)
+--E 325
+
+)clear all
+
+--S 326 of 5341
+t0:=1/(x*log(a*x))
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R        x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 5341
+r0:=log(log(a*x))
+--R 
+--R
+--R   (2)  log(log(a x))
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  log(log(a x))
+--R                                         Type: Union(Expression(Integer),...)
+--E 328
+
+--S 329 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 5341
+t0:=1/(x^2*log(a*x))
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R         2
+--R        x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 5341
+--r0:=a*Ei(-log(a*x))
+--E 332
+
+--S 333 of 5341
+--a0:=integrate(t0,x)
+--E 333
+
+--S 334 of 5341
+--m0:=a0-r0
+--E 334
+
+--S 335 of 5341
+--d0:=D(m0,x)
+--E 335
+
+)clear all
+
+--S 336 of 5341
+t0:=1/(x^3*log(a*x))
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R         3
+--R        x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 5341
+--r0:=a^2*Ei(-2*log(a*x))
+--E 337
+
+--S 338 of 5341
+--a0:=integrate(t0,x)
+--E 338
+
+--S 339 of 5341
+--m0:=a0-r0
+--E 339
+
+--S 340 of 5341
+--d0:=D(m0,x)
+--E 340
+
+)clear all
+
+--S 341 of 5341
+t0:=x^m/log(a*x)^2
+--R 
+--R
+--R             m
+--R            x
+--R   (1)  ---------
+--R                2
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 5341
+--r0:=(1+m)*x^(1+m)*(a*x)^(-1-m)*Ei((1+m)*log(a*x))-x^(1+m)/log(a*x)
+--E 342
+
+--S 343 of 5341
+--a0:=integrate(t0,x)
+--E 343
+
+--S 344 of 5341
+--m0:=a0-r0
+--E 344
+
+--S 345 of 5341
+--d0:=D(m0,x)
+--E 345
+
+)clear all
+
+--S 346 of 5341
+t0:=x^3/log(a*x)^2
+--R 
+--R
+--R             3
+--R            x
+--R   (1)  ---------
+--R                2
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 5341
+--r0:=4*Ei(4*log(a*x))/a^4-x^4/log(a*x)
+--E 347
+
+--S 348 of 5341
+--a0:=integrate(t0,x)
+--E 348
+
+--S 349 of 5341
+--m0:=a0-r0
+--E 349
+
+--S 350 of 5341
+--d0:=D(m0,x)
+--E 350
+
+)clear all
+
+--S 351 of 5341
+t0:=x^2/log(a*x)^2
+--R 
+--R
+--R             2
+--R            x
+--R   (1)  ---------
+--R                2
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 5341
+--r0:=3*Ei(3*log(a*x))/a^3-x^3/log(a*x)
+--E 352
+
+--S 353 of 5341
+--a0:=integrate(t0,x)
+--E 353
+
+--S 354 of 5341
+--m0:=a0-r0
+--E 354
+
+--S 355 of 5341
+--d0:=D(m0,x)
+--E 355
+
+)clear all
+
+--S 356 of 5341
+t0:=x/log(a*x)^2
+--R 
+--R
+--R            x
+--R   (1)  ---------
+--R                2
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 5341
+--r0:=2*Ei(2*log(a*x))/a^2-x^2/log(a*x)
+--E 357
+
+--S 358 of 5341
+--a0:=integrate(t0,x)
+--E 358
+
+--S 359 of 5341
+--m0:=a0-r0
+--E 359
+
+--S 360 of 5341
+--d0:=D(m0,x)
+--E 360
+
+)clear all
+
+--S 361 of 5341
+t0:=1/log(a*x)^2
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R                2
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 5341
+--r0:=Li(a*x)/a-x/log(a*x)
+--E 362
+
+--S 363 of 5341
+--a0:=integrate(t0,x)
+--E 363
+
+--S 364 of 5341
+--m0:=a0-r0
+--E 364
+
+--S 365 of 5341
+--d0:=D(m0,x)
+--E 365
+
+)clear all
+
+--S 366 of 5341
+t0:=1/(x*log(a*x)^2)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R                  2
+--R        x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 5341
+r0:=(-1)/log(a*x)
+--R 
+--R
+--R              1
+--R   (2)  - --------
+--R          log(a x)
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R              1
+--R   (3)  - --------
+--R          log(a x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 368
+
+--S 369 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+--S 370 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 370
+
+)clear all
+
+--S 371 of 5341
+t0:=1/(x^2*log(a*x)^2)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         2        2
+--R        x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 5341
+--r0:=-a*Ei(-log(a*x))+(-1)/(x*log(a*x))
+--E 372
+
+--S 373 of 5341
+--a0:=integrate(t0,x)
+--E 373
+
+--S 374 of 5341
+--m0:=a0-r0
+--E 374
+
+--S 375 of 5341
+--d0:=D(m0,x)
+--E 375
+
+)clear all
+
+--S 376 of 5341
+t0:=1/(x^3*log(a*x)^2)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         3        2
+--R        x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 5341
+--r0:=-2*a^2*Ei(-2*log(a*x))+(-1)/(x^2*log(a*x))
+--E 377
+
+--S 378 of 5341
+--a0:=integrate(t0,x)
+--E 378
+
+--S 379 of 5341
+--m0:=a0-r0
+--E 379
+
+--S 380 of 5341
+--d0:=D(m0,x)
+--E 380
+
+)clear all
+
+--S 381 of 5341
+t0:=x^m/log(a*x)^3
+--R 
+--R
+--R             m
+--R            x
+--R   (1)  ---------
+--R                3
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 381
+
+--S 382 of 5341
+--r0:=1/2*(1+m)^2*x^(1+m)*(a*x)^(-1-m)*Ei((1+m)*log(a*x))-_
+--   1/2*x^(1+m)/log(a*x)^2-1/2*(1+m)*x^(1+m)/log(a*x)
+--E 382
+
+--S 383 of 5341
+--a0:=integrate(t0,x)
+--E 383
+
+--S 384 of 5341
+--m0:=a0-r0
+--E 384
+
+--S 385 of 5341
+--d0:=D(m0,x)
+--E 385
+
+)clear all
+
+--S 386 of 5341
+t0:=x^3/log(a*x)^3
+--R 
+--R
+--R             3
+--R            x
+--R   (1)  ---------
+--R                3
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 5341
+--r0:=8*Ei(4*log(a*x))/a^4-1/2*x^4/log(a*x)^2-2*x^4/log(a*x)
+--E 387
+
+--S 388 of 5341
+--a0:=integrate(t0,x)
+--E 388
+
+--S 389 of 5341
+--m0:=a0-r0
+--E 389
+
+--S 390 of 5341
+--d0:=D(m0,x)
+--E 390
+
+)clear all
+
+--S 391 of 5341
+t0:=x^2/log(a*x)^3
+--R 
+--R
+--R             2
+--R            x
+--R   (1)  ---------
+--R                3
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 5341
+--r0:=9/2*Ei(3*log(a*x))/a^3-1/2*x^3/log(a*x)^2-3/2*x^3/log(a*x)
+--E 392
+
+--S 393 of 5341
+--a0:=integrate(t0,x)
+--E 393
+
+--S 394 of 5341
+--m0:=a0-r0
+--E 394
+
+--S 395 of 5341
+--d0:=D(m0,x)
+--E 395
+
+)clear all
+
+--S 396 of 5341
+t0:=x/log(a*x)^3
+--R 
+--R
+--R            x
+--R   (1)  ---------
+--R                3
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 396
+
+--S 397 of 5341
+--r0:=2*Ei(2*log(a*x))/a^2-1/2*x^2/log(a*x)^2-x^2/log(a*x)
+--E 397
+
+--S 398 of 5341
+--a0:=integrate(t0,x)
+--E 398
+
+--S 399 of 5341
+--m0:=a0-r0
+--E 399
+
+--S 400 of 5341
+--d0:=D(m0,x)
+--E 400
+
+)clear all
+
+--S 401 of 5341
+t0:=1/log(a*x)^3
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R                3
+--R        log(a x)
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 5341
+--r0:=1/2*Li(a*x)/a-1/2*x/log(a*x)^2-1/2*x/log(a*x)
+--E 402
+
+--S 403 of 5341
+--a0:=integrate(t0,x)
+--E 403
+
+--S 404 of 5341
+--m0:=a0-r0
+--E 404
+
+--S 405 of 5341
+--d0:=D(m0,x)
+--E 405
+
+)clear all
+
+--S 406 of 5341
+t0:=1/(x*log(a*x)^3)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R                  3
+--R        x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 5341
+r0:=(-1/2)/log(a*x)^2
+--R 
+--R
+--R               1
+--R   (2)  - ----------
+--R                   2
+--R          2log(a x)
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R               1
+--R   (3)  - ----------
+--R                   2
+--R          2log(a x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 408
+
+--S 409 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 410
+
+)clear all
+
+--S 411 of 5341
+t0:=1/(x^2*log(a*x)^3)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         2        3
+--R        x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 411
+
+--S 412 of 5341
+--r0:=1/2*a*Ei(-log(a*x))+(-1/2)/(x*log(a*x)^2)+1/2/(x*log(a*x))
+--E 412
+
+--S 413 of 5341
+--a0:=integrate(t0,x)
+--E 413
+
+--S 414 of 5341
+--m0:=a0-r0
+--E 414
+
+--S 415 of 5341
+--d0:=D(m0,x)
+--E 415
+
+)clear all
+
+--S 416 of 5341
+t0:=1/(x^3*log(a*x)^3)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         3        3
+--R        x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 5341
+--r0:=2*a^2*Ei(-2*log(a*x))+(-1/2)/(x^2*log(a*x)^2)+1/(x^2*log(a*x))
+--E 417
+
+--S 418 of 5341
+--a0:=integrate(t0,x)
+--E 418
+
+--S 419 of 5341
+--m0:=a0-r0
+--E 419
+
+--S 420 of 5341
+--d0:=D(m0,x)
+--E 420
+
+)clear all
+
+--S 421 of 5341
+t0:=x^m*sqrt(log(a*x^n))
+--R 
+--R
+--R           +---------+
+--R         m |       n
+--R   (1)  x \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 5341
+--r0:=-1/2*x^(1+m)*erfi(sqrt(1+m)*sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)*_
+--   sqrt(n)/((1+m)^(3/2)*(a*x^n)^((1+m)/n))+x^(1+m)*sqrt(log(a*x^n))/(1+m)
+--E 422
+
+--S 423 of 5341
+--a0:=integrate(t0,x)
+--E 423
+
+--S 424 of 5341
+--m0:=a0-r0
+--E 424
+
+--S 425 of 5341
+--d0:=D(m0,x)
+--E 425
+
+)clear all
+
+--S 426 of 5341
+t0:=x^3*sqrt(log(a*x^n))
+--R 
+--R
+--R           +---------+
+--R         3 |       n
+--R   (1)  x \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 5341
+--r0:=-1/16*x^4*erfi(2*sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)*_
+--   sqrt(n)/(a*x^n)^(4/n)+1/4*x^4*sqrt(log(a*x^n))
+--E 427
+
+--S 428 of 5341
+--a0:=integrate(t0,x)
+--E 428
+
+--S 429 of 5341
+--m0:=a0-r0
+--E 429
+
+--S 430 of 5341
+--d0:=D(m0,x)
+--E 430
+
+)clear all
+
+--S 431 of 5341
+t0:=x^2*sqrt(log(a*x^n))
+--R 
+--R
+--R           +---------+
+--R         2 |       n
+--R   (1)  x \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 5341
+--r0:=-1/6*x^3*erfi(sqrt(3)*sqrt(log(a*x^n))/sqrt(n))*sqrt(1/3*%pi)*_
+--   sqrt(n)/(a*x^n)^(3/n)+1/3*x^3*sqrt(log(a*x^n))
+--E 432
+
+--S 433 of 5341
+--a0:=integrate(t0,x)
+--E 433
+
+--S 434 of 5341
+--m0:=a0-r0
+--E 434
+
+--S 435 of 5341
+--d0:=D(m0,x)
+--E 435
+
+)clear all
+
+--S 436 of 5341
+t0:=x*sqrt(log(a*x^n))
+--R 
+--R
+--R          +---------+
+--R          |       n
+--R   (1)  x\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 5341
+--r0:=-1/4*x^2*erfi(sqrt(2)*sqrt(log(a*x^n))/sqrt(n))*sqrt(1/2*%pi)*_
+--   sqrt(n)/(a*x^n)^(2/n)+1/2*x^2*sqrt(log(a*x^n))
+--E 437
+
+--S 438 of 5341
+--a0:=integrate(t0,x)
+--E 438
+
+--S 439 of 5341
+--m0:=a0-r0
+--E 439
+
+--S 440 of 5341
+--d0:=D(m0,x)
+--E 440
+
+)clear all
+
+--S 441 of 5341
+t0:=sqrt(log(a*x^n))
+--R 
+--R
+--R         +---------+
+--R         |       n
+--R   (1)  \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 5341
+--r0:=-1/2*x*erfi(sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)*sqrt(n)/_
+--   (a*x^n)^(1/n)+x*sqrt(log(a*x^n))
+--E 442
+
+--S 443 of 5341
+--a0:=integrate(t0,x)
+--E 443
+
+--S 444 of 5341
+--m0:=a0-r0
+--E 444
+
+--S 445 of 5341
+--d0:=D(m0,x)
+--E 445
+
+)clear all
+
+--S 446 of 5341
+t0:=sqrt(log(a*x^n))/x
+--R 
+--R
+--R         +---------+
+--R         |       n
+--R        \|log(a x )
+--R   (1)  ------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 5341
+r0:=2/3*log(a*x^n)^(3/2)/n
+--R 
+--R
+--R                   +---------+
+--R                n  |       n
+--R        2log(a x )\|log(a x )
+--R   (2)  ----------------------
+--R                  3n
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                              +-----------------+
+--R        (2n log(x) + 2log(a))\|n log(x) + log(a)
+--R   (3)  -----------------------------------------
+--R                            3n
+--R                                         Type: Union(Expression(Integer),...)
+--E 448
+
+--S 449 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                     +---------+
+--R                  n  |       n                           +-----------------+
+--R        - 2log(a x )\|log(a x )  + (2n log(x) + 2log(a))\|n log(x) + log(a)
+--R   (4)  --------------------------------------------------------------------
+--R                                         3n
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 5341
+t0:=sqrt(log(a*x^n))/x^2
+--R 
+--R
+--R         +---------+
+--R         |       n
+--R        \|log(a x )
+--R   (1)  ------------
+--R              2
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 5341
+r0:=1/2*(a*x^n)^(1/n)*erf(sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)*sqrt(n)/x-_
+   sqrt(log(a*x^n))/x
+--R 
+--R
+--R                        1     +---------+
+--R                        -     |       n        +---------+
+--R         +-+ +---+    n n    \|log(a x )       |       n
+--R        \|n \|%pi (a x ) erf(------------) - 2\|log(a x )
+--R                                  +-+
+--R                                 \|n
+--R   (2)  --------------------------------------------------
+--R                                2x
+--R                                                    Type: Expression(Integer)
+--E 452
+
+-- integrate: implementation incomplete (constant residues)
+--S 453 of 5341
+--a0:=integrate(t0,x)
+--E 453
+
+--S 454 of 5341
+--m0:=a0-r0
+--E 454
+
+--S 455 of 5341
+--d0:=D(m0,x)
+--E 455
+
+)clear all
+
+--S 456 of 5341
+t0:=sqrt(log(a*x^n))/x^3
+--R 
+--R
+--R         +---------+
+--R         |       n
+--R        \|log(a x )
+--R   (1)  ------------
+--R              3
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 5341
+r0:=1/4*(a*x^n)^(2/n)*erf(sqrt(2)*sqrt(log(a*x^n))/sqrt(n))*sqrt(1/2*%pi)*_
+   sqrt(n)/x^2-1/2*sqrt(log(a*x^n))/x^2
+--R 
+--R
+--R                        2         +---------+
+--R                        -     +-+ |       n            +---------+
+--R         +-+ +---+    n n    \|2 \|log(a x )       +-+ |       n
+--R        \|n \|%pi (a x ) erf(----------------) - 2\|2 \|log(a x )
+--R                                    +-+
+--R                                   \|n
+--R   (2)  ----------------------------------------------------------
+--R                                    2 +-+
+--R                                  4x \|2
+--R                                                    Type: Expression(Integer)
+--E 457
+
+-- integrate: implementation incomplete (constant residues)
+--S 458 of 5341
+--a0:=integrate(t0,x)
+--E 458
+
+--S 459 of 5341
+--m0:=a0-r0
+--E 459
+
+--S 460 of 5341
+--d0:=D(m0,x)
+--E 460
+
+)clear all
+
+--S 461 of 5341
+t0:=x^m*log(a*x^n)^(3/2)
+--R 
+--R
+--R                    +---------+
+--R         m       n  |       n
+--R   (1)  x log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 5341
+--r0:=x^(1+m)*log(a*x^n)^(3/2)/(1+m)+3/4*n^(3/2)*x^(1+m)*erfi(sqrt(1+m)*_
+--   sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)/((1+m)^(5/2)*(a*x^n)^((1+m)/n))-_
+--   3/2*n*x^(1+m)*sqrt(log(a*x^n))/(1+m)^2
+--E 462
+
+--S 463 of 5341
+--a0:=integrate(t0,x)
+--E 463
+
+--S 464 of 5341
+--m0:=a0-r0
+--E 464
+
+--S 465 of 5341
+--d0:=D(m0,x)
+--E 465
+
+)clear all
+
+--S 466 of 5341
+t0:=x^3*log(a*x^n)^(3/2)
+--R 
+--R
+--R                    +---------+
+--R         3       n  |       n
+--R   (1)  x log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 5341
+--r0:=1/4*x^4*log(a*x^n)^(3/2)+3/128*n^(3/2)*x^4*erfi(2*sqrt(log(a*x^n))/_
+--   sqrt(n))*sqrt(%pi)/(a*x^n)^(4/n)-3/32*n*x^4*sqrt(log(a*x^n))
+--E 467
+
+--S 468 of 5341
+--a0:=integrate(t0,x)
+--E 468
+
+--S 469 of 5341
+--m0:=a0-r0
+--E 469
+
+--S 470 of 5341
+--d0:=D(m0,x)
+--E 470
+
+)clear all
+
+--S 471 of 5341
+t0:=x^2*log(a*x^n)^(3/2)
+--R 
+--R
+--R                    +---------+
+--R         2       n  |       n
+--R   (1)  x log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 5341
+--r0:=1/3*x^3*log(a*x^n)^(3/2)+1/12*n^(3/2)*x^3*erfi(sqrt(3)*_
+--   sqrt(log(a*x^n))/sqrt(n))*sqrt(1/3*%pi)/(a*x^n)^(3/n)-1/6*n*x^3*_
+--   sqrt(log(a*x^n))
+--E 472
+
+--S 473 of 5341
+--a0:=integrate(t0,x)
+--E 473
+
+--S 474 of 5341
+--m0:=a0-r0
+--E 474
+
+--S 475 of 5341
+--d0:=D(m0,x)
+--E 475
+
+)clear all
+
+--S 476 of 5341
+t0:=x*log(a*x^n)^(3/2)
+--R 
+--R
+--R                    +---------+
+--R                 n  |       n
+--R   (1)  x log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 5341
+--r0:=1/2*x^2*log(a*x^n)^(3/2)+3/16*n^(3/2)*x^2*erfi(sqrt(2)*_
+--   sqrt(log(a*x^n))/sqrt(n))*sqrt(1/2*%pi)/(a*x^n)^(2/n)-3/8*n*x^2*_
+--   sqrt(log(a*x^n))
+--E 477
+
+--S 478 of 5341
+--a0:=integrate(t0,x)
+--E 478
+
+--S 479 of 5341
+--m0:=a0-r0
+--E 479
+
+--S 480 of 5341
+--d0:=D(m0,x)
+--E 480
+
+)clear all
+
+--S 481 of 5341
+t0:=log(a*x^n)^(3/2)
+--R 
+--R
+--R                  +---------+
+--R               n  |       n
+--R   (1)  log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 5341
+--r0:=x*log(a*x^n)^(3/2)+3/4*n^(3/2)*x*erfi(sqrt(log(a*x^n))/sqrt(n))*_
+--   sqrt(%pi)/(a*x^n)^(1/n)-3/2*n*x*sqrt(log(a*x^n))
+--E 482
+
+--S 483 of 5341
+--a0:=integrate(t0,x)
+--E 483
+
+--S 484 of 5341
+--m0:=a0-r0
+--E 484
+
+--S 485 of 5341
+--d0:=D(m0,x)
+--E 485
+
+)clear all
+
+--S 486 of 5341
+t0:=log(a*x^n)^(3/2)/x
+--R 
+--R
+--R                  +---------+
+--R               n  |       n
+--R        log(a x )\|log(a x )
+--R   (1)  ---------------------
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 5341
+r0:=2/5*log(a*x^n)^(5/2)/n
+--R 
+--R
+--R                    +---------+
+--R                n 2 |       n
+--R        2log(a x ) \|log(a x )
+--R   (2)  -----------------------
+--R                   5n
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2      2                            2  +-----------------+
+--R        (2n log(x)  + 4n log(a)log(x) + 2log(a) )\|n log(x) + log(a)
+--R   (3)  -------------------------------------------------------------
+--R                                      5n
+--R                                         Type: Union(Expression(Integer),...)
+--E 488
+
+--S 489 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +---------+
+--R                 n 2 |       n
+--R       - 2log(a x ) \|log(a x )
+--R     + 
+--R          2      2                            2  +-----------------+
+--R       (2n log(x)  + 4n log(a)log(x) + 2log(a) )\|n log(x) + log(a)
+--R  /
+--R     5n
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 490
+
+)clear all
+
+--S 491 of 5341
+t0:=log(a*x^n)^(3/2)/x^2
+--R 
+--R
+--R                  +---------+
+--R               n  |       n
+--R        log(a x )\|log(a x )
+--R   (1)  ---------------------
+--R                   2
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 5341
+r0:=-log(a*x^n)^(3/2)/x+3/4*n^(3/2)*(a*x^n)^(1/n)*erf(sqrt(log(a*x^n))/_
+   sqrt(n))*sqrt(%pi)/x-3/2*n*sqrt(log(a*x^n))/x
+--R 
+--R
+--R                          1     +---------+
+--R                          -     |       n                          +---------+
+--R           +-+ +---+    n n    \|log(a x )                n        |       n
+--R        3n\|n \|%pi (a x ) erf(------------) + (- 4log(a x ) - 6n)\|log(a x )
+--R                                    +-+
+--R                                   \|n
+--R   (2)  ----------------------------------------------------------------------
+--R                                          4x
+--R                                                    Type: Expression(Integer)
+--E 492
+
+-- integrate: implementation incomplete (constant residues)
+--S 493 of 5341
+--a0:=integrate(t0,x)
+--E 493
+
+--S 494 of 5341
+--m0:=a0-r0
+--E 494
+
+--S 495 of 5341
+--d0:=D(m0,x)
+--E 495
+
+)clear all
+
+--S 496 of 5341
+t0:=log(a*x^n)^(3/2)/x^3
+--R 
+--R
+--R                  +---------+
+--R               n  |       n
+--R        log(a x )\|log(a x )
+--R   (1)  ---------------------
+--R                   3
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 5341
+r0:=-1/2*log(a*x^n)^(3/2)/x^2+3/16*n^(3/2)*(a*x^n)^(2/n)*erf(sqrt(2)*_
+   sqrt(log(a*x^n))/sqrt(n))*sqrt(1/2*%pi)/x^2-3/8*n*sqrt(log(a*x^n))/x^2
+--R 
+--R
+--R   (2)
+--R                         2         +---------+
+--R                         -     +-+ |       n
+--R          +-+ +---+    n n    \|2 \|log(a x )
+--R       3n\|n \|%pi (a x ) erf(----------------)
+--R                                     +-+
+--R                                    \|n
+--R     + 
+--R                                   +---------+
+--R            +-+       n       +-+  |       n
+--R       (- 8\|2 log(a x ) - 6n\|2 )\|log(a x )
+--R  /
+--R        2 +-+
+--R     16x \|2
+--R                                                    Type: Expression(Integer)
+--E 497
+
+-- integrate: implementation incomplete (constant residues)
+--S 498 of 5341
+--a0:=integrate(t0,x)
+--E 498
+
+--S 499 of 5341
+--m0:=a0-r0
+--E 499
+
+--S 500 of 5341
+--d0:=D(m0,x)
+--E 500
+
+)clear all
+
+--S 501 of 5341
+t0:=x^m/sqrt(log(a*x^n))
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         +---------+
+--R         |       n
+--R        \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 5341
+--r0:=x^(1+m)*erfi(sqrt(1+m)*sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)/_
+--   ((a*x^n)^((1+m)/n)*sqrt(1+m)*sqrt(n))
+--E 502
+
+--S 503 of 5341
+--a0:=integrate(t0,x)
+--E 503
+
+--S 504 of 5341
+--m0:=a0-r0
+--E 504
+
+--S 505 of 5341
+--d0:=D(m0,x)
+--E 505
+
+)clear all
+
+--S 506 of 5341
+t0:=x^3/sqrt(log(a*x^n))
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         +---------+
+--R         |       n
+--R        \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 5341
+--r0:=1/2*x^4*erfi(2*sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)/((a*x^n)^(4/n)*_
+--   sqrt(n))
+--E 507
+
+--S 508 of 5341
+--a0:=integrate(t0,x)
+--E 508
+
+--S 509 of 5341
+--m0:=a0-r0
+--E 509
+
+--S 510 of 5341
+--d0:=D(m0,x)
+--E 510
+
+)clear all
+
+--S 511 of 5341
+t0:=x^2/sqrt(log(a*x^n))
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         +---------+
+--R         |       n
+--R        \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 5341
+--r0:=x^3*erfi(sqrt(3)*sqrt(log(a*x^n))/sqrt(n))*sqrt(1/3*%pi)/_
+--   ((a*x^n)^(3/n)*sqrt(n))
+--E 512
+
+--S 513 of 5341
+--a0:=integrate(t0,x)
+--E 513
+
+--S 514 of 5341
+--m0:=a0-r0
+--E 514
+
+--S 515 of 5341
+--d0:=D(m0,x)
+--E 515
+
+)clear all
+
+--S 516 of 5341
+t0:=x/sqrt(log(a*x^n))
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         +---------+
+--R         |       n
+--R        \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 5341
+--r0:=x^2*erfi(sqrt(2)*sqrt(log(a*x^n))/sqrt(n))*sqrt(1/2*%pi)/_
+--   ((a*x^n)^(2/n)*sqrt(n))
+--E 517
+
+--S 518 of 5341
+--a0:=integrate(t0,x)
+--E 518
+
+--S 519 of 5341
+--m0:=a0-r0
+--E 519
+
+--S 520 of 5341
+--d0:=D(m0,x)
+--E 520
+
+)clear all
+
+--S 521 of 5341
+t0:=1/sqrt(log(a*x^n))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         +---------+
+--R         |       n
+--R        \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 5341
+--r0:=x*erfi(sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)/((a*x^n)^(1/n)*sqrt(n))
+--E 522
+
+--S 523 of 5341
+--a0:=integrate(t0,x)
+--E 523
+
+--S 524 of 5341
+--m0:=a0-r0
+--E 524
+
+--S 525 of 5341
+--d0:=D(m0,x)
+--E 525
+
+)clear all
+
+--S 526 of 5341
+t0:=1/(x*sqrt(log(a*x^n)))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R          +---------+
+--R          |       n
+--R        x\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 5341
+r0:=2*sqrt(log(a*x^n))/n
+--R 
+--R
+--R          +---------+
+--R          |       n
+--R        2\|log(a x )
+--R   (2)  -------------
+--R              n
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +-----------------+
+--R        2\|n log(x) + log(a)
+--R   (3)  ---------------------
+--R                  n
+--R                                         Type: Union(Expression(Integer),...)
+--E 528
+
+--S 529 of 5341
+m0:=a0-r0
+--R 
+--R
+--R            +---------+
+--R            |       n       +-----------------+
+--R        - 2\|log(a x )  + 2\|n log(x) + log(a)
+--R   (4)  ---------------------------------------
+--R                           n
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 530
+
+)clear all
+
+--S 531 of 5341
+t0:=1/(x^2*sqrt(log(a*x^n)))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R           +---------+
+--R         2 |       n
+--R        x \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 5341
+r0:=(a*x^n)^(1/n)*erf(sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)/(x*sqrt(n))
+--R 
+--R
+--R                    1     +---------+
+--R                    -     |       n
+--R         +---+    n n    \|log(a x )
+--R        \|%pi (a x ) erf(------------)
+--R                              +-+
+--R                             \|n
+--R   (2)  ------------------------------
+--R                       +-+
+--R                     x\|n
+--R                                                    Type: Expression(Integer)
+--E 532
+
+-- integrate: implementation incomplete (constant residues)
+--S 533 of 5341
+--a0:=integrate(t0,x)
+--E 533
+
+--S 534 of 5341
+--m0:=a0-r0
+--E 534
+
+--S 535 of 5341
+--d0:=D(m0,x)
+--E 535
+
+)clear all
+
+--S 536 of 5341
+t0:=1/(x^3*sqrt(log(a*x^n)))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R           +---------+
+--R         3 |       n
+--R        x \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 5341
+r0:=(a*x^n)^(2/n)*erf(sqrt(2)*sqrt(log(a*x^n))/sqrt(n))*sqrt(1/2*%pi)/_
+   (x^2*sqrt(n))
+--R 
+--R
+--R                    2         +---------+
+--R                    -     +-+ |       n
+--R         +---+    n n    \|2 \|log(a x )
+--R        \|%pi (a x ) erf(----------------)
+--R                                +-+
+--R                               \|n
+--R   (2)  ----------------------------------
+--R                     2 +-+ +-+
+--R                    x \|2 \|n
+--R                                                    Type: Expression(Integer)
+--E 537
+
+-- integrate: implementation incomplete (constant residues)
+--S 538 of 5341
+--a0:=integrate(t0,x)
+--E 538
+
+--S 539 of 5341
+--m0:=a0-r0
+--E 539
+
+--S 540 of 5341
+--d0:=D(m0,x)
+--E 540
+
+)clear all
+
+--S 541 of 5341
+t0:=x^m/log(a*x^n)^(3/2)
+--R 
+--R
+--R                   m
+--R                  x
+--R   (1)  ---------------------
+--R                  +---------+
+--R               n  |       n
+--R        log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 5341
+--r0:=2*x^(1+m)*erfi(sqrt(1+m)*sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)*_
+--   sqrt(1+m)/(n^(3/2)*(a*x^n)^((1+m)/n))-2*x^(1+m)/(n*sqrt(log(a*x^n)))
+--E 542
+
+--S 543 of 5341
+--a0:=integrate(t0,x)
+--E 543
+
+--S 544 of 5341
+--m0:=a0-r0
+--E 544
+
+--S 545 of 5341
+--d0:=D(m0,x)
+--E 545
+
+)clear all
+
+--S 546 of 5341
+t0:=x^3/log(a*x^n)^(3/2)
+--R 
+--R
+--R                   3
+--R                  x
+--R   (1)  ---------------------
+--R                  +---------+
+--R               n  |       n
+--R        log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 5341
+--r0:=4*x^4*erfi(2*sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)/(n^(3/2)*_
+--   (a*x^n)^(4/n))-2*x^4/(n*sqrt(log(a*x^n)))
+--E 547
+
+--S 548 of 5341
+--a0:=integrate(t0,x)
+--E 548
+
+--S 549 of 5341
+--m0:=a0-r0
+--E 549
+
+--S 550 of 5341
+--d0:=D(m0,x)
+--E 550
+
+)clear all
+
+--S 551 of 5341
+t0:=x^2/log(a*x^n)^(3/2)
+--R 
+--R
+--R                   2
+--R                  x
+--R   (1)  ---------------------
+--R                  +---------+
+--R               n  |       n
+--R        log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 5341
+--r0:=2*x^3*erfi(sqrt(3)*sqrt(log(a*x^n))/sqrt(n))*sqrt(3*%pi)/(n^(3/2)*_
+--   (a*x^n)^(3/n))-2*x^3/(n*sqrt(log(a*x^n)))
+--E 552
+
+--S 553 of 5341
+--a0:=integrate(t0,x)
+--E 553
+
+--S 554 of 5341
+--m0:=a0-r0
+--E 554
+
+--S 555 of 5341
+--d0:=D(m0,x)
+--E 555
+
+)clear all
+
+--S 556 of 5341
+t0:=x/log(a*x^n)^(3/2)
+--R 
+--R
+--R                  x
+--R   (1)  ---------------------
+--R                  +---------+
+--R               n  |       n
+--R        log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 5341
+--r0:=2*x^2*erfi(sqrt(2)*sqrt(log(a*x^n))/sqrt(n))*sqrt(2*%pi)/(n^(3/2)*_
+--   (a*x^n)^(2/n))-2*x^2/(n*sqrt(log(a*x^n)))
+--E 557
+
+--S 558 of 5341
+--a0:=integrate(t0,x)
+--E 558
+
+--S 559 of 5341
+--m0:=a0-r0
+--E 559
+
+--S 560 of 5341
+--d0:=D(m0,x)
+--E 560
+
+)clear all
+
+--S 561 of 5341
+t0:=1/log(a*x^n)^(3/2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R                  +---------+
+--R               n  |       n
+--R        log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 5341
+--r0:=2*x*erfi(sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)/(n^(3/2)*(a*x^n)^(1/n))-_
+--   2*x/(n*sqrt(log(a*x^n)))
+--E 562
+
+--S 563 of 5341
+--a0:=integrate(t0,x)
+--E 563
+
+--S 564 of 5341
+--m0:=a0-r0
+--E 564
+
+--S 565 of 5341
+--d0:=D(m0,x)
+--E 565
+
+)clear all
+
+--S 566 of 5341
+t0:=1/(x*log(a*x^n)^(3/2))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R                    +---------+
+--R                 n  |       n
+--R        x log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 5341
+r0:=(-2)/(n*sqrt(log(a*x^n)))
+--R 
+--R
+--R                2
+--R   (2)  - -------------
+--R            +---------+
+--R            |       n
+--R          n\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    2
+--R   (3)  - ---------------------
+--R            +-----------------+
+--R          n\|n log(x) + log(a)
+--R                                         Type: Union(Expression(Integer),...)
+--E 568
+
+--S 569 of 5341
+m0:=a0-r0
+--R 
+--R
+--R            +---------+
+--R            |       n       +-----------------+
+--R        - 2\|log(a x )  + 2\|n log(x) + log(a)
+--R   (4)  ---------------------------------------
+--R                                 +---------+
+--R             +-----------------+ |       n
+--R           n\|n log(x) + log(a) \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 5341
+t0:=1/(x^2*log(a*x^n)^(3/2))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R                    +---------+
+--R         2       n  |       n
+--R        x log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 5341
+r0:=-2*(a*x^n)^(1/n)*erf(sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)/(n^(3/2)*x)+_
+   (-2)/(n*x*sqrt(log(a*x^n)))
+--R 
+--R
+--R                       1                 +---------+
+--R                       - +---------+     |       n
+--R            +---+    n n |       n      \|log(a x )       +-+
+--R        - 2\|%pi (a x ) \|log(a x ) erf(------------) - 2\|n
+--R                                             +-+
+--R                                            \|n
+--R   (2)  -----------------------------------------------------
+--R                                 +---------+
+--R                             +-+ |       n
+--R                         n x\|n \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 572
+
+-- integrate: implementation incomplete (constant residues)
+--S 573 of 5341
+--a0:=integrate(t0,x)
+--E 573
+
+--S 574 of 5341
+--m0:=a0-r0
+--E 574
+
+--S 575 of 5341
+--d0:=D(m0,x)
+--E 575
+
+)clear all
+
+--S 576 of 5341
+t0:=1/(x^3*log(a*x^n)^(3/2))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R                    +---------+
+--R         3       n  |       n
+--R        x log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 5341
+r0:=-2*(a*x^n)^(2/n)*erf(sqrt(2)*sqrt(log(a*x^n))/sqrt(n))*sqrt(2*%pi)/_
+   (n^(3/2)*x^2)+(-2)/(n*x^2*sqrt(log(a*x^n)))
+--R 
+--R
+--R                        2                     +---------+
+--R                        - +---------+     +-+ |       n
+--R            +----+    n n |       n      \|2 \|log(a x )       +-+
+--R        - 2\|2%pi (a x ) \|log(a x ) erf(----------------) - 2\|n
+--R                                                +-+
+--R                                               \|n
+--R   (2)  ----------------------------------------------------------
+--R                                    +---------+
+--R                              2 +-+ |       n
+--R                           n x \|n \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 577
+
+-- integrate: implementation incomplete (constant residues)
+--S 578 of 5341
+--a0:=integrate(t0,x)
+--E 578
+
+--S 579 of 5341
+--m0:=a0-r0
+--E 579
+
+--S 580 of 5341
+--d0:=D(m0,x)
+--E 580
+
+)clear all
+
+--S 581 of 5341
+t0:=x^m/log(a*x^n)^(5/2)
+--R 
+--R
+--R                   m
+--R                  x
+--R   (1)  ----------------------
+--R                   +---------+
+--R               n 2 |       n
+--R        log(a x ) \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 5341
+--r0:=-2/3*x^(1+m)/(n*log(a*x^n)^(3/2))+4/3*(1+m)^(3/2)*x^(1+m)*_
+--   erfi(sqrt(1+m)*sqrt(log(a*x^n))/sqrt(n))*sqrt(%pi)/(n^(5/2)*_
+--   (a*x^n)^((1+m)/n))-4/3*(1+m)*x^(1+m)/(n^2*sqrt(log(a*x^n)))
+--E 582
+
+--S 583 of 5341
+--a0:=integrate(t0,x)
+--E 583
+
+--S 584 of 5341
+--m0:=a0-r0
+--E 584
+
+--S 585 of 5341
+--d0:=D(m0,x)
+--E 585
+
+)clear all
+
+--S 586 of 5341
+t0:=x^3/log(a*x^n)^(5/2)
+--R 
+--R
+--R                   3
+--R                  x
+--R   (1)  ----------------------
+--R                   +---------+
+--R               n 2 |       n
+--R        log(a x ) \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 5341
+--r0:=-2/3*x^4/(n*log(a*x^n)^(3/2))+32/3*x^4*erfi(2*sqrt(log(a*x^n))/_
+--   sqrt(n))*sqrt(%pi)/(n^(5/2)*(a*x^n)^(4/n))-16/3*x^4/(n^2*sqrt(log(a*x^n)))
+--E 587
+
+--S 588 of 5341
+--a0:=integrate(t0,x)
+--E 588
+
+--S 589 of 5341
+--m0:=a0-r0
+--E 589
+
+--S 590 of 5341
+--d0:=D(m0,x)
+--E 590
+
+)clear all
+
+--S 591 of 5341
+t0:=x^2/log(a*x^n)^(5/2)
+--R 
+--R
+--R                   2
+--R                  x
+--R   (1)  ----------------------
+--R                   +---------+
+--R               n 2 |       n
+--R        log(a x ) \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 5341
+--r0:=-2/3*x^3/(n*log(a*x^n)^(3/2))+4*x^3*erfi(sqrt(3)*sqrt(log(a*x^n))/_
+--   sqrt(n))*sqrt(3*%pi)/(n^(5/2)*(a*x^n)^(3/n))-4*x^3/(n^2*sqrt(log(a*x^n)))
+--E 592
+
+--S 593 of 5341
+--a0:=integrate(t0,x)
+--E 593
+
+--S 594 of 5341
+--m0:=a0-r0
+--E 594
+
+--S 595 of 5341
+--d0:=D(m0,x)
+--E 595
+
+)clear all
+
+--S 596 of 5341
+t0:=x/log(a*x^n)^(5/2)
+--R 
+--R
+--R                   x
+--R   (1)  ----------------------
+--R                   +---------+
+--R               n 2 |       n
+--R        log(a x ) \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 5341
+--r0:=-2/3*x^2/(n*log(a*x^n)^(3/2))+8/3*x^2*erfi(sqrt(2)*sqrt(log(a*x^n))/_
+-- sqrt(n))*sqrt(2*%pi)/(n^(5/2)*(a*x^n)^(2/n))-8/3*x^2/(n^2*sqrt(log(a*x^n)))
+--E 597
+
+--S 598 of 5341
+--a0:=integrate(t0,x)
+--E 598
+
+--S 599 of 5341
+--m0:=a0-r0
+--E 599
+
+--S 600 of 5341
+--d0:=D(m0,x)
+--E 600
+
+)clear all
+
+--S 601 of 5341
+t0:=1/log(a*x^n)^(5/2)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R                   +---------+
+--R               n 2 |       n
+--R        log(a x ) \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 5341
+--r0:=-2/3*x/(n*log(a*x^n)^(3/2))+4/3*x*erfi(sqrt(log(a*x^n))/sqrt(n))*_
+--   sqrt(%pi)/(n^(5/2)*(a*x^n)^(1/n))-4/3*x/(n^2*sqrt(log(a*x^n)))
+--E 602
+
+--S 603 of 5341
+--a0:=integrate(t0,x)
+--E 603
+
+--S 604 of 5341
+--m0:=a0-r0
+--E 604
+
+--S 605 of 5341
+--d0:=D(m0,x)
+--E 605
+
+)clear all
+
+--S 606 of 5341
+t0:=1/(x*log(a*x^n)^(5/2))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R                     +---------+
+--R                 n 2 |       n
+--R        x log(a x ) \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 5341
+r0:=(-2/3)/(n*log(a*x^n)^(3/2))
+--R 
+--R
+--R                      2
+--R   (2)  - ------------------------
+--R                       +---------+
+--R                    n  |       n
+--R          3n log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               2
+--R   (3)  - -------------------------------------------
+--R             2                    +-----------------+
+--R          (3n log(x) + 3n log(a))\|n log(x) + log(a)
+--R                                         Type: Union(Expression(Integer),...)
+--E 608
+
+--S 609 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                     +---------+
+--R                  n  |       n                           +-----------------+
+--R        - 2log(a x )\|log(a x )  + (2n log(x) + 2log(a))\|n log(x) + log(a)
+--R   (4)  --------------------------------------------------------------------
+--R                                                               +---------+
+--R             2                          n  +-----------------+ |       n
+--R          (3n log(x) + 3n log(a))log(a x )\|n log(x) + log(a) \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 610
+
+)clear all
+
+--S 611 of 5341
+t0:=1/(x^2*log(a*x^n)^(5/2))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R                     +---------+
+--R         2       n 2 |       n
+--R        x log(a x ) \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 5341
+r0:=(-2/3)/(n*x*log(a*x^n)^(3/2))+4/3*(a*x^n)^(1/n)*erf(sqrt(log(a*x^n))/_
+   sqrt(n))*sqrt(%pi)/(n^(5/2)*x)+4/3/(n^2*x*sqrt(log(a*x^n)))
+--R 
+--R
+--R   (2)
+--R                             1                 +---------+
+--R                             - +---------+     |       n
+--R         +---+       n     n n |       n      \|log(a x )       +-+       n
+--R       4\|%pi log(a x )(a x ) \|log(a x ) erf(------------) + 4\|n log(a x )
+--R                                                   +-+
+--R                                                  \|n
+--R     + 
+--R            +-+
+--R       - 2n\|n
+--R  /
+--R                       +---------+
+--R       2  +-+       n  |       n
+--R     3n x\|n log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 612
+
+-- integrate: implementation incomplete (constant residues)
+--S 613 of 5341
+--a0:=integrate(t0,x)
+--E 613
+
+--S 614 of 5341
+--m0:=a0-r0
+--E 614
+
+--S 615 of 5341
+--d0:=D(m0,x)
+--E 615
+
+)clear all
+
+--S 616 of 5341
+t0:=1/(x^3*log(a*x^n)^(5/2))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R                     +---------+
+--R         3       n 2 |       n
+--R        x log(a x ) \|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 5341
+r0:=(-2/3)/(n*x^2*log(a*x^n)^(3/2))+8/3*(a*x^n)^(2/n)*erf(sqrt(2)*_
+   sqrt(log(a*x^n))/sqrt(n))*sqrt(2*%pi)/(n^(5/2)*x^2)+8/3/(n^2*x^2*_
+   sqrt(log(a*x^n)))
+--R 
+--R
+--R   (2)
+--R                              2                     +---------+
+--R                              - +---------+     +-+ |       n
+--R         +----+       n     n n |       n      \|2 \|log(a x )
+--R       8\|2%pi log(a x )(a x ) \|log(a x ) erf(----------------)
+--R                                                      +-+
+--R                                                     \|n
+--R     + 
+--R         +-+       n       +-+
+--R       8\|n log(a x ) - 2n\|n
+--R  /
+--R                        +---------+
+--R       2 2 +-+       n  |       n
+--R     3n x \|n log(a x )\|log(a x )
+--R                                                    Type: Expression(Integer)
+--E 617
+
+-- integrate: implementation incomplete (constant residues)
+--S 618 of 5341
+--a0:=integrate(t0,x)
+--E 618
+
+--S 619 of 5341
+--m0:=a0-r0
+--E 619
+
+--S 620 of 5341
+--d0:=D(m0,x)
+--E 620
+
+)clear all
+
+--S 621 of 5341
+t0:=x^m*log(a*x)^p
+--R 
+--R
+--R         m        p
+--R   (1)  x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 5341
+--r0:=x^(1+m)*(a*x)^(-1-m)*GAMMA(1+p,-(1+m)*log(a*x))*log(a*x)^p/((1+m)*_
+--   (-(1+m)*log(a*x))^p)
+--E 622
+
+--S 623 of 5341
+--a0:=integrate(t0,x)
+--E 623
+
+--S 624 of 5341
+--m0:=a0-r0
+--E 624
+
+--S 625 of 5341
+--d0:=D(m0,x)
+--E 625
+
+)clear all
+
+--S 626 of 5341
+t0:=x^3*log(a*x)^p
+--R 
+--R
+--R         3        p
+--R   (1)  x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 5341
+--r0:=4^(-1-p)*GAMMA(1+p,-4*log(a*x))*log(a*x)^p/(a^4*(-log(a*x))^p)
+--E 627
+
+--S 628 of 5341
+--a0:=integrate(t0,x)
+--E 628
+
+--S 629 of 5341
+--m0:=a0-r0
+--E 629
+
+--S 630 of 5341
+--d0:=D(m0,x)
+--E 630
+
+)clear all
+
+--S 631 of 5341
+t0:=x^2*log(a*x)^p
+--R 
+--R
+--R         2        p
+--R   (1)  x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 5341
+--r0:=3^(-1-p)*GAMMA(1+p,-3*log(a*x))*log(a*x)^p/(a^3*(-log(a*x))^p)
+--E 632
+
+--S 633 of 5341
+--a0:=integrate(t0,x)
+--E 633
+
+--S 634 of 5341
+--m0:=a0-r0
+--E 634
+
+--S 635 of 5341
+--d0:=D(m0,x)
+--E 635
+
+)clear all
+
+--S 636 of 5341
+t0:=x*log(a*x)^p
+--R 
+--R
+--R                  p
+--R   (1)  x log(a x)
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 5341
+--r0:=2^(-1-p)*GAMMA(1+p,-2*log(a*x))*log(a*x)^p/(a^2*(-log(a*x))^p)
+--E 637
+
+--S 638 of 5341
+--a0:=integrate(t0,x)
+--E 638
+
+--S 639 of 5341
+--m0:=a0-r0
+--E 639
+
+--S 640 of 5341
+--d0:=D(m0,x)
+--E 640
+
+)clear all
+
+--S 641 of 5341
+t0:=log(a*x)^p
+--R 
+--R
+--R                p
+--R   (1)  log(a x)
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 5341
+--r0:=GAMMA(1+p,-log(a*x))*log(a*x)^p/(a*(-log(a*x))^p)
+--E 642
+
+--S 643 of 5341
+--a0:=integrate(t0,x)
+--E 643
+
+--S 644 of 5341
+--m0:=a0-r0
+--E 644
+
+--S 645 of 5341
+--d0:=D(m0,x)
+--E 645
+
+)clear all
+
+--S 646 of 5341
+t0:=log(a*x)^p/x
+--R 
+--R
+--R                p
+--R        log(a x)
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 5341
+r0:=log(a*x)^(1+p)/(1+p)
+--R 
+--R
+--R                p + 1
+--R        log(a x)
+--R   (2)  -------------
+--R            p + 1
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  p log(log(a x))
+--R        log(a x)%e
+--R   (3)  -------------------------
+--R                  p + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 648
+
+--S 649 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  p log(log(a x))           p + 1
+--R        log(a x)%e                - log(a x)
+--R   (4)  -----------------------------------------
+--R                          p + 1
+--R                                                    Type: Expression(Integer)
+--E 649
+
+--S 650 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 650
+
+)clear all
+
+--S 651 of 5341
+t0:=log(a*x)^p/x^2
+--R 
+--R
+--R                p
+--R        log(a x)
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 5341
+--r0:=-a*GAMMA(1+p,log(a*x))
+--E 652
+
+--S 653 of 5341
+--a0:=integrate(t0,x)
+--E 653
+
+--S 654 of 5341
+--m0:=a0-r0
+--E 654
+
+--S 655 of 5341
+--d0:=D(m0,x)
+--E 655
+
+)clear all
+
+--S 656 of 5341
+t0:=log(a*x)^p/x^3
+--R 
+--R
+--R                p
+--R        log(a x)
+--R   (1)  ---------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 5341
+--r0:=-2^(-1-p)*a^2*GAMMA(1+p,2*log(a*x))
+--E 657
+
+--S 658 of 5341
+--a0:=integrate(t0,x)
+--E 658
+
+--S 659 of 5341
+--m0:=a0-r0
+--E 659
+
+--S 660 of 5341
+--d0:=D(m0,x)
+--E 660
+
+)clear all
+
+--S 661 of 5341
+t0:=x^m*log(a*x^n)^p
+--R 
+--R
+--R         m       n p
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 5341
+--r0:=x^(1+m)*GAMMA(1+p,-(1+m)*log(a*x^n)/n)*log(a*x^n)^p/((1+m)*_
+--   (a*x^n)^((1+m)/n)*(-(1+m)*log(a*x^n)/n)^p)
+--E 662
+
+--S 663 of 5341
+--a0:=integrate(t0,x)
+--E 663
+
+--S 664 of 5341
+--m0:=a0-r0
+--E 664
+
+--S 665 of 5341
+--d0:=D(m0,x)
+--E 665
+
+)clear all
+
+--S 666 of 5341
+t0:=x^(-1+n)*log(a*x^n)^p
+--R 
+--R
+--R         n - 1       n p
+--R   (1)  x     log(a x )
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 5341
+--r0:=GAMMA(1+p,-log(a*x^n))*log(a*x^n)^p/(a*n*(-log(a*x^n))^p)
+--E 667
+
+--S 668 of 5341
+--a0:=integrate(t0,x)
+--E 668
+
+--S 669 of 5341
+--m0:=a0-r0
+--E 669
+
+--S 670 of 5341
+--d0:=D(m0,x)
+--E 670
+
+)clear all
+
+--S 671 of 5341
+t0:=x^3*log(a*x^n)^p
+--R 
+--R
+--R         3       n p
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 5341
+--r0:=4^(-1-p)*x^4*GAMMA(1+p,-4*log(a*x^n)/n)*log(a*x^n)^p/((a*x^n)^(4/n)*_
+--   (-log(a*x^n)/n)^p)
+--E 672
+
+--S 673 of 5341
+--a0:=integrate(t0,x)
+--E 673
+
+--S 674 of 5341
+--m0:=a0-r0
+--E 674
+
+--S 675 of 5341
+--d0:=D(m0,x)
+--E 675
+
+)clear all
+
+--S 676 of 5341
+t0:=x^2*log(a*x^n)^p
+--R 
+--R
+--R         2       n p
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 5341
+--r0:=3^(-1-p)*x^3*GAMMA(1+p,-3*log(a*x^n)/n)*log(a*x^n)^p/((a*x^n)^(3/n)*_
+--   (-log(a*x^n)/n)^p)
+--E 677
+
+--S 678 of 5341
+--a0:=integrate(t0,x)
+--E 678
+
+--S 679 of 5341
+--m0:=a0-r0
+--E 679
+
+--S 680 of 5341
+--d0:=D(m0,x)
+--E 680
+
+)clear all
+
+--S 681 of 5341
+t0:=x*log(a*x^n)^p
+--R 
+--R
+--R                 n p
+--R   (1)  x log(a x )
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 5341
+--r0:=2^(-1-p)*x^2*GAMMA(1+p,-2*log(a*x^n)/n)*log(a*x^n)^p/((a*x^n)^(2/n)*_
+--   (-log(a*x^n)/n)^p)
+--E 682
+
+--S 683 of 5341
+--a0:=integrate(t0,x)
+--E 683
+
+--S 684 of 5341
+--m0:=a0-r0
+--E 684
+
+--S 685 of 5341
+--d0:=D(m0,x)
+--E 685
+
+)clear all
+
+--S 686 of 5341
+t0:=log(a*x^n)^p
+--R 
+--R
+--R               n p
+--R   (1)  log(a x )
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 5341
+--r0:=x*GAMMA(1+p,-log(a*x^n)/n)*log(a*x^n)^p/((a*x^n)^(1/n)*(-log(a*x^n)/n)^p)
+--E 687
+
+--S 688 of 5341
+--a0:=integrate(t0,x)
+--E 688
+
+--S 689 of 5341
+--m0:=a0-r0
+--E 689
+
+--S 690 of 5341
+--d0:=D(m0,x)
+--E 690
+
+)clear all
+
+--S 691 of 5341
+t0:=log(a*x^n)^p/x
+--R 
+--R
+--R               n p
+--R        log(a x )
+--R   (1)  ----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 691
+
+--S 692 of 5341
+r0:=log(a*x^n)^(1+p)/(n*(1+p))
+--R 
+--R
+--R               n p + 1
+--R        log(a x )
+--R   (2)  --------------
+--R            n p + n
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             p log(n log(x) + log(a))
+--R        (n log(x) + log(a))%e
+--R   (3)  ---------------------------------------------
+--R                           n p + n
+--R                                         Type: Union(Expression(Integer),...)
+--E 693
+
+--S 694 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                 n p + 1                        p log(n log(x) + log(a))
+--R        - log(a x )      + (n log(x) + log(a))%e
+--R   (4)  ----------------------------------------------------------------
+--R                                     n p + n
+--R                                                    Type: Expression(Integer)
+--E 694
+
+--S 695 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 695
+
+)clear all
+
+--S 696 of 5341
+t0:=log(a*x^n)^p/x^2
+--R 
+--R
+--R               n p
+--R        log(a x )
+--R   (1)  ----------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 5341
+--r0:=-(a*x^n)^(1/n)*GAMMA(1+p,log(a*x^n)/n)*log(a*x^n)^p/(x*(log(a*x^n)/n)^p)
+--E 697
+
+--S 698 of 5341
+--a0:=integrate(t0,x)
+--E 698
+
+--S 699 of 5341
+--m0:=a0-r0
+--E 699
+
+--S 700 of 5341
+--d0:=D(m0,x)
+--E 700
+
+)clear all
+
+--S 701 of 5341
+t0:=log(a*x^n)^p/x^3
+--R 
+--R
+--R               n p
+--R        log(a x )
+--R   (1)  ----------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 5341
+--r0:=-2^(-1-p)*(a*x^n)^(2/n)*GAMMA(1+p,2*log(a*x^n)/n)*log(a*x^n)^p/_
+--   (x^2*(log(a*x^n)/n)^p)
+--E 702
+
+--S 703 of 5341
+--a0:=integrate(t0,x)
+--E 703
+
+--S 704 of 5341
+--m0:=a0-r0
+--E 704
+
+--S 705 of 5341
+--d0:=D(m0,x)
+--E 705
+
+)clear all
+
+--S 706 of 5341
+t0:=x^m*log(c*(b*x^n)^p)
+--R 
+--R
+--R         m          n p
+--R   (1)  x log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 5341
+r0:=-n*p*x^(1+m)/(1+m)^2+x^(1+m)*log(c*(b*x^n)^p)/(1+m)
+--R 
+--R
+--R                m + 1          n p         m + 1
+--R        (m + 1)x     log(c (b x ) ) - n p x
+--R   (2)  ----------------------------------------
+--R                        2
+--R                       m  + 2m + 1
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                                        m log(x)
+--R   ((m + 1)n p x log(x) + (m + 1)x log(c) + (m + 1)p x log(b) - n p x)%e
+--R   -----------------------------------------------------------------------------
+--R                                     2
+--R                                    m  + 2m + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 708
+
+--S 709 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 m + 1          n p
+--R       (- m - 1)x     log(c (b x ) )
+--R     + 
+--R         ((m + 1)n p x log(x) + (m + 1)x log(c) + (m + 1)p x log(b) - n p x)
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R            m + 1
+--R       n p x
+--R  /
+--R      2
+--R     m  + 2m + 1
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 710
+
+)clear all
+
+--S 711 of 5341
+t0:=x^2*log(c*(b*x^n)^p)
+--R 
+--R
+--R         2          n p
+--R   (1)  x log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 5341
+r0:=-1/9*n*p*x^3+1/3*x^3*log(c*(b*x^n)^p)
+--R 
+--R
+--R          3          n p         3
+--R        3x log(c (b x ) ) - n p x
+--R   (2)  --------------------------
+--R                     9
+--R                                                    Type: Expression(Integer)
+--E 712
+
+--S 713 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3           3             3              3
+--R        3n p x log(x) + 3x log(c) + 3p x log(b) - n p x
+--R   (3)  ------------------------------------------------
+--R                                9
+--R                                         Type: Union(Expression(Integer),...)
+--E 713
+
+--S 714 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           3          n p         3          3            3
+--R        - x log(c (b x ) ) + n p x log(x) + x log(c) + p x log(b)
+--R   (4)  ---------------------------------------------------------
+--R                                    3
+--R                                                    Type: Expression(Integer)
+--E 714
+
+--S 715 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 715
+
+)clear all
+
+--S 716 of 5341
+t0:=x*log(c*(b*x^n)^p)
+--R 
+--R
+--R                    n p
+--R   (1)  x log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 5341
+r0:=-1/4*n*p*x^2+1/2*x^2*log(c*(b*x^n)^p)
+--R 
+--R
+--R          2          n p         2
+--R        2x log(c (b x ) ) - n p x
+--R   (2)  --------------------------
+--R                     4
+--R                                                    Type: Expression(Integer)
+--E 717
+
+--S 718 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2           2             2              2
+--R        2n p x log(x) + 2x log(c) + 2p x log(b) - n p x
+--R   (3)  ------------------------------------------------
+--R                                4
+--R                                         Type: Union(Expression(Integer),...)
+--E 718
+
+--S 719 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           2          n p         2          2            2
+--R        - x log(c (b x ) ) + n p x log(x) + x log(c) + p x log(b)
+--R   (4)  ---------------------------------------------------------
+--R                                    2
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 720
+
+)clear all
+
+--S 721 of 5341
+t0:=log(c*(b*x^n)^p)
+--R 
+--R
+--R                  n p
+--R   (1)  log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 5341
+r0:=-n*p*x+x*log(c*(b*x^n)^p)
+--R 
+--R
+--R                    n p
+--R   (2)  x log(c (b x ) ) - n p x
+--R                                                    Type: Expression(Integer)
+--E 722
+
+--S 723 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  n p x log(x) + x log(c) + p x log(b) - n p x
+--R                                         Type: Union(Expression(Integer),...)
+--E 723
+
+--S 724 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                      n p
+--R   (4)  - x log(c (b x ) ) + n p x log(x) + x log(c) + p x log(b)
+--R                                                    Type: Expression(Integer)
+--E 724
+
+--S 725 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 725
+
+)clear all
+
+--S 726 of 5341
+t0:=log(c*(b*x^n)^p)/x
+--R 
+--R
+--R                  n p
+--R        log(c (b x ) )
+--R   (1)  --------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 726
+
+--S 727 of 5341
+r0:=1/2*log(c*(b*x^n)^p)^2/(n*p),-1/2*n*p*log(x)^2+log(x)*log(c*(b*x^n)^p)
+--R 
+--R
+--R                   n p 2                  n p              2
+--R         log(c (b x ) )  2log(x)log(c (b x ) ) - n p log(x)
+--R   (2)  [---------------,-----------------------------------]
+--R               2n p                       2
+--R                                             Type: Tuple(Expression(Integer))
+--E 727
+
+--S 728 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  2
+--R        n p log(x)  + (2log(c) + 2p log(b))log(x)
+--R   (3)  -----------------------------------------
+--R                            2
+--R                                         Type: Union(Expression(Integer),...)
+--E 728
+
+--S 729 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                    n p 2    2 2      2                      2
+--R        - log(c (b x ) )  + n p log(x)  + (2n p log(c) + 2n p log(b))log(x)
+--R   (4)  -------------------------------------------------------------------
+--R                                        2n p
+--R                                                    Type: Expression(Integer)
+--E 729
+
+--S 730 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 730
+
+)clear all
+
+--S 731 of 5341
+t0:=log(c*(b*x^n)^p)/x^2
+--R 
+--R
+--R                  n p
+--R        log(c (b x ) )
+--R   (1)  --------------
+--R               2
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 5341
+r0:=-n*p/x-log(c*(b*x^n)^p)/x
+--R 
+--R
+--R                    n p
+--R        - log(c (b x ) ) - n p
+--R   (2)  ----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - n p log(x) - log(c) - p log(b) - n p
+--R   (3)  --------------------------------------
+--R                           x
+--R                                         Type: Union(Expression(Integer),...)
+--E 733
+
+--S 734 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  n p
+--R        log(c (b x ) ) - n p log(x) - log(c) - p log(b)
+--R   (4)  -----------------------------------------------
+--R                               x
+--R                                                    Type: Expression(Integer)
+--E 734
+
+--S 735 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 735
+
+)clear all
+
+--S 736 of 5341
+t0:=log(c*(b*x^n)^p)/x^3
+--R 
+--R
+--R                  n p
+--R        log(c (b x ) )
+--R   (1)  --------------
+--R               3
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 736
+
+--S 737 of 5341
+r0:=-1/4*n*p/x^2-1/2*log(c*(b*x^n)^p)/x^2
+--R 
+--R
+--R                     n p
+--R        - 2log(c (b x ) ) - n p
+--R   (2)  -----------------------
+--R                    2
+--R                  4x
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 2n p log(x) - 2log(c) - 2p log(b) - n p
+--R   (3)  -----------------------------------------
+--R                             2
+--R                           4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 738
+
+--S 739 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  n p
+--R        log(c (b x ) ) - n p log(x) - log(c) - p log(b)
+--R   (4)  -----------------------------------------------
+--R                                2
+--R                              2x
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 740
+
+)clear all
+
+--S 741 of 5341
+t0:=log(c*(b*x^n)^p)/x^4
+--R 
+--R
+--R                  n p
+--R        log(c (b x ) )
+--R   (1)  --------------
+--R               4
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 741
+
+--S 742 of 5341
+r0:=-1/9*n*p/x^3-1/3*log(c*(b*x^n)^p)/x^3
+--R 
+--R
+--R                     n p
+--R        - 3log(c (b x ) ) - n p
+--R   (2)  -----------------------
+--R                    3
+--R                  9x
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - 3n p log(x) - 3log(c) - 3p log(b) - n p
+--R   (3)  -----------------------------------------
+--R                             3
+--R                           9x
+--R                                         Type: Union(Expression(Integer),...)
+--E 743
+
+--S 744 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  n p
+--R        log(c (b x ) ) - n p log(x) - log(c) - p log(b)
+--R   (4)  -----------------------------------------------
+--R                                3
+--R                              3x
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 745
+
+)clear all
+
+--S 746 of 5341
+t0:=x^m*log(c*(b*x^n)^p)^2
+--R 
+--R
+--R         m          n p 2
+--R   (1)  x log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 5341
+r0:=2*n^2*p^2*x^(1+m)/(1+m)^3-2*n*p*x^(1+m)*log(c*(b*x^n)^p)/(1+m)^2+_
+   x^(1+m)*log(c*(b*x^n)^p)^2/(1+m)
+--R 
+--R
+--R   (2)
+--R         2           m + 1          n p 2                  m + 1          n p
+--R       (m  + 2m + 1)x     log(c (b x ) )  + (- 2m - 2)n p x     log(c (b x ) )
+--R     + 
+--R         2 2 m + 1
+--R       2n p x
+--R  /
+--R      3     2
+--R     m  + 3m  + 3m + 1
+--R                                                    Type: Expression(Integer)
+--E 747
+
+--S 748 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2           2 2        2
+--R         (m  + 2m + 1)n p x log(x)
+--R       + 
+--R                2                            2             2
+--R             (2m  + 4m + 2)n p x log(c) + (2m  + 4m + 2)n p x log(b)
+--R           + 
+--R                        2 2
+--R             (- 2m - 2)n p x
+--R        *
+--R           log(x)
+--R       + 
+--R           2                  2
+--R         (m  + 2m + 1)x log(c)
+--R       + 
+--R             2
+--R         ((2m  + 4m + 2)p x log(b) + (- 2m - 2)n p x)log(c)
+--R       + 
+--R           2           2        2                2             2 2
+--R         (m  + 2m + 1)p x log(b)  + (- 2m - 2)n p x log(b) + 2n p x
+--R    *
+--R         m log(x)
+--R       %e
+--R  /
+--R      3     2
+--R     m  + 3m  + 3m + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 748
+
+--S 749 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2           m + 1          n p 2                m + 1          n p
+--R       (- m  - 2m - 1)x     log(c (b x ) )  + (2m + 2)n p x     log(c (b x ) )
+--R     + 
+--R             2           2 2        2
+--R           (m  + 2m + 1)n p x log(x)
+--R         + 
+--R                  2                            2             2
+--R               (2m  + 4m + 2)n p x log(c) + (2m  + 4m + 2)n p x log(b)
+--R             + 
+--R                          2 2
+--R               (- 2m - 2)n p x
+--R          *
+--R             log(x)
+--R         + 
+--R             2                  2
+--R           (m  + 2m + 1)x log(c)
+--R         + 
+--R               2
+--R           ((2m  + 4m + 2)p x log(b) + (- 2m - 2)n p x)log(c)
+--R         + 
+--R             2           2        2                2             2 2
+--R           (m  + 2m + 1)p x log(b)  + (- 2m - 2)n p x log(b) + 2n p x
+--R      *
+--R           m log(x)
+--R         %e
+--R     + 
+--R           2 2 m + 1
+--R       - 2n p x
+--R  /
+--R      3     2
+--R     m  + 3m  + 3m + 1
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 750
+
+)clear all
+
+--S 751 of 5341
+t0:=x^2*log(c*(b*x^n)^p)^2
+--R 
+--R
+--R         2          n p 2
+--R   (1)  x log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 5341
+r0:=2/27*n^2*p^2*x^3-2/9*n*p*x^3*log(c*(b*x^n)^p)+1/3*x^3*log(c*(b*x^n)^p)^2
+--R 
+--R
+--R          3          n p 2         3          n p      2 2 3
+--R        9x log(c (b x ) )  - 6n p x log(c (b x ) ) + 2n p x
+--R   (2)  ----------------------------------------------------
+--R                                 27
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2 2 3      2           3              2 3           2 2 3
+--R       9n p x log(x)  + (18n p x log(c) + 18n p x log(b) - 6n p x )log(x)
+--R     + 
+--R         3      2         3               3            2 3      2
+--R       9x log(c)  + (18p x log(b) - 6n p x )log(c) + 9p x log(b)
+--R     + 
+--R             2 3           2 2 3
+--R       - 6n p x log(b) + 2n p x
+--R  /
+--R     27
+--R                                         Type: Union(Expression(Integer),...)
+--E 753
+
+--S 754 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3          n p 2         3          n p      2 2 3      2
+--R       - 3x log(c (b x ) )  + 2n p x log(c (b x ) ) + 3n p x log(x)
+--R     + 
+--R              3             2 3           2 2 3            3      2
+--R       (6n p x log(c) + 6n p x log(b) - 2n p x )log(x) + 3x log(c)
+--R     + 
+--R            3               3            2 3      2       2 3
+--R       (6p x log(b) - 2n p x )log(c) + 3p x log(b)  - 2n p x log(b)
+--R  /
+--R     9
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 755
+
+)clear all
+
+--S 756 of 5341
+t0:=x*log(c*(b*x^n)^p)^2
+--R 
+--R
+--R                    n p 2
+--R   (1)  x log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 5341
+r0:=1/4*n^2*p^2*x^2-1/2*n*p*x^2*log(c*(b*x^n)^p)+1/2*x^2*log(c*(b*x^n)^p)^2
+--R 
+--R
+--R          2          n p 2         2          n p     2 2 2
+--R        2x log(c (b x ) )  - 2n p x log(c (b x ) ) + n p x
+--R   (2)  ---------------------------------------------------
+--R                                 4
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2 2 2      2          2             2 2           2 2 2
+--R       2n p x log(x)  + (4n p x log(c) + 4n p x log(b) - 2n p x )log(x)
+--R     + 
+--R         2      2        2               2            2 2      2       2 2
+--R       2x log(c)  + (4p x log(b) - 2n p x )log(c) + 2p x log(b)  - 2n p x log(b)
+--R     + 
+--R        2 2 2
+--R       n p x
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 758
+
+--S 759 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          2          n p 2        2          n p     2 2 2      2
+--R       - x log(c (b x ) )  + n p x log(c (b x ) ) + n p x log(x)
+--R     + 
+--R              2             2 2          2 2 2           2      2
+--R       (2n p x log(c) + 2n p x log(b) - n p x )log(x) + x log(c)
+--R     + 
+--R            2              2           2 2      2      2 2
+--R       (2p x log(b) - n p x )log(c) + p x log(b)  - n p x log(b)
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 760
+
+)clear all
+
+--S 761 of 5341
+t0:=log(c*(b*x^n)^p)^2
+--R 
+--R
+--R                  n p 2
+--R   (1)  log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 5341
+r0:=2*n^2*p^2*x-2*n*p*x*log(c*(b*x^n)^p)+x*log(c*(b*x^n)^p)^2
+--R 
+--R
+--R                    n p 2                    n p      2 2
+--R   (2)  x log(c (b x ) )  - 2n p x log(c (b x ) ) + 2n p x
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      2 2        2                        2             2 2                   2
+--R     n p x log(x)  + (2n p x log(c) + 2n p x log(b) - 2n p x)log(x) + x log(c)
+--R   + 
+--R                                     2        2       2             2 2
+--R     (2p x log(b) - 2n p x)log(c) + p x log(b)  - 2n p x log(b) + 2n p x
+--R                                         Type: Union(Expression(Integer),...)
+--E 763
+
+--S 764 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   n p 2                    n p     2 2        2
+--R     - x log(c (b x ) )  + 2n p x log(c (b x ) ) + n p x log(x)
+--R   + 
+--R                          2             2 2                   2
+--R     (2n p x log(c) + 2n p x log(b) - 2n p x)log(x) + x log(c)
+--R   + 
+--R                                     2        2       2
+--R     (2p x log(b) - 2n p x)log(c) + p x log(b)  - 2n p x log(b)
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 765
+
+)clear all
+
+--S 766 of 5341
+t0:=log(c*(b*x^n)^p)^2/x
+--R 
+--R
+--R                  n p 2
+--R        log(c (b x ) )
+--R   (1)  ---------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 5341
+r0:=1/3*log(c*(b*x^n)^p)^3/(n*p)
+--R 
+--R
+--R                  n p 3
+--R        log(c (b x ) )
+--R   (2)  ---------------
+--R              3n p
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R        2 2      3                      2             2
+--R       n p log(x)  + (3n p log(c) + 3n p log(b))log(x)
+--R     + 
+--R               2                       2      2
+--R       (3log(c)  + 6p log(b)log(c) + 3p log(b) )log(x)
+--R  /
+--R     3
+--R                                         Type: Union(Expression(Integer),...)
+--E 768
+
+--S 769 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                   n p 3    3 3      3      2 2           2 3             2
+--R       - log(c (b x ) )  + n p log(x)  + (3n p log(c) + 3n p log(b))log(x)
+--R     + 
+--R                   2       2                   3      2
+--R       (3n p log(c)  + 6n p log(b)log(c) + 3n p log(b) )log(x)
+--R  /
+--R     3n p
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 770
+
+)clear all
+
+--S 771 of 5341
+t0:=log(c*(b*x^n)^p)^2/x^2
+--R 
+--R
+--R                  n p 2
+--R        log(c (b x ) )
+--R   (1)  ---------------
+--R                2
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 771
+
+--S 772 of 5341
+r0:=-2*n^2*p^2/x-2*n*p*log(c*(b*x^n)^p)/x-log(c*(b*x^n)^p)^2/x
+--R 
+--R
+--R                    n p 2                  n p      2 2
+--R        - log(c (b x ) )  - 2n p log(c (b x ) ) - 2n p
+--R   (2)  -----------------------------------------------
+--R                               x
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2      2                        2           2 2                2
+--R       - n p log(x)  + (- 2n p log(c) - 2n p log(b) - 2n p )log(x) - log(c)
+--R     + 
+--R                                     2      2       2           2 2
+--R       (- 2p log(b) - 2n p)log(c) - p log(b)  - 2n p log(b) - 2n p
+--R  /
+--R     x
+--R                                         Type: Union(Expression(Integer),...)
+--E 773
+
+--S 774 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 n p 2                  n p     2 2      2
+--R       log(c (b x ) )  + 2n p log(c (b x ) ) - n p log(x)
+--R     + 
+--R                            2           2 2                2
+--R       (- 2n p log(c) - 2n p log(b) - 2n p )log(x) - log(c)
+--R     + 
+--R                                     2      2       2
+--R       (- 2p log(b) - 2n p)log(c) - p log(b)  - 2n p log(b)
+--R  /
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 775
+
+)clear all
+
+--S 776 of 5341
+t0:=log(c*(b*x^n)^p)^2/x^3
+--R 
+--R
+--R                  n p 2
+--R        log(c (b x ) )
+--R   (1)  ---------------
+--R                3
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 5341
+r0:=-1/4*n^2*p^2/x^2-1/2*n*p*log(c*(b*x^n)^p)/x^2-1/2*log(c*(b*x^n)^p)^2/x^2
+--R 
+--R
+--R                     n p 2                  n p     2 2
+--R        - 2log(c (b x ) )  - 2n p log(c (b x ) ) - n p
+--R   (2)  -----------------------------------------------
+--R                                2
+--R                              4x
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 2      2                        2           2 2                 2
+--R       - 2n p log(x)  + (- 4n p log(c) - 4n p log(b) - 2n p )log(x) - 2log(c)
+--R     + 
+--R                                      2      2       2          2 2
+--R       (- 4p log(b) - 2n p)log(c) - 2p log(b)  - 2n p log(b) - n p
+--R  /
+--R       2
+--R     4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 778
+
+--S 779 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 n p 2                 n p     2 2      2
+--R       log(c (b x ) )  + n p log(c (b x ) ) - n p log(x)
+--R     + 
+--R                            2          2 2                2
+--R       (- 2n p log(c) - 2n p log(b) - n p )log(x) - log(c)
+--R     + 
+--R                                    2      2      2
+--R       (- 2p log(b) - n p)log(c) - p log(b)  - n p log(b)
+--R  /
+--R       2
+--R     2x
+--R                                                    Type: Expression(Integer)
+--E 779
+
+--S 780 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 780
+
+)clear all
+
+--S 781 of 5341
+t0:=log(c*(b*x^n)^p)^2/x^4
+--R 
+--R
+--R                  n p 2
+--R        log(c (b x ) )
+--R   (1)  ---------------
+--R                4
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 781
+
+--S 782 of 5341
+r0:=-2/27*n^2*p^2/x^3-2/9*n*p*log(c*(b*x^n)^p)/x^3-1/3*log(c*(b*x^n)^p)^2/x^3
+--R 
+--R
+--R                     n p 2                  n p      2 2
+--R        - 9log(c (b x ) )  - 6n p log(c (b x ) ) - 2n p
+--R   (2)  ------------------------------------------------
+--R                                 3
+--R                              27x
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 2      2                          2           2 2                 2
+--R       - 9n p log(x)  + (- 18n p log(c) - 18n p log(b) - 6n p )log(x) - 9log(c)
+--R     + 
+--R                                       2      2       2           2 2
+--R       (- 18p log(b) - 6n p)log(c) - 9p log(b)  - 6n p log(b) - 2n p
+--R  /
+--R        3
+--R     27x
+--R                                         Type: Union(Expression(Integer),...)
+--E 783
+
+--S 784 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  n p 2                  n p      2 2      2
+--R       3log(c (b x ) )  + 2n p log(c (b x ) ) - 3n p log(x)
+--R     + 
+--R                            2           2 2                 2
+--R       (- 6n p log(c) - 6n p log(b) - 2n p )log(x) - 3log(c)
+--R     + 
+--R                                      2      2       2
+--R       (- 6p log(b) - 2n p)log(c) - 3p log(b)  - 2n p log(b)
+--R  /
+--R       3
+--R     9x
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 785
+
+)clear all
+
+--S 786 of 5341
+t0:=x^m/log(c*(b*x^n)^p)
+--R 
+--R
+--R               m
+--R              x
+--R   (1)  --------------
+--R                  n p
+--R        log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 5341
+--r0:=x^(1+m)*Ei((1+m)*log(c*(b*x^n)^p)/(n*p))/(n*p*(c*_
+--   (b*x^n)^p)^((1+m)/(n*p)))
+--E 787
+
+--S 788 of 5341
+--a0:=integrate(t0,x)
+--E 788
+
+--S 789 of 5341
+--m0:=a0-r0
+--E 789
+
+--S 790 of 5341
+--d0:=D(m0,x)
+--E 790
+
+)clear all
+
+--S 791 of 5341
+t0:=x^m/log(c*(b*x^n)^p)^2
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ---------------
+--R                  n p 2
+--R        log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 5341
+--r0:=(1+m)*x^(1+m)*Ei((1+m)*log(c*(b*x^n)^p)/(n*p))/(n^2*p^2*_
+--   (c*(b*x^n)^p)^((1+m)/(n*p)))-x^(1+m)/(n*p*log(c*(b*x^n)^p))
+--E 792
+
+--S 793 of 5341
+--a0:=integrate(t0,x)
+--E 793
+
+--S 794 of 5341
+--m0:=a0-r0
+--E 794
+
+--S 795 of 5341
+--d0:=D(m0,x)
+--E 795
+
+)clear all
+
+--S 796 of 5341
+t0:=x^m*log(c*(b*x^n)^p)^q
+--R 
+--R
+--R         m          n p q
+--R   (1)  x log(c (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 5341
+--r0:=x^(1+m)*GAMMA(1+q,-(1+m)*log(c*(b*x^n)^p)/(n*p))*log(c*(b*x^n)^p)^q/_
+--   ((1+m)*(c*(b*x^n)^p)^((1+m)/(n*p))*(-(1+m)*log(c*(b*x^n)^p)/(n*p))^q)
+--E 797
+
+--S 798 of 5341
+--a0:=integrate(t0,x)
+--E 798
+
+--S 799 of 5341
+--m0:=a0-r0
+--E 799
+
+--S 800 of 5341
+--d0:=D(m0,x)
+--E 800
+
+)clear all
+
+--S 801 of 5341
+t0:=(a+b*x)^m*log(c*x)
+--R 
+--R
+--R                         m
+--R   (1)  log(c x)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 801
+
+--S 802 of 5341
+--r0:=-(a+b*x)^(1+m)/(b*(1+m)^2)+(a+b*x)^(1+m)*hypergeometric(1,1+m,2+m,_
+--   (a+b*x)/a)/(b*(1+m)^2)+(a+b*x)^(1+m)*log(c*x)/(b*(1+m))
+--E 802
+
+--S 803 of 5341
+--a0:=integrate(t0,x)
+--E 803
+
+--S 804 of 5341
+--m0:=a0-r0
+--E 804
+
+--S 805 of 5341
+--d0:=D(m0,x)
+--E 805
+
+)clear all
+
+--S 806 of 5341
+t0:=(a+b*x)^3*log(c*x)
+--R 
+--R
+--R          3 3       2 2     2       3
+--R   (1)  (b x  + 3a b x  + 3a b x + a )log(c x)
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 5341
+r0:=-a^3*x-3/4*a^2*b*x^2-1/3*a*b^2*x^3-1/16*b^3*x^4-1/4*a^4*log(x)/b+_
+   1/4*(a+b*x)^4*log(c*x)/b
+--R 
+--R
+--R   (2)
+--R           4 4        3 3      2 2 2      3         4               4
+--R       (12b x  + 48a b x  + 72a b x  + 48a b x + 12a )log(c x) - 12a log(x)
+--R     + 
+--R           4 4        3 3      2 2 2      3
+--R       - 3b x  - 16a b x  - 36a b x  - 48a b x
+--R  /
+--R     48b
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 4        2 3      2   2      3               3 4        2 3
+--R       (12b x  + 48a b x  + 72a b x  + 48a x)log(c x) - 3b x  - 16a b x
+--R     + 
+--R            2   2      3
+--R       - 36a b x  - 48a x
+--R  /
+--R     48
+--R                                         Type: Union(Expression(Integer),...)
+--E 808
+
+--S 809 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           4            4
+--R        - a log(c x) + a log(x)
+--R   (4)  -----------------------
+--R                   4b
+--R                                                    Type: Expression(Integer)
+--E 809
+
+--S 810 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 810
+
+)clear all
+
+--S 811 of 5341
+t0:=(a+b*x)^2*log(c*x)
+--R 
+--R
+--R          2 2             2
+--R   (1)  (b x  + 2a b x + a )log(c x)
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 5341
+r0:=-a^2*x-1/2*a*b*x^2-1/9*b^2*x^3-1/3*a^3*log(x)/b+1/3*(a+b*x)^3*log(c*x)/b
+--R 
+--R
+--R   (2)
+--R          3 3        2 2      2        3              3           3 3       2 2
+--R       (6b x  + 18a b x  + 18a b x + 6a )log(c x) - 6a log(x) - 2b x  - 9a b x
+--R     + 
+--R            2
+--R       - 18a b x
+--R  /
+--R     18b
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 3          2      2               2 3         2      2
+--R        (6b x  + 18a b x  + 18a x)log(c x) - 2b x  - 9a b x  - 18a x
+--R   (3)  ------------------------------------------------------------
+--R                                     18
+--R                                         Type: Union(Expression(Integer),...)
+--E 813
+
+--S 814 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           3            3
+--R        - a log(c x) + a log(x)
+--R   (4)  -----------------------
+--R                   3b
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 815
+
+)clear all
+
+--S 816 of 5341
+t0:=(a+b*x)*log(c*x)
+--R 
+--R
+--R   (1)  (b x + a)log(c x)
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 5341
+r0:=-a*x-1/4*b*x^2+1/2*x*(2*a+b*x)*log(c*x),-a*x-1/4*b*x^2-1/2*a^2*log(x)/b+_
+   1/2*(a+b*x)^2*log(c*x)/b
+--R 
+--R
+--R   (2)
+--R         2                      2
+--R    (2b x  + 4a x)log(c x) - b x  - 4a x
+--R   [------------------------------------,
+--R                      4
+--R       2 2              2              2          2 2
+--R    (2b x  + 4a b x + 2a )log(c x) - 2a log(x) - b x  - 4a b x
+--R    ----------------------------------------------------------]
+--R                                4b
+--R                                             Type: Tuple(Expression(Integer))
+--E 817
+
+--S 818 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R             2                      2
+--R        (2b x  + 4a x)log(c x) - b x  - 4a x
+--R   (3)  ------------------------------------
+--R                          4
+--R                                         Type: Union(Expression(Integer),...)
+--E 818
+
+--S 819 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 820
+
+)clear all
+
+--S 821 of 5341
+t0:=log(c*x)/(a+b*x)
+--R 
+--R
+--R        log(c x)
+--R   (1)  --------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 5341
+--r0:=log(c*x)*log((a+b*x)/a)/b+polylog(2,-b*x/a)/b
+--E 822
+
+--S 823 of 5341
+--a0:=integrate(t0,x)
+--E 823
+
+--S 824 of 5341
+--m0:=a0-r0
+--E 824
+
+--S 825 of 5341
+--d0:=D(m0,x)
+--E 825
+
+)clear all
+
+--S 826 of 5341
+t0:=log(c*x)/(a+b*x)^2
+--R 
+--R
+--R             log(c x)
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 5341
+r0:=log(x)/(a*b)-log(c*x)/(b*(a+b*x))-log(a+b*x)/(a*b)
+--R 
+--R
+--R        - a log(c x) + (- b x - a)log(b x + a) + (b x + a)log(x)
+--R   (2)  --------------------------------------------------------
+--R                                  2     2
+--R                               a b x + a b
+--R                                                    Type: Expression(Integer)
+--E 827
+
+--S 828 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - a log(c x) + (- b x - a)log(b x + a) + (b x + a)log(x)
+--R   (3)  --------------------------------------------------------
+--R                                  2     2
+--R                               a b x + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 828
+
+--S 829 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 830
+
+)clear all
+
+--S 831 of 5341
+t0:=log(c*x)/(a+b*x)^3
+--R 
+--R
+--R                  log(c x)
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        b x  + 3a b x  + 3a b x + a
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 5341
+r0:=1/2/(a*b*(a+b*x))+1/2*log(x)/(a^2*b)-1/2*log(c*x)/(b*(a+b*x)^2)-_
+   1/2*log(a+b*x)/(a^2*b)
+--R 
+--R
+--R   (2)
+--R          2               2 2             2
+--R       - a log(c x) + (- b x  - 2a b x - a )log(b x + a)
+--R     + 
+--R         2 2             2                   2
+--R       (b x  + 2a b x + a )log(x) + a b x + a
+--R  /
+--R       2 3 2     3 2      4
+--R     2a b x  + 4a b x + 2a b
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2               2 2             2
+--R       - a log(c x) + (- b x  - 2a b x - a )log(b x + a)
+--R     + 
+--R         2 2             2                   2
+--R       (b x  + 2a b x + a )log(x) + a b x + a
+--R  /
+--R       2 3 2     3 2      4
+--R     2a b x  + 4a b x + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 833
+
+--S 834 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 834
+
+--S 835 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 835
+
+)clear all
+
+--S 836 of 5341
+t0:=log(c*x)/(a+b*x)^4
+--R 
+--R
+--R                       log(c x)
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        b x  + 4a b x  + 6a b x  + 4a b x + a
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 5341
+r0:=1/6/(a*b*(a+b*x)^2)+1/3/(a^2*b*(a+b*x))+1/3*log(x)/(a^3*b)-_
+   1/3*log(c*x)/(b*(a+b*x)^3)-1/3*log(a+b*x)/(a^3*b)
+--R 
+--R
+--R   (2)
+--R           3                3 3       2 2     2        3
+--R       - 2a log(c x) + (- 2b x  - 6a b x  - 6a b x - 2a )log(b x + a)
+--R     + 
+--R          3 3       2 2     2        3              2 2     2        3
+--R       (2b x  + 6a b x  + 6a b x + 2a )log(x) + 2a b x  + 5a b x + 3a
+--R  /
+--R       3 4 3      4 3 2      5 2      6
+--R     6a b x  + 18a b x  + 18a b x + 6a b
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3                3 3       2 2     2        3
+--R       - 2a log(c x) + (- 2b x  - 6a b x  - 6a b x - 2a )log(b x + a)
+--R     + 
+--R          3 3       2 2     2        3              2 2     2        3
+--R       (2b x  + 6a b x  + 6a b x + 2a )log(x) + 2a b x  + 5a b x + 3a
+--R  /
+--R       3 4 3      4 3 2      5 2      6
+--R     6a b x  + 18a b x  + 18a b x + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 838
+
+--S 839 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 839
+
+--S 840 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 840
+
+)clear all
+
+--S 841 of 5341
+t0:=(a+b*x)^m*log(c*x^n)
+--R 
+--R
+--R                 m       n
+--R   (1)  (b x + a) log(c x )
+--R                                                    Type: Expression(Integer)
+--E 841
+
+--S 842 of 5341
+--r0:=-n*(a+b*x)^(1+m)/(b*(1+m)^2)+n*(a+b*x)^(1+m)*hypergeometric(1,_
+--   1+m,2+m,(a+b*x)/a)/(b*(1+m)^2)+(a+b*x)^(1+m)*log(c*x^n)/(b*(1+m))
+--E 842
+
+--S 843 of 5341
+--a0:=integrate(t0,x)
+--E 843
+
+--S 844 of 5341
+--m0:=a0-r0
+--E 844
+
+--S 845 of 5341
+--d0:=D(m0,x)
+--E 845
+
+)clear all
+
+--S 846 of 5341
+t0:=(a+b*x)^3*log(c*x^n)
+--R 
+--R
+--R          3 3       2 2     2       3        n
+--R   (1)  (b x  + 3a b x  + 3a b x + a )log(c x )
+--R                                                    Type: Expression(Integer)
+--E 846
+
+--S 847 of 5341
+r0:=-a^3*n*x-3/4*a^2*b*n*x^2-1/3*a*b^2*n*x^3-1/16*b^3*n*x^4-_
+   1/4*a^4*n*log(x)/b+1/4*(a+b*x)^4*log(c*x^n)/b
+--R 
+--R
+--R   (2)
+--R           4 4        3 3      2 2 2      3         4        n       4
+--R       (12b x  + 48a b x  + 72a b x  + 48a b x + 12a )log(c x ) - 12a n log(x)
+--R     + 
+--R           4   4        3   3      2 2   2      3
+--R       - 3b n x  - 16a b n x  - 36a b n x  - 48a b n x
+--R  /
+--R     48b
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3   4        2   3      2     2      3
+--R       (12b n x  + 48a b n x  + 72a b n x  + 48a n x)log(x)
+--R     + 
+--R           3 4        2 3      2   2      3             3   4        2   3
+--R       (12b x  + 48a b x  + 72a b x  + 48a x)log(c) - 3b n x  - 16a b n x
+--R     + 
+--R            2     2      3
+--R       - 36a b n x  - 48a n x
+--R  /
+--R     48
+--R                                         Type: Union(Expression(Integer),...)
+--E 848
+
+--S 849 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           4 4       3 3     2 2 2     3       4        n
+--R       (- b x  - 4a b x  - 6a b x  - 4a b x - a )log(c x )
+--R     + 
+--R         4   4       3   3     2 2   2     3         4
+--R       (b n x  + 4a b n x  + 6a b n x  + 4a b n x + a n)log(x)
+--R     + 
+--R         4 4       3 3     2 2 2     3
+--R       (b x  + 4a b x  + 6a b x  + 4a b x)log(c)
+--R  /
+--R     4b
+--R                                                    Type: Expression(Integer)
+--E 849
+
+--S 850 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 850
+
+)clear all
+
+--S 851 of 5341
+t0:=(a+b*x)^2*log(c*x^n)
+--R 
+--R
+--R          2 2             2        n
+--R   (1)  (b x  + 2a b x + a )log(c x )
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 5341
+r0:=-a^2*n*x-1/2*a*b*n*x^2-1/9*b^2*n*x^3-1/3*a^3*n*log(x)/b+1/3*(a+b*x)^3*_
+   log(c*x^n)/b
+--R 
+--R
+--R   (2)
+--R          3 3        2 2      2        3        n      3             3   3
+--R       (6b x  + 18a b x  + 18a b x + 6a )log(c x ) - 6a n log(x) - 2b n x
+--R     + 
+--R             2   2      2
+--R       - 9a b n x  - 18a b n x
+--R  /
+--R     18b
+--R                                                    Type: Expression(Integer)
+--E 852
+
+--S 853 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2   3            2      2                2 3          2      2
+--R       (6b n x  + 18a b n x  + 18a n x)log(x) + (6b x  + 18a b x  + 18a x)log(c)
+--R     + 
+--R           2   3           2      2
+--R       - 2b n x  - 9a b n x  - 18a n x
+--R  /
+--R     18
+--R                                         Type: Union(Expression(Integer),...)
+--E 853
+
+--S 854 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3 3       2 2     2       3        n
+--R       (- b x  - 3a b x  - 3a b x - a )log(c x )
+--R     + 
+--R         3   3       2   2     2         3
+--R       (b n x  + 3a b n x  + 3a b n x + a n)log(x)
+--R     + 
+--R         3 3       2 2     2
+--R       (b x  + 3a b x  + 3a b x)log(c)
+--R  /
+--R     3b
+--R                                                    Type: Expression(Integer)
+--E 854
+
+--S 855 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 855
+
+)clear all
+
+--S 856 of 5341
+t0:=(a+b*x)*log(c*x^n)
+--R 
+--R
+--R                        n
+--R   (1)  (b x + a)log(c x )
+--R                                                    Type: Expression(Integer)
+--E 856
+
+--S 857 of 5341
+r0:=-a*n*x-1/4*b*n*x^2-1/2*a^2*n*log(x)/b+1/2*(a+b*x)^2*log(c*x^n)/b
+--R 
+--R
+--R           2 2              2        n      2            2   2
+--R        (2b x  + 4a b x + 2a )log(c x ) - 2a n log(x) - b n x  - 4a b n x
+--R   (2)  -----------------------------------------------------------------
+--R                                        4b
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2                        2                      2
+--R        (2b n x  + 4a n x)log(x) + (2b x  + 4a x)log(c) - b n x  - 4a n x
+--R   (3)  -----------------------------------------------------------------
+--R                                        4
+--R                                         Type: Union(Expression(Integer),...)
+--E 858
+
+--S 859 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2 2             2        n      2   2               2
+--R       (- b x  - 2a b x - a )log(c x ) + (b n x  + 2a b n x + a n)log(x)
+--R     + 
+--R         2 2
+--R       (b x  + 2a b x)log(c)
+--R  /
+--R     2b
+--R                                                    Type: Expression(Integer)
+--E 859
+
+--S 860 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 860
+
+)clear all
+
+--S 861 of 5341
+t0:=log(c*x^n)/(a+b*x)
+--R 
+--R
+--R               n
+--R        log(c x )
+--R   (1)  ---------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 861
+
+--S 862 of 5341
+--r0:=log(c*x^n)*log((a+b*x)/a)/b+n*polylog(2,-b*x/a)/b
+--E 862
+
+--S 863 of 5341
+--a0:=integrate(t0,x)
+--E 863
+
+--S 864 of 5341
+--m0:=a0-r0
+--E 864
+
+--S 865 of 5341
+--d0:=D(m0,x)
+--E 865
+
+)clear all
+
+--S 866 of 5341
+t0:=log(c*x^n)/(a+b*x)^2
+--R 
+--R
+--R                    n
+--R             log(c x )
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 5341
+r0:=n*log(x)/(a*b)-log(c*x^n)/(b*(a+b*x))-n*log(a+b*x)/(a*b)
+--R 
+--R
+--R                   n
+--R        - a log(c x ) + (- b n x - a n)log(b x + a) + (b n x + a n)log(x)
+--R   (2)  -----------------------------------------------------------------
+--R                                      2     2
+--R                                   a b x + a b
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (- b n x - a n)log(b x + a) + b n x log(x) - a log(c)
+--R   (3)  -----------------------------------------------------
+--R                                2     2
+--R                             a b x + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 868
+
+--S 869 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               n
+--R        log(c x ) - n log(x) - log(c)
+--R   (4)  -----------------------------
+--R                   2
+--R                  b x + a b
+--R                                                    Type: Expression(Integer)
+--E 869
+
+--S 870 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 870
+
+)clear all
+
+--S 871 of 5341
+t0:=log(c*x^n)/(a+b*x)^3
+--R 
+--R
+--R                         n
+--R                  log(c x )
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        b x  + 3a b x  + 3a b x + a
+--R                                                    Type: Expression(Integer)
+--E 871
+
+--S 872 of 5341
+r0:=1/2*n/(a*b*(a+b*x))+1/2*n*log(x)/(a^2*b)-1/2*log(c*x^n)/(b*(a+b*x)^2)-_
+   1/2*n*log(a+b*x)/(a^2*b)
+--R 
+--R
+--R   (2)
+--R          2       n        2   2               2
+--R       - a log(c x ) + (- b n x  - 2a b n x - a n)log(b x + a)
+--R     + 
+--R         2   2               2                      2
+--R       (b n x  + 2a b n x + a n)log(x) + a b n x + a n
+--R  /
+--R       2 3 2     3 2      4
+--R     2a b x  + 4a b x + 2a b
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2   2               2                   2   2
+--R       (- b n x  - 2a b n x - a n)log(b x + a) + (b n x  + 2a b n x)log(x)
+--R     + 
+--R          2                    2
+--R       - a log(c) + a b n x + a n
+--R  /
+--R       2 3 2     3 2      4
+--R     2a b x  + 4a b x + 2a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 873
+
+--S 874 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               n
+--R        log(c x ) - n log(x) - log(c)
+--R   (4)  -----------------------------
+--R              3 2       2      2
+--R            2b x  + 4a b x + 2a b
+--R                                                    Type: Expression(Integer)
+--E 874
+
+--S 875 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 875
+
+)clear all
+
+--S 876 of 5341
+t0:=log(c*x^n)/(a+b*x)^4
+--R 
+--R
+--R                              n
+--R                       log(c x )
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        b x  + 4a b x  + 6a b x  + 4a b x + a
+--R                                                    Type: Expression(Integer)
+--E 876
+
+--S 877 of 5341
+r0:=1/6*n/(a*b*(a+b*x)^2)+1/3*n/(a^2*b*(a+b*x))+1/3*n*log(x)/(a^3*b)-_
+   1/3*log(c*x^n)/(b*(a+b*x)^3)-1/3*n*log(a+b*x)/(a^3*b)
+--R 
+--R
+--R   (2)
+--R           3       n         3   3       2   2     2          3
+--R       - 2a log(c x ) + (- 2b n x  - 6a b n x  - 6a b n x - 2a n)log(b x + a)
+--R     + 
+--R        3   3       2   2     2          3               2   2     2          3
+--R     (2b n x  + 6a b n x  + 6a b n x + 2a n)log(x) + 2a b n x  + 5a b n x + 3a n
+--R  /
+--R       3 4 3      4 3 2      5 2      6
+--R     6a b x  + 18a b x  + 18a b x + 6a b
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--S 878 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3   3       2   2     2          3
+--R       (- 2b n x  - 6a b n x  - 6a b n x - 2a n)log(b x + a)
+--R     + 
+--R          3   3       2   2     2                 3             2   2     2
+--R       (2b n x  + 6a b n x  + 6a b n x)log(x) - 2a log(c) + 2a b n x  + 5a b n x
+--R     + 
+--R         3
+--R       3a n
+--R  /
+--R       3 4 3      4 3 2      5 2      6
+--R     6a b x  + 18a b x  + 18a b x + 6a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 878
+
+--S 879 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                n
+--R         log(c x ) - n log(x) - log(c)
+--R   (4)  -------------------------------
+--R          4 3       3 2     2 2      3
+--R        3b x  + 9a b x  + 9a b x + 3a b
+--R                                                    Type: Expression(Integer)
+--E 879
+
+--S 880 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 880
+
+)clear all
+
+--S 881 of 5341
+t0:=log(c*x^n)/(2+4*x)^2
+--R 
+--R
+--R                  n
+--R           log(c x )
+--R   (1)  --------------
+--R           2
+--R        16x  + 16x + 4
+--R                                                    Type: Expression(Integer)
+--E 881
+
+--S 882 of 5341
+r0:=1/8*n*log(x)-1/8*log(c*x^n)/(1+2*x)-1/8*n*log(1+2*x)
+--R 
+--R
+--R                 n
+--R        - log(c x ) + (- 2n x - n)log(2x + 1) + (2n x + n)log(x)
+--R   (2)  --------------------------------------------------------
+--R                                 16x + 8
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (- 2n x - n)log(2x + 1) + 2n x log(x) - log(c)
+--R   (3)  ----------------------------------------------
+--R                            16x + 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 883
+
+--S 884 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               n
+--R        log(c x ) - n log(x) - log(c)
+--R   (4)  -----------------------------
+--R                   16x + 8
+--R                                                    Type: Expression(Integer)
+--E 884
+
+--S 885 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 885
+
+)clear all
+
+--S 886 of 5341
+t0:=x*log(a*x^2)/(1-a*x^2)
+--R 
+--R
+--R                   2
+--R          x log(a x )
+--R   (1)  - -----------
+--R               2
+--R            a x  - 1
+--R                                                    Type: Expression(Integer)
+--E 886
+
+--S 887 of 5341
+--r0:=1/2*polylog(2,1-a*x^2)/a
+--E 887
+
+--S 888 of 5341
+--a0:=integrate(t0,x)
+--E 888
+
+--S 889 of 5341
+--m0:=a0-r0
+--E 889
+
+--S 890 of 5341
+--d0:=D(m0,x)
+--E 890
+
+)clear all
+
+--S 891 of 5341
+t0:=log(a*x)/(1-a*x)
+--R 
+--R
+--R          log(a x)
+--R   (1)  - --------
+--R           a x - 1
+--R                                                    Type: Expression(Integer)
+--E 891
+
+--S 892 of 5341
+--r0:=polylog(2,1-a*x)/a
+--E 892
+
+--S 893 of 5341
+--a0:=integrate(t0,x)
+--E 893
+
+--S 894 of 5341
+--m0:=a0-r0
+--E 894
+
+--S 895 of 5341
+--d0:=D(m0,x)
+--E 895
+
+)clear all
+
+--S 896 of 5341
+t0:=log(a/x)/(a*x-x^2)
+--R 
+--R
+--R               a
+--R           log(-)
+--R               x
+--R   (1)  - --------
+--R           2
+--R          x  - a x
+--R                                                    Type: Expression(Integer)
+--E 896
+
+--S 897 of 5341
+--r0:=polylog(2,(-a+x)/x)/a
+--E 897
+
+--S 898 of 5341
+--a0:=integrate(t0,x)
+--E 898
+
+--S 899 of 5341
+--m0:=a0-r0
+--E 899
+
+--S 900 of 5341
+--d0:=D(m0,x)
+--E 900
+
+)clear all
+
+--S 901 of 5341
+t0:=log(a/x^2)/(a*x-x^3)
+--R 
+--R
+--R                a
+--R           log(--)
+--R                2
+--R               x
+--R   (1)  - --------
+--R           3
+--R          x  - a x
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 5341
+--r0:=1/2*polylog(2,(-a+x^2)/x^2)/a
+--E 902
+
+--S 903 of 5341
+--a0:=integrate(t0,x)
+--E 903
+
+--S 904 of 5341
+--m0:=a0-r0
+--E 904
+
+--S 905 of 5341
+--d0:=D(m0,x)
+--E 905
+
+)clear all
+
+--S 906 of 5341
+t0:=log(x/a)/(a-x)
+--R 
+--R
+--R              x
+--R          log(-)
+--R              a
+--R   (1)  - ------
+--R           x - a
+--R                                                    Type: Expression(Integer)
+--E 906
+
+--S 907 of 5341
+--r0:=polylog(2,(a-x)/a)
+--E 907
+
+--S 908 of 5341
+--a0:=integrate(t0,x)
+--E 908
+
+--S 909 of 5341
+--m0:=a0-r0
+--E 909
+
+--S 910 of 5341
+--d0:=D(m0,x)
+--E 910
+
+)clear all
+
+--S 911 of 5341
+t0:=x*log(x^2/a)/(a-x^2)
+--R 
+--R
+--R                 2
+--R                x
+--R          x log(--)
+--R                 a
+--R   (1)  - ---------
+--R             2
+--R            x  - a
+--R                                                    Type: Expression(Integer)
+--E 911
+
+--S 912 of 5341
+--r0:=1/2*polylog(2,(a-x^2)/a)
+--E 912
+
+--S 913 of 5341
+--a0:=integrate(t0,x)
+--E 913
+
+--S 914 of 5341
+--m0:=a0-r0
+--E 914
+
+--S 915 of 5341
+--d0:=D(m0,x)
+--E 915
+
+)clear all
+
+--S 916 of 5341
+t0:=log(a+b*x)
+--R 
+--R
+--R   (1)  log(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 916
+
+--S 917 of 5341
+r0:=-x+(a+b*x)*log(a+b*x)/b
+--R 
+--R
+--R        (b x + a)log(b x + a) - b x
+--R   (2)  ---------------------------
+--R                     b
+--R                                                    Type: Expression(Integer)
+--E 917
+
+--S 918 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (b x + a)log(b x + a) - b x
+--R   (3)  ---------------------------
+--R                     b
+--R                                         Type: Union(Expression(Integer),...)
+--E 918
+
+--S 919 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 919
+
+--S 920 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 920
+
+)clear all
+
+--S 921 of 5341
+t0:=log(a+b*x)^2
+--R 
+--R
+--R                    2
+--R   (1)  log(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 921
+
+--S 922 of 5341
+r0:=2*x-2*(a+b*x)*log(a+b*x)/b+(a+b*x)*log(a+b*x)^2/b
+--R 
+--R
+--R                             2
+--R        (b x + a)log(b x + a)  + (- 2b x - 2a)log(b x + a) + 2b x
+--R   (2)  ---------------------------------------------------------
+--R                                    b
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             2
+--R        (b x + a)log(b x + a)  + (- 2b x - 2a)log(b x + a) + 2b x
+--R   (3)  ---------------------------------------------------------
+--R                                    b
+--R                                         Type: Union(Expression(Integer),...)
+--E 923
+
+--S 924 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 924
+
+--S 925 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 925
+
+)clear all
+
+--S 926 of 5341
+t0:=log(a+b*x)^3
+--R 
+--R
+--R                    3
+--R   (1)  log(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 926
+
+--S 927 of 5341
+r0:=-6*x+6*(a+b*x)*log(a+b*x)/b-3*(a+b*x)*log(a+b*x)^2/b+(a+b*x)*log(a+b*x)^3/b
+--R 
+--R
+--R   (2)
+--R                            3                            2
+--R       (b x + a)log(b x + a)  + (- 3b x - 3a)log(b x + a)
+--R     + 
+--R       (6b x + 6a)log(b x + a) - 6b x
+--R  /
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 927
+
+--S 928 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                            3                            2
+--R       (b x + a)log(b x + a)  + (- 3b x - 3a)log(b x + a)
+--R     + 
+--R       (6b x + 6a)log(b x + a) - 6b x
+--R  /
+--R     b
+--R                                         Type: Union(Expression(Integer),...)
+--E 928
+
+--S 929 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 929
+
+--S 930 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 930
+
+)clear all
+
+--S 931 of 5341
+t0:=log(a+b*x+c*x)
+--R 
+--R
+--R   (1)  log((c + b)x + a)
+--R                                                    Type: Expression(Integer)
+--E 931
+
+--S 932 of 5341
+r0:=-x+(a+(b+c)*x)*log(a+(b+c)*x)/(b+c)
+--R 
+--R
+--R        ((c + b)x + a)log((c + b)x + a) + (- c - b)x
+--R   (2)  --------------------------------------------
+--R                            c + b
+--R                                                    Type: Expression(Integer)
+--E 932
+
+--S 933 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        ((c + b)x + a)log((c + b)x + a) + (- c - b)x
+--R   (3)  --------------------------------------------
+--R                            c + b
+--R                                         Type: Union(Expression(Integer),...)
+--E 933
+
+--S 934 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 934
+
+--S 935 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 935
+
+)clear all
+
+--S 936 of 5341
+t0:=log(a+b*x+c*x)^2
+--R 
+--R
+--R                         2
+--R   (1)  log((c + b)x + a)
+--R                                                    Type: Expression(Integer)
+--E 936
+
+--S 937 of 5341
+r0:=2*x-2*(a+(b+c)*x)*log(a+(b+c)*x)/(b+c)+(a+(b+c)*x)*log(a+(b+c)*x)^2/(b+c)
+--R 
+--R
+--R   (2)
+--R                                      2
+--R       ((c + b)x + a)log((c + b)x + a)  + ((- 2c - 2b)x - 2a)log((c + b)x + a)
+--R     + 
+--R       (2c + 2b)x
+--R  /
+--R     c + b
+--R                                                    Type: Expression(Integer)
+--E 937
+
+--S 938 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                      2
+--R       ((c + b)x + a)log((c + b)x + a)  + ((- 2c - 2b)x - 2a)log((c + b)x + a)
+--R     + 
+--R       (2c + 2b)x
+--R  /
+--R     c + b
+--R                                         Type: Union(Expression(Integer),...)
+--E 938
+
+--S 939 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 939
+
+--S 940 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 940
+
+)clear all
+
+--S 941 of 5341
+t0:=log(a+b*x+c*x)^3
+--R 
+--R
+--R                         3
+--R   (1)  log((c + b)x + a)
+--R                                                    Type: Expression(Integer)
+--E 941
+
+--S 942 of 5341
+r0:=-6*x+6*(a+(b+c)*x)*log(a+(b+c)*x)/(b+c)-3*(a+(b+c)*x)*log(a+(b+c)*x)^2/_
+   (b+c)+(a+(b+c)*x)*log(a+(b+c)*x)^3/(b+c)
+--R 
+--R
+--R   (2)
+--R                                      3                                       2
+--R       ((c + b)x + a)log((c + b)x + a)  + ((- 3c - 3b)x - 3a)log((c + b)x + a)
+--R     + 
+--R       ((6c + 6b)x + 6a)log((c + b)x + a) + (- 6c - 6b)x
+--R  /
+--R     c + b
+--R                                                    Type: Expression(Integer)
+--E 942
+
+--S 943 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                      3                                       2
+--R       ((c + b)x + a)log((c + b)x + a)  + ((- 3c - 3b)x - 3a)log((c + b)x + a)
+--R     + 
+--R       ((6c + 6b)x + 6a)log((c + b)x + a) + (- 6c - 6b)x
+--R  /
+--R     c + b
+--R                                         Type: Union(Expression(Integer),...)
+--E 943
+
+--S 944 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 944
+
+--S 945 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 945
+
+)clear all
+
+--S 946 of 5341
+t0:=x^m/log(c*(a+b*x))
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ----------------
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 946
+
+--S 947 of 5341
+--r0:=Int(x^m/log(a*c+b*c*x),x)
+--E 947
+
+--S 948 of 5341
+--a0:=integrate(t0,x)
+--E 948
+
+--S 949 of 5341
+--m0:=a0-r0
+--E 949
+
+--S 950 of 5341
+--d0:=D(m0,x)
+--E 950
+
+)clear all
+
+--S 951 of 5341
+t0:=x^3/log(c*(a+b*x))
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ----------------
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 951
+
+--S 952 of 5341
+--r0:=3*a^2*Ei(2*log(c*(a+b*x)))/(b^4*c^2)-3*a*Ei(3*log(c*(a+b*x)))/_
+--   (b^4*c^3)+Ei(4*log(c*(a+b*x)))/(b^4*c^4)-a^3*Li(c*(a+b*x))/(b^4*c)
+--E 952
+
+--S 953 of 5341
+--a0:=integrate(t0,x)
+--E 953
+
+--S 954 of 5341
+--m0:=a0-r0
+--E 954
+
+--S 955 of 5341
+--d0:=D(m0,x)
+--E 955
+
+)clear all
+
+--S 956 of 5341
+t0:=x^2/log(c*(a+b*x))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ----------------
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 5341
+--r0:=-2*a*Ei(2*log(c*(a+b*x)))/(b^3*c^2)+Ei(3*log(c*(a+b*x)))/(b^3*c^3)+_
+--   a^2*Li(c*(a+b*x))/(b^3*c)
+--E 957
+
+--S 958 of 5341
+--a0:=integrate(t0,x)
+--E 958
+
+--S 959 of 5341
+--m0:=a0-r0
+--E 959
+
+--S 960 of 5341
+--d0:=D(m0,x)
+--E 960
+
+)clear all
+
+--S 961 of 5341
+t0:=x/log(c*(a+b*x))
+--R 
+--R
+--R                x
+--R   (1)  ----------------
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 961
+
+--S 962 of 5341
+--r0:=Ei(2*log(c*(a+b*x)))/(b^2*c^2)-a*Li(c*(a+b*x))/(b^2*c)
+--E 962
+
+--S 963 of 5341
+--a0:=integrate(t0,x)
+--E 963
+
+--S 964 of 5341
+--m0:=a0-r0
+--E 964
+
+--S 965 of 5341
+--d0:=D(m0,x)
+--E 965
+
+)clear all
+
+--S 966 of 5341
+t0:=1/log(c*(a+b*x))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 966
+
+--S 967 of 5341
+--r0:=Li(c*(a+b*x))/(b*c)
+--E 967
+
+--S 968 of 5341
+--a0:=integrate(t0,x)
+--E 968
+
+--S 969 of 5341
+--m0:=a0-r0
+--E 969
+
+--S 970 of 5341
+--d0:=D(m0,x)
+--E 970
+
+)clear all
+
+--S 971 of 5341
+t0:=1/(x*log(c*(a+b*x)))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R        x log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 971
+
+--S 972 of 5341
+--r0:=Int(1/(x*log(a*c+b*c*x)),x)
+--E 972
+
+--S 973 of 5341
+--a0:=integrate(t0,x)
+--E 973
+
+--S 974 of 5341
+--m0:=a0-r0
+--E 974
+
+--S 975 of 5341
+--d0:=D(m0,x)
+--E 975
+
+)clear all
+
+--S 976 of 5341
+t0:=1/(x^2*log(c*(a+b*x)))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         2
+--R        x log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 976
+
+--S 977 of 5341
+--r0:=Int(1/(x^2*log(a*c+b*c*x)),x)
+--E 977
+
+--S 978 of 5341
+--a0:=integrate(t0,x)
+--E 978
+
+--S 979 of 5341
+--m0:=a0-r0
+--E 979
+
+--S 980 of 5341
+--d0:=D(m0,x)
+--E 980
+
+)clear all
+
+--S 981 of 5341
+t0:=x^m/log(c*(a+b*x))^2
+--R 
+--R
+--R                 m
+--R                x
+--R   (1)  -----------------
+--R                        2
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 981
+
+--S 982 of 5341
+--r0:=Int(x^m/log(a*c+b*c*x)^2,x)
+--E 982
+
+--S 983 of 5341
+--a0:=integrate(t0,x)
+--E 983
+
+--S 984 of 5341
+--m0:=a0-r0
+--E 984
+
+--S 985 of 5341
+--d0:=D(m0,x)
+--E 985
+
+)clear all
+
+--S 986 of 5341
+t0:=x^3/log(c*(a+b*x))^2
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  -----------------
+--R                        2
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 986
+
+--S 987 of 5341
+--r0:=6*a^2*Ei(2*log(c*(a+b*x)))/(b^4*c^2)-9*a*Ei(3*log(c*(a+b*x)))/_
+--   (b^4*c^3)+4*Ei(4*log(c*(a+b*x)))/(b^4*c^4)-a^3*Li(c*(a+b*x))/(b^4*c)-_
+--   x^3*(a+b*x)/(b*log(c*(a+b*x)))
+--E 987
+
+--S 988 of 5341
+--a0:=integrate(t0,x)
+--E 988
+
+--S 989 of 5341
+--m0:=a0-r0
+--E 989
+
+--S 990 of 5341
+--d0:=D(m0,x)
+--E 990
+
+)clear all
+
+--S 991 of 5341
+t0:=x^2/log(c*(a+b*x))^2
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  -----------------
+--R                        2
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 991
+
+--S 992 of 5341
+--r0:=-4*a*Ei(2*log(c*(a+b*x)))/(b^3*c^2)+3*Ei(3*log(c*(a+b*x)))/(b^3*c^3)+_
+--   a^2*Li(c*(a+b*x))/(b^3*c)-x^2*(a+b*x)/(b*log(c*(a+b*x)))
+--E 992
+
+--S 993 of 5341
+--a0:=integrate(t0,x)
+--E 993
+
+--S 994 of 5341
+--m0:=a0-r0
+--E 994
+
+--S 995 of 5341
+--d0:=D(m0,x)
+--E 995
+
+)clear all
+
+--S 996 of 5341
+t0:=x/log(c*(a+b*x))^2
+--R 
+--R
+--R                x
+--R   (1)  -----------------
+--R                        2
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 996
+
+--S 997 of 5341
+--r0:=2*Ei(2*log(c*(a+b*x)))/(b^2*c^2)-a*Li(c*(a+b*x))/(b^2*c)-_
+--   x*(a+b*x)/(b*log(c*(a+b*x)))
+--E 997
+
+--S 998 of 5341
+--a0:=integrate(t0,x)
+--E 998
+
+--S 999 of 5341
+--m0:=a0-r0
+--E 999
+
+--S 1000 of 5341
+--d0:=D(m0,x)
+--E 1000
+
+)clear all
+
+--S 1001 of 5341
+t0:=1/log(c*(a+b*x))^2
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R                        2
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 1001
+
+--S 1002 of 5341
+--r0:=Li(c*(a+b*x))/(b*c)+(-a-b*x)/(b*log(c*(a+b*x)))
+--E 1002
+
+--S 1003 of 5341
+--a0:=integrate(t0,x)
+--E 1003
+
+--S 1004 of 5341
+--m0:=a0-r0
+--E 1004
+
+--S 1005 of 5341
+--d0:=D(m0,x)
+--E 1005
+
+)clear all
+
+--S 1006 of 5341
+t0:=1/(x*log(c*(a+b*x))^2)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R                          2
+--R        x log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 1006
+
+--S 1007 of 5341
+--r0:=Int(1/(x*log(a*c+b*c*x)^2),x)
+--E 1007
+
+--S 1008 of 5341
+--a0:=integrate(t0,x)
+--E 1008
+
+--S 1009 of 5341
+--m0:=a0-r0
+--E 1009
+
+--S 1010 of 5341
+--d0:=D(m0,x)
+--E 1010
+
+)clear all
+
+--S 1011 of 5341
+t0:=1/(x^2*log(c*(a+b*x))^2)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         2                2
+--R        x log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 1011
+
+--S 1012 of 5341
+--r0:=Int(1/(x^2*log(a*c+b*c*x)^2),x)
+--E 1012
+
+--S 1013 of 5341
+--a0:=integrate(t0,x)
+--E 1013
+
+--S 1014 of 5341
+--m0:=a0-r0
+--E 1014
+
+--S 1015 of 5341
+--d0:=D(m0,x)
+--E 1015
+
+)clear all
+
+--S 1016 of 5341
+t0:=x^m/log(c*(a+b*x))^3
+--R 
+--R
+--R                 m
+--R                x
+--R   (1)  -----------------
+--R                        3
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 1016
+
+--S 1017 of 5341
+--r0:=Int(x^m/log(a*c+b*c*x)^3,x)
+--E 1017
+
+--S 1018 of 5341
+--a0:=integrate(t0,x)
+--E 1018
+
+--S 1019 of 5341
+--m0:=a0-r0
+--E 1019
+
+--S 1020 of 5341
+--d0:=D(m0,x)
+--E 1020
+
+)clear all
+
+--S 1021 of 5341
+t0:=x^3/log(c*(a+b*x))^3
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  -----------------
+--R                        3
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 1021
+
+--S 1022 of 5341
+--r0:=6*a^2*Ei(2*log(c*(a+b*x)))/(b^4*c^2)-27/2*a*Ei(3*log(c*(a+b*x)))/_
+--   (b^4*c^3)+8*Ei(4*log(c*(a+b*x)))/(b^4*c^4)-1/2*a^3*Li(c*(a+b*x))/_
+--   (b^4*c)-1/2*x^3*(a+b*x)/(b*log(c*(a+b*x))^2)-3/2*a*x^2*(a+b*x)/_
+--   (b^2*log(c*(a+b*x)))-2*x^3*(a+b*x)/(b*log(c*(a+b*x)))
+--E 1022
+
+--S 1023 of 5341
+--a0:=integrate(t0,x)
+--E 1023
+
+--S 1024 of 5341
+--m0:=a0-r0
+--E 1024
+
+--S 1025 of 5341
+--d0:=D(m0,x)
+--E 1025
+
+)clear all
+
+--S 1026 of 5341
+t0:=x^2/log(c*(a+b*x))^3
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  -----------------
+--R                        3
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 1026
+
+--S 1027 of 5341
+--r0:=-4*a*Ei(2*log(c*(a+b*x)))/(b^3*c^2)+9/2*Ei(3*log(c*(a+b*x)))/_
+--   (b^3*c^3)+1/2*a^2*Li(c*(a+b*x))/(b^3*c)-1/2*x^2*(a+b*x)/_
+--   (b*log(c*(a+b*x))^2)-a*x*(a+b*x)/(b^2*log(c*(a+b*x)))-_
+--   3/2*x^2*(a+b*x)/(b*log(c*(a+b*x)))
+--E 1027
+
+--S 1028 of 5341
+--a0:=integrate(t0,x)
+--E 1028
+
+--S 1029 of 5341
+--m0:=a0-r0
+--E 1029
+
+--S 1030 of 5341
+--d0:=D(m0,x)
+--E 1030
+
+)clear all
+
+--S 1031 of 5341
+t0:=x/log(c*(a+b*x))^3
+--R 
+--R
+--R                x
+--R   (1)  -----------------
+--R                        3
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 1031
+
+--S 1032 of 5341
+--r0:=2*Ei(2*log(c*(a+b*x)))/(b^2*c^2)-1/2*a*Li(c*(a+b*x))/(b^2*c)-_
+--   1/2*x*(a+b*x)/(b*log(c*(a+b*x))^2)-1/2*a*(a+b*x)/(b^2*log(c*(a+b*x)))-_
+--   x*(a+b*x)/(b*log(c*(a+b*x)))
+--E 1032
+
+--S 1033 of 5341
+--a0:=integrate(t0,x)
+--E 1033
+
+--S 1034 of 5341
+--m0:=a0-r0
+--E 1034
+
+--S 1035 of 5341
+--d0:=D(m0,x)
+--E 1035
+
+)clear all
+
+--S 1036 of 5341
+t0:=1/log(c*(a+b*x))^3
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R                        3
+--R        log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 1036
+
+--S 1037 of 5341
+--r0:=1/2*Li(c*(a+b*x))/(b*c)+1/2*(-a-b*x)/(b*log(c*(a+b*x))^2)+_
+--   1/2*(-a-b*x)/(b*log(c*(a+b*x)))
+--E 1037
+
+--S 1038 of 5341
+--a0:=integrate(t0,x)
+--E 1038
+
+--S 1039 of 5341
+--m0:=a0-r0
+--E 1039
+
+--S 1040 of 5341
+--d0:=D(m0,x)
+--E 1040
+
+)clear all
+
+--S 1041 of 5341
+t0:=1/(x*log(c*(a+b*x))^3)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R                          3
+--R        x log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 1041
+
+--S 1042 of 5341
+--r0:=Int(1/(x*log(a*c+b*c*x)^3),x)
+--E 1042
+
+--S 1043 of 5341
+--a0:=integrate(t0,x)
+--E 1043
+
+--S 1044 of 5341
+--m0:=a0-r0
+--E 1044
+
+--S 1045 of 5341
+--d0:=D(m0,x)
+--E 1045
+
+)clear all
+
+--S 1046 of 5341
+t0:=1/(x^2*log(c*(a+b*x))^3)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         2                3
+--R        x log(b c x + a c)
+--R                                                    Type: Expression(Integer)
+--E 1046
+
+--S 1047 of 5341
+--r0:=Int(1/(x^2*log(a*c+b*c*x)^3),x)
+--E 1047
+
+--S 1048 of 5341
+--a0:=integrate(t0,x)
+--E 1048
+
+--S 1049 of 5341
+--m0:=a0-r0
+--E 1049
+
+--S 1050 of 5341
+--d0:=D(m0,x)
+--E 1050
+
+)clear all
+
+--S 1051 of 5341
+t0:=x^m*log(c*(a+b*x)^p)
+--R 
+--R
+--R         m               p
+--R   (1)  x log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1051
+
+--S 1052 of 5341
+--r0:=-p*x^(1+m)/(1+m)^2+p*x^(1+m)*hypergeometric(1,1+m,2+m,-b*x/a)/(1+m)^2+_
+--   x^(1+m)*log(c*(a+b*x)^p)/(1+m)
+--E 1052
+
+--S 1053 of 5341
+--a0:=integrate(t0,x)
+--E 1053
+
+--S 1054 of 5341
+--m0:=a0-r0
+--E 1054
+
+--S 1055 of 5341
+--d0:=D(m0,x)
+--E 1055
+
+)clear all
+
+--S 1056 of 5341
+t0:=(d+e*x)^m*log(c*(a+b*x)^n)
+--R 
+--R
+--R                 m               n
+--R   (1)  (e x + d) log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1056
+
+--S 1057 of 5341
+--r0:=b*n*(d+e*x)^(2+m)*hypergeometric(1,2+m,3+m,b*(d+e*x)/(b*d-a*e))/_
+--   (e*(b*d-a*e)*(1+m)*(2+m))+(d+e*x)^(1+m)*log(c*(a+b*x)^n)/(e*(1+m))
+--E 1057
+
+--S 1058 of 5341
+--a0:=integrate(t0,x)
+--E 1058
+
+--S 1059 of 5341
+--m0:=a0-r0
+--E 1059
+
+--S 1060 of 5341
+--d0:=D(m0,x)
+--E 1060
+
+)clear all
+
+--S 1061 of 5341
+t0:=(d+e*x)^5*log(c*(a+b*x)^n)
+--R 
+--R
+--R          5 5       4 4      2 3 3      3 2 2     4       5                n
+--R   (1)  (e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d )log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1061
+
+--S 1062 of 5341
+r0:=-1/6*(b*d-a*e)^5*n*x/b^5-1/12*(b*d-a*e)^4*n*(d+e*x)^2/(b^4*e)-_
+   1/18*(b*d-a*e)^3*n*(d+e*x)^3/(b^3*e)-1/24*(b*d-a*e)^2*n*(d+e*x)^4/(b^2*e)-_
+   1/30*(b*d-a*e)*n*(d+e*x)^5/(b*e)-1/36*n*(d+e*x)^6/e-1/6*(b*d-a*e)^6*n*_
+   log(a+b*x)/(b^6*e)+1/6*(d+e*x)^6*log(c*(a+b*x)^n)/e
+--R 
+--R
+--R   (2)
+--R              6 6 6       6   5 5       6 2 4 4        6 3 3 3       6 4 2 2
+--R           60b e x  + 360b d e x  + 900b d e x  + 1200b d e x  + 900b d e x
+--R         + 
+--R               6 5         6 6
+--R           360b d e x + 60b d
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R                6 6       5     5       4 2 2 4        3 3 3 3       2 4 4 2
+--R           - 60a e  + 360a b d e  - 900a b d e  + 1200a b d e  - 900a b d e
+--R         + 
+--R                 5 5       6 6
+--R           360a b d e - 60b d
+--R      *
+--R         n log(b x + a)
+--R     + 
+--R            6 6   6         5 6      6   5    5
+--R       - 10b e n x  + (12a b e  - 72b d e )n x
+--R     + 
+--R             2 4 6        5   5       6 2 4    4
+--R       (- 15a b e  + 90a b d e  - 225b d e )n x
+--R     + 
+--R           3 3 6       2 4   5         5 2 4       6 3 3    3
+--R       (20a b e  - 120a b d e  + 300a b d e  - 400b d e )n x
+--R     + 
+--R             4 2 6       3 3   5       2 4 2 4         5 3 3       6 4 2    2
+--R       (- 30a b e  + 180a b d e  - 450a b d e  + 600a b d e  - 450b d e )n x
+--R     + 
+--R              5   6       4 2   5       3 3 2 4        2 4 3 3         5 4 2
+--R           60a b e  - 360a b d e  + 900a b d e  - 1200a b d e  + 900a b d e
+--R         + 
+--R                 6 5
+--R           - 360b d e
+--R      *
+--R         n x
+--R     + 
+--R             4 2 2 4       3 3 3 3       2 4 4 2         5 5       6 6
+--R       (- 30a b d e  + 140a b d e  - 255a b d e  + 222a b d e - 87b d )n
+--R  /
+--R         6
+--R     360b e
+--R                                                    Type: Expression(Integer)
+--E 1062
+
+--S 1063 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              6 5   6       6   4   5       6 2 3   4        6 3 2   3
+--R           60b e n x  + 360b d e n x  + 900b d e n x  + 1200b d e n x
+--R         + 
+--R               6 4     2       6 5
+--R           900b d e n x  + 360b d n x
+--R         + 
+--R                    6 5       5     4       4 2 2 3        3 3 3 2       2 4 4
+--R               - 60a e  + 360a b d e  - 900a b d e  + 1200a b d e  - 900a b d e
+--R             + 
+--R                     5 5
+--R               360a b d
+--R          *
+--R             n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R              6 5 6       6   4 5       6 2 3 4        6 3 2 3       6 4   2
+--R           60b e x  + 360b d e x  + 900b d e x  + 1200b d e x  + 900b d e x
+--R         + 
+--R               6 5
+--R           360b d x
+--R      *
+--R         log(c)
+--R     + 
+--R            6 5   6         5 5      6   4    5
+--R       - 10b e n x  + (12a b e  - 72b d e )n x
+--R     + 
+--R             2 4 5        5   4       6 2 3    4
+--R       (- 15a b e  + 90a b d e  - 225b d e )n x
+--R     + 
+--R           3 3 5       2 4   4         5 2 3       6 3 2    3
+--R       (20a b e  - 120a b d e  + 300a b d e  - 400b d e )n x
+--R     + 
+--R             4 2 5       3 3   4       2 4 2 3         5 3 2       6 4     2
+--R       (- 30a b e  + 180a b d e  - 450a b d e  + 600a b d e  - 450b d e)n x
+--R     + 
+--R              5   5       4 2   4       3 3 2 3        2 4 3 2         5 4
+--R           60a b e  - 360a b d e  + 900a b d e  - 1200a b d e  + 900a b d e
+--R         + 
+--R                 6 5
+--R           - 360b d
+--R      *
+--R         n x
+--R  /
+--R         6
+--R     360b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1063
+
+--S 1064 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                4 6 6       4   5 5       4 2 4 4        4 3 3 3       4 4 2 2
+--R           - 60b e x  - 360b d e x  - 900b d e x  - 1200b d e x  - 900b d e x
+--R         + 
+--R                 4 5         4 6
+--R           - 360b d e x - 60b d
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R              4 6   6       4   5   5       4 2 4   4        4 3 3   3
+--R           60b e n x  + 360b d e n x  + 900b d e n x  + 1200b d e n x
+--R         + 
+--R               4 4 2   2       4 5           4 6
+--R           900b d e n x  + 360b d e n x + 60b d n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R              4 6 6       4   5 5       4 2 4 4        4 3 3 3       4 4 2 2
+--R           60b e x  + 360b d e x  + 900b d e x  + 1200b d e x  + 900b d e x
+--R         + 
+--R               4 5
+--R           360b d e x
+--R      *
+--R         log(c)
+--R     + 
+--R           4 2 4       3   3 3       2 2 4 2         3 5       4 6
+--R       (30a d e  - 140a b d e  + 255a b d e  - 222a b d e + 87b d )n
+--R  /
+--R         4
+--R     360b e
+--R                                                    Type: Expression(Integer)
+--E 1064
+
+--S 1065 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1065
+
+)clear all
+
+--S 1066 of 5341
+t0:=(d+e*x)^4*log(c*(a+b*x)^n)
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4                n
+--R   (1)  (e x  + 4d e x  + 6d e x  + 4d e x + d )log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1066
+
+--S 1067 of 5341
+r0:=-1/5*(b*d-a*e)^4*n*x/b^4-1/10*(b*d-a*e)^3*n*(d+e*x)^2/(b^3*e)-_
+   1/15*(b*d-a*e)^2*n*(d+e*x)^3/(b^2*e)-1/20*(b*d-a*e)*n*(d+e*x)^4/(b*e)-_
+   1/25*n*(d+e*x)^5/e-1/5*(b*d-a*e)^5*n*log(a+b*x)/(b^5*e)+1/5*(d+e*x)^5*_
+   log(c*(a+b*x)^n)/e
+--R 
+--R
+--R   (2)
+--R              5 5 5       5   4 4       5 2 3 3       5 3 2 2       5 4
+--R           60b e x  + 300b d e x  + 600b d e x  + 600b d e x  + 300b d e x
+--R         + 
+--R              5 5
+--R           60b d
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R                5 5       4     4       3 2 2 3       2 3 3 2         4 4
+--R             60a e  - 300a b d e  + 600a b d e  - 600a b d e  + 300a b d e
+--R           + 
+--R                  5 5
+--R             - 60b d
+--R      *
+--R         n log(b x + a)
+--R     + 
+--R            5 5   5         4 5      5   4    4
+--R       - 12b e n x  + (15a b e  - 75b d e )n x
+--R     + 
+--R             2 3 5         4   4       5 2 3    3
+--R       (- 20a b e  + 100a b d e  - 200b d e )n x
+--R     + 
+--R           3 2 5       2 3   4         4 2 3       5 3 2    2
+--R       (30a b e  - 150a b d e  + 300a b d e  - 300b d e )n x
+--R     + 
+--R             4   5       3 2   4       2 3 2 3         4 3 2       5 4
+--R       (- 60a b e  + 300a b d e  - 600a b d e  + 600a b d e  - 300b d e)n x
+--R     + 
+--R           3 2 2 3       2 3 3 2         4 4       5 5
+--R       (30a b d e  - 110a b d e  + 145a b d e - 77b d )n
+--R  /
+--R         5
+--R     300b e
+--R                                                    Type: Expression(Integer)
+--E 1067
+
+--S 1068 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              5 4   5       5   3   4       5 2 2   3       5 3     2
+--R           60b e n x  + 300b d e n x  + 600b d e n x  + 600b d e n x
+--R         + 
+--R               5 4
+--R           300b d n x
+--R         + 
+--R               5 4       4     3       3 2 2 2       2 3 3          4 4
+--R           (60a e  - 300a b d e  + 600a b d e  - 600a b d e + 300a b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           5 4 5       5   3 4       5 2 2 3       5 3   2       5 4
+--R       (60b e x  + 300b d e x  + 600b d e x  + 600b d e x  + 300b d x)log(c)
+--R     + 
+--R            5 4   5         4 4      5   3    4
+--R       - 12b e n x  + (15a b e  - 75b d e )n x
+--R     + 
+--R             2 3 4         4   3       5 2 2    3
+--R       (- 20a b e  + 100a b d e  - 200b d e )n x
+--R     + 
+--R           3 2 4       2 3   3         4 2 2       5 3     2
+--R       (30a b e  - 150a b d e  + 300a b d e  - 300b d e)n x
+--R     + 
+--R             4   4       3 2   3       2 3 2 2         4 3        5 4
+--R       (- 60a b e  + 300a b d e  - 600a b d e  + 600a b d e - 300b d )n x
+--R  /
+--R         5
+--R     300b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1068
+
+--S 1069 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                3 5 5       3   4 4       3 2 3 3       3 3 2 2       3 4
+--R           - 60b e x  - 300b d e x  - 600b d e x  - 600b d e x  - 300b d e x
+--R         + 
+--R                3 5
+--R           - 60b d
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R              3 5   5       3   4   4       3 2 3   3       3 3 2   2
+--R           60b e n x  + 300b d e n x  + 600b d e n x  + 600b d e n x
+--R         + 
+--R               3 4           3 5
+--R           300b d e n x + 60b d n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           3 5 5       3   4 4       3 2 3 3       3 3 2 2       3 4
+--R       (60b e x  + 300b d e x  + 600b d e x  + 600b d e x  + 300b d e x)log(c)
+--R     + 
+--R             3 2 3       2   3 2         2 4       3 5
+--R       (- 30a d e  + 110a b d e  - 145a b d e + 77b d )n
+--R  /
+--R         3
+--R     300b e
+--R                                                    Type: Expression(Integer)
+--E 1069
+
+--S 1070 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1070
+
+)clear all
+
+--S 1071 of 5341
+t0:=(d+e*x)^3*log(c*(a+b*x)^n)
+--R 
+--R
+--R          3 3       2 2     2       3                n
+--R   (1)  (e x  + 3d e x  + 3d e x + d )log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1071
+
+--S 1072 of 5341
+r0:=-1/4*(b*d-a*e)^3*n*x/b^3-1/8*(b*d-a*e)^2*n*(d+e*x)^2/(b^2*e)-_
+   1/12*(b*d-a*e)*n*(d+e*x)^3/(b*e)-1/16*n*(d+e*x)^4/e-1/4*(b*d-a*e)^4*n*_
+   log(a+b*x)/(b^4*e)+1/4*(d+e*x)^4*log(c*(a+b*x)^n)/e
+--R 
+--R
+--R   (2)
+--R             4 4 4      4   3 3      4 2 2 2      4 3         4 4
+--R         (12b e x  + 48b d e x  + 72b d e x  + 48b d e x + 12b d )
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R             4 4      3     3      2 2 2 2        3 3       4 4
+--R       (- 12a e  + 48a b d e  - 72a b d e  + 48a b d e - 12b d )n log(b x + a)
+--R     + 
+--R           4 4   4        3 4      4   3    3
+--R       - 3b e n x  + (4a b e  - 16b d e )n x
+--R     + 
+--R            2 2 4        3   3      4 2 2    2
+--R       (- 6a b e  + 24a b d e  - 36b d e )n x
+--R     + 
+--R           3   4      2 2   3        3 2 2      4 3
+--R       (12a b e  - 48a b d e  + 72a b d e  - 48b d e)n x
+--R     + 
+--R            2 2 2 2        3 3       4 4
+--R       (- 6a b d e  + 16a b d e - 13b d )n
+--R  /
+--R        4
+--R     48b e
+--R                                                    Type: Expression(Integer)
+--E 1072
+
+--S 1073 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              4 3   4      4   2   3      4 2     2      4 3
+--R           12b e n x  + 48b d e n x  + 72b d e n x  + 48b d n x
+--R         + 
+--R                 4 3      3     2      2 2 2         3 3
+--R           (- 12a e  + 48a b d e  - 72a b d e + 48a b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           4 3 4      4   2 3      4 2   2      4 3             4 3   4
+--R       (12b e x  + 48b d e x  + 72b d e x  + 48b d x)log(c) - 3b e n x
+--R     + 
+--R            3 3      4   2    3        2 2 3        3   2      4 2     2
+--R       (4a b e  - 16b d e )n x  + (- 6a b e  + 24a b d e  - 36b d e)n x
+--R     + 
+--R           3   3      2 2   2        3 2       4 3
+--R       (12a b e  - 48a b d e  + 72a b d e - 48b d )n x
+--R  /
+--R        4
+--R     48b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1073
+
+--S 1074 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               2 4 4      2   3 3      2 2 2 2      2 3         2 4
+--R         (- 12b e x  - 48b d e x  - 72b d e x  - 48b d e x - 12b d )
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R             2 4   4      2   3   3      2 2 2   2      2 3           2 4
+--R         (12b e n x  + 48b d e n x  + 72b d e n x  + 48b d e n x + 12b d n)
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           2 4 4      2   3 3      2 2 2 2      2 3
+--R       (12b e x  + 48b d e x  + 72b d e x  + 48b d e x)log(c)
+--R     + 
+--R          2 2 2          3       2 4
+--R       (6a d e  - 16a b d e + 13b d )n
+--R  /
+--R        2
+--R     48b e
+--R                                                    Type: Expression(Integer)
+--E 1074
+
+--S 1075 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1075
+
+)clear all
+
+--S 1076 of 5341
+t0:=(d+e*x)^2*log(c*(a+b*x)^n)
+--R 
+--R
+--R          2 2             2                n
+--R   (1)  (e x  + 2d e x + d )log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1076
+
+--S 1077 of 5341
+r0:=-1/3*(b*d-a*e)^2*n*x/b^2-1/6*(b*d-a*e)*n*(d+e*x)^2/(b*e)-_
+   1/9*n*(d+e*x)^3/e-1/3*(b*d-a*e)^3*n*log(a+b*x)/(b^3*e)+_
+   1/3*(d+e*x)^3*log(c*(a+b*x)^n)/e
+--R 
+--R
+--R   (2)
+--R          3 3 3      3   2 2      3 2        3 3                n
+--R       (6b e x  + 18b d e x  + 18b d e x + 6b d )log(c (b x + a) )
+--R     + 
+--R          3 3      2     2        2 2      3 3                    3 3   3
+--R       (6a e  - 18a b d e  + 18a b d e - 6b d )n log(b x + a) - 2b e n x
+--R     + 
+--R            2 3     3   2    2        2   3        2   2      3 2
+--R       (3a b e  - 9b d e )n x  + (- 6a b e  + 18a b d e  - 18b d e)n x
+--R     + 
+--R            2 2      3 3
+--R       (3a b d e - 5b d )n
+--R  /
+--R        3
+--R     18b e
+--R                                                    Type: Expression(Integer)
+--E 1077
+
+--S 1078 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 2   3      3       2      3 2
+--R             6b e n x  + 18b d e n x  + 18b d n x
+--R           + 
+--R                3 2      2             2 2
+--R             (6a e  - 18a b d e + 18a b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R          3 2 3      3     2      3 2             3 2   3
+--R       (6b e x  + 18b d e x  + 18b d x)log(c) - 2b e n x
+--R     + 
+--R            2 2     3       2        2   2        2         3 2
+--R       (3a b e  - 9b d e)n x  + (- 6a b e  + 18a b d e - 18b d )n x
+--R  /
+--R        3
+--R     18b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1078
+
+--S 1079 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3 3          2 2        2          3                n
+--R       (- 6b e x  - 18b d e x  - 18b d e x - 6b d )log(c (b x + a) )
+--R     + 
+--R            3   3          2   2        2            3
+--R       (6b e n x  + 18b d e n x  + 18b d e n x + 6b d n)log(b x + a)
+--R     + 
+--R            3 3          2 2        2                    2        3
+--R       (6b e x  + 18b d e x  + 18b d e x)log(c) + (- 3a d e + 5b d )n
+--R  /
+--R     18b e
+--R                                                    Type: Expression(Integer)
+--E 1079
+
+--S 1080 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1080
+
+)clear all
+
+--S 1081 of 5341
+t0:=(d+e*x)*log(c*(a+b*x)^n)
+--R 
+--R
+--R                                n
+--R   (1)  (e x + d)log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1081
+
+--S 1082 of 5341
+r0:=-1/2*(b*d-a*e)*n*x/b-1/4*n*(d+e*x)^2/e-1/2*(b*d-a*e)^2*n*log(a+b*x)/_
+   (b^2*e)+1/2*(d+e*x)^2*log(c*(a+b*x)^n)/e
+--R 
+--R
+--R   (2)
+--R          2 2 2     2          2 2                n
+--R       (2b e x  + 4b d e x + 2b d )log(c (b x + a) )
+--R     + 
+--R            2 2                2 2                   2 2   2
+--R       (- 2a e  + 4a b d e - 2b d )n log(b x + a) - b e n x
+--R     + 
+--R              2     2           2 2
+--R       (2a b e  - 4b d e)n x - b d n
+--R  /
+--R       2
+--R     4b e
+--R                                                    Type: Expression(Integer)
+--E 1082
+
+--S 1083 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2     2     2             2
+--R       (2b e n x  + 4b d n x + (- 2a e + 4a b d)n)log(b x + a)
+--R     + 
+--R          2   2     2              2     2               2
+--R       (2b e x  + 4b d x)log(c) - b e n x  + (2a b e - 4b d)n x
+--R  /
+--R       2
+--R     4b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1083
+
+--S 1084 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            2 2              2                n
+--R       (- 2e x  - 4d e x - 2d )log(c (b x + a) )
+--R     + 
+--R          2   2                2                    2 2                    2
+--R       (2e n x  + 4d e n x + 2d n)log(b x + a) + (2e x  + 4d e x)log(c) + d n
+--R  /
+--R     4e
+--R                                                    Type: Expression(Integer)
+--E 1084
+
+--S 1085 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1085
+
+)clear all
+
+--S 1086 of 5341
+t0:=log(c*(a+b*x)^n)
+--R 
+--R
+--R                       n
+--R   (1)  log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1086
+
+--S 1087 of 5341
+r0:=-n*x+(a+b*x)*log(c*(a+b*x)^n)/b
+--R 
+--R
+--R                                n
+--R        (b x + a)log(c (b x + a) ) - b n x
+--R   (2)  ----------------------------------
+--R                         b
+--R                                                    Type: Expression(Integer)
+--E 1087
+
+--S 1088 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (b n x + a n)log(b x + a) + b x log(c) - b n x
+--R   (3)  ----------------------------------------------
+--R                               b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1088
+
+--S 1089 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                                  n
+--R        (- b x - a)log(c (b x + a) ) + (b n x + a n)log(b x + a) + b x log(c)
+--R   (4)  ---------------------------------------------------------------------
+--R                                          b
+--R                                                    Type: Expression(Integer)
+--E 1089
+
+--S 1090 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1090
+
+)clear all
+
+--S 1091 of 5341
+t0:=log(c*(a+b*x)^n)/(d+e*x)
+--R 
+--R
+--R                       n
+--R        log(c (b x + a) )
+--R   (1)  -----------------
+--R             e x + d
+--R                                                    Type: Expression(Integer)
+--E 1091
+
+--S 1092 of 5341
+--r0:=log(c*(a+b*x)^n)*log(b*(d+e*x)/(b*d-a*e))/e+_
+--   n*polylog(2,-e*(a+b*x)/(b*d-a*e))/e
+--E 1092
+
+--S 1093 of 5341
+--a0:=integrate(t0,x)
+--E 1093
+
+--S 1094 of 5341
+--m0:=a0-r0
+--E 1094
+
+--S 1095 of 5341
+--d0:=D(m0,x)
+--E 1095
+
+)clear all
+
+--S 1096 of 5341
+t0:=log(c*(a+b*x)^n)/(d+e*x)^2
+--R 
+--R
+--R                        n
+--R         log(c (b x + a) )
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 1096
+
+--S 1097 of 5341
+r0:=b*n*log(a+b*x)/(e*(b*d-a*e))-log(c*(a+b*x)^n)/(e*(d+e*x))-_
+   b*n*log(d+e*x)/(e*(b*d-a*e))
+--R 
+--R
+--R   (2)
+--R                                   n
+--R       (- a e + b d)log(c (b x + a) ) + (b e n x + b d n)log(e x + d)
+--R     + 
+--R       (- b e n x - b d n)log(b x + a)
+--R  /
+--R         3        2          2      2
+--R     (a e  - b d e )x + a d e  - b d e
+--R                                                    Type: Expression(Integer)
+--E 1097
+
+--S 1098 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       (b e n x + b d n)log(e x + d) + (- b e n x - a e n)log(b x + a)
+--R     + 
+--R       (- a e + b d)log(c)
+--R  /
+--R         3        2          2      2
+--R     (a e  - b d e )x + a d e  - b d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1098
+
+--S 1099 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                       n
+--R        log(c (b x + a) ) - n log(b x + a) - log(c)
+--R   (4)  -------------------------------------------
+--R                          2
+--R                         e x + d e
+--R                                                    Type: Expression(Integer)
+--E 1099
+
+--S 1100 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1100
+
+)clear all
+
+--S 1101 of 5341
+t0:=log(c*(a+b*x)^n)/(d+e*x)^3
+--R 
+--R
+--R                             n
+--R              log(c (b x + a) )
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 1101
+
+--S 1102 of 5341
+r0:=1/2*b*n/(e*(b*d-a*e)*(d+e*x))+1/2*b^2*n*log(a+b*x)/(e*(b*d-a*e)^2)-_
+   1/2*log(c*(a+b*x)^n)/(e*(d+e*x)^2)-1/2*b^2*n*log(d+e*x)/(e*(b*d-a*e)^2)
+--R 
+--R
+--R   (2)
+--R           2 2               2 2                n
+--R       (- a e  + 2a b d e - b d )log(c (b x + a) )
+--R     + 
+--R           2 2   2     2           2 2
+--R       (- b e n x  - 2b d e n x - b d n)log(e x + d)
+--R     + 
+--R         2 2   2     2           2 2                         2    2
+--R       (b e n x  + 2b d e n x + b d n)log(b x + a) + (- a b e  + b d e)n x
+--R     + 
+--R                     2 2
+--R       (- a b d e + b d )n
+--R  /
+--R          2 5           4     2 2 3  2      2   4         2 3     2 3 2
+--R       (2a e  - 4a b d e  + 2b d e )x  + (4a d e  - 8a b d e  + 4b d e )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       2a d e  - 4a b d e  + 2b d e
+--R                                                    Type: Expression(Integer)
+--E 1102
+
+--S 1103 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 2   2     2           2 2
+--R       (- b e n x  - 2b d e n x - b d n)log(e x + d)
+--R     + 
+--R         2 2   2     2              2 2
+--R       (b e n x  + 2b d e n x + (- a e  + 2a b d e)n)log(b x + a)
+--R     + 
+--R           2 2               2 2                  2    2
+--R       (- a e  + 2a b d e - b d )log(c) + (- a b e  + b d e)n x
+--R     + 
+--R                     2 2
+--R       (- a b d e + b d )n
+--R  /
+--R          2 5           4     2 2 3  2      2   4         2 3     2 3 2
+--R       (2a e  - 4a b d e  + 2b d e )x  + (4a d e  - 8a b d e  + 4b d e )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       2a d e  - 4a b d e  + 2b d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1103
+
+--S 1104 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                       n
+--R        log(c (b x + a) ) - n log(b x + a) - log(c)
+--R   (4)  -------------------------------------------
+--R                     3 2       2      2
+--R                   2e x  + 4d e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 1104
+
+--S 1105 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1105
+
+)clear all
+
+--S 1106 of 5341
+t0:=log(c*(a+b*x)^n)/(d+e*x)^4
+--R 
+--R
+--R                                  n
+--R                   log(c (b x + a) )
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 1106
+
+--S 1107 of 5341
+r0:=1/6*b*n/(e*(b*d-a*e)*(d+e*x)^2)+1/3*b^2*n/(e*(b*d-a*e)^2*(d+e*x))+_
+   1/3*b^3*n*log(a+b*x)/(e*(b*d-a*e)^3)-1/3*log(c*(a+b*x)^n)/(e*(d+e*x)^3)-_
+   1/3*b^3*n*log(d+e*x)/(e*(b*d-a*e)^3)
+--R 
+--R
+--R   (2)
+--R            3 3     2     2       2 2      3 3                n
+--R       (- 2a e  + 6a b d e  - 6a b d e + 2b d )log(c (b x + a) )
+--R     + 
+--R          3 3   3     3   2   2     3 2          3 3
+--R       (2b e n x  + 6b d e n x  + 6b d e n x + 2b d n)log(e x + d)
+--R     + 
+--R            3 3   3     3   2   2     3 2          3 3
+--R       (- 2b e n x  - 6b d e n x  - 6b d e n x - 2b d n)log(b x + a)
+--R     + 
+--R            2 3     3   2    2       2   3       2   2     3 2
+--R       (2a b e  - 2b d e )n x  + (- a b e  + 6a b d e  - 5b d e)n x
+--R     + 
+--R           2     2       2 2      3 3
+--R       (- a b d e  + 4a b d e - 3b d )n
+--R  /
+--R          3 7      2     6        2 2 5     3 3 4  3
+--R       (6a e  - 18a b d e  + 18a b d e  - 6b d e )x
+--R     + 
+--R           3   6      2   2 5        2 3 4      3 4 3  2
+--R       (18a d e  - 54a b d e  + 54a b d e  - 18b d e )x
+--R     + 
+--R           3 2 5      2   3 4        2 4 3      3 5 2       3 3 4      2   4 3
+--R       (18a d e  - 54a b d e  + 54a b d e  - 18b d e )x + 6a d e  - 18a b d e
+--R     + 
+--R            2 5 2     3 6
+--R       18a b d e  - 6b d e
+--R                                                    Type: Expression(Integer)
+--E 1107
+
+--S 1108 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3 3   3     3   2   2     3 2          3 3
+--R       (2b e n x  + 6b d e n x  + 6b d e n x + 2b d n)log(e x + d)
+--R     + 
+--R               3 3   3     3   2   2     3 2
+--R           - 2b e n x  - 6b d e n x  - 6b d e n x
+--R         + 
+--R                3 3     2     2       2 2
+--R           (- 2a e  + 6a b d e  - 6a b d e)n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R            3 3     2     2       2 2      3 3               2 3     3   2    2
+--R       (- 2a e  + 6a b d e  - 6a b d e + 2b d )log(c) + (2a b e  - 2b d e )n x
+--R     + 
+--R           2   3       2   2     3 2            2     2       2 2      3 3
+--R       (- a b e  + 6a b d e  - 5b d e)n x + (- a b d e  + 4a b d e - 3b d )n
+--R  /
+--R          3 7      2     6        2 2 5     3 3 4  3
+--R       (6a e  - 18a b d e  + 18a b d e  - 6b d e )x
+--R     + 
+--R           3   6      2   2 5        2 3 4      3 4 3  2
+--R       (18a d e  - 54a b d e  + 54a b d e  - 18b d e )x
+--R     + 
+--R           3 2 5      2   3 4        2 4 3      3 5 2       3 3 4      2   4 3
+--R       (18a d e  - 54a b d e  + 54a b d e  - 18b d e )x + 6a d e  - 18a b d e
+--R     + 
+--R            2 5 2     3 6
+--R       18a b d e  - 6b d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1108
+
+--S 1109 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                       n
+--R        log(c (b x + a) ) - n log(b x + a) - log(c)
+--R   (4)  -------------------------------------------
+--R                4 3       3 2     2 2      3
+--R              3e x  + 9d e x  + 9d e x + 3d e
+--R                                                    Type: Expression(Integer)
+--E 1109
+
+--S 1110 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1110
+
+)clear all
+
+--S 1111 of 5341
+t0:=(d+e*x)^m*log(c*(a+b*x)^n)^2
+--R 
+--R
+--R                 m               n 2
+--R   (1)  (e x + d) log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1111
+
+--S 1112 of 5341
+--r0:=Int((d+e*x)^m*log(c*(a+b*x)^n)^2,x)
+--E 1112
+
+--S 1113 of 5341
+--a0:=integrate(t0,x)
+--E 1113
+
+--S 1114 of 5341
+--m0:=a0-r0
+--E 1114
+
+--S 1115 of 5341
+--d0:=D(m0,x)
+--E 1115
+
+)clear all
+
+--S 1116 of 5341
+t0:=(d+e*x)^3*log(c*(a+b*x)^n)^2
+--R 
+--R
+--R          3 3       2 2     2       3                n 2
+--R   (1)  (e x  + 3d e x  + 3d e x + d )log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1116
+
+--S 1117 of 5341
+r0:=25/24*(b*d-a*e)^3*n^2*x/b^3+13/48*(b*d-a*e)^2*n^2*(d+e*x)^2/(b^2*e)+_
+   7/72*(b*d-a*e)*n^2*(d+e*x)^3/(b*e)+1/32*n^2*(d+e*x)^4/e+13/24*(b*d-_
+   a*e)^4*n^2*log(a+b*x)/(b^4*e)-1/2*(b*d-a*e)^3*n*(a+b*x)*log(c*(a+b*x)^n)/_
+   b^4-1/4*(b*d-a*e)^2*n*(d+e*x)^2*log(c*(a+b*x)^n)/(b^2*e)-1/6*(b*d-a*e)*_
+   n*(d+e*x)^3*log(c*(a+b*x)^n)/(b*e)-1/8*n*(d+e*x)^4*log(c*(a+b*x)^n)/e+_
+   1/4*(b*d-a*e)^3*(a+b*x)*log(c*(a+b*x)^n)^2/b^4+1/4*(b*d-a*e)^2*(a+b*x)*_
+   (d+e*x)*log(c*(a+b*x)^n)^2/b^3+1/4*(b*d-a*e)*(a+b*x)*(d+e*x)^2*log(c*_
+   (a+b*x)^n)^2/b^2+1/4*(a+b*x)*(d+e*x)^3*log(c*(a+b*x)^n)^2/b
+--R 
+--R
+--R   (2)
+--R              4 4 4       4   3 3       4 2 2 2       4 3         4 4
+--R           72b e x  + 288b d e x  + 432b d e x  + 288b d e x - 72a e
+--R         + 
+--R               3     3       2 2 2 2         3 3
+--R           288a b d e  - 432a b d e  + 288a b d e
+--R      *
+--R                        n 2
+--R         log(c (b x + a) )
+--R     + 
+--R                4 4   4         3 4       4   3    3
+--R           - 36b e n x  + (48a b e  - 192b d e )n x
+--R         + 
+--R                 2 2 4         3   3       4 2 2    2
+--R           (- 72a b e  + 288a b d e  - 432b d e )n x
+--R         + 
+--R                3   4       2 2   3         3 2 2       4 3
+--R           (144a b e  - 576a b d e  + 864a b d e  - 576b d e)n x
+--R         + 
+--R                4 4       3     3       2 2 2 2        3 3        4 4
+--R           (144a e  - 432a b d e  + 360a b d e  + 48a b d e - 156b d )n
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R              4 4       3     3       2 2 2 2         3 3        4 4  2
+--R         (156a e  - 624a b d e  + 936a b d e  - 624a b d e + 156b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R         4 4 2 4           3 4      4   3  2 3
+--R       9b e n x  + (- 28a b e  + 64b d e )n x
+--R     + 
+--R           2 2 4         3   3       4 2 2  2 2
+--R       (78a b e  - 240a b d e  + 216b d e )n x
+--R     + 
+--R              3   4        2 2   3          3 2 2       4 3   2
+--R       (- 300a b e  + 1056a b d e  - 1296a b d e  + 576b d e)n x
+--R     + 
+--R           2 2 2 2         3 3        4 4  2
+--R       (78a b d e  - 184a b d e + 115b d )n
+--R  /
+--R         4
+--R     288b e
+--R                                                    Type: Expression(Integer)
+--E 1117
+
+--S 1118 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              4 3 2 4       4   2 2 3       4 2   2 2       4 3 2
+--R           72b e n x  + 288b d e n x  + 432b d e n x  + 288b d n x
+--R         + 
+--R                 4 3       3     2       2 2 2          3 3  2
+--R           (- 72a e  + 288a b d e  - 432a b d e + 288a b d )n
+--R      *
+--R                     2
+--R         log(b x + a)
+--R     + 
+--R                   4 3   4       4   2   3       4 2     2       4 3
+--R               144b e n x  + 576b d e n x  + 864b d e n x  + 576b d n x
+--R             + 
+--R                      4 3       3     2       2 2 2          3 3
+--R               (- 144a e  + 576a b d e  - 864a b d e + 576a b d )n
+--R          *
+--R             log(c)
+--R         + 
+--R                4 3 2 4         3 3       4   2  2 3
+--R           - 36b e n x  + (48a b e  - 192b d e )n x
+--R         + 
+--R                 2 2 3         3   2       4 2   2 2
+--R           (- 72a b e  + 288a b d e  - 432b d e)n x
+--R         + 
+--R                3   3       2 2   2         3 2        4 3  2
+--R           (144a b e  - 576a b d e  + 864a b d e - 576b d )n x
+--R         + 
+--R                4 3        3     2        2 2 2          3 3  2
+--R           (300a e  - 1056a b d e  + 1296a b d e - 576a b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           4 3 4       4   2 3       4 2   2       4 3        2
+--R       (72b e x  + 288b d e x  + 432b d e x  + 288b d x)log(c)
+--R     + 
+--R                4 3   4         3 3       4   2    3
+--R           - 36b e n x  + (48a b e  - 192b d e )n x
+--R         + 
+--R                 2 2 3         3   2       4 2     2
+--R           (- 72a b e  + 288a b d e  - 432b d e)n x
+--R         + 
+--R                3   3       2 2   2         3 2        4 3
+--R           (144a b e  - 576a b d e  + 864a b d e - 576b d )n x
+--R      *
+--R         log(c)
+--R     + 
+--R         4 3 2 4           3 3      4   2  2 3
+--R       9b e n x  + (- 28a b e  + 64b d e )n x
+--R     + 
+--R           2 2 3         3   2       4 2   2 2
+--R       (78a b e  - 240a b d e  + 216b d e)n x
+--R     + 
+--R              3   3        2 2   2          3 2        4 3  2
+--R       (- 300a b e  + 1056a b d e  - 1296a b d e + 576b d )n x
+--R  /
+--R         4
+--R     288b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1118
+
+--S 1119 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                4 4 4       4   3 3       4 2 2 2       4 3         4 4
+--R           - 72b e x  - 288b d e x  - 432b d e x  - 288b d e x + 72a e
+--R         + 
+--R                 3     3       2 2 2 2         3 3
+--R           - 288a b d e  + 432a b d e  - 288a b d e
+--R      *
+--R                        n 2
+--R         log(c (b x + a) )
+--R     + 
+--R              4 4   4           3 4       4   3    3
+--R           36b e n x  + (- 48a b e  + 192b d e )n x
+--R         + 
+--R               2 2 4         3   3       4 2 2    2
+--R           (72a b e  - 288a b d e  + 432b d e )n x
+--R         + 
+--R                  3   4       2 2   3         3 2 2       4 3
+--R           (- 144a b e  + 576a b d e  - 864a b d e  + 576b d e)n x
+--R         + 
+--R                  4 4       3     3       2 2 2 2        3 3        4 4
+--R           (- 144a e  + 432a b d e  - 360a b d e  - 48a b d e + 156b d )n
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R              4 4 2 4       4   3 2 3       4 2 2 2 2       4 3   2
+--R           72b e n x  + 288b d e n x  + 432b d e n x  + 288b d e n x
+--R         + 
+--R                 4 4       3     3       2 2 2 2         3 3   2
+--R           (- 72a e  + 288a b d e  - 432a b d e  + 288a b d e)n
+--R      *
+--R                     2
+--R         log(b x + a)
+--R     + 
+--R                   4 4   4       4   3   3       4 2 2   2       4 3
+--R               144b e n x  + 576b d e n x  + 864b d e n x  + 576b d e n x
+--R             + 
+--R                      4 4       3     3       2 2 2 2         3 3
+--R               (- 144a e  + 576a b d e  - 864a b d e  + 576a b d e)n
+--R          *
+--R             log(c)
+--R         + 
+--R                4 4 2 4         3 4       4   3  2 3
+--R           - 36b e n x  + (48a b e  - 192b d e )n x
+--R         + 
+--R                 2 2 4         3   3       4 2 2  2 2
+--R           (- 72a b e  + 288a b d e  - 432b d e )n x
+--R         + 
+--R                3   4       2 2   3         3 2 2       4 3   2
+--R           (144a b e  - 576a b d e  + 864a b d e  - 576b d e)n x
+--R         + 
+--R                4 4       3     3       2 2 2 2        3 3        4 4  2
+--R           (144a e  - 432a b d e  + 360a b d e  + 48a b d e - 156b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           4 4 4       4   3 3       4 2 2 2       4 3          2
+--R       (72b e x  + 288b d e x  + 432b d e x  + 288b d e x)log(c)
+--R     + 
+--R                4 4   4         3 4       4   3    3
+--R           - 36b e n x  + (48a b e  - 192b d e )n x
+--R         + 
+--R                 2 2 4         3   3       4 2 2    2
+--R           (- 72a b e  + 288a b d e  - 432b d e )n x
+--R         + 
+--R                3   4       2 2   3         3 2 2       4 3
+--R           (144a b e  - 576a b d e  + 864a b d e  - 576b d e)n x
+--R      *
+--R         log(c)
+--R     + 
+--R             2 2 2 2         3 3        4 4  2
+--R       (- 78a b d e  + 184a b d e - 115b d )n
+--R  /
+--R         4
+--R     288b e
+--R                                                    Type: Expression(Integer)
+--E 1119
+
+--S 1120 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1120
+
+)clear all
+
+--S 1121 of 5341
+t0:=(d+e*x)^2*log(c*(a+b*x)^n)^2
+--R 
+--R
+--R          2 2             2                n 2
+--R   (1)  (e x  + 2d e x + d )log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1121
+
+--S 1122 of 5341
+r0:=11/9*(b*d-a*e)^2*n^2*x/b^2+5/18*(b*d-a*e)*n^2*(d+e*x)^2/(b*e)+2/27*n^2*_
+   (d+e*x)^3/e+5/9*(b*d-a*e)^3*n^2*log(a+b*x)/(b^3*e)-2/3*(b*d-a*e)^2*n*_
+   (a+b*x)*log(c*(a+b*x)^n)/b^3-1/3*(b*d-a*e)*n*(d+e*x)^2*log(c*(a+b*x)^n)/_
+   (b*e)-2/9*n*(d+e*x)^3*log(c*(a+b*x)^n)/e+1/3*(b*d-a*e)^2*(a+b*x)*log(c*(a+_
+   b*x)^n)^2/b^3+1/3*(b*d-a*e)*(a+b*x)*(d+e*x)*log(c*(a+b*x)^n)^2/b^2+_
+   1/3*(a+b*x)*(d+e*x)^2*log(c*(a+b*x)^n)^2/b
+--R 
+--R
+--R   (2)
+--R             3 3 3      3   2 2      3 2         3 3      2     2        2 2
+--R         (18b e x  + 54b d e x  + 54b d e x + 18a e  - 54a b d e  + 54a b d e)
+--R      *
+--R                        n 2
+--R         log(c (b x + a) )
+--R     + 
+--R                3 3   3         2 3      3   2    2
+--R           - 12b e n x  + (18a b e  - 54b d e )n x
+--R         + 
+--R                 2   3         2   2       3 2
+--R           (- 36a b e  + 108a b d e  - 108b d e)n x
+--R         + 
+--R                 3 3      2     2        2 2       3 3
+--R           (- 36a e  + 72a b d e  - 18a b d e - 30b d )n
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R             3 3      2     2        2 2       3 3  2                 3 3 2 3
+--R       (- 30a e  + 90a b d e  - 90a b d e + 30b d )n log(b x + a) + 4b e n x
+--R     + 
+--R               2 3      3   2  2 2       2   3         2   2       3 2   2
+--R       (- 15a b e  + 27b d e )n x  + (66a b e  - 162a b d e  + 108b d e)n x
+--R     + 
+--R               2 2       3 3  2
+--R       (- 15a b d e + 19b d )n
+--R  /
+--R        3
+--R     54b e
+--R                                                    Type: Expression(Integer)
+--E 1122
+
+--S 1123 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 2 2 3      3     2 2      3 2 2
+--R           18b e n x  + 54b d e n x  + 54b d n x
+--R         + 
+--R               3 2      2             2 2  2
+--R           (18a e  - 54a b d e + 54a b d )n
+--R      *
+--R                     2
+--R         log(b x + a)
+--R     + 
+--R                  3 2   3       3       2       3 2
+--R               36b e n x  + 108b d e n x  + 108b d n x
+--R             + 
+--R                   3 2       2              2 2
+--R               (36a e  - 108a b d e + 108a b d )n
+--R          *
+--R             log(c)
+--R         + 
+--R                3 2 2 3         2 2      3     2 2
+--R           - 12b e n x  + (18a b e  - 54b d e)n x
+--R         + 
+--R                 2   2         2          3 2  2
+--R           (- 36a b e  + 108a b d e - 108b d )n x
+--R         + 
+--R                 3 2       2              2 2  2
+--R           (- 66a e  + 162a b d e - 108a b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           3 2 3      3     2      3 2        2
+--R       (18b e x  + 54b d e x  + 54b d x)log(c)
+--R     + 
+--R                3 2   3         2 2      3       2
+--R           - 12b e n x  + (18a b e  - 54b d e)n x
+--R         + 
+--R                 2   2         2          3 2
+--R           (- 36a b e  + 108a b d e - 108b d )n x
+--R      *
+--R         log(c)
+--R     + 
+--R         3 2 2 3           2 2      3     2 2
+--R       4b e n x  + (- 15a b e  + 27b d e)n x
+--R     + 
+--R           2   2         2          3 2  2
+--R       (66a b e  - 162a b d e + 108b d )n x
+--R  /
+--R        3
+--R     54b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1123
+
+--S 1124 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               3 3 3      3   2 2      3 2         3 3      2     2        2 2
+--R         (- 18b e x  - 54b d e x  - 54b d e x - 18a e  + 54a b d e  - 54a b d e)
+--R      *
+--R                        n 2
+--R         log(c (b x + a) )
+--R     + 
+--R              3 3   3           2 3      3   2    2
+--R           12b e n x  + (- 18a b e  + 54b d e )n x
+--R         + 
+--R               2   3         2   2       3 2
+--R           (36a b e  - 108a b d e  + 108b d e)n x
+--R         + 
+--R               3 3      2     2        2 2       3 3
+--R           (36a e  - 72a b d e  + 18a b d e + 30b d )n
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R              3 3 2 3      3   2 2 2      3 2   2
+--R           18b e n x  + 54b d e n x  + 54b d e n x
+--R         + 
+--R               3 3      2     2        2 2   2
+--R           (18a e  - 54a b d e  + 54a b d e)n
+--R      *
+--R                     2
+--R         log(b x + a)
+--R     + 
+--R                  3 3   3       3   2   2       3 2
+--R               36b e n x  + 108b d e n x  + 108b d e n x
+--R             + 
+--R                   3 3       2     2         2 2
+--R               (36a e  - 108a b d e  + 108a b d e)n
+--R          *
+--R             log(c)
+--R         + 
+--R                3 3 2 3         2 3      3   2  2 2
+--R           - 12b e n x  + (18a b e  - 54b d e )n x
+--R         + 
+--R                 2   3         2   2       3 2   2
+--R           (- 36a b e  + 108a b d e  - 108b d e)n x
+--R         + 
+--R                 3 3      2     2        2 2       3 3  2
+--R           (- 36a e  + 72a b d e  - 18a b d e - 30b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           3 3 3      3   2 2      3 2          2
+--R       (18b e x  + 54b d e x  + 54b d e x)log(c)
+--R     + 
+--R                3 3   3         2 3      3   2    2
+--R           - 12b e n x  + (18a b e  - 54b d e )n x
+--R         + 
+--R                 2   3         2   2       3 2
+--R           (- 36a b e  + 108a b d e  - 108b d e)n x
+--R      *
+--R         log(c)
+--R     + 
+--R             2 2       3 3  2
+--R       (15a b d e - 19b d )n
+--R  /
+--R        3
+--R     54b e
+--R                                                    Type: Expression(Integer)
+--E 1124
+
+--S 1125 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1125
+
+)clear all
+
+--S 1126 of 5341
+t0:=(d+e*x)*log(c*(a+b*x)^n)^2
+--R 
+--R
+--R                                n 2
+--R   (1)  (e x + d)log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1126
+
+--S 1127 of 5341
+r0:=3/2*(b*d-a*e)*n^2*x/b+1/4*n^2*(d+e*x)^2/e+1/2*(b*d-a*e)^2*n^2*_
+   log(a+b*x)/(b^2*e)-(b*d-a*e)*n*(a+b*x)*log(c*(a+b*x)^n)/b^2-_
+   1/2*n*(d+e*x)^2*log(c*(a+b*x)^n)/e+1/2*(b*d-a*e)*(a+b*x)*log(c*(a+_
+   b*x)^n)^2/b^2+1/2*(a+b*x)*(d+e*x)*log(c*(a+b*x)^n)^2/b
+--R 
+--R
+--R   (2)
+--R          2 2 2     2          2 2                           n 2
+--R       (2b e x  + 4b d e x - 2a e  + 4a b d e)log(c (b x + a) )
+--R     + 
+--R              2 2   2          2     2             2 2                2 2
+--R         (- 2b e n x  + (4a b e  - 8b d e)n x + (4a e  - 4a b d e - 2b d )n)
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R          2 2                2 2  2                2 2 2 2
+--R       (2a e  - 4a b d e + 2b d )n log(b x + a) + b e n x
+--R     + 
+--R                2     2     2     2 2 2
+--R       (- 6a b e  + 8b d e)n x + b d n
+--R  /
+--R       2
+--R     4b e
+--R                                                    Type: Expression(Integer)
+--E 1127
+
+--S 1128 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2   2 2     2   2         2            2             2
+--R       (2b e n x  + 4b d n x + (- 2a e + 4a b d)n )log(b x + a)
+--R     + 
+--R              2     2     2             2                        2   2 2
+--R           (4b e n x  + 8b d n x + (- 4a e + 8a b d)n)log(c) - 2b e n x
+--R         + 
+--R                       2   2       2            2
+--R           (4a b e - 8b d)n x + (6a e - 8a b d)n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R          2   2     2          2        2     2               2
+--R       (2b e x  + 4b d x)log(c)  + (- 2b e n x  + (4a b e - 8b d)n x)log(c)
+--R     + 
+--R        2   2 2                 2   2
+--R       b e n x  + (- 6a b e + 8b d)n x
+--R  /
+--R       2
+--R     4b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1128
+
+--S 1129 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            2 2 2     2          2 2                           n 2
+--R       (- 2b e x  - 4b d e x + 2a e  - 4a b d e)log(c (b x + a) )
+--R     + 
+--R            2 2   2            2     2               2 2                2 2
+--R         (2b e n x  + (- 4a b e  + 8b d e)n x + (- 4a e  + 4a b d e + 2b d )n)
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R          2 2 2 2     2     2         2 2             2             2
+--R       (2b e n x  + 4b d e n x + (- 2a e  + 4a b d e)n )log(b x + a)
+--R     + 
+--R              2 2   2     2               2 2                         2 2 2 2
+--R           (4b e n x  + 8b d e n x + (- 4a e  + 8a b d e)n)log(c) - 2b e n x
+--R         + 
+--R                  2     2     2       2 2                2 2  2
+--R           (4a b e  - 8b d e)n x + (4a e  - 4a b d e - 2b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R          2 2 2     2            2        2 2   2          2     2
+--R       (2b e x  + 4b d e x)log(c)  + (- 2b e n x  + (4a b e  - 8b d e)n x)log(c)
+--R     + 
+--R          2 2 2
+--R       - b d n
+--R  /
+--R       2
+--R     4b e
+--R                                                    Type: Expression(Integer)
+--E 1129
+
+--S 1130 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1130
+
+)clear all
+
+--S 1131 of 5341
+t0:=log(c*(a+b*x)^n)^2
+--R 
+--R
+--R                       n 2
+--R   (1)  log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1131
+
+--S 1132 of 5341
+r0:=2*n^2*x-2*n*(a+b*x)*log(c*(a+b*x)^n)/b+(a+b*x)*log(c*(a+b*x)^n)^2/b
+--R 
+--R
+--R   (2)
+--R                           n 2                                   n        2
+--R   (b x + a)log(c (b x + a) )  + (- 2b n x - 2a n)log(c (b x + a) ) + 2b n x
+--R   -------------------------------------------------------------------------
+--R                                       b
+--R                                                    Type: Expression(Integer)
+--E 1132
+
+--S 1133 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2       2             2
+--R       (b n x + a n )log(b x + a)
+--R     + 
+--R                                    2        2                          2
+--R       ((2b n x + 2a n)log(c) - 2b n x - 2a n )log(b x + a) + b x log(c)
+--R     + 
+--R                             2
+--R       - 2b n x log(c) + 2b n x
+--R  /
+--R     b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1133
+
+--S 1134 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 n 2                                 n
+--R       (- b x - a)log(c (b x + a) )  + (2b n x + 2a n)log(c (b x + a) )
+--R     + 
+--R           2       2             2
+--R       (b n x + a n )log(b x + a)
+--R     + 
+--R                                    2        2                          2
+--R       ((2b n x + 2a n)log(c) - 2b n x - 2a n )log(b x + a) + b x log(c)
+--R     + 
+--R       - 2b n x log(c)
+--R  /
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 1134
+
+--S 1135 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1135
+
+)clear all
+
+--S 1136 of 5341
+t0:=log(c*(a+b*x)^n)^2/(d+e*x)
+--R 
+--R
+--R                       n 2
+--R        log(c (b x + a) )
+--R   (1)  ------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 1136
+
+--S 1137 of 5341
+--r0:=log(c*(a+b*x)^n)^2*log(b*(d+e*x)/(b*d-a*e))/e+2*n*log(c*(a+b*x)^n)*_
+--   polylog(2,-e*(a+b*x)/(b*d-a*e))/e-2*n^2*polylog(3,-e*(a+b*x)/(b*d-a*e))/e
+--E 1137
+
+--S 1138 of 5341
+--a0:=integrate(t0,x)
+--E 1138
+
+--S 1139 of 5341
+--m0:=a0-r0
+--E 1139
+
+--S 1140 of 5341
+--d0:=D(m0,x)
+--E 1140
+
+)clear all
+
+--S 1141 of 5341
+t0:=log(c*(a+b*x)^n)^2/(d+e*x)^2
+--R 
+--R
+--R                       n 2
+--R        log(c (b x + a) )
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 1141
+
+--S 1142 of 5341
+--r0:=(a+b*x)*log(c*(a+b*x)^n)^2/((b*d-a*e)*(d+e*x))-2*b*n*log(c*(a+b*x)^n)*_
+--   log(b*(d+e*x)/(b*d-a*e))/(e*(b*d-a*e))-2*b*n^2*polylog(2,-e*(a+b*x)/_
+--   (b*d-a*e))/(e*(b*d-a*e))
+--E 1142
+
+--S 1143 of 5341
+--a0:=integrate(t0,x)
+--E 1143
+
+--S 1144 of 5341
+--m0:=a0-r0
+--E 1144
+
+--S 1145 of 5341
+--d0:=D(m0,x)
+--E 1145
+
+)clear all
+
+--S 1146 of 5341
+t0:=log(c*(a+b*x)^n)^2/(d+e*x)^3
+--R 
+--R
+--R                            n 2
+--R             log(c (b x + a) )
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 1146
+
+--S 1147 of 5341
+--r0:=-b^2*n^2*log(a+b*x)/(e*(b*d-a*e)^2)+b*n*log(c*(a+b*x)^n)/(e*(b*d-a*e)*_
+--   (d+e*x))+1/2*(a+b*x)*log(c*(a+b*x)^n)^2/((b*d-a*e)*(d+e*x)^2)+1/2*b*_
+--   (a+b*x)*log(c*(a+b*x)^n)^2/((b*d-a*e)^2*(d+e*x))+b^2*n^2*log(d+e*x)/_
+--   (e*(b*d-a*e)^2)-b^2*n*log(c*(a+b*x)^n)*log(b*(d+e*x)/(b*d-a*e))/_
+--   (e*(b*d-a*e)^2)-b^2*n^2*polylog(2,-e*(a+b*x)/(b*d-a*e))/(e*(b*d-a*e)^2)
+--E 1147
+
+--S 1148 of 5341
+--a0:=integrate(t0,x)
+--E 1148
+
+--S 1149 of 5341
+--m0:=a0-r0
+--E 1149
+
+--S 1150 of 5341
+--d0:=D(m0,x)
+--E 1150
+
+)clear all
+
+--S 1151 of 5341
+t0:=log(c*(a+b*x)^n)^2/(d+e*x)^4
+--R 
+--R
+--R                                 n 2
+--R                  log(c (b x + a) )
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 1151
+
+--S 1152 of 5341
+--r0:=-1/3*b^2*n^2/(e*(b*d-a*e)^2*(d+e*x))-b^3*n^2*log(a+b*x)/(e*(b*d-_
+--   a*e)^3)+1/3*b*n*log(c*(a+b*x)^n)/(e*(b*d-a*e)*(d+e*x)^2)+2/3*b^2*n*_
+--   log(c*(a+b*x)^n)/(e*(b*d-a*e)^2*(d+e*x))+1/3*(a+b*x)*log(c*(a+_
+--   b*x)^n)^2/((b*d-a*e)*(d+e*x)^3)+1/3*b*(a+b*x)*log(c*(a+b*x)^n)^2/_
+--   ((b*d-a*e)^2*(d+e*x)^2)+1/3*b^2*(a+b*x)*log(c*(a+b*x)^n)^2/((b*d-_
+--   a*e)^3*(d+e*x))+b^3*n^2*log(d+e*x)/(e*(b*d-a*e)^3)-2/3*b^3*n*_
+--   log(c*(a+b*x)^n)*log(b*(d+e*x)/(b*d-a*e))/(e*(b*d-a*e)^3)-_
+--   2/3*b^3*n^2*polylog(2,-e*(a+b*x)/(b*d-a*e))/(e*(b*d-a*e)^3)
+--E 1152
+
+--S 1153 of 5341
+--a0:=integrate(t0,x)
+--E 1153
+
+--S 1154 of 5341
+--m0:=a0-r0
+--E 1154
+
+--S 1155 of 5341
+--d0:=D(m0,x)
+--E 1155
+
+)clear all
+
+--S 1156 of 5341
+t0:=(d+e*x)^m*log(c*(a+b*x)^n)^3
+--R 
+--R
+--R                 m               n 3
+--R   (1)  (e x + d) log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1156
+
+--S 1157 of 5341
+--r0:=Int((d+e*x)^m*log(c*(a+b*x)^n)^3,x)
+--E 1157
+
+--S 1158 of 5341
+--a0:=integrate(t0,x)
+--E 1158
+
+--S 1159 of 5341
+--m0:=a0-r0
+--E 1159
+
+--S 1160 of 5341
+--d0:=D(m0,x)
+--E 1160
+
+)clear all
+
+--S 1161 of 5341
+t0:=(d+e*x)^3*log(c*(a+b*x)^n)^3
+--R 
+--R
+--R          3 3       2 2     2       3                n 3
+--R   (1)  (e x  + 3d e x  + 3d e x + d )log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1161
+
+--S 1162 of 5341
+r0:=-415/96*(b*d-a*e)^3*n^3*x/b^3-115/192*(b*d-a*e)^2*n^3*(d+e*x)^2/(b^2*e)-_
+   37/288*(b*d-a*e)*n^3*(d+e*x)^3/(b*e)-3/128*n^3*(d+e*x)^4/e-115/96*(b*d-_
+   a*e)^4*n^3*log(a+b*x)/(b^4*e)+25/8*(b*d-a*e)^3*n^2*(a+b*x)*log(c*(a+_
+   b*x)^n)/b^4+13/16*(b*d-a*e)^2*n^2*(d+e*x)^2*log(c*(a+b*x)^n)/(b^2*e)+_
+   7/24*(b*d-a*e)*n^2*(d+e*x)^3*log(c*(a+b*x)^n)/(b*e)+3/32*n^2*(d+e*x)^4*_
+   log(c*(a+b*x)^n)/e-25/16*(b*d-a*e)^3*n*(a+b*x)*log(c*(a+b*x)^n)^2/b^4-_
+   13/16*(b*d-a*e)^2*n*(a+b*x)*(d+e*x)*log(c*(a+b*x)^n)^2/b^3-7/16*(b*d-_
+   a*e)*n*(a+b*x)*(d+e*x)^2*log(c*(a+b*x)^n)^2/b^2-3/16*n*(a+b*x)*(d+_
+   e*x)^3*log(c*(a+b*x)^n)^2/b+1/4*(b*d-a*e)^3*(a+b*x)*log(c*(a+b*x)^n)^3/_
+   b^4+1/4*(b*d-a*e)^2*(a+b*x)*(d+e*x)*log(c*(a+b*x)^n)^3/b^3+1/4*(b*d-_
+   a*e)*(a+b*x)*(d+e*x)^2*log(c*(a+b*x)^n)^3/b^2+1/4*(a+b*x)*(d+e*x)^3*_
+   log(c*(a+b*x)^n)^3/b
+--R 
+--R
+--R   (2)
+--R               4 4 4        4   3 3        4 2 2 2        4 3          4 4
+--R           288b e x  + 1152b d e x  + 1728b d e x  + 1152b d e x - 288a e
+--R         + 
+--R                3     3        2 2 2 2          3 3
+--R           1152a b d e  - 1728a b d e  + 1152a b d e
+--R      *
+--R                        n 3
+--R         log(c (b x + a) )
+--R     + 
+--R                 4 4   4          3 4        4   3    3
+--R           - 216b e n x  + (288a b e  - 1152b d e )n x
+--R         + 
+--R                  2 2 4          3   3        4 2 2    2
+--R           (- 432a b e  + 1728a b d e  - 2592b d e )n x
+--R         + 
+--R                3   4        2 2   3          3 2 2        4 3
+--R           (864a b e  - 3456a b d e  + 5184a b d e  - 3456b d e)n x
+--R         + 
+--R                 4 4        3     3        2 2 2 2          3 3
+--R           (1800a e  - 6336a b d e  + 7776a b d e  - 3456a b d e)n
+--R      *
+--R                        n 2
+--R         log(c (b x + a) )
+--R     + 
+--R               4 4 2 4            3 4       4   3  2 3
+--R           108b e n x  + (- 336a b e  + 768b d e )n x
+--R         + 
+--R                2 2 4          3   3        4 2 2  2 2
+--R           (936a b e  - 2880a b d e  + 2592b d e )n x
+--R         + 
+--R                   3   4         2 2   3           3 2 2        4 3   2
+--R           (- 3600a b e  + 12672a b d e  - 15552a b d e  + 6912b d e)n x
+--R         + 
+--R                 4 4         3     3        2 2 2 2          3 3         4 4  2
+--R         (- 3600a e  + 10800a b d e  - 9864a b d e  + 1392a b d e + 1380b d )n
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R                 4 4        3     3        2 2 2 2          3 3         4 4  3
+--R         (- 1380a e  + 5520a b d e  - 8280a b d e  + 5520a b d e - 1380b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R            4 4 3 4          3 4       4   3  3 3
+--R       - 27b e n x  + (148a b e  - 256b d e )n x
+--R     + 
+--R              2 2 4          3   3        4 2 2  3 2
+--R       (- 690a b e  + 1824a b d e  - 1296b d e )n x
+--R     + 
+--R             3   4         2 2   3           3 2 2        4 3   3
+--R       (4980a b e  - 16320a b d e  + 18144a b d e  - 6912b d e)n x
+--R     + 
+--R              2 2 2 2          3 3        4 4  3
+--R       (- 690a b d e  + 1528a b d e - 865b d )n
+--R  /
+--R          4
+--R     1152b e
+--R                                                    Type: Expression(Integer)
+--E 1162
+
+--S 1163 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               4 3 3 4        4   2 3 3        4 2   3 2        4 3 3
+--R           288b e n x  + 1152b d e n x  + 1728b d e n x  + 1152b d n x
+--R         + 
+--R                  4 3        3     2        2 2 2           3 3  3
+--R           (- 288a e  + 1152a b d e  - 1728a b d e + 1152a b d )n
+--R      *
+--R                     3
+--R         log(b x + a)
+--R     + 
+--R                   4 3 2 4        4   2 2 3        4 2   2 2        4 3 2
+--R               864b e n x  + 3456b d e n x  + 5184b d e n x  + 3456b d n x
+--R             + 
+--R                      4 3        3     2        2 2 2           3 3  2
+--R               (- 864a e  + 3456a b d e  - 5184a b d e + 3456a b d )n
+--R          *
+--R             log(c)
+--R         + 
+--R                 4 3 3 4          3 3        4   2  3 3
+--R           - 216b e n x  + (288a b e  - 1152b d e )n x
+--R         + 
+--R                  2 2 3          3   2        4 2   3 2
+--R           (- 432a b e  + 1728a b d e  - 2592b d e)n x
+--R         + 
+--R                3   3        2 2   2          3 2         4 3  3
+--R           (864a b e  - 3456a b d e  + 5184a b d e - 3456b d )n x
+--R         + 
+--R                 4 3        3     2        2 2 2           3 3  3
+--R           (1800a e  - 6336a b d e  + 7776a b d e - 3456a b d )n
+--R      *
+--R                     2
+--R         log(b x + a)
+--R     + 
+--R                   4 3   4        4   2   3        4 2     2        4 3
+--R               864b e n x  + 3456b d e n x  + 5184b d e n x  + 3456b d n x
+--R             + 
+--R                      4 3        3     2        2 2 2           3 3
+--R               (- 864a e  + 3456a b d e  - 5184a b d e + 3456a b d )n
+--R          *
+--R                   2
+--R             log(c)
+--R         + 
+--R                     4 3 2 4          3 3        4   2  2 3
+--R               - 432b e n x  + (576a b e  - 2304b d e )n x
+--R             + 
+--R                      2 2 3          3   2        4 2   2 2
+--R               (- 864a b e  + 3456a b d e  - 5184b d e)n x
+--R             + 
+--R                     3   3        2 2   2           3 2         4 3  2
+--R               (1728a b e  - 6912a b d e  + 10368a b d e - 6912b d )n x
+--R             + 
+--R                     4 3         3     2         2 2 2           3 3  2
+--R               (3600a e  - 12672a b d e  + 15552a b d e - 6912a b d )n
+--R          *
+--R             log(c)
+--R         + 
+--R               4 3 3 4            3 3       4   2  3 3
+--R           108b e n x  + (- 336a b e  + 768b d e )n x
+--R         + 
+--R                2 2 3          3   2        4 2   3 2
+--R           (936a b e  - 2880a b d e  + 2592b d e)n x
+--R         + 
+--R                   3   3         2 2   2           3 2         4 3  3
+--R           (- 3600a b e  + 12672a b d e  - 15552a b d e + 6912b d )n x
+--R         + 
+--R                   4 3         3     2         2 2 2           3 3  3
+--R           (- 4980a e  + 16320a b d e  - 18144a b d e + 6912a b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R            4 3 4        4   2 3        4 2   2        4 3        3
+--R       (288b e x  + 1152b d e x  + 1728b d e x  + 1152b d x)log(c)
+--R     + 
+--R                 4 3   4          3 3        4   2    3
+--R           - 216b e n x  + (288a b e  - 1152b d e )n x
+--R         + 
+--R                  2 2 3          3   2        4 2     2
+--R           (- 432a b e  + 1728a b d e  - 2592b d e)n x
+--R         + 
+--R                3   3        2 2   2          3 2         4 3
+--R           (864a b e  - 3456a b d e  + 5184a b d e - 3456b d )n x
+--R      *
+--R               2
+--R         log(c)
+--R     + 
+--R               4 3 2 4            3 3       4   2  2 3
+--R           108b e n x  + (- 336a b e  + 768b d e )n x
+--R         + 
+--R                2 2 3          3   2        4 2   2 2
+--R           (936a b e  - 2880a b d e  + 2592b d e)n x
+--R         + 
+--R                   3   3         2 2   2           3 2         4 3  2
+--R           (- 3600a b e  + 12672a b d e  - 15552a b d e + 6912b d )n x
+--R      *
+--R         log(c)
+--R     + 
+--R            4 3 3 4          3 3       4   2  3 3
+--R       - 27b e n x  + (148a b e  - 256b d e )n x
+--R     + 
+--R              2 2 3          3   2        4 2   3 2
+--R       (- 690a b e  + 1824a b d e  - 1296b d e)n x
+--R     + 
+--R             3   3         2 2   2           3 2         4 3  3
+--R       (4980a b e  - 16320a b d e  + 18144a b d e - 6912b d )n x
+--R  /
+--R          4
+--R     1152b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1163
+
+--S 1164 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 4 4 4        4   3 3        4 2 2 2        4 3          4 4
+--R           - 288b e x  - 1152b d e x  - 1728b d e x  - 1152b d e x + 288a e
+--R         + 
+--R                  3     3        2 2 2 2          3 3
+--R           - 1152a b d e  + 1728a b d e  - 1152a b d e
+--R      *
+--R                        n 3
+--R         log(c (b x + a) )
+--R     + 
+--R               4 4   4            3 4        4   3    3
+--R           216b e n x  + (- 288a b e  + 1152b d e )n x
+--R         + 
+--R                2 2 4          3   3        4 2 2    2
+--R           (432a b e  - 1728a b d e  + 2592b d e )n x
+--R         + 
+--R                  3   4        2 2   3          3 2 2        4 3
+--R           (- 864a b e  + 3456a b d e  - 5184a b d e  + 3456b d e)n x
+--R         + 
+--R                   4 4        3     3        2 2 2 2          3 3
+--R           (- 1800a e  + 6336a b d e  - 7776a b d e  + 3456a b d e)n
+--R      *
+--R                        n 2
+--R         log(c (b x + a) )
+--R     + 
+--R                 4 4 2 4          3 4       4   3  2 3
+--R           - 108b e n x  + (336a b e  - 768b d e )n x
+--R         + 
+--R                  2 2 4          3   3        4 2 2  2 2
+--R           (- 936a b e  + 2880a b d e  - 2592b d e )n x
+--R         + 
+--R                 3   4         2 2   3           3 2 2        4 3   2
+--R           (3600a b e  - 12672a b d e  + 15552a b d e  - 6912b d e)n x
+--R         + 
+--R                 4 4         3     3        2 2 2 2          3 3         4 4  2
+--R           (3600a e  - 10800a b d e  + 9864a b d e  - 1392a b d e - 1380b d )n
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R               4 4 3 4        4   3 3 3        4 2 2 3 2        4 3   3
+--R           288b e n x  + 1152b d e n x  + 1728b d e n x  + 1152b d e n x
+--R         + 
+--R                  4 4        3     3        2 2 2 2          3 3   3
+--R           (- 288a e  + 1152a b d e  - 1728a b d e  + 1152a b d e)n
+--R      *
+--R                     3
+--R         log(b x + a)
+--R     + 
+--R                   4 4 2 4        4   3 2 3        4 2 2 2 2        4 3   2
+--R               864b e n x  + 3456b d e n x  + 5184b d e n x  + 3456b d e n x
+--R             + 
+--R                      4 4        3     3        2 2 2 2          3 3   2
+--R               (- 864a e  + 3456a b d e  - 5184a b d e  + 3456a b d e)n
+--R          *
+--R             log(c)
+--R         + 
+--R                 4 4 3 4          3 4        4   3  3 3
+--R           - 216b e n x  + (288a b e  - 1152b d e )n x
+--R         + 
+--R                  2 2 4          3   3        4 2 2  3 2
+--R           (- 432a b e  + 1728a b d e  - 2592b d e )n x
+--R         + 
+--R                3   4        2 2   3          3 2 2        4 3   3
+--R           (864a b e  - 3456a b d e  + 5184a b d e  - 3456b d e)n x
+--R         + 
+--R                 4 4        3     3        2 2 2 2          3 3   3
+--R           (1800a e  - 6336a b d e  + 7776a b d e  - 3456a b d e)n
+--R      *
+--R                     2
+--R         log(b x + a)
+--R     + 
+--R                   4 4   4        4   3   3        4 2 2   2        4 3
+--R               864b e n x  + 3456b d e n x  + 5184b d e n x  + 3456b d e n x
+--R             + 
+--R                      4 4        3     3        2 2 2 2          3 3
+--R               (- 864a e  + 3456a b d e  - 5184a b d e  + 3456a b d e)n
+--R          *
+--R                   2
+--R             log(c)
+--R         + 
+--R                     4 4 2 4          3 4        4   3  2 3
+--R               - 432b e n x  + (576a b e  - 2304b d e )n x
+--R             + 
+--R                      2 2 4          3   3        4 2 2  2 2
+--R               (- 864a b e  + 3456a b d e  - 5184b d e )n x
+--R             + 
+--R                     3   4        2 2   3           3 2 2        4 3   2
+--R               (1728a b e  - 6912a b d e  + 10368a b d e  - 6912b d e)n x
+--R             + 
+--R                     4 4         3     3         2 2 2 2          3 3   2
+--R               (3600a e  - 12672a b d e  + 15552a b d e  - 6912a b d e)n
+--R          *
+--R             log(c)
+--R         + 
+--R               4 4 3 4            3 4       4   3  3 3
+--R           108b e n x  + (- 336a b e  + 768b d e )n x
+--R         + 
+--R                2 2 4          3   3        4 2 2  3 2
+--R           (936a b e  - 2880a b d e  + 2592b d e )n x
+--R         + 
+--R                   3   4         2 2   3           3 2 2        4 3   3
+--R           (- 3600a b e  + 12672a b d e  - 15552a b d e  + 6912b d e)n x
+--R         + 
+--R                 4 4         3     3        2 2 2 2          3 3         4 4  3
+--R         (- 3600a e  + 10800a b d e  - 9864a b d e  + 1392a b d e + 1380b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R            4 4 4        4   3 3        4 2 2 2        4 3          3
+--R       (288b e x  + 1152b d e x  + 1728b d e x  + 1152b d e x)log(c)
+--R     + 
+--R                 4 4   4          3 4        4   3    3
+--R           - 216b e n x  + (288a b e  - 1152b d e )n x
+--R         + 
+--R                  2 2 4          3   3        4 2 2    2
+--R           (- 432a b e  + 1728a b d e  - 2592b d e )n x
+--R         + 
+--R                3   4        2 2   3          3 2 2        4 3
+--R           (864a b e  - 3456a b d e  + 5184a b d e  - 3456b d e)n x
+--R      *
+--R               2
+--R         log(c)
+--R     + 
+--R               4 4 2 4            3 4       4   3  2 3
+--R           108b e n x  + (- 336a b e  + 768b d e )n x
+--R         + 
+--R                2 2 4          3   3        4 2 2  2 2
+--R           (936a b e  - 2880a b d e  + 2592b d e )n x
+--R         + 
+--R                   3   4         2 2   3           3 2 2        4 3   2
+--R           (- 3600a b e  + 12672a b d e  - 15552a b d e  + 6912b d e)n x
+--R      *
+--R         log(c)
+--R     + 
+--R            2 2 2 2          3 3        4 4  3
+--R       (690a b d e  - 1528a b d e + 865b d )n
+--R  /
+--R          4
+--R     1152b e
+--R                                                    Type: Expression(Integer)
+--E 1164
+
+--S 1165 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1165
+
+)clear all
+
+--S 1166 of 5341
+t0:=(d+e*x)^2*log(c*(a+b*x)^n)^3
+--R 
+--R
+--R          2 2             2                n 3
+--R   (1)  (e x  + 2d e x + d )log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1166
+
+--S 1167 of 5341
+r0:=-85/18*(b*d-a*e)^2*n^3*x/b^2-19/36*(b*d-a*e)*n^3*(d+e*x)^2/(b*e)-_
+   2/27*n^3*(d+e*x)^3/e-19/18*(b*d-a*e)^3*n^3*log(a+b*x)/(b^3*e)+_
+   11/3*(b*d-a*e)^2*n^2*(a+b*x)*log(c*(a+b*x)^n)/b^3+5/6*(b*d-a*e)*n^2*_
+   (d+e*x)^2*log(c*(a+b*x)^n)/(b*e)+2/9*n^2*(d+e*x)^3*log(c*(a+b*x)^n)/e-_
+   11/6*(b*d-a*e)^2*n*(a+b*x)*log(c*(a+b*x)^n)^2/b^3-5/6*(b*d-a*e)*n*_
+   (a+b*x)*(d+e*x)*log(c*(a+b*x)^n)^2/b^2-1/3*n*(a+b*x)*(d+e*x)^2*log(c*_
+   (a+b*x)^n)^2/b+1/3*(b*d-a*e)^2*(a+b*x)*log(c*(a+b*x)^n)^3/b^3+1/3*(b*d-_
+   a*e)*(a+b*x)*(d+e*x)*log(c*(a+b*x)^n)^3/b^2+1/3*(a+b*x)*(d+e*x)^2*_
+   log(c*(a+b*x)^n)^3/b
+--R 
+--R
+--R   (2)
+--R                3 3 3       3   2 2       3 2         3 3       2     2
+--R             36b e x  + 108b d e x  + 108b d e x + 36a e  - 108a b d e
+--R           + 
+--R                   2 2
+--R             108a b d e
+--R      *
+--R                        n 3
+--R         log(c (b x + a) )
+--R     + 
+--R                3 3   3         2 3       3   2    2
+--R           - 36b e n x  + (54a b e  - 162b d e )n x
+--R         + 
+--R                  2   3         2   2       3 2
+--R           (- 108a b e  + 324a b d e  - 324b d e)n x
+--R         + 
+--R                  3 3       2     2         2 2
+--R           (- 198a e  + 486a b d e  - 324a b d e)n
+--R      *
+--R                        n 2
+--R         log(c (b x + a) )
+--R     + 
+--R              3 3 2 3           2 3       3   2  2 2
+--R           24b e n x  + (- 90a b e  + 162b d e )n x
+--R         + 
+--R                2   3         2   2       3 2   2
+--R           (396a b e  - 972a b d e  + 648b d e)n x
+--R         + 
+--R                3 3       2     2         2 2        3 3  2
+--R           (396a e  - 792a b d e  + 306a b d e + 114b d )n
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R            3 3       2     2         2 2        3 3  3                 3 3 3 3
+--R       (114a e  - 342a b d e  + 342a b d e - 114b d )n log(b x + a) - 8b e n x
+--R     + 
+--R             2 3      3   2  3 2          2   3          2   2       3 2   3
+--R       (57a b e  - 81b d e )n x  + (- 510a b e  + 1134a b d e  - 648b d e)n x
+--R     + 
+--R             2 2       3 3  3
+--R       (57a b d e - 65b d )n
+--R  /
+--R         3
+--R     108b e
+--R                                                    Type: Expression(Integer)
+--E 1167
+
+--S 1168 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 2 3 3       3     3 2       3 2 3
+--R           36b e n x  + 108b d e n x  + 108b d n x
+--R         + 
+--R               3 2       2              2 2  3
+--R           (36a e  - 108a b d e + 108a b d )n
+--R      *
+--R                     3
+--R         log(b x + a)
+--R     + 
+--R                   3 2 2 3       3     2 2       3 2 2
+--R               108b e n x  + 324b d e n x  + 324b d n x
+--R             + 
+--R                    3 2       2              2 2  2
+--R               (108a e  - 324a b d e + 324a b d )n
+--R          *
+--R             log(c)
+--R         + 
+--R                3 2 3 3         2 2       3     3 2
+--R           - 36b e n x  + (54a b e  - 162b d e)n x
+--R         + 
+--R                  2   2         2          3 2  3
+--R           (- 108a b e  + 324a b d e - 324b d )n x
+--R         + 
+--R                  3 2       2              2 2  3
+--R           (- 198a e  + 486a b d e - 324a b d )n
+--R      *
+--R                     2
+--R         log(b x + a)
+--R     + 
+--R                   3 2   3       3       2       3 2
+--R               108b e n x  + 324b d e n x  + 324b d n x
+--R             + 
+--R                    3 2       2              2 2
+--R               (108a e  - 324a b d e + 324a b d )n
+--R          *
+--R                   2
+--R             log(c)
+--R         + 
+--R                    3 2 2 3          2 2       3     2 2
+--R               - 72b e n x  + (108a b e  - 324b d e)n x
+--R             + 
+--R                      2   2         2          3 2  2
+--R               (- 216a b e  + 648a b d e - 648b d )n x
+--R             + 
+--R                      3 2       2              2 2  2
+--R               (- 396a e  + 972a b d e - 648a b d )n
+--R          *
+--R             log(c)
+--R         + 
+--R              3 2 3 3           2 2       3     3 2
+--R           24b e n x  + (- 90a b e  + 162b d e)n x
+--R         + 
+--R                2   2         2          3 2  3
+--R           (396a b e  - 972a b d e + 648b d )n x
+--R         + 
+--R                3 2        2              2 2  3
+--R           (510a e  - 1134a b d e + 648a b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           3 2 3       3     2       3 2        3
+--R       (36b e x  + 108b d e x  + 108b d x)log(c)
+--R     + 
+--R                3 2   3         2 2       3       2
+--R           - 36b e n x  + (54a b e  - 162b d e)n x
+--R         + 
+--R                  2   2         2          3 2
+--R           (- 108a b e  + 324a b d e - 324b d )n x
+--R      *
+--R               2
+--R         log(c)
+--R     + 
+--R              3 2 2 3           2 2       3     2 2
+--R           24b e n x  + (- 90a b e  + 162b d e)n x
+--R         + 
+--R                2   2         2          3 2  2
+--R           (396a b e  - 972a b d e + 648b d )n x
+--R      *
+--R         log(c)
+--R     + 
+--R           3 2 3 3         2 2      3     3 2
+--R       - 8b e n x  + (57a b e  - 81b d e)n x
+--R     + 
+--R              2   2          2          3 2  3
+--R       (- 510a b e  + 1134a b d e - 648b d )n x
+--R  /
+--R         3
+--R     108b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1168
+
+--S 1169 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                3 3 3       3   2 2       3 2         3 3       2     2
+--R           - 36b e x  - 108b d e x  - 108b d e x - 36a e  + 108a b d e
+--R         + 
+--R                   2 2
+--R           - 108a b d e
+--R      *
+--R                        n 3
+--R         log(c (b x + a) )
+--R     + 
+--R              3 3   3           2 3       3   2    2
+--R           36b e n x  + (- 54a b e  + 162b d e )n x
+--R         + 
+--R                2   3         2   2       3 2
+--R           (108a b e  - 324a b d e  + 324b d e)n x
+--R         + 
+--R                3 3       2     2         2 2
+--R           (198a e  - 486a b d e  + 324a b d e)n
+--R      *
+--R                        n 2
+--R         log(c (b x + a) )
+--R     + 
+--R                3 3 2 3         2 3       3   2  2 2
+--R           - 24b e n x  + (90a b e  - 162b d e )n x
+--R         + 
+--R                  2   3         2   2       3 2   2
+--R           (- 396a b e  + 972a b d e  - 648b d e)n x
+--R         + 
+--R                  3 3       2     2         2 2        3 3  2
+--R           (- 396a e  + 792a b d e  - 306a b d e - 114b d )n
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R              3 3 3 3       3   2 3 2       3 2   3
+--R           36b e n x  + 108b d e n x  + 108b d e n x
+--R         + 
+--R               3 3       2     2         2 2   3
+--R           (36a e  - 108a b d e  + 108a b d e)n
+--R      *
+--R                     3
+--R         log(b x + a)
+--R     + 
+--R                   3 3 2 3       3   2 2 2       3 2   2
+--R               108b e n x  + 324b d e n x  + 324b d e n x
+--R             + 
+--R                    3 3       2     2         2 2   2
+--R               (108a e  - 324a b d e  + 324a b d e)n
+--R          *
+--R             log(c)
+--R         + 
+--R                3 3 3 3         2 3       3   2  3 2
+--R           - 36b e n x  + (54a b e  - 162b d e )n x
+--R         + 
+--R                  2   3         2   2       3 2   3
+--R           (- 108a b e  + 324a b d e  - 324b d e)n x
+--R         + 
+--R                  3 3       2     2         2 2   3
+--R           (- 198a e  + 486a b d e  - 324a b d e)n
+--R      *
+--R                     2
+--R         log(b x + a)
+--R     + 
+--R                   3 3   3       3   2   2       3 2
+--R               108b e n x  + 324b d e n x  + 324b d e n x
+--R             + 
+--R                    3 3       2     2         2 2
+--R               (108a e  - 324a b d e  + 324a b d e)n
+--R          *
+--R                   2
+--R             log(c)
+--R         + 
+--R                    3 3 2 3          2 3       3   2  2 2
+--R               - 72b e n x  + (108a b e  - 324b d e )n x
+--R             + 
+--R                      2   3         2   2       3 2   2
+--R               (- 216a b e  + 648a b d e  - 648b d e)n x
+--R             + 
+--R                      3 3       2     2         2 2   2
+--R               (- 396a e  + 972a b d e  - 648a b d e)n
+--R          *
+--R             log(c)
+--R         + 
+--R              3 3 3 3           2 3       3   2  3 2
+--R           24b e n x  + (- 90a b e  + 162b d e )n x
+--R         + 
+--R                2   3         2   2       3 2   3
+--R           (396a b e  - 972a b d e  + 648b d e)n x
+--R         + 
+--R                3 3       2     2         2 2        3 3  3
+--R           (396a e  - 792a b d e  + 306a b d e + 114b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           3 3 3       3   2 2       3 2          3
+--R       (36b e x  + 108b d e x  + 108b d e x)log(c)
+--R     + 
+--R                3 3   3         2 3       3   2    2
+--R           - 36b e n x  + (54a b e  - 162b d e )n x
+--R         + 
+--R                  2   3         2   2       3 2
+--R           (- 108a b e  + 324a b d e  - 324b d e)n x
+--R      *
+--R               2
+--R         log(c)
+--R     + 
+--R              3 3 2 3           2 3       3   2  2 2
+--R           24b e n x  + (- 90a b e  + 162b d e )n x
+--R         + 
+--R                2   3         2   2       3 2   2
+--R           (396a b e  - 972a b d e  + 648b d e)n x
+--R      *
+--R         log(c)
+--R     + 
+--R               2 2       3 3  3
+--R       (- 57a b d e + 65b d )n
+--R  /
+--R         3
+--R     108b e
+--R                                                    Type: Expression(Integer)
+--E 1169
+
+--S 1170 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1170
+
+)clear all
+
+--S 1171 of 5341
+t0:=(d+e*x)*log(c*(a+b*x)^n)^3
+--R 
+--R
+--R                                n 3
+--R   (1)  (e x + d)log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1171
+
+--S 1172 of 5341
+r0:=-21/4*(b*d-a*e)*n^3*x/b-3/8*n^3*(d+e*x)^2/e-3/4*(b*d-a*e)^2*n^3*_
+   log(a+b*x)/(b^2*e)+9/2*(b*d-a*e)*n^2*(a+b*x)*log(c*(a+b*x)^n)/b^2+_
+   3/4*n^2*(d+e*x)^2*log(c*(a+b*x)^n)/e-9/4*(b*d-a*e)*n*(a+b*x)*_
+   log(c*(a+b*x)^n)^2/b^2-3/4*n*(a+b*x)*(d+e*x)*log(c*(a+b*x)^n)^2/b+_
+   1/2*(b*d-a*e)*(a+b*x)*log(c*(a+b*x)^n)^3/b^2+1/2*(a+b*x)*(d+e*x)*_
+   log(c*(a+b*x)^n)^3/b
+--R 
+--R
+--R   (2)
+--R          2 2 2     2          2 2                           n 3
+--R       (4b e x  + 8b d e x - 4a e  + 8a b d e)log(c (b x + a) )
+--R     + 
+--R              2 2   2           2      2              2 2
+--R         (- 6b e n x  + (12a b e  - 24b d e)n x + (18a e  - 24a b d e)n)
+--R      *
+--R                        n 2
+--R         log(c (b x + a) )
+--R     + 
+--R             2 2 2 2             2      2     2
+--R           6b e n x  + (- 36a b e  + 48b d e)n x
+--R         + 
+--R                 2 2                 2 2  2
+--R           (- 36a e  + 36a b d e + 6b d )n
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R            2 2                 2 2  3                 2 2 3 2
+--R       (- 6a e  + 12a b d e - 6b d )n log(b x + a) - 3b e n x
+--R     + 
+--R               2      2     3      2 2 3
+--R       (42a b e  - 48b d e)n x - 3b d n
+--R  /
+--R       2
+--R     8b e
+--R                                                    Type: Expression(Integer)
+--E 1172
+
+--S 1173 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2   3 2     2   3         2            3             3
+--R       (4b e n x  + 8b d n x + (- 4a e + 8a b d)n )log(b x + a)
+--R     + 
+--R               2   2 2      2   2          2             2            2   3 2
+--R           (12b e n x  + 24b d n x + (- 12a e + 24a b d)n )log(c) - 6b e n x
+--R         + 
+--R                         2   3        2             3
+--R           (12a b e - 24b d)n x + (18a e - 24a b d)n
+--R      *
+--R                     2
+--R         log(b x + a)
+--R     + 
+--R               2     2      2              2                    2
+--R           (12b e n x  + 24b d n x + (- 12a e + 24a b d)n)log(c)
+--R         + 
+--R                 2   2 2                 2   2        2             2
+--R           (- 12b e n x  + (24a b e - 48b d)n x + (36a e - 48a b d)n )log(c)
+--R         + 
+--R             2   3 2                   2   3          2             3
+--R           6b e n x  + (- 36a b e + 48b d)n x + (- 42a e + 48a b d)n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R          2   2     2          3        2     2                 2            2
+--R       (4b e x  + 8b d x)log(c)  + (- 6b e n x  + (12a b e - 24b d)n x)log(c)
+--R     + 
+--R          2   2 2                   2   2             2   3 2
+--R       (6b e n x  + (- 36a b e + 48b d)n x)log(c) - 3b e n x
+--R     + 
+--R                     2   3
+--R       (42a b e - 48b d)n x
+--R  /
+--R       2
+--R     8b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1173
+
+--S 1174 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            2 2 2     2          2 2                           n 3
+--R       (- 4b e x  - 8b d e x + 4a e  - 8a b d e)log(c (b x + a) )
+--R     + 
+--R            2 2   2             2      2                2 2
+--R         (6b e n x  + (- 12a b e  + 24b d e)n x + (- 18a e  + 24a b d e)n)
+--R      *
+--R                        n 2
+--R         log(c (b x + a) )
+--R     + 
+--R                 2 2 2 2           2      2     2
+--R             - 6b e n x  + (36a b e  - 48b d e)n x
+--R           + 
+--R                 2 2                 2 2  2
+--R             (36a e  - 36a b d e - 6b d )n
+--R      *
+--R                        n
+--R         log(c (b x + a) )
+--R     + 
+--R          2 2 3 2     2     3         2 2             3             3
+--R       (4b e n x  + 8b d e n x + (- 4a e  + 8a b d e)n )log(b x + a)
+--R     + 
+--R               2 2 2 2      2     2          2 2              2
+--R           (12b e n x  + 24b d e n x + (- 12a e  + 24a b d e)n )log(c)
+--R         + 
+--R               2 2 3 2           2      2     3        2 2              3
+--R           - 6b e n x  + (12a b e  - 24b d e)n x + (18a e  - 24a b d e)n
+--R      *
+--R                     2
+--R         log(b x + a)
+--R     + 
+--R               2 2   2      2                2 2                     2
+--R           (12b e n x  + 24b d e n x + (- 12a e  + 24a b d e)n)log(c)
+--R         + 
+--R                   2 2 2 2           2      2     2        2 2              2
+--R             (- 12b e n x  + (24a b e  - 48b d e)n x + (36a e  - 48a b d e)n )
+--R          *
+--R             log(c)
+--R         + 
+--R             2 2 3 2             2      2     3
+--R           6b e n x  + (- 36a b e  + 48b d e)n x
+--R         + 
+--R                 2 2                 2 2  3
+--R           (- 36a e  + 36a b d e + 6b d )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R          2 2 2     2            3
+--R       (4b e x  + 8b d e x)log(c)
+--R     + 
+--R            2 2   2           2      2              2
+--R       (- 6b e n x  + (12a b e  - 24b d e)n x)log(c)
+--R     + 
+--R          2 2 2 2             2      2     2             2 2 3
+--R       (6b e n x  + (- 36a b e  + 48b d e)n x)log(c) + 3b d n
+--R  /
+--R       2
+--R     8b e
+--R                                                    Type: Expression(Integer)
+--E 1174
+
+--S 1175 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1175
+
+)clear all
+
+--S 1176 of 5341
+t0:=log(c*(a+b*x)^n)^3
+--R 
+--R
+--R                       n 3
+--R   (1)  log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1176
+
+--S 1177 of 5341
+r0:=-6*n^3*x+6*n^2*(a+b*x)*log(c*(a+b*x)^n)/b-3*n*(a+b*x)*log(c*(a+_
+   b*x)^n)^2/b+(a+b*x)*log(c*(a+b*x)^n)^3/b
+--R 
+--R
+--R   (2)
+--R                               n 3                                   n 2
+--R       (b x + a)log(c (b x + a) )  + (- 3b n x - 3a n)log(c (b x + a) )
+--R     + 
+--R            2        2                n        3
+--R       (6b n x + 6a n )log(c (b x + a) ) - 6b n x
+--R  /
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 1177
+
+--S 1178 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3       3             3
+--R       (b n x + a n )log(b x + a)
+--R     + 
+--R             2        2              3        3             2
+--R       ((3b n x + 3a n )log(c) - 3b n x - 3a n )log(b x + a)
+--R     + 
+--R                               2          2        2              3        3
+--R         ((3b n x + 3a n)log(c)  + (- 6b n x - 6a n )log(c) + 6b n x + 6a n )
+--R      *
+--R         log(b x + a)
+--R     + 
+--R                 3                2       2               3
+--R       b x log(c)  - 3b n x log(c)  + 6b n x log(c) - 6b n x
+--R  /
+--R     b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1178
+
+--S 1179 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                 n 3                                 n 2
+--R       (- b x - a)log(c (b x + a) )  + (3b n x + 3a n)log(c (b x + a) )
+--R     + 
+--R              2        2                n        3       3             3
+--R       (- 6b n x - 6a n )log(c (b x + a) ) + (b n x + a n )log(b x + a)
+--R     + 
+--R             2        2              3        3             2
+--R       ((3b n x + 3a n )log(c) - 3b n x - 3a n )log(b x + a)
+--R     + 
+--R                               2          2        2              3        3
+--R         ((3b n x + 3a n)log(c)  + (- 6b n x - 6a n )log(c) + 6b n x + 6a n )
+--R      *
+--R         log(b x + a)
+--R     + 
+--R                 3                2       2
+--R       b x log(c)  - 3b n x log(c)  + 6b n x log(c)
+--R  /
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 1179
+
+--S 1180 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1180
+
+)clear all
+
+--S 1181 of 5341
+t0:=log(c*(a+b*x)^n)^3/(d+e*x)
+--R 
+--R
+--R                       n 3
+--R        log(c (b x + a) )
+--R   (1)  ------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 1181
+
+--S 1182 of 5341
+--r0:=log(c*(a+b*x)^n)^3*log(b*(d+e*x)/(b*d-a*e))/e+3*n*log(c*(a+b*x)^n)^2*_
+--   polylog(2,-e*(a+b*x)/(b*d-a*e))/e-6*n^2*log(c*(a+b*x)^n)*_
+--   polylog(3,-e*(a+b*x)/(b*d-a*e))/e+6*n^3*polylog(4,-e*(a+b*x)/(b*d-a*e))/e
+--E 1182
+
+--S 1183 of 5341
+--a0:=integrate(t0,x)
+--E 1183
+
+--S 1184 of 5341
+--m0:=a0-r0
+--E 1184
+
+--S 1185 of 5341
+--d0:=D(m0,x)
+--E 1185
+
+)clear all
+
+--S 1186 of 5341
+t0:=log(c*(a+b*x)^n)^3/(d+e*x)^2
+--R 
+--R
+--R                       n 3
+--R        log(c (b x + a) )
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 1186
+
+--S 1187 of 5341
+--r0:=(a+b*x)*log(c*(a+b*x)^n)^3/((b*d-a*e)*(d+e*x))-3*b*n*log(c*(a+_
+--   b*x)^n)^2*log(b*(d+e*x)/(b*d-a*e))/(e*(b*d-a*e))-6*b*n^2*log(c*(a+_
+--   b*x)^n)*polylog(2,-e*(a+b*x)/(b*d-a*e))/(e*(b*d-a*e))+6*b*n^3*_
+--   polylog(3,-e*(a+b*x)/(b*d-a*e))/(e*(b*d-a*e))
+--E 1187
+
+--S 1188 of 5341
+--a0:=integrate(t0,x)
+--E 1188
+
+--S 1189 of 5341
+--m0:=a0-r0
+--E 1189
+
+--S 1190 of 5341
+--d0:=D(m0,x)
+--E 1190
+
+)clear all
+
+--S 1191 of 5341
+t0:=log(c*(a+b*x)^n)^3/(d+e*x)^3
+--R 
+--R
+--R                            n 3
+--R             log(c (b x + a) )
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 1191
+
+--S 1192 of 5341
+--r0:=-3/2*b*n*(a+b*x)*log(c*(a+b*x)^n)^2/((b*d-a*e)^2*(d+e*x))+_
+--   1/2*(a+b*x)*log(c*(a+b*x)^n)^3/((b*d-a*e)*(d+e*x)^2)+1/2*b*(a+b*x)*_
+--   log(c*(a+b*x)^n)^3/((b*d-a*e)^2*(d+e*x))+3*b^2*n^2*log(c*(a+b*x)^n)*_
+--   log(b*(d+e*x)/(b*d-a*e))/(e*(b*d-a*e)^2)-3/2*b^2*n*log(c*(a+b*x)^n)^2*_
+--   log(b*(d+e*x)/(b*d-a*e))/(e*(b*d-a*e)^2)+3*b^2*n^3*_
+--   polylog(2,-e*(a+b*x)/(b*d-a*e))/(e*(b*d-a*e)^2)-3*b^2*n^2*_
+--   log(c*(a+b*x)^n)*polylog(2,-e*(a+b*x)/(b*d-a*e))/(e*(b*d-a*e)^2)+_
+--   3*b^2*n^3*polylog(3,-e*(a+b*x)/(b*d-a*e))/(e*(b*d-a*e)^2)
+--E 1192
+
+--S 1193 of 5341
+--a0:=integrate(t0,x)
+--E 1193
+
+--S 1194 of 5341
+--m0:=a0-r0
+--E 1194
+
+--S 1195 of 5341
+--d0:=D(m0,x)
+--E 1195
+
+)clear all
+
+--S 1196 of 5341
+t0:=log(c*(a+b*x)^n)^3/(d+e*x)^4
+--R 
+--R
+--R                                 n 3
+--R                  log(c (b x + a) )
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 1196
+
+--S 1197 of 5341
+--r0:=b^3*n^3*log(a+b*x)/(e*(b*d-a*e)^3)-b^2*n^2*log(c*(a+b*x)^n)/_
+--   (e*(b*d-a*e)^2*(d+e*x))-1/2*b*n*(a+b*x)*log(c*(a+b*x)^n)^2/((b*d-_
+--   a*e)^2*(d+e*x)^2)-3/2*b^2*n*(a+b*x)*log(c*(a+b*x)^n)^2/((b*d-a*e)^3*_
+--   (d+e*x))+1/3*(a+b*x)*log(c*(a+b*x)^n)^3/((b*d-a*e)*(d+e*x)^3)+_
+--   1/3*b*(a+b*x)*log(c*(a+b*x)^n)^3/((b*d-a*e)^2*(d+e*x)^2)+_
+--   1/3*b^2*(a+b*x)*log(c*(a+b*x)^n)^3/((b*d-a*e)^3*(d+e*x))-b^3*n^3*_
+--   log(d+e*x)/(e*(b*d-a*e)^3)+3*b^3*n^2*log(c*(a+b*x)^n)*log(b*(d+e*x)/_
+--   (b*d-a*e))/(e*(b*d-a*e)^3)-b^3*n*log(c*(a+b*x)^n)^2*log(b*(d+e*x)/_
+--   (b*d-a*e))/(e*(b*d-a*e)^3)+3*b^3*n^3*polylog(2,-e*(a+b*x)/_
+--   (b*d-a*e))/(e*(b*d-a*e)^3)-2*b^3*n^2*log(c*(a+b*x)^n)*_
+--   polylog(2,-e*(a+b*x)/(b*d-a*e))/(e*(b*d-a*e)^3)+2*b^3*n^3*_
+--   polylog(3,-e*(a+b*x)/(b*d-a*e))/(e*(b*d-a*e)^3)
+--E 1197
+
+--S 1198 of 5341
+--a0:=integrate(t0,x)
+--E 1198
+
+--S 1199 of 5341
+--m0:=a0-r0
+--E 1199
+
+--S 1200 of 5341
+--d0:=D(m0,x)
+--E 1200
+
+)clear all
+
+--S 1201 of 5341
+t0:=log(c*(d+e*x))/(f+g*x)
+--R 
+--R
+--R        log(c e x + c d)
+--R   (1)  ----------------
+--R             g x + f
+--R                                                    Type: Expression(Integer)
+--E 1201
+
+--S 1202 of 5341
+--r0:=log(c*(d+e*x))*log(e*(f+g*x)/(e*f-d*g))/g+polylog(2,-g*(d+e*x)/_
+--   (e*f-d*g))/g
+--E 1202
+
+--S 1203 of 5341
+--a0:=integrate(t0,x)
+--E 1203
+
+--S 1204 of 5341
+--m0:=a0-r0
+--E 1204
+
+--S 1205 of 5341
+--d0:=D(m0,x)
+--E 1205
+
+)clear all
+
+--S 1206 of 5341
+t0:=log(-g*(d+e*x)/(e*f-d*g))/(f+g*x)
+--R 
+--R
+--R            e g x + d g
+--R        log(-----------)
+--R             d g - e f
+--R   (1)  ----------------
+--R             g x + f
+--R                                                    Type: Expression(Integer)
+--E 1206
+
+--S 1207 of 5341
+--r0:=-polylog(2,e*(f+g*x)/(e*f-d*g))/g
+--E 1207
+
+--S 1208 of 5341
+--a0:=integrate(t0,x)
+--E 1208
+
+--S 1209 of 5341
+--m0:=a0-r0
+--E 1209
+
+--S 1210 of 5341
+--d0:=D(m0,x)
+--E 1210
+
+)clear all
+
+--S 1211 of 5341
+t0:=log(1+b*x)/x
+--R 
+--R
+--R        log(b x + 1)
+--R   (1)  ------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 1211
+
+--S 1212 of 5341
+--r0:=-polylog(2,-b*x)
+--E 1212
+
+--S 1213 of 5341
+--a0:=integrate(t0,x)
+--E 1213
+
+--S 1214 of 5341
+--m0:=a0-r0
+--E 1214
+
+--S 1215 of 5341
+--d0:=D(m0,x)
+--E 1215
+
+)clear all
+
+--S 1216 of 5341
+t0:=(d+e*x)^m/log(c*(a+b*x)^n)
+--R 
+--R
+--R                     m
+--R            (e x + d)
+--R   (1)  -----------------
+--R                       n
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1216
+
+--S 1217 of 5341
+--r0:=Int((d+e*x)^m/log(c*(a+b*x)^n),x)
+--E 1217
+
+--S 1218 of 5341
+--a0:=integrate(t0,x)
+--E 1218
+
+--S 1219 of 5341
+--m0:=a0-r0
+--E 1219
+
+--S 1220 of 5341
+--d0:=D(m0,x)
+--E 1220
+
+)clear all
+
+--S 1221 of 5341
+t0:=(d+e*x)^4/log(c*(a+b*x)^n)
+--R 
+--R
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R   (1)  --------------------------------------
+--R                                  n
+--R                   log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1221
+
+--S 1222 of 5341
+--r0:=(b*d-a*e)^4*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^5*n*(c*(a+_
+--   b*x)^n)^(1/n))+4*e*(b*d-a*e)^3*(a+b*x)^2*Ei(2*log(c*(a+b*x)^n)/n)/_
+--   (b^5*n*(c*(a+b*x)^n)^(2/n))+6*e^2*(b*d-a*e)^2*(a+b*x)^3*Ei(3*_
+--   log(c*(a+b*x)^n)/n)/(b^5*n*(c*(a+b*x)^n)^(3/n))+4*e^3*(b*d-a*e)*_
+--   (a+b*x)^4*Ei(4*log(c*(a+b*x)^n)/n)/(b^5*n*(c*(a+b*x)^n)^(4/n))+_
+--   e^4*(a+b*x)^5*Ei(5*log(c*(a+b*x)^n)/n)/(b^5*n*(c*(a+b*x)^n)^(5/n))
+--E 1222
+
+--S 1223 of 5341
+--a0:=integrate(t0,x)
+--E 1223
+
+--S 1224 of 5341
+--m0:=a0-r0
+--E 1224
+
+--S 1225 of 5341
+--d0:=D(m0,x)
+--E 1225
+
+)clear all
+
+--S 1226 of 5341
+t0:=(d+e*x)^3/log(c*(a+b*x)^n)
+--R 
+--R
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R   (1)  ----------------------------
+--R                             n
+--R              log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1226
+
+--S 1227 of 5341
+--r0:=(b*d-a*e)^3*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^4*n*(c*(a+_
+--   b*x)^n)^(1/n))+3*e*(b*d-a*e)^2*(a+b*x)^2*Ei(2*log(c*(a+_
+--   b*x)^n)/n)/(b^4*n*(c*(a+b*x)^n)^(2/n))+3*e^2*(b*d-a*e)*(a+_
+--   b*x)^3*Ei(3*log(c*(a+b*x)^n)/n)/(b^4*n*(c*(a+b*x)^n)^(3/n))+_
+--   e^3*(a+b*x)^4*Ei(4*log(c*(a+b*x)^n)/n)/(b^4*n*(c*(a+b*x)^n)^(4/n))
+--E 1227
+
+--S 1228 of 5341
+--a0:=integrate(t0,x)
+--E 1228
+
+--S 1229 of 5341
+--m0:=a0-r0
+--E 1229
+
+--S 1230 of 5341
+--d0:=D(m0,x)
+--E 1230
+
+)clear all
+
+--S 1231 of 5341
+t0:=(d+e*x)^2/log(c*(a+b*x)^n)
+--R 
+--R
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R   (1)  ------------------
+--R                        n
+--R         log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1231
+
+--S 1232 of 5341
+--r0:=(b*d-a*e)^2*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^3*n*(c*(a+_
+--   b*x)^n)^(1/n))+2*e*(b*d-a*e)*(a+b*x)^2*Ei(2*log(c*(a+b*x)^n)/n)/_
+--   (b^3*n*(c*(a+b*x)^n)^(2/n))+e^2*(a+b*x)^3*Ei(3*log(c*(a+b*x)^n)/n)/_
+--   (b^3*n*(c*(a+b*x)^n)^(3/n))
+--E 1232
+
+--S 1233 of 5341
+--a0:=integrate(t0,x)
+--E 1233
+
+--S 1234 of 5341
+--m0:=a0-r0
+--E 1234
+
+--S 1235 of 5341
+--d0:=D(m0,x)
+--E 1235
+
+)clear all
+
+--S 1236 of 5341
+t0:=(d+e*x)/log(c*(a+b*x)^n)
+--R 
+--R
+--R             e x + d
+--R   (1)  -----------------
+--R                       n
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1236
+
+--S 1237 of 5341
+--r0:=(b*d-a*e)*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^2*n*(c*(a+_
+--   b*x)^n)^(1/n))+e*(a+b*x)^2*Ei(2*log(c*(a+b*x)^n)/n)/(b^2*n*(c*(a+_
+--   b*x)^n)^(2/n))
+--E 1237
+
+--S 1238 of 5341
+--a0:=integrate(t0,x)
+--E 1238
+
+--S 1239 of 5341
+--m0:=a0-r0
+--E 1239
+
+--S 1240 of 5341
+--d0:=D(m0,x)
+--E 1240
+
+)clear all
+
+--S 1241 of 5341
+t0:=1/log(c*(a+b*x)^n)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R                       n
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1241
+
+--S 1242 of 5341
+--r0:=(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b*n*(c*(a+b*x)^n)^(1/n))
+--E 1242
+
+--S 1243 of 5341
+--a0:=integrate(t0,x)
+--E 1243
+
+--S 1244 of 5341
+--m0:=a0-r0
+--E 1244
+
+--S 1245 of 5341
+--d0:=D(m0,x)
+--E 1245
+
+)clear all
+
+--S 1246 of 5341
+t0:=1/((d+e*x)*log(c*(a+b*x)^n))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                                n
+--R        (e x + d)log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1246
+
+--S 1247 of 5341
+--r0:=Int(1/((d+e*x)*log(c*(a+b*x)^n)),x)
+--E 1247
+
+--S 1248 of 5341
+--a0:=integrate(t0,x)
+--E 1248
+
+--S 1249 of 5341
+--m0:=a0-r0
+--E 1249
+
+--S 1250 of 5341
+--d0:=D(m0,x)
+--E 1250
+
+)clear all
+
+--S 1251 of 5341
+t0:=(d+e*x)^m/log(c*(a+b*x)^n)^2
+--R 
+--R
+--R                     m
+--R            (e x + d)
+--R   (1)  ------------------
+--R                       n 2
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1251
+
+--S 1252 of 5341
+--r0:=Int((d+e*x)^m/log(c*(a+b*x)^n)^2,x)
+--E 1252
+
+--S 1253 of 5341
+--a0:=integrate(t0,x)
+--E 1253
+
+--S 1254 of 5341
+--m0:=a0-r0
+--E 1254
+
+--S 1255 of 5341
+--d0:=D(m0,x)
+--E 1255
+
+)clear all
+
+--S 1256 of 5341
+t0:=(d+e*x)^4/log(c*(a+b*x)^n)^2
+--R 
+--R
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R   (1)  --------------------------------------
+--R                                 n 2
+--R                  log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1256
+
+--S 1257 of 5341
+--r0:=(b*d-a*e)^4*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^5*n^2*(c*(a+_
+--   b*x)^n)^(1/n))+8*e*(b*d-a*e)^3*(a+b*x)^2*Ei(2*log(c*(a+b*x)^n)/n)/_
+--   (b^5*n^2*(c*(a+b*x)^n)^(2/n))+18*e^2*(b*d-a*e)^2*(a+b*x)^3*Ei(3*_
+--   log(c*(a+b*x)^n)/n)/(b^5*n^2*(c*(a+b*x)^n)^(3/n))+16*e^3*(b*d-a*e)*_
+--   (a+b*x)^4*Ei(4*log(c*(a+b*x)^n)/n)/(b^5*n^2*(c*(a+b*x)^n)^(4/n))+_
+--   5*e^4*(a+b*x)^5*Ei(5*log(c*(a+b*x)^n)/n)/(b^5*n^2*(c*(a+_
+--   b*x)^n)^(5/n))-(a+b*x)*(d+e*x)^4/(b*n*log(c*(a+b*x)^n))
+--E 1257
+
+--S 1258 of 5341
+--a0:=integrate(t0,x)
+--E 1258
+
+--S 1259 of 5341
+--m0:=a0-r0
+--E 1259
+
+--S 1260 of 5341
+--d0:=D(m0,x)
+--E 1260
+
+)clear all
+
+--S 1261 of 5341
+t0:=(d+e*x)^3/log(c*(a+b*x)^n)^2
+--R 
+--R
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R   (1)  ----------------------------
+--R                            n 2
+--R             log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1261
+
+--S 1262 of 5341
+--r0:=(b*d-a*e)^3*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^4*n^2*(c*(a+_
+--   b*x)^n)^(1/n))+6*e*(b*d-a*e)^2*(a+b*x)^2*Ei(2*log(c*(a+b*x)^n)/n)/_
+--   (b^4*n^2*(c*(a+b*x)^n)^(2/n))+9*e^2*(b*d-a*e)*(a+b*x)^3*Ei(3*_
+--   log(c*(a+b*x)^n)/n)/(b^4*n^2*(c*(a+b*x)^n)^(3/n))+4*e^3*(a+b*x)^4*_
+--   Ei(4*log(c*(a+b*x)^n)/n)/(b^4*n^2*(c*(a+b*x)^n)^(4/n))-(a+b*x)*_
+--   (d+e*x)^3/(b*n*log(c*(a+b*x)^n))
+--E 1262
+
+--S 1263 of 5341
+--a0:=integrate(t0,x)
+--E 1263
+
+--S 1264 of 5341
+--m0:=a0-r0
+--E 1264
+
+--S 1265 of 5341
+--d0:=D(m0,x)
+--E 1265
+
+)clear all
+
+--S 1266 of 5341
+t0:=(d+e*x)^2/log(c*(a+b*x)^n)^2
+--R 
+--R
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R   (1)  ------------------
+--R                       n 2
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1266
+
+--S 1267 of 5341
+--r0:=(b*d-a*e)^2*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^3*n^2*(c*(a+_
+--   b*x)^n)^(1/n))+4*e*(b*d-a*e)*(a+b*x)^2*Ei(2*log(c*(a+b*x)^n)/n)/_
+--   (b^3*n^2*(c*(a+b*x)^n)^(2/n))+3*e^2*(a+b*x)^3*Ei(3*log(c*(a+_
+--   b*x)^n)/n)/(b^3*n^2*(c*(a+b*x)^n)^(3/n))-(a+b*x)*(d+e*x)^2/(b*n*_
+--   log(c*(a+b*x)^n))
+--E 1267
+
+--S 1268 of 5341
+--a0:=integrate(t0,x)
+--E 1268
+
+--S 1269 of 5341
+--m0:=a0-r0
+--E 1269
+
+--S 1270 of 5341
+--d0:=D(m0,x)
+--E 1270
+
+)clear all
+
+--S 1271 of 5341
+t0:=(d+e*x)/log(c*(a+b*x)^n)^2
+--R 
+--R
+--R              e x + d
+--R   (1)  ------------------
+--R                       n 2
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1271
+
+--S 1272 of 5341
+--r0:=(b*d-a*e)*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^2*n^2*(c*(a+_
+--   b*x)^n)^(1/n))+2*e*(a+b*x)^2*Ei(2*log(c*(a+b*x)^n)/n)/(b^2*n^2*(c*_
+--   (a+b*x)^n)^(2/n))-(a+b*x)*(d+e*x)/(b*n*log(c*(a+b*x)^n))
+--E 1272
+
+--S 1273 of 5341
+--a0:=integrate(t0,x)
+--E 1273
+
+--S 1274 of 5341
+--m0:=a0-r0
+--E 1274
+
+--S 1275 of 5341
+--d0:=D(m0,x)
+--E 1275
+
+)clear all
+
+--S 1276 of 5341
+t0:=1/log(c*(a+b*x)^n)^2
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R                       n 2
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1276
+
+--S 1277 of 5341
+--r0:=(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b*n^2*(c*(a+b*x)^n)^(1/n))+_
+--   (-a-b*x)/(b*n*log(c*(a+b*x)^n))
+--E 1277
+
+--S 1278 of 5341
+--a0:=integrate(t0,x)
+--E 1278
+
+--S 1279 of 5341
+--m0:=a0-r0
+--E 1279
+
+--S 1280 of 5341
+--d0:=D(m0,x)
+--E 1280
+
+)clear all
+
+--S 1281 of 5341
+t0:=1/((d+e*x)*log(c*(a+b*x)^n)^2)
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                                n 2
+--R        (e x + d)log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1281
+
+--S 1282 of 5341
+--r0:=Int(1/((d+e*x)*log(c*(a+b*x)^n)^2),x)
+--E 1282
+
+--S 1283 of 5341
+--a0:=integrate(t0,x)
+--E 1283
+
+--S 1284 of 5341
+--m0:=a0-r0
+--E 1284
+
+--S 1285 of 5341
+--d0:=D(m0,x)
+--E 1285
+
+)clear all
+
+--S 1286 of 5341
+t0:=(d+e*x)^m/log(c*(a+b*x)^n)^3
+--R 
+--R
+--R                     m
+--R            (e x + d)
+--R   (1)  ------------------
+--R                       n 3
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1286
+
+--S 1287 of 5341
+--r0:=Int((d+e*x)^m/log(c*(a+b*x)^n)^3,x)
+--E 1287
+
+--S 1288 of 5341
+--a0:=integrate(t0,x)
+--E 1288
+
+--S 1289 of 5341
+--m0:=a0-r0
+--E 1289
+
+--S 1290 of 5341
+--d0:=D(m0,x)
+--E 1290
+
+)clear all
+
+--S 1291 of 5341
+t0:=(d+e*x)^3/log(c*(a+b*x)^n)^3
+--R 
+--R
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R   (1)  ----------------------------
+--R                            n 3
+--R             log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1291
+
+--S 1292 of 5341
+--r0:=1/2*(b*d-a*e)^3*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^4*n^3*(c*(a+_
+--   b*x)^n)^(1/n))+6*e*(b*d-a*e)^2*(a+b*x)^2*Ei(2*log(c*(a+b*x)^n)/n)/_
+--   (b^4*n^3*(c*(a+b*x)^n)^(2/n))+27/2*e^2*(b*d-a*e)*(a+b*x)^3*_
+--   Ei(3*log(c*(a+b*x)^n)/n)/(b^4*n^3*(c*(a+b*x)^n)^(3/n))+8*e^3*_
+--   (a+b*x)^4*Ei(4*log(c*(a+b*x)^n)/n)/(b^4*n^3*(c*(a+b*x)^n)^(4/n))-_
+--   1/2*(a+b*x)*(d+e*x)^3/(b*n*log(c*(a+b*x)^n)^2)+3/2*(b*d-a*e)*_
+--   (a+b*x)*(d+e*x)^2/(b^2*n^2*log(c*(a+b*x)^n))-2*(a+b*x)*(d+e*x)^3/_
+--   (b*n^2*log(c*(a+b*x)^n))
+--E 1292
+
+--S 1293 of 5341
+--a0:=integrate(t0,x)
+--E 1293
+
+--S 1294 of 5341
+--m0:=a0-r0
+--E 1294
+
+--S 1295 of 5341
+--d0:=D(m0,x)
+--E 1295
+
+)clear all
+
+--S 1296 of 5341
+t0:=(d+e*x)^2/log(c*(a+b*x)^n)^3
+--R 
+--R
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R   (1)  ------------------
+--R                       n 3
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1296
+
+--S 1297 of 5341
+--r0:=1/2*(b*d-a*e)^2*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^3*n^3*(c*(a+_
+--   b*x)^n)^(1/n))+4*e*(b*d-a*e)*(a+b*x)^2*Ei(2*log(c*(a+b*x)^n)/n)/_
+--   (b^3*n^3*(c*(a+b*x)^n)^(2/n))+9/2*e^2*(a+b*x)^3*Ei(3*log(c*(a+_
+--   b*x)^n)/n)/(b^3*n^3*(c*(a+b*x)^n)^(3/n))-1/2*(a+b*x)*(d+e*x)^2/_
+--   (b*n*log(c*(a+b*x)^n)^2)+(b*d-a*e)*(a+b*x)*(d+e*x)/(b^2*n^2*_
+--   log(c*(a+b*x)^n))-3/2*(a+b*x)*(d+e*x)^2/(b*n^2*log(c*(a+b*x)^n))
+--E 1297
+
+--S 1298 of 5341
+--a0:=integrate(t0,x)
+--E 1298
+
+--S 1299 of 5341
+--m0:=a0-r0
+--E 1299
+
+--S 1300 of 5341
+--d0:=D(m0,x)
+--E 1300
+
+)clear all
+
+--S 1301 of 5341
+t0:=(d+e*x)/log(c*(a+b*x)^n)^3
+--R 
+--R
+--R              e x + d
+--R   (1)  ------------------
+--R                       n 3
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1301
+
+--S 1302 of 5341
+--r0:=1/2*(b*d-a*e)*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b^2*n^3*(c*(a+_
+--   b*x)^n)^(1/n))+2*e*(a+b*x)^2*Ei(2*log(c*(a+b*x)^n)/n)/(b^2*n^3*_
+--   (c*(a+b*x)^n)^(2/n))-1/2*(a+b*x)*(d+e*x)/(b*n*log(c*(a+b*x)^n)^2)+_
+--   1/2*(b*d-a*e)*(a+b*x)/(b^2*n^2*log(c*(a+b*x)^n))-(a+b*x)*_
+--   (d+e*x)/(b*n^2*log(c*(a+b*x)^n))
+--E 1302
+
+--S 1303 of 5341
+--a0:=integrate(t0,x)
+--E 1303
+
+--S 1304 of 5341
+--m0:=a0-r0
+--E 1304
+
+--S 1305 of 5341
+--d0:=D(m0,x)
+--E 1305
+
+)clear all
+
+--S 1306 of 5341
+t0:=1/log(c*(a+b*x)^n)^3
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R                       n 3
+--R        log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1306
+
+--S 1307 of 5341
+--r0:=1/2*(a+b*x)*Ei(log(c*(a+b*x)^n)/n)/(b*n^3*(c*(a+b*x)^n)^(1/n))+_
+-- 1/2*(-a-b*x)/(b*n*log(c*(a+b*x)^n)^2)+1/2*(-a-b*x)/(b*n^2*log(c*(a+b*x)^n))
+--E 1307
+
+--S 1308 of 5341
+--a0:=integrate(t0,x)
+--E 1308
+
+--S 1309 of 5341
+--m0:=a0-r0
+--E 1309
+
+--S 1310 of 5341
+--d0:=D(m0,x)
+--E 1310
+
+)clear all
+
+--S 1311 of 5341
+t0:=1/((d+e*x)*log(c*(a+b*x)^n)^3)
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                                n 3
+--R        (e x + d)log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 1311
+
+--S 1312 of 5341
+--r0:=Int(1/((d+e*x)*log(c*(a+b*x)^n)^3),x)
+--E 1312
+
+--S 1313 of 5341
+--a0:=integrate(t0,x)
+--E 1313
+
+--S 1314 of 5341
+--m0:=a0-r0
+--E 1314
+
+--S 1315 of 5341
+--d0:=D(m0,x)
+--E 1315
+
+)clear all
+
+--S 1316 of 5341
+t0:=(f+g*x)^m*(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R                   m               n               m
+--R   (1)  b (g x + f) log(c (e x + d) ) + a (g x + f)
+--R                                                    Type: Expression(Integer)
+--E 1316
+
+--S 1317 of 5341
+--r0:=b*e*n*(f+g*x)^(2+m)*hypergeometric(1,2+m,3+m,e*(f+g*x)/(e*f-d*g))/_
+--   (g*(e*f-d*g)*(1+m)*(2+m))+(f+g*x)^(1+m)*(a+b*log(c*(d+e*x)^n))/(g*(1+m))
+--E 1317
+
+--S 1318 of 5341
+--a0:=integrate(t0,x)
+--E 1318
+
+--S 1319 of 5341
+--m0:=a0-r0
+--E 1319
+
+--S 1320 of 5341
+--d0:=D(m0,x)
+--E 1320
+
+)clear all
+
+--S 1321 of 5341
+t0:=(f+g*x)^4*(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R   (1)
+--R         4 4         3 3       2 2 2       3         4                n
+--R     (b g x  + 4b f g x  + 6b f g x  + 4b f g x + b f )log(c (e x + d) )
+--R   + 
+--R        4 4         3 3       2 2 2       3         4
+--R     a g x  + 4a f g x  + 6a f g x  + 4a f g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1321
+
+--S 1322 of 5341
+r0:=-1/5*b*(e*f-d*g)^4*n*x/e^4-1/10*b*(e*f-d*g)^3*n*(f+g*x)^2/(e^3*g)-_
+   1/15*b*(e*f-d*g)^2*n*(f+g*x)^3/(e^2*g)-1/20*b*(e*f-d*g)*n*(f+g*x)^4/_
+   (e*g)-1/25*b*n*(f+g*x)^5/g-1/5*b*(e*f-d*g)^5*n*log(d+e*x)/(e^5*g)+_
+   1/5*(f+g*x)^5*(a+b*log(c*(d+e*x)^n))/g
+--R 
+--R
+--R   (2)
+--R                5 5 5         5   4 4         5 2 3 3         5 3 2 2
+--R           60b e g x  + 300b e f g x  + 600b e f g x  + 600b e f g x
+--R         + 
+--R                 5 4           5 5
+--R           300b e f g x + 60b e f
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R                5 5         4     4         3 2 2 3         2 3 3 2
+--R           60b d g  - 300b d e f g  + 600b d e f g  - 600b d e f g
+--R         + 
+--R                   4 4         5 5
+--R           300b d e f g - 60b e f
+--R      *
+--R         n log(e x + d)
+--R     + 
+--R               5 5         5 5  5            4 5        5   4           5   4  4
+--R       (- 12b e g n + 60a e g )x  + ((15b d e g  - 75b e f g )n + 300a e f g )x
+--R     + 
+--R                2 3 5           4   4         5 2 3           5 2 3  3
+--R       ((- 20b d e g  + 100b d e f g  - 200b e f g )n + 600a e f g )x
+--R     + 
+--R                 3 2 5         2 3   4           4 2 3         5 3 2
+--R           (30b d e g  - 150b d e f g  + 300b d e f g  - 300b e f g )n
+--R         + 
+--R                 5 3 2
+--R           600a e f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                      4   5         3 2   4         2 3 2 3           4 3 2
+--R               - 60b d e g  + 300b d e f g  - 600b d e f g  + 600b d e f g
+--R             + 
+--R                       5 4
+--R               - 300b e f g
+--R          *
+--R             n
+--R         + 
+--R                 5 4
+--R           300a e f g
+--R      *
+--R         x
+--R     + 
+--R             3 2 2 3         2 3 3 2           4 4         5 5          5 5
+--R       (30b d e f g  - 110b d e f g  + 145b d e f g - 77b e f )n + 60a e f
+--R  /
+--R         5
+--R     300e g
+--R                                                    Type: Expression(Integer)
+--E 1322
+
+--S 1323 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                5 4   5         5   3   4         5 2 2   3         5 3     2
+--R           60b e g n x  + 300b e f g n x  + 600b e f g n x  + 600b e f g n x
+--R         + 
+--R                 5 4
+--R           300b e f n x
+--R         + 
+--R                    5 4         4     3         3 2 2 2         2 3 3
+--R               60b d g  - 300b d e f g  + 600b d e f g  - 600b d e f g
+--R             + 
+--R                       4 4
+--R               300b d e f
+--R          *
+--R             n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                  5 4 5         5   3 4         5 2 2 3         5 3   2
+--R             60b e g x  + 300b e f g x  + 600b e f g x  + 600b e f g x
+--R           + 
+--R                   5 4
+--R             300b e f x
+--R      *
+--R         log(c)
+--R     + 
+--R               5 4         5 4  5            4 4        5   3           5   3  4
+--R       (- 12b e g n + 60a e g )x  + ((15b d e g  - 75b e f g )n + 300a e f g )x
+--R     + 
+--R                2 3 4           4   3         5 2 2           5 2 2  3
+--R       ((- 20b d e g  + 100b d e f g  - 200b e f g )n + 600a e f g )x
+--R     + 
+--R                   3 2 4         2 3   3           4 2 2         5 3
+--R             (30b d e g  - 150b d e f g  + 300b d e f g  - 300b e f g)n
+--R           + 
+--R                   5 3
+--R             600a e f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                      4   4         3 2   3         2 3 2 2           4 3
+--R               - 60b d e g  + 300b d e f g  - 600b d e f g  + 600b d e f g
+--R             + 
+--R                       5 4
+--R               - 300b e f
+--R          *
+--R             n
+--R         + 
+--R                 5 4
+--R           300a e f
+--R      *
+--R         x
+--R  /
+--R         5
+--R     300e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1323
+
+--S 1324 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  3 5 5         3   4 4         3 2 3 3         3 3 2 2
+--R           - 60b e g x  - 300b e f g x  - 600b e f g x  - 600b e f g x
+--R         + 
+--R                   3 4           3 5
+--R           - 300b e f g x - 60b e f
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R                3 5   5         3   4   4         3 2 3   3         3 3 2   2
+--R           60b e g n x  + 300b e f g n x  + 600b e f g n x  + 600b e f g n x
+--R         + 
+--R                 3 4             3 5
+--R           300b e f g n x + 60b e f n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                3 5 5         3   4 4         3 2 3 3         3 3 2 2
+--R           60b e g x  + 300b e f g x  + 600b e f g x  + 600b e f g x
+--R         + 
+--R                 3 4
+--R           300b e f g x
+--R      *
+--R         log(c)
+--R     + 
+--R               3 2 3         2   3 2           2 4         3 5          3 5
+--R       (- 30b d f g  + 110b d e f g  - 145b d e f g + 77b e f )n - 60a e f
+--R  /
+--R         3
+--R     300e g
+--R                                                    Type: Expression(Integer)
+--E 1324
+
+--S 1325 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1325
+
+)clear all
+
+--S 1326 of 5341
+t0:=(f+g*x)^3*(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R   (1)
+--R         3 3         2 2       2         3                n       3 3
+--R     (b g x  + 3b f g x  + 3b f g x + b f )log(c (e x + d) ) + a g x
+--R   + 
+--R           2 2       2         3
+--R     3a f g x  + 3a f g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1326
+
+--S 1327 of 5341
+r0:=-1/4*b*(e*f-d*g)^3*n*x/e^3-1/8*b*(e*f-d*g)^2*n*(f+g*x)^2/(e^2*g)-_
+   1/12*b*(e*f-d*g)*n*(f+g*x)^3/(e*g)-1/16*b*n*(f+g*x)^4/g-_
+   1/4*b*(e*f-d*g)^4*n*log(d+e*x)/(e^4*g)+1/4*(f+g*x)^4*(a+b*_
+   log(c*(d+e*x)^n))/g
+--R 
+--R
+--R   (2)
+--R               4 4 4        4   3 3        4 2 2 2        4 3           4 4
+--R         (12b e g x  + 48b e f g x  + 72b e f g x  + 48b e f g x + 12b e f )
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R                 4 4        3     3        2 2 2 2          3 3         4 4
+--R         (- 12b d g  + 48b d e f g  - 72b d e f g  + 48b d e f g - 12b e f )n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R              4 4         4 4  4           3 4        4   3          4   3  3
+--R       (- 3b e g n + 12a e g )x  + ((4b d e g  - 16b e f g )n + 48a e f g )x
+--R     + 
+--R               2 2 4          3   3        4 2 2          4 2 2  2
+--R       ((- 6b d e g  + 24b d e f g  - 36b e f g )n + 72a e f g )x
+--R     + 
+--R              3   4        2 2   3          3 2 2        4 3           4 3
+--R       ((12b d e g  - 48b d e f g  + 72b d e f g  - 48b e f g)n + 48a e f g)x
+--R     + 
+--R              2 2 2 2          3 3         4 4          4 4
+--R       (- 6b d e f g  + 16b d e f g - 13b e f )n + 12a e f
+--R  /
+--R        4
+--R     48e g
+--R                                                    Type: Expression(Integer)
+--E 1327
+
+--S 1328 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                4 3   4        4   2   3        4 2     2        4 3
+--R           12b e g n x  + 48b e f g n x  + 72b e f g n x  + 48b e f n x
+--R         + 
+--R                   4 3        3     2        2 2 2           3 3
+--R           (- 12b d g  + 48b d e f g  - 72b d e f g + 48b d e f )n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R             4 3 4        4   2 3        4 2   2        4 3
+--R       (12b e g x  + 48b e f g x  + 72b e f g x  + 48b e f x)log(c)
+--R     + 
+--R              4 3         4 3  4           3 3        4   2          4   2  3
+--R       (- 3b e g n + 12a e g )x  + ((4b d e g  - 16b e f g )n + 48a e f g )x
+--R     + 
+--R               2 2 3          3   2        4 2           4 2   2
+--R       ((- 6b d e g  + 24b d e f g  - 36b e f g)n + 72a e f g)x
+--R     + 
+--R              3   3        2 2   2          3 2         4 3          4 3
+--R       ((12b d e g  - 48b d e f g  + 72b d e f g - 48b e f )n + 48a e f )x
+--R  /
+--R        4
+--R     48e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1328
+
+--S 1329 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 2 4 4        2   3 3        2 2 2 2        2 3           2 4
+--R         (- 12b e g x  - 48b e f g x  - 72b e f g x  - 48b e f g x - 12b e f )
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R                2 4   4        2   3   3        2 2 2   2        2 3
+--R           12b e g n x  + 48b e f g n x  + 72b e f g n x  + 48b e f g n x
+--R         + 
+--R                2 4
+--R           12b e f n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R             2 4 4        2   3 3        2 2 2 2        2 3
+--R       (12b e g x  + 48b e f g x  + 72b e f g x  + 48b e f g x)log(c)
+--R     + 
+--R            2 2 2            3         2 4          2 4
+--R       (6b d f g  - 16b d e f g + 13b e f )n - 12a e f
+--R  /
+--R        2
+--R     48e g
+--R                                                    Type: Expression(Integer)
+--E 1329
+
+--S 1330 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1330
+
+)clear all
+
+--S 1331 of 5341
+t0:=(f+g*x)^2*(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R            2 2                 2                n       2 2                 2
+--R   (1)  (b g x  + 2b f g x + b f )log(c (e x + d) ) + a g x  + 2a f g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1331
+
+--S 1332 of 5341
+r0:=-1/3*b*(e*f-d*g)^2*n*x/e^2-1/6*b*(e*f-d*g)*n*(f+g*x)^2/(e*g)-_
+   1/9*b*n*(f+g*x)^3/g-1/3*b*(e*f-d*g)^3*n*log(d+e*x)/(e^3*g)+_
+   1/3*(f+g*x)^3*(a+b*log(c*(d+e*x)^n))/g
+--R 
+--R
+--R   (2)
+--R            3 3 3        3   2 2        3 2          3 3                n
+--R       (6b e g x  + 18b e f g x  + 18b e f g x + 6b e f )log(c (e x + d) )
+--R     + 
+--R            3 3        2     2          2 2        3 3
+--R       (6b d g  - 18b d e f g  + 18b d e f g - 6b e f )n log(e x + d)
+--R     + 
+--R              3 3        3 3  3           2 3       3   2          3   2  2
+--R       (- 2b e g n + 6a e g )x  + ((3b d e g  - 9b e f g )n + 18a e f g )x
+--R     + 
+--R               2   3          2   2        3 2           3 2
+--R       ((- 6b d e g  + 18b d e f g  - 18b e f g)n + 18a e f g)x
+--R     + 
+--R              2 2        3 3         3 3
+--R       (3b d e f g - 5b e f )n + 6a e f
+--R  /
+--R        3
+--R     18e g
+--R                                                    Type: Expression(Integer)
+--E 1332
+
+--S 1333 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 2   3        3       2        3 2
+--R           6b e g n x  + 18b e f g n x  + 18b e f n x
+--R         + 
+--R                3 2        2               2 2
+--R           (6b d g  - 18b d e f g + 18b d e f )n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 2 3        3     2        3 2                  3 2        3 2  3
+--R       (6b e g x  + 18b e f g x  + 18b e f x)log(c) + (- 2b e g n + 6a e g )x
+--R     + 
+--R               2 2       3             3     2
+--R       ((3b d e g  - 9b e f g)n + 18a e f g)x
+--R     + 
+--R               2   2          2           3 2          3 2
+--R       ((- 6b d e g  + 18b d e f g - 18b e f )n + 18a e f )x
+--R  /
+--R        3
+--R     18e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1333
+
+--S 1334 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                3 3            2 2          2            3                n
+--R       (- 6b e g x  - 18b e f g x  - 18b e f g x - 6b e f )log(c (e x + d) )
+--R     + 
+--R              3   3            2   2          2              3
+--R       (6b e g n x  + 18b e f g n x  + 18b e f g n x + 6b e f n)log(e x + d)
+--R     + 
+--R              3 3            2 2          2                      2          3
+--R       (6b e g x  + 18b e f g x  + 18b e f g x)log(c) + (- 3b d f g + 5b e f )n
+--R     + 
+--R               3
+--R       - 6a e f
+--R  /
+--R     18e g
+--R                                                    Type: Expression(Integer)
+--E 1334
+
+--S 1335 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1335
+
+)clear all
+
+--S 1336 of 5341
+t0:=(f+g*x)*(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R                                    n
+--R   (1)  (b g x + b f)log(c (e x + d) ) + a g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1336
+
+--S 1337 of 5341
+r0:=-1/2*b*(e*f-d*g)*n*x/e-1/4*b*n*(f+g*x)^2/g-1/2*b*(e*f-d*g)^2*n*_
+   log(d+e*x)/(e^2*g)+1/2*(f+g*x)^2*(a+b*log(c*(d+e*x)^n))/g
+--R 
+--R
+--R   (2)
+--R            2 2 2       2            2 2                n
+--R       (2b e g x  + 4b e f g x + 2b e f )log(c (e x + d) )
+--R     + 
+--R              2 2                    2 2
+--R       (- 2b d g  + 4b d e f g - 2b e f )n log(e x + d)
+--R     + 
+--R             2 2        2 2  2             2       2            2           2 2
+--R       (- b e g n + 2a e g )x  + ((2b d e g  - 4b e f g)n + 4a e f g)x - b e f n
+--R     + 
+--R           2 2
+--R       2a e f
+--R  /
+--R       2
+--R     4e g
+--R                                                    Type: Expression(Integer)
+--E 1337
+
+--S 1338 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2     2       2               2
+--R       (2b e g n x  + 4b e f n x + (- 2b d g + 4b d e f)n)log(e x + d)
+--R     + 
+--R            2   2       2                   2          2   2
+--R       (2b e g x  + 4b e f x)log(c) + (- b e g n + 2a e g)x
+--R     + 
+--R                        2          2
+--R       ((2b d e g - 4b e f)n + 4a e f)x
+--R  /
+--R       2
+--R     4e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1338
+
+--S 1339 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2 2                  2                n
+--R       (- 2b g x  - 4b f g x - 2b f )log(c (e x + d) )
+--R     + 
+--R            2   2                    2
+--R       (2b g n x  + 4b f g n x + 2b f n)log(e x + d)
+--R     + 
+--R            2 2                        2        2
+--R       (2b g x  + 4b f g x)log(c) + b f n - 2a f
+--R  /
+--R     4g
+--R                                                    Type: Expression(Integer)
+--E 1339
+
+--S 1340 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1340
+
+)clear all
+
+--S 1341 of 5341
+t0:=a+b*log(c*(d+e*x)^n)
+--R 
+--R
+--R                         n
+--R   (1)  b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1341
+
+--S 1342 of 5341
+r0:=a*x-b*n*x+b*(d+e*x)*log(c*(d+e*x)^n)/e
+--R 
+--R
+--R                                    n
+--R        (b e x + b d)log(c (e x + d) ) + (- b e n + a e)x
+--R   (2)  -------------------------------------------------
+--R                                e
+--R                                                    Type: Expression(Integer)
+--E 1342
+
+--S 1343 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (b e n x + b d n)log(e x + d) + b e x log(c) + (- b e n + a e)x
+--R   (3)  ---------------------------------------------------------------
+--R                                       e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1343
+
+--S 1344 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     n
+--R       (- b e x - b d)log(c (e x + d) ) + (b e n x + b d n)log(e x + d)
+--R     + 
+--R       b e x log(c)
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 1344
+
+--S 1345 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1345
+
+)clear all
+
+--S 1346 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))/(f+g*x)
+--R 
+--R
+--R                         n
+--R        b log(c (e x + d) ) + a
+--R   (1)  -----------------------
+--R                g x + f
+--R                                                    Type: Expression(Integer)
+--E 1346
+
+--S 1347 of 5341
+--r0:=(a+b*log(c*(d+e*x)^n))*log(e*(f+g*x)/(e*f-d*g))/g+b*n*_
+--   polylog(2,-g*(d+e*x)/(e*f-d*g))/g
+--E 1347
+
+--S 1348 of 5341
+--a0:=integrate(t0,x)
+--E 1348
+
+--S 1349 of 5341
+--m0:=a0-r0
+--E 1349
+
+--S 1350 of 5341
+--d0:=D(m0,x)
+--E 1350
+
+)clear all
+
+--S 1351 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))/(f+g*x)^2
+--R 
+--R
+--R                         n
+--R        b log(c (e x + d) ) + a
+--R   (1)  -----------------------
+--R            2 2             2
+--R           g x  + 2f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1351
+
+--S 1352 of 5341
+r0:=b*e*n*log(d+e*x)/(g*(e*f-d*g))+(-a-b*log(c*(d+e*x)^n))/(g*(f+g*x))-_
+   b*e*n*log(f+g*x)/(g*(e*f-d*g))
+--R 
+--R
+--R   (2)
+--R                                       n
+--R       (- b d g + b e f)log(c (e x + d) ) + (b e g n x + b e f n)log(g x + f)
+--R     + 
+--R       (- b e g n x - b e f n)log(e x + d) - a d g + a e f
+--R  /
+--R         3        2          2      2
+--R     (d g  - e f g )x + d f g  - e f g
+--R                                                    Type: Expression(Integer)
+--E 1352
+
+--S 1353 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       (b e g n x + b e f n)log(g x + f) + (- b e g n x - b d g n)log(e x + d)
+--R     + 
+--R       (- b d g + b e f)log(c) - a d g + a e f
+--R  /
+--R         3        2          2      2
+--R     (d g  - e f g )x + d f g  - e f g
+--R                                         Type: Union(Expression(Integer),...)
+--E 1353
+
+--S 1354 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                         n
+--R        b log(c (e x + d) ) - b n log(e x + d) - b log(c)
+--R   (4)  -------------------------------------------------
+--R                             2
+--R                            g x + f g
+--R                                                    Type: Expression(Integer)
+--E 1354
+
+--S 1355 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1355
+
+)clear all
+
+--S 1356 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))/(f+g*x)^3
+--R 
+--R
+--R                            n
+--R           b log(c (e x + d) ) + a
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        g x  + 3f g x  + 3f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1356
+
+--S 1357 of 5341
+r0:=1/2*b*e*n/(g*(e*f-d*g)*(f+g*x))+1/2*b*e^2*n*log(d+e*x)/(g*(e*f-d*g)^2)+_
+   1/2*(-a-b*log(c*(d+e*x)^n))/(g*(f+g*x)^2)-1/2*b*e^2*n*log(f+g*x)/_
+   (g*(e*f-d*g)^2)
+--R 
+--R
+--R   (2)
+--R             2 2                   2 2                n
+--R       (- b d g  + 2b d e f g - b e f )log(c (e x + d) )
+--R     + 
+--R             2 2   2       2             2 2
+--R       (- b e g n x  - 2b e f g n x - b e f n)log(g x + f)
+--R     + 
+--R           2 2   2       2             2 2
+--R       (b e g n x  + 2b e f g n x + b e f n)log(e x + d)
+--R     + 
+--R                 2      2                            2 2        2 2
+--R       (- b d e g  + b e f g)n x + (- b d e f g + b e f )n - a d g  + 2a d e f g
+--R     + 
+--R            2 2
+--R       - a e f
+--R  /
+--R          2 5           4     2 2 3  2      2   4         2 3     2 3 2
+--R       (2d g  - 4d e f g  + 2e f g )x  + (4d f g  - 8d e f g  + 4e f g )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       2d f g  - 4d e f g  + 2e f g
+--R                                                    Type: Expression(Integer)
+--E 1357
+
+--S 1358 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             2 2   2       2             2 2
+--R       (- b e g n x  - 2b e f g n x - b e f n)log(g x + f)
+--R     + 
+--R           2 2   2       2                2 2
+--R       (b e g n x  + 2b e f g n x + (- b d g  + 2b d e f g)n)log(e x + d)
+--R     + 
+--R             2 2                   2 2                    2      2
+--R       (- b d g  + 2b d e f g - b e f )log(c) + (- b d e g  + b e f g)n x
+--R     + 
+--R                         2 2        2 2                   2 2
+--R       (- b d e f g + b e f )n - a d g  + 2a d e f g - a e f
+--R  /
+--R          2 5           4     2 2 3  2      2   4         2 3     2 3 2
+--R       (2d g  - 4d e f g  + 2e f g )x  + (4d f g  - 8d e f g  + 4e f g )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       2d f g  - 4d e f g  + 2e f g
+--R                                         Type: Union(Expression(Integer),...)
+--E 1358
+
+--S 1359 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                         n
+--R        b log(c (e x + d) ) - b n log(e x + d) - b log(c)
+--R   (4)  -------------------------------------------------
+--R                        3 2       2      2
+--R                      2g x  + 4f g x + 2f g
+--R                                                    Type: Expression(Integer)
+--E 1359
+
+--S 1360 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1360
+
+)clear all
+
+--S 1361 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))/(f+g*x)^4
+--R 
+--R
+--R                                 n
+--R                b log(c (e x + d) ) + a
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        g x  + 4f g x  + 6f g x  + 4f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1361
+
+--S 1362 of 5341
+r0:=1/6*b*e*n/(g*(e*f-d*g)*(f+g*x)^2)+1/3*b*e^2*n/(g*(e*f-d*g)^2*(f+g*x))+_
+   1/3*b*e^3*n*log(d+e*x)/(g*(e*f-d*g)^3)+1/3*(-a-b*log(c*(d+e*x)^n))/_
+   (g*(f+g*x)^3)-1/3*b*e^3*n*log(f+g*x)/(g*(e*f-d*g)^3)
+--R 
+--R
+--R   (2)
+--R              3 3       2     2         2 2        3 3                n
+--R       (- 2b d g  + 6b d e f g  - 6b d e f g + 2b e f )log(c (e x + d) )
+--R     + 
+--R            3 3   3       3   2   2       3 2            3 3
+--R       (2b e g n x  + 6b e f g n x  + 6b e f g n x + 2b e f n)log(g x + f)
+--R     + 
+--R              3 3   3       3   2   2       3 2            3 3
+--R       (- 2b e g n x  - 6b e f g n x  - 6b e f g n x - 2b e f n)log(e x + d)
+--R     + 
+--R              2 3       3   2    2         2   3         2   2       3 2
+--R       (2b d e g  - 2b e f g )n x  + (- b d e g  + 6b d e f g  - 5b e f g)n x
+--R     + 
+--R             2     2         2 2        3 3         3 3       2     2
+--R       (- b d e f g  + 4b d e f g - 3b e f )n - 2a d g  + 6a d e f g
+--R     + 
+--R               2 2        3 3
+--R       - 6a d e f g + 2a e f
+--R  /
+--R          3 7      2     6        2 2 5     3 3 4  3
+--R       (6d g  - 18d e f g  + 18d e f g  - 6e f g )x
+--R     + 
+--R           3   6      2   2 5        2 3 4      3 4 3  2
+--R       (18d f g  - 54d e f g  + 54d e f g  - 18e f g )x
+--R     + 
+--R           3 2 5      2   3 4        2 4 3      3 5 2       3 3 4      2   4 3
+--R       (18d f g  - 54d e f g  + 54d e f g  - 18e f g )x + 6d f g  - 18d e f g
+--R     + 
+--R            2 5 2     3 6
+--R       18d e f g  - 6e f g
+--R                                                    Type: Expression(Integer)
+--E 1362
+
+--S 1363 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 3   3       3   2   2       3 2            3 3
+--R       (2b e g n x  + 6b e f g n x  + 6b e f g n x + 2b e f n)log(g x + f)
+--R     + 
+--R                 3 3   3       3   2   2       3 2
+--R           - 2b e g n x  - 6b e f g n x  - 6b e f g n x
+--R         + 
+--R                  3 3       2     2         2 2
+--R           (- 2b d g  + 6b d e f g  - 6b d e f g)n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R              3 3       2     2         2 2        3 3
+--R       (- 2b d g  + 6b d e f g  - 6b d e f g + 2b e f )log(c)
+--R     + 
+--R              2 3       3   2    2         2   3         2   2       3 2
+--R       (2b d e g  - 2b e f g )n x  + (- b d e g  + 6b d e f g  - 5b e f g)n x
+--R     + 
+--R             2     2         2 2        3 3         3 3       2     2
+--R       (- b d e f g  + 4b d e f g - 3b e f )n - 2a d g  + 6a d e f g
+--R     + 
+--R               2 2        3 3
+--R       - 6a d e f g + 2a e f
+--R  /
+--R          3 7      2     6        2 2 5     3 3 4  3
+--R       (6d g  - 18d e f g  + 18d e f g  - 6e f g )x
+--R     + 
+--R           3   6      2   2 5        2 3 4      3 4 3  2
+--R       (18d f g  - 54d e f g  + 54d e f g  - 18e f g )x
+--R     + 
+--R           3 2 5      2   3 4        2 4 3      3 5 2       3 3 4      2   4 3
+--R       (18d f g  - 54d e f g  + 54d e f g  - 18e f g )x + 6d f g  - 18d e f g
+--R     + 
+--R            2 5 2     3 6
+--R       18d e f g  - 6e f g
+--R                                         Type: Union(Expression(Integer),...)
+--E 1363
+
+--S 1364 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                         n
+--R        b log(c (e x + d) ) - b n log(e x + d) - b log(c)
+--R   (4)  -------------------------------------------------
+--R                   4 3       3 2     2 2      3
+--R                 3g x  + 9f g x  + 9f g x + 3f g
+--R                                                    Type: Expression(Integer)
+--E 1364
+
+--S 1365 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1365
+
+)clear all
+
+--S 1366 of 5341
+t0:=(f+g*x)^m*(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R   (1)
+--R      2         m               n 2                 m               n
+--R     b (g x + f) log(c (e x + d) )  + 2a b (g x + f) log(c (e x + d) )
+--R   + 
+--R      2         m
+--R     a (g x + f)
+--R                                                    Type: Expression(Integer)
+--E 1366
+
+--S 1367 of 5341
+--r0:=a^2*(f+g*x)^(1+m)/(g*(1+m))+2*a*b*e*n*(f+g*x)^(2+m)*_
+--   hypergeometric(1,2+m,3+m,e*(f+g*x)/(e*f-d*g))/(g*(e*f-d*g)*(1+m)*_
+--   (2+m))+b^2*Int((f+g*x)^m*log(c*(d+e*x)^n)^2,x)+2*a*b*(f+g*x)^(1+m)*_
+--   log(c*(d+e*x)^n)/(g*(1+m))
+--E 1367
+
+--S 1368 of 5341
+--a0:=integrate(t0,x)
+--E 1368
+
+--S 1369 of 5341
+--m0:=a0-r0
+--E 1369
+
+--S 1370 of 5341
+--d0:=D(m0,x)
+--E 1370
+
+)clear all
+
+--S 1371 of 5341
+t0:=(f+g*x)^3*(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R   (1)
+--R       2 3 3     2   2 2     2 2       2 3                n 2
+--R     (b g x  + 3b f g x  + 3b f g x + b f )log(c (e x + d) )
+--R   + 
+--R            3 3           2 2         2            3                n     2 3 3
+--R     (2a b g x  + 6a b f g x  + 6a b f g x + 2a b f )log(c (e x + d) ) + a g x
+--R   + 
+--R       2   2 2     2 2       2 3
+--R     3a f g x  + 3a f g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1371
+
+--S 1372 of 5341
+r0:=-1/2*a*b*(e*f-d*g)^3*n*x/e^3+25/24*b^2*(e*f-d*g)^3*n^2*x/e^3+_
+   13/48*b^2*(e*f-d*g)^2*n^2*(f+g*x)^2/(e^2*g)+7/72*b^2*(e*f-d*g)*n^2*_
+   (f+g*x)^3/(e*g)+1/32*b^2*n^2*(f+g*x)^4/g+13/24*b^2*(e*f-d*g)^4*n^2*_
+   log(d+e*x)/(e^4*g)-1/2*b^2*(e*f-d*g)^3*n*(d+e*x)*log(c*(d+e*x)^n)/e^4-_
+   1/4*b*(e*f-d*g)^2*n*(f+g*x)^2*(a+b*log(c*(d+e*x)^n))/(e^2*g)-_
+   1/6*b*(e*f-d*g)*n*(f+g*x)^3*(a+b*log(c*(d+e*x)^n))/(e*g)-1/8*b*n*_
+   (f+g*x)^4*(a+b*log(c*(d+e*x)^n))/g+1/4*(e*f-d*g)^3*(d+e*x)*(a+b*_
+   log(c*(d+e*x)^n))^2/e^4+1/4*(e*f-d*g)^2*(d+e*x)*(f+g*x)*(a+b*log(c*_
+   (d+e*x)^n))^2/e^3+1/4*(e*f-d*g)*(d+e*x)*(f+g*x)^2*(a+b*log(c*(d+_
+   e*x)^n))^2/e^2+1/4*(d+e*x)*(f+g*x)^3*(a+b*log(c*(d+e*x)^n))^2/e
+--R 
+--R
+--R   (2)
+--R              2 4 4 4       2 4   3 3       2 4 2 2 2       2 4 3         2 4 4
+--R           72b e g x  + 288b e f g x  + 432b e f g x  + 288b e f g x - 72b d g
+--R         + 
+--R               2 3     3       2 2 2 2 2       2   3 3
+--R           288b d e f g  - 432b d e f g  + 288b d e f g
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R                 2 4 4            4 4  4
+--R           (- 36b e g n + 144a b e g )x
+--R         + 
+--R                2   3 4       2 4   3             4   3  3
+--R           ((48b d e g  - 192b e f g )n + 576a b e f g )x
+--R         + 
+--R                  2 2 2 4       2   3   3       2 4 2 2             4 2 2  2
+--R           ((- 72b d e g  + 288b d e f g  - 432b e f g )n + 864a b e f g )x
+--R         + 
+--R                    2 3   4       2 2 2   3       2   3 2 2       2 4 3
+--R               (144b d e g  - 576b d e f g  + 864b d e f g  - 576b e f g)n
+--R             + 
+--R                       4 3
+--R               576a b e f g
+--R          *
+--R             x
+--R         + 
+--R                     2 4 4       2 3     3       2 2 2 2 2      2   3 3
+--R                 144b d g  - 432b d e f g  + 360b d e f g  + 48b d e f g
+--R               + 
+--R                       2 4 4
+--R                 - 156b e f
+--R          *
+--R             n
+--R         + 
+--R                     4 4           3     3           2 2 2 2             3 3
+--R           - 144a b d g  + 576a b d e f g  - 864a b d e f g  + 576a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R              2 4 4       2 3     3       2 2 2 2 2       2   3 3        2 4 4
+--R         (156b d g  - 624b d e f g  + 936b d e f g  - 624b d e f g + 156b e f )
+--R      *
+--R          2
+--R         n log(e x + d)
+--R     + 
+--R          2 4 4 2          4 4       2 4 4  4
+--R       (9b e g n  - 36a b e g n + 72a e g )x
+--R     + 
+--R                 2   3 4      2 4   3  2             3 4           4   3
+--R           (- 28b d e g  + 64b e f g )n  + (48a b d e g  - 192a b e f g )n
+--R         + 
+--R               2 4   3
+--R           288a e f g
+--R      *
+--R          3
+--R         x
+--R     + 
+--R               2 2 2 4       2   3   3       2 4 2 2  2
+--R           (78b d e g  - 240b d e f g  + 216b e f g )n
+--R         + 
+--R                     2 2 4             3   3           4 2 2         2 4 2 2
+--R           (- 72a b d e g  + 288a b d e f g  - 432a b e f g )n + 432a e f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  2 3   4        2 2 2   3        2   3 2 2       2 4 3   2
+--R           (- 300b d e g  + 1056b d e f g  - 1296b d e f g  + 576b e f g)n
+--R         + 
+--R                    3   4           2 2   3             3 2 2           4 3
+--R           (144a b d e g  - 576a b d e f g  + 864a b d e f g  - 576a b e f g)n
+--R         + 
+--R               2 4 3
+--R           288a e f g
+--R      *
+--R         x
+--R     + 
+--R           2 2 2 2 2       2   3 3        2 4 4  2
+--R       (78b d e f g  - 184b d e f g + 115b e f )n
+--R     + 
+--R                 2 2 2 2             3 3            4 4        2 4 4
+--R       (- 72a b d e f g  + 192a b d e f g - 156a b e f )n - 72a d g
+--R     + 
+--R           2 3     3       2 2 2 2 2       2   3 3
+--R       288a d e f g  - 432a d e f g  + 288a d e f g
+--R  /
+--R         4
+--R     288e g
+--R                                                    Type: Expression(Integer)
+--E 1372
+
+--S 1373 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 4 3 2 4       2 4   2 2 3       2 4 2   2 2       2 4 3 2
+--R           72b e g n x  + 288b e f g n x  + 432b e f g n x  + 288b e f n x
+--R         + 
+--R                 2 4 3       2 3     2       2 2 2 2        2   3 3  2
+--R           (- 72b d g  + 288b d e f g  - 432b d e f g + 288b d e f )n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R                   2 4 3   4       2 4   2   3       2 4 2     2       2 4 3
+--R               144b e g n x  + 576b e f g n x  + 864b e f g n x  + 576b e f n x
+--R             + 
+--R                      2 4 3       2 3     2       2 2 2 2        2   3 3
+--R               (- 144b d g  + 576b d e f g  - 864b d e f g + 576b d e f )n
+--R          *
+--R             log(c)
+--R         + 
+--R                 2 4 3 2           4 3   4
+--R           (- 36b e g n  + 144a b e g n)x
+--R         + 
+--R                2   3 3       2 4   2  2           4   2   3
+--R           ((48b d e g  - 192b e f g )n  + 576a b e f g n)x
+--R         + 
+--R                  2 2 2 3       2   3   2       2 4 2   2           4 2     2
+--R           ((- 72b d e g  + 288b d e f g  - 432b e f g)n  + 864a b e f g n)x
+--R         + 
+--R                    2 3   3       2 2 2   2       2   3 2        2 4 3  2
+--R               (144b d e g  - 576b d e f g  + 864b d e f g - 576b e f )n
+--R             + 
+--R                       4 3
+--R               576a b e f n
+--R          *
+--R             x
+--R         + 
+--R                2 4 3        2 3     2        2 2 2 2        2   3 3  2
+--R           (300b d g  - 1056b d e f g  + 1296b d e f g - 576b d e f )n
+--R         + 
+--R                      4 3           3     2           2 2 2              3 3
+--R           (- 144a b d g  + 576a b d e f g  - 864a b d e f g + 576a b d e f )n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 4 3 4       2 4   2 3       2 4 2   2       2 4 3        2
+--R       (72b e g x  + 288b e f g x  + 432b e f g x  + 288b e f x)log(c)
+--R     + 
+--R                 2 4 3            4 3  4
+--R           (- 36b e g n + 144a b e g )x
+--R         + 
+--R                2   3 3       2 4   2             4   2  3
+--R           ((48b d e g  - 192b e f g )n + 576a b e f g )x
+--R         + 
+--R                  2 2 2 3       2   3   2       2 4 2              4 2   2
+--R           ((- 72b d e g  + 288b d e f g  - 432b e f g)n + 864a b e f g)x
+--R         + 
+--R                    2 3   3       2 2 2   2       2   3 2        2 4 3
+--R               (144b d e g  - 576b d e f g  + 864b d e f g - 576b e f )n
+--R             + 
+--R                       4 3
+--R               576a b e f
+--R          *
+--R             x
+--R      *
+--R         log(c)
+--R     + 
+--R          2 4 3 2          4 3       2 4 3  4
+--R       (9b e g n  - 36a b e g n + 72a e g )x
+--R     + 
+--R                 2   3 3      2 4   2  2             3 3           4   2
+--R           (- 28b d e g  + 64b e f g )n  + (48a b d e g  - 192a b e f g )n
+--R         + 
+--R               2 4   2
+--R           288a e f g
+--R      *
+--R          3
+--R         x
+--R     + 
+--R               2 2 2 3       2   3   2       2 4 2   2
+--R           (78b d e g  - 240b d e f g  + 216b e f g)n
+--R         + 
+--R                     2 2 3             3   2           4 2          2 4 2
+--R           (- 72a b d e g  + 288a b d e f g  - 432a b e f g)n + 432a e f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  2 3   3        2 2 2   2        2   3 2        2 4 3  2
+--R           (- 300b d e g  + 1056b d e f g  - 1296b d e f g + 576b e f )n
+--R         + 
+--R                    3   3           2 2   2             3 2            4 3
+--R           (144a b d e g  - 576a b d e f g  + 864a b d e f g - 576a b e f )n
+--R         + 
+--R               2 4 3
+--R           288a e f
+--R      *
+--R         x
+--R  /
+--R         4
+--R     288e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1373
+
+--S 1374 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2 4 4 4       2 4   3 3       2 4 2 2 2       2 4 3
+--R           - 72b e g x  - 288b e f g x  - 432b e f g x  - 288b e f g x
+--R         + 
+--R              2 4 4       2 3     3       2 2 2 2 2       2   3 3
+--R           72b d g  - 288b d e f g  + 432b d e f g  - 288b d e f g
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R               2 4 4            4 4  4
+--R           (36b e g n - 144a b e g )x
+--R         + 
+--R                  2   3 4       2 4   3             4   3  3
+--R           ((- 48b d e g  + 192b e f g )n - 576a b e f g )x
+--R         + 
+--R                2 2 2 4       2   3   3       2 4 2 2             4 2 2  2
+--R           ((72b d e g  - 288b d e f g  + 432b e f g )n - 864a b e f g )x
+--R         + 
+--R                      2 3   4       2 2 2   3       2   3 2 2       2 4 3
+--R               (- 144b d e g  + 576b d e f g  - 864b d e f g  + 576b e f g)n
+--R             + 
+--R                         4 3
+--R               - 576a b e f g
+--R          *
+--R             x
+--R         + 
+--R                     2 4 4       2 3     3       2 2 2 2 2      2   3 3
+--R               - 144b d g  + 432b d e f g  - 360b d e f g  - 48b d e f g
+--R             + 
+--R                   2 4 4
+--R               156b e f
+--R          *
+--R             n
+--R         + 
+--R                   4 4           3     3           2 2 2 2             3 3
+--R           144a b d g  - 576a b d e f g  + 864a b d e f g  - 576a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R              2 4 4 2 4       2 4   3 2 3       2 4 2 2 2 2       2 4 3   2
+--R           72b e g n x  + 288b e f g n x  + 432b e f g n x  + 288b e f g n x
+--R         + 
+--R                 2 4 4       2 3     3       2 2 2 2 2       2   3 3   2
+--R           (- 72b d g  + 288b d e f g  - 432b d e f g  + 288b d e f g)n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R                   2 4 4   4       2 4   3   3       2 4 2 2   2
+--R               144b e g n x  + 576b e f g n x  + 864b e f g n x
+--R             + 
+--R                   2 4 3
+--R               576b e f g n x
+--R             + 
+--R                      2 4 4       2 3     3       2 2 2 2 2       2   3 3
+--R               (- 144b d g  + 576b d e f g  - 864b d e f g  + 576b d e f g)n
+--R          *
+--R             log(c)
+--R         + 
+--R                 2 4 4 2           4 4   4
+--R           (- 36b e g n  + 144a b e g n)x
+--R         + 
+--R                2   3 4       2 4   3  2           4   3   3
+--R           ((48b d e g  - 192b e f g )n  + 576a b e f g n)x
+--R         + 
+--R                  2 2 2 4       2   3   3       2 4 2 2  2           4 2 2   2
+--R           ((- 72b d e g  + 288b d e f g  - 432b e f g )n  + 864a b e f g n)x
+--R         + 
+--R                    2 3   4       2 2 2   3       2   3 2 2       2 4 3   2
+--R               (144b d e g  - 576b d e f g  + 864b d e f g  - 576b e f g)n
+--R             + 
+--R                       4 3
+--R               576a b e f g n
+--R          *
+--R             x
+--R         + 
+--R                     2 4 4       2 3     3       2 2 2 2 2      2   3 3
+--R                 144b d g  - 432b d e f g  + 360b d e f g  + 48b d e f g
+--R               + 
+--R                       2 4 4
+--R                 - 156b e f
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                    4 4           3     3           2 2 2 2             3 3
+--R         (- 144a b d g  + 576a b d e f g  - 864a b d e f g  + 576a b d e f g)n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 4 4 4       2 4   3 3       2 4 2 2 2       2 4 3          2
+--R       (72b e g x  + 288b e f g x  + 432b e f g x  + 288b e f g x)log(c)
+--R     + 
+--R                 2 4 4            4 4  4
+--R           (- 36b e g n + 144a b e g )x
+--R         + 
+--R                2   3 4       2 4   3             4   3  3
+--R           ((48b d e g  - 192b e f g )n + 576a b e f g )x
+--R         + 
+--R                  2 2 2 4       2   3   3       2 4 2 2             4 2 2  2
+--R           ((- 72b d e g  + 288b d e f g  - 432b e f g )n + 864a b e f g )x
+--R         + 
+--R                    2 3   4       2 2 2   3       2   3 2 2       2 4 3
+--R               (144b d e g  - 576b d e f g  + 864b d e f g  - 576b e f g)n
+--R             + 
+--R                       4 3
+--R               576a b e f g
+--R          *
+--R             x
+--R      *
+--R         log(c)
+--R     + 
+--R             2 2 2 2 2       2   3 3        2 4 4  2
+--R       (- 78b d e f g  + 184b d e f g - 115b e f )n
+--R     + 
+--R               2 2 2 2             3 3            4 4        2 4 4
+--R       (72a b d e f g  - 192a b d e f g + 156a b e f )n + 72a d g
+--R     + 
+--R             2 3     3       2 2 2 2 2       2   3 3
+--R       - 288a d e f g  + 432a d e f g  - 288a d e f g
+--R  /
+--R         4
+--R     288e g
+--R                                                    Type: Expression(Integer)
+--E 1374
+
+--S 1375 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1375
+
+)clear all
+
+--S 1376 of 5341
+t0:=(f+g*x)^2*(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R   (1)
+--R       2 2 2     2         2 2                n 2
+--R     (b g x  + 2b f g x + b f )log(c (e x + d) )
+--R   + 
+--R            2 2                      2                n     2 2 2     2
+--R     (2a b g x  + 4a b f g x + 2a b f )log(c (e x + d) ) + a g x  + 2a f g x
+--R   + 
+--R      2 2
+--R     a f
+--R                                                    Type: Expression(Integer)
+--E 1376
+
+--S 1377 of 5341
+r0:=-2/3*a*b*(e*f-d*g)^2*n*x/e^2+11/9*b^2*(e*f-d*g)^2*n^2*x/e^2+_
+   5/18*b^2*(e*f-d*g)*n^2*(f+g*x)^2/(e*g)+2/27*b^2*n^2*(f+g*x)^3/g+_
+   5/9*b^2*(e*f-d*g)^3*n^2*log(d+e*x)/(e^3*g)-2/3*b^2*(e*f-d*g)^2*n*_
+   (d+e*x)*log(c*(d+e*x)^n)/e^3-1/3*b*(e*f-d*g)*n*(f+g*x)^2*(a+b*log(c*_
+   (d+e*x)^n))/(e*g)-2/9*b*n*(f+g*x)^3*(a+b*log(c*(d+e*x)^n))/g+1/3*(e*f-_
+   d*g)^2*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/e^3+1/3*(e*f-d*g)*(d+e*x)*_
+   (f+g*x)*(a+b*log(c*(d+e*x)^n))^2/e^2+1/3*(d+e*x)*(f+g*x)^2*(a+b*_
+   log(c*(d+e*x)^n))^2/e
+--R 
+--R
+--R   (2)
+--R              2 3 3 3      2 3   2 2      2 3 2         2 3 3      2 2     2
+--R           18b e g x  + 54b e f g x  + 54b e f g x + 18b d g  - 54b d e f g
+--R         + 
+--R              2   2 2
+--R           54b d e f g
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R                 2 3 3           3 3  3
+--R           (- 12b e g n + 36a b e g )x
+--R         + 
+--R                2   2 3      2 3   2             3   2  2
+--R           ((18b d e g  - 54b e f g )n + 108a b e f g )x
+--R         + 
+--R                  2 2   3       2   2   2       2 3 2              3 2
+--R           ((- 36b d e g  + 108b d e f g  - 108b e f g)n + 108a b e f g)x
+--R         + 
+--R                 2 3 3      2 2     2      2   2 2       2 3 3            3 3
+--R           (- 36b d g  + 72b d e f g  - 18b d e f g - 30b e f )n + 36a b d g
+--R         + 
+--R                     2     2             2 2
+--R           - 108a b d e f g  + 108a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R             2 3 3      2 2     2      2   2 2       2 3 3  2
+--R       (- 30b d g  + 90b d e f g  - 90b d e f g + 30b e f )n log(e x + d)
+--R     + 
+--R          2 3 3 2          3 3       2 3 3  3
+--R       (4b e g n  - 12a b e g n + 18a e g )x
+--R     + 
+--R                 2   2 3      2 3   2  2             2 3          3   2
+--R           (- 15b d e g  + 27b e f g )n  + (18a b d e g  - 54a b e f g )n
+--R         + 
+--R              2 3   2
+--R           54a e f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R               2 2   3       2   2   2       2 3 2   2
+--R           (66b d e g  - 162b d e f g  + 108b e f g)n
+--R         + 
+--R                     2   3             2   2           3 2         2 3 2
+--R           (- 36a b d e g  + 108a b d e f g  - 108a b e f g)n + 54a e f g
+--R      *
+--R         x
+--R     + 
+--R             2   2 2       2 3 3  2             2 2           3 3        2 3 3
+--R       (- 15b d e f g + 19b e f )n  + (18a b d e f g - 30a b e f )n + 18a d g
+--R     + 
+--R            2 2     2      2   2 2
+--R       - 54a d e f g  + 54a d e f g
+--R  /
+--R        3
+--R     54e g
+--R                                                    Type: Expression(Integer)
+--E 1377
+
+--S 1378 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 3 2 2 3      2 3     2 2      2 3 2 2
+--R           18b e g n x  + 54b e f g n x  + 54b e f n x
+--R         + 
+--R               2 3 2      2 2           2   2 2  2
+--R           (18b d g  - 54b d e f g + 54b d e f )n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R                  2 3 2   3       2 3       2       2 3 2
+--R               36b e g n x  + 108b e f g n x  + 108b e f n x
+--R             + 
+--R                   2 3 2       2 2            2   2 2
+--R               (36b d g  - 108b d e f g + 108b d e f )n
+--R          *
+--R             log(c)
+--R         + 
+--R                 2 3 2 2          3 2   3
+--R           (- 12b e g n  + 36a b e g n)x
+--R         + 
+--R                2   2 2      2 3     2           3       2
+--R           ((18b d e g  - 54b e f g)n  + 108a b e f g n)x
+--R         + 
+--R                  2 2   2       2   2          2 3 2  2           3 2
+--R           ((- 36b d e g  + 108b d e f g - 108b e f )n  + 108a b e f n)x
+--R         + 
+--R                 2 3 2       2 2            2   2 2  2
+--R           (- 66b d g  + 162b d e f g - 108b d e f )n
+--R         + 
+--R                   3 2           2                  2 2
+--R           (36a b d g  - 108a b d e f g + 108a b d e f )n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 3 2 3      2 3     2      2 3 2        2
+--R       (18b e g x  + 54b e f g x  + 54b e f x)log(c)
+--R     + 
+--R                 2 3 2           3 2  3
+--R           (- 12b e g n + 36a b e g )x
+--R         + 
+--R                2   2 2      2 3                3     2
+--R           ((18b d e g  - 54b e f g)n + 108a b e f g)x
+--R         + 
+--R                  2 2   2       2   2          2 3 2             3 2
+--R           ((- 36b d e g  + 108b d e f g - 108b e f )n + 108a b e f )x
+--R      *
+--R         log(c)
+--R     + 
+--R          2 3 2 2          3 2       2 3 2  3
+--R       (4b e g n  - 12a b e g n + 18a e g )x
+--R     + 
+--R                 2   2 2      2 3     2             2 2          3
+--R           (- 15b d e g  + 27b e f g)n  + (18a b d e g  - 54a b e f g)n
+--R         + 
+--R              2 3
+--R           54a e f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R               2 2   2       2   2          2 3 2  2
+--R           (66b d e g  - 162b d e f g + 108b e f )n
+--R         + 
+--R                     2   2             2              3 2        2 3 2
+--R           (- 36a b d e g  + 108a b d e f g - 108a b e f )n + 54a e f
+--R      *
+--R         x
+--R  /
+--R        3
+--R     54e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1378
+
+--S 1379 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                2 3 3 3      2 3   2 2      2 3 2         2 3 3      2 2     2
+--R           - 18b e g x  - 54b e f g x  - 54b e f g x - 18b d g  + 54b d e f g
+--R         + 
+--R                2   2 2
+--R           - 54b d e f g
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R               2 3 3           3 3  3
+--R           (12b e g n - 36a b e g )x
+--R         + 
+--R                  2   2 3      2 3   2             3   2  2
+--R           ((- 18b d e g  + 54b e f g )n - 108a b e f g )x
+--R         + 
+--R                2 2   3       2   2   2       2 3 2              3 2
+--R           ((36b d e g  - 108b d e f g  + 108b e f g)n - 108a b e f g)x
+--R         + 
+--R               2 3 3      2 2     2      2   2 2       2 3 3            3 3
+--R           (36b d g  - 72b d e f g  + 18b d e f g + 30b e f )n - 36a b d g
+--R         + 
+--R                   2     2             2 2
+--R           108a b d e f g  - 108a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R              2 3 3 2 3      2 3   2 2 2      2 3 2   2
+--R           18b e g n x  + 54b e f g n x  + 54b e f g n x
+--R         + 
+--R               2 3 3      2 2     2      2   2 2   2
+--R           (18b d g  - 54b d e f g  + 54b d e f g)n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R                  2 3 3   3       2 3   2   2       2 3 2
+--R               36b e g n x  + 108b e f g n x  + 108b e f g n x
+--R             + 
+--R                   2 3 3       2 2     2       2   2 2
+--R               (36b d g  - 108b d e f g  + 108b d e f g)n
+--R          *
+--R             log(c)
+--R         + 
+--R                 2 3 3 2          3 3   3
+--R           (- 12b e g n  + 36a b e g n)x
+--R         + 
+--R                2   2 3      2 3   2  2           3   2   2
+--R           ((18b d e g  - 54b e f g )n  + 108a b e f g n)x
+--R         + 
+--R                  2 2   3       2   2   2       2 3 2   2           3 2
+--R           ((- 36b d e g  + 108b d e f g  - 108b e f g)n  + 108a b e f g n)x
+--R         + 
+--R                 2 3 3      2 2     2      2   2 2       2 3 3  2
+--R           (- 36b d g  + 72b d e f g  - 18b d e f g - 30b e f )n
+--R         + 
+--R                   3 3           2     2             2 2
+--R           (36a b d g  - 108a b d e f g  + 108a b d e f g)n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           2 3 3 3      2 3   2 2      2 3 2          2
+--R       (18b e g x  + 54b e f g x  + 54b e f g x)log(c)
+--R     + 
+--R                 2 3 3           3 3  3
+--R           (- 12b e g n + 36a b e g )x
+--R         + 
+--R                2   2 3      2 3   2             3   2  2
+--R           ((18b d e g  - 54b e f g )n + 108a b e f g )x
+--R         + 
+--R                  2 2   3       2   2   2       2 3 2              3 2
+--R           ((- 36b d e g  + 108b d e f g  - 108b e f g)n + 108a b e f g)x
+--R      *
+--R         log(c)
+--R     + 
+--R           2   2 2       2 3 3  2               2 2           3 3        2 3 3
+--R       (15b d e f g - 19b e f )n  + (- 18a b d e f g + 30a b e f )n - 18a d g
+--R     + 
+--R          2 2     2      2   2 2
+--R       54a d e f g  - 54a d e f g
+--R  /
+--R        3
+--R     54e g
+--R                                                    Type: Expression(Integer)
+--E 1379
+
+--S 1380 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1380
+
+)clear all
+
+--S 1381 of 5341
+t0:=(f+g*x)*(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R   (1)
+--R       2       2                 n 2                                     n
+--R     (b g x + b f)log(c (e x + d) )  + (2a b g x + 2a b f)log(c (e x + d) )
+--R   + 
+--R      2       2
+--R     a g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1381
+
+--S 1382 of 5341
+r0:=-a*b*(e*f-d*g)*n*x/e+3/2*b^2*(e*f-d*g)*n^2*x/e+1/4*b^2*n^2*(f+g*x)^2/g+_
+   1/2*b^2*(e*f-d*g)^2*n^2*log(d+e*x)/(e^2*g)-b^2*(e*f-d*g)*n*(d+e*x)*_
+   log(c*(d+e*x)^n)/e^2-1/2*b*n*(f+g*x)^2*(a+b*log(c*(d+e*x)^n))/g+_
+   1/2*(e*f-d*g)*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/e^2+1/2*(d+e*x)*(f+g*x)*_
+   (a+b*log(c*(d+e*x)^n))^2/e
+--R 
+--R
+--R   (2)
+--R          2 2 2 2     2 2          2 2 2     2                       n 2
+--R       (2b e g x  + 4b e f g x - 2b d g  + 4b d e f g)log(c (e x + d) )
+--R     + 
+--R                2 2 2          2 2  2       2     2     2 2              2
+--R           (- 2b e g n + 4a b e g )x  + ((4b d e g  - 8b e f g)n + 8a b e f g)x
+--R         + 
+--R              2 2 2     2            2 2 2           2 2
+--R           (4b d g  - 4b d e f g - 2b e f )n - 4a b d g  + 8a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R          2 2 2     2            2 2 2  2
+--R       (2b d g  - 4b d e f g + 2b e f )n log(e x + d)
+--R     + 
+--R         2 2 2 2         2 2      2 2 2  2
+--R       (b e g n  - 2a b e g n + 2a e g )x
+--R     + 
+--R             2     2     2 2     2              2         2          2 2
+--R       ((- 6b d e g  + 8b e f g)n  + (4a b d e g  - 8a b e f g)n + 4a e f g)x
+--R     + 
+--R        2 2 2 2         2 2      2 2 2     2
+--R       b e f n  - 2a b e f n - 2a d g  + 4a d e f g
+--R  /
+--R       2
+--R     4e g
+--R                                                    Type: Expression(Integer)
+--E 1382
+
+--S 1383 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2   2 2     2 2   2         2 2      2       2             2
+--R       (2b e g n x  + 4b e f n x + (- 2b d g + 4b d e f)n )log(e x + d)
+--R     + 
+--R              2 2     2     2 2             2 2      2
+--R           (4b e g n x  + 8b e f n x + (- 4b d g + 8b d e f)n)log(c)
+--R         + 
+--R                2 2   2         2     2       2          2 2   2         2
+--R           (- 2b e g n  + 4a b e g n)x  + ((4b d e g - 8b e f)n  + 8a b e f n)x
+--R         + 
+--R              2 2      2       2            2
+--R           (6b d g - 8b d e f)n  + (- 4a b d g + 8a b d e f)n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R          2 2   2     2 2          2
+--R       (2b e g x  + 4b e f x)log(c)
+--R     + 
+--R             2 2            2   2       2          2 2            2
+--R       ((- 2b e g n + 4a b e g)x  + ((4b d e g - 8b e f)n + 8a b e f)x)log(c)
+--R     + 
+--R         2 2   2         2        2 2   2
+--R       (b e g n  - 2a b e g n + 2a e g)x
+--R     + 
+--R             2          2 2   2                       2        2 2
+--R       ((- 6b d e g + 8b e f)n  + (4a b d e g - 8a b e f)n + 4a e f)x
+--R  /
+--R       2
+--R     4e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1383
+
+--S 1384 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            2 2 2 2     2 2          2 2 2     2                       n 2
+--R       (- 2b e g x  - 4b e f g x + 2b d g  - 4b d e f g)log(c (e x + d) )
+--R     + 
+--R              2 2 2          2 2  2         2     2     2 2              2
+--R           (2b e g n - 4a b e g )x  + ((- 4b d e g  + 8b e f g)n - 8a b e f g)x
+--R         + 
+--R                2 2 2     2            2 2 2           2 2
+--R           (- 4b d g  + 4b d e f g + 2b e f )n + 4a b d g  - 8a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R          2 2 2 2 2     2 2     2         2 2 2     2         2             2
+--R       (2b e g n x  + 4b e f g n x + (- 2b d g  + 4b d e f g)n )log(e x + d)
+--R     + 
+--R              2 2 2   2     2 2               2 2 2     2
+--R           (4b e g n x  + 8b e f g n x + (- 4b d g  + 8b d e f g)n)log(c)
+--R         + 
+--R                2 2 2 2         2 2   2
+--R           (- 2b e g n  + 4a b e g n)x
+--R         + 
+--R               2     2     2 2     2         2
+--R           ((4b d e g  - 8b e f g)n  + 8a b e f g n)x
+--R         + 
+--R              2 2 2     2            2 2 2  2            2 2
+--R           (4b d g  - 4b d e f g - 2b e f )n  + (- 4a b d g  + 8a b d e f g)n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R          2 2 2 2     2 2            2
+--R       (2b e g x  + 4b e f g x)log(c)
+--R     + 
+--R               2 2 2          2 2  2       2     2     2 2              2
+--R         ((- 2b e g n + 4a b e g )x  + ((4b d e g  - 8b e f g)n + 8a b e f g)x)
+--R      *
+--R         log(c)
+--R     + 
+--R          2 2 2 2         2 2      2 2 2     2
+--R       - b e f n  + 2a b e f n + 2a d g  - 4a d e f g
+--R  /
+--R       2
+--R     4e g
+--R                                                    Type: Expression(Integer)
+--E 1384
+
+--S 1385 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1385
+
+)clear all
+
+--S 1386 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R         2               n 2                       n     2
+--R   (1)  b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1386
+
+--S 1387 of 5341
+r0:=-2*a*b*n*x+2*b^2*n^2*x-2*b^2*n*(d+e*x)*log(c*(d+e*x)^n)/e+(d+e*x)*_
+   (a+b*log(c*(d+e*x)^n))^2/e
+--R 
+--R
+--R   (2)
+--R         2       2                 n 2
+--R       (b e x + b d)log(c (e x + d) )
+--R     + 
+--R             2                   2                            n
+--R       ((- 2b e n + 2a b e)x - 2b d n + 2a b d)log(c (e x + d) )
+--R     + 
+--R          2   2               2       2
+--R       (2b e n  - 2a b e n + a e)x + a d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 1387
+
+--S 1388 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2   2     2   2             2
+--R       (b e n x + b d n )log(e x + d)
+--R     + 
+--R              2          2                  2   2                  2   2
+--R           (2b e n x + 2b d n)log(c) + (- 2b e n  + 2a b e n)x - 2b d n
+--R         + 
+--R           2a b d n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R      2          2        2                           2   2               2
+--R     b e x log(c)  + (- 2b e n + 2a b e)x log(c) + (2b e n  - 2a b e n + a e)x
+--R  /
+--R     e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1388
+
+--S 1389 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2       2                 n 2
+--R       (- b e x - b d)log(c (e x + d) )
+--R     + 
+--R           2                   2                            n
+--R       ((2b e n - 2a b e)x + 2b d n - 2a b d)log(c (e x + d) )
+--R     + 
+--R         2   2     2   2             2
+--R       (b e n x + b d n )log(e x + d)
+--R     + 
+--R              2          2                  2   2                  2   2
+--R           (2b e n x + 2b d n)log(c) + (- 2b e n  + 2a b e n)x - 2b d n
+--R         + 
+--R           2a b d n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R        2          2        2                         2
+--R       b e x log(c)  + (- 2b e n + 2a b e)x log(c) - a d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 1389
+
+--S 1390 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1390
+
+)clear all
+
+--S 1391 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^2/(f+g*x)
+--R 
+--R
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R   (1)  --------------------------------------------------
+--R                              g x + f
+--R                                                    Type: Expression(Integer)
+--E 1391
+
+--S 1392 of 5341
+--r0:=(a+b*log(c*(d+e*x)^n))^2*log(e*(f+g*x)/(e*f-d*g))/g+2*b*n*(a+_
+--   b*log(c*(d+e*x)^n))*polylog(2,-g*(d+e*x)/(e*f-d*g))/g-2*b^2*n^2*_
+--   polylog(3,-g*(d+e*x)/(e*f-d*g))/g
+--E 1392
+
+--S 1393 of 5341
+--a0:=integrate(t0,x)
+--E 1393
+
+--S 1394 of 5341
+--m0:=a0-r0
+--E 1394
+
+--S 1395 of 5341
+--d0:=D(m0,x)
+--E 1395
+
+)clear all
+
+--S 1396 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^2/(f+g*x)^2
+--R 
+--R
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R   (1)  --------------------------------------------------
+--R                         2 2             2
+--R                        g x  + 2f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1396
+
+--S 1397 of 5341
+--r0:=(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/((e*f-d*g)*(f+g*x))-2*b*e*n*_
+--   (a+b*log(c*(d+e*x)^n))*log(e*(f+g*x)/(e*f-d*g))/(g*(e*f-d*g))-_
+--   2*b^2*e*n^2*polylog(2,-g*(d+e*x)/(e*f-d*g))/(g*(e*f-d*g))
+--E 1397
+
+--S 1398 of 5341
+--a0:=integrate(t0,x)
+--E 1398
+
+--S 1399 of 5341
+--m0:=a0-r0
+--E 1399
+
+--S 1400 of 5341
+--d0:=D(m0,x)
+--E 1400
+
+)clear all
+
+--S 1401 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^2/(f+g*x)^3
+--R 
+--R
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R   (1)  --------------------------------------------------
+--R                    3 3       2 2     2       3
+--R                   g x  + 3f g x  + 3f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1401
+
+--S 1402 of 5341
+--r0:=-b^2*e^2*n^2*log(d+e*x)/(g*(e*f-d*g)^2)+b*e*n*(a+b*log(c*(d+_
+--   e*x)^n))/(g*(e*f-d*g)*(f+g*x))+1/2*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/_
+--   ((e*f-d*g)*(f+g*x)^2)+1/2*e*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/_
+--   ((e*f-d*g)^2*(f+g*x))+b^2*e^2*n^2*log(f+g*x)/(g*(e*f-d*g)^2)-_
+--   b*e^2*n*(a+b*log(c*(d+e*x)^n))*log(e*(f+g*x)/(e*f-d*g))/_
+--   (g*(e*f-d*g)^2)-b^2*e^2*n^2*polylog(2,-g*(d+e*x)/(e*f-d*g))/_
+--   (g*(e*f-d*g)^2)
+--E 1402
+
+--S 1403 of 5341
+--a0:=integrate(t0,x)
+--E 1403
+
+--S 1404 of 5341
+--m0:=a0-r0
+--E 1404
+
+--S 1405 of 5341
+--d0:=D(m0,x)
+--E 1405
+
+)clear all
+
+--S 1406 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^2/(f+g*x)^4
+--R 
+--R
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R   (1)  --------------------------------------------------
+--R               4 4       3 3     2 2 2     3       4
+--R              g x  + 4f g x  + 6f g x  + 4f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1406
+
+--S 1407 of 5341
+--r0:=-1/3*b^2*e^2*n^2/(g*(e*f-d*g)^2*(f+g*x))-b^2*e^3*n^2*log(d+e*x)/_
+--   (g*(e*f-d*g)^3)+1/3*b*e*n*(a+b*log(c*(d+e*x)^n))/(g*(e*f-d*g)*_
+--   (f+g*x)^2)+2/3*b*e^2*n*(a+b*log(c*(d+e*x)^n))/(g*(e*f-d*g)^2*(f+g*x))+_
+--   1/3*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/((e*f-d*g)*(f+g*x)^3)+_
+--   1/3*e*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/((e*f-d*g)^2*(f+g*x)^2)+_
+--   1/3*e^2*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/((e*f-d*g)^3*(f+g*x))+_
+--   b^2*e^3*n^2*log(f+g*x)/(g*(e*f-d*g)^3)-2/3*b*e^3*n*(a+b*log(c*_
+--   (d+e*x)^n))*log(e*(f+g*x)/(e*f-d*g))/(g*(e*f-d*g)^3)-_
+--   2/3*b^2*e^3*n^2*polylog(2,-g*(d+e*x)/(e*f-d*g))/(g*(e*f-d*g)^3)
+--E 1407
+
+--S 1408 of 5341
+--a0:=integrate(t0,x)
+--E 1408
+
+--S 1409 of 5341
+--m0:=a0-r0
+--E 1409
+
+--S 1410 of 5341
+--d0:=D(m0,x)
+--E 1410
+
+)clear all
+
+--S 1411 of 5341
+t0:=(f+g*x)^m*(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R      3         m               n 3       2         m               n 2
+--R     b (g x + f) log(c (e x + d) )  + 3a b (g x + f) log(c (e x + d) )
+--R   + 
+--R       2           m               n     3         m
+--R     3a b (g x + f) log(c (e x + d) ) + a (g x + f)
+--R                                                    Type: Expression(Integer)
+--E 1411
+
+--S 1412 of 5341
+--r0:=a^3*(f+g*x)^(1+m)/(g*(1+m))+3*a^2*b*e*n*(f+g*x)^(2+m)*_
+--   hypergeometric(1,2+m,3+m,e*(f+g*x)/(e*f-d*g))/(g*(e*f-d*g)*(1+m)*_
+--   (2+m))+3*a*b^2*Int((f+g*x)^m*log(c*(d+e*x)^n)^2,x)+b^3*Int((f+g*x)^m*_
+--   log(c*(d+e*x)^n)^3,x)+3*a^2*b*(f+g*x)^(1+m)*log(c*(d+e*x)^n)/(g*(1+m))
+--E 1412
+
+--S 1413 of 5341
+--a0:=integrate(t0,x)
+--E 1413
+
+--S 1414 of 5341
+--m0:=a0-r0
+--E 1414
+
+--S 1415 of 5341
+--d0:=D(m0,x)
+--E 1415
+
+)clear all
+
+--S 1416 of 5341
+t0:=(f+g*x)^3*(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R       3 3 3     3   2 2     3 2       3 3                n 3
+--R     (b g x  + 3b f g x  + 3b f g x + b f )log(c (e x + d) )
+--R   + 
+--R          2 3 3       2   2 2       2 2          2 3                n 2
+--R     (3a b g x  + 9a b f g x  + 9a b f g x + 3a b f )log(c (e x + d) )
+--R   + 
+--R        2   3 3     2     2 2     2   2        2   3                n     3 3 3
+--R     (3a b g x  + 9a b f g x  + 9a b f g x + 3a b f )log(c (e x + d) ) + a g x
+--R   + 
+--R       3   2 2     3 2       3 3
+--R     3a f g x  + 3a f g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1416
+
+--S 1417 of 5341
+r0:=25/8*a*b^2*(e*f-d*g)^3*n^2*x/e^3-415/96*b^3*(e*f-d*g)^3*n^3*x/e^3-_
+   115/192*b^3*(e*f-d*g)^2*n^3*(f+g*x)^2/(e^2*g)-37/288*b^3*(e*f-d*g)*n^3*_
+   (f+g*x)^3/(e*g)-3/128*b^3*n^3*(f+g*x)^4/g-115/96*b^3*(e*f-d*g)^4*n^3*_
+   log(d+e*x)/(e^4*g)+25/8*b^3*(e*f-d*g)^3*n^2*(d+e*x)*log(c*(d+e*x)^n)/e^4+_
+   13/16*b^2*(e*f-d*g)^2*n^2*(f+g*x)^2*(a+b*log(c*(d+e*x)^n))/(e^2*g)+_
+   7/24*b^2*(e*f-d*g)*n^2*(f+g*x)^3*(a+b*log(c*(d+e*x)^n))/(e*g)+3/32*b^2*_
+   n^2*(f+g*x)^4*(a+b*log(c*(d+e*x)^n))/g-25/16*b*(e*f-d*g)^3*n*(d+e*x)*_
+   (a+b*log(c*(d+e*x)^n))^2/e^4-13/16*b*(e*f-d*g)^2*n*(d+e*x)*(f+g*x)*_
+   (a+b*log(c*(d+e*x)^n))^2/e^3-7/16*b*(e*f-d*g)*n*(d+e*x)*(f+g*x)^2*_
+   (a+b*log(c*(d+e*x)^n))^2/e^2-3/16*b*n*(d+e*x)*(f+g*x)^3*(a+b*log(c*_
+   (d+e*x)^n))^2/e+1/4*(e*f-d*g)^3*(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/e^4+_
+   1/4*(e*f-d*g)^2*(d+e*x)*(f+g*x)*(a+b*log(c*(d+e*x)^n))^3/e^3+1/4*_
+   (e*f-d*g)*(d+e*x)*(f+g*x)^2*(a+b*log(c*(d+e*x)^n))^3/e^2+1/4*(d+e*x)*_
+   (f+g*x)^3*(a+b*log(c*(d+e*x)^n))^3/e
+--R 
+--R
+--R   (2)
+--R               3 4 4 4        3 4   3 3        3 4 2 2 2        3 4 3
+--R           288b e g x  + 1152b e f g x  + 1728b e f g x  + 1152b e f g x
+--R         + 
+--R                 3 4 4        3 3     3        3 2 2 2 2        3   3 3
+--R           - 288b d g  + 1152b d e f g  - 1728b d e f g  + 1152b d e f g
+--R      *
+--R                        n 3
+--R         log(c (e x + d) )
+--R     + 
+--R                  3 4 4          2 4 4  4
+--R           (- 216b e g n + 864a b e g )x
+--R         + 
+--R                 3   3 4        3 4   3            2 4   3  3
+--R           ((288b d e g  - 1152b e f g )n + 3456a b e f g )x
+--R         + 
+--R                   3 2 2 4        3   3   3        3 4 2 2            2 4 2 2  2
+--R           ((- 432b d e g  + 1728b d e f g  - 2592b e f g )n + 5184a b e f g )x
+--R         + 
+--R                    3 3   4        3 2 2   3        3   3 2 2        3 4 3
+--R               (864b d e g  - 3456b d e f g  + 5184b d e f g  - 3456b e f g)n
+--R             + 
+--R                      2 4 3
+--R               3456a b e f g
+--R          *
+--R             x
+--R         + 
+--R                 3 4 4        3 3     3        3 2 2 2 2        3   3 3
+--R           (1800b d g  - 6336b d e f g  + 7776b d e f g  - 3456b d e f g)n
+--R         + 
+--R                 2 4 4          2 3     3          2 2 2 2 2          2   3 3
+--R         - 864a b d g  + 3456a b d e f g  - 5184a b d e f g  + 3456a b d e f g
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R                3 4 4 2         2 4 4        2   4 4  4
+--R           (108b e g n  - 432a b e g n + 864a b e g )x
+--R         + 
+--R                      3   3 4       3 4   3  2
+--R               (- 336b d e g  + 768b e f g )n
+--R             + 
+--R                      2   3 4          2 4   3          2   4   3
+--R               (576a b d e g  - 2304a b e f g )n + 3456a b e f g
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    3 2 2 4        3   3   3        3 4 2 2  2
+--R               (936b d e g  - 2880b d e f g  + 2592b e f g )n
+--R             + 
+--R                        2 2 2 4          2   3   3          2 4 2 2
+--R               (- 864a b d e g  + 3456a b d e f g  - 5184a b e f g )n
+--R             + 
+--R                    2   4 2 2
+--R               5184a b e f g
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                          3 3   4         3 2 2   3         3   3 2 2
+--R                   - 3600b d e g  + 12672b d e f g  - 15552b d e f g
+--R                 + 
+--R                        3 4 3
+--R                   6912b e f g
+--R              *
+--R                  2
+--R                 n
+--R             + 
+--R                          2 3   4          2 2 2   3           2   3 2 2
+--R                   1728a b d e g  - 6912a b d e f g  + 10368a b d e f g
+--R                 + 
+--R                            2 4 3
+--R                   - 6912a b e f g
+--R              *
+--R                 n
+--R             + 
+--R                    2   4 3
+--R               3456a b e f g
+--R          *
+--R             x
+--R         + 
+--R                      3 4 4         3 3     3        3 2 2 2 2        3   3 3
+--R               - 3600b d g  + 10800b d e f g  - 9864b d e f g  + 1392b d e f g
+--R             + 
+--R                    3 4 4
+--R               1380b e f
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                      2 4 4           2 3     3           2 2 2 2 2
+--R               3600a b d g  - 12672a b d e f g  + 15552a b d e f g
+--R             + 
+--R                        2   3 3
+--R               - 6912a b d e f g
+--R          *
+--R             n
+--R         + 
+--R               2   4 4        2   3     3        2   2 2 2 2        2     3 3
+--R         - 864a b d g  + 3456a b d e f g  - 5184a b d e f g  + 3456a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R                  3 4 4        3 3     3        3 2 2 2 2        3   3 3
+--R           - 1380b d g  + 5520b d e f g  - 8280b d e f g  + 5520b d e f g
+--R         + 
+--R                  3 4 4
+--R           - 1380b e f
+--R      *
+--R          3
+--R         n log(e x + d)
+--R     + 
+--R             3 4 4 3         2 4 4 2       2   4 4        3 4 4  4
+--R       (- 27b e g n  + 108a b e g n  - 216a b e g n + 288a e g )x
+--R     + 
+--R                3   3 4       3 4   3  3            2   3 4         2 4   3  2
+--R           (148b d e g  - 256b e f g )n  + (- 336a b d e g  + 768a b e f g )n
+--R         + 
+--R                2     3 4        2   4   3          3 4   3
+--R           (288a b d e g  - 1152a b e f g )n + 1152a e f g
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                  3 2 2 4        3   3   3        3 4 2 2  3
+--R           (- 690b d e g  + 1824b d e f g  - 1296b e f g )n
+--R         + 
+--R                  2 2 2 4          2   3   3          2 4 2 2  2
+--R           (936a b d e g  - 2880a b d e f g  + 2592a b e f g )n
+--R         + 
+--R                2   2 2 4        2     3   3        2   4 2 2          3 4 2 2
+--R         (- 432a b d e g  + 1728a b d e f g  - 2592a b e f g )n + 1728a e f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 3   4         3 2 2   3         3   3 2 2        3 4 3   3
+--R           (4980b d e g  - 16320b d e f g  + 18144b d e f g  - 6912b e f g)n
+--R         + 
+--R                        2 3   4           2 2 2   3           2   3 2 2
+--R               - 3600a b d e g  + 12672a b d e f g  - 15552a b d e f g
+--R             + 
+--R                      2 4 3
+--R               6912a b e f g
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                     2   3   4        2   2 2   3        2     3 2 2
+--R                 864a b d e g  - 3456a b d e f g  + 5184a b d e f g
+--R               + 
+--R                        2   4 3
+--R                 - 3456a b e f g
+--R          *
+--R             n
+--R         + 
+--R                3 4 3
+--R           1152a e f g
+--R      *
+--R         x
+--R     + 
+--R              3 2 2 2 2        3   3 3        3 4 4  3
+--R       (- 690b d e f g  + 1528b d e f g - 865b e f )n
+--R     + 
+--R              2 2 2 2 2          2   3 3           2 4 4  2
+--R       (936a b d e f g  - 2208a b d e f g + 1380a b e f )n
+--R     + 
+--R             2   4 4        2   3     3        2   2 2 2 2        2     3 3
+--R       (1800a b d g  - 6336a b d e f g  + 7776a b d e f g  - 3456a b d e f g)n
+--R     + 
+--R             3 4 4        3 3     3        3 2 2 2 2        3   3 3
+--R       - 288a d g  + 1152a d e f g  - 1728a d e f g  + 1152a d e f g
+--R  /
+--R          4
+--R     1152e g
+--R                                                    Type: Expression(Integer)
+--E 1417
+
+--S 1418 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 4 3 3 4        3 4   2 3 3        3 4 2   3 2        3 4 3 3
+--R           288b e g n x  + 1152b e f g n x  + 1728b e f g n x  + 1152b e f n x
+--R         + 
+--R                  3 4 3        3 3     2        3 2 2 2         3   3 3  3
+--R           (- 288b d g  + 1152b d e f g  - 1728b d e f g + 1152b d e f )n
+--R      *
+--R                     3
+--R         log(e x + d)
+--R     + 
+--R                   3 4 3 2 4        3 4   2 2 3        3 4 2   2 2
+--R               864b e g n x  + 3456b e f g n x  + 5184b e f g n x
+--R             + 
+--R                    3 4 3 2
+--R               3456b e f n x
+--R             + 
+--R                      3 4 3        3 3     2        3 2 2 2         3   3 3  2
+--R               (- 864b d g  + 3456b d e f g  - 5184b d e f g + 3456b d e f )n
+--R          *
+--R             log(c)
+--R         + 
+--R                  3 4 3 3         2 4 3 2  4
+--R           (- 216b e g n  + 864a b e g n )x
+--R         + 
+--R                 3   3 3        3 4   2  3          2 4   2 2  3
+--R           ((288b d e g  - 1152b e f g )n  + 3456a b e f g n )x
+--R         + 
+--R                        3 2 2 3        3   3   2        3 4 2   3
+--R                 (- 432b d e g  + 1728b d e f g  - 2592b e f g)n
+--R               + 
+--R                        2 4 2   2
+--R                 5184a b e f g n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 3   3        3 2 2   2        3   3 2         3 4 3  3
+--R               (864b d e g  - 3456b d e f g  + 5184b d e f g - 3456b e f )n
+--R             + 
+--R                      2 4 3 2
+--R               3456a b e f n
+--R          *
+--R             x
+--R         + 
+--R                 3 4 3        3 3     2        3 2 2 2         3   3 3  3
+--R           (1800b d g  - 6336b d e f g  + 7776b d e f g - 3456b d e f )n
+--R         + 
+--R                  2 4 3          2 3     2          2 2 2 2           2   3 3  2
+--R         (- 864a b d g  + 3456a b d e f g  - 5184a b d e f g + 3456a b d e f )n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R                   3 4 3   4        3 4   2   3        3 4 2     2
+--R               864b e g n x  + 3456b e f g n x  + 5184b e f g n x
+--R             + 
+--R                    3 4 3
+--R               3456b e f n x
+--R             + 
+--R                      3 4 3        3 3     2        3 2 2 2         3   3 3
+--R               (- 864b d g  + 3456b d e f g  - 5184b d e f g + 3456b d e f )n
+--R          *
+--R                   2
+--R             log(c)
+--R         + 
+--R                      3 4 3 2          2 4 3   4
+--R               (- 432b e g n  + 1728a b e g n)x
+--R             + 
+--R                     3   3 3        3 4   2  2          2 4   2   3
+--R               ((576b d e g  - 2304b e f g )n  + 6912a b e f g n)x
+--R             + 
+--R                          3 2 2 3        3   3   2        3 4 2   2
+--R                   (- 864b d e g  + 3456b d e f g  - 5184b e f g)n
+--R                 + 
+--R                           2 4 2
+--R                   10368a b e f g n
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                              3 3   3        3 2 2   2         3   3 2
+--R                         1728b d e g  - 6912b d e f g  + 10368b d e f g
+--R                       + 
+--R                                3 4 3
+--R                         - 6912b e f
+--R                  *
+--R                      2
+--R                     n
+--R                 + 
+--R                          2 4 3
+--R                   6912a b e f n
+--R              *
+--R                 x
+--R             + 
+--R                     3 4 3         3 3     2         3 2 2 2         3   3 3  2
+--R               (3600b d g  - 12672b d e f g  + 15552b d e f g - 6912b d e f )n
+--R             + 
+--R                            2 4 3          2 3     2           2 2 2 2
+--R                   - 1728a b d g  + 6912a b d e f g  - 10368a b d e f g
+--R                 + 
+--R                          2   3 3
+--R                   6912a b d e f
+--R              *
+--R                 n
+--R          *
+--R             log(c)
+--R         + 
+--R                3 4 3 3         2 4 3 2       2   4 3   4
+--R           (108b e g n  - 432a b e g n  + 864a b e g n)x
+--R         + 
+--R                      3   3 3       3 4   2  3
+--R               (- 336b d e g  + 768b e f g )n
+--R             + 
+--R                      2   3 3          2 4   2  2        2   4   2
+--R               (576a b d e g  - 2304a b e f g )n  + 3456a b e f g n
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    3 2 2 3        3   3   2        3 4 2   3
+--R               (936b d e g  - 2880b d e f g  + 2592b e f g)n
+--R             + 
+--R                        2 2 2 3          2   3   2          2 4 2   2
+--R               (- 864a b d e g  + 3456a b d e f g  - 5184a b e f g)n
+--R             + 
+--R                    2   4 2
+--R               5184a b e f g n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                            3 3   3         3 2 2   2         3   3 2
+--R                     - 3600b d e g  + 12672b d e f g  - 15552b d e f g
+--R                   + 
+--R                          3 4 3
+--R                     6912b e f
+--R              *
+--R                  3
+--R                 n
+--R             + 
+--R                          2 3   3          2 2 2   2           2   3 2
+--R                   1728a b d e g  - 6912a b d e f g  + 10368a b d e f g
+--R                 + 
+--R                            2 4 3
+--R                   - 6912a b e f
+--R              *
+--R                  2
+--R                 n
+--R             + 
+--R                    2   4 3
+--R               3456a b e f n
+--R          *
+--R             x
+--R         + 
+--R                   3 4 3         3 3     2         3 2 2 2         3   3 3  3
+--R           (- 4980b d g  + 16320b d e f g  - 18144b d e f g + 6912b d e f )n
+--R         + 
+--R                      2 4 3           2 3     2           2 2 2 2
+--R               3600a b d g  - 12672a b d e f g  + 15552a b d e f g
+--R             + 
+--R                        2   3 3
+--R               - 6912a b d e f
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                2   4 3        2   3     2        2   2 2 2         2     3 3
+--R         (- 864a b d g  + 3456a b d e f g  - 5184a b d e f g + 3456a b d e f )n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 4 3 4        3 4   2 3        3 4 2   2        3 4 3        3
+--R       (288b e g x  + 1152b e f g x  + 1728b e f g x  + 1152b e f x)log(c)
+--R     + 
+--R                  3 4 3          2 4 3  4
+--R           (- 216b e g n + 864a b e g )x
+--R         + 
+--R                 3   3 3        3 4   2            2 4   2  3
+--R           ((288b d e g  - 1152b e f g )n + 3456a b e f g )x
+--R         + 
+--R                   3 2 2 3        3   3   2        3 4 2             2 4 2   2
+--R           ((- 432b d e g  + 1728b d e f g  - 2592b e f g)n + 5184a b e f g)x
+--R         + 
+--R                    3 3   3        3 2 2   2        3   3 2         3 4 3
+--R               (864b d e g  - 3456b d e f g  + 5184b d e f g - 3456b e f )n
+--R             + 
+--R                      2 4 3
+--R               3456a b e f
+--R          *
+--R             x
+--R      *
+--R               2
+--R         log(c)
+--R     + 
+--R                3 4 3 2         2 4 3        2   4 3  4
+--R           (108b e g n  - 432a b e g n + 864a b e g )x
+--R         + 
+--R                      3   3 3       3 4   2  2
+--R               (- 336b d e g  + 768b e f g )n
+--R             + 
+--R                      2   3 3          2 4   2          2   4   2
+--R               (576a b d e g  - 2304a b e f g )n + 3456a b e f g
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    3 2 2 3        3   3   2        3 4 2   2
+--R               (936b d e g  - 2880b d e f g  + 2592b e f g)n
+--R             + 
+--R                        2 2 2 3          2   3   2          2 4 2
+--R               (- 864a b d e g  + 3456a b d e f g  - 5184a b e f g)n
+--R             + 
+--R                    2   4 2
+--R               5184a b e f g
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                            3 3   3         3 2 2   2         3   3 2
+--R                     - 3600b d e g  + 12672b d e f g  - 15552b d e f g
+--R                   + 
+--R                          3 4 3
+--R                     6912b e f
+--R              *
+--R                  2
+--R                 n
+--R             + 
+--R                          2 3   3          2 2 2   2           2   3 2
+--R                   1728a b d e g  - 6912a b d e f g  + 10368a b d e f g
+--R                 + 
+--R                            2 4 3
+--R                   - 6912a b e f
+--R              *
+--R                 n
+--R             + 
+--R                    2   4 3
+--R               3456a b e f
+--R          *
+--R             x
+--R      *
+--R         log(c)
+--R     + 
+--R             3 4 3 3         2 4 3 2       2   4 3        3 4 3  4
+--R       (- 27b e g n  + 108a b e g n  - 216a b e g n + 288a e g )x
+--R     + 
+--R                3   3 3       3 4   2  3            2   3 3         2 4   2  2
+--R           (148b d e g  - 256b e f g )n  + (- 336a b d e g  + 768a b e f g )n
+--R         + 
+--R                2     3 3        2   4   2          3 4   2
+--R           (288a b d e g  - 1152a b e f g )n + 1152a e f g
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                  3 2 2 3        3   3   2        3 4 2   3
+--R           (- 690b d e g  + 1824b d e f g  - 1296b e f g)n
+--R         + 
+--R                  2 2 2 3          2   3   2          2 4 2   2
+--R           (936a b d e g  - 2880a b d e f g  + 2592a b e f g)n
+--R         + 
+--R                  2   2 2 3        2     3   2        2   4 2           3 4 2
+--R           (- 432a b d e g  + 1728a b d e f g  - 2592a b e f g)n + 1728a e f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 3 3   3         3 2 2   2         3   3 2         3 4 3  3
+--R           (4980b d e g  - 16320b d e f g  + 18144b d e f g - 6912b e f )n
+--R         + 
+--R                        2 3   3           2 2 2   2           2   3 2
+--R               - 3600a b d e g  + 12672a b d e f g  - 15552a b d e f g
+--R             + 
+--R                      2 4 3
+--R               6912a b e f
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                2   3   3        2   2 2   2        2     3 2         2   4 3
+--R           (864a b d e g  - 3456a b d e f g  + 5184a b d e f g - 3456a b e f )n
+--R         + 
+--R                3 4 3
+--R           1152a e f
+--R      *
+--R         x
+--R  /
+--R          4
+--R     1152e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1418
+
+--S 1419 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3 4 4 4        3 4   3 3        3 4 2 2 2        3 4 3
+--R           - 288b e g x  - 1152b e f g x  - 1728b e f g x  - 1152b e f g x
+--R         + 
+--R               3 4 4        3 3     3        3 2 2 2 2        3   3 3
+--R           288b d g  - 1152b d e f g  + 1728b d e f g  - 1152b d e f g
+--R      *
+--R                        n 3
+--R         log(c (e x + d) )
+--R     + 
+--R                3 4 4          2 4 4  4
+--R           (216b e g n - 864a b e g )x
+--R         + 
+--R                   3   3 4        3 4   3            2 4   3  3
+--R           ((- 288b d e g  + 1152b e f g )n - 3456a b e f g )x
+--R         + 
+--R                 3 2 2 4        3   3   3        3 4 2 2            2 4 2 2  2
+--R           ((432b d e g  - 1728b d e f g  + 2592b e f g )n - 5184a b e f g )x
+--R         + 
+--R                      3 3   4        3 2 2   3        3   3 2 2        3 4 3
+--R               (- 864b d e g  + 3456b d e f g  - 5184b d e f g  + 3456b e f g)n
+--R             + 
+--R                        2 4 3
+--R               - 3456a b e f g
+--R          *
+--R             x
+--R         + 
+--R                   3 4 4        3 3     3        3 2 2 2 2        3   3 3
+--R           (- 1800b d g  + 6336b d e f g  - 7776b d e f g  + 3456b d e f g)n
+--R         + 
+--R                 2 4 4          2 3     3          2 2 2 2 2          2   3 3
+--R           864a b d g  - 3456a b d e f g  + 5184a b d e f g  - 3456a b d e f g
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R                  3 4 4 2         2 4 4        2   4 4  4
+--R           (- 108b e g n  + 432a b e g n - 864a b e g )x
+--R         + 
+--R                    3   3 4       3 4   3  2
+--R               (336b d e g  - 768b e f g )n
+--R             + 
+--R                        2   3 4          2 4   3          2   4   3
+--R               (- 576a b d e g  + 2304a b e f g )n - 3456a b e f g
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                      3 2 2 4        3   3   3        3 4 2 2  2
+--R               (- 936b d e g  + 2880b d e f g  - 2592b e f g )n
+--R             + 
+--R                      2 2 2 4          2   3   3          2 4 2 2
+--R               (864a b d e g  - 3456a b d e f g  + 5184a b e f g )n
+--R             + 
+--R                      2   4 2 2
+--R               - 5184a b e f g
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                          3 3   4         3 2 2   3         3   3 2 2
+--R                     3600b d e g  - 12672b d e f g  + 15552b d e f g
+--R                   + 
+--R                            3 4 3
+--R                     - 6912b e f g
+--R              *
+--R                  2
+--R                 n
+--R             + 
+--R                            2 3   4          2 2 2   3           2   3 2 2
+--R                   - 1728a b d e g  + 6912a b d e f g  - 10368a b d e f g
+--R                 + 
+--R                          2 4 3
+--R                   6912a b e f g
+--R              *
+--R                 n
+--R             + 
+--R                      2   4 3
+--R               - 3456a b e f g
+--R          *
+--R             x
+--R         + 
+--R                    3 4 4         3 3     3        3 2 2 2 2        3   3 3
+--R               3600b d g  - 10800b d e f g  + 9864b d e f g  - 1392b d e f g
+--R             + 
+--R                      3 4 4
+--R               - 1380b e f
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                        2 4 4           2 3     3           2 2 2 2 2
+--R               - 3600a b d g  + 12672a b d e f g  - 15552a b d e f g
+--R             + 
+--R                      2   3 3
+--R               6912a b d e f g
+--R          *
+--R             n
+--R         + 
+--R               2   4 4        2   3     3        2   2 2 2 2        2     3 3
+--R           864a b d g  - 3456a b d e f g  + 5184a b d e f g  - 3456a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R               3 4 4 3 4        3 4   3 3 3        3 4 2 2 3 2        3 4 3   3
+--R           288b e g n x  + 1152b e f g n x  + 1728b e f g n x  + 1152b e f g n x
+--R         + 
+--R                  3 4 4        3 3     3        3 2 2 2 2        3   3 3   3
+--R           (- 288b d g  + 1152b d e f g  - 1728b d e f g  + 1152b d e f g)n
+--R      *
+--R                     3
+--R         log(e x + d)
+--R     + 
+--R                   3 4 4 2 4        3 4   3 2 3        3 4 2 2 2 2
+--R               864b e g n x  + 3456b e f g n x  + 5184b e f g n x
+--R             + 
+--R                    3 4 3   2
+--R               3456b e f g n x
+--R             + 
+--R                    3 4 4        3 3     3        3 2 2 2 2        3   3 3   2
+--R             (- 864b d g  + 3456b d e f g  - 5184b d e f g  + 3456b d e f g)n
+--R          *
+--R             log(c)
+--R         + 
+--R                  3 4 4 3         2 4 4 2  4
+--R           (- 216b e g n  + 864a b e g n )x
+--R         + 
+--R                 3   3 4        3 4   3  3          2 4   3 2  3
+--R           ((288b d e g  - 1152b e f g )n  + 3456a b e f g n )x
+--R         + 
+--R                      3 2 2 4        3   3   3        3 4 2 2  3
+--R               (- 432b d e g  + 1728b d e f g  - 2592b e f g )n
+--R             + 
+--R                      2 4 2 2 2
+--R               5184a b e f g n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 3   4        3 2 2   3        3   3 2 2        3 4 3   3
+--R               (864b d e g  - 3456b d e f g  + 5184b d e f g  - 3456b e f g)n
+--R             + 
+--R                      2 4 3   2
+--R               3456a b e f g n
+--R          *
+--R             x
+--R         + 
+--R                 3 4 4        3 3     3        3 2 2 2 2        3   3 3   3
+--R           (1800b d g  - 6336b d e f g  + 7776b d e f g  - 3456b d e f g)n
+--R         + 
+--R                       2 4 4          2 3     3          2 2 2 2 2
+--R               - 864a b d g  + 3456a b d e f g  - 5184a b d e f g
+--R             + 
+--R                      2   3 3
+--R               3456a b d e f g
+--R          *
+--R              2
+--R             n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R                   3 4 4   4        3 4   3   3        3 4 2 2   2
+--R               864b e g n x  + 3456b e f g n x  + 5184b e f g n x
+--R             + 
+--R                    3 4 3
+--R               3456b e f g n x
+--R             + 
+--R                      3 4 4        3 3     3        3 2 2 2 2        3   3 3
+--R               (- 864b d g  + 3456b d e f g  - 5184b d e f g  + 3456b d e f g)n
+--R          *
+--R                   2
+--R             log(c)
+--R         + 
+--R                      3 4 4 2          2 4 4   4
+--R               (- 432b e g n  + 1728a b e g n)x
+--R             + 
+--R                     3   3 4        3 4   3  2          2 4   3   3
+--R               ((576b d e g  - 2304b e f g )n  + 6912a b e f g n)x
+--R             + 
+--R                          3 2 2 4        3   3   3        3 4 2 2  2
+--R                   (- 864b d e g  + 3456b d e f g  - 5184b e f g )n
+--R                 + 
+--R                           2 4 2 2
+--R                   10368a b e f g n
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                            3 3   4        3 2 2   3         3   3 2 2
+--R                       1728b d e g  - 6912b d e f g  + 10368b d e f g
+--R                     + 
+--R                              3 4 3
+--R                       - 6912b e f g
+--R                  *
+--R                      2
+--R                     n
+--R                 + 
+--R                          2 4 3
+--R                   6912a b e f g n
+--R              *
+--R                 x
+--R             + 
+--R                          3 4 4         3 3     3         3 2 2 2 2
+--R                     3600b d g  - 12672b d e f g  + 15552b d e f g
+--R                   + 
+--R                            3   3 3
+--R                     - 6912b d e f g
+--R              *
+--R                  2
+--R                 n
+--R             + 
+--R                            2 4 4          2 3     3           2 2 2 2 2
+--R                   - 1728a b d g  + 6912a b d e f g  - 10368a b d e f g
+--R                 + 
+--R                          2   3 3
+--R                   6912a b d e f g
+--R              *
+--R                 n
+--R          *
+--R             log(c)
+--R         + 
+--R                3 4 4 3         2 4 4 2       2   4 4   4
+--R           (108b e g n  - 432a b e g n  + 864a b e g n)x
+--R         + 
+--R                      3   3 4       3 4   3  3
+--R               (- 336b d e g  + 768b e f g )n
+--R             + 
+--R                      2   3 4          2 4   3  2        2   4   3
+--R               (576a b d e g  - 2304a b e f g )n  + 3456a b e f g n
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    3 2 2 4        3   3   3        3 4 2 2  3
+--R               (936b d e g  - 2880b d e f g  + 2592b e f g )n
+--R             + 
+--R                        2 2 2 4          2   3   3          2 4 2 2  2
+--R               (- 864a b d e g  + 3456a b d e f g  - 5184a b e f g )n
+--R             + 
+--R                    2   4 2 2
+--R               5184a b e f g n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                          3 3   4         3 2 2   3         3   3 2 2
+--R                   - 3600b d e g  + 12672b d e f g  - 15552b d e f g
+--R                 + 
+--R                        3 4 3
+--R                   6912b e f g
+--R              *
+--R                  3
+--R                 n
+--R             + 
+--R                          2 3   4          2 2 2   3           2   3 2 2
+--R                   1728a b d e g  - 6912a b d e f g  + 10368a b d e f g
+--R                 + 
+--R                            2 4 3
+--R                   - 6912a b e f g
+--R              *
+--R                  2
+--R                 n
+--R             + 
+--R                    2   4 3
+--R               3456a b e f g n
+--R          *
+--R             x
+--R         + 
+--R                      3 4 4         3 3     3        3 2 2 2 2        3   3 3
+--R               - 3600b d g  + 10800b d e f g  - 9864b d e f g  + 1392b d e f g
+--R             + 
+--R                    3 4 4
+--R               1380b e f
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                      2 4 4           2 3     3           2 2 2 2 2
+--R               3600a b d g  - 12672a b d e f g  + 15552a b d e f g
+--R             + 
+--R                        2   3 3
+--R               - 6912a b d e f g
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                     2   4 4        2   3     3        2   2 2 2 2
+--R               - 864a b d g  + 3456a b d e f g  - 5184a b d e f g
+--R             + 
+--R                    2     3 3
+--R               3456a b d e f g
+--R          *
+--R             n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            3 4 4 4        3 4   3 3        3 4 2 2 2        3 4 3          3
+--R       (288b e g x  + 1152b e f g x  + 1728b e f g x  + 1152b e f g x)log(c)
+--R     + 
+--R                  3 4 4          2 4 4  4
+--R           (- 216b e g n + 864a b e g )x
+--R         + 
+--R                 3   3 4        3 4   3            2 4   3  3
+--R           ((288b d e g  - 1152b e f g )n + 3456a b e f g )x
+--R         + 
+--R                   3 2 2 4        3   3   3        3 4 2 2            2 4 2 2  2
+--R           ((- 432b d e g  + 1728b d e f g  - 2592b e f g )n + 5184a b e f g )x
+--R         + 
+--R                    3 3   4        3 2 2   3        3   3 2 2        3 4 3
+--R               (864b d e g  - 3456b d e f g  + 5184b d e f g  - 3456b e f g)n
+--R             + 
+--R                      2 4 3
+--R               3456a b e f g
+--R          *
+--R             x
+--R      *
+--R               2
+--R         log(c)
+--R     + 
+--R                3 4 4 2         2 4 4        2   4 4  4
+--R           (108b e g n  - 432a b e g n + 864a b e g )x
+--R         + 
+--R                      3   3 4       3 4   3  2
+--R               (- 336b d e g  + 768b e f g )n
+--R             + 
+--R                      2   3 4          2 4   3          2   4   3
+--R               (576a b d e g  - 2304a b e f g )n + 3456a b e f g
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                    3 2 2 4        3   3   3        3 4 2 2  2
+--R               (936b d e g  - 2880b d e f g  + 2592b e f g )n
+--R             + 
+--R                        2 2 2 4          2   3   3          2 4 2 2
+--R               (- 864a b d e g  + 3456a b d e f g  - 5184a b e f g )n
+--R             + 
+--R                    2   4 2 2
+--R               5184a b e f g
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                          3 3   4         3 2 2   3         3   3 2 2
+--R                   - 3600b d e g  + 12672b d e f g  - 15552b d e f g
+--R                 + 
+--R                        3 4 3
+--R                   6912b e f g
+--R              *
+--R                  2
+--R                 n
+--R             + 
+--R                          2 3   4          2 2 2   3           2   3 2 2
+--R                   1728a b d e g  - 6912a b d e f g  + 10368a b d e f g
+--R                 + 
+--R                            2 4 3
+--R                   - 6912a b e f g
+--R              *
+--R                 n
+--R             + 
+--R                    2   4 3
+--R               3456a b e f g
+--R          *
+--R             x
+--R      *
+--R         log(c)
+--R     + 
+--R            3 2 2 2 2        3   3 3        3 4 4  3
+--R       (690b d e f g  - 1528b d e f g + 865b e f )n
+--R     + 
+--R                2 2 2 2 2          2   3 3           2 4 4  2
+--R       (- 936a b d e f g  + 2208a b d e f g - 1380a b e f )n
+--R     + 
+--R               2   4 4        2   3     3        2   2 2 2 2        2     3 3
+--R       (- 1800a b d g  + 6336a b d e f g  - 7776a b d e f g  + 3456a b d e f g)n
+--R     + 
+--R           3 4 4        3 3     3        3 2 2 2 2        3   3 3
+--R       288a d g  - 1152a d e f g  + 1728a d e f g  - 1152a d e f g
+--R  /
+--R          4
+--R     1152e g
+--R                                                    Type: Expression(Integer)
+--E 1419
+
+--S 1420 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1420
+
+)clear all
+
+--S 1421 of 5341
+t0:=(f+g*x)^2*(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R       3 2 2     3         3 2                n 3
+--R     (b g x  + 2b f g x + b f )log(c (e x + d) )
+--R   + 
+--R          2 2 2       2            2 2                n 2
+--R     (3a b g x  + 6a b f g x + 3a b f )log(c (e x + d) )
+--R   + 
+--R        2   2 2     2            2   2                n     3 2 2     3
+--R     (3a b g x  + 6a b f g x + 3a b f )log(c (e x + d) ) + a g x  + 2a f g x
+--R   + 
+--R      3 2
+--R     a f
+--R                                                    Type: Expression(Integer)
+--E 1421
+
+--S 1422 of 5341
+r0:=11/3*a*b^2*(e*f-d*g)^2*n^2*x/e^2-85/18*b^3*(e*f-d*g)^2*n^3*x/e^2-_
+   19/36*b^3*(e*f-d*g)*n^3*(f+g*x)^2/(e*g)-2/27*b^3*n^3*(f+g*x)^3/g-_
+   19/18*b^3*(e*f-d*g)^3*n^3*log(d+e*x)/(e^3*g)+11/3*b^3*(e*f-d*g)^2*n^2*_
+   (d+e*x)*log(c*(d+e*x)^n)/e^3+5/6*b^2*(e*f-d*g)*n^2*(f+g*x)^2*(a+_
+   b*log(c*(d+e*x)^n))/(e*g)+2/9*b^2*n^2*(f+g*x)^3*(a+b*log(c*(d+e*x)^n))/g-_
+   11/6*b*(e*f-d*g)^2*n*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/e^3-5/6*b*(e*f-_
+   d*g)*n*(d+e*x)*(f+g*x)*(a+b*log(c*(d+e*x)^n))^2/e^2-1/3*b*n*(d+e*x)*_
+   (f+g*x)^2*(a+b*log(c*(d+e*x)^n))^2/e+1/3*(e*f-d*g)^2*(d+e*x)*(a+_
+   b*log(c*(d+e*x)^n))^3/e^3+1/3*(e*f-d*g)*(d+e*x)*(f+g*x)*(a+b*log(c*(d+_
+   e*x)^n))^3/e^2+1/3*(d+e*x)*(f+g*x)^2*(a+b*log(c*(d+e*x)^n))^3/e
+--R 
+--R
+--R   (2)
+--R              3 3 3 3       3 3   2 2       3 3 2         3 3 3       3 2     2
+--R           36b e g x  + 108b e f g x  + 108b e f g x + 36b d g  - 108b d e f g
+--R         + 
+--R               3   2 2
+--R           108b d e f g
+--R      *
+--R                        n 3
+--R         log(c (e x + d) )
+--R     + 
+--R                 3 3 3          2 3 3  3
+--R           (- 36b e g n + 108a b e g )x
+--R         + 
+--R                3   2 3       3 3   2           2 3   2  2
+--R           ((54b d e g  - 162b e f g )n + 324a b e f g )x
+--R         + 
+--R                   3 2   3       3   2   2       3 3 2            2 3 2
+--R           ((- 108b d e g  + 324b d e f g  - 324b e f g)n + 324a b e f g)x
+--R         + 
+--R                  3 3 3       3 2     2       3   2 2            2 3 3
+--R           (- 198b d g  + 486b d e f g  - 324b d e f g)n + 108a b d g
+--R         + 
+--R                   2 2     2         2   2 2
+--R           - 324a b d e f g  + 324a b d e f g
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R               3 3 3 2        2 3 3        2   3 3  3
+--R           (24b e g n  - 72a b e g n + 108a b e g )x
+--R         + 
+--R                     3   2 3       3 3   2  2          2   2 3         2 3   2
+--R               (- 90b d e g  + 162b e f g )n  + (108a b d e g  - 324a b e f g )n
+--R             + 
+--R                   2   3   2
+--R               324a b e f g
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 2   3       3   2   2       3 3 2   2
+--R               (396b d e g  - 972b d e f g  + 648b e f g)n
+--R             + 
+--R                      2 2   3         2   2   2         2 3 2          2   3 2
+--R             (- 216a b d e g  + 648a b d e f g  - 648a b e f g)n + 324a b e f g
+--R          *
+--R             x
+--R         + 
+--R                3 3 3       3 2     2       3   2 2        3 3 3  2
+--R           (396b d g  - 792b d e f g  + 306b d e f g + 114b e f )n
+--R         + 
+--R                    2 3 3         2 2     2         2   2 2          2   3 3
+--R           (- 396a b d g  + 972a b d e f g  - 648a b d e f g)n + 108a b d g
+--R         + 
+--R                 2   2     2       2     2 2
+--R           - 324a b d e f g  + 324a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R            3 3 3       3 2     2       3   2 2        3 3 3  3
+--R       (114b d g  - 342b d e f g  + 342b d e f g - 114b e f )n log(e x + d)
+--R     + 
+--R            3 3 3 3        2 3 3 2      2   3 3       3 3 3  3
+--R       (- 8b e g n  + 24a b e g n  - 36a b e g n + 36a e g )x
+--R     + 
+--R               3   2 3      3 3   2  3           2   2 3         2 3   2  2
+--R           (57b d e g  - 81b e f g )n  + (- 90a b d e g  + 162a b e f g )n
+--R         + 
+--R               2     2 3       2   3   2         3 3   2
+--R           (54a b d e g  - 162a b e f g )n + 108a e f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 2   3        3   2   2       3 3 2   3
+--R           (- 510b d e g  + 1134b d e f g  - 648b e f g)n
+--R         + 
+--R                  2 2   3         2   2   2         2 3 2   2
+--R           (396a b d e g  - 972a b d e f g  + 648a b e f g)n
+--R         + 
+--R                  2   2   3       2     2   2       2   3 2          3 3 2
+--R           (- 108a b d e g  + 324a b d e f g  - 324a b e f g)n + 108a e f g
+--R      *
+--R         x
+--R     + 
+--R           3   2 2       3 3 3  3           2   2 2          2 3 3  2
+--R       (57b d e f g - 65b e f )n  + (- 90a b d e f g + 114a b e f )n
+--R     + 
+--R              2   3 3       2   2     2       2     2 2         3 3 3
+--R       (- 198a b d g  + 486a b d e f g  - 324a b d e f g)n + 36a d g
+--R     + 
+--R             3 2     2       3   2 2
+--R       - 108a d e f g  + 108a d e f g
+--R  /
+--R         3
+--R     108e g
+--R                                                    Type: Expression(Integer)
+--E 1422
+
+--S 1423 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              3 3 2 3 3       3 3     3 2       3 3 2 3
+--R           36b e g n x  + 108b e f g n x  + 108b e f n x
+--R         + 
+--R               3 3 2       3 2            3   2 2  3
+--R           (36b d g  - 108b d e f g + 108b d e f )n
+--R      *
+--R                     3
+--R         log(e x + d)
+--R     + 
+--R                   3 3 2 2 3       3 3     2 2       3 3 2 2
+--R               108b e g n x  + 324b e f g n x  + 324b e f n x
+--R             + 
+--R                    3 3 2       3 2            3   2 2  2
+--R               (108b d g  - 324b d e f g + 324b d e f )n
+--R          *
+--R             log(c)
+--R         + 
+--R                 3 3 2 3         2 3 2 2  3
+--R           (- 36b e g n  + 108a b e g n )x
+--R         + 
+--R                3   2 2       3 3     3         2 3     2  2
+--R           ((54b d e g  - 162b e f g)n  + 324a b e f g n )x
+--R         + 
+--R                   3 2   2       3   2          3 3 2  3         2 3 2 2
+--R           ((- 108b d e g  + 324b d e f g - 324b e f )n  + 324a b e f n )x
+--R         + 
+--R                  3 3 2       3 2            3   2 2  3
+--R           (- 198b d g  + 486b d e f g - 324b d e f )n
+--R         + 
+--R                  2 3 2         2 2              2   2 2  2
+--R           (108a b d g  - 324a b d e f g + 324a b d e f )n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R                   3 3 2   3       3 3       2       3 3 2
+--R               108b e g n x  + 324b e f g n x  + 324b e f n x
+--R             + 
+--R                    3 3 2       3 2            3   2 2
+--R               (108b d g  - 324b d e f g + 324b d e f )n
+--R          *
+--R                   2
+--R             log(c)
+--R         + 
+--R                     3 3 2 2         2 3 2   3
+--R               (- 72b e g n  + 216a b e g n)x
+--R             + 
+--R                     3   2 2       3 3     2         2 3       2
+--R               ((108b d e g  - 324b e f g)n  + 648a b e f g n)x
+--R             + 
+--R                       3 2   2       3   2          3 3 2  2         2 3 2
+--R               ((- 216b d e g  + 648b d e f g - 648b e f )n  + 648a b e f n)x
+--R             + 
+--R                      3 3 2       3 2            3   2 2  2
+--R               (- 396b d g  + 972b d e f g - 648b d e f )n
+--R             + 
+--R                      2 3 2         2 2              2   2 2
+--R               (216a b d g  - 648a b d e f g + 648a b d e f )n
+--R          *
+--R             log(c)
+--R         + 
+--R               3 3 2 3        2 3 2 2       2   3 2   3
+--R           (24b e g n  - 72a b e g n  + 108a b e g n)x
+--R         + 
+--R                     3   2 2       3 3     3          2   2 2         2 3     2
+--R               (- 90b d e g  + 162b e f g)n  + (108a b d e g  - 324a b e f g)n
+--R             + 
+--R                   2   3
+--R               324a b e f g n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 2   2       3   2          3 3 2  3
+--R               (396b d e g  - 972b d e f g + 648b e f )n
+--R             + 
+--R                      2 2   2         2   2            2 3 2  2       2   3 2
+--R             (- 216a b d e g  + 648a b d e f g - 648a b e f )n  + 324a b e f n
+--R          *
+--R             x
+--R         + 
+--R                3 3 2        3 2            3   2 2  3
+--R           (510b d g  - 1134b d e f g + 648b d e f )n
+--R         + 
+--R                    2 3 2         2 2              2   2 2  2
+--R           (- 396a b d g  + 972a b d e f g - 648a b d e f )n
+--R         + 
+--R                2   3 2       2   2            2     2 2
+--R           (108a b d g  - 324a b d e f g + 324a b d e f )n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 3 2 3       3 3     2       3 3 2        3
+--R       (36b e g x  + 108b e f g x  + 108b e f x)log(c)
+--R     + 
+--R                 3 3 2          2 3 2  3
+--R           (- 36b e g n + 108a b e g )x
+--R         + 
+--R                3   2 2       3 3              2 3     2
+--R           ((54b d e g  - 162b e f g)n + 324a b e f g)x
+--R         + 
+--R                   3 2   2       3   2          3 3 2           2 3 2
+--R           ((- 108b d e g  + 324b d e f g - 324b e f )n + 324a b e f )x
+--R      *
+--R               2
+--R         log(c)
+--R     + 
+--R               3 3 2 2        2 3 2        2   3 2  3
+--R           (24b e g n  - 72a b e g n + 108a b e g )x
+--R         + 
+--R                     3   2 2       3 3     2          2   2 2         2 3
+--R               (- 90b d e g  + 162b e f g)n  + (108a b d e g  - 324a b e f g)n
+--R             + 
+--R                   2   3
+--R               324a b e f g
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 2   2       3   2          3 3 2  2
+--R               (396b d e g  - 972b d e f g + 648b e f )n
+--R             + 
+--R                        2 2   2         2   2            2 3 2         2   3 2
+--R               (- 216a b d e g  + 648a b d e f g - 648a b e f )n + 324a b e f
+--R          *
+--R             x
+--R      *
+--R         log(c)
+--R     + 
+--R            3 3 2 3        2 3 2 2      2   3 2       3 3 2  3
+--R       (- 8b e g n  + 24a b e g n  - 36a b e g n + 36a e g )x
+--R     + 
+--R               3   2 2      3 3     3           2   2 2         2 3     2
+--R           (57b d e g  - 81b e f g)n  + (- 90a b d e g  + 162a b e f g)n
+--R         + 
+--R               2     2 2       2   3            3 3
+--R           (54a b d e g  - 162a b e f g)n + 108a e f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                  3 2   2        3   2          3 3 2  3
+--R           (- 510b d e g  + 1134b d e f g - 648b e f )n
+--R         + 
+--R                  2 2   2         2   2            2 3 2  2
+--R           (396a b d e g  - 972a b d e f g + 648a b e f )n
+--R         + 
+--R                  2   2   2       2     2          2   3 2         3 3 2
+--R           (- 108a b d e g  + 324a b d e f g - 324a b e f )n + 108a e f
+--R      *
+--R         x
+--R  /
+--R         3
+--R     108e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1423
+
+--S 1424 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                3 3 3 3       3 3   2 2       3 3 2         3 3 3
+--R           - 36b e g x  - 108b e f g x  - 108b e f g x - 36b d g
+--R         + 
+--R               3 2     2       3   2 2
+--R           108b d e f g  - 108b d e f g
+--R      *
+--R                        n 3
+--R         log(c (e x + d) )
+--R     + 
+--R               3 3 3          2 3 3  3
+--R           (36b e g n - 108a b e g )x
+--R         + 
+--R                  3   2 3       3 3   2           2 3   2  2
+--R           ((- 54b d e g  + 162b e f g )n - 324a b e f g )x
+--R         + 
+--R                 3 2   3       3   2   2       3 3 2            2 3 2
+--R           ((108b d e g  - 324b d e f g  + 324b e f g)n - 324a b e f g)x
+--R         + 
+--R                3 3 3       3 2     2       3   2 2            2 3 3
+--R           (198b d g  - 486b d e f g  + 324b d e f g)n - 108a b d g
+--R         + 
+--R                 2 2     2         2   2 2
+--R           324a b d e f g  - 324a b d e f g
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R                 3 3 3 2        2 3 3        2   3 3  3
+--R           (- 24b e g n  + 72a b e g n - 108a b e g )x
+--R         + 
+--R                   3   2 3       3 3   2  2            2   2 3         2 3   2
+--R               (90b d e g  - 162b e f g )n  + (- 108a b d e g  + 324a b e f g )n
+--R             + 
+--R                     2   3   2
+--R               - 324a b e f g
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      3 2   3       3   2   2       3 3 2   2
+--R               (- 396b d e g  + 972b d e f g  - 648b e f g)n
+--R             + 
+--R                      2 2   3         2   2   2         2 3 2          2   3 2
+--R               (216a b d e g  - 648a b d e f g  + 648a b e f g)n - 324a b e f g
+--R          *
+--R             x
+--R         + 
+--R                  3 3 3       3 2     2       3   2 2        3 3 3  2
+--R           (- 396b d g  + 792b d e f g  - 306b d e f g - 114b e f )n
+--R         + 
+--R                  2 3 3         2 2     2         2   2 2          2   3 3
+--R           (396a b d g  - 972a b d e f g  + 648a b d e f g)n - 108a b d g
+--R         + 
+--R               2   2     2       2     2 2
+--R           324a b d e f g  - 324a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R              3 3 3 3 3       3 3   2 3 2       3 3 2   3
+--R           36b e g n x  + 108b e f g n x  + 108b e f g n x
+--R         + 
+--R               3 3 3       3 2     2       3   2 2   3
+--R           (36b d g  - 108b d e f g  + 108b d e f g)n
+--R      *
+--R                     3
+--R         log(e x + d)
+--R     + 
+--R                   3 3 3 2 3       3 3   2 2 2       3 3 2   2
+--R               108b e g n x  + 324b e f g n x  + 324b e f g n x
+--R             + 
+--R                    3 3 3       3 2     2       3   2 2   2
+--R               (108b d g  - 324b d e f g  + 324b d e f g)n
+--R          *
+--R             log(c)
+--R         + 
+--R                 3 3 3 3         2 3 3 2  3
+--R           (- 36b e g n  + 108a b e g n )x
+--R         + 
+--R                3   2 3       3 3   2  3         2 3   2 2  2
+--R           ((54b d e g  - 162b e f g )n  + 324a b e f g n )x
+--R         + 
+--R                   3 2   3       3   2   2       3 3 2   3         2 3 2   2
+--R           ((- 108b d e g  + 324b d e f g  - 324b e f g)n  + 324a b e f g n )x
+--R         + 
+--R                  3 3 3       3 2     2       3   2 2   3
+--R           (- 198b d g  + 486b d e f g  - 324b d e f g)n
+--R         + 
+--R                  2 3 3         2 2     2         2   2 2   2
+--R           (108a b d g  - 324a b d e f g  + 324a b d e f g)n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R                   3 3 3   3       3 3   2   2       3 3 2
+--R               108b e g n x  + 324b e f g n x  + 324b e f g n x
+--R             + 
+--R                    3 3 3       3 2     2       3   2 2
+--R               (108b d g  - 324b d e f g  + 324b d e f g)n
+--R          *
+--R                   2
+--R             log(c)
+--R         + 
+--R                     3 3 3 2         2 3 3   3
+--R               (- 72b e g n  + 216a b e g n)x
+--R             + 
+--R                     3   2 3       3 3   2  2         2 3   2   2
+--R               ((108b d e g  - 324b e f g )n  + 648a b e f g n)x
+--R             + 
+--R                            3 2   3       3   2   2       3 3 2   2
+--R                     (- 216b d e g  + 648b d e f g  - 648b e f g)n
+--R                   + 
+--R                           2 3 2
+--R                     648a b e f g n
+--R              *
+--R                 x
+--R             + 
+--R                      3 3 3       3 2     2       3   2 2   2
+--R               (- 396b d g  + 972b d e f g  - 648b d e f g)n
+--R             + 
+--R                      2 3 3         2 2     2         2   2 2
+--R               (216a b d g  - 648a b d e f g  + 648a b d e f g)n
+--R          *
+--R             log(c)
+--R         + 
+--R               3 3 3 3        2 3 3 2       2   3 3   3
+--R           (24b e g n  - 72a b e g n  + 108a b e g n)x
+--R         + 
+--R                     3   2 3       3 3   2  3
+--R               (- 90b d e g  + 162b e f g )n
+--R             + 
+--R                      2   2 3         2 3   2  2       2   3   2
+--R               (108a b d e g  - 324a b e f g )n  + 324a b e f g n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 2   3       3   2   2       3 3 2   3
+--R               (396b d e g  - 972b d e f g  + 648b e f g)n
+--R             + 
+--R                        2 2   3         2   2   2         2 3 2   2
+--R               (- 216a b d e g  + 648a b d e f g  - 648a b e f g)n
+--R             + 
+--R                   2   3 2
+--R               324a b e f g n
+--R          *
+--R             x
+--R         + 
+--R                3 3 3       3 2     2       3   2 2        3 3 3  3
+--R           (396b d g  - 792b d e f g  + 306b d e f g + 114b e f )n
+--R         + 
+--R                    2 3 3         2 2     2         2   2 2   2
+--R           (- 396a b d g  + 972a b d e f g  - 648a b d e f g)n
+--R         + 
+--R                2   3 3       2   2     2       2     2 2
+--R           (108a b d g  - 324a b d e f g  + 324a b d e f g)n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R           3 3 3 3       3 3   2 2       3 3 2          3
+--R       (36b e g x  + 108b e f g x  + 108b e f g x)log(c)
+--R     + 
+--R                 3 3 3          2 3 3  3
+--R           (- 36b e g n + 108a b e g )x
+--R         + 
+--R                3   2 3       3 3   2           2 3   2  2
+--R           ((54b d e g  - 162b e f g )n + 324a b e f g )x
+--R         + 
+--R                   3 2   3       3   2   2       3 3 2            2 3 2
+--R           ((- 108b d e g  + 324b d e f g  - 324b e f g)n + 324a b e f g)x
+--R      *
+--R               2
+--R         log(c)
+--R     + 
+--R               3 3 3 2        2 3 3        2   3 3  3
+--R           (24b e g n  - 72a b e g n + 108a b e g )x
+--R         + 
+--R                     3   2 3       3 3   2  2          2   2 3         2 3   2
+--R               (- 90b d e g  + 162b e f g )n  + (108a b d e g  - 324a b e f g )n
+--R             + 
+--R                   2   3   2
+--R               324a b e f g
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3 2   3       3   2   2       3 3 2   2
+--R               (396b d e g  - 972b d e f g  + 648b e f g)n
+--R             + 
+--R                      2 2   3         2   2   2         2 3 2          2   3 2
+--R             (- 216a b d e g  + 648a b d e f g  - 648a b e f g)n + 324a b e f g
+--R          *
+--R             x
+--R      *
+--R         log(c)
+--R     + 
+--R             3   2 2       3 3 3  3         2   2 2          2 3 3  2
+--R       (- 57b d e f g + 65b e f )n  + (90a b d e f g - 114a b e f )n
+--R     + 
+--R            2   3 3       2   2     2       2     2 2         3 3 3
+--R       (198a b d g  - 486a b d e f g  + 324a b d e f g)n - 36a d g
+--R     + 
+--R           3 2     2       3   2 2
+--R       108a d e f g  - 108a d e f g
+--R  /
+--R         3
+--R     108e g
+--R                                                    Type: Expression(Integer)
+--E 1424
+
+--S 1425 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1425
+
+)clear all
+
+--S 1426 of 5341
+t0:=(f+g*x)*(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R       3       3                 n 3        2          2                 n 2
+--R     (b g x + b f)log(c (e x + d) )  + (3a b g x + 3a b f)log(c (e x + d) )
+--R   + 
+--R        2          2                   n     3       3
+--R     (3a b g x + 3a b f)log(c (e x + d) ) + a g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1426
+
+--S 1427 of 5341
+r0:=9/2*a*b^2*(e*f-d*g)*n^2*x/e-21/4*b^3*(e*f-d*g)*n^3*x/e-3/8*b^3*n^3*_
+   (f+g*x)^2/g-3/4*b^3*(e*f-d*g)^2*n^3*log(d+e*x)/(e^2*g)+9/2*b^3*(e*f-_
+   d*g)*n^2*(d+e*x)*log(c*(d+e*x)^n)/e^2+3/4*b^2*n^2*(f+g*x)^2*(a+_
+   b*log(c*(d+e*x)^n))/g-9/4*b*(e*f-d*g)*n*(d+e*x)*(a+b*log(c*(d+_
+   e*x)^n))^2/e^2-3/4*b*n*(d+e*x)*(f+g*x)*(a+b*log(c*(d+e*x)^n))^2/e+_
+   1/2*(e*f-d*g)*(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/e^2+1/2*(d+e*x)*(f+g*x)*_
+   (a+b*log(c*(d+e*x)^n))^3/e
+--R 
+--R
+--R   (2)
+--R          3 2 2 2     3 2          3 2 2     3                       n 3
+--R       (4b e g x  + 8b e f g x - 4b d g  + 8b d e f g)log(c (e x + d) )
+--R     + 
+--R                3 2 2         2 2 2  2
+--R           (- 6b e g n + 12a b e g )x
+--R         + 
+--R                3     2      3 2             2 2
+--R           ((12b d e g  - 24b e f g)n + 24a b e f g)x
+--R         + 
+--R               3 2 2      3                 2 2 2        2
+--R           (18b d g  - 24b d e f g)n - 12a b d g  + 24a b d e f g
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R              3 2 2 2        2 2 2       2   2 2  2
+--R           (6b e g n  - 12a b e g n + 12a b e g )x
+--R         + 
+--R                     3     2      3 2     2         2     2        2 2
+--R               (- 36b d e g  + 48b e f g)n  + (24a b d e g  - 48a b e f g)n
+--R             + 
+--R                  2   2
+--R               24a b e f g
+--R          *
+--R             x
+--R         + 
+--R                 3 2 2      3            3 2 2  2
+--R           (- 36b d g  + 36b d e f g + 6b e f )n
+--R         + 
+--R                 2 2 2        2               2   2 2      2
+--R           (36a b d g  - 48a b d e f g)n - 12a b d g  + 24a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R            3 2 2      3            3 2 2  3
+--R       (- 6b d g  + 12b d e f g - 6b e f )n log(e x + d)
+--R     + 
+--R            3 2 2 3       2 2 2 2     2   2 2      3 2 2  2
+--R       (- 3b e g n  + 6a b e g n  - 6a b e g n + 4a e g )x
+--R     + 
+--R               3     2      3 2     3           2     2        2 2     2
+--R           (42b d e g  - 48b e f g)n  + (- 36a b d e g  + 48a b e f g)n
+--R         + 
+--R               2       2      2   2          3 2
+--R           (12a b d e g  - 24a b e f g)n + 8a e f g
+--R      *
+--R         x
+--R     + 
+--R           3 2 2 3       2 2 2 2       2   2 2      2                3 2 2
+--R       - 3b e f n  + 6a b e f n  + (18a b d g  - 24a b d e f g)n - 4a d g
+--R     + 
+--R         3
+--R       8a d e f g
+--R  /
+--R       2
+--R     8e g
+--R                                                    Type: Expression(Integer)
+--E 1427
+
+--S 1428 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3 2   3 2     3 2   3         3 2      3       3             3
+--R       (4b e g n x  + 8b e f n x + (- 4b d g + 8b d e f)n )log(e x + d)
+--R     + 
+--R               3 2   2 2      3 2   2          3 2       3       2
+--R           (12b e g n x  + 24b e f n x + (- 12b d g + 24b d e f)n )log(c)
+--R         + 
+--R                3 2   3        2 2   2  2
+--R           (- 6b e g n  + 12a b e g n )x
+--R         + 
+--R                3           3 2   3        2 2   2         3 2       3       3
+--R           ((12b d e g - 24b e f)n  + 24a b e f n )x + (18b d g - 24b d e f)n
+--R         + 
+--R                   2 2         2       2
+--R           (- 12a b d g + 24a b d e f)n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R               3 2     2      3 2              3 2       3              2
+--R           (12b e g n x  + 24b e f n x + (- 12b d g + 24b d e f)n)log(c)
+--R         + 
+--R                     3 2   2        2 2     2
+--R               (- 12b e g n  + 24a b e g n)x
+--R             + 
+--R                    3           3 2   2        2 2
+--R               ((24b d e g - 48b e f)n  + 48a b e f n)x
+--R             + 
+--R                   3 2       3       2           2 2         2
+--R               (36b d g - 48b d e f)n  + (- 24a b d g + 48a b d e f)n
+--R          *
+--R             log(c)
+--R         + 
+--R              3 2   3        2 2   2      2   2     2
+--R           (6b e g n  - 12a b e g n  + 12a b e g n)x
+--R         + 
+--R                     3           3 2   3         2             2 2   2
+--R               (- 36b d e g + 48b e f)n  + (24a b d e g - 48a b e f)n
+--R             + 
+--R                  2   2
+--R               24a b e f n
+--R          *
+--R             x
+--R         + 
+--R                 3 2       3       3         2 2         2       2
+--R           (- 42b d g + 48b d e f)n  + (36a b d g - 48a b d e f)n
+--R         + 
+--R                 2   2       2
+--R           (- 12a b d g + 24a b d e f)n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R          3 2   2     3 2          3
+--R       (4b e g x  + 8b e f x)log(c)
+--R     + 
+--R               3 2           2 2   2        3           3 2           2 2
+--R         ((- 6b e g n + 12a b e g)x  + ((12b d e g - 24b e f)n + 24a b e f)x)
+--R      *
+--R               2
+--R         log(c)
+--R     + 
+--R              3 2   2        2 2         2   2   2
+--R           (6b e g n  - 12a b e g n + 12a b e g)x
+--R         + 
+--R                3           3 2   2         2             2 2         2   2
+--R         ((- 36b d e g + 48b e f)n  + (24a b d e g - 48a b e f)n + 24a b e f)x
+--R      *
+--R         log(c)
+--R     + 
+--R            3 2   3       2 2   2     2   2        3 2   2
+--R       (- 3b e g n  + 6a b e g n  - 6a b e g n + 4a e g)x
+--R     + 
+--R               3           3 2   3           2             2 2   2
+--R           (42b d e g - 48b e f)n  + (- 36a b d e g + 48a b e f)n
+--R         + 
+--R               2             2   2        3 2
+--R           (12a b d e g - 24a b e f)n + 8a e f
+--R      *
+--R         x
+--R  /
+--R       2
+--R     8e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1428
+
+--S 1429 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3 2 2 2     3 2          3 2 2     3                       n 3
+--R       (- 4b e g x  - 8b e f g x + 4b d g  - 8b d e f g)log(c (e x + d) )
+--R     + 
+--R              3 2 2         2 2 2  2
+--R           (6b e g n - 12a b e g )x
+--R         + 
+--R                  3     2      3 2             2 2
+--R           ((- 12b d e g  + 24b e f g)n - 24a b e f g)x
+--R         + 
+--R                 3 2 2      3                 2 2 2        2
+--R           (- 18b d g  + 24b d e f g)n + 12a b d g  - 24a b d e f g
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R                3 2 2 2        2 2 2       2   2 2  2
+--R           (- 6b e g n  + 12a b e g n - 12a b e g )x
+--R         + 
+--R                   3     2      3 2     2           2     2        2 2
+--R               (36b d e g  - 48b e f g)n  + (- 24a b d e g  + 48a b e f g)n
+--R             + 
+--R                    2   2
+--R               - 24a b e f g
+--R          *
+--R             x
+--R         + 
+--R               3 2 2      3            3 2 2  2
+--R           (36b d g  - 36b d e f g - 6b e f )n
+--R         + 
+--R                   2 2 2        2               2   2 2      2
+--R           (- 36a b d g  + 48a b d e f g)n + 12a b d g  - 24a b d e f g
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R          3 2 2 3 2     3 2     3         3 2 2     3         3             3
+--R       (4b e g n x  + 8b e f g n x + (- 4b d g  + 8b d e f g)n )log(e x + d)
+--R     + 
+--R               3 2 2 2 2      3 2     2          3 2 2      3         2
+--R           (12b e g n x  + 24b e f g n x + (- 12b d g  + 24b d e f g)n )log(c)
+--R         + 
+--R                3 2 2 3        2 2 2 2  2
+--R           (- 6b e g n  + 12a b e g n )x
+--R         + 
+--R                3     2      3 2     3        2 2     2
+--R           ((12b d e g  - 24b e f g)n  + 24a b e f g n )x
+--R         + 
+--R               3 2 2      3         3           2 2 2        2         2
+--R           (18b d g  - 24b d e f g)n  + (- 12a b d g  + 24a b d e f g)n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R               3 2 2   2      3 2                3 2 2      3                2
+--R           (12b e g n x  + 24b e f g n x + (- 12b d g  + 24b d e f g)n)log(c)
+--R         + 
+--R                     3 2 2 2        2 2 2   2
+--R               (- 12b e g n  + 24a b e g n)x
+--R             + 
+--R                    3     2      3 2     2        2 2
+--R               ((24b d e g  - 48b e f g)n  + 48a b e f g n)x
+--R             + 
+--R                   3 2 2      3         2           2 2 2        2
+--R               (36b d g  - 48b d e f g)n  + (- 24a b d g  + 48a b d e f g)n
+--R          *
+--R             log(c)
+--R         + 
+--R              3 2 2 3        2 2 2 2      2   2 2   2
+--R           (6b e g n  - 12a b e g n  + 12a b e g n)x
+--R         + 
+--R                     3     2      3 2     3         2     2        2 2     2
+--R               (- 36b d e g  + 48b e f g)n  + (24a b d e g  - 48a b e f g)n
+--R             + 
+--R                  2   2
+--R               24a b e f g n
+--R          *
+--R             x
+--R         + 
+--R                 3 2 2      3            3 2 2  3
+--R           (- 36b d g  + 36b d e f g + 6b e f )n
+--R         + 
+--R                 2 2 2        2         2         2   2 2      2
+--R           (36a b d g  - 48a b d e f g)n  + (- 12a b d g  + 24a b d e f g)n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R          3 2 2 2     3 2            3
+--R       (4b e g x  + 8b e f g x)log(c)
+--R     + 
+--R                3 2 2         2 2 2  2
+--R           (- 6b e g n + 12a b e g )x
+--R         + 
+--R                3     2      3 2             2 2
+--R           ((12b d e g  - 24b e f g)n + 24a b e f g)x
+--R      *
+--R               2
+--R         log(c)
+--R     + 
+--R              3 2 2 2        2 2 2       2   2 2  2
+--R           (6b e g n  - 12a b e g n + 12a b e g )x
+--R         + 
+--R                     3     2      3 2     2         2     2        2 2
+--R               (- 36b d e g  + 48b e f g)n  + (24a b d e g  - 48a b e f g)n
+--R             + 
+--R                  2   2
+--R               24a b e f g
+--R          *
+--R             x
+--R      *
+--R         log(c)
+--R     + 
+--R         3 2 2 3       2 2 2 2         2   2 2      2                3 2 2
+--R       3b e f n  - 6a b e f n  + (- 18a b d g  + 24a b d e f g)n + 4a d g
+--R     + 
+--R           3
+--R       - 8a d e f g
+--R  /
+--R       2
+--R     8e g
+--R                                                    Type: Expression(Integer)
+--E 1429
+
+--S 1430 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1430
+
+)clear all
+
+--S 1431 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1431
+
+--S 1432 of 5341
+r0:=6*a*b^2*n^2*x-6*b^3*n^3*x+6*b^3*n^2*(d+e*x)*log(c*(d+e*x)^n)/e-3*b*n*_
+   (d+e*x)*(a+b*log(c*(d+e*x)^n))^2/e+(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/e
+--R 
+--R
+--R   (2)
+--R         3       3                 n 3
+--R       (b e x + b d)log(c (e x + d) )
+--R     + 
+--R             3          2        3          2                 n 2
+--R       ((- 3b e n + 3a b e)x - 3b d n + 3a b d)log(c (e x + d) )
+--R     + 
+--R             3   2       2        2          3   2       2        2
+--R         ((6b e n  - 6a b e n + 3a b e)x + 6b d n  - 6a b d n + 3a b d)
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R            3   3       2   2     2         3        2         3
+--R       (- 6b e n  + 6a b e n  - 3a b e n + a e)x - 3a b d n + a d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 1432
+
+--S 1433 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3   3     3   3             3
+--R       (b e n x + b d n )log(e x + d)
+--R     + 
+--R              3   2      3   2               3   3       2   2       3   3
+--R           (3b e n x + 3b d n )log(c) + (- 3b e n  + 3a b e n )x - 3b d n
+--R         + 
+--R               2   2
+--R           3a b d n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R              3          3          2
+--R           (3b e n x + 3b d n)log(c)
+--R         + 
+--R                 3   2       2          3   2       2
+--R           ((- 6b e n  + 6a b e n)x - 6b d n  + 6a b d n)log(c)
+--R         + 
+--R              3   3       2   2     2            3   3       2   2     2
+--R           (6b e n  - 6a b e n  + 3a b e n)x + 6b d n  - 6a b d n  + 3a b d n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R        3          3        3          2          2
+--R       b e x log(c)  + (- 3b e n + 3a b e)x log(c)
+--R     + 
+--R          3   2       2        2
+--R       (6b e n  - 6a b e n + 3a b e)x log(c)
+--R     + 
+--R            3   3       2   2     2         3
+--R       (- 6b e n  + 6a b e n  - 3a b e n + a e)x
+--R  /
+--R     e
+--R                                         Type: Union(Expression(Integer),...)
+--E 1433
+
+--S 1434 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3       3                 n 3
+--R       (- b e x - b d)log(c (e x + d) )
+--R     + 
+--R           3          2        3          2                 n 2
+--R       ((3b e n - 3a b e)x + 3b d n - 3a b d)log(c (e x + d) )
+--R     + 
+--R               3   2       2        2          3   2       2        2
+--R         ((- 6b e n  + 6a b e n - 3a b e)x - 6b d n  + 6a b d n - 3a b d)
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R         3   3     3   3             3
+--R       (b e n x + b d n )log(e x + d)
+--R     + 
+--R              3   2      3   2               3   3       2   2       3   3
+--R           (3b e n x + 3b d n )log(c) + (- 3b e n  + 3a b e n )x - 3b d n
+--R         + 
+--R               2   2
+--R           3a b d n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R              3          3          2
+--R           (3b e n x + 3b d n)log(c)
+--R         + 
+--R                 3   2       2          3   2       2
+--R           ((- 6b e n  + 6a b e n)x - 6b d n  + 6a b d n)log(c)
+--R         + 
+--R              3   3       2   2     2            3   3       2   2     2
+--R           (6b e n  - 6a b e n  + 3a b e n)x + 6b d n  - 6a b d n  + 3a b d n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R        3          3        3          2          2
+--R       b e x log(c)  + (- 3b e n + 3a b e)x log(c)
+--R     + 
+--R          3   2       2        2                 2         3
+--R       (6b e n  - 6a b e n + 3a b e)x log(c) + 3a b d n - a d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 1434
+
+--S 1435 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1435
+
+)clear all
+
+--S 1436 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^3/(f+g*x)
+--R 
+--R
+--R   (1)
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R   ----------------------------------------------------------------------------
+--R                                      g x + f
+--R                                                    Type: Expression(Integer)
+--E 1436
+
+--S 1437 of 5341
+--r0:=(a+b*log(c*(d+e*x)^n))^3*log(e*(f+g*x)/(e*f-d*g))/g+3*b*n*(a+b*log(c*_
+--   (d+e*x)^n))^2*polylog(2,-g*(d+e*x)/(e*f-d*g))/g-6*b^2*n^2*(a+b*log(c*_
+--   (d+e*x)^n))*polylog(3,-g*(d+e*x)/(e*f-d*g))/g+6*b^3*n^3*polylog(4,_
+--   -g*(d+e*x)/(e*f-d*g))/g
+--E 1437
+
+--S 1438 of 5341
+--a0:=integrate(t0,x)
+--E 1438
+
+--S 1439 of 5341
+--m0:=a0-r0
+--E 1439
+
+--S 1440 of 5341
+--d0:=D(m0,x)
+--E 1440
+
+)clear all
+
+--S 1441 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^3/(f+g*x)^2
+--R 
+--R
+--R   (1)
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R   ----------------------------------------------------------------------------
+--R                                 2 2             2
+--R                                g x  + 2f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1441
+
+--S 1442 of 5341
+--r0:=(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/((e*f-d*g)*(f+g*x))-3*b*e*n*(a+_
+--   b*log(c*(d+e*x)^n))^2*log(e*(f+g*x)/(e*f-d*g))/(g*(e*f-d*g))-_
+--   6*b^2*e*n^2*(a+b*log(c*(d+e*x)^n))*polylog(2,-g*(d+e*x)/(e*f-d*g))/_
+--   (g*(e*f-d*g))+6*b^3*e*n^3*polylog(3,-g*(d+e*x)/(e*f-d*g))/(g*(e*f-d*g))
+--E 1442
+
+--S 1443 of 5341
+--a0:=integrate(t0,x)
+--E 1443
+
+--S 1444 of 5341
+--m0:=a0-r0
+--E 1444
+
+--S 1445 of 5341
+--d0:=D(m0,x)
+--E 1445
+
+)clear all
+
+--S 1446 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^3/(f+g*x)^3
+--R 
+--R
+--R   (1)
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R   ----------------------------------------------------------------------------
+--R                            3 3       2 2     2       3
+--R                           g x  + 3f g x  + 3f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1446
+
+--S 1447 of 5341
+--r0:=-3/2*b*e*n*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/((e*f-d*g)^2*(f+g*x))+_
+--   1/2*(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/((e*f-d*g)*(f+g*x)^2)+_
+--   1/2*e*(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/((e*f-d*g)^2*(f+g*x))+_
+--   3*b^2*e^2*n^2*(a+b*log(c*(d+e*x)^n))*log(e*(f+g*x)/(e*f-d*g))/_
+--   (g*(e*f-d*g)^2)-3/2*b*e^2*n*(a+b*log(c*(d+e*x)^n))^2*log(e*(f+g*x)/_
+--   (e*f-d*g))/(g*(e*f-d*g)^2)+3*b^3*e^2*n^3*polylog(2,-g*(d+e*x)/_
+--   (e*f-d*g))/(g*(e*f-d*g)^2)-3*b^2*e^2*n^2*(a+b*log(c*(d+e*x)^n))*_
+--   polylog(2,-g*(d+e*x)/(e*f-d*g))/(g*(e*f-d*g)^2)+3*b^3*e^2*n^3*_
+--   polylog(3,-g*(d+e*x)/(e*f-d*g))/(g*(e*f-d*g)^2)
+--E 1447
+
+--S 1448 of 5341
+--a0:=integrate(t0,x)
+--E 1448
+
+--S 1449 of 5341
+--m0:=a0-r0
+--E 1449
+
+--S 1450 of 5341
+--d0:=D(m0,x)
+--E 1450
+
+)clear all
+
+--S 1451 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^3/(f+g*x)^4
+--R 
+--R
+--R   (1)
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R   ----------------------------------------------------------------------------
+--R                       4 4       3 3     2 2 2     3       4
+--R                      g x  + 4f g x  + 6f g x  + 4f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1451
+
+--S 1452 of 5341
+--r0:=b^3*e^3*n^3*log(d+e*x)/(g*(e*f-d*g)^3)-b^2*e^2*n^2*(a+b*log(c*(d+_
+--   e*x)^n))/(g*(e*f-d*g)^2*(f+g*x))-1/2*b*e*n*(d+e*x)*(a+b*log(c*(d+_
+--   e*x)^n))^2/((e*f-d*g)^2*(f+g*x)^2)-3/2*b*e^2*n*(d+e*x)*(a+b*log(c*(d+_
+--   e*x)^n))^2/((e*f-d*g)^3*(f+g*x))+1/3*(d+e*x)*(a+b*log(c*(d+_
+--   e*x)^n))^3/((e*f-d*g)*(f+g*x)^3)+1/3*e*(d+e*x)*(a+b*log(c*(d+_
+--   e*x)^n))^3/((e*f-d*g)^2*(f+g*x)^2)+1/3*e^2*(d+e*x)*(a+b*log(c*(d+_
+--   e*x)^n))^3/((e*f-d*g)^3*(f+g*x))-b^3*e^3*n^3*log(f+g*x)/(g*(e*f-_
+--   d*g)^3)+3*b^2*e^3*n^2*(a+b*log(c*(d+e*x)^n))*log(e*(f+g*x)/(e*f-_
+--   d*g))/(g*(e*f-d*g)^3)-b*e^3*n*(a+b*log(c*(d+e*x)^n))^2*log(e*(f+_
+--   g*x)/(e*f-d*g))/(g*(e*f-d*g)^3)+3*b^3*e^3*n^3*polylog(2,-g*(d+_
+--   e*x)/(e*f-d*g))/(g*(e*f-d*g)^3)-2*b^2*e^3*n^2*(a+b*log(c*(d+_
+--   e*x)^n))*polylog(2,-g*(d+e*x)/(e*f-d*g))/(g*(e*f-d*g)^3)+2*b^3*_
+--   e^3*n^3*polylog(3,-g*(d+e*x)/(e*f-d*g))/(g*(e*f-d*g)^3)
+--E 1452
+
+--S 1453 of 5341
+--a0:=integrate(t0,x)
+--E 1453
+
+--S 1454 of 5341
+--m0:=a0-r0
+--E 1454
+
+--S 1455 of 5341
+--d0:=D(m0,x)
+--E 1455
+
+)clear all
+
+--S 1456 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^3/(f+g*x)^5
+--R 
+--R
+--R   (1)
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R   ----------------------------------------------------------------------------
+--R                 5 5       4 4      2 3 3      3 2 2     4       5
+--R                g x  + 5f g x  + 10f g x  + 10f g x  + 5f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1456
+
+--S 1457 of 5341
+--r0:=1/4*b^3*e^3*n^3/(g*(e*f-d*g)^3*(f+g*x))+3/2*b^3*e^4*n^3*_
+--  log(d+e*x)/(g*(e*f-d*g)^4)-1/4*b^2*e^2*n^2*(a+b*log(c*(d+e*x)^n))/_
+--  (g*(e*f-d*g)^2*(f+g*x)^2)-5/4*b^2*e^3*n^2*(a+b*log(c*(d+e*x)^n))/_
+--  (g*(e*f-d*g)^3*(f+g*x))-1/4*b*e*n*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/_
+--  ((e*f-d*g)^2*(f+g*x)^3)-5/8*b*e^2*n*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/_
+--  ((e*f-d*g)^3*(f+g*x)^2)-11/8*b*e^3*n*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/_
+--  ((e*f-d*g)^4*(f+g*x))+1/4*(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/((e*f-d*g)*_
+--  (f+g*x)^4)+1/4*e*(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/((e*f-d*g)^2*_
+--  (f+g*x)^3)+1/4*e^2*(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/((e*f-d*g)^3*_
+--  (f+g*x)^2)+1/4*e^3*(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/((e*f-d*g)^4*_
+--  (f+g*x))-3/2*b^3*e^4*n^3*log(f+g*x)/(g*(e*f-d*g)^4)+11/4*b^2*e^4*_
+--  n^2*(a+b*log(c*(d+e*x)^n))*log(e*(f+g*x)/(e*f-d*g))/(g*(e*f-d*g)^4)-_
+--  3/4*b*e^4*n*(a+b*log(c*(d+e*x)^n))^2*log(e*(f+g*x)/(e*f-d*g))/(g*_
+--  (e*f-d*g)^4)+11/4*b^3*e^4*n^3*polylog(2,-g*(d+e*x)/(e*f-d*g))/(g*_
+--  (e*f-d*g)^4)-3/2*b^2*e^4*n^2*(a+b*log(c*(d+e*x)^n))*polylog(2,-g*_
+--  (d+e*x)/(e*f-d*g))/(g*(e*f-d*g)^4)+3/2*b^3*e^4*n^3*polylog(3,-g*_
+--  (d+e*x)/(e*f-d*g))/(g*(e*f-d*g)^4)
+--E 1457
+
+--S 1458 of 5341
+--a0:=integrate(t0,x)
+--E 1458
+
+--S 1459 of 5341
+--m0:=a0-r0
+--E 1459
+
+--S 1460 of 5341
+--d0:=D(m0,x)
+--E 1460
+
+)clear all
+
+--S 1461 of 5341
+t0:=(f+g*x)^m/(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R                        m
+--R               (g x + f)
+--R   (1)  -----------------------
+--R                         n
+--R        b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1461
+
+--S 1462 of 5341
+--r0:=Int((f+g*x)^m/(a+b*log(c*(d+e*x)^n)),x)
+--E 1462
+
+--S 1463 of 5341
+--a0:=integrate(t0,x)
+--E 1463
+
+--S 1464 of 5341
+--m0:=a0-r0
+--E 1464
+
+--S 1465 of 5341
+--d0:=D(m0,x)
+--E 1465
+
+)clear all
+
+--S 1466 of 5341
+t0:=(f+g*x)^4/(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R         4 4       3 3     2 2 2     3       4
+--R        g x  + 4f g x  + 6f g x  + 4f g x + f
+--R   (1)  --------------------------------------
+--R                                 n
+--R                b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1466
+
+--S 1467 of 5341
+--r0:=(e*f-d*g)^4*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*_
+--  b*e^5*n*(c*(d+e*x)^n)^(1/n))+4*g*(e*f-d*g)^3*(d+e*x)^2*Ei(2*(a+_
+--  b*log(c*(d+e*x)^n))/(b*n))/(%e^(2*a/(b*n))*b*e^5*n*(c*(d+_
+--  e*x)^n)^(2/n))+6*g^2*(e*f-d*g)^2*(d+e*x)^3*Ei(3*(a+b*log(c*_
+--  (d+e*x)^n))/(b*n))/(%e^(3*a/(b*n))*b*e^5*n*(c*(d+e*x)^n)^(3/n))+_
+--  4*g^3*(e*f-d*g)*(d+e*x)^4*Ei(4*(a+b*log(c*(d+e*x)^n))/(b*n))/_
+--  (%e^(4*a/(b*n))*b*e^5*n*(c*(d+e*x)^n)^(4/n))+g^4*(d+e*x)^5*Ei(5*_
+--  (a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(5*a/(b*n))*b*e^5*n*(c*(d+e*x)^n)^(5/n))
+--E 1467
+
+--S 1468 of 5341
+--a0:=integrate(t0,x)
+--E 1468
+
+--S 1469 of 5341
+--m0:=a0-r0
+--E 1469
+
+--S 1470 of 5341
+--d0:=D(m0,x)
+--E 1470
+
+)clear all
+
+--S 1471 of 5341
+t0:=(f+g*x)^3/(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R         3 3       2 2     2       3
+--R        g x  + 3f g x  + 3f g x + f
+--R   (1)  ----------------------------
+--R                            n
+--R           b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1471
+
+--S 1472 of 5341
+--r0:=(e*f-d*g)^3*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*_
+--  b*e^4*n*(c*(d+e*x)^n)^(1/n))+3*g*(e*f-d*g)^2*(d+e*x)^2*Ei(2*(a+b*_
+--  log(c*(d+e*x)^n))/(b*n))/(%e^(2*a/(b*n))*b*e^4*n*(c*(d+e*x)^n)^(2/n))+_
+--  3*g^2*(e*f-d*g)*(d+e*x)^3*Ei(3*(a+b*log(c*(d+e*x)^n))/(b*n))/_
+--  (%e^(3*a/(b*n))*b*e^4*n*(c*(d+e*x)^n)^(3/n))+g^3*(d+e*x)^4*Ei(4*_
+--  (a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(4*a/(b*n))*b*e^4*n*(c*(d+e*x)^n)^(4/n))
+--E 1472
+
+--S 1473 of 5341
+--a0:=integrate(t0,x)
+--E 1473
+
+--S 1474 of 5341
+--m0:=a0-r0
+--E 1474
+
+--S 1475 of 5341
+--d0:=D(m0,x)
+--E 1475
+
+)clear all
+
+--S 1476 of 5341
+t0:=(f+g*x)^2/(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R            2 2             2
+--R           g x  + 2f g x + f
+--R   (1)  -----------------------
+--R                         n
+--R        b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1476
+
+--S 1477 of 5341
+--r0:=(e*f-d*g)^2*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*_
+--  b*e^3*n*(c*(d+e*x)^n)^(1/n))+2*g*(e*f-d*g)*(d+e*x)^2*Ei(2*(a+b*_
+--  log(c*(d+e*x)^n))/(b*n))/(%e^(2*a/(b*n))*b*e^3*n*(c*(d+e*x)^n)^(2/n))+_
+--  g^2*(d+e*x)^3*Ei(3*(a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(3*a/(b*n))*_
+--  b*e^3*n*(c*(d+e*x)^n)^(3/n))
+--E 1477
+
+--S 1478 of 5341
+--a0:=integrate(t0,x)
+--E 1478
+
+--S 1479 of 5341
+--m0:=a0-r0
+--E 1479
+
+--S 1480 of 5341
+--d0:=D(m0,x)
+--E 1480
+
+)clear all
+
+--S 1481 of 5341
+t0:=(f+g*x)/(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R                g x + f
+--R   (1)  -----------------------
+--R                         n
+--R        b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1481
+
+--S 1482 of 5341
+--r0:=(e*f-d*g)*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*_
+--  b*e^2*n*(c*(d+e*x)^n)^(1/n))+g*(d+e*x)^2*Ei(2*(a+b*log(c*(d+e*x)^n))/_
+--  (b*n))/(%e^(2*a/(b*n))*b*e^2*n*(c*(d+e*x)^n)^(2/n))
+--E 1482
+
+--S 1483 of 5341
+--a0:=integrate(t0,x)
+--E 1483
+
+--S 1484 of 5341
+--m0:=a0-r0
+--E 1484
+
+--S 1485 of 5341
+--d0:=D(m0,x)
+--E 1485
+
+)clear all
+
+--S 1486 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R                         n
+--R        b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1486
+
+--S 1487 of 5341
+--r0:=(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*_
+--  b*e*n*(c*(d+e*x)^n)^(1/n))
+--E 1487
+
+--S 1488 of 5341
+--a0:=integrate(t0,x)
+--E 1488
+
+--S 1489 of 5341
+--m0:=a0-r0
+--E 1489
+
+--S 1490 of 5341
+--d0:=D(m0,x)
+--E 1490
+
+)clear all
+
+--S 1491 of 5341
+t0:=1/((f+g*x)*(a+b*log(c*(d+e*x)^n)))
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R                                    n
+--R        (b g x + b f)log(c (e x + d) ) + a g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1491
+
+--S 1492 of 5341
+--r0:=Int(1/((f+g*x)*(a+b*log(c*(d+e*x)^n))),x)
+--E 1492
+
+--S 1493 of 5341
+--a0:=integrate(t0,x)
+--E 1493
+
+--S 1494 of 5341
+--m0:=a0-r0
+--E 1494
+
+--S 1495 of 5341
+--d0:=D(m0,x)
+--E 1495
+
+)clear all
+
+--S 1496 of 5341
+t0:=(f+g*x)^m/(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R                                     m
+--R                            (g x + f)
+--R   (1)  --------------------------------------------------
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1496
+
+--S 1497 of 5341
+--r0:=Int((f+g*x)^m/(a+b*log(c*(d+e*x)^n))^2,x)
+--E 1497
+
+--S 1498 of 5341
+--a0:=integrate(t0,x)
+--E 1498
+
+--S 1499 of 5341
+--m0:=a0-r0
+--E 1499
+
+--S 1500 of 5341
+--d0:=D(m0,x)
+--E 1500
+
+)clear all
+
+--S 1501 of 5341
+t0:=(f+g*x)^4/(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R               4 4       3 3     2 2 2     3       4
+--R              g x  + 4f g x  + 6f g x  + 4f g x + f
+--R   (1)  --------------------------------------------------
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1501
+
+--S 1502 of 5341
+--r0:=(e*f-d*g)^4*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*_
+--  b^2*e^5*n^2*(c*(d+e*x)^n)^(1/n))+8*g*(e*f-d*g)^3*(d+e*x)^2*Ei(2*_
+--  (a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(2*a/(b*n))*b^2*e^5*n^2*(c*_
+--  (d+e*x)^n)^(2/n))+18*g^2*(e*f-d*g)^2*(d+e*x)^3*Ei(3*(a+b*log(c*_
+--  (d+e*x)^n))/(b*n))/(%e^(3*a/(b*n))*b^2*e^5*n^2*(c*(d+e*x)^n)^(3/n))+_
+--  16*g^3*(e*f-d*g)*(d+e*x)^4*Ei(4*(a+b*log(c*(d+e*x)^n))/(b*n))/_
+--  (%e^(4*a/(b*n))*b^2*e^5*n^2*(c*(d+e*x)^n)^(4/n))+5*g^4*(d+e*x)^5*_
+--  Ei(5*(a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(5*a/(b*n))*b^2*e^5*n^2*_
+--  (c*(d+e*x)^n)^(5/n))-(d+e*x)*(f+g*x)^4/(b*e*n*(a+b*log(c*(d+e*x)^n)))
+--E 1502
+
+--S 1503 of 5341
+--a0:=integrate(t0,x)
+--E 1503
+
+--S 1504 of 5341
+--m0:=a0-r0
+--E 1504
+
+--S 1505 of 5341
+--d0:=D(m0,x)
+--E 1505
+
+)clear all
+
+--S 1506 of 5341
+t0:=(f+g*x)^3/(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R                    3 3       2 2     2       3
+--R                   g x  + 3f g x  + 3f g x + f
+--R   (1)  --------------------------------------------------
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1506
+
+--S 1507 of 5341
+--r0:=(e*f-d*g)^3*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*_
+--  b^2*e^4*n^2*(c*(d+e*x)^n)^(1/n))+6*g*(e*f-d*g)^2*(d+e*x)^2*Ei(2*_
+--  (a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(2*a/(b*n))*b^2*e^4*n^2*(c*_
+--  (d+e*x)^n)^(2/n))+9*g^2*(e*f-d*g)*(d+e*x)^3*Ei(3*(a+b*log(c*_
+--  (d+e*x)^n))/(b*n))/(%e^(3*a/(b*n))*b^2*e^4*n^2*(c*(d+e*x)^n)^(3/n))+_
+--  4*g^3*(d+e*x)^4*Ei(4*(a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(4*a/(b*n))*_
+--  b^2*e^4*n^2*(c*(d+e*x)^n)^(4/n))-(d+e*x)*(f+g*x)^3/(b*e*n*(a+_
+--  b*log(c*(d+e*x)^n)))
+--E 1507
+
+--S 1508 of 5341
+--a0:=integrate(t0,x)
+--E 1508
+
+--S 1509 of 5341
+--m0:=a0-r0
+--E 1509
+
+--S 1510 of 5341
+--d0:=D(m0,x)
+--E 1510
+
+)clear all
+
+--S 1511 of 5341
+t0:=(f+g*x)^2/(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R                         2 2             2
+--R                        g x  + 2f g x + f
+--R   (1)  --------------------------------------------------
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1511
+
+--S 1512 of 5341
+--r0:=(e*f-d*g)^2*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*_
+--  b^2*e^3*n^2*(c*(d+e*x)^n)^(1/n))+4*g*(e*f-d*g)*(d+e*x)^2*Ei(2*(a+_
+--  b*log(c*(d+e*x)^n))/(b*n))/(%e^(2*a/(b*n))*b^2*e^3*n^2*(c*_
+--  (d+e*x)^n)^(2/n))+3*g^2*(d+e*x)^3*Ei(3*(a+b*log(c*(d+e*x)^n))/(b*n))/_
+--  (%e^(3*a/(b*n))*b^2*e^3*n^2*(c*(d+e*x)^n)^(3/n))-(d+e*x)*(f+g*x)^2/_
+--  (b*e*n*(a+b*log(c*(d+e*x)^n)))
+--E 1512
+
+--S 1513 of 5341
+--a0:=integrate(t0,x)
+--E 1513
+
+--S 1514 of 5341
+--m0:=a0-r0
+--E 1514
+
+--S 1515 of 5341
+--d0:=D(m0,x)
+--E 1515
+
+)clear all
+
+--S 1516 of 5341
+t0:=(f+g*x)/(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R                              g x + f
+--R   (1)  --------------------------------------------------
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1516
+
+--S 1517 of 5341
+--r0:=(e*f-d*g)*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*b^2*_
+--  e^2*n^2*(c*(d+e*x)^n)^(1/n))+2*g*(d+e*x)^2*Ei(2*(a+b*log(c*(d+e*x)^n))/_
+--  (b*n))/(%e^(2*a/(b*n))*b^2*e^2*n^2*(c*(d+e*x)^n)^(2/n))-(d+e*x)*_
+--  (f+g*x)/(b*e*n*(a+b*log(c*(d+e*x)^n)))
+--E 1517
+
+--S 1518 of 5341
+--a0:=integrate(t0,x)
+--E 1518
+
+--S 1519 of 5341
+--m0:=a0-r0
+--E 1519
+
+--S 1520 of 5341
+--d0:=D(m0,x)
+--E 1520
+
+)clear all
+
+--S 1521 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R                                 1
+--R   (1)  --------------------------------------------------
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1521
+
+--S 1522 of 5341
+--r0:=(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*b^2*e*n^2*_
+--  (c*(d+e*x)^n)^(1/n))+(-d-e*x)/(b*e*n*(a+b*log(c*(d+e*x)^n)))
+--E 1522
+
+--S 1523 of 5341
+--a0:=integrate(t0,x)
+--E 1523
+
+--S 1524 of 5341
+--m0:=a0-r0
+--E 1524
+
+--S 1525 of 5341
+--d0:=D(m0,x)
+--E 1525
+
+)clear all
+
+--S 1526 of 5341
+t0:=1/((f+g*x)*(a+b*log(c*(d+e*x)^n))^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R         2       2                 n 2                                     n
+--R       (b g x + b f)log(c (e x + d) )  + (2a b g x + 2a b f)log(c (e x + d) )
+--R     + 
+--R        2       2
+--R       a g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1526
+
+--S 1527 of 5341
+--r0:=Int(1/((f+g*x)*(a+b*log(c*(d+e*x)^n))^2),x)
+--E 1527
+
+--S 1528 of 5341
+--a0:=integrate(t0,x)
+--E 1528
+
+--S 1529 of 5341
+--m0:=a0-r0
+--E 1529
+
+--S 1530 of 5341
+--d0:=D(m0,x)
+--E 1530
+
+)clear all
+
+--S 1531 of 5341
+t0:=(f+g*x)^m/(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R                                             m
+--R                                    (g x + f)
+--R   ----------------------------------------------------------------------------
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1531
+
+--S 1532 of 5341
+--r0:=Int((f+g*x)^m/(a+b*log(c*(d+e*x)^n))^3,x)
+--E 1532
+
+--S 1533 of 5341
+--a0:=integrate(t0,x)
+--E 1533
+
+--S 1534 of 5341
+--m0:=a0-r0
+--E 1534
+
+--S 1535 of 5341
+--d0:=D(m0,x)
+--E 1535
+
+)clear all
+
+--S 1536 of 5341
+t0:=(f+g*x)^4/(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R                       4 4       3 3     2 2 2     3       4
+--R                      g x  + 4f g x  + 6f g x  + 4f g x + f
+--R   ----------------------------------------------------------------------------
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1536
+
+--S 1537 of 5341
+--r0:=1/2*(e*f-d*g)^4*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/_
+--  (%e^(a/(b*n))*b^3*e^5*n^3*(c*(d+e*x)^n)^(1/n))+8*g*(e*f-d*g)^3*_
+--  (d+e*x)^2*Ei(2*(a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(2*a/(b*n))*b^3*_
+--  e^5*n^3*(c*(d+e*x)^n)^(2/n))+27*g^2*(e*f-d*g)^2*(d+e*x)^3*Ei(3*_
+--  (a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(3*a/(b*n))*b^3*e^5*n^3*(c*_
+--  (d+e*x)^n)^(3/n))+32*g^3*(e*f-d*g)*(d+e*x)^4*Ei(4*(a+b*log(c*_
+--  (d+e*x)^n))/(b*n))/(%e^(4*a/(b*n))*b^3*e^5*n^3*(c*(d+e*x)^n)^(4/n))+_
+--  25/2*g^4*(d+e*x)^5*Ei(5*(a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(5*a/(b*n))*_
+--  b^3*e^5*n^3*(c*(d+e*x)^n)^(5/n))-1/2*(d+e*x)*(f+g*x)^4/(b*e*n*(a+_
+--  b*log(c*(d+e*x)^n))^2)+2*(e*f-d*g)*(d+e*x)*(f+g*x)^3/(b^2*e^2*n^2*_
+--  (a+b*log(c*(d+e*x)^n)))-5/2*(d+e*x)*(f+g*x)^4/(b^2*e*n^2*(a+b*_
+--  log(c*(d+e*x)^n)))
+--E 1537
+
+--S 1538 of 5341
+--a0:=integrate(t0,x)
+--E 1538
+
+--S 1539 of 5341
+--m0:=a0-r0
+--E 1539
+
+--S 1540 of 5341
+--d0:=D(m0,x)
+--E 1540
+
+)clear all
+
+--S 1541 of 5341
+t0:=(f+g*x)^3/(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R                            3 3       2 2     2       3
+--R                           g x  + 3f g x  + 3f g x + f
+--R   ----------------------------------------------------------------------------
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1541
+
+--S 1542 of 5341
+--r0:=1/2*(e*f-d*g)^3*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/_
+--  (%e^(a/(b*n))*b^3*e^4*n^3*(c*(d+e*x)^n)^(1/n))+6*g*(e*f-d*g)^2*_
+--  (d+e*x)^2*Ei(2*(a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(2*a/(b*n))*b^3*_
+--  e^4*n^3*(c*(d+e*x)^n)^(2/n))+27/2*g^2*(e*f-d*g)*(d+e*x)^3*Ei(3*_
+--  (a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(3*a/(b*n))*b^3*e^4*n^3*(c*(d+_
+--  e*x)^n)^(3/n))+8*g^3*(d+e*x)^4*Ei(4*(a+b*log(c*(d+e*x)^n))/(b*n))/_
+--  (%e^(4*a/(b*n))*b^3*e^4*n^3*(c*(d+e*x)^n)^(4/n))-1/2*(d+e*x)*_
+--  (f+g*x)^3/(b*e*n*(a+b*log(c*(d+e*x)^n))^2)+3/2*(e*f-d*g)*(d+e*x)*_
+--  (f+g*x)^2/(b^2*e^2*n^2*(a+b*log(c*(d+e*x)^n)))-2*(d+e*x)*(f+g*x)^3/_
+--  (b^2*e*n^2*(a+b*log(c*(d+e*x)^n)))
+--E 1542
+
+--S 1543 of 5341
+--a0:=integrate(t0,x)
+--E 1543
+
+--S 1544 of 5341
+--m0:=a0-r0
+--E 1544
+
+--S 1545 of 5341
+--d0:=D(m0,x)
+--E 1545
+
+)clear all
+
+--S 1546 of 5341
+t0:=(f+g*x)^2/(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R                                 2 2             2
+--R                                g x  + 2f g x + f
+--R   ----------------------------------------------------------------------------
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1546
+
+--S 1547 of 5341
+--r0:=1/2*(e*f-d*g)^2*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/_
+--  (%e^(a/(b*n))*b^3*e^3*n^3*(c*(d+e*x)^n)^(1/n))+4*g*(e*f-d*g)*_
+--  (d+e*x)^2*Ei(2*(a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(2*a/(b*n))*b^3*_
+--  e^3*n^3*(c*(d+e*x)^n)^(2/n))+9/2*g^2*(d+e*x)^3*Ei(3*(a+b*log(c*_
+--  (d+e*x)^n))/(b*n))/(%e^(3*a/(b*n))*b^3*e^3*n^3*(c*(d+e*x)^n)^(3/n))-_
+--  1/2*(d+e*x)*(f+g*x)^2/(b*e*n*(a+b*log(c*(d+e*x)^n))^2)+(e*f-d*g)*_
+--  (d+e*x)*(f+g*x)/(b^2*e^2*n^2*(a+b*log(c*(d+e*x)^n)))-3/2*(d+e*x)*_
+--  (f+g*x)^2/(b^2*e*n^2*(a+b*log(c*(d+e*x)^n)))
+--E 1547
+
+--S 1548 of 5341
+--a0:=integrate(t0,x)
+--E 1548
+
+--S 1549 of 5341
+--m0:=a0-r0
+--E 1549
+
+--S 1550 of 5341
+--d0:=D(m0,x)
+--E 1550
+
+)clear all
+
+--S 1551 of 5341
+t0:=(f+g*x)/(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R                                      g x + f
+--R   ----------------------------------------------------------------------------
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1551
+
+--S 1552 of 5341
+--r0:=1/2*(e*f-d*g)*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*_
+--  b^3*e^2*n^3*(c*(d+e*x)^n)^(1/n))+2*g*(d+e*x)^2*Ei(2*(a+b*log(c*_
+--  (d+e*x)^n))/(b*n))/(%e^(2*a/(b*n))*b^3*e^2*n^3*(c*(d+e*x)^n)^(2/n))-_
+--  1/2*(d+e*x)*(f+g*x)/(b*e*n*(a+b*log(c*(d+e*x)^n))^2)+1/2*(e*f-d*g)*_
+--  (d+e*x)/(b^2*e^2*n^2*(a+b*log(c*(d+e*x)^n)))-(d+e*x)*(f+g*x)/(b^2*e*_
+--  n^2*(a+b*log(c*(d+e*x)^n)))
+--E 1552
+
+--S 1553 of 5341
+--a0:=integrate(t0,x)
+--E 1553
+
+--S 1554 of 5341
+--m0:=a0-r0
+--E 1554
+
+--S 1555 of 5341
+--d0:=D(m0,x)
+--E 1555
+
+)clear all
+
+--S 1556 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R                                         1
+--R   ----------------------------------------------------------------------------
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1556
+
+--S 1557 of 5341
+--r0:=1/2*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*b^3*e*_
+--  n^3*(c*(d+e*x)^n)^(1/n))+1/2*(-d-e*x)/(b*e*n*(a+b*log(c*(d+e*x)^n))^2)+_
+--  1/2*(-d-e*x)/(b^2*e*n^2*(a+b*log(c*(d+e*x)^n)))
+--E 1557
+
+--S 1558 of 5341
+--a0:=integrate(t0,x)
+--E 1558
+
+--S 1559 of 5341
+--m0:=a0-r0
+--E 1559
+
+--S 1560 of 5341
+--d0:=D(m0,x)
+--E 1560
+
+)clear all
+
+--S 1561 of 5341
+t0:=1/((f+g*x)*(a+b*log(c*(d+e*x)^n))^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R         3       3                 n 3        2          2                 n 2
+--R       (b g x + b f)log(c (e x + d) )  + (3a b g x + 3a b f)log(c (e x + d) )
+--R     + 
+--R          2          2                   n     3       3
+--R       (3a b g x + 3a b f)log(c (e x + d) ) + a g x + a f
+--R                                                    Type: Expression(Integer)
+--E 1561
+
+--S 1562 of 5341
+--r0:=Int(1/((f+g*x)*(a+b*log(c*(d+e*x)^n))^3),x)
+--E 1562
+
+--S 1563 of 5341
+--a0:=integrate(t0,x)
+--E 1563
+
+--S 1564 of 5341
+--m0:=a0-r0
+--E 1564
+
+--S 1565 of 5341
+--d0:=D(m0,x)
+--E 1565
+
+)clear all
+
+--S 1566 of 5341
+t0:=(f+g*x)^3*(a+b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R                                       +-----------------------+
+--R          3 3       2 2     2       3  |                 n
+--R   (1)  (g x  + 3f g x  + 3f g x + f )\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1566
+
+--S 1567 of 5341
+--r0:=-1/8*g^2*(e*f-d*g)*(d+e*x)^3*erfi(sqrt(3)*sqrt(a+b*log(c*(d+e*x)^n))/_
+--  (sqrt(b)*sqrt(n)))*sqrt(1/3*%pi)*sqrt(b)*sqrt(n)/(%e^(3*a/(b*n))*e^4*_
+--  (c*(d+e*x)^n)^(3/n))-3/4*g*(e*f-d*g)^2*(d+e*x)^2*erfi(sqrt(2)*_
+--  sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(1/2*%pi)*sqrt(b)*_
+--  sqrt(n)/(%e^(2*a/(b*n))*e^4*(c*(d+e*x)^n)^(2/n))-1/2*(e*f-d*g)^3*_
+--  (d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)*_
+--  sqrt(b)*sqrt(n)/(%e^(a/(b*n))*e^4*(c*(d+e*x)^n)^(1/n))-1/16*g^3*_
+--  (d+e*x)^4*erfi(2*sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(%pi)*sqrt(b)*sqrt(n)/(%e^(4*a/(b*n))*e^4*(c*(d+e*x)^n)^(4/n))-_
+--  1/8*g^2*(e*f-d*g)*(d+e*x)^3*erfi(sqrt(3)*sqrt(a+b*log(c*(d+e*x)^n))/_
+--  (sqrt(b)*sqrt(n)))*sqrt(3*%pi)*sqrt(b)*sqrt(n)/(%e^(3*a/(b*n))*e^4*_
+--  (c*(d+e*x)^n)^(3/n))+1/4*(e*f-d*g)^3*(d+e*x)*sqrt(a+b*log(c*_
+--  (d+e*x)^n))/e^4+1/4*(e*f-d*g)^2*(d+e*x)*(f+g*x)*sqrt(a+b*log(c*_
+--  (d+e*x)^n))/e^3+1/4*(e*f-d*g)*(d+e*x)*(f+g*x)^2*sqrt(a+b*log(c*_
+--  (d+e*x)^n))/e^2+1/4*(d+e*x)*(f+g*x)^3*sqrt(a+b*log(c*(d+e*x)^n))/e
+--E 1567
+
+--S 1568 of 5341
+--a0:=integrate(t0,x)
+--E 1568
+
+--S 1569 of 5341
+--m0:=a0-r0
+--E 1569
+
+--S 1570 of 5341
+--d0:=D(m0,x)
+--E 1570
+
+)clear all
+
+--S 1571 of 5341
+t0:=(f+g*x)^2*(a+b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R                             +-----------------------+
+--R          2 2             2  |                 n
+--R   (1)  (g x  + 2f g x + f )\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1571
+
+--S 1572 of 5341
+--r0:=-1/6*g^2*(d+e*x)^3*erfi(sqrt(3)*sqrt(a+b*log(c*(d+e*x)^n))/_
+--  (sqrt(b)*sqrt(n)))*sqrt(1/3*%pi)*sqrt(b)*sqrt(n)/(%e^(3*a/(b*n))*_
+--  e^3*(c*(d+e*x)^n)^(3/n))-1/2*g*(e*f-d*g)*(d+e*x)^2*erfi(sqrt(2)*_
+--  sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(1/2*%pi)*sqrt(b)*_
+--  sqrt(n)/(%e^(2*a/(b*n))*e^3*(c*(d+e*x)^n)^(2/n))-1/2*(e*f-d*g)^2*_
+--  (d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)*_
+--  sqrt(b)*sqrt(n)/(%e^(a/(b*n))*e^3*(c*(d+e*x)^n)^(1/n))+_
+--  1/3*(e*f-d*g)^2*(d+e*x)*sqrt(a+b*log(c*(d+e*x)^n))/e^3+_
+--  1/3*(e*f-d*g)*(d+e*x)*(f+g*x)*sqrt(a+b*log(c*(d+e*x)^n))/e^2+_
+--  1/3*(d+e*x)*(f+g*x)^2*sqrt(a+b*log(c*(d+e*x)^n))/e
+--E 1572
+
+--S 1573 of 5341
+--a0:=integrate(t0,x)
+--E 1573
+
+--S 1574 of 5341
+--m0:=a0-r0
+--E 1574
+
+--S 1575 of 5341
+--d0:=D(m0,x)
+--E 1575
+
+)clear all
+
+--S 1576 of 5341
+t0:=(f+g*x)*(a+b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R                  +-----------------------+
+--R                  |                 n
+--R   (1)  (g x + f)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1576
+
+--S 1577 of 5341
+--r0:=-1/4*g*(d+e*x)^2*erfi(sqrt(2)*sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*_
+--  sqrt(n)))*sqrt(1/2*%pi)*sqrt(b)*sqrt(n)/(%e^(2*a/(b*n))*e^2*(c*_
+--  (d+e*x)^n)^(2/n))-1/2*(e*f-d*g)*(d+e*x)*erfi(sqrt(a+b*log(c*_
+--  (d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)*sqrt(b)*sqrt(n)/_
+--  (%e^(a/(b*n))*e^2*(c*(d+e*x)^n)^(1/n))+1/2*(e*f-d*g)*(d+e*x)*_
+--  sqrt(a+b*log(c*(d+e*x)^n))/e^2+1/2*(d+e*x)*(f+g*x)*sqrt(a+b*_
+--  log(c*(d+e*x)^n))/e
+--E 1577
+
+--S 1578 of 5341
+--a0:=integrate(t0,x)
+--E 1578
+
+--S 1579 of 5341
+--m0:=a0-r0
+--E 1579
+
+--S 1580 of 5341
+--d0:=D(m0,x)
+--E 1580
+
+)clear all
+
+--S 1581 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R         +-----------------------+
+--R         |                 n
+--R   (1)  \|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1581
+
+--S 1582 of 5341
+--r0:=-1/2*(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(%pi)*sqrt(b)*sqrt(n)/(%e^(a/(b*n))*e*(c*(d+e*x)^n)^(1/n))+(d+e*x)*_
+--  sqrt(a+b*log(c*(d+e*x)^n))/e
+--E 1582
+
+--S 1583 of 5341
+--a0:=integrate(t0,x)
+--E 1583
+
+--S 1584 of 5341
+--m0:=a0-r0
+--E 1584
+
+--S 1585 of 5341
+--d0:=D(m0,x)
+--E 1585
+
+)clear all
+
+--S 1586 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^(1/2)/(f+g*x)
+--R 
+--R
+--R         +-----------------------+
+--R         |                 n
+--R        \|b log(c (e x + d) ) + a
+--R   (1)  --------------------------
+--R                  g x + f
+--R                                                    Type: Expression(Integer)
+--E 1586
+
+--S 1587 of 5341
+--r0:=-1/2*b*e*n*Int(log(e*f/(e*f-d*g)+e*g*x/(e*f-d*g))/((d+e*x)*_
+--  sqrt(a+b*log(c*(d+e*x)^n))),x)/g+log(e*(f+g*x)/(e*f-d*g))*_
+--  sqrt(a+b*log(c*(d+e*x)^n))/g
+--E 1587
+
+--S 1588 of 5341
+--a0:=integrate(t0,x)
+--E 1588
+
+--S 1589 of 5341
+--m0:=a0-r0
+--E 1589
+
+--S 1590 of 5341
+--d0:=D(m0,x)
+--E 1590
+
+)clear all
+
+--S 1591 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^(1/2)/(f+g*x)^2
+--R 
+--R
+--R         +-----------------------+
+--R         |                 n
+--R        \|b log(c (e x + d) ) + a
+--R   (1)  --------------------------
+--R             2 2             2
+--R            g x  + 2f g x + f
+--R                                                    Type: Expression(Integer)
+--E 1591
+
+--S 1592 of 5341
+--r0:=-1/2*b*e*n*Int(1/((f+g*x)*sqrt(a+b*log(c*(d+e*x)^n))),x)/(e*f-d*g)+_
+--  (d+e*x)*sqrt(a+b*log(c*(d+e*x)^n))/((e*f-d*g)*(f+g*x))
+--E 1592
+
+--S 1593 of 5341
+--a0:=integrate(t0,x)
+--E 1593
+
+--S 1594 of 5341
+--m0:=a0-r0
+--E 1594
+
+--S 1595 of 5341
+--d0:=D(m0,x)
+--E 1595
+
+)clear all
+
+--S 1596 of 5341
+t0:=(f+g*x)^2*(a+b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R   (1)
+--R          2 2                 2                n       2 2                 2
+--R     ((b g x  + 2b f g x + b f )log(c (e x + d) ) + a g x  + 2a f g x + a f )
+--R  *
+--R      +-----------------------+
+--R      |                 n
+--R     \|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1596
+
+--S 1597 of 5341
+--r0:=1/3*(e*f-d*g)^2*(d+e*x)*(a+b*log(c*(d+e*x)^n))^(3/2)/e^3+1/3*_
+--  (e*f-d*g)*(d+e*x)*(f+g*x)*(a+b*log(c*(d+e*x)^n))^(3/2)/e^2+1/3*_
+--  (d+e*x)*(f+g*x)^2*(a+b*log(c*(d+e*x)^n))^(3/2)/e+1/12*b^(3/2)*g^2*_
+--  n^(3/2)*(d+e*x)^3*erfi(sqrt(3)*sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*_
+--  sqrt(n)))*sqrt(1/3*%pi)/(%e^(3*a/(b*n))*e^3*(c*(d+e*x)^n)^(3/n))+_
+--  3/8*b^(3/2)*g*(e*f-d*g)*n^(3/2)*(d+e*x)^2*erfi(sqrt(2)*sqrt(a+b*_
+--  log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(1/2*%pi)/(%e^(2*a/(b*n))*_
+--  e^3*(c*(d+e*x)^n)^(2/n))+3/4*b^(3/2)*(e*f-d*g)^2*n^(3/2)*(d+e*x)*_
+--  erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)/_
+--  (%e^(a/(b*n))*e^3*(c*(d+e*x)^n)^(1/n))-11/12*b*(e*f-d*g)^2*n*_
+--  (d+e*x)*sqrt(a+b*log(c*(d+e*x)^n))/e^3-5/12*b*(e*f-d*g)*n*(d+e*x)*_
+--  (f+g*x)*sqrt(a+b*log(c*(d+e*x)^n))/e^2-1/6*b*n*(d+e*x)*(f+g*x)^2*_
+--  sqrt(a+b*log(c*(d+e*x)^n))/e
+--E 1597
+
+--S 1598 of 5341
+--a0:=integrate(t0,x)
+--E 1598
+
+--S 1599 of 5341
+--m0:=a0-r0
+--E 1599
+
+--S 1600 of 5341
+--d0:=D(m0,x)
+--E 1600
+
+)clear all
+
+--S 1601 of 5341
+t0:=(f+g*x)*(a+b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R   (1)
+--R                                                  +-----------------------+
+--R                                n                 |                 n
+--R   ((b g x + b f)log(c (e x + d) ) + a g x + a f)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1601
+
+--S 1602 of 5341
+--r0:=1/2*(e*f-d*g)*(d+e*x)*(a+b*log(c*(d+e*x)^n))^(3/2)/e^2+1/2*(d+e*x)*_
+--  (f+g*x)*(a+b*log(c*(d+e*x)^n))^(3/2)/e+3/16*b^(3/2)*g*n^(3/2)*_
+--  (d+e*x)^2*erfi(sqrt(2)*sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(1/2*%pi)/(%e^(2*a/(b*n))*e^2*(c*(d+e*x)^n)^(2/n))+3/4*b^(3/2)*_
+--  (e*f-d*g)*n^(3/2)*(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*_
+--  sqrt(n)))*sqrt(%pi)/(%e^(a/(b*n))*e^2*(c*(d+e*x)^n)^(1/n))-9/8*b*_
+--  (e*f-d*g)*n*(d+e*x)*sqrt(a+b*log(c*(d+e*x)^n))/e^2-3/8*b*n*(d+e*x)*_
+--  (f+g*x)*sqrt(a+b*log(c*(d+e*x)^n))/e
+--E 1602
+
+--S 1603 of 5341
+--a0:=integrate(t0,x)
+--E 1603
+
+--S 1604 of 5341
+--m0:=a0-r0
+--E 1604
+
+--S 1605 of 5341
+--d0:=D(m0,x)
+--E 1605
+
+)clear all
+
+--S 1606 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R                                  +-----------------------+
+--R                          n       |                 n
+--R   (1)  (b log(c (e x + d) ) + a)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1606
+
+--S 1607 of 5341
+--r0:=(d+e*x)*(a+b*log(c*(d+e*x)^n))^(3/2)/e+3/4*b^(3/2)*n^(3/2)*(d+e*x)*_
+--  erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)/_
+--  (%e^(a/(b*n))*e*(c*(d+e*x)^n)^(1/n))-3/2*b*n*(d+e*x)*sqrt(a+b*_
+--  log(c*(d+e*x)^n))/e
+--E 1607
+
+--S 1608 of 5341
+--a0:=integrate(t0,x)
+--E 1608
+
+--S 1609 of 5341
+--m0:=a0-r0
+--E 1609
+
+--S 1610 of 5341
+--d0:=D(m0,x)
+--E 1610
+
+)clear all
+
+--S 1611 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^(3/2)/(f+g*x)
+--R 
+--R
+--R                                  +-----------------------+
+--R                          n       |                 n
+--R        (b log(c (e x + d) ) + a)\|b log(c (e x + d) ) + a
+--R   (1)  ---------------------------------------------------
+--R                              g x + f
+--R                                                    Type: Expression(Integer)
+--E 1611
+
+--S 1612 of 5341
+--r0:=-3/4*b^2*e*n^2*Int(polylog(2,(-d*g-e*g*x)/(e*f-d*g))/((d+e*x)*_
+--  sqrt(a+b*log(c*(d+e*x)^n))),x)/g+(a+b*log(c*(d+e*x)^n))^(3/2)*_
+--  log(e*(f+g*x)/(e*f-d*g))/g+3/2*b*n*polylog(2,-g*(d+e*x)/(e*f-d*g))*_
+--  sqrt(a+b*log(c*(d+e*x)^n))/g
+--E 1612
+
+--S 1613 of 5341
+--a0:=integrate(t0,x)
+--E 1613
+
+--S 1614 of 5341
+--m0:=a0-r0
+--E 1614
+
+--S 1615 of 5341
+--d0:=D(m0,x)
+--E 1615
+
+)clear all
+
+--S 1616 of 5341
+t0:=(f+g*x)^3/(a+b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R         3 3       2 2     2       3
+--R        g x  + 3f g x  + 3f g x + f
+--R   (1)  ----------------------------
+--R          +-----------------------+
+--R          |                 n
+--R         \|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1616
+
+--S 1617 of 5341
+--r0:=3*g*(e*f-d*g)^2*(d+e*x)^2*erfi(sqrt(2)*sqrt(a+b*log(c*(d+e*x)^n))/_
+--  (sqrt(b)*sqrt(n)))*sqrt(1/2*%pi)/(%e^(2*a/(b*n))*e^4*(c*_
+--  (d+e*x)^n)^(2/n)*sqrt(b)*sqrt(n))+(e*f-d*g)^3*(d+e*x)*_
+--  erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)/_
+--  (%e^(a/(b*n))*e^4*(c*(d+e*x)^n)^(1/n)*sqrt(b)*sqrt(n))+1/2*g^3*_
+--  (d+e*x)^4*erfi(2*sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(%pi)/(%e^(4*a/(b*n))*e^4*(c*(d+e*x)^n)^(4/n)*sqrt(b)*sqrt(n))+_
+--  g^2*(e*f-d*g)*(d+e*x)^3*erfi(sqrt(3)*sqrt(a+b*log(c*(d+e*x)^n))/_
+--  (sqrt(b)*sqrt(n)))*sqrt(3*%pi)/(%e^(3*a/(b*n))*e^4*(c*_
+--  (d+e*x)^n)^(3/n)*sqrt(b)*sqrt(n))
+--E 1617
+
+--S 1618 of 5341
+--a0:=integrate(t0,x)
+--E 1618
+
+--S 1619 of 5341
+--m0:=a0-r0
+--E 1619
+
+--S 1620 of 5341
+--d0:=D(m0,x)
+--E 1620
+
+)clear all
+
+--S 1621 of 5341
+t0:=(f+g*x)^2/(a+b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R             2 2             2
+--R            g x  + 2f g x + f
+--R   (1)  --------------------------
+--R         +-----------------------+
+--R         |                 n
+--R        \|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1621
+
+--S 1622 of 5341
+--r0:=g^2*(d+e*x)^3*erfi(sqrt(3)*sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*_
+--  sqrt(n)))*sqrt(1/3*%pi)/(%e^(3*a/(b*n))*e^3*(c*(d+e*x)^n)^(3/n)*_
+--  sqrt(b)*sqrt(n))+(e*f-d*g)^2*(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/_
+--  (sqrt(b)*sqrt(n)))*sqrt(%pi)/(%e^(a/(b*n))*e^3*(c*(d+e*x)^n)^(1/n)*_
+--  sqrt(b)*sqrt(n))+g*(e*f-d*g)*(d+e*x)^2*erfi(sqrt(2)*sqrt(a+b*log(c*_
+--  (d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(2*%pi)/(%e^(2*a/(b*n))*e^3*_
+--  (c*(d+e*x)^n)^(2/n)*sqrt(b)*sqrt(n))
+--E 1622
+
+--S 1623 of 5341
+--a0:=integrate(t0,x)
+--E 1623
+
+--S 1624 of 5341
+--m0:=a0-r0
+--E 1624
+
+--S 1625 of 5341
+--d0:=D(m0,x)
+--E 1625
+
+)clear all
+
+--S 1626 of 5341
+t0:=(f+g*x)/(a+b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R                  g x + f
+--R   (1)  --------------------------
+--R         +-----------------------+
+--R         |                 n
+--R        \|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1626
+
+--S 1627 of 5341
+--r0:=g*(d+e*x)^2*erfi(sqrt(2)*sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*_
+--  sqrt(n)))*sqrt(1/2*%pi)/(%e^(2*a/(b*n))*e^2*(c*(d+e*x)^n)^(2/n)*_
+--  sqrt(b)*sqrt(n))+(e*f-d*g)*(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/_
+--  (sqrt(b)*sqrt(n)))*sqrt(%pi)/(%e^(a/(b*n))*e^2*(c*(d+e*x)^n)^(1/n)*_
+--  sqrt(b)*sqrt(n))
+--E 1627
+
+--S 1628 of 5341
+--a0:=integrate(t0,x)
+--E 1628
+
+--S 1629 of 5341
+--m0:=a0-r0
+--E 1629
+
+--S 1630 of 5341
+--d0:=D(m0,x)
+--E 1630
+
+)clear all
+
+--S 1631 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R         +-----------------------+
+--R         |                 n
+--R        \|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1631
+
+--S 1632 of 5341
+--r0:=(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(%pi)/(%e^(a/(b*n))*e*(c*(d+e*x)^n)^(1/n)*sqrt(b)*sqrt(n))
+--E 1632
+
+--S 1633 of 5341
+--a0:=integrate(t0,x)
+--E 1633
+
+--S 1634 of 5341
+--m0:=a0-r0
+--E 1634
+
+--S 1635 of 5341
+--d0:=D(m0,x)
+--E 1635
+
+)clear all
+
+--S 1636 of 5341
+t0:=1/((f+g*x)*(a+b*log(c*(d+e*x)^n))^(1/2))
+--R 
+--R
+--R                         1
+--R   (1)  -----------------------------------
+--R                  +-----------------------+
+--R                  |                 n
+--R        (g x + f)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1636
+
+--S 1637 of 5341
+--r0:=Int(1/((f+g*x)*sqrt(a+b*log(c*(d+e*x)^n))),x)
+--E 1637
+
+--S 1638 of 5341
+--a0:=integrate(t0,x)
+--E 1638
+
+--S 1639 of 5341
+--m0:=a0-r0
+--E 1639
+
+--S 1640 of 5341
+--d0:=D(m0,x)
+--E 1640
+
+)clear all
+
+--S 1641 of 5341
+t0:=(f+g*x)^3/(a+b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R                     3 3       2 2     2       3
+--R                    g x  + 3f g x  + 3f g x + f
+--R   (1)  ---------------------------------------------------
+--R                                  +-----------------------+
+--R                          n       |                 n
+--R        (b log(c (e x + d) ) + a)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1641
+
+--S 1642 of 5341
+--r0:=2*(e*f-d*g)^3*(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*_
+--  sqrt(n)))*sqrt(%pi)/(%e^(a/(b*n))*b^(3/2)*e^4*n^(3/2)*(c*(d+_
+--  e*x)^n)^(1/n))+4*g^3*(d+e*x)^4*erfi(2*sqrt(a+b*log(c*(d+e*x)^n))/_
+--  (sqrt(b)*sqrt(n)))*sqrt(%pi)/(%e^(4*a/(b*n))*b^(3/2)*e^4*n^(3/2)*_
+--  (c*(d+e*x)^n)^(4/n))+6*g*(e*f-d*g)^2*(d+e*x)^2*erfi(sqrt(2)*_
+--  sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(2*%pi)/(%e^(2*_
+--  a/(b*n))*b^(3/2)*e^4*n^(3/2)*(c*(d+e*x)^n)^(2/n))+6*g^2*(e*f-d*g)*_
+--  (d+e*x)^3*erfi(sqrt(3)*sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(3*%pi)/(%e^(3*a/(b*n))*b^(3/2)*e^4*n^(3/2)*(c*(d+e*x)^n)^(3/n))-2*_
+--  (d+e*x)*(f+g*x)^3/(b*e*n*sqrt(a+b*log(c*(d+e*x)^n)))
+--E 1642
+
+--S 1643 of 5341
+--a0:=integrate(t0,x)
+--E 1643
+
+--S 1644 of 5341
+--m0:=a0-r0
+--E 1644
+
+--S 1645 of 5341
+--d0:=D(m0,x)
+--E 1645
+
+)clear all
+
+--S 1646 of 5341
+t0:=(f+g*x)^2/(a+b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R                          2 2             2
+--R                         g x  + 2f g x + f
+--R   (1)  ---------------------------------------------------
+--R                                  +-----------------------+
+--R                          n       |                 n
+--R        (b log(c (e x + d) ) + a)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1646
+
+--S 1647 of 5341
+--r0:=2*(e*f-d*g)^2*(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/_
+--  (sqrt(b)*sqrt(n)))*sqrt(%pi)/(%e^(a/(b*n))*b^(3/2)*e^3*n^(3/2)*_
+--  (c*(d+e*x)^n)^(1/n))+4*g*(e*f-d*g)*(d+e*x)^2*erfi(sqrt(2)*_
+--  sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(2*%pi)/(%e^(2*_
+--  a/(b*n))*b^(3/2)*e^3*n^(3/2)*(c*(d+e*x)^n)^(2/n))+2*g^2*(d+e*x)^3*_
+--  erfi(sqrt(3)*sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(3*%pi)/(%e^(3*a/(b*n))*b^(3/2)*e^3*n^(3/2)*(c*(d+e*x)^n)^(3/n))-_
+--  2*(d+e*x)*(f+g*x)^2/(b*e*n*sqrt(a+b*log(c*(d+e*x)^n)))
+--E 1647
+
+--S 1648 of 5341
+--a0:=integrate(t0,x)
+--E 1648
+
+--S 1649 of 5341
+--m0:=a0-r0
+--E 1649
+
+--S 1650 of 5341
+--d0:=D(m0,x)
+--E 1650
+
+)clear all
+
+--S 1651 of 5341
+t0:=(f+g*x)/(a+b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R                              g x + f
+--R   (1)  ---------------------------------------------------
+--R                                  +-----------------------+
+--R                          n       |                 n
+--R        (b log(c (e x + d) ) + a)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1651
+
+--S 1652 of 5341
+--r0:=2*(e*f-d*g)*(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*_
+--  sqrt(n)))*sqrt(%pi)/(%e^(a/(b*n))*b^(3/2)*e^2*n^(3/2)*(c*_
+--  (d+e*x)^n)^(1/n))+2*g*(d+e*x)^2*erfi(sqrt(2)*sqrt(a+b*log(c*_
+--  (d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(2*%pi)/(%e^(2*a/(b*n))*b^(3/2)*_
+--  e^2*n^(3/2)*(c*(d+e*x)^n)^(2/n))-2*(d+e*x)*(f+g*x)/(b*e*n*sqrt(a+_
+--  b*log(c*(d+e*x)^n)))
+--E 1652
+
+--S 1653 of 5341
+--a0:=integrate(t0,x)
+--E 1653
+
+--S 1654 of 5341
+--m0:=a0-r0
+--E 1654
+
+--S 1655 of 5341
+--d0:=D(m0,x)
+--E 1655
+
+)clear all
+
+--S 1656 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R                                 1
+--R   (1)  ---------------------------------------------------
+--R                                  +-----------------------+
+--R                          n       |                 n
+--R        (b log(c (e x + d) ) + a)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1656
+
+--S 1657 of 5341
+--r0:=2*(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(%pi)/(%e^(a/(b*n))*b^(3/2)*e*n^(3/2)*(c*(d+e*x)^n)^(1/n))-_
+--  2*(d+e*x)/(b*e*n*sqrt(a+b*log(c*(d+e*x)^n)))
+--E 1657
+
+--S 1658 of 5341
+--a0:=integrate(t0,x)
+--E 1658
+
+--S 1659 of 5341
+--m0:=a0-r0
+--E 1659
+
+--S 1660 of 5341
+--d0:=D(m0,x)
+--E 1660
+
+)clear all
+
+--S 1661 of 5341
+t0:=1/((f+g*x)*(a+b*log(c*(d+e*x)^n))^(3/2))
+--R 
+--R
+--R   (1)
+--R                                       1
+--R   ------------------------------------------------------------------------
+--R                                                  +-----------------------+
+--R                                n                 |                 n
+--R   ((b g x + b f)log(c (e x + d) ) + a g x + a f)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 1661
+
+--S 1662 of 5341
+--r0:=Int(1/((f+g*x)*(a+b*log(c*(d+e*x)^n))^(3/2)),x)
+--E 1662
+
+--S 1663 of 5341
+--a0:=integrate(t0,x)
+--E 1663
+
+--S 1664 of 5341
+--m0:=a0-r0
+--E 1664
+
+--S 1665 of 5341
+--d0:=D(m0,x)
+--E 1665
+
+)clear all
+
+--S 1666 of 5341
+t0:=(f+g*x)^(3/2)*(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R                      +-------+               n                  +-------+
+--R   (1)  (b g x + b f)\|g x + f log(c (e x + d) ) + (a g x + a f)\|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1666
+
+--S 1667 of 5341
+r0:=-4/15*b*(e*f-d*g)*n*(f+g*x)^(3/2)/(e*g)-4/25*b*n*(f+g*x)^(5/2)/g+_
+   4/5*b*(e*f-d*g)^(5/2)*n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))/_
+   (e^(5/2)*g)+2/5*(f+g*x)^(5/2)*(a+b*log(c*(d+e*x)^n))/g-4/5*b*(e*f-d*g)^2*_
+   n*sqrt(f+g*x)/(e^2*g)
+--R 
+--R
+--R   (2)
+--R             2 2 2        2             2 2  +-+ +-------+               n
+--R       (30b e g x  + 60b e f g x + 30b e f )\|e \|g x + f log(c (e x + d) )
+--R     + 
+--R                                                                 +-+ +-------+
+--R             2 2                       2 2   +-----------+      \|e \|g x + f
+--R       (60b d g  - 120b d e f g + 60b e f )n\|- d g + e f atanh(--------------)
+--R                                                                 +-----------+
+--R                                                                \|- d g + e f
+--R     + 
+--R                   2 2         2 2  2              2        2             2
+--R           (- 12b e g n + 30a e g )x  + ((20b d e g  - 44b e f g)n + 60a e f g)x
+--R         + 
+--R                   2 2                       2 2          2 2
+--R           (- 60b d g  + 140b d e f g - 92b e f )n + 30a e f
+--R      *
+--R          +-+ +-------+
+--R         \|e \|g x + f
+--R  /
+--R        2  +-+
+--R     75e g\|e
+--R                                                    Type: Expression(Integer)
+--E 1667
+
+--S 1668 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                +-----------+
+--R                 2 2                      2 2   |- d g + e f
+--R           (30b d g  - 60b d e f g + 30b e f )n |-----------
+--R                                               \|     e
+--R        *
+--R                  +-----------+
+--R                  |- d g + e f  +-------+
+--R               2e |----------- \|g x + f  + e g x - d g + 2e f
+--R                 \|     e
+--R           log(-----------------------------------------------)
+--R                                   e x + d
+--R       + 
+--R                   2 2   2        2               2 2
+--R             (30b e g n x  + 60b e f g n x + 30b e f n)log(e x + d)
+--R           + 
+--R                   2 2 2        2             2 2
+--R             (30b e g x  + 60b e f g x + 30b e f )log(c)
+--R           + 
+--R                     2 2         2 2  2
+--R             (- 12b e g n + 30a e g )x
+--R           + 
+--R                        2        2             2
+--R             ((20b d e g  - 44b e f g)n + 60a e f g)x
+--R           + 
+--R                     2 2                       2 2          2 2
+--R             (- 60b d g  + 140b d e f g - 92b e f )n + 30a e f
+--R        *
+--R            +-------+
+--R           \|g x + f
+--R    /
+--R          2
+--R       75e g
+--R     ,
+--R
+--R                                               +---------+       +-------+
+--R               2 2                       2 2   |d g - e f       \|g x + f
+--R         (60b d g  - 120b d e f g + 60b e f )n |--------- atan(------------)
+--R                                              \|    e           +---------+
+--R                                                                |d g - e f
+--R                                                                |---------
+--R                                                               \|    e
+--R       + 
+--R                   2 2   2        2               2 2
+--R             (30b e g n x  + 60b e f g n x + 30b e f n)log(e x + d)
+--R           + 
+--R                   2 2 2        2             2 2
+--R             (30b e g x  + 60b e f g x + 30b e f )log(c)
+--R           + 
+--R                     2 2         2 2  2
+--R             (- 12b e g n + 30a e g )x
+--R           + 
+--R                        2        2             2
+--R             ((20b d e g  - 44b e f g)n + 60a e f g)x
+--R           + 
+--R                     2 2                       2 2          2 2
+--R             (- 60b d g  + 140b d e f g - 92b e f )n + 30a e f
+--R        *
+--R            +-------+
+--R           \|g x + f
+--R    /
+--R          2
+--R       75e g
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1668
+
+--S 1669 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                           +-----------+
+--R              2 2                    2 2   |- d g + e f  +-+
+--R         (2b d g  - 4b d e f g + 2b e f )n |----------- \|e
+--R                                          \|     e
+--R      *
+--R                +-----------+
+--R                |- d g + e f  +-------+
+--R             2e |----------- \|g x + f  + e g x - d g + 2e f
+--R               \|     e
+--R         log(-----------------------------------------------)
+--R                                 e x + d
+--R     + 
+--R              2 2 2       2            2 2  +-+ +-------+               n
+--R       (- 2b e g x  - 4b e f g x - 2b e f )\|e \|g x + f log(c (e x + d) )
+--R     + 
+--R                                                               +-+ +-------+
+--R              2 2                    2 2   +-----------+      \|e \|g x + f
+--R       (- 4b d g  + 8b d e f g - 4b e f )n\|- d g + e f atanh(--------------)
+--R                                                               +-----------+
+--R                                                              \|- d g + e f
+--R     + 
+--R                2 2   2       2              2 2
+--R           (2b e g n x  + 4b e f g n x + 2b e f n)log(e x + d)
+--R         + 
+--R                2 2 2       2            2 2
+--R           (2b e g x  + 4b e f g x + 2b e f )log(c)
+--R      *
+--R          +-+ +-------+
+--R         \|e \|g x + f
+--R  /
+--R       2  +-+
+--R     5e g\|e
+--R                                                    Type: Expression(Integer)
+--E 1669
+
+--S 1670 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1670
+
+--S 1671 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              2 2 2       2            2 2  +-+ +-------+               n
+--R       (- 2b e g x  - 4b e f g x - 2b e f )\|e \|g x + f log(c (e x + d) )
+--R     + 
+--R                                                               +-+ +-------+
+--R              2 2                    2 2   +-----------+      \|e \|g x + f
+--R       (- 4b d g  + 8b d e f g - 4b e f )n\|- d g + e f atanh(--------------)
+--R                                                               +-----------+
+--R                                                              \|- d g + e f
+--R     + 
+--R                                             +---------+       +-------+
+--R            2 2                    2 2   +-+ |d g - e f       \|g x + f
+--R       (4b d g  - 8b d e f g + 4b e f )n\|e  |--------- atan(------------)
+--R                                            \|    e           +---------+
+--R                                                              |d g - e f
+--R                                                              |---------
+--R                                                             \|    e
+--R     + 
+--R                2 2   2       2              2 2
+--R           (2b e g n x  + 4b e f g n x + 2b e f n)log(e x + d)
+--R         + 
+--R                2 2 2       2            2 2
+--R           (2b e g x  + 4b e f g x + 2b e f )log(c)
+--R      *
+--R          +-+ +-------+
+--R         \|e \|g x + f
+--R  /
+--R       2  +-+
+--R     5e g\|e
+--R                                                    Type: Expression(Integer)
+--E 1671
+
+--S 1672 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1672
+
+)clear all
+
+--S 1673 of 5341
+t0:=(f+g*x)^(1/2)*(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R          +-------+               n      +-------+
+--R   (1)  b\|g x + f log(c (e x + d) ) + a\|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1673
+
+--S 1674 of 5341
+r0:=-4/9*b*n*(f+g*x)^(3/2)/g+4/3*b*(e*f-d*g)^(3/2)*n*atanh(sqrt(e)*_
+   sqrt(f+g*x)/sqrt(e*f-d*g))/(e^(3/2)*g)+2/3*(f+g*x)^(3/2)*(a+_
+   b*log(c*(d+e*x)^n))/g-4/3*b*(e*f-d*g)*n*sqrt(f+g*x)/(e*g)
+--R 
+--R
+--R   (2)
+--R                           +-+ +-------+               n
+--R       (6b e g x + 6b e f)\|e \|g x + f log(c (e x + d) )
+--R     + 
+--R                                                  +-+ +-------+
+--R                              +-----------+      \|e \|g x + f
+--R       (- 12b d g + 12b e f)n\|- d g + e f atanh(--------------)
+--R                                                  +-----------+
+--R                                                 \|- d g + e f
+--R     + 
+--R                                                                +-+ +-------+
+--R       ((- 4b e g n + 6a e g)x + (12b d g - 16b e f)n + 6a e f)\|e \|g x + f
+--R  /
+--R          +-+
+--R     9e g\|e
+--R                                                    Type: Expression(Integer)
+--E 1674
+
+--S 1675 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                              +-----------+
+--R                              |- d g + e f
+--R           (6b d g - 6b e f)n |-----------
+--R                             \|     e
+--R        *
+--R                    +-----------+
+--R                    |- d g + e f  +-------+
+--R               - 2e |----------- \|g x + f  + e g x - d g + 2e f
+--R                   \|     e
+--R           log(-------------------------------------------------)
+--R                                    e x + d
+--R       + 
+--R             (6b e g n x + 6b e f n)log(e x + d) + (6b e g x + 6b e f)log(c)
+--R           + 
+--R             (- 4b e g n + 6a e g)x + (12b d g - 16b e f)n + 6a e f
+--R        *
+--R            +-------+
+--R           \|g x + f
+--R    /
+--R       9e g
+--R     ,
+--R
+--R                                +---------+       +-------+
+--R                                |d g - e f       \|g x + f
+--R         (- 12b d g + 12b e f)n |--------- atan(------------)
+--R                               \|    e           +---------+
+--R                                                 |d g - e f
+--R                                                 |---------
+--R                                                \|    e
+--R       + 
+--R             (6b e g n x + 6b e f n)log(e x + d) + (6b e g x + 6b e f)log(c)
+--R           + 
+--R             (- 4b e g n + 6a e g)x + (12b d g - 16b e f)n + 6a e f
+--R        *
+--R            +-------+
+--R           \|g x + f
+--R    /
+--R       9e g
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1675
+
+--S 1676 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             +-+ +-------+               n
+--R       (- 2b e g x - 2b e f)\|e \|g x + f log(c (e x + d) )
+--R     + 
+--R                            +-----------+
+--R                            |- d g + e f  +-+
+--R         (2b d g - 2b e f)n |----------- \|e
+--R                           \|     e
+--R      *
+--R                  +-----------+
+--R                  |- d g + e f  +-------+
+--R             - 2e |----------- \|g x + f  + e g x - d g + 2e f
+--R                 \|     e
+--R         log(-------------------------------------------------)
+--R                                  e x + d
+--R     + 
+--R                                              +-+ +-------+
+--R                          +-----------+      \|e \|g x + f
+--R       (4b d g - 4b e f)n\|- d g + e f atanh(--------------)
+--R                                              +-----------+
+--R                                             \|- d g + e f
+--R     + 
+--R                                                                           +-+
+--R         ((2b e g n x + 2b e f n)log(e x + d) + (2b e g x + 2b e f)log(c))\|e
+--R      *
+--R          +-------+
+--R         \|g x + f
+--R  /
+--R          +-+
+--R     3e g\|e
+--R                                                    Type: Expression(Integer)
+--E 1676
+
+--S 1677 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1677
+
+--S 1678 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                             +-+ +-------+               n
+--R       (- 2b e g x - 2b e f)\|e \|g x + f log(c (e x + d) )
+--R     + 
+--R                                              +-+ +-------+
+--R                          +-----------+      \|e \|g x + f
+--R       (4b d g - 4b e f)n\|- d g + e f atanh(--------------)
+--R                                              +-----------+
+--R                                             \|- d g + e f
+--R     + 
+--R                                +---------+       +-------+
+--R                            +-+ |d g - e f       \|g x + f
+--R       (- 4b d g + 4b e f)n\|e  |--------- atan(------------)
+--R                               \|    e           +---------+
+--R                                                 |d g - e f
+--R                                                 |---------
+--R                                                \|    e
+--R     + 
+--R                                                                           +-+
+--R         ((2b e g n x + 2b e f n)log(e x + d) + (2b e g x + 2b e f)log(c))\|e
+--R      *
+--R          +-------+
+--R         \|g x + f
+--R  /
+--R          +-+
+--R     3e g\|e
+--R                                                    Type: Expression(Integer)
+--E 1678
+
+--S 1679 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1679
+
+)clear all
+
+--S 1680 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))/(f+g*x)^(1/2)
+--R 
+--R
+--R                         n
+--R        b log(c (e x + d) ) + a
+--R   (1)  -----------------------
+--R                +-------+
+--R               \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1680
+
+--S 1681 of 5341
+r0:=4*b*n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*sqrt(e*f-d*g)/(g*sqrt(e))-_
+   4*b*n*sqrt(f+g*x)/g+2*(a+b*log(c*(d+e*x)^n))*sqrt(f+g*x)/g
+--R 
+--R
+--R   (2)
+--R          +-+ +-------+               n
+--R       2b\|e \|g x + f log(c (e x + d) )
+--R     + 
+--R                                +-+ +-------+
+--R            +-----------+      \|e \|g x + f                   +-+ +-------+
+--R       4b n\|- d g + e f atanh(--------------) + (- 4b n + 2a)\|e \|g x + f
+--R                                +-----------+
+--R                               \|- d g + e f
+--R  /
+--R       +-+
+--R     g\|e
+--R                                                    Type: Expression(Integer)
+--E 1681
+
+--S 1682 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                  +-----------+
+--R                                  |- d g + e f  +-------+
+--R              +-----------+    2e |----------- \|g x + f  + e g x - d g + 2e f
+--R              |- d g + e f       \|     e
+--R         2b n |----------- log(-----------------------------------------------)
+--R             \|     e                              e x + d
+--R       + 
+--R                                                     +-------+
+--R         (2b n log(e x + d) + 2b log(c) - 4b n + 2a)\|g x + f
+--R    /
+--R       g
+--R     ,
+--R
+--R              +---------+       +-------+
+--R              |d g - e f       \|g x + f
+--R         4b n |--------- atan(------------)
+--R             \|    e           +---------+
+--R                               |d g - e f
+--R                               |---------
+--R                              \|    e
+--R       + 
+--R                                                     +-------+
+--R         (2b n log(e x + d) + 2b log(c) - 4b n + 2a)\|g x + f
+--R    /
+--R       g
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1682
+
+--S 1683 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              +-----------+
+--R              |- d g + e f  +-+
+--R         2b n |----------- \|e
+--R             \|     e
+--R      *
+--R                +-----------+
+--R                |- d g + e f  +-------+
+--R             2e |----------- \|g x + f  + e g x - d g + 2e f
+--R               \|     e
+--R         log(-----------------------------------------------)
+--R                                 e x + d
+--R     + 
+--R            +-+ +-------+               n
+--R       - 2b\|e \|g x + f log(c (e x + d) )
+--R     + 
+--R                                  +-+ +-------+
+--R              +-----------+      \|e \|g x + f
+--R       - 4b n\|- d g + e f atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- d g + e f
+--R     + 
+--R                                       +-+ +-------+
+--R       (2b n log(e x + d) + 2b log(c))\|e \|g x + f
+--R  /
+--R       +-+
+--R     g\|e
+--R                                                    Type: Expression(Integer)
+--E 1683
+
+--S 1684 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1684
+
+--S 1685 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            +-+ +-------+               n
+--R       - 2b\|e \|g x + f log(c (e x + d) )
+--R     + 
+--R                                  +-+ +-------+
+--R              +-----------+      \|e \|g x + f
+--R       - 4b n\|- d g + e f atanh(--------------)
+--R                                  +-----------+
+--R                                 \|- d g + e f
+--R     + 
+--R                +---------+       +-------+
+--R            +-+ |d g - e f       \|g x + f
+--R       4b n\|e  |--------- atan(------------)
+--R               \|    e           +---------+
+--R                                 |d g - e f
+--R                                 |---------
+--R                                \|    e
+--R     + 
+--R                                       +-+ +-------+
+--R       (2b n log(e x + d) + 2b log(c))\|e \|g x + f
+--R  /
+--R       +-+
+--R     g\|e
+--R                                                    Type: Expression(Integer)
+--E 1685
+
+--S 1686 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1686
+
+)clear all
+
+--S 1687 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))/(f+g*x)^(3/2)
+--R 
+--R
+--R                         n
+--R        b log(c (e x + d) ) + a
+--R   (1)  -----------------------
+--R                    +-------+
+--R          (g x + f)\|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1687
+
+--S 1688 of 5341
+r0:=-4*b*n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*sqrt(e)/(g*sqrt(e*f-_
+   d*g))-2*(a+b*log(c*(d+e*x)^n))/(g*sqrt(f+g*x))
+--R 
+--R
+--R   (2)
+--R            +-----------+               n
+--R       - 2b\|- d g + e f log(c (e x + d) )
+--R     + 
+--R                                  +-+ +-------+
+--R              +-+ +-------+      \|e \|g x + f        +-----------+
+--R       - 4b n\|e \|g x + f atanh(--------------) - 2a\|- d g + e f
+--R                                  +-----------+
+--R                                 \|- d g + e f
+--R  /
+--R       +-----------+ +-------+
+--R     g\|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1688
+
+--S 1689 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                +-----------+
+--R                |      e      +-------+
+--R           2b n |- --------- \|g x + f
+--R               \|  d g - e f
+--R        *
+--R                             +-----------+
+--R                             |      e      +-------+
+--R               (2d g - 2e f) |- --------- \|g x + f  + e g x - d g + 2e f
+--R                            \|  d g - e f
+--R           log(----------------------------------------------------------)
+--R                                         e x + d
+--R       + 
+--R         - 2b n log(e x + d) - 2b log(c) - 2a
+--R    /
+--R         +-------+
+--R       g\|g x + f
+--R     ,
+--R
+--R              +---------+                       +-------+
+--R              |    e      +-------+           e\|g x + f
+--R         4b n |--------- \|g x + f atan(-----------------------)
+--R             \|d g - e f                            +---------+
+--R                                                    |    e
+--R                                        (d g - e f) |---------
+--R                                                   \|d g - e f
+--R       + 
+--R         - 2b n log(e x + d) - 2b log(c) - 2a
+--R    /
+--R         +-------+
+--R       g\|g x + f
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1689
+
+--S 1690 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                            +-----------+
+--R              +-----------+ |      e      +-------+
+--R         2b n\|- d g + e f  |- --------- \|g x + f
+--R                           \|  d g - e f
+--R      *
+--R                           +-----------+
+--R                           |      e      +-------+
+--R             (2d g - 2e f) |- --------- \|g x + f  + e g x - d g + 2e f
+--R                          \|  d g - e f
+--R         log(----------------------------------------------------------)
+--R                                       e x + d
+--R     + 
+--R          +-----------+               n
+--R       2b\|- d g + e f log(c (e x + d) )
+--R     + 
+--R                                +-+ +-------+
+--R            +-+ +-------+      \|e \|g x + f
+--R       4b n\|e \|g x + f atanh(--------------)
+--R                                +-----------+
+--R                               \|- d g + e f
+--R     + 
+--R                                         +-----------+
+--R       (- 2b n log(e x + d) - 2b log(c))\|- d g + e f
+--R  /
+--R       +-----------+ +-------+
+--R     g\|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1690
+
+--S 1691 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1691
+
+--S 1692 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          +-----------+               n
+--R       2b\|- d g + e f log(c (e x + d) )
+--R     + 
+--R                                +-+ +-------+
+--R            +-+ +-------+      \|e \|g x + f
+--R       4b n\|e \|g x + f atanh(--------------)
+--R                                +-----------+
+--R                               \|- d g + e f
+--R     + 
+--R                          +---------+                       +-------+
+--R            +-----------+ |    e      +-------+           e\|g x + f
+--R       4b n\|- d g + e f  |--------- \|g x + f atan(-----------------------)
+--R                         \|d g - e f                            +---------+
+--R                                                                |    e
+--R                                                    (d g - e f) |---------
+--R                                                               \|d g - e f
+--R     + 
+--R                                         +-----------+
+--R       (- 2b n log(e x + d) - 2b log(c))\|- d g + e f
+--R  /
+--R       +-----------+ +-------+
+--R     g\|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1692
+
+--S 1693 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1693
+
+)clear all
+
+--S 1694 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))/(f+g*x)^(5/2)
+--R 
+--R
+--R                             n
+--R            b log(c (e x + d) ) + a
+--R   (1)  ------------------------------
+--R          2 2             2  +-------+
+--R        (g x  + 2f g x + f )\|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1694
+
+--S 1695 of 5341
+r0:=-4/3*b*e^(3/2)*n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))/(g*(e*f-_
+   d*g)^(3/2))-2/3*(a+b*log(c*(d+e*x)^n))/(g*(f+g*x)^(3/2))+_
+   4/3*b*e*n/(g*(e*f-d*g)*sqrt(f+g*x))
+--R 
+--R
+--R   (2)
+--R                           +-----------+               n
+--R       (- 2b d g + 2b e f)\|- d g + e f log(c (e x + d) )
+--R     + 
+--R                                                   +-+ +-------+
+--R                               +-+ +-------+      \|e \|g x + f
+--R       (4b e g n x + 4b e f n)\|e \|g x + f atanh(--------------)
+--R                                                   +-----------+
+--R                                                  \|- d g + e f
+--R     + 
+--R                                                   +-----------+
+--R       (- 4b e g n x - 4b e f n - 2a d g + 2a e f)\|- d g + e f
+--R  /
+--R           3         2           2       2   +-----------+ +-------+
+--R     ((3d g  - 3e f g )x + 3d f g  - 3e f g)\|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1695
+
+--S 1696 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                   +-----------+
+--R                                   |      e      +-------+
+--R           (2b e g n x + 2b e f n) |- --------- \|g x + f
+--R                                  \|  d g - e f
+--R        *
+--R                               +-----------+
+--R                               |      e      +-------+
+--R               (- 2d g + 2e f) |- --------- \|g x + f  + e g x - d g + 2e f
+--R                              \|  d g - e f
+--R           log(------------------------------------------------------------)
+--R                                          e x + d
+--R       + 
+--R         (- 2b d g + 2b e f)n log(e x + d) + (- 2b d g + 2b e f)log(c)
+--R       + 
+--R         - 4b e g n x - 4b e f n - 2a d g + 2a e f
+--R    /
+--R             3         2           2       2   +-------+
+--R       ((3d g  - 3e f g )x + 3d f g  - 3e f g)\|g x + f
+--R     ,
+--R
+--R                                     +---------+
+--R                                     |    e      +-------+
+--R           (- 4b e g n x - 4b e f n) |--------- \|g x + f
+--R                                    \|d g - e f
+--R        *
+--R                        +-------+
+--R                      e\|g x + f
+--R           atan(-----------------------)
+--R                            +---------+
+--R                            |    e
+--R                (d g - e f) |---------
+--R                           \|d g - e f
+--R       + 
+--R         (- 2b d g + 2b e f)n log(e x + d) + (- 2b d g + 2b e f)log(c)
+--R       + 
+--R         - 4b e g n x - 4b e f n - 2a d g + 2a e f
+--R    /
+--R             3         2           2       2   +-------+
+--R       ((3d g  - 3e f g )x + 3d f g  - 3e f g)\|g x + f
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1696
+
+--S 1697 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         +-----------+               n
+--R       (2b d g - 2b e f)\|- d g + e f log(c (e x + d) )
+--R     + 
+--R                                               +-----------+
+--R                                 +-----------+ |      e      +-------+
+--R         (2b e g n x + 2b e f n)\|- d g + e f  |- --------- \|g x + f
+--R                                              \|  d g - e f
+--R      *
+--R                             +-----------+
+--R                             |      e      +-------+
+--R             (- 2d g + 2e f) |- --------- \|g x + f  + e g x - d g + 2e f
+--R                            \|  d g - e f
+--R         log(------------------------------------------------------------)
+--R                                        e x + d
+--R     + 
+--R                                                     +-+ +-------+
+--R                                 +-+ +-------+      \|e \|g x + f
+--R       (- 4b e g n x - 4b e f n)\|e \|g x + f atanh(--------------)
+--R                                                     +-----------+
+--R                                                    \|- d g + e f
+--R     + 
+--R         ((- 2b d g + 2b e f)n log(e x + d) + (- 2b d g + 2b e f)log(c))
+--R      *
+--R          +-----------+
+--R         \|- d g + e f
+--R  /
+--R           3         2           2       2   +-----------+ +-------+
+--R     ((3d g  - 3e f g )x + 3d f g  - 3e f g)\|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1697
+
+--S 1698 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1698
+
+--S 1699 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                         +-----------+               n
+--R       (2b d g - 2b e f)\|- d g + e f log(c (e x + d) )
+--R     + 
+--R                                                     +-+ +-------+
+--R                                 +-+ +-------+      \|e \|g x + f
+--R       (- 4b e g n x - 4b e f n)\|e \|g x + f atanh(--------------)
+--R                                                     +-----------+
+--R                                                    \|- d g + e f
+--R     + 
+--R                                                 +---------+
+--R                                   +-----------+ |    e      +-------+
+--R         (- 4b e g n x - 4b e f n)\|- d g + e f  |--------- \|g x + f
+--R                                                \|d g - e f
+--R      *
+--R                      +-------+
+--R                    e\|g x + f
+--R         atan(-----------------------)
+--R                          +---------+
+--R                          |    e
+--R              (d g - e f) |---------
+--R                         \|d g - e f
+--R     + 
+--R         ((- 2b d g + 2b e f)n log(e x + d) + (- 2b d g + 2b e f)log(c))
+--R      *
+--R          +-----------+
+--R         \|- d g + e f
+--R  /
+--R           3         2           2       2   +-----------+ +-------+
+--R     ((3d g  - 3e f g )x + 3d f g  - 3e f g)\|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1699
+
+--S 1700 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1700
+
+)clear all
+
+--S 1701 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))/(f+g*x)^(7/2)
+--R 
+--R
+--R                                  n
+--R                 b log(c (e x + d) ) + a
+--R   (1)  ----------------------------------------
+--R          3 3       2 2     2       3  +-------+
+--R        (g x  + 3f g x  + 3f g x + f )\|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1701
+
+--S 1702 of 5341
+r0:=4/15*b*e*n/(g*(e*f-d*g)*(f+g*x)^(3/2))-4/5*b*e^(5/2)*n*atanh(sqrt(e)*_
+   sqrt(f+g*x)/sqrt(e*f-d*g))/(g*(e*f-d*g)^(5/2))-2/5*(a+b*log(c*(d+_
+   e*x)^n))/(g*(f+g*x)^(5/2))+4/5*b*e^2*n/(g*(e*f-d*g)^2*sqrt(f+g*x))
+--R 
+--R
+--R   (2)
+--R              2 2                     2 2  +-----------+               n
+--R       (- 6b d g  + 12b d e f g - 6b e f )\|- d g + e f log(c (e x + d) )
+--R     + 
+--R                 2 2   2        2               2 2   +-+ +-------+
+--R         (- 12b e g n x  - 24b e f g n x - 12b e f n)\|e \|g x + f
+--R      *
+--R                +-+ +-------+
+--R               \|e \|g x + f
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- d g + e f
+--R     + 
+--R                2 2   2              2        2
+--R           12b e g n x  + (- 4b d e g  + 28b e f g)n x
+--R         + 
+--R                                2 2         2 2                     2 2
+--R           (- 4b d e f g + 16b e f )n - 6a d g  + 12a d e f g - 6a e f
+--R      *
+--R          +-----------+
+--R         \|- d g + e f
+--R  /
+--R             2 5            4      2 2 3  2
+--R         (15d g  - 30d e f g  + 15e f g )x
+--R       + 
+--R             2   4          2 3      2 3 2        2 2 3          3 2      2 4
+--R         (30d f g  - 60d e f g  + 30e f g )x + 15d f g  - 30d e f g  + 15e f g
+--R    *
+--R        +-----------+ +-------+
+--R       \|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1702
+
+--S 1703 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                    +-----------+
+--R                2 2   2        2              2 2   |      e      +-------+
+--R           (6b e g n x  + 12b e f g n x + 6b e f n) |- --------- \|g x + f
+--R                                                   \|  d g - e f
+--R        *
+--R                             +-----------+
+--R                             |      e      +-------+
+--R               (2d g - 2e f) |- --------- \|g x + f  + e g x - d g + 2e f
+--R                            \|  d g - e f
+--R           log(----------------------------------------------------------)
+--R                                         e x + d
+--R       + 
+--R                2 2                     2 2
+--R         (- 6b d g  + 12b d e f g - 6b e f )n log(e x + d)
+--R       + 
+--R                2 2                     2 2               2 2   2
+--R         (- 6b d g  + 12b d e f g - 6b e f )log(c) + 12b e g n x
+--R       + 
+--R                    2        2                               2 2         2 2
+--R         (- 4b d e g  + 28b e f g)n x + (- 4b d e f g + 16b e f )n - 6a d g
+--R       + 
+--R                           2 2
+--R         12a d e f g - 6a e f
+--R    /
+--R               2 5            4      2 2 3  2
+--R           (15d g  - 30d e f g  + 15e f g )x
+--R         + 
+--R             2   4          2 3      2 3 2        2 2 3          3 2      2 4
+--R         (30d f g  - 60d e f g  + 30e f g )x + 15d f g  - 30d e f g  + 15e f g
+--R      *
+--R          +-------+
+--R         \|g x + f
+--R     ,
+--R
+--R                                                      +---------+
+--R                 2 2   2        2               2 2   |    e      +-------+
+--R           (12b e g n x  + 24b e f g n x + 12b e f n) |--------- \|g x + f
+--R                                                     \|d g - e f
+--R        *
+--R                        +-------+
+--R                      e\|g x + f
+--R           atan(-----------------------)
+--R                            +---------+
+--R                            |    e
+--R                (d g - e f) |---------
+--R                           \|d g - e f
+--R       + 
+--R                2 2                     2 2
+--R         (- 6b d g  + 12b d e f g - 6b e f )n log(e x + d)
+--R       + 
+--R                2 2                     2 2               2 2   2
+--R         (- 6b d g  + 12b d e f g - 6b e f )log(c) + 12b e g n x
+--R       + 
+--R                    2        2                               2 2         2 2
+--R         (- 4b d e g  + 28b e f g)n x + (- 4b d e f g + 16b e f )n - 6a d g
+--R       + 
+--R                           2 2
+--R         12a d e f g - 6a e f
+--R    /
+--R               2 5            4      2 2 3  2
+--R           (15d g  - 30d e f g  + 15e f g )x
+--R         + 
+--R             2   4          2 3      2 3 2        2 2 3          3 2      2 4
+--R         (30d f g  - 60d e f g  + 30e f g )x + 15d f g  - 30d e f g  + 15e f g
+--R      *
+--R          +-------+
+--R         \|g x + f
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1703
+
+--S 1704 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                               +-----------+
+--R              2 2   2       2              2 2   +-----------+ |      e
+--R         (2b e g n x  + 4b e f g n x + 2b e f n)\|- d g + e f  |- ---------
+--R                                                              \|  d g - e f
+--R      *
+--R                                   +-----------+
+--R                                   |      e      +-------+
+--R                     (2d g - 2e f) |- --------- \|g x + f  + e g x - d g + 2e f
+--R        +-------+                 \|  d g - e f
+--R       \|g x + f log(----------------------------------------------------------)
+--R                                               e x + d
+--R     + 
+--R            2 2                    2 2  +-----------+               n
+--R       (2b d g  - 4b d e f g + 2b e f )\|- d g + e f log(c (e x + d) )
+--R     + 
+--R              2 2   2       2              2 2   +-+ +-------+
+--R         (4b e g n x  + 8b e f g n x + 4b e f n)\|e \|g x + f
+--R      *
+--R                +-+ +-------+
+--R               \|e \|g x + f
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- d g + e f
+--R     + 
+--R                  2 2                    2 2
+--R           (- 2b d g  + 4b d e f g - 2b e f )n log(e x + d)
+--R         + 
+--R                  2 2                    2 2
+--R           (- 2b d g  + 4b d e f g - 2b e f )log(c)
+--R      *
+--R          +-----------+
+--R         \|- d g + e f
+--R  /
+--R            2 5            4     2 2 3  2       2   4          2 3      2 3 2
+--R         (5d g  - 10d e f g  + 5e f g )x  + (10d f g  - 20d e f g  + 10e f g )x
+--R       + 
+--R           2 2 3          3 2     2 4
+--R         5d f g  - 10d e f g  + 5e f g
+--R    *
+--R        +-----------+ +-------+
+--R       \|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1704
+
+--S 1705 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1705
+
+--S 1706 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            2 2                    2 2  +-----------+               n
+--R       (2b d g  - 4b d e f g + 2b e f )\|- d g + e f log(c (e x + d) )
+--R     + 
+--R              2 2   2       2              2 2   +-+ +-------+
+--R         (4b e g n x  + 8b e f g n x + 4b e f n)\|e \|g x + f
+--R      *
+--R                +-+ +-------+
+--R               \|e \|g x + f
+--R         atanh(--------------)
+--R                +-----------+
+--R               \|- d g + e f
+--R     + 
+--R                                                               +---------+
+--R              2 2   2       2              2 2   +-----------+ |    e
+--R         (4b e g n x  + 8b e f g n x + 4b e f n)\|- d g + e f  |---------
+--R                                                              \|d g - e f
+--R      *
+--R                                +-------+
+--R          +-------+           e\|g x + f
+--R         \|g x + f atan(-----------------------)
+--R                                    +---------+
+--R                                    |    e
+--R                        (d g - e f) |---------
+--R                                   \|d g - e f
+--R     + 
+--R                  2 2                    2 2
+--R           (- 2b d g  + 4b d e f g - 2b e f )n log(e x + d)
+--R         + 
+--R                  2 2                    2 2
+--R           (- 2b d g  + 4b d e f g - 2b e f )log(c)
+--R      *
+--R          +-----------+
+--R         \|- d g + e f
+--R  /
+--R            2 5            4     2 2 3  2       2   4          2 3      2 3 2
+--R         (5d g  - 10d e f g  + 5e f g )x  + (10d f g  - 20d e f g  + 10e f g )x
+--R       + 
+--R           2 2 3          3 2     2 4
+--R         5d f g  - 10d e f g  + 5e f g
+--R    *
+--R        +-----------+ +-------+
+--R       \|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1706
+
+--S 1707 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1707
+
+)clear all
+
+--S 1708 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))/(f+g*x)^(9/2)
+--R 
+--R
+--R                                       n
+--R                      b log(c (e x + d) ) + a
+--R   (1)  --------------------------------------------------
+--R          4 4       3 3     2 2 2     3       4  +-------+
+--R        (g x  + 4f g x  + 6f g x  + 4f g x + f )\|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1708
+
+--S 1709 of 5341
+r0:=4/35*b*e*n/(g*(e*f-d*g)*(f+g*x)^(5/2))+4/21*b*e^2*n/(g*(e*f-d*g)^2*_
+   (f+g*x)^(3/2))-4/7*b*e^(7/2)*n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-_
+   d*g))/(g*(e*f-d*g)^(7/2))-2/7*(a+b*log(c*(d+e*x)^n))/(g*(f+g*x)^(7/2))+_
+   4/7*b*e^3*n/(g*(e*f-d*g)^3*sqrt(f+g*x))
+--R 
+--R
+--R   (2)
+--R                 3 3        2     2          2 2         3 3  +-----------+
+--R         (- 30b d g  + 90b d e f g  - 90b d e f g + 30b e f )\|- d g + e f
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R               3 3   3         3   2   2         3 2             3 3   +-+
+--R         (60b e g n x  + 180b e f g n x  + 180b e f g n x + 60b e f n)\|e
+--R      *
+--R                          +-+ +-------+
+--R          +-------+      \|e \|g x + f
+--R         \|g x + f atanh(--------------)
+--R                          +-----------+
+--R                         \|- d g + e f
+--R     + 
+--R                  3 3   3           2 3         3   2    2
+--R           - 60b e g n x  + (20b d e g  - 200b e f g )n x
+--R         + 
+--R                   2   3          2   2         3 2
+--R           (- 12b d e g  + 64b d e f g  - 232b e f g)n x
+--R         + 
+--R                   2     2          2 2         3 3          3 3        2     2
+--R           (- 12b d e f g  + 44b d e f g - 92b e f )n - 30a d g  + 90a d e f g
+--R         + 
+--R                    2 2         3 3
+--R           - 90a d e f g + 30a e f
+--R      *
+--R          +-----------+
+--R         \|- d g + e f
+--R  /
+--R              3 7       2     6         2 2 5       3 3 4  3
+--R         (105d g  - 315d e f g  + 315d e f g  - 105e f g )x
+--R       + 
+--R              3   6       2   2 5         2 3 4       3 4 3  2
+--R         (315d f g  - 945d e f g  + 945d e f g  - 315e f g )x
+--R       + 
+--R              3 2 5       2   3 4         2 4 3       3 5 2         3 3 4
+--R         (315d f g  - 945d e f g  + 945d e f g  - 315e f g )x + 105d f g
+--R       + 
+--R               2   4 3         2 5 2       3 6
+--R         - 315d e f g  + 315d e f g  - 105e f g
+--R    *
+--R        +-----------+ +-------+
+--R       \|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1709
+
+--S 1710 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 3 3   3        3   2   2        3 2             3 3
+--R           (30b e g n x  + 90b e f g n x  + 90b e f g n x + 30b e f n)
+--R        *
+--R            +-----------+
+--R            |      e      +-------+
+--R            |- --------- \|g x + f
+--R           \|  d g - e f
+--R        *
+--R                               +-----------+
+--R                               |      e      +-------+
+--R               (- 2d g + 2e f) |- --------- \|g x + f  + e g x - d g + 2e f
+--R                              \|  d g - e f
+--R           log(------------------------------------------------------------)
+--R                                          e x + d
+--R       + 
+--R                 3 3        2     2          2 2         3 3
+--R         (- 30b d g  + 90b d e f g  - 90b d e f g + 30b e f )n log(e x + d)
+--R       + 
+--R                 3 3        2     2          2 2         3 3
+--R         (- 30b d g  + 90b d e f g  - 90b d e f g + 30b e f )log(c)
+--R       + 
+--R                3 3   3           2 3         3   2    2
+--R         - 60b e g n x  + (20b d e g  - 200b e f g )n x
+--R       + 
+--R                 2   3          2   2         3 2
+--R         (- 12b d e g  + 64b d e f g  - 232b e f g)n x
+--R       + 
+--R                 2     2          2 2         3 3          3 3        2     2
+--R         (- 12b d e f g  + 44b d e f g - 92b e f )n - 30a d g  + 90a d e f g
+--R       + 
+--R                  2 2         3 3
+--R         - 90a d e f g + 30a e f
+--R    /
+--R                3 7       2     6         2 2 5       3 3 4  3
+--R           (105d g  - 315d e f g  + 315d e f g  - 105e f g )x
+--R         + 
+--R                3   6       2   2 5         2 3 4       3 4 3  2
+--R           (315d f g  - 945d e f g  + 945d e f g  - 315e f g )x
+--R         + 
+--R                3 2 5       2   3 4         2 4 3       3 5 2         3 3 4
+--R           (315d f g  - 945d e f g  + 945d e f g  - 315e f g )x + 105d f g
+--R         + 
+--R                 2   4 3         2 5 2       3 6
+--R           - 315d e f g  + 315d e f g  - 105e f g
+--R      *
+--R          +-------+
+--R         \|g x + f
+--R     ,
+--R
+--R                   3 3   3         3   2   2         3 2             3 3
+--R           (- 60b e g n x  - 180b e f g n x  - 180b e f g n x - 60b e f n)
+--R        *
+--R            +---------+                       +-------+
+--R            |    e      +-------+           e\|g x + f
+--R            |--------- \|g x + f atan(-----------------------)
+--R           \|d g - e f                            +---------+
+--R                                                  |    e
+--R                                      (d g - e f) |---------
+--R                                                 \|d g - e f
+--R       + 
+--R                 3 3        2     2          2 2         3 3
+--R         (- 30b d g  + 90b d e f g  - 90b d e f g + 30b e f )n log(e x + d)
+--R       + 
+--R                 3 3        2     2          2 2         3 3
+--R         (- 30b d g  + 90b d e f g  - 90b d e f g + 30b e f )log(c)
+--R       + 
+--R                3 3   3           2 3         3   2    2
+--R         - 60b e g n x  + (20b d e g  - 200b e f g )n x
+--R       + 
+--R                 2   3          2   2         3 2
+--R         (- 12b d e g  + 64b d e f g  - 232b e f g)n x
+--R       + 
+--R                 2     2          2 2         3 3          3 3        2     2
+--R         (- 12b d e f g  + 44b d e f g - 92b e f )n - 30a d g  + 90a d e f g
+--R       + 
+--R                  2 2         3 3
+--R         - 90a d e f g + 30a e f
+--R    /
+--R                3 7       2     6         2 2 5       3 3 4  3
+--R           (105d g  - 315d e f g  + 315d e f g  - 105e f g )x
+--R         + 
+--R                3   6       2   2 5         2 3 4       3 4 3  2
+--R           (315d f g  - 945d e f g  + 945d e f g  - 315e f g )x
+--R         + 
+--R                3 2 5       2   3 4         2 4 3       3 5 2         3 3 4
+--R           (315d f g  - 945d e f g  + 945d e f g  - 315e f g )x + 105d f g
+--R         + 
+--R                 2   4 3         2 5 2       3 6
+--R           - 315d e f g  + 315d e f g  - 105e f g
+--R      *
+--R          +-------+
+--R         \|g x + f
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1710
+
+--S 1711 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R              3 3       2     2         2 2        3 3  +-----------+
+--R         (2b d g  - 6b d e f g  + 6b d e f g - 2b e f )\|- d g + e f
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R              3 3   3       3   2   2       3 2            3 3   +-----------+
+--R         (2b e g n x  + 6b e f g n x  + 6b e f g n x + 2b e f n)\|- d g + e f
+--R      *
+--R          +-----------+
+--R          |      e      +-------+
+--R          |- --------- \|g x + f
+--R         \|  d g - e f
+--R      *
+--R                             +-----------+
+--R                             |      e      +-------+
+--R             (- 2d g + 2e f) |- --------- \|g x + f  + e g x - d g + 2e f
+--R                            \|  d g - e f
+--R         log(------------------------------------------------------------)
+--R                                        e x + d
+--R     + 
+--R                3 3   3        3   2   2        3 2            3 3   +-+
+--R         (- 4b e g n x  - 12b e f g n x  - 12b e f g n x - 4b e f n)\|e
+--R      *
+--R                          +-+ +-------+
+--R          +-------+      \|e \|g x + f
+--R         \|g x + f atanh(--------------)
+--R                          +-----------+
+--R                         \|- d g + e f
+--R     + 
+--R                  3 3       2     2         2 2        3 3
+--R           (- 2b d g  + 6b d e f g  - 6b d e f g + 2b e f )n log(e x + d)
+--R         + 
+--R                  3 3       2     2         2 2        3 3
+--R           (- 2b d g  + 6b d e f g  - 6b d e f g + 2b e f )log(c)
+--R      *
+--R          +-----------+
+--R         \|- d g + e f
+--R  /
+--R            3 7      2     6        2 2 5     3 3 4  3
+--R         (7d g  - 21d e f g  + 21d e f g  - 7e f g )x
+--R       + 
+--R             3   6      2   2 5        2 3 4      3 4 3  2
+--R         (21d f g  - 63d e f g  + 63d e f g  - 21e f g )x
+--R       + 
+--R             3 2 5      2   3 4        2 4 3      3 5 2       3 3 4      2   4 3
+--R         (21d f g  - 63d e f g  + 63d e f g  - 21e f g )x + 7d f g  - 21d e f g
+--R       + 
+--R              2 5 2     3 6
+--R         21d e f g  - 7e f g
+--R    *
+--R        +-----------+ +-------+
+--R       \|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1711
+
+--S 1712 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1712
+
+--S 1713 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R              3 3       2     2         2 2        3 3  +-----------+
+--R         (2b d g  - 6b d e f g  + 6b d e f g - 2b e f )\|- d g + e f
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R                3 3   3        3   2   2        3 2            3 3   +-+
+--R         (- 4b e g n x  - 12b e f g n x  - 12b e f g n x - 4b e f n)\|e
+--R      *
+--R                          +-+ +-------+
+--R          +-------+      \|e \|g x + f
+--R         \|g x + f atanh(--------------)
+--R                          +-----------+
+--R                         \|- d g + e f
+--R     + 
+--R                3 3   3        3   2   2        3 2            3 3
+--R         (- 4b e g n x  - 12b e f g n x  - 12b e f g n x - 4b e f n)
+--R      *
+--R                        +---------+                       +-------+
+--R          +-----------+ |    e      +-------+           e\|g x + f
+--R         \|- d g + e f  |--------- \|g x + f atan(-----------------------)
+--R                       \|d g - e f                            +---------+
+--R                                                              |    e
+--R                                                  (d g - e f) |---------
+--R                                                             \|d g - e f
+--R     + 
+--R                  3 3       2     2         2 2        3 3
+--R           (- 2b d g  + 6b d e f g  - 6b d e f g + 2b e f )n log(e x + d)
+--R         + 
+--R                  3 3       2     2         2 2        3 3
+--R           (- 2b d g  + 6b d e f g  - 6b d e f g + 2b e f )log(c)
+--R      *
+--R          +-----------+
+--R         \|- d g + e f
+--R  /
+--R            3 7      2     6        2 2 5     3 3 4  3
+--R         (7d g  - 21d e f g  + 21d e f g  - 7e f g )x
+--R       + 
+--R             3   6      2   2 5        2 3 4      3 4 3  2
+--R         (21d f g  - 63d e f g  + 63d e f g  - 21e f g )x
+--R       + 
+--R             3 2 5      2   3 4        2 4 3      3 5 2       3 3 4      2   4 3
+--R         (21d f g  - 63d e f g  + 63d e f g  - 21e f g )x + 7d f g  - 21d e f g
+--R       + 
+--R              2 5 2     3 6
+--R         21d e f g  - 7e f g
+--R    *
+--R        +-----------+ +-------+
+--R       \|- d g + e f \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1713
+
+--S 1714 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1714
+
+)clear all
+
+--S 1715 of 5341
+t0:=(f+g*x)^(3/2)*(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R   (1)
+--R       2       2   +-------+               n 2
+--R     (b g x + b f)\|g x + f log(c (e x + d) )
+--R   + 
+--R                         +-------+               n      2       2   +-------+
+--R     (2a b g x + 2a b f)\|g x + f log(c (e x + d) ) + (a g x + a f)\|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1715
+
+--S 1716 of 5341
+--r0:=128/225*b^2*(e*f-d*g)*n^2*(f+g*x)^(3/2)/(e*g)+16/125*b^2*n^2*_
+--  (f+g*x)^(5/2)/g+8/5*a*b*(e*f-d*g)^(5/2)*n*atanh(sqrt(e)*sqrt(f+g*x)/_
+--  sqrt(e*f-d*g))/(e^(5/2)*g)-368/75*b^2*(e*f-d*g)^(5/2)*n^2*_
+--  atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))/(e^(5/2)*g)-8/5*b^2*_
+--  (e*f-d*g)^(5/2)*n^2*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))^2/_
+--  (e^(5/2)*g)-8/15*b*(e*f-d*g)*n*(f+g*x)^(3/2)*(a+b*log(c*(d+e*x)^n))/_
+--  (e*g)-8/25*b*n*(f+g*x)^(5/2)*(a+b*log(c*(d+e*x)^n))/g+2/5*(d+e*x)*_
+--  (f+g*x)^(3/2)*(a+b*log(c*(d+e*x)^n))^2/e+8/5*b^2*(e*f-d*g)^(5/2)*_
+--  n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*log(c*(d-e*f/g+_
+--  e*(f+g*x)/g)^n)/(e^(5/2)*g)+16/5*b^2*(e*f-d*g)^(5/2)*n^2*_
+--  atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*log(2/(1-sqrt(e)*_
+--  sqrt(f+g*x)/sqrt(e*f-d*g)))/(e^(5/2)*g)+8/5*b^2*(e*f-d*g)^(5/2)*_
+--  n^2*polylog(2,(-sqrt(e*f-d*g)-sqrt(e)*sqrt(f+g*x))/(sqrt(e*f-d*g)-_
+--  sqrt(e)*sqrt(f+g*x)))/(e^(5/2)*g)+2/5*a^2*(e*f-d*g)^2*sqrt(f+g*x)/_
+--  (e^2*g)-8/5*a*b*(e*f-d*g)^2*n*sqrt(f+g*x)/(e^2*g)+368/75*b^2*_
+--  (e*f-d*g)^2*n^2*sqrt(f+g*x)/(e^2*g)+2/5*(e*f-d*g)*(d+e*x)*(a+b*_
+--  log(c*(d+e*x)^n))^2*sqrt(f+g*x)/e^2+4/5*a*b*(e*f-d*g)^2*log(c*_
+--  (d-e*f/g+e*(f+g*x)/g)^n)*sqrt(f+g*x)/(e^2*g)-8/5*b^2*(e*f-d*g)^2*_
+--  n*log(c*(d-e*f/g+e*(f+g*x)/g)^n)*sqrt(f+g*x)/(e^2*g)+2/5*b^2*_
+--  (e*f-d*g)^2*log(c*(d-e*f/g+e*(f+g*x)/g)^n)^2*sqrt(f+g*x)/(e^2*g)
+--E 1716
+
+--S 1717 of 5341
+--a0:=integrate(t0,x)
+--E 1717
+
+--S 1718 of 5341
+--m0:=a0-r0
+--E 1718
+
+--S 1719 of 5341
+--d0:=D(m0,x)
+--E 1719
+
+)clear all
+
+--S 1720 of 5341
+t0:=(f+g*x)^(1/2)*(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R   (1)
+--R      2 +-------+               n 2        +-------+               n
+--R     b \|g x + f log(c (e x + d) )  + 2a b\|g x + f log(c (e x + d) )
+--R   + 
+--R      2 +-------+
+--R     a \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1720
+
+--S 1721 of 5341
+--r0:=16/27*b^2*n^2*(f+g*x)^(3/2)/g+8/3*a*b*(e*f-d*g)^(3/2)*n*atanh(sqrt(e)*_
+--  sqrt(f+g*x)/sqrt(e*f-d*g))/(e^(3/2)*g)-64/9*b^2*(e*f-d*g)^(3/2)*n^2*_
+--  atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))/(e^(3/2)*g)-8/3*b^2*(e*f-_
+--  d*g)^(3/2)*n^2*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))^2/(e^(3/2)*g)-_
+--  8/9*b*n*(f+g*x)^(3/2)*(a+b*log(c*(d+e*x)^n))/g+8/3*b^2*(e*f-d*g)^(3/2)*_
+--  n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*log(c*(d-e*f/g+e*(f+_
+--  g*x)/g)^n)/(e^(3/2)*g)+16/3*b^2*(e*f-d*g)^(3/2)*n^2*atanh(sqrt(e)*_
+--  sqrt(f+g*x)/sqrt(e*f-d*g))*log(2/(1-sqrt(e)*sqrt(f+g*x)/sqrt(e*f-_
+--  d*g)))/(e^(3/2)*g)+8/3*b^2*(e*f-d*g)^(3/2)*n^2*polylog(2,(-sqrt(e*f-_
+--  d*g)-sqrt(e)*sqrt(f+g*x))/(sqrt(e*f-d*g)-sqrt(e)*sqrt(f+g*x)))/_
+--  (e^(3/2)*g)+2/3*a^2*(e*f-d*g)*sqrt(f+g*x)/(e*g)-8/3*a*b*(e*f-d*g)*_
+--  n*sqrt(f+g*x)/(e*g)+64/9*b^2*(e*f-d*g)*n^2*sqrt(f+g*x)/(e*g)+_
+--  2/3*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2*sqrt(f+g*x)/e+4/3*a*b*(e*f-d*g)*_
+--  log(c*(d-e*f/g+e*(f+g*x)/g)^n)*sqrt(f+g*x)/(e*g)-8/3*b^2*(e*f-d*g)*_
+--  n*log(c*(d-e*f/g+e*(f+g*x)/g)^n)*sqrt(f+g*x)/(e*g)+2/3*b^2*(e*f-d*g)*_
+--  log(c*(d-e*f/g+e*(f+g*x)/g)^n)^2*sqrt(f+g*x)/(e*g)
+--E 1721
+
+--S 1722 of 5341
+--a0:=integrate(t0,x)
+--E 1722
+
+--S 1723 of 5341
+--m0:=a0-r0
+--E 1723
+
+--S 1724 of 5341
+--d0:=D(m0,x)
+--E 1724
+
+)clear all
+
+--S 1725 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^2/(f+g*x)^(1/2)
+--R 
+--R
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R   (1)  --------------------------------------------------
+--R                             +-------+
+--R                            \|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1725
+
+--S 1726 of 5341
+--r0:=8*a*b*n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*sqrt(e*f-d*g)/_
+--  (g*sqrt(e))-16*b^2*n^2*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*_
+--  sqrt(e*f-d*g)/(g*sqrt(e))-8*b^2*n^2*atanh(sqrt(e)*sqrt(f+g*x)/_
+--  sqrt(e*f-d*g))^2*sqrt(e*f-d*g)/(g*sqrt(e))+8*b^2*n*atanh(sqrt(e)*_
+--  sqrt(f+g*x)/sqrt(e*f-d*g))*log(c*(d-e*f/g+e*(f+g*x)/g)^n)*sqrt(e*f-_
+--  d*g)/(g*sqrt(e))+16*b^2*n^2*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*_
+--  log(2/(1-sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g)))*sqrt(e*f-d*g)/(g*_
+--  sqrt(e))+8*b^2*n^2*polylog(2,(-sqrt(e*f-d*g)-sqrt(e)*sqrt(f+g*x))/_
+--  (sqrt(e*f-d*g)-sqrt(e)*sqrt(f+g*x)))*sqrt(e*f-d*g)/(g*sqrt(e))+2*a^2*_
+--  sqrt(f+g*x)/g-8*a*b*n*sqrt(f+g*x)/g+16*b^2*n^2*sqrt(f+g*x)/g+4*a*b*_
+--  log(c*(d-e*f/g+e*(f+g*x)/g)^n)*sqrt(f+g*x)/g-8*b^2*n*log(c*(d-e*f/g+_
+--  e*(f+g*x)/g)^n)*sqrt(f+g*x)/g+2*b^2*log(c*(d-e*f/g+e*(f+g*x)/g)^n)^2*_
+--  sqrt(f+g*x)/g
+--E 1726
+
+--S 1727 of 5341
+--a0:=integrate(t0,x)
+--E 1727
+
+--S 1728 of 5341
+--m0:=a0-r0
+--E 1728
+
+--S 1729 of 5341
+--d0:=D(m0,x)
+--E 1729
+
+)clear all
+
+--S 1730 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^2/(f+g*x)^(3/2)
+--R 
+--R
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R   (1)  --------------------------------------------------
+--R                                  +-------+
+--R                        (g x + f)\|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1730
+
+--S 1731 of 5341
+--r0:=-8*a*b*n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*sqrt(e)/_
+--  (g*sqrt(e*f-d*g))+8*b^2*n^2*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))^2*_
+--  sqrt(e)/(g*sqrt(e*f-d*g))-8*b^2*n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-_
+--  d*g))*log(c*(d-e*f/g+e*(f+g*x)/g)^n)*sqrt(e)/(g*sqrt(e*f-d*g))-_
+--  16*b^2*n^2*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*log(2/(1-sqrt(e)*_
+--  sqrt(f+g*x)/sqrt(e*f-d*g)))*sqrt(e)/(g*sqrt(e*f-d*g))-8*b^2*n^2*_
+--  polylog(2,(-sqrt(e*f-d*g)-sqrt(e)*sqrt(f+g*x))/(sqrt(e*f-d*g)-sqrt(e)*_
+--  sqrt(f+g*x)))*sqrt(e)/(g*sqrt(e*f-d*g))+2*(d+e*x)*(a+b*log(c*(d+_
+--  e*x)^n))^2/((e*f-d*g)*sqrt(f+g*x))-2*a^2*e*sqrt(f+g*x)/(g*(e*f-d*g))+_
+--  8*a*b*e*n*sqrt(f+g*x)/(g*(e*f-d*g))-8*b*e*n*(a+b*log(c*(d+e*x)^n))*_
+--  sqrt(f+g*x)/(g*(e*f-d*g))-4*a*b*e*log(c*(d-e*f/g+e*(f+g*x)/g)^n)*_
+--  sqrt(f+g*x)/(g*(e*f-d*g))+8*b^2*e*n*log(c*(d-e*f/g+e*(f+g*x)/g)^n)*_
+--  sqrt(f+g*x)/(g*(e*f-d*g))-2*b^2*e*log(c*(d-e*f/g+e*(f+g*x)/g)^n)^2*_
+--  sqrt(f+g*x)/(g*(e*f-d*g))
+--E 1731
+
+--S 1732 of 5341
+--a0:=integrate(t0,x)
+--E 1732
+
+--S 1733 of 5341
+--m0:=a0-r0
+--E 1733
+
+--S 1734 of 5341
+--d0:=D(m0,x)
+--E 1734
+
+)clear all
+
+--S 1735 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^2/(f+g*x)^(5/2)
+--R 
+--R
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R   (1)  --------------------------------------------------
+--R                    2 2             2  +-------+
+--R                  (g x  + 2f g x + f )\|g x + f
+--R                                                    Type: Expression(Integer)
+--E 1735
+
+--S 1736 of 5341
+--r0:=-8/3*a*b*e^(3/2)*n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))/_
+--  (g*(e*f-d*g)^(3/2))+16/3*b^2*e^(3/2)*n^2*atanh(sqrt(e)*sqrt(f+g*x)/_
+--  sqrt(e*f-d*g))/(g*(e*f-d*g)^(3/2))+8/3*b^2*e^(3/2)*n^2*atanh(sqrt(e)*_
+--  sqrt(f+g*x)/sqrt(e*f-d*g))^2/(g*(e*f-d*g)^(3/2))+2/3*(d+e*x)*(a+_
+--  b*log(c*(d+e*x)^n))^2/((e*f-d*g)*(f+g*x)^(3/2))-8/3*b^2*e^(3/2)*_
+--  n*atanh(sqrt(e)*sqrt(f+g*x)/sqrt(e*f-d*g))*log(c*(d-e*f/g+e*(f+_
+--  g*x)/g)^n)/(g*(e*f-d*g)^(3/2))-16/3*b^2*e^(3/2)*n^2*atanh(sqrt(e)*_
+--  sqrt(f+g*x)/sqrt(e*f-d*g))*log(2/(1-sqrt(e)*sqrt(f+g*x)/sqrt(e*f-_
+--  d*g)))/(g*(e*f-d*g)^(3/2))-8/3*b^2*e^(3/2)*n^2*polylog(2,_
+--  (-sqrt(e*f-d*g)-sqrt(e)*sqrt(f+g*x))/(sqrt(e*f-d*g)-sqrt(e)*_
+--  sqrt(f+g*x)))/(g*(e*f-d*g)^(3/2))+8/3*b*e*n*(a+b*log(c*(d+e*x)^n))/_
+--  (g*(e*f-d*g)*sqrt(f+g*x))+2/3*e*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/_
+--  ((e*f-d*g)^2*sqrt(f+g*x))-2/3*a^2*e^2*sqrt(f+g*x)/(g*(e*f-d*g)^2)+_
+--  8/3*a*b*e^2*n*sqrt(f+g*x)/(g*(e*f-d*g)^2)-8/3*b*e^2*n*(a+b*log(c*_
+--  (d+e*x)^n))*sqrt(f+g*x)/(g*(e*f-d*g)^2)-4/3*a*b*e^2*log(c*(d-e*f/g+_
+--  e*(f+g*x)/g)^n)*sqrt(f+g*x)/(g*(e*f-d*g)^2)+8/3*b^2*e^2*n*log(c*_
+--  (d-e*f/g+e*(f+g*x)/g)^n)*sqrt(f+g*x)/(g*(e*f-d*g)^2)-2/3*b^2*e^2*_
+--  log(c*(d-e*f/g+e*(f+g*x)/g)^n)^2*sqrt(f+g*x)/(g*(e*f-d*g)^2)
+--E 1736
+
+--S 1737 of 5341
+--a0:=integrate(t0,x)
+--E 1737
+
+--S 1738 of 5341
+--m0:=a0-r0
+--E 1738
+
+--S 1739 of 5341
+--d0:=D(m0,x)
+--E 1739
+
+)clear all
+
+--S 1740 of 5341
+t0:=(f+g*x)^m*(a+b*log(c*(d+e*x)^n))^p
+--R 
+--R
+--R                 m                  n      p
+--R   (1)  (g x + f) (b log(c (e x + d) ) + a)
+--R                                                    Type: Expression(Integer)
+--E 1740
+
+--S 1741 of 5341
+--r0:=Int((f+g*x)^m*(a+b*log(c*(d+e*x)^n))^p,x)
+--E 1741
+
+--S 1742 of 5341
+--a0:=integrate(t0,x)
+--E 1742
+
+--S 1743 of 5341
+--m0:=a0-r0
+--E 1743
+
+--S 1744 of 5341
+--d0:=D(m0,x)
+--E 1744
+
+)clear all
+
+--S 1745 of 5341
+t0:=(f+g*x)^3*(a+b*log(c*(d+e*x)^n))^p
+--R 
+--R
+--R          3 3       2 2     2       3                   n      p
+--R   (1)  (g x  + 3f g x  + 3f g x + f )(b log(c (e x + d) ) + a)
+--R                                                    Type: Expression(Integer)
+--E 1745
+
+--S 1746 of 5341
+--r0:=4^(-1-p)*g^3*(d+e*x)^4*GAMMA(1+p,-4*(a+b*log(c*(d+e*x)^n))/(b*n))*_
+--  (a+b*log(c*(d+e*x)^n))^p/(%e^(4*a/(b*n))*e^4*(c*(d+e*x)^n)^(4/n)*_
+--  ((-a-b*log(c*(d+e*x)^n))/(b*n))^p)+g^2*(e*f-d*g)*(d+e*x)^3*_
+--  GAMMA(1+p,-3*(a+b*log(c*(d+e*x)^n))/(b*n))*(a+b*log(c*(d+e*x)^n))^p/_
+--  (3^p*%e^(3*a/(b*n))*e^4*(c*(d+e*x)^n)^(3/n)*((-a-b*log(c*(d+e*x)^n))/_
+--  (b*n))^p)+3*2^(-1-p)*g*(e*f-d*g)^2*(d+e*x)^2*GAMMA(1+p,-2*(a+_
+--  b*log(c*(d+e*x)^n))/(b*n))*(a+b*log(c*(d+e*x)^n))^p/(%e^(2*a/(b*n))*_
+--  e^4*(c*(d+e*x)^n)^(2/n)*((-a-b*log(c*(d+e*x)^n))/(b*n))^p)+(e*f-_
+--  d*g)^3*(d+e*x)*GAMMA(1+p,(-a-b*log(c*(d+e*x)^n))/(b*n))*(a+_
+--  b*log(c*(d+e*x)^n))^p/(%e^(a/(b*n))*e^4*(c*(d+e*x)^n)^(1/n)*_
+--  ((-a-b*log(c*(d+e*x)^n))/(b*n))^p)
+--E 1746
+
+--S 1747 of 5341
+--a0:=integrate(t0,x)
+--E 1747
+
+--S 1748 of 5341
+--m0:=a0-r0
+--E 1748
+
+--S 1749 of 5341
+--d0:=D(m0,x)
+--E 1749
+
+)clear all
+
+--S 1750 of 5341
+t0:=(f+g*x)^2*(a+b*log(c*(d+e*x)^n))^p
+--R 
+--R
+--R          2 2             2                   n      p
+--R   (1)  (g x  + 2f g x + f )(b log(c (e x + d) ) + a)
+--R                                                    Type: Expression(Integer)
+--E 1750
+
+--S 1751 of 5341
+--r0:=3^(-1-p)*g^2*(d+e*x)^3*GAMMA(1+p,-3*(a+b*log(c*(d+e*x)^n))/(b*n))*_
+--  (a+b*log(c*(d+e*x)^n))^p/(%e^(3*a/(b*n))*e^3*(c*(d+e*x)^n)^(3/n)*_
+--  ((-a-b*log(c*(d+e*x)^n))/(b*n))^p)+g*(e*f-d*g)*(d+e*x)^2*_
+--  GAMMA(1+p,-2*(a+b*log(c*(d+e*x)^n))/(b*n))*(a+b*log(c*(d+e*x)^n))^p/_
+--  (2^p*%e^(2*a/(b*n))*e^3*(c*(d+e*x)^n)^(2/n)*((-a-b*log(c*(d+e*x)^n))/_
+--  (b*n))^p)+(e*f-d*g)^2*(d+e*x)*GAMMA(1+p,(-a-b*log(c*(d+e*x)^n))/(b*n))*_
+--  (a+b*log(c*(d+e*x)^n))^p/(%e^(a/(b*n))*e^3*(c*(d+e*x)^n)^(1/n)*_
+--  ((-a-b*log(c*(d+e*x)^n))/(b*n))^p)
+--E 1751
+
+--S 1752 of 5341
+--a0:=integrate(t0,x)
+--E 1752
+
+--S 1753 of 5341
+--m0:=a0-r0
+--E 1753
+
+--S 1754 of 5341
+--d0:=D(m0,x)
+--E 1754
+
+)clear all
+
+--S 1755 of 5341
+t0:=(f+g*x)*(a+b*log(c*(d+e*x)^n))^p
+--R 
+--R
+--R                                   n      p
+--R   (1)  (g x + f)(b log(c (e x + d) ) + a)
+--R                                                    Type: Expression(Integer)
+--E 1755
+
+--S 1756 of 5341
+--r0:=2^(-1-p)*g*(d+e*x)^2*GAMMA(1+p,-2*(a+b*log(c*(d+e*x)^n))/(b*n))*_
+--  (a+b*log(c*(d+e*x)^n))^p/(%e^(2*a/(b*n))*e^2*(c*(d+e*x)^n)^(2/n)*_
+--  ((-a-b*log(c*(d+e*x)^n))/(b*n))^p)+(e*f-d*g)*(d+e*x)*_
+--  GAMMA(1+p,(-a-b*log(c*(d+e*x)^n))/(b*n))*(a+b*log(c*(d+e*x)^n))^p/_
+--  (%e^(a/(b*n))*e^2*(c*(d+e*x)^n)^(1/n)*((-a-b*log(c*(d+e*x)^n))/(b*n))^p)
+--E 1756
+
+--S 1757 of 5341
+--a0:=integrate(t0,x)
+--E 1757
+
+--S 1758 of 5341
+--m0:=a0-r0
+--E 1758
+
+--S 1759 of 5341
+--d0:=D(m0,x)
+--E 1759
+
+)clear all
+
+--S 1760 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^p
+--R 
+--R
+--R                          n      p
+--R   (1)  (b log(c (e x + d) ) + a)
+--R                                                    Type: Expression(Integer)
+--E 1760
+
+--S 1761 of 5341
+--r0:=(d+e*x)*GAMMA(1+p,(-a-b*log(c*(d+e*x)^n))/(b*n))*_
+--  (a+b*log(c*(d+e*x)^n))^p/(%e^(a/(b*n))*e*(c*(d+e*x)^n)^(1/n)*_
+--  ((-a-b*log(c*(d+e*x)^n))/(b*n))^p)
+--E 1761
+
+--S 1762 of 5341
+--a0:=integrate(t0,x)
+--E 1762
+
+--S 1763 of 5341
+--m0:=a0-r0
+--E 1763
+
+--S 1764 of 5341
+--d0:=D(m0,x)
+--E 1764
+
+)clear all
+
+--S 1765 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^p/(f+g*x)
+--R 
+--R
+--R                          n      p
+--R        (b log(c (e x + d) ) + a)
+--R   (1)  --------------------------
+--R                  g x + f
+--R                                                    Type: Expression(Integer)
+--E 1765
+
+--S 1766 of 5341
+--r0:=Int((a+b*log(c*(d+e*x)^n))^p/(f+g*x),x)
+--E 1766
+
+--S 1767 of 5341
+--a0:=integrate(t0,x)
+--E 1767
+
+--S 1768 of 5341
+--m0:=a0-r0
+--E 1768
+
+--S 1769 of 5341
+--d0:=D(m0,x)
+--E 1769
+
+)clear all
+
+--S 1770 of 5341
+t0:=x^m*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R         m          2     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1770
+
+--S 1771 of 5341
+--r0:=-2*p*x^(1+m)/(1+m)^2+2*p*x^(1+m)*hypergeometric(1,1/2*(1+m),_
+--  1/2*(3+m),-b*x^2/a)/(1+m)^2+x^(1+m)*log(c*(a+b*x^2)^p)/(1+m)
+--E 1771
+
+--S 1772 of 5341
+--a0:=integrate(t0,x)
+--E 1772
+
+--S 1773 of 5341
+--m0:=a0-r0
+--E 1773
+
+--S 1774 of 5341
+--d0:=D(m0,x)
+--E 1774
+
+)clear all
+
+--S 1775 of 5341
+t0:=x^4*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R         4          2     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1775
+
+--S 1776 of 5341
+r0:=-2/5*a^2*p*x/b^2+2/15*a*p*x^3/b-2/25*p*x^5+2/5*a^(5/2)*p*_
+   atan(x*sqrt(b)/sqrt(a))/b^(5/2)+1/5*x^5*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R   (2)
+--R                                                      +-+
+--R          2 5 +-+          2     p       2  +-+     x\|b
+--R       15b x \|b log(c (b x  + a) ) + 30a p\|a atan(-----)
+--R                                                      +-+
+--R                                                     \|a
+--R     + 
+--R            2   5            3      2     +-+
+--R       (- 6b p x  + 10a b p x  - 30a p x)\|b
+--R  /
+--R        2 +-+
+--R     75b \|b
+--R                                                    Type: Expression(Integer)
+--E 1776
+
+--S 1777 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             +---+
+--R                             |  a       2
+--R               +---+    2b x |- -  + b x  - a
+--R            2  |  a         \|  b                   2   5       2
+--R         15a p |- - log(---------------------) + 15b p x log(b x  + a)
+--R              \|  b               2
+--R                               b x  + a
+--R       + 
+--R            2 5           2   5            3      2
+--R         15b x log(c) - 6b p x  + 10a b p x  - 30a p x
+--R    /
+--R          2
+--R       75b
+--R     ,
+--R
+--R                          +-+
+--R                          |a
+--R                 +-+      |-
+--R              2  |a      \|b        2   5       2           2 5           2   5
+--R         - 30a p |- atan(----) + 15b p x log(b x  + a) + 15b x log(c) - 6b p x
+--R                \|b        x
+--R       + 
+--R                  3      2
+--R         10a b p x  - 30a p x
+--R    /
+--R          2
+--R       75b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1777
+
+--S 1778 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             +---+
+--R                             |  a       2
+--R           +---+        2b x |- -  + b x  - a
+--R        2  |  a  +-+        \|  b                 2 5 +-+          2     p
+--R       a p |- - \|b log(---------------------) - b x \|b log(c (b x  + a) )
+--R          \|  b                   2
+--R                               b x  + a
+--R     + 
+--R                        +-+
+--R           2  +-+     x\|b       2   5       2         2 5        +-+
+--R       - 2a p\|a atan(-----) + (b p x log(b x  + a) + b x log(c))\|b
+--R                        +-+
+--R                       \|a
+--R  /
+--R       2 +-+
+--R     5b \|b
+--R                                                    Type: Expression(Integer)
+--E 1778
+
+--S 1779 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1779
+
+--S 1780 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                     +-+
+--R          2 5 +-+          2     p      2  +-+     x\|b
+--R       - b x \|b log(c (b x  + a) ) - 2a p\|a atan(-----)
+--R                                                     +-+
+--R                                                    \|a
+--R     + 
+--R                           +-+
+--R                           |a
+--R              +-+          |-
+--R           2  |a  +-+     \|b       2   5       2         2 5        +-+
+--R       - 2a p |- \|b atan(----) + (b p x log(b x  + a) + b x log(c))\|b
+--R             \|b            x
+--R  /
+--R       2 +-+
+--R     5b \|b
+--R                                                    Type: Expression(Integer)
+--E 1780
+
+--S 1781 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1781
+
+)clear all
+
+--S 1782 of 5341
+t0:=x^3*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R         3          2     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1782
+
+--S 1783 of 5341
+r0:=1/4*a*p*x^2/b-1/8*p*x^4-1/4*a^2*p*log(a+b*x^2)/b^2+1/4*x^4*_
+   log(c*(a+b*x^2)^p)
+--R 
+--R
+--R          2 4          2     p      2         2         2   4           2
+--R        2b x log(c (b x  + a) ) - 2a p log(b x  + a) - b p x  + 2a b p x
+--R   (2)  -----------------------------------------------------------------
+--R                                         2
+--R                                       8b
+--R                                                    Type: Expression(Integer)
+--E 1783
+
+--S 1784 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2   4     2         2          2 4          2   4           2
+--R        (2b p x  - 2a p)log(b x  + a) + 2b x log(c) - b p x  + 2a b p x
+--R   (3)  ----------------------------------------------------------------
+--R                                         2
+--R                                       8b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1784
+
+--S 1785 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           4          2     p       4       2         4
+--R        - x log(c (b x  + a) ) + p x log(b x  + a) + x log(c)
+--R   (4)  -----------------------------------------------------
+--R                                  4
+--R                                                    Type: Expression(Integer)
+--E 1785
+
+--S 1786 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1786
+
+)clear all
+
+--S 1787 of 5341
+t0:=x^2*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R         2          2     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1787
+
+--S 1788 of 5341
+r0:=2/3*a*p*x/b-2/9*p*x^3-2/3*a^(3/2)*p*atan(x*sqrt(b)/sqrt(a))/b^(3/2)+_
+   1/3*x^3*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R   (2)
+--R                                                +-+
+--R       3 +-+          2     p         +-+     x\|b              3           +-+
+--R   3b x \|b log(c (b x  + a) ) - 6a p\|a atan(-----) + (- 2b p x  + 6a p x)\|b
+--R                                                +-+
+--R                                               \|a
+--R   ----------------------------------------------------------------------------
+--R                                         +-+
+--R                                      9b\|b
+--R                                                    Type: Expression(Integer)
+--E 1788
+
+--S 1789 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                              +---+
+--R                              |  a       2
+--R              +---+    - 2b x |- -  + b x  - a
+--R              |  a           \|  b                      3       2
+--R         3a p |- - log(-----------------------) + 3b p x log(b x  + a)
+--R             \|  b                2
+--R                               b x  + a
+--R       + 
+--R             3               3
+--R         3b x log(c) - 2b p x  + 6a p x
+--R    /
+--R       9b
+--R     ,
+--R                  +-+
+--R                  |a
+--R         +-+      |-
+--R         |a      \|b           3       2            3               3
+--R    6a p |- atan(----) + 3b p x log(b x  + a) + 3b x log(c) - 2b p x  + 6a p x
+--R        \|b        x
+--R    --------------------------------------------------------------------------]
+--R                                        9b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1789
+
+--S 1790 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                              +---+
+--R                                                              |  a       2
+--R                                          +---+        - 2b x |- -  + b x  - a
+--R            3 +-+          2     p        |  a  +-+          \|  b
+--R       - b x \|b log(c (b x  + a) ) + a p |- - \|b log(-----------------------)
+--R                                         \|  b                    2
+--R                                                               b x  + a
+--R     + 
+--R                      +-+
+--R            +-+     x\|b           3       2           3        +-+
+--R       2a p\|a atan(-----) + (b p x log(b x  + a) + b x log(c))\|b
+--R                      +-+
+--R                     \|a
+--R  /
+--R        +-+
+--R     3b\|b
+--R                                                    Type: Expression(Integer)
+--E 1790
+
+--S 1791 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1791
+
+--S 1792 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                     +-+
+--R            3 +-+          2     p         +-+     x\|b
+--R       - b x \|b log(c (b x  + a) ) + 2a p\|a atan(-----)
+--R                                                     +-+
+--R                                                    \|a
+--R     + 
+--R                         +-+
+--R                         |a
+--R            +-+          |-
+--R            |a  +-+     \|b           3       2           3        +-+
+--R       2a p |- \|b atan(----) + (b p x log(b x  + a) + b x log(c))\|b
+--R           \|b            x
+--R  /
+--R        +-+
+--R     3b\|b
+--R                                                    Type: Expression(Integer)
+--E 1792
+
+--S 1793 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1793
+
+)clear all
+
+--S 1794 of 5341
+t0:=x*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R                    2     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1794
+
+--S 1795 of 5341
+r0:=-1/2*p*x^2+1/2*(a+b*x^2)*log(c*(a+b*x^2)^p)/b
+--R 
+--R
+--R            2               2     p         2
+--R        (b x  + a)log(c (b x  + a) ) - b p x
+--R   (2)  -------------------------------------
+--R                          2b
+--R                                                    Type: Expression(Integer)
+--E 1795
+
+--S 1796 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R              2              2           2              2
+--R        (b p x  + a p)log(b x  + a) + b x log(c) - b p x
+--R   (3)  -------------------------------------------------
+--R                                2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1796
+
+--S 1797 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         2               2     p          2              2           2
+--R   (- b x  - a)log(c (b x  + a) ) + (b p x  + a p)log(b x  + a) + b x log(c)
+--R   -------------------------------------------------------------------------
+--R                                       2b
+--R                                                    Type: Expression(Integer)
+--E 1797
+
+--S 1798 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1798
+
+)clear all
+
+--S 1799 of 5341
+t0:=log(c*(a+b*x^2)^p)
+--R 
+--R
+--R                  2     p
+--R   (1)  log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1799
+
+--S 1800 of 5341
+r0:=-2*p*x+x*log(c*(a+b*x^2)^p)+2*p*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/sqrt(b)
+--R 
+--R
+--R                                               +-+
+--R          +-+          2     p       +-+     x\|b          +-+
+--R        x\|b log(c (b x  + a) ) + 2p\|a atan(-----) - 2p x\|b
+--R                                               +-+
+--R                                              \|a
+--R   (2)  ------------------------------------------------------
+--R                                  +-+
+--R                                 \|b
+--R                                                    Type: Expression(Integer)
+--E 1800
+
+--S 1801 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +---+
+--R                    |  a       2
+--R      +---+    2b x |- -  + b x  - a
+--R      |  a         \|  b                           2
+--R   [p |- - log(---------------------) + p x log(b x  + a) + x log(c) - 2p x,
+--R     \|  b               2
+--R                      b x  + a
+--R                  +-+
+--R                  |a
+--R         +-+      |-
+--R         |a      \|b                2
+--R    - 2p |- atan(----) + p x log(b x  + a) + x log(c) - 2p x]
+--R        \|b        x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1801
+
+--S 1802 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           +---+
+--R                           |  a       2
+--R         +---+        2b x |- -  + b x  - a
+--R         |  a  +-+        \|  b                  +-+          2     p
+--R       p |- - \|b log(---------------------) - x\|b log(c (b x  + a) )
+--R        \|  b                   2
+--R                             b x  + a
+--R     + 
+--R                      +-+
+--R            +-+     x\|b                 2                  +-+
+--R       - 2p\|a atan(-----) + (p x log(b x  + a) + x log(c))\|b
+--R                      +-+
+--R                     \|a
+--R  /
+--R      +-+
+--R     \|b
+--R                                                    Type: Expression(Integer)
+--E 1802
+
+--S 1803 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1803
+
+--S 1804 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                       +-+
+--R                                                                       |a
+--R                                                +-+       +-+          |-
+--R           +-+          2     p       +-+     x\|b        |a  +-+     \|b
+--R       - x\|b log(c (b x  + a) ) - 2p\|a atan(-----) - 2p |- \|b atan(----)
+--R                                                +-+      \|b            x
+--R                                               \|a
+--R     + 
+--R                   2                  +-+
+--R       (p x log(b x  + a) + x log(c))\|b
+--R  /
+--R      +-+
+--R     \|b
+--R                                                    Type: Expression(Integer)
+--E 1804
+
+--S 1805 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1805
+
+)clear all
+
+--S 1806 of 5341
+t0:=log(c*(a+b*x^2)^p)/x
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 1806
+
+--S 1807 of 5341
+--r0:=1/2*log(-b*x^2/a)*log(c*(a+b*x^2)^p)+1/2*p*polylog(2,(a+b*x^2)/a)
+--E 1807
+
+--S 1808 of 5341
+--a0:=integrate(t0,x)
+--E 1808
+
+--S 1809 of 5341
+--m0:=a0-r0
+--E 1809
+
+--S 1810 of 5341
+--d0:=D(m0,x)
+--E 1810
+
+)clear all
+
+--S 1811 of 5341
+t0:=log(c*(a+b*x^2)^p)/x^2
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1811
+
+--S 1812 of 5341
+r0:=-log(c*(a+b*x^2)^p)/x+2*p*atan(x*sqrt(b)/sqrt(a))*sqrt(b)/sqrt(a)
+--R 
+--R
+--R                                                  +-+
+--R           +-+          2     p         +-+     x\|b
+--R        - \|a log(c (b x  + a) ) + 2p x\|b atan(-----)
+--R                                                  +-+
+--R                                                 \|a
+--R   (2)  ----------------------------------------------
+--R                               +-+
+--R                             x\|a
+--R                                                    Type: Expression(Integer)
+--E 1812
+
+--S 1813 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +---+
+--R                      |  b       2
+--R        +---+    2a x |- -  + b x  - a
+--R        |  b         \|  a                         2
+--R    p x |- - log(---------------------) - p log(b x  + a) - log(c)
+--R       \|  a               2
+--R                        b x  + a
+--R   [--------------------------------------------------------------,
+--R                                   x
+--R                     +-+
+--R                     |b
+--R           +-+     a |-
+--R           |b       \|a              2
+--R    - 2p x |- atan(-----) - p log(b x  + a) - log(c)
+--R          \|a       b x
+--R    ------------------------------------------------]
+--R                            x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1813
+
+--S 1814 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             +---+
+--R                             |  b       2
+--R           +---+        2a x |- -  + b x  - a
+--R           |  b  +-+        \|  a                 +-+          2     p
+--R       p x |- - \|a log(---------------------) + \|a log(c (b x  + a) )
+--R          \|  a                   2
+--R                               b x  + a
+--R     + 
+--R                        +-+
+--R              +-+     x\|b                 2                +-+
+--R       - 2p x\|b atan(-----) + (- p log(b x  + a) - log(c))\|a
+--R                        +-+
+--R                       \|a
+--R  /
+--R       +-+
+--R     x\|a
+--R                                                    Type: Expression(Integer)
+--E 1814
+
+--S 1815 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1815
+
+--S 1816 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                         +-+
+--R                                                                         |b
+--R                                               +-+             +-+     a |-
+--R        +-+          2     p         +-+     x\|b          +-+ |b       \|a
+--R       \|a log(c (b x  + a) ) - 2p x\|b atan(-----) - 2p x\|a  |- atan(-----)
+--R                                               +-+            \|a       b x
+--R                                              \|a
+--R     + 
+--R                   2                +-+
+--R       (- p log(b x  + a) - log(c))\|a
+--R  /
+--R       +-+
+--R     x\|a
+--R                                                    Type: Expression(Integer)
+--E 1816
+
+--S 1817 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1817
+
+)clear all
+
+--S 1818 of 5341
+t0:=log(c*(a+b*x^2)^p)/x^3
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1818
+
+--S 1819 of 5341
+r0:=b*p*log(x)/a-1/2*(a+b*x^2)*log(c*(a+b*x^2)^p)/(a*x^2),b*p*log(x)/a-_
+   1/2*b*p*log(a+b*x^2)/a-1/2*log(c*(a+b*x^2)^p)/x^2
+--R 
+--R
+--R   (2)
+--R          2               2     p          2
+--R    (- b x  - a)log(c (b x  + a) ) + 2b p x log(x)
+--R   [----------------------------------------------,
+--R                             2
+--R                         2a x
+--R                  2     p         2       2              2
+--R    - a log(c (b x  + a) ) - b p x log(b x  + a) + 2b p x log(x)
+--R    ------------------------------------------------------------]
+--R                                    2
+--R                                2a x
+--R                                             Type: Tuple(Expression(Integer))
+--E 1819
+
+--S 1820 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2              2              2
+--R        (- b p x  - a p)log(b x  + a) + 2b p x log(x) - a log(c)
+--R   (3)  --------------------------------------------------------
+--R                                      2
+--R                                  2a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1820
+
+--S 1821 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       2               2     p            2              2
+--R   (b x  + a)log(c (b x  + a) ) + (- b p x  - a p)log(b x  + a) - a log(c)
+--R   -----------------------------------------------------------------------
+--R                                        2
+--R                                    2a x
+--R                                                    Type: Expression(Integer)
+--E 1821
+
+--S 1822 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1822
+
+)clear all
+
+--S 1823 of 5341
+t0:=log(c*(a+b*x^2)^p)/x^4
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 4
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1823
+
+--S 1824 of 5341
+r0:=-2/3*b*p/(a*x)-2/3*b^(3/2)*p*atan(x*sqrt(b)/sqrt(a))/a^(3/2)-_
+   1/3*log(c*(a+b*x^2)^p)/x^3
+--R 
+--R
+--R                                                      +-+
+--R            +-+          2     p          3 +-+     x\|b           2 +-+
+--R        - a\|a log(c (b x  + a) ) - 2b p x \|b atan(-----) - 2b p x \|a
+--R                                                      +-+
+--R                                                     \|a
+--R   (2)  ----------------------------------------------------------------
+--R                                        3 +-+
+--R                                    3a x \|a
+--R                                                    Type: Expression(Integer)
+--E 1824
+
+--S 1825 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                +---+
+--R                                |  b       2
+--R                +---+    - 2a x |- -  + b x  - a
+--R              3 |  b           \|  a                           2
+--R         b p x  |- - log(-----------------------) - a p log(b x  + a) - a log(c)
+--R               \|  a                2
+--R                                 b x  + a
+--R       + 
+--R                 2
+--R         - 2b p x
+--R    /
+--R           3
+--R       3a x
+--R     ,
+--R                      +-+
+--R                      |b
+--R            +-+     a |-
+--R          3 |b       \|a                2                         2
+--R    2b p x  |- atan(-----) - a p log(b x  + a) - a log(c) - 2b p x
+--R           \|a       b x
+--R    ---------------------------------------------------------------]
+--R                                     3
+--R                                 3a x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1825
+
+--S 1826 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                            +---+
+--R                                                            |  b       2
+--R                                        +---+        - 2a x |- -  + b x  - a
+--R         +-+          2     p         3 |  b  +-+          \|  a
+--R       a\|a log(c (b x  + a) ) + b p x  |- - \|a log(-----------------------)
+--R                                       \|  a                    2
+--R                                                             b x  + a
+--R     + 
+--R                         +-+
+--R             3 +-+     x\|b                   2                  +-+
+--R       2b p x \|b atan(-----) + (- a p log(b x  + a) - a log(c))\|a
+--R                         +-+
+--R                        \|a
+--R  /
+--R         3 +-+
+--R     3a x \|a
+--R                                                    Type: Expression(Integer)
+--E 1826
+
+--S 1827 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1827
+
+--S 1828 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                   +-+
+--R         +-+          2     p          3 +-+     x\|b
+--R       a\|a log(c (b x  + a) ) + 2b p x \|b atan(-----)
+--R                                                   +-+
+--R                                                  \|a
+--R     + 
+--R                             +-+
+--R                             |b
+--R                   +-+     a |-
+--R             3 +-+ |b       \|a                   2                  +-+
+--R       2b p x \|a  |- atan(-----) + (- a p log(b x  + a) - a log(c))\|a
+--R                  \|a       b x
+--R  /
+--R         3 +-+
+--R     3a x \|a
+--R                                                    Type: Expression(Integer)
+--E 1828
+
+--S 1829 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1829
+
+)clear all
+
+--S 1830 of 5341
+t0:=log(c*(a+b*x^2)^p)/x^5
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 5
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1830
+
+--S 1831 of 5341
+r0:=-1/4*b*p/(a*x^2)-1/2*b^2*p*log(x)/a^2+1/4*b^2*p*log(a+b*x^2)/a^2-_
+   1/4*log(c*(a+b*x^2)^p)/x^4
+--R 
+--R
+--R   (2)
+--R      2          2     p     2   4       2          2   4                2
+--R   - a log(c (b x  + a) ) + b p x log(b x  + a) - 2b p x log(x) - a b p x
+--R   -----------------------------------------------------------------------
+--R                                      2 4
+--R                                    4a x
+--R                                                    Type: Expression(Integer)
+--E 1831
+
+--S 1832 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2   4    2         2          2   4          2                2
+--R        (b p x  - a p)log(b x  + a) - 2b p x log(x) - a log(c) - a b p x
+--R   (3)  -----------------------------------------------------------------
+--R                                        2 4
+--R                                      4a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1832
+
+--S 1833 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  2     p             2
+--R        log(c (b x  + a) ) - p log(b x  + a) - log(c)
+--R   (4)  ---------------------------------------------
+--R                               4
+--R                             4x
+--R                                                    Type: Expression(Integer)
+--E 1833
+
+--S 1834 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1834
+
+)clear all
+
+--S 1835 of 5341
+t0:=log(c*(a+b*x^2)^p)/x^6
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 6
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1835
+
+--S 1836 of 5341
+r0:=-2/15*b*p/(a*x^3)+2/5*b^2*p/(a^2*x)+2/5*b^(5/2)*p*atan(x*sqrt(b)/_
+   sqrt(a))/a^(5/2)-1/5*log(c*(a+b*x^2)^p)/x^5
+--R 
+--R
+--R   (2)
+--R                                                       +-+
+--R           2 +-+          2     p      2   5 +-+     x\|b
+--R       - 3a \|a log(c (b x  + a) ) + 6b p x \|b atan(-----)
+--R                                                       +-+
+--R                                                      \|a
+--R     + 
+--R          2   4           2  +-+
+--R       (6b p x  - 2a b p x )\|a
+--R  /
+--R        2 5 +-+
+--R     15a x \|a
+--R                                                    Type: Expression(Integer)
+--E 1836
+
+--S 1837 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               +---+
+--R                               |  b       2
+--R                 +---+    2a x |- -  + b x  - a
+--R           2   5 |  b         \|  a                  2         2
+--R         3b p x  |- - log(---------------------) - 3a p log(b x  + a)
+--R                \|  a               2
+--R                                 b x  + a
+--R       + 
+--R             2           2   4           2
+--R         - 3a log(c) + 6b p x  - 2a b p x
+--R    /
+--R          2 5
+--R       15a x
+--R     ,
+--R
+--R                             +-+
+--R                             |b
+--R                   +-+     a |-
+--R             2   5 |b       \|a       2         2          2           2   4
+--R         - 6b p x  |- atan(-----) - 3a p log(b x  + a) - 3a log(c) + 6b p x
+--R                  \|a       b x
+--R       + 
+--R                   2
+--R         - 2a b p x
+--R    /
+--R          2 5
+--R       15a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 1837
+
+--S 1838 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                +---+
+--R                                |  b       2
+--R              +---+        2a x |- -  + b x  - a
+--R        2   5 |  b  +-+        \|  a                 2 +-+          2     p
+--R       b p x  |- - \|a log(---------------------) + a \|a log(c (b x  + a) )
+--R             \|  a                   2
+--R                                  b x  + a
+--R     + 
+--R                           +-+
+--R           2   5 +-+     x\|b         2         2         2        +-+
+--R       - 2b p x \|b atan(-----) + (- a p log(b x  + a) - a log(c))\|a
+--R                           +-+
+--R                          \|a
+--R  /
+--R       2 5 +-+
+--R     5a x \|a
+--R                                                    Type: Expression(Integer)
+--E 1838
+
+--S 1839 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1839
+
+--S 1840 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                    +-+
+--R        2 +-+          2     p      2   5 +-+     x\|b
+--R       a \|a log(c (b x  + a) ) - 2b p x \|b atan(-----)
+--R                                                    +-+
+--R                                                   \|a
+--R     + 
+--R                               +-+
+--R                               |b
+--R                     +-+     a |-
+--R           2   5 +-+ |b       \|a         2         2         2        +-+
+--R       - 2b p x \|a  |- atan(-----) + (- a p log(b x  + a) - a log(c))\|a
+--R                    \|a       b x
+--R  /
+--R       2 5 +-+
+--R     5a x \|a
+--R                                                    Type: Expression(Integer)
+--E 1840
+
+--S 1841 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 1841
+
+)clear all
+
+--S 1842 of 5341
+t0:=log(c*(a+b*x^2)^p)/x^7
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 7
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1842
+
+--S 1843 of 5341
+r0:=-1/12*b*p/(a*x^4)+1/6*b^2*p/(a^2*x^2)+1/3*b^3*p*log(x)/a^3-_
+   1/6*b^3*p*log(a+b*x^2)/a^3-1/6*log(c*(a+b*x^2)^p)/x^6
+--R 
+--R
+--R   (2)
+--R           3          2     p      3   6       2          3   6
+--R       - 2a log(c (b x  + a) ) - 2b p x log(b x  + a) + 4b p x log(x)
+--R     + 
+--R           2   4    2     2
+--R       2a b p x  - a b p x
+--R  /
+--R        3 6
+--R     12a x
+--R                                                    Type: Expression(Integer)
+--E 1843
+
+--S 1844 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3   6     3         2          3   6           3             2   4
+--R       (- 2b p x  - 2a p)log(b x  + a) + 4b p x log(x) - 2a log(c) + 2a b p x
+--R     + 
+--R          2     2
+--R       - a b p x
+--R  /
+--R        3 6
+--R     12a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1844
+
+--S 1845 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  2     p             2
+--R        log(c (b x  + a) ) - p log(b x  + a) - log(c)
+--R   (4)  ---------------------------------------------
+--R                               6
+--R                             6x
+--R                                                    Type: Expression(Integer)
+--E 1845
+
+--S 1846 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1846
+
+)clear all
+
+--S 1847 of 5341
+t0:=x^m*log(c*(a+b*x^3)^p)
+--R 
+--R
+--R         m          3     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1847
+
+--S 1848 of 5341
+--r0:=-3*p*x^(1+m)/(1+m)^2+3*p*x^(1+m)*hypergeometric(1,1/3*(1+m),_
+--  1/3*(4+m),-b*x^3/a)/(1+m)^2+x^(1+m)*log(c*(a+b*x^3)^p)/(1+m)
+--E 1848
+
+--S 1849 of 5341
+--a0:=integrate(t0,x)
+--E 1849
+
+--S 1850 of 5341
+--m0:=a0-r0
+--E 1850
+
+--S 1851 of 5341
+--d0:=D(m0,x)
+--E 1851
+
+)clear all
+
+--S 1852 of 5341
+t0:=x^5*log(c*(a+b*x^3)^p)
+--R 
+--R
+--R         5          3     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1852
+
+--S 1853 of 5341
+r0:=1/6*a*p*x^3/b-1/12*p*x^6-1/6*a^2*p*log(a+b*x^3)/b^2+1/6*x^6*_
+   log(c*(a+b*x^3)^p)
+--R 
+--R
+--R          2 6          3     p      2         3         2   6           3
+--R        2b x log(c (b x  + a) ) - 2a p log(b x  + a) - b p x  + 2a b p x
+--R   (2)  -----------------------------------------------------------------
+--R                                          2
+--R                                       12b
+--R                                                    Type: Expression(Integer)
+--E 1853
+
+--S 1854 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2   6     2         3          2 6          2   6           3
+--R        (2b p x  - 2a p)log(b x  + a) + 2b x log(c) - b p x  + 2a b p x
+--R   (3)  ----------------------------------------------------------------
+--R                                         2
+--R                                      12b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1854
+
+--S 1855 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           6          3     p       6       3         6
+--R        - x log(c (b x  + a) ) + p x log(b x  + a) + x log(c)
+--R   (4)  -----------------------------------------------------
+--R                                  6
+--R                                                    Type: Expression(Integer)
+--E 1855
+
+--S 1856 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1856
+
+)clear all
+
+--S 1857 of 5341
+t0:=x^4*log(c*(a+b*x^3)^p)
+--R 
+--R
+--R         4          3     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1857
+
+--S 1858 of 5341
+r0:=3/10*a*p*x^2/b-3/25*p*x^5+1/5*a^(5/3)*p*log(a^(1/3)+b^(1/3)*x)/_
+   b^(5/3)-1/10*a^(5/3)*p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   b^(5/3)+1/5*x^5*log(c*(a+b*x^3)^p)+1/5*a^(5/3)*p*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/b^(5/3)
+--R 
+--R
+--R   (2)
+--R              3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       - 5a p \|a  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             3+-+2     3+-+   3+-+         5 3+-+2          3     p
+--R       10a p \|a  log(x\|b  + \|a ) + 10b x  \|b  log(c (b x  + a) )
+--R     + 
+--R                              3+-+   3+-+
+--R               +-+3+-+2     2x\|b  - \|a              5          2 3+-+2
+--R       - 10a p\|3 \|a  atan(-------------) + (- 6b p x  + 15a p x )\|b
+--R                                +-+3+-+
+--R                               \|3 \|a
+--R  /
+--R         3+-+2
+--R     50b \|b
+--R                                                    Type: Expression(Integer)
+--E 1858
+
+--S 1859 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +--+       +--+2
+--R              | 2        | 2
+--R              |a         |a
+--R       10a p  |-- log(b  |--   + a x)
+--R             3| 2       3| 2
+--R             \|b        \|b
+--R     + 
+--R               +--+           +--+2      +--+
+--R               | 2            | 2        | 2
+--R               |a             |a         |a       2
+--R       - 5a p  |-- log(- b x  |--   + a  |-- + a x )
+--R              3| 2           3| 2       3| 2
+--R              \|b            \|b        \|b
+--R     + 
+--R                                      +--+2
+--R                                      | 2
+--R                                 +-+  |a
+--R                    +--+       b\|3   |--
+--R                    | 2              3| 2
+--R               +-+  |a               \|b              5       3
+--R       - 10a p\|3   |-- atan(--------------- + 10b p x log(b x  + a)
+--R                   3| 2         +--+2
+--R                   \|b          | 2
+--R                                |a
+--R                             b  |--   - 2a x
+--R                               3| 2
+--R                               \|b
+--R     + 
+--R            5               5          2
+--R       10b x log(c) - 6b p x  + 15a p x
+--R  /
+--R     50b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1859
+
+--S 1860 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3+-+2     2 3+-+2   3+-+3+-+   3+-+2         3+-+2     3+-+   3+-+
+--R       a p \|a  log(x  \|b  - x\|a \|b  + \|a  ) - 2a p \|a  log(x\|b  + \|a )
+--R     + 
+--R             +--+            +--+2
+--R             | 2             | 2
+--R             |a  3+-+2       |a                5 3+-+2          3     p
+--R       2a p  |-- \|b  log(b  |--   + a x - 2b x  \|b  log(c (b x  + a) )
+--R            3| 2            3| 2
+--R            \|b             \|b
+--R     + 
+--R              +--+                +--+2      +--+
+--R              | 2                 | 2        | 2
+--R              |a  3+-+2           |a         |a       2
+--R       - a p  |-- \|b  log(- b x  |--   + a  |-- + a x )
+--R             3| 2                3| 2       3| 2
+--R             \|b                 \|b        \|b
+--R     + 
+--R                           3+-+   3+-+
+--R            +-+3+-+2     2x\|b  - \|a
+--R       2a p\|3 \|a  atan(-------------)
+--R                             +-+3+-+
+--R                            \|3 \|a
+--R     + 
+--R                                          +--+2
+--R                                          | 2
+--R                                     +-+  |a
+--R                   +--+            b\|3   |--
+--R                   | 2                   3| 2
+--R              +-+  |a  3+-+2             \|b
+--R       - 2a p\|3   |-- \|b  atan(---------------)
+--R                  3| 2              +--+2
+--R                  \|b               | 2
+--R                                    |a
+--R                                 b  |--   - 2a x
+--R                                   3| 2
+--R                                   \|b
+--R     + 
+--R              5       3            5       3+-+2
+--R       (2b p x log(b x  + a) + 2b x log(c))\|b
+--R  /
+--R         3+-+2
+--R     10b \|b
+--R                                                    Type: Expression(Integer)
+--E 1860
+
+--S 1861 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1861
+
+)clear all
+
+--S 1862 of 5341
+t0:=x^3*log(c*(a+b*x^3)^p)
+--R 
+--R
+--R         3          3     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1862
+
+--S 1863 of 5341
+r0:=3/4*a*p*x/b-3/16*p*x^4-1/4*a^(4/3)*p*log(a^(1/3)+b^(1/3)*x)/b^(4/3)+_
+   1/8*a^(4/3)*p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/b^(4/3)+_
+   1/4*x^4*log(c*(a+b*x^3)^p)+1/4*a^(4/3)*p*atan((a^(1/3)-2*b^(1/3)*x)/_
+   (a^(1/3)*sqrt(3)))*sqrt(3)/b^(4/3)
+--R 
+--R
+--R   (2)
+--R           3+-+     2 3+-+2   3+-+3+-+   3+-+2        3+-+     3+-+   3+-+
+--R       2a p\|a log(x  \|b  - x\|a \|b  + \|a  ) - 4a p\|a log(x\|b  + \|a )
+--R     + 
+--R                                                        3+-+   3+-+
+--R           4 3+-+          3     p        +-+3+-+     2x\|b  - \|a
+--R       4b x  \|b log(c (b x  + a)  - 4a p\|3 \|a atan(-------------)
+--R                                                          +-+3+-+
+--R                                                         \|3 \|a
+--R     + 
+--R                4           3+-+
+--R       (- 3b p x  + 12a p x)\|b
+--R  /
+--R        3+-+
+--R     16b\|b
+--R                                                    Type: Expression(Integer)
+--E 1863
+
+--S 1864 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +---+     +---+2      +---+             +---+       +---+
+--R               |  a      |  a        |  a    2         |  a        |  a
+--R       - 2a p 3|- - log(3|- -   + x 3|- - + x  + 4a p 3|- - log(- 3|- -  + x)
+--R              \|  b     \|  b       \|  b             \|  b       \|  b
+--R     + 
+--R                                  +---+
+--R                             +-+  |  a
+--R                 +---+      \|3  3|- -
+--R            +-+  |  a            \|  b         4       3            4
+--R       4a p\|3  3|- - atan(----------- + 4b p x log(b x  + a) + 4b x log(c)
+--R                \|  b       +---+
+--R                            |  a
+--R                           3|- -  + 2x
+--R                           \|  b
+--R     + 
+--R               4
+--R       - 3b p x  + 12a p x
+--R  /
+--R     16b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1864
+
+--S 1865 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3+-+     2 3+-+2   3+-+3+-+   3+-+2        3+-+     3+-+   3+-+
+--R       - a p\|a log(x  \|b  - x\|a \|b  + \|a  ) + 2a p\|a log(x\|b  + \|a )
+--R     + 
+--R              +---+         +---+2      +---+
+--R              |  a 3+-+     |  a        |  a    2       4 3+-+          3     p
+--R       - a p 3|- - \|b log(3|- -   + x 3|- - + x  - 2b x  \|b log(c (b x  + a) )
+--R             \|  b         \|  b       \|  b
+--R     + 
+--R             +---+           +---+                          3+-+   3+-+
+--R             |  a 3+-+       |  a             +-+3+-+     2x\|b  - \|a
+--R       2a p 3|- - \|b log(- 3|- -  + x + 2a p\|3 \|a atan(-------------)
+--R            \|  b           \|  b                             +-+3+-+
+--R                                                             \|3 \|a
+--R     + 
+--R                                      +---+
+--R                                 +-+  |  a
+--R                 +---+          \|3  3|- -
+--R            +-+  |  a 3+-+           \|  b
+--R       2a p\|3  3|- - \|b atan(-----------)
+--R                \|  b           +---+
+--R                                |  a
+--R                               3|- -  + 2x
+--R                               \|  b
+--R     + 
+--R              4       3            4       3+-+
+--R       (2b p x log(b x  + a) + 2b x log(c))\|b
+--R  /
+--R       3+-+
+--R     8b\|b
+--R                                                    Type: Expression(Integer)
+--E 1865
+
+--S 1866 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1866
+
+)clear all
+
+--S 1867 of 5341
+t0:=x^2*log(c*(a+b*x^3)^p)
+--R 
+--R
+--R         2          3     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1867
+
+--S 1868 of 5341
+r0:=-1/3*p*x^3+1/3*(a+b*x^3)*log(c*(a+b*x^3)^p)/b
+--R 
+--R
+--R            3               3     p         3
+--R        (b x  + a)log(c (b x  + a) ) - b p x
+--R   (2)  -------------------------------------
+--R                          3b
+--R                                                    Type: Expression(Integer)
+--E 1868
+
+--S 1869 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R              3              3           3              3
+--R        (b p x  + a p)log(b x  + a) + b x log(c) - b p x
+--R   (3)  -------------------------------------------------
+--R                                3b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1869
+
+--S 1870 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         3               3     p          3              3           3
+--R   (- b x  - a)log(c (b x  + a) ) + (b p x  + a p)log(b x  + a) + b x log(c)
+--R   -------------------------------------------------------------------------
+--R                                       3b
+--R                                                    Type: Expression(Integer)
+--E 1870
+
+--S 1871 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1871
+
+)clear all
+
+--S 1872 of 5341
+t0:=x*log(c*(a+b*x^3)^p)
+--R 
+--R
+--R                    3     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1872
+
+--S 1873 of 5341
+r0:=-3/4*p*x^2-1/2*a^(2/3)*p*log(a^(1/3)+b^(1/3)*x)/b^(2/3)+1/4*a^(2/3)*p*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/b^(2/3)+1/2*x^2*log(c*(a+_
+   b*x^3)^p)-1/2*a^(2/3)*p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*_
+   sqrt(3)/b^(2/3)
+--R 
+--R
+--R   (2)
+--R         3+-+2     2 3+-+2   3+-+3+-+   3+-+2       3+-+2     3+-+   3+-+
+--R       p \|a  log(x  \|b  - x\|a \|b  + \|a  ) - 2p \|a  log(x\|b  + \|a )
+--R     + 
+--R                                                      3+-+   3+-+
+--R         2 3+-+2          3     p      +-+3+-+2     2x\|b  - \|a         2 3+-+2
+--R       2x  \|b  log(c (b x  + a)  + 2p\|3 \|a  atan(-------------) - 3p x  \|b
+--R                                                        +-+3+-+
+--R                                                       \|3 \|a
+--R  /
+--R      3+-+2
+--R     4\|b
+--R                                                    Type: Expression(Integer)
+--E 1873
+
+--S 1874 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           +----+       +----+2
+--R           |   2        |   2
+--R           |  a         |  a
+--R       2p  |- -- log(b  |- --   + a x)
+--R          3|   2       3|   2
+--R          \|  b        \|  b
+--R     + 
+--R            +----+           +----+2      +----+
+--R            |   2            |   2        |   2
+--R            |  a             |  a         |  a       2
+--R       - p  |- -- log(- b x  |- --   - a  |- -- + a x )
+--R           3|   2           3|   2       3|   2
+--R           \|  b            \|  b        \|  b
+--R     + 
+--R                                     +----+2
+--R                                     |   2
+--R                                +-+  |  a
+--R                 +----+       b\|3   |- --
+--R                 |   2              3|   2
+--R            +-+  |  a               \|  b           2       3          2
+--R       - 2p\|3   |- -- atan(----------------- + 2p x log(b x  + a) + 2x log(c)
+--R                3|   2         +----+2
+--R                \|  b          |   2
+--R                               |  a
+--R                            b  |- --   - 2a x
+--R                              3|   2
+--R                              \|  b
+--R     + 
+--R             2
+--R       - 3p x
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 1874
+
+--S 1875 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3+-+2     2 3+-+2   3+-+3+-+   3+-+2       3+-+2     3+-+   3+-+
+--R       - p \|a  log(x  \|b  - x\|a \|b  + \|a  ) + 2p \|a  log(x\|b  + \|a )
+--R     + 
+--R           +----+            +----+2
+--R           |   2             |   2
+--R           |  a  3+-+2       |  a              2 3+-+2          3     p
+--R       2p  |- -- \|b  log(b  |- --   + a x - 2x  \|b  log(c (b x  + a) )
+--R          3|   2            3|   2
+--R          \|  b             \|  b
+--R     + 
+--R            +----+                +----+2      +----+
+--R            |   2                 |   2        |   2
+--R            |  a  3+-+2           |  a         |  a       2
+--R       - p  |- -- \|b  log(- b x  |- --   - a  |- -- + a x )
+--R           3|   2                3|   2       3|   2
+--R           \|  b                 \|  b        \|  b
+--R     + 
+--R                           3+-+   3+-+
+--R            +-+3+-+2     2x\|b  - \|a
+--R       - 2p\|3 \|a  atan(-------------)
+--R                             +-+3+-+
+--R                            \|3 \|a
+--R     + 
+--R                                          +----+2
+--R                                          |   2
+--R                                     +-+  |  a
+--R                 +----+            b\|3   |- --
+--R                 |   2                   3|   2
+--R            +-+  |  a  3+-+2             \|  b
+--R       - 2p\|3   |- -- \|b  atan(-----------------)
+--R                3|   2              +----+2
+--R                \|  b               |   2
+--R                                    |  a
+--R                                 b  |- --   - 2a x
+--R                                   3|   2
+--R                                   \|  b
+--R     + 
+--R            2       3          2       3+-+2
+--R       (2p x log(b x  + a) + 2x log(c))\|b
+--R  /
+--R      3+-+2
+--R     4\|b
+--R                                                    Type: Expression(Integer)
+--E 1875
+
+--S 1876 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1876
+
+)clear all
+
+--S 1877 of 5341
+t0:=log(c*(a+b*x^3)^p)
+--R 
+--R
+--R                  3     p
+--R   (1)  log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1877
+
+--S 1878 of 5341
+r0:=-3*p*x+a^(1/3)*p*log(a^(1/3)+b^(1/3)*x)/b^(1/3)-1/2*a^(1/3)*p*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/b^(1/3)+x*log(c*(a+b*x^3)^p)-_
+   a^(1/3)*p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/b^(1/3)
+--R 
+--R
+--R   (2)
+--R          3+-+     2 3+-+2   3+-+3+-+   3+-+2      3+-+     3+-+   3+-+
+--R       - p\|a log(x  \|b  - x\|a \|b  + \|a  ) + 2p\|a log(x\|b  + \|a )
+--R     + 
+--R                                                   3+-+   3+-+
+--R         3+-+          3     p       +-+3+-+     2x\|b  - \|a         3+-+
+--R       2x\|b log(c (b x  + a) ) + 2p\|3 \|a atan(-------------) - 6p x\|b
+--R                                                     +-+3+-+
+--R                                                    \|3 \|a
+--R  /
+--R      3+-+
+--R     2\|b
+--R                                                    Type: Expression(Integer)
+--E 1878
+
+--S 1879 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +-+     +-+2      +-+           +-+     +-+
+--R            |a      |a        |a    2       |a      |a
+--R       - p 3|- log(3|-   - x 3|- + x  + 2p 3|- log(3|-  + x)
+--R           \|b     \|b       \|b           \|b     \|b
+--R     + 
+--R                              +-+
+--R                         +-+  |a
+--R               +-+      \|3  3|-
+--R          +-+  |a            \|b               3
+--R       2p\|3  3|- atan(--------- + 2p x log(b x  + a) + 2x log(c) - 6p x
+--R              \|b       +-+
+--R                        |a
+--R                       3|-  - 2x
+--R                       \|b
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 1879
+
+--S 1880 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        3+-+     2 3+-+2   3+-+3+-+   3+-+2      3+-+     3+-+   3+-+
+--R       p\|a log(x  \|b  - x\|a \|b  + \|a  ) - 2p\|a log(x\|b  + \|a )
+--R     + 
+--R            +-+         +-+2      +-+           +-+         +-+
+--R            |a 3+-+     |a        |a    2       |a 3+-+     |a
+--R       - p 3|- \|b log(3|-   - x 3|- + x  + 2p 3|- \|b log(3|-  + x)
+--R           \|b         \|b       \|b           \|b         \|b
+--R     + 
+--R                                                     3+-+   3+-+
+--R           3+-+          3     p       +-+3+-+     2x\|b  - \|a
+--R       - 2x\|b log(c (b x  + a) ) - 2p\|3 \|a atan(-------------)
+--R                                                       +-+3+-+
+--R                                                      \|3 \|a
+--R     + 
+--R                                  +-+
+--R                             +-+  |a
+--R               +-+          \|3  3|-
+--R          +-+  |a 3+-+           \|b                3                  3+-+
+--R       2p\|3  3|- \|b atan(--------- + (2p x log(b x  + a) + 2x log(c))\|b
+--R              \|b           +-+
+--R                            |a
+--R                           3|-  - 2x
+--R                           \|b
+--R  /
+--R      3+-+
+--R     2\|b
+--R                                                    Type: Expression(Integer)
+--E 1880
+
+--S 1881 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1881
+
+)clear all
+
+--S 1882 of 5341
+t0:=log(c*(a+b*x^3)^p)/x
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 1882
+
+--S 1883 of 5341
+--r0:=1/3*log(-b*x^3/a)*log(c*(a+b*x^3)^p)+1/3*p*polylog(2,(a+b*x^3)/a)
+--E 1883
+
+--S 1884 of 5341
+--a0:=integrate(t0,x)
+--E 1884
+
+--S 1885 of 5341
+--m0:=a0-r0
+--E 1885
+
+--S 1886 of 5341
+--d0:=D(m0,x)
+--E 1886
+
+)clear all
+
+--S 1887 of 5341
+t0:=log(c*(a+b*x^3)^p)/x^2
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1887
+
+--S 1888 of 5341
+r0:=-b^(1/3)*p*log(a^(1/3)+b^(1/3)*x)/a^(1/3)+1/2*b^(1/3)*p*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/a^(1/3)-log(c*(a+b*x^3)^p)/x-b^(1/3)*p*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/a^(1/3)
+--R 
+--R
+--R   (2)
+--R          3+-+     2 3+-+2   3+-+3+-+   3+-+2        3+-+     3+-+   3+-+
+--R       p x\|b log(x  \|b  - x\|a \|b  + \|a  ) - 2p x\|b log(x\|b  + \|a )
+--R     + 
+--R                                                      3+-+   3+-+
+--R          3+-+          3     p         +-+3+-+     2x\|b  - \|a
+--R       - 2\|a log(c (b x  + a) ) + 2p x\|3 \|b atan(-------------)
+--R                                                        +-+3+-+
+--R                                                       \|3 \|a
+--R  /
+--R       3+-+
+--R     2x\|a
+--R                                                    Type: Expression(Integer)
+--E 1888
+
+--S 1889 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             +---+       +---+2
+--R             |  b        |  b
+--R       2p x 3|- - log(a 3|- -   + b x)
+--R            \|  a       \|  a
+--R     + 
+--R              +---+           +---+2      +---+
+--R              |  b            |  b        |  b      2
+--R       - p x 3|- - log(- a x 3|- -   - a 3|- - + b x )
+--R             \|  a           \|  a       \|  a
+--R     + 
+--R                                      +---+2
+--R                                 +-+  |  b
+--R                   +---+       a\|3  3|- -
+--R              +-+  |  b              \|  a                3
+--R       - 2p x\|3  3|- - atan(---------------- - 2p log(b x  + a) - 2log(c)
+--R                  \|  a         +---+2
+--R                                |  b
+--R                             a 3|- -   - 2b x
+--R                               \|  a
+--R  /
+--R     2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1889
+
+--S 1890 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3+-+     2 3+-+2   3+-+3+-+   3+-+2        3+-+     3+-+   3+-+
+--R       - p x\|b log(x  \|b  - x\|a \|b  + \|a  ) + 2p x\|b log(x\|b  + \|a )
+--R     + 
+--R             +---+           +---+2
+--R             |  b 3+-+       |  b            3+-+          3     p
+--R       2p x 3|- - \|a log(a 3|- -   + b x + 2\|a log(c (b x  + a) )
+--R            \|  a           \|  a
+--R     + 
+--R              +---+               +---+2      +---+
+--R              |  b 3+-+           |  b        |  b      2
+--R       - p x 3|- - \|a log(- a x 3|- -   - a 3|- - + b x )
+--R             \|  a               \|  a       \|  a
+--R     + 
+--R                            3+-+   3+-+
+--R              +-+3+-+     2x\|b  - \|a
+--R       - 2p x\|3 \|b atan(-------------)
+--R                              +-+3+-+
+--R                             \|3 \|a
+--R     + 
+--R                                          +---+2
+--R                                     +-+  |  b
+--R                   +---+           a\|3  3|- -
+--R              +-+  |  b 3+-+             \|  a
+--R       - 2p x\|3  3|- - \|a atan(----------------)
+--R                  \|  a             +---+2
+--R                                    |  b
+--R                                 a 3|- -   - 2b x
+--R                                   \|  a
+--R     + 
+--R                    3                3+-+
+--R       (- 2p log(b x  + a) - 2log(c))\|a
+--R  /
+--R       3+-+
+--R     2x\|a
+--R                                                    Type: Expression(Integer)
+--E 1890
+
+--S 1891 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1891
+
+)clear all
+
+--S 1892 of 5341
+t0:=log(c*(a+b*x^3)^p)/x^3
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1892
+
+--S 1893 of 5341
+r0:=1/2*b^(2/3)*p*log(a^(1/3)+b^(1/3)*x)/a^(2/3)-1/4*b^(2/3)*p*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/a^(2/3)-1/2*log(c*(a+b*x^3)^p)/x^2-_
+   1/2*b^(2/3)*p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/a^(2/3)
+--R 
+--R
+--R   (2)
+--R            2 3+-+2     2 3+-+2   3+-+3+-+   3+-+2       2 3+-+2     3+-+   3+-+
+--R       - p x  \|b  log(x  \|b  - x\|a \|b  + \|a   + 2p x  \|b  log(x\|b  + \|a )
+--R     + 
+--R                                                         3+-+   3+-+
+--R          3+-+2          3     p        2 +-+3+-+2     2x\|b  - \|a
+--R       - 2\|a  log(c (b x  + a) ) + 2p x \|3 \|b  atan(-------------)
+--R                                                           +-+3+-+
+--R                                                          \|3 \|a
+--R  /
+--R       2 3+-+2
+--R     4x  \|a
+--R                                                    Type: Expression(Integer)
+--E 1893
+
+--S 1894 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +--+        +--+2         +--+
+--R               | 2         | 2           | 2
+--R            2  |b       2  |b            |b     2 2
+--R       - p x   |-- log(a   |--  - a b x  |-- + b x )
+--R              3| 2        3| 2          3| 2
+--R              \|a         \|a           \|a
+--R     + 
+--R                                                                  +--+
+--R                                                                  | 2
+--R                                                             +-+  |b
+--R              +--+       +--+                   +--+       a\|3   |--
+--R              | 2        | 2                    | 2              3| 2
+--R           2  |b         |b              2 +-+  |b               \|a
+--R       2p x   |-- log(a  |-- + b x + 2p x \|3   |-- atan(-------------)
+--R             3| 2       3| 2                   3| 2         +--+
+--R             \|a        \|a                    \|a          | 2
+--R                                                            |b
+--R                                                         a  |-- - 2b x
+--R                                                           3| 2
+--R                                                           \|a
+--R     + 
+--R                   3
+--R       - 2p log(b x  + a) - 2log(c)
+--R  /
+--R       2
+--R     4x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1894
+
+--S 1895 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +--+        +--+2         +--+
+--R                     | 2         | 2           | 2
+--R            2 3+-+2  |b       2  |b            |b     2 2
+--R       - p x  \|a    |-- log(a   |--  - a b x  |-- + b x )
+--R                    3| 2        3| 2          3| 2
+--R                    \|a         \|a           \|a
+--R     + 
+--R                    +--+       +--+
+--R                    | 2        | 2
+--R           2 3+-+2  |b         |b
+--R       2p x  \|a    |-- log(a  |-- + b x)
+--R                   3| 2       3| 2
+--R                   \|a        \|a
+--R     + 
+--R          2 3+-+2     2 3+-+2   3+-+3+-+   3+-+2       2 3+-+2     3+-+   3+-+
+--R       p x  \|b  log(x  \|b  - x\|a \|b  + \|a   - 2p x  \|b  log(x\|b  + \|a )
+--R     + 
+--R                                                       3+-+   3+-+
+--R        3+-+2          3     p        2 +-+3+-+2     2x\|b  - \|a
+--R       2\|a  log(c (b x  + a) ) - 2p x \|3 \|b  atan(-------------)
+--R                                                         +-+3+-+
+--R                                                        \|3 \|a
+--R     + 
+--R                                         +--+
+--R                                         | 2
+--R                                    +-+  |b
+--R                       +--+       a\|3   |--
+--R                       | 2              3| 2
+--R           2 +-+3+-+2  |b               \|a
+--R       2p x \|3 \|a    |-- atan(-------------)
+--R                      3| 2         +--+
+--R                      \|a          | 2
+--R                                   |b
+--R                                a  |-- - 2b x
+--R                                  3| 2
+--R                                  \|a
+--R     + 
+--R                    3                3+-+2
+--R       (- 2p log(b x  + a) - 2log(c))\|a
+--R  /
+--R       2 3+-+2
+--R     4x  \|a
+--R                                                    Type: Expression(Integer)
+--E 1895
+
+--S 1896 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1896
+
+)clear all
+
+--S 1897 of 5341
+t0:=log(c*(a+b*x^3)^p)/x^4
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 4
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1897
+
+--S 1898 of 5341
+r0:=b*p*log(x)/a-1/3*b*p*log(a+b*x^3)/a-1/3*log(c*(a+b*x^3)^p)/x^3
+--R 
+--R
+--R                      3     p         3       3              3
+--R        - a log(c (b x  + a) ) - b p x log(b x  + a) + 3b p x log(x)
+--R   (2)  ------------------------------------------------------------
+--R                                        3
+--R                                    3a x
+--R                                                    Type: Expression(Integer)
+--E 1898
+
+--S 1899 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                3              3              3
+--R        (- b p x  - a p)log(b x  + a) + 3b p x log(x) - a log(c)
+--R   (3)  --------------------------------------------------------
+--R                                      3
+--R                                  3a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1899
+
+--S 1900 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  3     p             3
+--R        log(c (b x  + a) ) - p log(b x  + a) - log(c)
+--R   (4)  ---------------------------------------------
+--R                               3
+--R                             3x
+--R                                                    Type: Expression(Integer)
+--E 1900
+
+--S 1901 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1901
+
+)clear all
+
+--S 1902 of 5341
+t0:=log(c*(a+b*x^3)^p)/x^5
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 5
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1902
+
+--S 1903 of 5341
+r0:=-3/4*b*p/(a*x)+1/4*b^(4/3)*p*log(a^(1/3)+b^(1/3)*x)/a^(4/3)-1/8*b^(4/3)*_
+   p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/a^(4/3)-1/4*log(c*(a+_
+   b*x^3)^p)/x^4+1/4*b^(4/3)*p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))*sqrt(3)/a^(4/3)
+--R 
+--R
+--R   (2)
+--R              4 3+-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       - b p x  \|b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             4 3+-+     3+-+   3+-+     3+-+          3     p
+--R       2b p x  \|b log(x\|b  + \|a  - 2a\|a log(c (b x  + a) )
+--R     + 
+--R                               3+-+   3+-+
+--R               4 +-+3+-+     2x\|b  - \|a           3 3+-+
+--R       - 2b p x \|3 \|b atan(-------------) - 6b p x  \|a
+--R                                 +-+3+-+
+--R                                \|3 \|a
+--R  /
+--R         4 3+-+
+--R     8a x  \|a
+--R                                                    Type: Expression(Integer)
+--E 1903
+
+--S 1904 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                +-+       +-+2                 +-+           +-+2      +-+
+--R             4  |b        |b                4  |b            |b        |b      2
+--R       2b p x  3|- log(a 3|-   + b x - b p x  3|- log(- a x 3|-   + a 3|- + b x )
+--R               \|a       \|a                  \|a           \|a       \|a
+--R     + 
+--R                                       +-+2
+--R                                  +-+  |b
+--R                      +-+       a\|3  3|-
+--R               4 +-+  |b              \|a                  3
+--R       - 2b p x \|3  3|- atan(-------------- - 2a p log(b x  + a) - 2a log(c)
+--R                     \|a         +-+2
+--R                                 |b
+--R                              a 3|-   - 2b x
+--R                                \|a
+--R     + 
+--R               3
+--R       - 6b p x
+--R  /
+--R         4
+--R     8a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1904
+
+--S 1905 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            4 3+-+     2 3+-+2   3+-+3+-+   3+-+2         4 3+-+     3+-+   3+-+
+--R       b p x  \|b log(x  \|b  - x\|a \|b  + \|a   - 2b p x  \|b log(x\|b  + \|a )
+--R     + 
+--R                     +-+       +-+2
+--R             4 3+-+  |b        |b            3+-+          3     p
+--R       2b p x  \|a  3|- log(a 3|-   + b  + 2a\|a log(c (b x  + a) )
+--R                    \|a       \|a
+--R     + 
+--R                      +-+           +-+2      +-+
+--R              4 3+-+  |b            |b        |b      2
+--R       - b p x  \|a  3|- log(- a x 3|-   + a 3|- + b x )
+--R                     \|a           \|a       \|a
+--R     + 
+--R                             3+-+   3+-+
+--R             4 +-+3+-+     2x\|b  - \|a
+--R       2b p x \|3 \|b atan(-------------)
+--R                               +-+3+-+
+--R                              \|3 \|a
+--R     + 
+--R                                           +-+2
+--R                                      +-+  |b
+--R                          +-+       a\|3  3|-
+--R               4 +-+3+-+  |b              \|a
+--R       - 2b p x \|3 \|a  3|- atan(--------------)
+--R                         \|a         +-+2
+--R                                     |b
+--R                                  a 3|-   - 2b x
+--R                                    \|a
+--R     + 
+--R                      3                  3+-+
+--R       (- 2a p log(b x  + a) - 2a log(c))\|a
+--R  /
+--R         4 3+-+
+--R     8a x  \|a
+--R                                                    Type: Expression(Integer)
+--E 1905
+
+--S 1906 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1906
+
+)clear all
+
+--S 1907 of 5341
+t0:=log(c*(a+b*x^3)^p)/x^6
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 6
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1907
+
+--S 1908 of 5341
+r0:=-3/10*b*p/(a*x^2)-1/5*b^(5/3)*p*log(a^(1/3)+b^(1/3)*x)/a^(5/3)+_
+   1/10*b^(5/3)*p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/a^(5/3)-_
+   1/5*log(c*(a+b*x^3)^p)/x^5+1/5*b^(5/3)*p*atan((a^(1/3)-2*b^(1/3)*x)/_
+   (a^(1/3)*sqrt(3)))*sqrt(3)/a^(5/3)
+--R 
+--R
+--R   (2)
+--R            5 3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       b p x  \|b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               5 3+-+2     3+-+   3+-+      3+-+2          3     p
+--R       - 2b p x  \|b  log(x\|b  + \|a  - 2a \|a  log(c (b x  + a) )
+--R     + 
+--R                                3+-+   3+-+
+--R               5 +-+3+-+2     2x\|b  - \|a           3 3+-+2
+--R       - 2b p x \|3 \|b  atan(-------------) - 3b p x  \|a
+--R                                  +-+3+-+
+--R                                 \|3 \|a
+--R  /
+--R          5 3+-+2
+--R     10a x  \|a
+--R                                                    Type: Expression(Integer)
+--E 1908
+
+--S 1909 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                 +----+        +----+2         +----+
+--R                 |   2         |   2           |   2
+--R              5  |  b       2  |  b            |  b     2 2
+--R       - b p x   |- -- log(a   |- --  + a b x  |- -- + b x )
+--R                3|   2        3|   2          3|   2
+--R                \|  a         \|  a           \|  a
+--R     + 
+--R                +----+         +----+
+--R                |   2          |   2
+--R             5  |  b           |  b
+--R       2b p x   |- -- log(- a  |- -- + b x)
+--R               3|   2         3|   2
+--R               \|  a          \|  a
+--R     + 
+--R                                        +----+
+--R                                        |   2
+--R                                   +-+  |  b
+--R                    +----+       a\|3   |- --
+--R                    |   2              3|   2
+--R             5 +-+  |  b               \|  a                 3
+--R       2b p x \|3   |- -- atan(--------------- - 2a p log(b x  + a) - 2a log(c)
+--R                   3|   2         +----+
+--R                   \|  a          |   2
+--R                                  |  b
+--R                               a  |- -- + 2b x
+--R                                 3|   2
+--R                                 \|  a
+--R     + 
+--R               3
+--R       - 3b p x
+--R  /
+--R          5
+--R     10a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1909
+
+--S 1910 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              5 3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       - b p x  \|b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             5 3+-+2     3+-+   3+-+
+--R       2b p x  \|b  log(x\|b  + \|a )
+--R     + 
+--R                 +----+             +----+2         +----+
+--R                 |   2              |   2           |   2
+--R              5  |  b  3+-+2     2  |  b            |  b     2 2
+--R       - b p x   |- -- \|a  log(a   |- --  + a b x  |- -- + b x )
+--R                3|   2             3|   2          3|   2
+--R                \|  a              \|  a           \|  a
+--R     + 
+--R                                             +----+              +----+
+--R                                             |   2               |   2
+--R          3+-+2          3     p          5  |  b  3+-+2         |  b
+--R       2a \|a  log(c (b x  + a) ) + 2b p x   |- -- \|a  log(- a  |- -- + b x)
+--R                                            3|   2              3|   2
+--R                                            \|  a               \|  a
+--R     + 
+--R                              3+-+   3+-+
+--R             5 +-+3+-+2     2x\|b  - \|a
+--R       2b p x \|3 \|b  atan(-------------)
+--R                                +-+3+-+
+--R                               \|3 \|a
+--R     + 
+--R                                             +----+
+--R                                             |   2
+--R                                        +-+  |  b
+--R                    +----+            a\|3   |- --
+--R                    |   2                   3|   2
+--R             5 +-+  |  b  3+-+2             \|  a
+--R       2b p x \|3   |- -- \|a  atan(---------------)
+--R                   3|   2              +----+
+--R                   \|  a               |   2
+--R                                       |  b
+--R                                    a  |- -- + 2b x
+--R                                      3|   2
+--R                                      \|  a
+--R     + 
+--R                      3                  3+-+2
+--R       (- 2a p log(b x  + a) - 2a log(c))\|a
+--R  /
+--R          5 3+-+2
+--R     10a x  \|a
+--R                                                    Type: Expression(Integer)
+--E 1910
+
+--S 1911 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1911
+
+)clear all
+
+--S 1912 of 5341
+t0:=log(c*(a+b*x^3)^p)/x^7
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 7
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1912
+
+--S 1913 of 5341
+r0:=-1/6*b*p/(a*x^3)-1/2*b^2*p*log(x)/a^2+1/6*b^2*p*log(a+b*x^3)/a^2-_
+   1/6*log(c*(a+b*x^3)^p)/x^6
+--R 
+--R
+--R   (2)
+--R      2          3     p     2   6       3          2   6                3
+--R   - a log(c (b x  + a) ) + b p x log(b x  + a) - 3b p x log(x) - a b p x
+--R   -----------------------------------------------------------------------
+--R                                      2 6
+--R                                    6a x
+--R                                                    Type: Expression(Integer)
+--E 1913
+
+--S 1914 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2   6    2         3          2   6          2                3
+--R        (b p x  - a p)log(b x  + a) - 3b p x log(x) - a log(c) - a b p x
+--R   (3)  -----------------------------------------------------------------
+--R                                        2 6
+--R                                      6a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1914
+
+--S 1915 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  3     p             3
+--R        log(c (b x  + a) ) - p log(b x  + a) - log(c)
+--R   (4)  ---------------------------------------------
+--R                               6
+--R                             6x
+--R                                                    Type: Expression(Integer)
+--E 1915
+
+--S 1916 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1916
+
+)clear all
+
+--S 1917 of 5341
+t0:=x^m*log(c*(a+b*sqrt(x))^p)
+--R 
+--R
+--R         m         +-+     p
+--R   (1)  x log(c (b\|x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1917
+
+--S 1918 of 5341
+--r0:=-1/2*p*x^(1+m)/(1+m)^2+1/2*p*x^(1+m)*hypergeometric(1,2*(1+m),3+2*m,_
+--  -b*sqrt(x)/a)/(1+m)^2+x^(1+m)*log(c*(a+b*sqrt(x))^p)/(1+m)
+--E 1918
+
+--S 1919 of 5341
+--a0:=integrate(t0,x)
+--E 1919
+
+--S 1920 of 5341
+--m0:=a0-r0
+--E 1920
+
+--S 1921 of 5341
+--d0:=D(m0,x)
+--E 1921
+
+)clear all
+
+--S 1922 of 5341
+t0:=x^3*log(c*(a+b*sqrt(x))^p)
+--R 
+--R
+--R         3         +-+     p
+--R   (1)  x log(c (b\|x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1922
+
+--S 1923 of 5341
+r0:=-1/8*a^6*p*x/b^6+1/12*a^5*p*x^(3/2)/b^5-1/16*a^4*p*x^2/b^4+1/20*a^3*_
+   p*x^(5/2)/b^3-1/24*a^2*p*x^3/b^2+1/28*a*p*x^(7/2)/b-1/32*p*x^4-1/4*a^8*_
+   p*log(a+b*sqrt(x))/b^8+1/4*x^4*log(c*(a+b*sqrt(x))^p)+1/4*a^7*p*sqrt(x)/b^7
+--R 
+--R
+--R   (2)
+--R           8 4         +-+     p        8        +-+
+--R       840b x log(c (b\|x  + a) ) - 840a p log(b\|x  + a)
+--R     + 
+--R              7   3       3 5   2       5 3          7     +-+       8   4
+--R       (120a b p x  + 168a b p x  + 280a b p x + 840a b p)\|x  - 105b p x
+--R     + 
+--R             2 6   3       4 4   2       6 2
+--R       - 140a b p x  - 210a b p x  - 420a b p x
+--R  /
+--R          8
+--R     3360b
+--R                                                    Type: Expression(Integer)
+--E 1923
+
+--S 1924 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            8   4       8        +-+
+--R       (840b p x  - 840a p)log(b\|x  + a)
+--R     + 
+--R              7   3       3 5   2       5 3          7     +-+       8 4
+--R       (120a b p x  + 168a b p x  + 280a b p x + 840a b p)\|x  + 840b x log(c)
+--R     + 
+--R             8   4       2 6   3       4 4   2       6 2
+--R       - 105b p x  - 140a b p x  - 210a b p x  - 420a b p x
+--R  /
+--R          8
+--R     3360b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1924
+
+--S 1925 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           4         +-+     p       4      +-+         4
+--R        - x log(c (b\|x  + a) ) + p x log(b\|x  + a) + x log(c)
+--R   (4)  -------------------------------------------------------
+--R                                   4
+--R                                                    Type: Expression(Integer)
+--E 1925
+
+--S 1926 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1926
+
+)clear all
+
+--S 1927 of 5341
+t0:=x^2*log(c*(a+b*sqrt(x))^p)
+--R 
+--R
+--R         2         +-+     p
+--R   (1)  x log(c (b\|x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1927
+
+--S 1928 of 5341
+r0:=-1/6*a^4*p*x/b^4+1/9*a^3*p*x^(3/2)/b^3-1/12*a^2*p*x^2/b^2+1/15*a*_
+   p*x^(5/2)/b-1/18*p*x^3-1/3*a^6*p*log(a+b*sqrt(x))/b^6+1/3*x^3*log(c*_
+   (a+b*sqrt(x))^p)+1/3*a^5*p*sqrt(x)/b^5
+--R 
+--R
+--R   (2)
+--R          6 3         +-+     p       6        +-+
+--R       60b x log(c (b\|x  + a) ) - 60a p log(b\|x  + a)
+--R     + 
+--R           5   2      3 3         5     +-+      6   3      2 4   2      4 2
+--R     (12a b p x  + 20a b p x + 60a b p)\|x  - 10b p x  - 15a b p x  - 30a b p x
+--R  /
+--R         6
+--R     180b
+--R                                                    Type: Expression(Integer)
+--E 1928
+
+--S 1929 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           6   3      6        +-+              5   2      3 3         5     +-+
+--R       (60b p x  - 60a p)log(b\|x  + a) + (12a b p x  + 20a b p x + 60a b p)\|x
+--R     + 
+--R          6 3            6   3      2 4   2      4 2
+--R       60b x log(c) - 10b p x  - 15a b p x  - 30a b p x
+--R  /
+--R         6
+--R     180b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1929
+
+--S 1930 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           3         +-+     p       3      +-+         3
+--R        - x log(c (b\|x  + a) ) + p x log(b\|x  + a) + x log(c)
+--R   (4)  -------------------------------------------------------
+--R                                   3
+--R                                                    Type: Expression(Integer)
+--E 1930
+
+--S 1931 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1931
+
+)clear all
+
+--S 1932 of 5341
+t0:=x*log(c*(a+b*sqrt(x))^p)
+--R 
+--R
+--R                   +-+     p
+--R   (1)  x log(c (b\|x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1932
+
+--S 1933 of 5341
+r0:=-1/4*a^2*p*x/b^2+1/6*a*p*x^(3/2)/b-1/8*p*x^2-1/2*a^4*p*log(a+_
+   b*sqrt(x))/b^4+1/2*x^2*log(c*(a+b*sqrt(x))^p)+1/2*a^3*p*sqrt(x)/b^3
+--R 
+--R
+--R   (2)
+--R          4 2         +-+     p       4        +-+
+--R       12b x log(c (b\|x  + a) ) - 12a p log(b\|x  + a)
+--R     + 
+--R            3         3     +-+     4   2     2 2
+--R       (4a b p x + 12a b p)\|x  - 3b p x  - 6a b p x
+--R  /
+--R        4
+--R     24b
+--R                                                    Type: Expression(Integer)
+--E 1933
+
+--S 1934 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4   2      4        +-+             3         3     +-+
+--R       (12b p x  - 12a p)log(b\|x  + a) + (4a b p x + 12a b p)\|x
+--R     + 
+--R          4 2           4   2     2 2
+--R       12b x log(c) - 3b p x  - 6a b p x
+--R  /
+--R        4
+--R     24b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1934
+
+--S 1935 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           2         +-+     p       2      +-+         2
+--R        - x log(c (b\|x  + a) ) + p x log(b\|x  + a) + x log(c)
+--R   (4)  -------------------------------------------------------
+--R                                   2
+--R                                                    Type: Expression(Integer)
+--E 1935
+
+--S 1936 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1936
+
+)clear all
+
+--S 1937 of 5341
+t0:=log(c*(a+b*sqrt(x))^p)
+--R 
+--R
+--R                 +-+     p
+--R   (1)  log(c (b\|x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 1937
+
+--S 1938 of 5341
+r0:=-1/2*p*x-a^2*p*log(a+b*sqrt(x))/b^2+x*log(c*(a+b*sqrt(x))^p)+a*p*sqrt(x)/b
+--R 
+--R
+--R          2           +-+     p      2        +-+               +-+    2
+--R        2b x log(c (b\|x  + a) ) - 2a p log(b\|x  + a) + 2a b p\|x  - b p x
+--R   (2)  -------------------------------------------------------------------
+--R                                          2
+--R                                        2b
+--R                                                    Type: Expression(Integer)
+--E 1938
+
+--S 1939 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2        2        +-+               +-+     2            2
+--R        (2b p x - 2a p)log(b\|x  + a) + 2a b p\|x  + 2b x log(c) - b p x
+--R   (3)  ----------------------------------------------------------------
+--R                                         2
+--R                                       2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1939
+
+--S 1940 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                     +-+     p              +-+
+--R   (4)  - x log(c (b\|x  + a) ) + p x log(b\|x  + a) + x log(c)
+--R                                                    Type: Expression(Integer)
+--E 1940
+
+--S 1941 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1941
+
+)clear all
+
+--S 1942 of 5341
+t0:=log(c*(a+b*sqrt(x))^p)/x
+--R 
+--R
+--R                 +-+     p
+--R        log(c (b\|x  + a) )
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 1942
+
+--S 1943 of 5341
+--r0:=2*log(-b*sqrt(x)/a)*log(c*(a+b*sqrt(x))^p)+_
+--  2*p*polylog(2,(a+b*sqrt(x))/a)
+--E 1943
+
+--S 1944 of 5341
+--a0:=integrate(t0,x)
+--E 1944
+
+--S 1945 of 5341
+--m0:=a0-r0
+--E 1945
+
+--S 1946 of 5341
+--d0:=D(m0,x)
+--E 1946
+
+)clear all
+
+--S 1947 of 5341
+t0:=log(c*(a+b*sqrt(x))^p)/x^2
+--R 
+--R
+--R                 +-+     p
+--R        log(c (b\|x  + a) )
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 1947
+
+--S 1948 of 5341
+r0:=-1/2*b^2*p*log(x)/a^2+b^2*p*log(a+b*sqrt(x))/a^2-log(c*(a+_
+   b*sqrt(x))^p)/x-b*p/(a*sqrt(x))
+--R 
+--R
+--R   (2)
+--R           2 +-+         +-+     p      2    +-+      +-+
+--R       - 2a \|x log(c (b\|x  + a) ) + 2b p x\|x log(b\|x  + a)
+--R     + 
+--R          2           +-+
+--R       - b p x log(x)\|x  - 2a b p x
+--R  /
+--R       2  +-+
+--R     2a x\|x
+--R                                                    Type: Expression(Integer)
+--E 1948
+
+--S 1949 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2       2        +-+         2         +-+          +-+    2
+--R        (b p x - a p)log(b\|x  + a) - b p x log(\|x ) - a b p\|x  - a log(c)
+--R   (3)  --------------------------------------------------------------------
+--R                                          2
+--R                                         a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1949
+
+--S 1950 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         2         +-+     p      2        +-+          2         +-+
+--R       2a log(c (b\|x  + a) ) - 2a p log(b\|x  + a) - 2b p x log(\|x )
+--R     + 
+--R        2               2
+--R       b p x log(x) - 2a log(c)
+--R  /
+--R       2
+--R     2a x
+--R                                                    Type: Expression(Integer)
+--E 1950
+
+--S 1951 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1951
+
+)clear all
+
+--S 1952 of 5341
+t0:=log(c*(a+b*sqrt(x))^p)/x^3
+--R 
+--R
+--R                 +-+     p
+--R        log(c (b\|x  + a) )
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 1952
+
+--S 1953 of 5341
+r0:=-1/6*b*p/(a*x^(3/2))+1/4*b^2*p/(a^2*x)-1/4*b^4*p*log(x)/a^4+1/2*b^4*p*_
+   log(a+b*sqrt(x))/a^4-1/2*log(c*(a+b*sqrt(x))^p)/x^2-1/2*b^3*p/(a^3*sqrt(x))
+--R 
+--R
+--R   (2)
+--R           4 +-+         +-+     p      4   2 +-+      +-+
+--R       - 6a \|x log(c (b\|x  + a) ) + 6b p x \|x log(b\|x  + a)
+--R     + 
+--R            4   2           2 2     +-+       3   2     3
+--R       (- 3b p x log(x) + 3a b p x)\|x  - 6a b p x  - 2a b p x
+--R  /
+--R        4 2 +-+
+--R     12a x \|x
+--R                                                    Type: Expression(Integer)
+--E 1953
+
+--S 1954 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          4   2     4        +-+          4   2     +-+
+--R       (6b p x  - 6a p)log(b\|x  + a) - 6b p x log(\|x )
+--R     + 
+--R              3        3     +-+     4           2 2
+--R       (- 6a b p x - 2a b p)\|x  - 6a log(c) + 3a b p x
+--R  /
+--R        4 2
+--R     12a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1954
+
+--S 1955 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         4         +-+     p      4        +-+          4   2     +-+
+--R       2a log(c (b\|x  + a) ) - 2a p log(b\|x  + a) - 2b p x log(\|x )
+--R     + 
+--R        4   2           4
+--R       b p x log(x) - 2a log(c)
+--R  /
+--R       4 2
+--R     4a x
+--R                                                    Type: Expression(Integer)
+--E 1955
+
+--S 1956 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1956
+
+)clear all
+
+--S 1957 of 5341
+t0:=log(c*(a+b*sqrt(x))^p)/x^4
+--R 
+--R
+--R                 +-+     p
+--R        log(c (b\|x  + a) )
+--R   (1)  -------------------
+--R                  4
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 1957
+
+--S 1958 of 5341
+r0:=-1/15*b*p/(a*x^(5/2))+1/12*b^2*p/(a^2*x^2)-1/9*b^3*p/(a^3*x^(3/2))+_
+   1/6*b^4*p/(a^4*x)-1/6*b^6*p*log(x)/a^6+1/3*b^6*p*log(a+b*sqrt(x))/a^6-_
+   1/3*log(c*(a+b*sqrt(x))^p)/x^3-1/3*b^5*p/(a^5*sqrt(x))
+--R 
+--R
+--R   (2)
+--R            6 +-+         +-+     p       6   3 +-+      +-+
+--R       - 60a \|x log(c (b\|x  + a) ) + 60b p x \|x log(b\|x  + a)
+--R     + 
+--R             6   3            2 4   2      4 2     +-+        5   3      3 3   2
+--R       (- 30b p x log(x) + 30a b p x  + 15a b p x)\|x  - 60a b p x  - 20a b p x
+--R     + 
+--R            5
+--R       - 12a b p x
+--R  /
+--R         6 3 +-+
+--R     180a x \|x
+--R                                                    Type: Expression(Integer)
+--E 1958
+
+--S 1959 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           6   3      6        +-+           6   3     +-+
+--R       (60b p x  - 60a p)log(b\|x  + a) - 60b p x log(\|x )
+--R     + 
+--R               5   2      3 3         5     +-+      6            2 4   2
+--R       (- 60a b p x  - 20a b p x - 12a b p)\|x  - 60a log(c) + 30a b p x
+--R     + 
+--R          4 2
+--R       15a b p x
+--R  /
+--R         6 3
+--R     180a x
+--R                                         Type: Union(Expression(Integer),...)
+--E 1959
+
+--S 1960 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         6         +-+     p      6        +-+          6   3     +-+
+--R       2a log(c (b\|x  + a) ) - 2a p log(b\|x  + a) - 2b p x log(\|x )
+--R     + 
+--R        6   3           6
+--R       b p x log(x) - 2a log(c)
+--R  /
+--R       6 3
+--R     6a x
+--R                                                    Type: Expression(Integer)
+--E 1960
+
+--S 1961 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1961
+
+)clear all
+
+--S 1962 of 5341
+t0:=log(a+b*sqrt(x))/sqrt(x)
+--R 
+--R
+--R              +-+
+--R        log(b\|x  + a)
+--R   (1)  --------------
+--R              +-+
+--R             \|x
+--R                                                    Type: Expression(Integer)
+--E 1962
+
+--S 1963 of 5341
+r0:=-2*sqrt(x)+2*log(a+b*sqrt(x))*(a+b*sqrt(x))/b
+--R 
+--R
+--R            +-+            +-+           +-+
+--R        (2b\|x  + 2a)log(b\|x  + a) - 2b\|x
+--R   (2)  ------------------------------------
+--R                          b
+--R                                                    Type: Expression(Integer)
+--E 1963
+
+--S 1964 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R            +-+            +-+           +-+
+--R        (2b\|x  + 2a)log(b\|x  + a) - 2b\|x
+--R   (3)  ------------------------------------
+--R                          b
+--R                                         Type: Union(Expression(Integer),...)
+--E 1964
+
+--S 1965 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1965
+
+--S 1966 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1966
+
+)clear all
+
+--S 1967 of 5341
+t0:=x^m*log(c*(a+b/x)^p)
+--R 
+--R
+--R         m       a x + b p
+--R   (1)  x log(c (-------) )
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 1967
+
+--S 1968 of 5341
+--r0:=p*x^(1+m)*hypergeometric(1,1+m,2+m,-a*x/b)/(1+m)^2+_
+--  x^(1+m)*log(c*(a+b/x)^p)/(1+m)
+--E 1968
+
+--S 1969 of 5341
+--a0:=integrate(t0,x)
+--E 1969
+
+--S 1970 of 5341
+--m0:=a0-r0
+--E 1970
+
+--S 1971 of 5341
+--d0:=D(m0,x)
+--E 1971
+
+)clear all
+
+--S 1972 of 5341
+t0:=x^4*log(c*(a+b/x)^p)
+--R 
+--R
+--R         4       a x + b p
+--R   (1)  x log(c (-------) )
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 1972
+
+--S 1973 of 5341
+r0:=-1/5*b^4*p*x/a^4+1/10*b^3*p*x^2/a^3-1/15*b^2*p*x^3/a^2+1/20*b*p*x^4/a+_
+   1/5*x^5*log(c*(a+b/x)^p)+1/5*b^5*p*log(b+a*x)/a^5
+--R 
+--R
+--R   (2)
+--R          5 5       a x + b p       5                   4     4     3 2   3
+--R       12a x log(c (-------) ) + 12b p log(a x + b) + 3a b p x  - 4a b p x
+--R                       x
+--R     + 
+--R         2 3   2        4
+--R       6a b p x  - 12a b p x
+--R  /
+--R        5
+--R     60a
+--R                                                    Type: Expression(Integer)
+--E 1973
+
+--S 1974 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          5                    5 5            5   5    a x + b      4     4
+--R       12b p log(a x + b) + 12a x log(c) + 12a p x log(-------) + 3a b p x
+--R                                                          x
+--R     + 
+--R           3 2   3     2 3   2        4
+--R       - 4a b p x  + 6a b p x  - 12a b p x
+--R  /
+--R        5
+--R     60a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1974
+
+--S 1975 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           5       a x + b p     5            5    a x + b
+--R        - x log(c (-------) ) + x log(c) + p x log(-------)
+--R                      x                               x
+--R   (4)  ---------------------------------------------------
+--R                                 5
+--R                                                    Type: Expression(Integer)
+--E 1975
+
+--S 1976 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1976
+
+)clear all
+
+--S 1977 of 5341
+t0:=x^3*log(c*(a+b/x)^p)
+--R 
+--R
+--R         3       a x + b p
+--R   (1)  x log(c (-------) )
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 1977
+
+--S 1978 of 5341
+r0:=1/4*b^3*p*x/a^3-1/8*b^2*p*x^2/a^2+1/12*b*p*x^3/a+1/4*x^4*log(c*(a+b/x)^p)-_
+   1/4*b^4*p*log(b+a*x)/a^4
+--R 
+--R
+--R   (2)
+--R     4 4       a x + b p      4                   3     3     2 2   2       3
+--R   6a x log(c (-------) ) - 6b p log(a x + b) + 2a b p x  - 3a b p x  + 6a b p x
+--R                  x
+--R   -----------------------------------------------------------------------------
+--R                                           4
+--R                                        24a
+--R                                                    Type: Expression(Integer)
+--E 1978
+
+--S 1979 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4                   4 4           4   4    a x + b      3     3
+--R       - 6b p log(a x + b) + 6a x log(c) + 6a p x log(-------) + 2a b p x
+--R                                                         x
+--R     + 
+--R           2 2   2       3
+--R       - 3a b p x  + 6a b p x
+--R  /
+--R        4
+--R     24a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1979
+
+--S 1980 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           4       a x + b p     4            4    a x + b
+--R        - x log(c (-------) ) + x log(c) + p x log(-------)
+--R                      x                               x
+--R   (4)  ---------------------------------------------------
+--R                                 4
+--R                                                    Type: Expression(Integer)
+--E 1980
+
+--S 1981 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1981
+
+)clear all
+
+--S 1982 of 5341
+t0:=x^2*log(c*(a+b/x)^p)
+--R 
+--R
+--R         2       a x + b p
+--R   (1)  x log(c (-------) )
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 1982
+
+--S 1983 of 5341
+r0:=-1/3*b^2*p*x/a^2+1/6*b*p*x^2/a+1/3*x^3*log(c*(a+b/x)^p)+1/3*b^3*p*_
+   log(b+a*x)/a^3
+--R 
+--R
+--R          3 3       a x + b p      3                  2     2       2
+--R        2a x log(c (-------) ) + 2b p log(a x + b) + a b p x  - 2a b p x
+--R                       x
+--R   (2)  ----------------------------------------------------------------
+--R                                         3
+--R                                       6a
+--R                                                    Type: Expression(Integer)
+--E 1983
+
+--S 1984 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R     3                   3 3           3   3    a x + b     2     2       2
+--R   2b p log(a x + b) + 2a x log(c) + 2a p x log(-------) + a b p x  - 2a b p x
+--R                                                   x
+--R   ---------------------------------------------------------------------------
+--R                                         3
+--R                                       6a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1984
+
+--S 1985 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           3       a x + b p     3            3    a x + b
+--R        - x log(c (-------) ) + x log(c) + p x log(-------)
+--R                      x                               x
+--R   (4)  ---------------------------------------------------
+--R                                 3
+--R                                                    Type: Expression(Integer)
+--E 1985
+
+--S 1986 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1986
+
+)clear all
+
+--S 1987 of 5341
+t0:=x*log(c*(a+b/x)^p)
+--R 
+--R
+--R                 a x + b p
+--R   (1)  x log(c (-------) )
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 1987
+
+--S 1988 of 5341
+r0:=1/2*b*p*x/a+1/2*x^2*log(c*(a+b/x)^p)-1/2*b^2*p*log(b+a*x)/a^2
+--R 
+--R
+--R         2 2       a x + b p     2
+--R        a x log(c (-------) ) - b p log(a x + b) + a b p x
+--R                      x
+--R   (2)  --------------------------------------------------
+--R                                  2
+--R                                2a
+--R                                                    Type: Expression(Integer)
+--E 1988
+
+--S 1989 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2                  2 2          2   2    a x + b
+--R        - b p log(a x + b) + a x log(c) + a p x log(-------) + a b p x
+--R                                                       x
+--R   (3)  --------------------------------------------------------------
+--R                                        2
+--R                                      2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1989
+
+--S 1990 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           2       a x + b p     2            2    a x + b
+--R        - x log(c (-------) ) + x log(c) + p x log(-------)
+--R                      x                               x
+--R   (4)  ---------------------------------------------------
+--R                                 2
+--R                                                    Type: Expression(Integer)
+--E 1990
+
+--S 1991 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1991
+
+)clear all
+
+--S 1992 of 5341
+t0:=log(c*(a+b/x)^p)
+--R 
+--R
+--R               a x + b p
+--R   (1)  log(c (-------) )
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 1992
+
+--S 1993 of 5341
+r0:=x*log(c*(a+b/x)^p)+b*p*log(b+a*x)/a
+--R 
+--R
+--R                   a x + b p
+--R        a x log(c (-------) ) + b p log(a x + b)
+--R                      x
+--R   (2)  ----------------------------------------
+--R                            a
+--R                                                    Type: Expression(Integer)
+--E 1993
+
+--S 1994 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                  a x + b
+--R        b p log(a x + b) + a x log(c) + a p x log(-------)
+--R                                                     x
+--R   (3)  --------------------------------------------------
+--R                                 a
+--R                                         Type: Union(Expression(Integer),...)
+--E 1994
+
+--S 1995 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                   a x + b p                       a x + b
+--R   (4)  - x log(c (-------) ) + x log(c) + p x log(-------)
+--R                      x                               x
+--R                                                    Type: Expression(Integer)
+--E 1995
+
+--S 1996 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1996
+
+)clear all
+
+--S 1997 of 5341
+t0:=log(c*(a+b/x)^p)/x
+--R 
+--R
+--R               a x + b p
+--R        log(c (-------) )
+--R                  x
+--R   (1)  -----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 1997
+
+--S 1998 of 5341
+--r0:=-log(c*(a+b/x)^p)*log(-b/(a*x))-p*polylog(2,(a+b/x)/a)
+--E 1998
+
+--S 1999 of 5341
+--a0:=integrate(t0,x)
+--E 1999
+
+--S 2000 of 5341
+--m0:=a0-r0
+--E 2000
+
+--S 2001 of 5341
+--d0:=D(m0,x)
+--E 2001
+
+)clear all
+
+--S 2002 of 5341
+t0:=log(c*(a+b/x)^p)/x^2
+--R 
+--R
+--R               a x + b p
+--R        log(c (-------) )
+--R                  x
+--R   (1)  -----------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2002
+
+--S 2003 of 5341
+r0:=p/x-(a+b/x)*log(c*(a+b/x)^p)/b
+--R 
+--R
+--R                          a x + b p
+--R        (- a x - b)log(c (-------) ) + b p
+--R                             x
+--R   (2)  ----------------------------------
+--R                        b x
+--R                                                    Type: Expression(Integer)
+--E 2003
+
+--S 2004 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                        a x + b
+--R        - b log(c) + (- a p x - b p)log(-------) + b p
+--R                                           x
+--R   (3)  ----------------------------------------------
+--R                              b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2004
+
+--S 2005 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                        a x + b p                                  a x + b
+--R        (a x + b)log(c (-------) ) - b log(c) + (- a p x - b p)log(-------)
+--R                           x                                          x
+--R   (4)  -------------------------------------------------------------------
+--R                                        b x
+--R                                                    Type: Expression(Integer)
+--E 2005
+
+--S 2006 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2006
+
+)clear all
+
+--S 2007 of 5341
+t0:=log(c*(a+b/x)^p)/x^3
+--R 
+--R
+--R               a x + b p
+--R        log(c (-------) )
+--R                  x
+--R   (1)  -----------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2007
+
+--S 2008 of 5341
+r0:=1/4*p/x^2-1/2*a*p/(b*x)-1/2*log(c*(a+b/x)^p)/x^2-1/2*a^2*p*log(x)/b^2+_
+   1/2*a^2*p*log(b+a*x)/b^2
+--R 
+--R
+--R   (2)
+--R       2       a x + b p      2   2                 2   2                     2
+--R   - 2b log(c (-------) ) + 2a p x log(a x + b) - 2a p x log(x) - 2a b p x + b p
+--R                  x
+--R   -----------------------------------------------------------------------------
+--R                                         2 2
+--R                                       4b x
+--R                                                    Type: Expression(Integer)
+--E 2008
+
+--S 2009 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2            2   2     2      a x + b                2
+--R        - 2b log(c) + (2a p x  - 2b p)log(-------) - 2a b p x + b p
+--R                                             x
+--R   (3)  -----------------------------------------------------------
+--R                                     2 2
+--R                                   4b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2009
+
+--S 2010 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        2       a x + b p     2   2                2   2          2
+--R       b log(c (-------) ) - a p x log(a x + b) + a p x log(x) - b log(c)
+--R                   x
+--R     + 
+--R         2   2    2      a x + b
+--R       (a p x  - b p)log(-------)
+--R                            x
+--R  /
+--R       2 2
+--R     2b x
+--R                                                    Type: Expression(Integer)
+--E 2010
+
+--S 2011 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2011
+
+)clear all
+
+--S 2012 of 5341
+t0:=log(c*(a+b/x)^p)/x^4
+--R 
+--R
+--R               a x + b p
+--R        log(c (-------) )
+--R                  x
+--R   (1)  -----------------
+--R                 4
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2012
+
+--S 2013 of 5341
+r0:=1/9*p/x^3-1/6*a*p/(b*x^2)+1/3*a^2*p/(b^2*x)-1/3*log(c*(a+b/x)^p)/x^3+_
+   1/3*a^3*p*log(x)/b^3-1/3*a^3*p*log(b+a*x)/b^3
+--R 
+--R
+--R   (2)
+--R           3       a x + b p      3   3                 3   3           2     2
+--R       - 6b log(c (-------) ) - 6a p x log(a x + b) + 6a p x log(x) + 6a b p x
+--R                      x
+--R     + 
+--R             2        3
+--R       - 3a b p x + 2b p
+--R  /
+--R        3 3
+--R     18b x
+--R                                                    Type: Expression(Integer)
+--E 2013
+
+--S 2014 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       3              3   3     3      a x + b      2     2       2        3
+--R   - 6b log(c) + (- 6a p x  - 6b p)log(-------) + 6a b p x  - 3a b p x + 2b p
+--R                                          x
+--R   --------------------------------------------------------------------------
+--R                                        3 3
+--R                                     18b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2014
+
+--S 2015 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        3       a x + b p     3   3                3   3          3
+--R       b log(c (-------) ) + a p x log(a x + b) - a p x log(x) - b log(c)
+--R                   x
+--R     + 
+--R           3   3    3      a x + b
+--R       (- a p x  - b p)log(-------)
+--R                              x
+--R  /
+--R       3 3
+--R     3b x
+--R                                                    Type: Expression(Integer)
+--E 2015
+
+--S 2016 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2016
+
+)clear all
+
+--S 2017 of 5341
+t0:=log(c*(a+b/x)^p)/x^5
+--R 
+--R
+--R               a x + b p
+--R        log(c (-------) )
+--R                  x
+--R   (1)  -----------------
+--R                 5
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2017
+
+--S 2018 of 5341
+r0:=1/16*p/x^4-1/12*a*p/(b*x^3)+1/8*a^2*p/(b^2*x^2)-1/4*a^3*p/(b^3*x)-_
+   1/4*log(c*(a+b/x)^p)/x^4-1/4*a^4*p*log(x)/b^4+1/4*a^4*p*log(b+a*x)/b^4
+--R 
+--R
+--R   (2)
+--R            4       a x + b p       4   4                  4   4
+--R       - 12b log(c (-------) ) + 12a p x log(a x + b) - 12a p x log(x)
+--R                       x
+--R     + 
+--R            3     3     2 2   2       3        4
+--R       - 12a b p x  + 6a b p x  - 4a b p x + 3b p
+--R  /
+--R        4 4
+--R     48b x
+--R                                                    Type: Expression(Integer)
+--E 2018
+
+--S 2019 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4             4   4      4      a x + b       3     3     2 2   2
+--R       - 12b log(c) + (12a p x  - 12b p)log(-------) - 12a b p x  + 6a b p x
+--R                                               x
+--R     + 
+--R             3        4
+--R       - 4a b p x + 3b p
+--R  /
+--R        4 4
+--R     48b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2019
+
+--S 2020 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        4       a x + b p     4   4                4   4          4
+--R       b log(c (-------) ) - a p x log(a x + b) + a p x log(x) - b log(c)
+--R                   x
+--R     + 
+--R         4   4    4      a x + b
+--R       (a p x  - b p)log(-------)
+--R                            x
+--R  /
+--R       4 4
+--R     4b x
+--R                                                    Type: Expression(Integer)
+--E 2020
+
+--S 2021 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2021
+
+)clear all
+
+--S 2022 of 5341
+t0:=log(1+b/x)/x
+--R 
+--R
+--R            x + b
+--R        log(-----)
+--R              x
+--R   (1)  ----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 2022
+
+--S 2023 of 5341
+--r0:=polylog(2,-b/x)
+--E 2023
+
+--S 2024 of 5341
+--a0:=integrate(t0,x)
+--E 2024
+
+--S 2025 of 5341
+--m0:=a0-r0
+--E 2025
+
+--S 2026 of 5341
+--d0:=D(m0,x)
+--E 2026
+
+)clear all
+
+--S 2027 of 5341
+t0:=x^m*log(c*(a+b/x^2)^p)
+--R 
+--R
+--R                    2     p
+--R         m       a x  + b
+--R   (1)  x log(c (--------) )
+--R                     2
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 2027
+
+--S 2028 of 5341
+--r0:=2*p*x^(1+m)*hypergeometric(1,1/2*(1+m),1/2*(3+m),-a*x^2/b)/(1+m)^2+_
+--  x^(1+m)*log(c*(a+b/x^2)^p)/(1+m)
+--E 2028
+
+--S 2029 of 5341
+--a0:=integrate(t0,x)
+--E 2029
+
+--S 2030 of 5341
+--m0:=a0-r0
+--E 2030
+
+--S 2031 of 5341
+--d0:=D(m0,x)
+--E 2031
+
+)clear all
+
+--S 2032 of 5341
+t0:=x^4*log(c*(a+b/x^2)^p)
+--R 
+--R
+--R                    2     p
+--R         4       a x  + b
+--R   (1)  x log(c (--------) )
+--R                     2
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 2032
+
+--S 2033 of 5341
+r0:=-2/5*b^2*p*x/a^2+2/15*b*p*x^3/a+2/5*b^(5/2)*p*atan(x*sqrt(a)/sqrt(b))/_
+   a^(5/2)+1/5*x^5*log(c*(a+b/x^2)^p)
+--R 
+--R
+--R   (2)
+--R                      2     p                   +-+
+--R     2 5 +-+       a x  + b        2  +-+     x\|a              3     2     +-+
+--R   3a x \|a log(c (--------) ) + 6b p\|b atan(-----) + (2a b p x  - 6b p x)\|a
+--R                       2                        +-+
+--R                      x                        \|b
+--R   ----------------------------------------------------------------------------
+--R                                        2 +-+
+--R                                     15a \|a
+--R                                                    Type: Expression(Integer)
+--E 2033
+
+--S 2034 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                            +---+
+--R                            |  b       2
+--R              +---+    2a x |- -  + a x  - b
+--R           2  |  b         \|  a                  2 5
+--R         3b p |- - log(---------------------) + 3a x log(c)
+--R             \|  a               2
+--R                              a x  + b
+--R       + 
+--R                       2
+--R           2   5    a x  + b            3     2
+--R         3a p x log(--------) + 2a b p x  - 6b p x
+--R                        2
+--R                       x
+--R    /
+--R          2
+--R       15a
+--R     ,
+--R
+--R                         +-+
+--R                         |b
+--R                +-+      |-                                 2
+--R             2  |b      \|a       2 5           2   5    a x  + b            3
+--R         - 6b p |- atan(----) + 3a x log(c) + 3a p x log(--------) + 2a b p x
+--R               \|a        x                                  2
+--R                                                            x
+--R       + 
+--R             2
+--R         - 6b p x
+--R    /
+--R          2
+--R       15a
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2034
+
+--S 2035 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             +---+
+--R                             |  b       2
+--R           +---+        2a x |- -  + a x  - b                      2     p
+--R        2  |  b  +-+        \|  a                 2 5 +-+       a x  + b
+--R       b p |- - \|a log(---------------------) - a x \|a log(c (--------) )
+--R          \|  a                   2                                 2
+--R                               a x  + b                            x
+--R     + 
+--R                        +-+                               2
+--R           2  +-+     x\|a       2 5          2   5    a x  + b   +-+
+--R       - 2b p\|b atan(-----) + (a x log(c) + a p x log(--------))\|a
+--R                        +-+                                2
+--R                       \|b                                x
+--R  /
+--R       2 +-+
+--R     5a \|a
+--R                                                    Type: Expression(Integer)
+--E 2035
+
+--S 2036 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2036
+
+--S 2037 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                        +-+
+--R                                                        |b
+--R                           2     p             +-+      |-
+--R          2 5 +-+       a x  + b        2  +-+ |b      \|a
+--R       - a x \|a log(c (--------) ) - 2b p\|a  |- atan(----)
+--R                            2                 \|a        x
+--R                           x
+--R     + 
+--R                        +-+                               2
+--R           2  +-+     x\|a       2 5          2   5    a x  + b   +-+
+--R       - 2b p\|b atan(-----) + (a x log(c) + a p x log(--------))\|a
+--R                        +-+                                2
+--R                       \|b                                x
+--R  /
+--R       2 +-+
+--R     5a \|a
+--R                                                    Type: Expression(Integer)
+--E 2037
+
+--S 2038 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2038
+
+)clear all
+
+--S 2039 of 5341
+t0:=x^3*log(c*(a+b/x^2)^p)
+--R 
+--R
+--R                    2     p
+--R         3       a x  + b
+--R   (1)  x log(c (--------) )
+--R                     2
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 2039
+
+--S 2040 of 5341
+r0:=1/4*b*p*x^2/a+1/4*x^4*log(c*(a+b/x^2)^p)-1/4*b^2*p*log(b+a*x^2)/a^2
+--R 
+--R
+--R                      2     p
+--R         2 4       a x  + b       2         2               2
+--R        a x log(c (--------) ) - b p log(a x  + b) + a b p x
+--R                       2
+--R                      x
+--R   (2)  -----------------------------------------------------
+--R                                   2
+--R                                 4a
+--R                                                    Type: Expression(Integer)
+--E 2040
+
+--S 2041 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        2
+--R           2         2         2 4          2   4    a x  + b           2
+--R        - b p log(a x  + b) + a x log(c) + a p x log(--------) + a b p x
+--R                                                         2
+--R                                                        x
+--R   (3)  -----------------------------------------------------------------
+--R                                         2
+--R                                       4a
+--R                                         Type: Union(Expression(Integer),...)
+--E 2041
+
+--S 2042 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                      2     p                          2
+--R           4       a x  + b       4            4    a x  + b
+--R        - x log(c (--------) ) + x log(c) + p x log(--------)
+--R                       2                                2
+--R                      x                                x
+--R   (4)  -----------------------------------------------------
+--R                                  4
+--R                                                    Type: Expression(Integer)
+--E 2042
+
+--S 2043 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2043
+
+)clear all
+
+--S 2044 of 5341
+t0:=x^2*log(c*(a+b/x^2)^p)
+--R 
+--R
+--R                    2     p
+--R         2       a x  + b
+--R   (1)  x log(c (--------) )
+--R                     2
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 2044
+
+--S 2045 of 5341
+r0:=2/3*b*p*x/a-2/3*b^(3/2)*p*atan(x*sqrt(a)/sqrt(b))/a^(3/2)+_
+   1/3*x^3*log(c*(a+b/x^2)^p)
+--R 
+--R
+--R                          2     p                   +-+
+--R           3 +-+       a x  + b           +-+     x\|a            +-+
+--R        a x \|a log(c (--------) ) - 2b p\|b atan(-----) + 2b p x\|a
+--R                           2                        +-+
+--R                          x                        \|b
+--R   (2)  -------------------------------------------------------------
+--R                                       +-+
+--R                                    3a\|a
+--R                                                    Type: Expression(Integer)
+--E 2045
+
+--S 2046 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                             +---+
+--R                             |  b       2
+--R             +---+    - 2a x |- -  + a x  - b
+--R             |  b           \|  a                   3
+--R         b p |- - log(-----------------------) + a x log(c)
+--R            \|  a                2
+--R                              a x  + b
+--R       + 
+--R                      2
+--R              3    a x  + b
+--R         a p x log(--------) + 2b p x
+--R                       2
+--R                      x
+--R    /
+--R       3a
+--R     ,
+--R                  +-+
+--R                  |b
+--R         +-+      |-                               2
+--R         |b      \|a        3              3    a x  + b
+--R    2b p |- atan(----) + a x log(c) + a p x log(--------) + 2b p x
+--R        \|a        x                                2
+--R                                                   x
+--R    --------------------------------------------------------------]
+--R                                  3a
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2046
+
+--S 2047 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                              +---+
+--R                                                              |  b       2
+--R                           2     p        +---+        - 2a x |- -  + a x  - b
+--R            3 +-+       a x  + b          |  b  +-+          \|  a
+--R       - a x \|a log(c (--------) ) + b p |- - \|a log(-----------------------)
+--R                            2            \|  a                    2
+--R                           x                                   a x  + b
+--R     + 
+--R                      +-+                               2
+--R            +-+     x\|a         3              3    a x  + b   +-+
+--R       2b p\|b atan(-----) + (a x log(c) + a p x log(--------))\|a
+--R                      +-+                                2
+--R                     \|b                                x
+--R  /
+--R        +-+
+--R     3a\|a
+--R                                                    Type: Expression(Integer)
+--E 2047
+
+--S 2048 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2048
+
+--S 2049 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                        +-+
+--R                                                        |b
+--R                           2     p             +-+      |-
+--R            3 +-+       a x  + b           +-+ |b      \|a
+--R       - a x \|a log(c (--------) ) + 2b p\|a  |- atan(----)
+--R                            2                 \|a        x
+--R                           x
+--R     + 
+--R                      +-+                               2
+--R            +-+     x\|a         3              3    a x  + b   +-+
+--R       2b p\|b atan(-----) + (a x log(c) + a p x log(--------))\|a
+--R                      +-+                                2
+--R                     \|b                                x
+--R  /
+--R        +-+
+--R     3a\|a
+--R                                                    Type: Expression(Integer)
+--E 2049
+
+--S 2050 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2050
+
+)clear all
+
+--S 2051 of 5341
+t0:=x*log(c*(a+b/x^2)^p)
+--R 
+--R
+--R                    2     p
+--R                 a x  + b
+--R   (1)  x log(c (--------) )
+--R                     2
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 2051
+
+--S 2052 of 5341
+r0:=1/2*x^2*log(c*(a+b/x^2)^p)+1/2*b*p*log(b+a*x^2)/a
+--R 
+--R
+--R                      2     p
+--R           2       a x  + b                 2
+--R        a x log(c (--------) ) + b p log(a x  + b)
+--R                       2
+--R                      x
+--R   (2)  ------------------------------------------
+--R                            2a
+--R                                                    Type: Expression(Integer)
+--E 2052
+
+--S 2053 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                      2
+--R                   2           2              2    a x  + b
+--R        b p log(a x  + b) + a x log(c) + a p x log(--------)
+--R                                                       2
+--R                                                      x
+--R   (3)  ----------------------------------------------------
+--R                                 2a
+--R                                         Type: Union(Expression(Integer),...)
+--E 2053
+
+--S 2054 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                      2     p                          2
+--R           2       a x  + b       2            2    a x  + b
+--R        - x log(c (--------) ) + x log(c) + p x log(--------)
+--R                       2                                2
+--R                      x                                x
+--R   (4)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 2054
+
+--S 2055 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2055
+
+)clear all
+
+--S 2056 of 5341
+t0:=log(c*(a+b/x^2)^p)
+--R 
+--R
+--R                  2     p
+--R               a x  + b
+--R   (1)  log(c (--------) )
+--R                   2
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 2056
+
+--S 2057 of 5341
+r0:=x*log(c*(a+b/x^2)^p)+2*p*atan(x*sqrt(a)/sqrt(b))*sqrt(b)/sqrt(a)
+--R 
+--R
+--R                       2     p                 +-+
+--R          +-+       a x  + b         +-+     x\|a
+--R        x\|a log(c (--------) ) + 2p\|b atan(-----)
+--R                        2                      +-+
+--R                       x                      \|b
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                            \|a
+--R                                                    Type: Expression(Integer)
+--E 2057
+
+--S 2058 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +---+
+--R                    |  b       2
+--R      +---+    2a x |- -  + a x  - b                          2
+--R      |  b         \|  a                                   a x  + b
+--R   [p |- - log(---------------------) + x log(c) + p x log(--------),
+--R     \|  a               2                                     2
+--R                      a x  + b                                x
+--R                  +-+
+--R                  |b
+--R         +-+      |-                           2
+--R         |b      \|a                        a x  + b
+--R    - 2p |- atan(----) + x log(c) + p x log(--------)]
+--R        \|a        x                            2
+--R                                               x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2058
+
+--S 2059 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           +---+
+--R                           |  b       2
+--R         +---+        2a x |- -  + a x  - b                   2     p
+--R         |  b  +-+        \|  a                  +-+       a x  + b
+--R       p |- - \|a log(---------------------) - x\|a log(c (--------) )
+--R        \|  a                   2                              2
+--R                             a x  + b                         x
+--R     + 
+--R                      +-+                           2
+--R            +-+     x\|a                         a x  + b   +-+
+--R       - 2p\|b atan(-----) + (x log(c) + p x log(--------))\|a
+--R                      +-+                            2
+--R                     \|b                            x
+--R  /
+--R      +-+
+--R     \|a
+--R                                                    Type: Expression(Integer)
+--E 2059
+
+--S 2060 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2060
+
+--S 2061 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                   +-+
+--R                                                   |b
+--R                        2     p           +-+      |-                  +-+
+--R           +-+       a x  + b         +-+ |b      \|a        +-+     x\|a
+--R       - x\|a log(c (--------) ) - 2p\|a  |- atan(----) - 2p\|b atan(-----)
+--R                         2               \|a        x                  +-+
+--R                        x                                             \|b
+--R     + 
+--R                              2
+--R                           a x  + b   +-+
+--R       (x log(c) + p x log(--------))\|a
+--R                               2
+--R                              x
+--R  /
+--R      +-+
+--R     \|a
+--R                                                    Type: Expression(Integer)
+--E 2061
+
+--S 2062 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2062
+
+)clear all
+
+--S 2063 of 5341
+t0:=log(c*(a+b/x^2)^p)/x
+--R 
+--R
+--R                  2     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   2
+--R                  x
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2063
+
+--S 2064 of 5341
+--r0:=-1/2*log(c*(a+b/x^2)^p)*log(-b/(a*x^2))-1/2*p*polylog(2,(a+b/x^2)/a)
+--E 2064
+
+--S 2065 of 5341
+--a0:=integrate(t0,x)
+--E 2065
+
+--S 2066 of 5341
+--m0:=a0-r0
+--E 2066
+
+--S 2067 of 5341
+--d0:=D(m0,x)
+--E 2067
+
+)clear all
+
+--S 2068 of 5341
+t0:=log(c*(a+b/x^2)^p)/x^2
+--R 
+--R
+--R                  2     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   2
+--R                  x
+--R   (1)  ------------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2068
+
+--S 2069 of 5341
+r0:=2*p/x-log(c*(a+b/x^2)^p)/x+2*p*atan(x*sqrt(a)/sqrt(b))*sqrt(a)/sqrt(b)
+--R 
+--R
+--R                        2     p                   +-+
+--R           +-+       a x  + b           +-+     x\|a        +-+
+--R        - \|b log(c (--------) ) + 2p x\|a atan(-----) + 2p\|b
+--R                         2                        +-+
+--R                        x                        \|b
+--R   (2)  -------------------------------------------------------
+--R                                   +-+
+--R                                 x\|b
+--R                                                    Type: Expression(Integer)
+--E 2069
+
+--S 2070 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      +---+
+--R                      |  a       2
+--R        +---+    2b x |- -  + a x  - b                      2
+--R        |  a         \|  b                               a x  + b
+--R    p x |- - log(---------------------) - log(c) - p log(--------) + 2p
+--R       \|  b               2                                 2
+--R                        a x  + b                            x
+--R   [-------------------------------------------------------------------,
+--R                                     x
+--R                     +-+
+--R                     |a
+--R           +-+     b |-                       2
+--R           |a       \|b                    a x  + b
+--R    - 2p x |- atan(-----) - log(c) - p log(--------) + 2p
+--R          \|b       a x                        2
+--R                                              x
+--R    -----------------------------------------------------]
+--R                              x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2070
+
+--S 2071 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                             +---+
+--R                             |  a       2
+--R           +---+        2b x |- -  + a x  - b                  2     p
+--R           |  a  +-+        \|  b                 +-+       a x  + b
+--R       p x |- - \|b log(---------------------) + \|b log(c (--------) )
+--R          \|  b                   2                             2
+--R                               a x  + b                        x
+--R     + 
+--R                        +-+                         2
+--R              +-+     x\|a                       a x  + b   +-+
+--R       - 2p x\|a atan(-----) + (- log(c) - p log(--------))\|b
+--R                        +-+                          2
+--R                       \|b                          x
+--R  /
+--R       +-+
+--R     x\|b
+--R                                                    Type: Expression(Integer)
+--E 2071
+
+--S 2072 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2072
+
+--S 2073 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                   +-+
+--R                                                   |a
+--R                     2     p         +-+         b |-                    +-+
+--R        +-+       a x  + b           |a  +-+      \|b          +-+     x\|a
+--R       \|b log(c (--------) ) - 2p x |- \|b atan(-----) - 2p x\|a atan(-----)
+--R                      2             \|b           a x                    +-+
+--R                     x                                                  \|b
+--R     + 
+--R                            2
+--R                         a x  + b   +-+
+--R       (- log(c) - p log(--------))\|b
+--R                             2
+--R                            x
+--R  /
+--R       +-+
+--R     x\|b
+--R                                                    Type: Expression(Integer)
+--E 2073
+
+--S 2074 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2074
+
+)clear all
+
+--S 2075 of 5341
+t0:=log(c*(a+b/x^2)^p)/x^3
+--R 
+--R
+--R                  2     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   2
+--R                  x
+--R   (1)  ------------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2075
+
+--S 2076 of 5341
+r0:=1/2*p/x^2-1/2*(a+b/x^2)*log(c*(a+b/x^2)^p)/b
+--R 
+--R
+--R                              2     p
+--R              2            a x  + b
+--R        (- a x  - b)log(c (--------) ) + b p
+--R                               2
+--R                              x
+--R   (2)  ------------------------------------
+--R                            2
+--R                        2b x
+--R                                                    Type: Expression(Integer)
+--E 2076
+
+--S 2077 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                            2
+--R                             2           a x  + b
+--R        - b log(c) + (- a p x  - b p)log(--------) + b p
+--R                                             2
+--R                                            x
+--R   (3)  ------------------------------------------------
+--R                                  2
+--R                              2b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 2077
+
+--S 2078 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                       2     p                                      2
+--R       2            a x  + b                         2           a x  + b
+--R   (a x  + b)log(c (--------) ) - b log(c) + (- a p x  - b p)log(--------)
+--R                        2                                            2
+--R                       x                                            x
+--R   -----------------------------------------------------------------------
+--R                                        2
+--R                                    2b x
+--R                                                    Type: Expression(Integer)
+--E 2078
+
+--S 2079 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2079
+
+)clear all
+
+--S 2080 of 5341
+t0:=log(c*(a+b/x^2)^p)/x^4
+--R 
+--R
+--R                  2     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   2
+--R                  x
+--R   (1)  ------------------
+--R                 4
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2080
+
+--S 2081 of 5341
+r0:=2/9*p/x^3-2/3*a*p/(b*x)-2/3*a^(3/2)*p*atan(x*sqrt(a)/sqrt(b))/b^(3/2)-_
+   1/3*log(c*(a+b/x^2)^p)/x^3
+--R 
+--R
+--R   (2)
+--R                     2     p                      +-+
+--R        +-+       a x  + b            3 +-+     x\|a              2         +-+
+--R   - 3b\|b log(c (--------) ) - 6a p x \|a atan(-----) + (- 6a p x  + 2b p)\|b
+--R                      2                           +-+
+--R                     x                           \|b
+--R   ----------------------------------------------------------------------------
+--R                                         3 +-+
+--R                                     9b x \|b
+--R                                                    Type: Expression(Integer)
+--E 2081
+
+--S 2082 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                 +---+
+--R                                 |  a       2
+--R                 +---+    - 2b x |- -  + a x  - b
+--R               3 |  a           \|  b
+--R         3a p x  |- - log(-----------------------) - 3b log(c)
+--R                \|  b                2
+--R                                  a x  + b
+--R       + 
+--R                       2
+--R                    a x  + b          2
+--R         - 3b p log(--------) - 6a p x  + 2b p
+--R                        2
+--R                       x
+--R    /
+--R           3
+--R       9b x
+--R     ,
+--R                      +-+
+--R                      |a
+--R            +-+     b |-                             2
+--R          3 |a       \|b                          a x  + b          2
+--R    6a p x  |- atan(-----) - 3b log(c) - 3b p log(--------) - 6a p x  + 2b p
+--R           \|b       a x                              2
+--R                                                     x
+--R    ------------------------------------------------------------------------]
+--R                                          3
+--R                                      9b x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2082
+
+--S 2083 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                            +---+
+--R                                                            |  a       2
+--R                      2     p           +---+        - 2b x |- -  + a x  - b
+--R         +-+       a x  + b           3 |  a  +-+          \|  b
+--R       b\|b log(c (--------) ) + a p x  |- - \|b log(-----------------------)
+--R                       2               \|  b                    2
+--R                      x                                      a x  + b
+--R     + 
+--R                         +-+                             2
+--R             3 +-+     x\|a                           a x  + b   +-+
+--R       2a p x \|a atan(-----) + (- b log(c) - b p log(--------))\|b
+--R                         +-+                              2
+--R                        \|b                              x
+--R  /
+--R         3 +-+
+--R     3b x \|b
+--R                                                    Type: Expression(Integer)
+--E 2083
+
+--S 2084 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2084
+
+--S 2085 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                       +-+
+--R                                                       |a
+--R                      2     p            +-+         b |-
+--R         +-+       a x  + b            3 |a  +-+      \|b
+--R       b\|b log(c (--------) ) + 2a p x  |- \|b atan(-----)
+--R                       2                \|b           a x
+--R                      x
+--R     + 
+--R                         +-+                             2
+--R             3 +-+     x\|a                           a x  + b   +-+
+--R       2a p x \|a atan(-----) + (- b log(c) - b p log(--------))\|b
+--R                         +-+                              2
+--R                        \|b                              x
+--R  /
+--R         3 +-+
+--R     3b x \|b
+--R                                                    Type: Expression(Integer)
+--E 2085
+
+--S 2086 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2086
+
+)clear all
+
+--S 2087 of 5341
+t0:=x^m*log(c*(a+b*x^n)^p)
+--R 
+--R
+--R         m          n     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2087
+
+--S 2088 of 5341
+--r0:=-n*p*x^(1+m)/(1+m)^2+n*p*x^(1+m)*_
+--  hypergeometric(1,(1+m)/n,(1+m+n)/n,-b*x^n/a)/(1+m)^2+x^(1+m)*_
+--  log(c*(a+b*x^n)^p)/(1+m)
+--E 2088
+
+--S 2089 of 5341
+--a0:=integrate(t0,x)
+--E 2089
+
+--S 2090 of 5341
+--m0:=a0-r0
+--E 2090
+
+--S 2091 of 5341
+--d0:=D(m0,x)
+--E 2091
+
+)clear all
+
+--S 2092 of 5341
+t0:=x^2*log(c*(a+b*x^n)^p)
+--R 
+--R
+--R         2          n     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2092
+
+--S 2093 of 5341
+--r0:=-1/9*n*p*x^3+1/9*n*p*x^3*_
+--  hypergeometric(1,3/n,(3+n)/n,-b*x^n/a)+1/3*x^3*log(c*(a+b*x^n)^p)
+--E 2093
+
+--S 2094 of 5341
+--a0:=integrate(t0,x)
+--E 2094
+
+--S 2095 of 5341
+--m0:=a0-r0
+--E 2095
+
+--S 2096 of 5341
+--d0:=D(m0,x)
+--E 2096
+
+)clear all
+
+--S 2097 of 5341
+t0:=x*log(c*(a+b*x^n)^p)
+--R 
+--R
+--R                    n     p
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2097
+
+--S 2098 of 5341
+--r0:=-1/4*n*p*x^2+1/4*n*p*x^2*_
+--  hypergeometric(1,2/n,(2+n)/n,-b*x^n/a)+1/2*x^2*log(c*(a+b*x^n)^p)
+--E 2098
+
+--S 2099 of 5341
+--a0:=integrate(t0,x)
+--E 2099
+
+--S 2100 of 5341
+--m0:=a0-r0
+--E 2100
+
+--S 2101 of 5341
+--d0:=D(m0,x)
+--E 2101
+
+)clear all
+
+--S 2102 of 5341
+t0:=log(c*(a+b*x^n)^p)
+--R 
+--R
+--R                  n     p
+--R   (1)  log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2102
+
+--S 2103 of 5341
+--r0:=-n*p*x+n*p*x*hypergeometric(1,1/n,1+1/n,-b*x^n/a)+x*log(c*(a+b*x^n)^p)
+--E 2103
+
+--S 2104 of 5341
+--a0:=integrate(t0,x)
+--E 2104
+
+--S 2105 of 5341
+--m0:=a0-r0
+--E 2105
+
+--S 2106 of 5341
+--d0:=D(m0,x)
+--E 2106
+
+)clear all
+
+--S 2107 of 5341
+t0:=log(c*(a+b*x^n)^p)/x
+--R 
+--R
+--R                  n     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2107
+
+--S 2108 of 5341
+--r0:=log(-b*x^n/a)*log(c*(a+b*x^n)^p)/n+p*polylog(2,(a+b*x^n)/a)/n
+--E 2108
+
+--S 2109 of 5341
+--a0:=integrate(t0,x)
+--E 2109
+
+--S 2110 of 5341
+--m0:=a0-r0
+--E 2110
+
+--S 2111 of 5341
+--d0:=D(m0,x)
+--E 2111
+
+)clear all
+
+--S 2112 of 5341
+t0:=log(c*(a+b*x^n)^p)/x^2
+--R 
+--R
+--R                  n     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2112
+
+--S 2113 of 5341
+--r0:=-n*p/x+n*p*hypergeometric(1,(-1)/n,(-1+n)/n,-b*x^n/a)/x-_
+--  log(c*(a+b*x^n)^p)/x
+--E 2113
+
+--S 2114 of 5341
+--a0:=integrate(t0,x)
+--E 2114
+
+--S 2115 of 5341
+--m0:=a0-r0
+--E 2115
+
+--S 2116 of 5341
+--d0:=D(m0,x)
+--E 2116
+
+)clear all
+
+--S 2117 of 5341
+t0:=log(c*(a+b*x^n)^p)/x^3
+--R 
+--R
+--R                  n     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2117
+
+--S 2118 of 5341
+--r0:=-1/4*n*p/x^2+1/4*n*p*hypergeometric(1,(-2)/n,(-2+n)/n,-b*x^n/a)/x^2-_
+--  1/2*log(c*(a+b*x^n)^p)/x^2
+--E 2118
+
+--S 2119 of 5341
+--a0:=integrate(t0,x)
+--E 2119
+
+--S 2120 of 5341
+--m0:=a0-r0
+--E 2120
+
+--S 2121 of 5341
+--d0:=D(m0,x)
+--E 2121
+
+)clear all
+
+--S 2122 of 5341
+t0:=log(c*(a+b*x^n)^p)/x^4
+--R 
+--R
+--R                  n     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 4
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2122
+
+--S 2123 of 5341
+--r0:=-1/9*n*p/x^3+1/9*n*p*hypergeometric(1,(-3)/n,(-3+n)/n,-b*x^n/a)/x^3-_
+--  1/3*log(c*(a+b*x^n)^p)/x^3
+--E 2123
+
+--S 2124 of 5341
+--a0:=integrate(t0,x)
+--E 2124
+
+--S 2125 of 5341
+--m0:=a0-r0
+--E 2125
+
+--S 2126 of 5341
+--d0:=D(m0,x)
+--E 2126
+
+)clear all
+
+--S 2127 of 5341
+t0:=log(1+b*x^n)/x
+--R 
+--R
+--R               n
+--R        log(b x  + 1)
+--R   (1)  -------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 2127
+
+--S 2128 of 5341
+--r0:=-polylog(2,-b*x^n)/n
+--E 2128
+
+--S 2129 of 5341
+--a0:=integrate(t0,x)
+--E 2129
+
+--S 2130 of 5341
+--m0:=a0-r0
+--E 2130
+
+--S 2131 of 5341
+--d0:=D(m0,x)
+--E 2131
+
+)clear all
+
+--S 2132 of 5341
+t0:=(d+e*x)^m*log(c*(a+b*x)^p)
+--R 
+--R
+--R                 m               p
+--R   (1)  (e x + d) log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 2132
+
+--S 2133 of 5341
+--r0:=b*p*(d+e*x)^(2+m)*hypergeometric(1,2+m,3+m,b*(d+e*x)/(b*d-a*e))/_
+--  (e*(b*d-a*e)*(1+m)*(2+m))+(d+e*x)^(1+m)*log(c*(a+b*x)^p)/(e*(1+m))
+--E 2133
+
+--S 2134 of 5341
+--a0:=integrate(t0,x)
+--E 2134
+
+--S 2135 of 5341
+--m0:=a0-r0
+--E 2135
+
+--S 2136 of 5341
+--d0:=D(m0,x)
+--E 2136
+
+)clear all
+
+--S 2137 of 5341
+t0:=(d+e*x)^3*log(c*(a+b*x)^p)
+--R 
+--R
+--R          3 3       2 2     2       3                p
+--R   (1)  (e x  + 3d e x  + 3d e x + d )log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 2137
+
+--S 2138 of 5341
+r0:=-1/4*(b*d-a*e)^3*p*x/b^3-1/8*(b*d-a*e)^2*p*(d+e*x)^2/(b^2*e)-_
+   1/12*(b*d-a*e)*p*(d+e*x)^3/(b*e)-1/16*p*(d+e*x)^4/e-1/4*(b*d-a*e)^4*p*_
+   log(a+b*x)/(b^4*e)+1/4*(d+e*x)^4*log(c*(a+b*x)^p)/e
+--R 
+--R
+--R   (2)
+--R             4 4 4      4   3 3      4 2 2 2      4 3         4 4
+--R         (12b e x  + 48b d e x  + 72b d e x  + 48b d e x + 12b d )
+--R      *
+--R                        p
+--R         log(c (b x + a) )
+--R     + 
+--R             4 4      3     3      2 2 2 2        3 3       4 4
+--R       (- 12a e  + 48a b d e  - 72a b d e  + 48a b d e - 12b d )p log(b x + a)
+--R     + 
+--R           4 4   4        3 4      4   3    3
+--R       - 3b e p x  + (4a b e  - 16b d e )p x
+--R     + 
+--R            2 2 4        3   3      4 2 2    2
+--R       (- 6a b e  + 24a b d e  - 36b d e )p x
+--R     + 
+--R           3   4      2 2   3        3 2 2      4 3
+--R       (12a b e  - 48a b d e  + 72a b d e  - 48b d e)p x
+--R     + 
+--R            2 2 2 2        3 3       4 4
+--R       (- 6a b d e  + 16a b d e - 13b d )p
+--R  /
+--R        4
+--R     48b e
+--R                                                    Type: Expression(Integer)
+--E 2138
+
+--S 2139 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              4 3   4      4   2   3      4 2     2      4 3
+--R           12b e p x  + 48b d e p x  + 72b d e p x  + 48b d p x
+--R         + 
+--R                 4 3      3     2      2 2 2         3 3
+--R           (- 12a e  + 48a b d e  - 72a b d e + 48a b d )p
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           4 3 4      4   2 3      4 2   2      4 3             4 3   4
+--R       (12b e x  + 48b d e x  + 72b d e x  + 48b d x)log(c) - 3b e p x
+--R     + 
+--R            3 3      4   2    3        2 2 3        3   2      4 2     2
+--R       (4a b e  - 16b d e )p x  + (- 6a b e  + 24a b d e  - 36b d e)p x
+--R     + 
+--R           3   3      2 2   2        3 2       4 3
+--R       (12a b e  - 48a b d e  + 72a b d e - 48b d )p x
+--R  /
+--R        4
+--R     48b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2139
+
+--S 2140 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R               2 4 4      2   3 3      2 2 2 2      2 3         2 4
+--R         (- 12b e x  - 48b d e x  - 72b d e x  - 48b d e x - 12b d )
+--R      *
+--R                        p
+--R         log(c (b x + a) )
+--R     + 
+--R             2 4   4      2   3   3      2 2 2   2      2 3           2 4
+--R         (12b e p x  + 48b d e p x  + 72b d e p x  + 48b d e p x + 12b d p)
+--R      *
+--R         log(b x + a)
+--R     + 
+--R           2 4 4      2   3 3      2 2 2 2      2 3
+--R       (12b e x  + 48b d e x  + 72b d e x  + 48b d e x)log(c)
+--R     + 
+--R          2 2 2          3       2 4
+--R       (6a d e  - 16a b d e + 13b d )p
+--R  /
+--R        2
+--R     48b e
+--R                                                    Type: Expression(Integer)
+--E 2140
+
+--S 2141 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2141
+
+)clear all
+
+--S 2142 of 5341
+t0:=(d+e*x)^2*log(c*(a+b*x)^p)
+--R 
+--R
+--R          2 2             2                p
+--R   (1)  (e x  + 2d e x + d )log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 2142
+
+--S 2143 of 5341
+r0:=-1/3*(b*d-a*e)^2*p*x/b^2-1/6*(b*d-a*e)*p*(d+e*x)^2/(b*e)-_
+   1/9*p*(d+e*x)^3/e-1/3*(b*d-a*e)^3*p*log(a+b*x)/(b^3*e)+1/3*(d+e*x)^3*_
+   log(c*(a+b*x)^p)/e
+--R 
+--R
+--R   (2)
+--R          3 3 3      3   2 2      3 2        3 3                p
+--R       (6b e x  + 18b d e x  + 18b d e x + 6b d )log(c (b x + a) )
+--R     + 
+--R          3 3      2     2        2 2      3 3                    3 3   3
+--R       (6a e  - 18a b d e  + 18a b d e - 6b d )p log(b x + a) - 2b e p x
+--R     + 
+--R            2 3     3   2    2        2   3        2   2      3 2
+--R       (3a b e  - 9b d e )p x  + (- 6a b e  + 18a b d e  - 18b d e)p x
+--R     + 
+--R            2 2      3 3
+--R       (3a b d e - 5b d )p
+--R  /
+--R        3
+--R     18b e
+--R                                                    Type: Expression(Integer)
+--E 2143
+
+--S 2144 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3 2   3      3       2      3 2
+--R             6b e p x  + 18b d e p x  + 18b d p x
+--R           + 
+--R                3 2      2             2 2
+--R             (6a e  - 18a b d e + 18a b d )p
+--R      *
+--R         log(b x + a)
+--R     + 
+--R          3 2 3      3     2      3 2             3 2   3
+--R       (6b e x  + 18b d e x  + 18b d x)log(c) - 2b e p x
+--R     + 
+--R            2 2     3       2        2   2        2         3 2
+--R       (3a b e  - 9b d e)p x  + (- 6a b e  + 18a b d e - 18b d )p x
+--R  /
+--R        3
+--R     18b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2144
+
+--S 2145 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3 3          2 2        2          3                p
+--R       (- 6b e x  - 18b d e x  - 18b d e x - 6b d )log(c (b x + a) )
+--R     + 
+--R            3   3          2   2        2            3
+--R       (6b e p x  + 18b d e p x  + 18b d e p x + 6b d p)log(b x + a)
+--R     + 
+--R            3 3          2 2        2                    2        3
+--R       (6b e x  + 18b d e x  + 18b d e x)log(c) + (- 3a d e + 5b d )p
+--R  /
+--R     18b e
+--R                                                    Type: Expression(Integer)
+--E 2145
+
+--S 2146 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2146
+
+)clear all
+
+--S 2147 of 5341
+t0:=(d+e*x)*log(c*(a+b*x)^p)
+--R 
+--R
+--R                                p
+--R   (1)  (e x + d)log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 2147
+
+--S 2148 of 5341
+r0:=-1/2*(b*d-a*e)*p*x/b-1/4*p*(d+e*x)^2/e-1/2*(b*d-a*e)^2*p*log(a+b*x)/_
+   (b^2*e)+1/2*(d+e*x)^2*log(c*(a+b*x)^p)/e
+--R 
+--R
+--R   (2)
+--R          2 2 2     2          2 2                p
+--R       (2b e x  + 4b d e x + 2b d )log(c (b x + a) )
+--R     + 
+--R            2 2                2 2                   2 2   2
+--R       (- 2a e  + 4a b d e - 2b d )p log(b x + a) - b e p x
+--R     + 
+--R              2     2           2 2
+--R       (2a b e  - 4b d e)p x - b d p
+--R  /
+--R       2
+--R     4b e
+--R                                                    Type: Expression(Integer)
+--E 2148
+
+--S 2149 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2     2     2             2
+--R       (2b e p x  + 4b d p x + (- 2a e + 4a b d)p)log(b x + a)
+--R     + 
+--R          2   2     2              2     2               2
+--R       (2b e x  + 4b d x)log(c) - b e p x  + (2a b e - 4b d)p x
+--R  /
+--R       2
+--R     4b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2149
+
+--S 2150 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            2 2              2                p
+--R       (- 2e x  - 4d e x - 2d )log(c (b x + a) )
+--R     + 
+--R          2   2                2                    2 2                    2
+--R       (2e p x  + 4d e p x + 2d p)log(b x + a) + (2e x  + 4d e x)log(c) + d p
+--R  /
+--R     4e
+--R                                                    Type: Expression(Integer)
+--E 2150
+
+--S 2151 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2151
+
+)clear all
+
+--S 2152 of 5341
+t0:=log(c*(a+b*x)^p)
+--R 
+--R
+--R                       p
+--R   (1)  log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 2152
+
+--S 2153 of 5341
+r0:=-p*x+(a+b*x)*log(c*(a+b*x)^p)/b
+--R 
+--R
+--R                                p
+--R        (b x + a)log(c (b x + a) ) - b p x
+--R   (2)  ----------------------------------
+--R                         b
+--R                                                    Type: Expression(Integer)
+--E 2153
+
+--S 2154 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (b p x + a p)log(b x + a) + b x log(c) - b p x
+--R   (3)  ----------------------------------------------
+--R                               b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2154
+
+--S 2155 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                                  p
+--R        (- b x - a)log(c (b x + a) ) + (b p x + a p)log(b x + a) + b x log(c)
+--R   (4)  ---------------------------------------------------------------------
+--R                                          b
+--R                                                    Type: Expression(Integer)
+--E 2155
+
+--S 2156 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2156
+
+)clear all
+
+--S 2157 of 5341
+t0:=log(c*(a+b*x)^p)/(d+e*x)
+--R 
+--R
+--R                       p
+--R        log(c (b x + a) )
+--R   (1)  -----------------
+--R             e x + d
+--R                                                    Type: Expression(Integer)
+--E 2157
+
+--S 2158 of 5341
+--r0:=log(c*(a+b*x)^p)*log(b*(d+e*x)/(b*d-a*e))/e+_
+--  p*polylog(2,-e*(a+b*x)/(b*d-a*e))/e
+--E 2158
+
+--S 2159 of 5341
+--a0:=integrate(t0,x)
+--E 2159
+
+--S 2160 of 5341
+--m0:=a0-r0
+--E 2160
+
+--S 2161 of 5341
+--d0:=D(m0,x)
+--E 2161
+
+)clear all
+
+--S 2162 of 5341
+t0:=log(c*(a+b*x)^p)/(d+e*x)^2
+--R 
+--R
+--R                        p
+--R         log(c (b x + a) )
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 2162
+
+--S 2163 of 5341
+r0:=b*p*log(a+b*x)/(e*(b*d-a*e))-log(c*(a+b*x)^p)/(e*(d+e*x))-_
+   b*p*log(d+e*x)/(e*(b*d-a*e))
+--R 
+--R
+--R   (2)
+--R                                   p
+--R       (- a e + b d)log(c (b x + a) ) + (b e p x + b d p)log(e x + d)
+--R     + 
+--R       (- b e p x - b d p)log(b x + a)
+--R  /
+--R         3        2          2      2
+--R     (a e  - b d e )x + a d e  - b d e
+--R                                                    Type: Expression(Integer)
+--E 2163
+
+--S 2164 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       (b e p x + b d p)log(e x + d) + (- b e p x - a e p)log(b x + a)
+--R     + 
+--R       (- a e + b d)log(c)
+--R  /
+--R         3        2          2      2
+--R     (a e  - b d e )x + a d e  - b d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 2164
+
+--S 2165 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                       p
+--R        log(c (b x + a) ) - p log(b x + a) - log(c)
+--R   (4)  -------------------------------------------
+--R                          2
+--R                         e x + d e
+--R                                                    Type: Expression(Integer)
+--E 2165
+
+--S 2166 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2166
+
+)clear all
+
+--S 2167 of 5341
+t0:=log(c*(a+b*x)^p)/(d+e*x)^3
+--R 
+--R
+--R                             p
+--R              log(c (b x + a) )
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 2167
+
+--S 2168 of 5341
+r0:=1/2*b*p/(e*(b*d-a*e)*(d+e*x))+1/2*b^2*p*log(a+b*x)/(e*(b*d-a*e)^2)-_
+   1/2*log(c*(a+b*x)^p)/(e*(d+e*x)^2)-1/2*b^2*p*log(d+e*x)/(e*(b*d-a*e)^2)
+--R 
+--R
+--R   (2)
+--R           2 2               2 2                p
+--R       (- a e  + 2a b d e - b d )log(c (b x + a) )
+--R     + 
+--R           2 2   2     2           2 2
+--R       (- b e p x  - 2b d e p x - b d p)log(e x + d)
+--R     + 
+--R         2 2   2     2           2 2                         2    2
+--R       (b e p x  + 2b d e p x + b d p)log(b x + a) + (- a b e  + b d e)p x
+--R     + 
+--R                     2 2
+--R       (- a b d e + b d )p
+--R  /
+--R          2 5           4     2 2 3  2      2   4         2 3     2 3 2
+--R       (2a e  - 4a b d e  + 2b d e )x  + (4a d e  - 8a b d e  + 4b d e )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       2a d e  - 4a b d e  + 2b d e
+--R                                                    Type: Expression(Integer)
+--E 2168
+
+--S 2169 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 2   2     2           2 2
+--R       (- b e p x  - 2b d e p x - b d p)log(e x + d)
+--R     + 
+--R         2 2   2     2              2 2
+--R       (b e p x  + 2b d e p x + (- a e  + 2a b d e)p)log(b x + a)
+--R     + 
+--R           2 2               2 2                  2    2
+--R       (- a e  + 2a b d e - b d )log(c) + (- a b e  + b d e)p x
+--R     + 
+--R                     2 2
+--R       (- a b d e + b d )p
+--R  /
+--R          2 5           4     2 2 3  2      2   4         2 3     2 3 2
+--R       (2a e  - 4a b d e  + 2b d e )x  + (4a d e  - 8a b d e  + 4b d e )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       2a d e  - 4a b d e  + 2b d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 2169
+
+--S 2170 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                       p
+--R        log(c (b x + a) ) - p log(b x + a) - log(c)
+--R   (4)  -------------------------------------------
+--R                     3 2       2      2
+--R                   2e x  + 4d e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 2170
+
+--S 2171 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2171
+
+)clear all
+
+--S 2172 of 5341
+t0:=log(c*(a+b*x)^p)/(d+e*x)^4
+--R 
+--R
+--R                                  p
+--R                   log(c (b x + a) )
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 2172
+
+--S 2173 of 5341
+r0:=1/6*b*p/(e*(b*d-a*e)*(d+e*x)^2)+1/3*b^2*p/(e*(b*d-a*e)^2*(d+e*x))+_
+   1/3*b^3*p*log(a+b*x)/(e*(b*d-a*e)^3)-1/3*log(c*(a+b*x)^p)/(e*(d+e*x)^3)-_
+   1/3*b^3*p*log(d+e*x)/(e*(b*d-a*e)^3)
+--R 
+--R
+--R   (2)
+--R            3 3     2     2       2 2      3 3                p
+--R       (- 2a e  + 6a b d e  - 6a b d e + 2b d )log(c (b x + a) )
+--R     + 
+--R          3 3   3     3   2   2     3 2          3 3
+--R       (2b e p x  + 6b d e p x  + 6b d e p x + 2b d p)log(e x + d)
+--R     + 
+--R            3 3   3     3   2   2     3 2          3 3
+--R       (- 2b e p x  - 6b d e p x  - 6b d e p x - 2b d p)log(b x + a)
+--R     + 
+--R            2 3     3   2    2       2   3       2   2     3 2
+--R       (2a b e  - 2b d e )p x  + (- a b e  + 6a b d e  - 5b d e)p x
+--R     + 
+--R           2     2       2 2      3 3
+--R       (- a b d e  + 4a b d e - 3b d )p
+--R  /
+--R          3 7      2     6        2 2 5     3 3 4  3
+--R       (6a e  - 18a b d e  + 18a b d e  - 6b d e )x
+--R     + 
+--R           3   6      2   2 5        2 3 4      3 4 3  2
+--R       (18a d e  - 54a b d e  + 54a b d e  - 18b d e )x
+--R     + 
+--R           3 2 5      2   3 4        2 4 3      3 5 2       3 3 4      2   4 3
+--R       (18a d e  - 54a b d e  + 54a b d e  - 18b d e )x + 6a d e  - 18a b d e
+--R     + 
+--R            2 5 2     3 6
+--R       18a b d e  - 6b d e
+--R                                                    Type: Expression(Integer)
+--E 2173
+
+--S 2174 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          3 3   3     3   2   2     3 2          3 3
+--R       (2b e p x  + 6b d e p x  + 6b d e p x + 2b d p)log(e x + d)
+--R     + 
+--R               3 3   3     3   2   2     3 2
+--R           - 2b e p x  - 6b d e p x  - 6b d e p x
+--R         + 
+--R                3 3     2     2       2 2
+--R           (- 2a e  + 6a b d e  - 6a b d e)p
+--R      *
+--R         log(b x + a)
+--R     + 
+--R            3 3     2     2       2 2      3 3               2 3     3   2    2
+--R       (- 2a e  + 6a b d e  - 6a b d e + 2b d )log(c) + (2a b e  - 2b d e )p x
+--R     + 
+--R           2   3       2   2     3 2            2     2       2 2      3 3
+--R       (- a b e  + 6a b d e  - 5b d e)p x + (- a b d e  + 4a b d e - 3b d )p
+--R  /
+--R          3 7      2     6        2 2 5     3 3 4  3
+--R       (6a e  - 18a b d e  + 18a b d e  - 6b d e )x
+--R     + 
+--R           3   6      2   2 5        2 3 4      3 4 3  2
+--R       (18a d e  - 54a b d e  + 54a b d e  - 18b d e )x
+--R     + 
+--R           3 2 5      2   3 4        2 4 3      3 5 2       3 3 4      2   4 3
+--R       (18a d e  - 54a b d e  + 54a b d e  - 18b d e )x + 6a d e  - 18a b d e
+--R     + 
+--R            2 5 2     3 6
+--R       18a b d e  - 6b d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 2174
+
+--S 2175 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                       p
+--R        log(c (b x + a) ) - p log(b x + a) - log(c)
+--R   (4)  -------------------------------------------
+--R                4 3       3 2     2 2      3
+--R              3e x  + 9d e x  + 9d e x + 3d e
+--R                                                    Type: Expression(Integer)
+--E 2175
+
+--S 2176 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2176
+
+)clear all
+
+--S 2177 of 5341
+t0:=(d+e*x)^m*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R                 m          2     p
+--R   (1)  (e x + d) log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2177
+
+--S 2178 of 5341
+--r0:=(d+e*x)^(1+m)*log(c*(a+b*x^2)^p)/(e*(1+m))+p*(d+e*x)^(2+m)*_
+--  hypergeometric(1,2+m,3+m,(d+e*x)*sqrt(b)/(-e*sqrt(-a)+d*sqrt(b)))*_
+--  sqrt(b)/(e*(1+m)*(2+m)*(-e*sqrt(-a)+d*sqrt(b)))+p*(d+e*x)^(2+m)*_
+--  hypergeometric(1,2+m,3+m,(d+e*x)*sqrt(b)/(e*sqrt(-a)+d*sqrt(b)))*_
+--  sqrt(b)/(e*(1+m)*(2+m)*(e*sqrt(-a)+d*sqrt(b)))
+--E 2178
+
+--S 2179 of 5341
+--a0:=integrate(t0,x)
+--E 2179
+
+--S 2180 of 5341
+--m0:=a0-r0
+--E 2180
+
+--S 2181 of 5341
+--d0:=D(m0,x)
+--E 2181
+
+)clear all
+
+--S 2182 of 5341
+t0:=(d+e*x)^3*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R          3 3       2 2     2       3           2     p
+--R   (1)  (e x  + 3d e x  + 3d e x + d )log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2182
+
+--S 2183 of 5341
+r0:=-2*d*(b*d^2-a*e^2)*p*x/b-1/4*e*(6*b*d^2-a*e^2)*p*x^2/b-2/3*d*e^2*p*x^3-_
+   1/8*e^3*p*x^4-1/4*(b^2*d^4-6*a*b*d^2*e^2+a^2*e^4)*p*log(a+b*x^2)/(b^2*e)+_
+   1/4*(d+e*x)^4*log(c*(a+b*x^2)^p)/e+2*d*(b*d^2-a*e^2)*p*atan(x*sqrt(b)/_
+   sqrt(a))*sqrt(a)/b^(3/2)
+--R 
+--R
+--R   (2)
+--R            2 4 4      2   3 3      2 2 2 2      2 3        2 4  +-+
+--R         (6b e x  + 24b d e x  + 36b d e x  + 24b d e x + 6b d )\|b
+--R      *
+--R                   2     p
+--R         log(c (b x  + a) )
+--R     + 
+--R                                           +-+
+--R                   3      2 3    +-+     x\|b
+--R       (- 48a b d e  + 48b d e)p\|a atan(-----)
+--R                                           +-+
+--R                                          \|a
+--R     + 
+--R                2 4          2 2     2 4          2          2 4   4
+--R           (- 6a e  + 36a b d e  - 6b d )p log(b x  + a) - 3b e p x
+--R         + 
+--R              2   3   3          4      2 2 2    2             3      2 3
+--R         - 16b d e p x  + (6a b e  - 36b d e )p x  + (48a b d e  - 48b d e)p x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R        2  +-+
+--R     24b e\|b
+--R                                                    Type: Expression(Integer)
+--E 2183
+
+--S 2184 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                +---+
+--R                                                |  a       2
+--R                                  +---+    2b x |- -  + b x  - a
+--R                     2      2 3   |  a         \|  b
+--R         (- 24a b d e  + 24b d )p |- - log(---------------------)
+--R                                 \|  b               2
+--R                                                  b x  + a
+--R       + 
+--R               2 3   4      2   2   3      2 2     2      2 3
+--R             6b e p x  + 24b d e p x  + 36b d e p x  + 24b d p x
+--R           + 
+--R                  2 3          2
+--R             (- 6a e  + 36a b d e)p
+--R        *
+--R                  2
+--R           log(b x  + a)
+--R       + 
+--R            2 3 4      2   2 3      2 2   2      2 3             2 3   4
+--R         (6b e x  + 24b d e x  + 36b d e x  + 24b d x)log(c) - 3b e p x
+--R       + 
+--R              2   2   3          3      2 2     2             2      2 3
+--R         - 16b d e p x  + (6a b e  - 36b d e)p x  + (48a b d e  - 48b d )p x
+--R    /
+--R          2
+--R       24b
+--R     ,
+--R
+--R                                         +-+
+--R                                         |a
+--R                                +-+      |-
+--R                   2      2 3   |a      \|b
+--R         (48a b d e  - 48b d )p |- atan(----)
+--R                               \|b        x
+--R       + 
+--R               2 3   4      2   2   3      2 2     2      2 3
+--R             6b e p x  + 24b d e p x  + 36b d e p x  + 24b d p x
+--R           + 
+--R                  2 3          2
+--R             (- 6a e  + 36a b d e)p
+--R        *
+--R                  2
+--R           log(b x  + a)
+--R       + 
+--R            2 3 4      2   2 3      2 2   2      2 3             2 3   4
+--R         (6b e x  + 24b d e x  + 36b d e x  + 24b d x)log(c) - 3b e p x
+--R       + 
+--R              2   2   3          3      2 2     2             2      2 3
+--R         - 16b d e p x  + (6a b e  - 36b d e)p x  + (48a b d e  - 48b d )p x
+--R    /
+--R          2
+--R       24b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2184
+
+--S 2185 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                               +---+
+--R                                               |  a       2
+--R                             +---+        2b x |- -  + b x  - a
+--R                3       3    |  a  +-+        \|  b
+--R       (- 4a d e  + 4b d e)p |- - \|b log(---------------------)
+--R                            \|  b                   2
+--R                                                 b x  + a
+--R     + 
+--R               4 4         3 3       2 2 2       3         4  +-+
+--R         (- b e x  - 4b d e x  - 6b d e x  - 4b d e x - b d )\|b
+--R      *
+--R                   2     p
+--R         log(c (b x  + a) )
+--R     + 
+--R                                     +-+
+--R              3       3    +-+     x\|b
+--R       (8a d e  - 8b d e)p\|a atan(-----)
+--R                                     +-+
+--R                                    \|a
+--R     + 
+--R                 4   4         3   3       2 2   2       3           4
+--R             (b e p x  + 4b d e p x  + 6b d e p x  + 4b d e p x + b d p)
+--R          *
+--R                    2
+--R             log(b x  + a)
+--R         + 
+--R               4 4         3 3       2 2 2       3
+--R           (b e x  + 4b d e x  + 6b d e x  + 4b d e x)log(c)
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R          +-+
+--R     4b e\|b
+--R                                                    Type: Expression(Integer)
+--E 2185
+
+--S 2186 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2186
+
+--S 2187 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R               4 4         3 3       2 2 2       3         4  +-+
+--R         (- b e x  - 4b d e x  - 6b d e x  - 4b d e x - b d )\|b
+--R      *
+--R                   2     p
+--R         log(c (b x  + a) )
+--R     + 
+--R                                     +-+
+--R              3       3    +-+     x\|b
+--R       (8a d e  - 8b d e)p\|a atan(-----)
+--R                                     +-+
+--R                                    \|a
+--R     + 
+--R                                        +-+
+--R                                        |a
+--R                           +-+          |-
+--R              3       3    |a  +-+     \|b
+--R       (8a d e  - 8b d e)p |- \|b atan(----)
+--R                          \|b            x
+--R     + 
+--R                 4   4         3   3       2 2   2       3           4
+--R             (b e p x  + 4b d e p x  + 6b d e p x  + 4b d e p x + b d p)
+--R          *
+--R                    2
+--R             log(b x  + a)
+--R         + 
+--R               4 4         3 3       2 2 2       3
+--R           (b e x  + 4b d e x  + 6b d e x  + 4b d e x)log(c)
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R          +-+
+--R     4b e\|b
+--R                                                    Type: Expression(Integer)
+--E 2187
+
+--S 2188 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2188
+
+)clear all
+
+--S 2189 of 5341
+t0:=(d+e*x)^2*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R          2 2             2           2     p
+--R   (1)  (e x  + 2d e x + d )log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2189
+
+--S 2190 of 5341
+r0:=-2/3*(3*b*d^2-a*e^2)*p*x/b-d*e*p*x^2-2/9*e^2*p*x^3-1/3*d*(b*d^2-_
+   3*a*e^2)*p*log(a+b*x^2)/(b*e)+1/3*(d+e*x)^3*log(c*(a+b*x^2)^p)/e+_
+   2/3*(3*b*d^2-a*e^2)*p*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/b^(3/2)
+--R 
+--R
+--R   (2)
+--R            3 3         2 2       2          3  +-+          2     p
+--R       (3b e x  + 9b d e x  + 9b d e x + 3b d )\|b log(c (b x  + a) )
+--R     + 
+--R                                      +-+
+--R              3        2    +-+     x\|b
+--R       (- 6a e  + 18b d e)p\|a atan(-----)
+--R                                      +-+
+--R                                     \|a
+--R     + 
+--R                  2       3          2            3   3         2   2
+--R           (9a d e  - 3b d )p log(b x  + a) - 2b e p x  - 9b d e p x
+--R         + 
+--R                3        2
+--R           (6a e  - 18b d e)p x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R          +-+
+--R     9b e\|b
+--R                                                    Type: Expression(Integer)
+--E 2190
+
+--S 2191 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                          +---+
+--R                                          |  a       2
+--R                            +---+    2b x |- -  + b x  - a
+--R                2       2   |  a         \|  b
+--R         (- 3a e  + 9b d )p |- - log(---------------------)
+--R                           \|  b               2
+--R                                            b x  + a
+--R       + 
+--R              2   3             2       2                      2
+--R         (3b e p x  + 9b d e p x  + 9b d p x + 9a d e p)log(b x  + a)
+--R       + 
+--R              2 3           2       2               2   3             2
+--R         (3b e x  + 9b d e x  + 9b d x)log(c) - 2b e p x  - 9b d e p x
+--R       + 
+--R              2        2
+--R         (6a e  - 18b d )p x
+--R    /
+--R       9b
+--R     ,
+--R
+--R                                    +-+
+--R                                    |a
+--R                           +-+      |-
+--R              2        2   |a      \|b
+--R         (6a e  - 18b d )p |- atan(----)
+--R                          \|b        x
+--R       + 
+--R              2   3             2       2                      2
+--R         (3b e p x  + 9b d e p x  + 9b d p x + 9a d e p)log(b x  + a)
+--R       + 
+--R              2 3           2       2               2   3             2
+--R         (3b e x  + 9b d e x  + 9b d x)log(c) - 2b e p x  - 9b d e p x
+--R       + 
+--R              2        2
+--R         (6a e  - 18b d )p x
+--R    /
+--R       9b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2191
+
+--S 2192 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                            +---+
+--R                                            |  a       2
+--R                          +---+        2b x |- -  + b x  - a
+--R             3       2    |  a  +-+        \|  b
+--R       (- a e  + 3b d e)p |- - \|b log(---------------------)
+--R                         \|  b                   2
+--R                                              b x  + a
+--R     + 
+--R             3 3         2 2       2         3  +-+          2     p
+--R       (- b e x  - 3b d e x  - 3b d e x - b d )\|b log(c (b x  + a) )
+--R     + 
+--R                                   +-+
+--R            3       2    +-+     x\|b
+--R       (2a e  - 6b d e)p\|a atan(-----)
+--R                                   +-+
+--R                                  \|a
+--R     + 
+--R               3   3         2   2       2           3         2
+--R           (b e p x  + 3b d e p x  + 3b d e p x + b d p)log(b x  + a)
+--R         + 
+--R               3 3         2 2       2
+--R           (b e x  + 3b d e x  + 3b d e x)log(c)
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R          +-+
+--R     3b e\|b
+--R                                                    Type: Expression(Integer)
+--E 2192
+
+--S 2193 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2193
+
+--S 2194 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             3 3         2 2       2         3  +-+          2     p
+--R       (- b e x  - 3b d e x  - 3b d e x - b d )\|b log(c (b x  + a) )
+--R     + 
+--R                                                                         +-+
+--R                                                                         |a
+--R                                   +-+                      +-+          |-
+--R            3       2    +-+     x\|b          3       2    |a  +-+     \|b
+--R       (2a e  - 6b d e)p\|a atan(-----) + (2a e  - 6b d e)p |- \|b atan(----)
+--R                                   +-+                     \|b            x
+--R                                  \|a
+--R     + 
+--R               3   3         2   2       2           3         2
+--R           (b e p x  + 3b d e p x  + 3b d e p x + b d p)log(b x  + a)
+--R         + 
+--R               3 3         2 2       2
+--R           (b e x  + 3b d e x  + 3b d e x)log(c)
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R          +-+
+--R     3b e\|b
+--R                                                    Type: Expression(Integer)
+--E 2194
+
+--S 2195 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2195
+
+)clear all
+
+--S 2196 of 5341
+t0:=(d+e*x)*log(c*(a+b*x^2)^p)
+--R 
+--R
+--R                           2     p
+--R   (1)  (e x + d)log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2196
+
+--S 2197 of 5341
+r0:=-2*d*p*x-1/2*e*p*x^2-1/2*(b*d^2-a*e^2)*p*log(a+b*x^2)/(b*e)+_
+   1/2*(d+e*x)^2*log(c*(a+b*x^2)^p)/e+2*d*p*atan(x*sqrt(b)/sqrt(a))*_
+   sqrt(a)/sqrt(b)
+--R 
+--R
+--R   (2)
+--R           2 2                 2  +-+          2     p
+--R       (b e x  + 2b d e x + b d )\|b log(c (b x  + a) )
+--R     + 
+--R                          +-+
+--R                +-+     x\|b
+--R       4b d e p\|a atan(-----)
+--R                          +-+
+--R                         \|a
+--R     + 
+--R            2      2          2           2   2               +-+
+--R       ((a e  - b d )p log(b x  + a) - b e p x  - 4b d e p x)\|b
+--R  /
+--R          +-+
+--R     2b e\|b
+--R                                                    Type: Expression(Integer)
+--E 2197
+
+--S 2198 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                              +---+
+--R                              |  a       2
+--R                +---+    2b x |- -  + b x  - a
+--R                |  a         \|  b
+--R         2b d p |- - log(---------------------)
+--R               \|  b               2
+--R                                b x  + a
+--R       + 
+--R                 2                           2              2
+--R         (b e p x  + 2b d p x + a e p)log(b x  + a) + (b e x  + 2b d x)log(c)
+--R       + 
+--R                  2
+--R         - b e p x  - 4b d p x
+--R    /
+--R       2b
+--R     ,
+--R
+--R                           +-+
+--R                           |a
+--R                  +-+      |-
+--R                  |a      \|b             2                           2
+--R         - 4b d p |- atan(----) + (b e p x  + 2b d p x + a e p)log(b x  + a)
+--R                 \|b        x
+--R       + 
+--R               2                          2
+--R         (b e x  + 2b d x)log(c) - b e p x  - 4b d p x
+--R    /
+--R       2b
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2198
+
+--S 2199 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                +---+
+--R                                |  a       2
+--R              +---+        2b x |- -  + b x  - a
+--R              |  a  +-+        \|  b
+--R       2d e p |- - \|b log(---------------------)
+--R             \|  b                   2
+--R                                  b x  + a
+--R     + 
+--R                                                                       +-+
+--R           2 2             2  +-+          2     p           +-+     x\|b
+--R       (- e x  - 2d e x - d )\|b log(c (b x  + a) ) - 4d e p\|a atan(-----)
+--R                                                                       +-+
+--R                                                                      \|a
+--R     + 
+--R          2   2               2         2          2 2                  +-+
+--R       ((e p x  + 2d e p x + d p)log(b x  + a) + (e x  + 2d e x)log(c))\|b
+--R  /
+--R        +-+
+--R     2e\|b
+--R                                                    Type: Expression(Integer)
+--E 2199
+
+--S 2200 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2200
+
+--S 2201 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                       +-+
+--R           2 2             2  +-+          2     p           +-+     x\|b
+--R       (- e x  - 2d e x - d )\|b log(c (b x  + a) ) - 4d e p\|a atan(-----)
+--R                                                                       +-+
+--R                                                                      \|a
+--R     + 
+--R                             +-+
+--R                             |a
+--R                +-+          |-
+--R                |a  +-+     \|b
+--R       - 4d e p |- \|b atan(----)
+--R               \|b            x
+--R     + 
+--R          2   2               2         2          2 2                  +-+
+--R       ((e p x  + 2d e p x + d p)log(b x  + a) + (e x  + 2d e x)log(c))\|b
+--R  /
+--R        +-+
+--R     2e\|b
+--R                                                    Type: Expression(Integer)
+--E 2201
+
+--S 2202 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2202
+
+)clear all
+
+--S 2203 of 5341
+t0:=log(c*(a+b*x^2)^p)
+--R 
+--R
+--R                  2     p
+--R   (1)  log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2203
+
+--S 2204 of 5341
+r0:=-2*p*x+x*log(c*(a+b*x^2)^p)+2*p*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/sqrt(b)
+--R 
+--R
+--R                                               +-+
+--R          +-+          2     p       +-+     x\|b          +-+
+--R        x\|b log(c (b x  + a) ) + 2p\|a atan(-----) - 2p x\|b
+--R                                               +-+
+--R                                              \|a
+--R   (2)  ------------------------------------------------------
+--R                                  +-+
+--R                                 \|b
+--R                                                    Type: Expression(Integer)
+--E 2204
+
+--S 2205 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +---+
+--R                    |  a       2
+--R      +---+    2b x |- -  + b x  - a
+--R      |  a         \|  b                           2
+--R   [p |- - log(---------------------) + p x log(b x  + a) + x log(c) - 2p x,
+--R     \|  b               2
+--R                      b x  + a
+--R                  +-+
+--R                  |a
+--R         +-+      |-
+--R         |a      \|b                2
+--R    - 2p |- atan(----) + p x log(b x  + a) + x log(c) - 2p x]
+--R        \|b        x
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2205
+
+--S 2206 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           +---+
+--R                           |  a       2
+--R         +---+        2b x |- -  + b x  - a
+--R         |  a  +-+        \|  b                  +-+          2     p
+--R       p |- - \|b log(---------------------) - x\|b log(c (b x  + a) )
+--R        \|  b                   2
+--R                             b x  + a
+--R     + 
+--R                      +-+
+--R            +-+     x\|b                 2                  +-+
+--R       - 2p\|a atan(-----) + (p x log(b x  + a) + x log(c))\|b
+--R                      +-+
+--R                     \|a
+--R  /
+--R      +-+
+--R     \|b
+--R                                                    Type: Expression(Integer)
+--E 2206
+
+--S 2207 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2207
+
+--S 2208 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                       +-+
+--R                                                                       |a
+--R                                                +-+       +-+          |-
+--R           +-+          2     p       +-+     x\|b        |a  +-+     \|b
+--R       - x\|b log(c (b x  + a) ) - 2p\|a atan(-----) - 2p |- \|b atan(----)
+--R                                                +-+      \|b            x
+--R                                               \|a
+--R     + 
+--R                   2                  +-+
+--R       (p x log(b x  + a) + x log(c))\|b
+--R  /
+--R      +-+
+--R     \|b
+--R                                                    Type: Expression(Integer)
+--E 2208
+
+--S 2209 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2209
+
+)clear all
+
+--S 2210 of 5341
+t0:=log(c*(a+b*x^2)^p)/(d+e*x)
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2210
+
+--S 2211 of 5341
+--r0:=log(d+e*x)*log(c*(a+b*x^2)^p)/e-p*log(d+e*x)*log(e*(sqrt(-a)-_
+--  x*sqrt(b))/(e*sqrt(-a)+d*sqrt(b)))/e-p*log(d+e*x)*log(-e*(sqrt(-a)+_
+--  x*sqrt(b))/(-e*sqrt(-a)+d*sqrt(b)))/e-p*polylog(2,(d+e*x)*sqrt(b)/_
+--  (-e*sqrt(-a)+d*sqrt(b)))/e-p*polylog(2,(d+e*x)*sqrt(b)/(e*sqrt(-a)+_
+--  d*sqrt(b)))/e
+--E 2211
+
+--S 2212 of 5341
+--a0:=integrate(t0,x)
+--E 2212
+
+--S 2213 of 5341
+--m0:=a0-r0
+--E 2213
+
+--S 2214 of 5341
+--d0:=D(m0,x)
+--E 2214
+
+)clear all
+
+--S 2215 of 5341
+t0:=log(c*(a+b*x^2)^p)/(d+e*x)^2
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 2215
+
+--S 2216 of 5341
+r0:=-2*b*d*p*log(d+e*x)/(e*(b*d^2+a*e^2))+b*d*p*log(a+b*x^2)/(e*(b*d^2+_
+   a*e^2))-log(c*(a+b*x^2)^p)/(e*(d+e*x))+2*p*atan(x*sqrt(b)/sqrt(a))*_
+   sqrt(a)*sqrt(b)/(b*d^2+a*e^2)
+--R 
+--R
+--R   (2)
+--R                                                                           +-+
+--R             2      2           2     p       2              +-+ +-+     x\|b
+--R       (- a e  - b d )log(c (b x  + a) ) + (2e p x + 2d e p)\|a \|b atan(-----)
+--R                                                                           +-+
+--R                                                                          \|a
+--R     + 
+--R                       2         2                            2
+--R       (b d e p x + b d p)log(b x  + a) + (- 2b d e p x - 2b d p)log(e x + d)
+--R  /
+--R         4      2 2          3      3
+--R     (a e  + b d e )x + a d e  + b d e
+--R                                                    Type: Expression(Integer)
+--E 2216
+
+--S 2217 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                       +-----+      2
+--R           2             +-----+    2x\|- a b  + b x  - a
+--R         (e p x + d e p)\|- a b log(---------------------)
+--R                                              2
+--R                                           b x  + a
+--R       + 
+--R                         2         2                            2
+--R         (b d e p x - a e p)log(b x  + a) + (- 2b d e p x - 2b d p)log(e x + d)
+--R       + 
+--R               2      2
+--R         (- a e  - b d )log(c)
+--R    /
+--R           4      2 2          3      3
+--R       (a e  + b d e )x + a d e  + b d e
+--R     ,
+--R
+--R                                        +---+
+--R              2              +---+     \|a b
+--R         (- 2e p x - 2d e p)\|a b atan(------)
+--R                                         b x
+--R       + 
+--R                         2         2                            2
+--R         (b d e p x - a e p)log(b x  + a) + (- 2b d e p x - 2b d p)log(e x + d)
+--R       + 
+--R               2      2
+--R         (- a e  - b d )log(c)
+--R    /
+--R           4      2 2          3      3
+--R       (a e  + b d e )x + a d e  + b d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2217
+
+--S 2218 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                     +-----+      2
+--R         2             +-----+    2x\|- a b  + b x  - a
+--R       (e p x + d e p)\|- a b log(---------------------)
+--R                                            2
+--R                                         b x  + a
+--R     + 
+--R                                                                           +-+
+--R           2      2           2     p         2              +-+ +-+     x\|b
+--R       (a e  + b d )log(c (b x  + a) ) + (- 2e p x - 2d e p)\|a \|b atan(-----)
+--R                                                                           +-+
+--R                                                                          \|a
+--R     + 
+--R             2      2          2              2      2
+--R       (- a e  - b d )p log(b x  + a) + (- a e  - b d )log(c)
+--R  /
+--R         4      2 2          3      3
+--R     (a e  + b d e )x + a d e  + b d e
+--R                                                    Type: Expression(Integer)
+--E 2218
+
+--S 2219 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2219
+
+--S 2220 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                                                        +---+
+--R           2      2           2     p         2              +---+     \|a b
+--R       (a e  + b d )log(c (b x  + a) ) + (- 2e p x - 2d e p)\|a b atan(------)
+--R                                                                         b x
+--R     + 
+--R                                         +-+
+--R            2              +-+ +-+     x\|b           2      2          2
+--R       (- 2e p x - 2d e p)\|a \|b atan(-----) + (- a e  - b d )p log(b x  + a)
+--R                                         +-+
+--R                                        \|a
+--R     + 
+--R             2      2
+--R       (- a e  - b d )log(c)
+--R  /
+--R         4      2 2          3      3
+--R     (a e  + b d e )x + a d e  + b d e
+--R                                                    Type: Expression(Integer)
+--E 2220
+
+--S 2221 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2221
+
+)clear all
+
+--S 2222 of 5341
+t0:=log(c*(a+b*x^2)^p)/(d+e*x)^3
+--R 
+--R
+--R                       2     p
+--R             log(c (b x  + a) )
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 2222
+
+--S 2223 of 5341
+r0:=b*d*p/(e*(b*d^2+a*e^2)*(d+e*x))-b*(b*d^2-a*e^2)*p*log(d+e*x)/(e*(b*d^2+_
+   a*e^2)^2)+1/2*b*(b*d^2-a*e^2)*p*log(a+b*x^2)/(e*(b*d^2+a*e^2)^2)-_
+   1/2*log(c*(a+b*x^2)^p)/(e*(d+e*x)^2)+2*b^(3/2)*d*p*atan(x*sqrt(b)/_
+   sqrt(a))*sqrt(a)/(b*d^2+a*e^2)^2
+--R 
+--R
+--R   (2)
+--R           2 4         2 2    2 4           2     p
+--R       (- a e  - 2a b d e  - b d )log(c (b x  + a) )
+--R     + 
+--R                                                           +-+
+--R              3   2       2 2          3     +-+ +-+     x\|b
+--R       (4b d e p x  + 8b d e p x + 4b d e p)\|a \|b atan(-----)
+--R                                                           +-+
+--R                                                          \|a
+--R     + 
+--R                   4    2 2 2    2              3     2 3
+--R           (- a b e  + b d e )p x  + (- 2a b d e  + 2b d e)p x
+--R         + 
+--R                   2 2    2 4
+--R           (- a b d e  + b d )p
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R                  4     2 2 2    2            3     2 3
+--R           (2a b e  - 2b d e )p x  + (4a b d e  - 4b d e)p x
+--R         + 
+--R                  2 2     2 4
+--R           (2a b d e  - 2b d )p
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                3     2 3               2 2     2 4
+--R       (2a b d e  + 2b d e)p x + (2a b d e  + 2b d )p
+--R  /
+--R          2 7         2 5     2 4 3  2      2   6         3 4     2 5 2
+--R       (2a e  + 4a b d e  + 2b d e )x  + (4a d e  + 8a b d e  + 4b d e )x
+--R     + 
+--R         2 2 5         4 3     2 6
+--R       2a d e  + 4a b d e  + 2b d e
+--R                                                    Type: Expression(Integer)
+--E 2223
+
+--S 2224 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                             +-----+      2
+--R                3   2       2 2          3     +-----+    2x\|- a b  + b x  - a
+--R         (2b d e p x  + 4b d e p x + 2b d e p)\|- a b log(---------------------)
+--R                                                                    2
+--R                                                                 b x  + a
+--R       + 
+--R                     4    2 2 2    2              3     2 3
+--R             (- a b e  + b d e )p x  + (- 2a b d e  + 2b d e)p x
+--R           + 
+--R                 2 4         2 2
+--R             (- a e  - 3a b d e )p
+--R        *
+--R                  2
+--R           log(b x  + a)
+--R       + 
+--R                    4     2 2 2    2            3     2 3
+--R             (2a b e  - 2b d e )p x  + (4a b d e  - 4b d e)p x
+--R           + 
+--R                    2 2     2 4
+--R             (2a b d e  - 2b d )p
+--R        *
+--R           log(e x + d)
+--R       + 
+--R             2 4         2 2    2 4                   3     2 3
+--R         (- a e  - 2a b d e  - b d )log(c) + (2a b d e  + 2b d e)p x
+--R       + 
+--R                2 2     2 4
+--R         (2a b d e  + 2b d )p
+--R    /
+--R            2 7         2 5     2 4 3  2      2   6         3 4     2 5 2
+--R         (2a e  + 4a b d e  + 2b d e )x  + (4a d e  + 8a b d e  + 4b d e )x
+--R       + 
+--R           2 2 5         4 3     2 6
+--R         2a d e  + 4a b d e  + 2b d e
+--R     ,
+--R
+--R                                                            +---+
+--R                  3   2       2 2          3     +---+     \|a b
+--R         (- 4b d e p x  - 8b d e p x - 4b d e p)\|a b atan(------)
+--R                                                             b x
+--R       + 
+--R                     4    2 2 2    2              3     2 3
+--R             (- a b e  + b d e )p x  + (- 2a b d e  + 2b d e)p x
+--R           + 
+--R                 2 4         2 2
+--R             (- a e  - 3a b d e )p
+--R        *
+--R                  2
+--R           log(b x  + a)
+--R       + 
+--R                    4     2 2 2    2            3     2 3
+--R             (2a b e  - 2b d e )p x  + (4a b d e  - 4b d e)p x
+--R           + 
+--R                    2 2     2 4
+--R             (2a b d e  - 2b d )p
+--R        *
+--R           log(e x + d)
+--R       + 
+--R             2 4         2 2    2 4                   3     2 3
+--R         (- a e  - 2a b d e  - b d )log(c) + (2a b d e  + 2b d e)p x
+--R       + 
+--R                2 2     2 4
+--R         (2a b d e  + 2b d )p
+--R    /
+--R            2 7         2 5     2 4 3  2      2   6         3 4     2 5 2
+--R         (2a e  + 4a b d e  + 2b d e )x  + (4a d e  + 8a b d e  + 4b d e )x
+--R       + 
+--R           2 2 5         4 3     2 6
+--R         2a d e  + 4a b d e  + 2b d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 2224
+
+--S 2225 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                                           +-----+      2
+--R              3   2       2 2          3     +-----+    2x\|- a b  + b x  - a
+--R       (2b d e p x  + 4b d e p x + 2b d e p)\|- a b log(---------------------)
+--R                                                                  2
+--R                                                               b x  + a
+--R     + 
+--R         2 4         2 2    2 4           2     p
+--R       (a e  + 2a b d e  + b d )log(c (b x  + a) )
+--R     + 
+--R                                                             +-+
+--R                3   2       2 2          3     +-+ +-+     x\|b
+--R       (- 4b d e p x  - 8b d e p x - 4b d e p)\|a \|b atan(-----)
+--R                                                             +-+
+--R                                                            \|a
+--R     + 
+--R           2 4         2 2    2 4          2
+--R       (- a e  - 2a b d e  - b d )p log(b x  + a)
+--R     + 
+--R           2 4         2 2    2 4
+--R       (- a e  - 2a b d e  - b d )log(c)
+--R  /
+--R          2 7         2 5     2 4 3  2      2   6         3 4     2 5 2
+--R       (2a e  + 4a b d e  + 2b d e )x  + (4a d e  + 8a b d e  + 4b d e )x
+--R     + 
+--R         2 2 5         4 3     2 6
+--R       2a d e  + 4a b d e  + 2b d e
+--R                                                    Type: Expression(Integer)
+--E 2225
+
+--S 2226 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2226
+
+--S 2227 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R         2 4         2 2    2 4           2     p
+--R       (a e  + 2a b d e  + b d )log(c (b x  + a) )
+--R     + 
+--R                                                          +---+
+--R                3   2       2 2          3     +---+     \|a b
+--R       (- 4b d e p x  - 8b d e p x - 4b d e p)\|a b atan(------)
+--R                                                           b x
+--R     + 
+--R                                                             +-+
+--R                3   2       2 2          3     +-+ +-+     x\|b
+--R       (- 4b d e p x  - 8b d e p x - 4b d e p)\|a \|b atan(-----)
+--R                                                             +-+
+--R                                                            \|a
+--R     + 
+--R           2 4         2 2    2 4          2
+--R       (- a e  - 2a b d e  - b d )p log(b x  + a)
+--R     + 
+--R           2 4         2 2    2 4
+--R       (- a e  - 2a b d e  - b d )log(c)
+--R  /
+--R          2 7         2 5     2 4 3  2      2   6         3 4     2 5 2
+--R       (2a e  + 4a b d e  + 2b d e )x  + (4a d e  + 8a b d e  + 4b d e )x
+--R     + 
+--R         2 2 5         4 3     2 6
+--R       2a d e  + 4a b d e  + 2b d e
+--R                                                    Type: Expression(Integer)
+--E 2227
+
+--S 2228 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 2228
+
+)clear all
+
+--S 2229 of 5341
+t0:=(d+e*x)^m*log(c*(a+b*x^3)^p)
+--R 
+--R
+--R                 m          3     p
+--R   (1)  (e x + d) log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2229
+
+--S 2230 of 5341
+--r0:=b^(1/3)*p*(d+e*x)^(2+m)*hypergeometric(1,2+m,3+m,b^(1/3)*(d+e*x)/_
+--  (b^(1/3)*d-a^(1/3)*e))/(e*(b^(1/3)*d-a^(1/3)*e)*(1+m)*(2+m))+b^(1/3)*_
+--  p*(d+e*x)^(2+m)*hypergeometric(1,2+m,3+m,b^(1/3)*(d+e*x)/(b^(1/3)*d+_
+--  (-1)^(1/3)*a^(1/3)*e))/(e*(b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e)*(1+m)*_
+--  (2+m))+b^(1/3)*p*(d+e*x)^(2+m)*hypergeometric(1,2+m,3+m,b^(1/3)*_
+--  (d+e*x)/(b^(1/3)*d-(-1)^(2/3)*a^(1/3)*e))/(e*(b^(1/3)*d-(-1)^(2/3)*_
+--  a^(1/3)*e)*(1+m)*(2+m))+(d+e*x)^(1+m)*log(c*(a+b*x^3)^p)/(e*(1+m))
+--E 2230
+
+--S 2231 of 5341
+--a0:=integrate(t0,x)
+--E 2231
+
+--S 2232 of 5341
+--m0:=a0-r0
+--E 2232
+
+--S 2233 of 5341
+--d0:=D(m0,x)
+--E 2233
+
+)clear all
+
+--S 2234 of 5341
+t0:=(d+e*x)^3*log(c*(a+b*x^3)^p)
+--R 
+--R
+--R          3 3       2 2     2       3           3     p
+--R   (1)  (e x  + 3d e x  + 3d e x + d )log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2234
+
+--S 2235 of 5341
+r0:=-3/4*(4*b*d^3-a*e^3)*p*x/b-9/4*d^2*e*p*x^2-d*e^2*p*x^3-3/16*e^3*p*x^4+_
+   1/4*a^(1/3)*(4*b*d^3-6*a^(1/3)*b^(2/3)*d^2*e-a*e^3)*p*log(a^(1/3)+_
+   b^(1/3)*x)/b^(4/3)-1/8*a^(1/3)*(4*b*d^3-6*a^(1/3)*b^(2/3)*d^2*e-a*e^3)*_
+   p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/b^(4/3)-1/4*d*(b*d^3-_
+   4*a*e^3)*p*log(a+b*x^3)/(b*e)+1/4*(d+e*x)^4*log(c*(a+b*x^3)^p)/e-_
+   1/4*a^(1/3)*(4*b*d^3+6*a^(1/3)*b^(2/3)*d^2*e-a*e^3)*p*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/b^(4/3)
+--R 
+--R
+--R   (2)
+--R             2 2  3+-+2 3+-+2       4       3   3+-+
+--R         (12d e p \|a   \|b  + (2a e  - 8b d e)p\|a )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             2 2  3+-+2 3+-+2         4        3   3+-+      3+-+   3+-+
+--R       (- 24d e p \|a   \|b  + (- 4a e  + 16b d e)p\|a )log(x\|b  + \|a )
+--R     + 
+--R              4 4          3 3        2 2 2        3          4 3+-+
+--R         (4b e x  + 16b d e x  + 24b d e x  + 16b d e x + 4b d )\|b
+--R      *
+--R                   3     p
+--R         log(c (b x  + a) )
+--R     + 
+--R                                                                    3+-+   3+-+
+--R           2 2  +-+3+-+2 3+-+2         4        3    +-+3+-+      2x\|b  - \|a
+--R       (24d e p\|3 \|a   \|b  + (- 4a e  + 16b d e)p\|3 \|a )atan(-------------)
+--R                                                                      +-+3+-+
+--R                                                                     \|3 \|a
+--R     + 
+--R                   3       4          3            4   4          3   3
+--R           (16a d e  - 4b d )p log(b x  + a) - 3b e p x  - 16b d e p x
+--R         + 
+--R                  2 2   2         4        3
+--R           - 36b d e p x  + (12a e  - 48b d e)p x
+--R      *
+--R         3+-+
+--R         \|b
+--R  /
+--R          3+-+
+--R     16b e\|b
+--R                                                    Type: Expression(Integer)
+--E 2235
+
+--S 2236 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              +-------------------------------------------------------+
+--R              |    2    2            2            2 2 4          5   2
+--R              |- 6b %%U0  + 12a b d e p %%U0 + (3a d e  - 36a b d e)p
+--R           8b |-------------------------------------------------------
+--R              |                            2
+--R             \|                          2b
+--R         + 
+--R                              2
+--R           - 8b %%U0 + 24a d e p
+--R      *
+--R         log
+--R                    3 2              2   6        2 3 3      3 6
+--R                (48b d e %%U0 + (- 2a b e  - 32a b d e  - 32b d )p)
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |    2    2            2            2 2 4          5   2
+--R                 |- 6b %%U0  + 12a b d e p %%U0 + (3a d e  - 36a b d e)p
+--R                 |-------------------------------------------------------
+--R                 |                            2
+--R                \|                          2b
+--R            + 
+--R                 3 2      2      2   6         2 3 3      3 6
+--R              48b d e %%U0  + (2a b e  - 112a b d e  + 32b d )p %%U0
+--R            + 
+--R                3 9      2   3 6         2 6 3      3 9  2
+--R              (a e  - 12a b d e  - 168a b d e  - 64b d )p x
+--R            + 
+--R                   3   8      2   4 5         2 7 2  2
+--R              (- 2a d e  + 28a b d e  + 112a b d e )p
+--R     + 
+--R                +-------------------------------------------------------+
+--R                |    2    2            2            2 2 4          5   2
+--R                |- 6b %%U0  + 12a b d e p %%U0 + (3a d e  - 36a b d e)p
+--R           - 8b |-------------------------------------------------------
+--R                |                            2
+--R               \|                          2b
+--R         + 
+--R                              2
+--R           - 8b %%U0 + 24a d e p
+--R      *
+--R         log
+--R                      3 2            2   6        2 3 3      3 6
+--R                (- 48b d e %%U0 + (2a b e  + 32a b d e  + 32b d )p)
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |    2    2            2            2 2 4          5   2
+--R                 |- 6b %%U0  + 12a b d e p %%U0 + (3a d e  - 36a b d e)p
+--R                 |-------------------------------------------------------
+--R                 |                            2
+--R                \|                          2b
+--R            + 
+--R                 3 2      2      2   6         2 3 3      3 6
+--R              48b d e %%U0  + (2a b e  - 112a b d e  + 32b d )p %%U0
+--R            + 
+--R                3 9      2   3 6         2 6 3      3 9  2
+--R              (a e  - 12a b d e  - 168a b d e  - 64b d )p x
+--R            + 
+--R                   3   8      2   4 5         2 7 2  2
+--R              (- 2a d e  + 28a b d e  + 112a b d e )p
+--R     + 
+--R         16b %%U0
+--R      *
+--R         log
+--R                   3 2      2        2   6         2 3 3      3 6
+--R              - 96b d e %%U0  + (- 4a b e  + 224a b d e  - 64b d )p %%U0
+--R            + 
+--R                3 9      2   3 6         2 6 3      3 9  2
+--R              (a e  - 12a b d e  - 168a b d e  - 64b d )p x
+--R            + 
+--R                 3   8      2   4 5         2 7 2  2
+--R              (4a d e  - 56a b d e  - 224a b d e )p
+--R     + 
+--R            3   4          2   3        2     2        3           3
+--R       (4b e p x  + 16b d e p x  + 24b d e p x  + 16b d p x)log(b x  + a)
+--R     + 
+--R            3 4          2 3        2   2        3               3   4
+--R       (4b e x  + 16b d e x  + 24b d e x  + 16b d x)log(c) - 3b e p x
+--R     + 
+--R                2   3        2     2         3        3
+--R       - 16b d e p x  - 36b d e p x  + (12a e  - 48b d )p x
+--R  /
+--R     16b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2236
+
+--S 2237 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                    +-------------------------------------------------------+
+--R                    |    2    2            2            2 2 4          5   2
+--R               3+-+ |- 6b %%U0  + 12a b d e p %%U0 + (3a d e  - 36a b d e)p
+--R           4b e\|b  |-------------------------------------------------------
+--R                    |                            2
+--R                   \|                          2b
+--R         + 
+--R                 3+-+              3 3+-+
+--R           - 4b e\|b %%U0 + 12a d e p\|b
+--R      *
+--R         log
+--R                    3 2              2   6        2 3 3      3 6
+--R                (48b d e %%U0 + (- 2a b e  - 32a b d e  - 32b d )p)
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |    2    2            2            2 2 4          5   2
+--R                 |- 6b %%U0  + 12a b d e p %%U0 + (3a d e  - 36a b d e)p
+--R                 |-------------------------------------------------------
+--R                 |                            2
+--R                \|                          2b
+--R            + 
+--R                 3 2      2      2   6         2 3 3      3 6
+--R              48b d e %%U0  + (2a b e  - 112a b d e  + 32b d )p %%U0
+--R            + 
+--R                3 9      2   3 6         2 6 3      3 9  2
+--R              (a e  - 12a b d e  - 168a b d e  - 64b d )p x
+--R            + 
+--R                   3   8      2   4 5         2 7 2  2
+--R              (- 2a d e  + 28a b d e  + 112a b d e )p
+--R     + 
+--R                      +-------------------------------------------------------+
+--R                      |    2    2            2            2 2 4          5   2
+--R                 3+-+ |- 6b %%U0  + 12a b d e p %%U0 + (3a d e  - 36a b d e)p
+--R           - 4b e\|b  |-------------------------------------------------------
+--R                      |                            2
+--R                     \|                          2b
+--R         + 
+--R                 3+-+              3 3+-+
+--R           - 4b e\|b %%U0 + 12a d e p\|b
+--R      *
+--R         log
+--R                      3 2            2   6        2 3 3      3 6
+--R                (- 48b d e %%U0 + (2a b e  + 32a b d e  + 32b d )p)
+--R             *
+--R                 +-------------------------------------------------------+
+--R                 |    2    2            2            2 2 4          5   2
+--R                 |- 6b %%U0  + 12a b d e p %%U0 + (3a d e  - 36a b d e)p
+--R                 |-------------------------------------------------------
+--R                 |                            2
+--R                \|                          2b
+--R            + 
+--R                 3 2      2      2   6         2 3 3      3 6
+--R              48b d e %%U0  + (2a b e  - 112a b d e  + 32b d )p %%U0
+--R            + 
+--R                3 9      2   3 6         2 6 3      3 9  2
+--R              (a e  - 12a b d e  - 168a b d e  - 64b d )p x
+--R            + 
+--R                   3   8      2   4 5         2 7 2  2
+--R              (- 2a d e  + 28a b d e  + 112a b d e )p
+--R     + 
+--R              2 2  3+-+2 3+-+2        4       3   3+-+
+--R         (- 6d e p \|a   \|b  + (- a e  + 4b d e)p\|a )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           2 2  3+-+2 3+-+2       4       3   3+-+      3+-+   3+-+
+--R       (12d e p \|a   \|b  + (2a e  - 8b d e)p\|a )log(x\|b  + \|a )
+--R     + 
+--R                4 4         3 3        2 2 2       3          4 3+-+
+--R         (- 2b e x  - 8b d e x  - 12b d e x  - 8b d e x - 2b d )\|b
+--R      *
+--R                   3     p
+--R         log(c (b x  + a) )
+--R     + 
+--R             3+-+
+--R         8b e\|b %%U0
+--R      *
+--R         log
+--R                   3 2      2        2   6         2 3 3      3 6
+--R              - 96b d e %%U0  + (- 4a b e  + 224a b d e  - 64b d )p %%U0
+--R            + 
+--R                3 9      2   3 6         2 6 3      3 9  2
+--R              (a e  - 12a b d e  - 168a b d e  - 64b d )p x
+--R            + 
+--R                 3   8      2   4 5         2 7 2  2
+--R              (4a d e  - 56a b d e  - 224a b d e )p
+--R     + 
+--R                                                                   3+-+   3+-+
+--R             2 2  +-+3+-+2 3+-+2       4       3    +-+3+-+      2x\|b  - \|a
+--R       (- 12d e p\|3 \|a   \|b  + (2a e  - 8b d e)p\|3 \|a )atan(-------------)
+--R                                                                     +-+3+-+
+--R                                                                    \|3 \|a
+--R     + 
+--R                   4   4         3   3        2 2   2       3
+--R               2b e p x  + 8b d e p x  + 12b d e p x  + 8b d e p x
+--R             + 
+--R                        3       4
+--R               (- 8a d e  + 2b d )p
+--R          *
+--R                    3
+--R             log(b x  + a)
+--R         + 
+--R                4 4         3 3        2 2 2       3
+--R           (2b e x  + 8b d e x  + 12b d e x  + 8b d e x)log(c)
+--R      *
+--R         3+-+
+--R         \|b
+--R  /
+--R         3+-+
+--R     8b e\|b
+--R                                                    Type: Expression(Integer)
+--E 2237
+
+--S 2238 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2238
+
+)clear all
+
+--S 2239 of 5341
+t0:=(d+e*x)^2*log(c*(a+b*x^3)^p)
+--R 
+--R
+--R          2 2             2           3     p
+--R   (1)  (e x  + 2d e x + d )log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2239
+
+--S 2240 of 5341
+r0:=-3*d^2*p*x-3/2*d*e*p*x^2-1/3*e^2*p*x^3+a^(1/3)*d*(b^(1/3)*d-a^(1/3)*e)*_
+   p*log(a^(1/3)+b^(1/3)*x)/b^(2/3)-1/2*a^(1/3)*d*(b^(1/3)*d-a^(1/3)*e)*p*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/b^(2/3)-1/3*(b*d^3-a*e^3)*p*_
+   log(a+b*x^3)/(b*e)+1/3*(d+e*x)^3*log(c*(a+b*x^3)^p)/e-a^(1/3)*d*(b^(1/3)*_
+   d+a^(1/3)*e)*p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/b^(2/3)
+--R 
+--R
+--R   (2)
+--R              2   3+-+3+-+         2  3+-+2      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- 3b d e p\|a \|b  + 3b d e p \|a  )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            2   3+-+3+-+         2  3+-+2      3+-+   3+-+
+--R       (6b d e p\|a \|b  - 6b d e p \|a  )log(x\|b  + \|a )
+--R     + 
+--R            3 3         2 2       2          3 3+-+2          3     p
+--R       (2b e x  + 6b d e x  + 6b d e x + 2b d )\|b  log(c (b x  + a) )
+--R     + 
+--R                                                        3+-+   3+-+
+--R            2    +-+3+-+3+-+         2  +-+3+-+2      2x\|b  - \|a
+--R       (6b d e p\|3 \|a \|b  + 6b d e p\|3 \|a  )atan(-------------)
+--R                                                          +-+3+-+
+--R                                                         \|3 \|a
+--R     + 
+--R                  3       3          3            3   3         2   2
+--R             (2a e  - 2b d )p log(b x  + a) - 2b e p x  - 9b d e p x
+--R           + 
+--R                    2
+--R             - 18b d e p x
+--R      *
+--R         3+-+2
+--R         \|b
+--R  /
+--R          3+-+2
+--R     6b e \|b
+--R                                                    Type: Expression(Integer)
+--E 2240
+
+--S 2241 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                +---------------------------------------------------+
+--R                |    2    2         2             2 4          3   2
+--R                |- 9b %%V0  + 6a b e p %%V0 + (- a e  - 36a b d e)p
+--R           - 3b |---------------------------------------------------  - 3b %%V0
+--R                |                          2
+--R               \|                        3b
+--R         + 
+--R               2
+--R           3a e p
+--R      *
+--R         log
+--R                   2                  3     2 3
+--R                (9b e %%V0 + (- 3a b e  - 9b d )p)
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |    2    2         2             2 4          3   2
+--R                 |- 9b %%V0  + 6a b e p %%V0 + (- a e  - 36a b d e)p
+--R                 |---------------------------------------------------
+--R                 |                          2
+--R                \|                        3b
+--R            + 
+--R                  2      2          3     2 3                  2 3      2 5  2
+--R              - 9b e %%V0  + (6a b e  - 9b d )p %%V0 + (18a b d e  + 18b d )p x
+--R            + 
+--R                  2 5          3 2  2
+--R              (- a e  - 15a b d e )p
+--R     + 
+--R              +---------------------------------------------------+
+--R              |    2    2         2             2 4          3   2
+--R              |- 9b %%V0  + 6a b e p %%V0 + (- a e  - 36a b d e)p
+--R           3b |---------------------------------------------------  - 3b %%V0
+--R              |                          2
+--R             \|                        3b
+--R         + 
+--R               2
+--R           3a e p
+--R      *
+--R         log
+--R                     2                3     2 3
+--R                (- 9b e %%V0 + (3a b e  + 9b d )p)
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |    2    2         2             2 4          3   2
+--R                 |- 9b %%V0  + 6a b e p %%V0 + (- a e  - 36a b d e)p
+--R                 |---------------------------------------------------
+--R                 |                          2
+--R                \|                        3b
+--R            + 
+--R                  2      2          3     2 3                  2 3      2 5  2
+--R              - 9b e %%V0  + (6a b e  - 9b d )p %%V0 + (18a b d e  + 18b d )p x
+--R            + 
+--R                  2 5          3 2  2
+--R              (- a e  - 15a b d e )p
+--R     + 
+--R         6b %%V0
+--R      *
+--R         log
+--R                2      2            3     2 3                 2 3     2 5  2
+--R              9b e %%V0  + (- 6a b e  + 9b d )p %%V0 + (9a b d e  + 9b d )p x
+--R            + 
+--R                2 5          3 2  2
+--R              (a e  + 15a b d e )p
+--R     + 
+--R            2   3             2       2           3
+--R       (2b e p x  + 6b d e p x  + 6b d p x)log(b x  + a)
+--R     + 
+--R          2 3           2       2               2   3             2        2
+--R     (2b e x  + 6b d e x  + 6b d x)log(c) - 2b e p x  - 9b d e p x  - 18b d p x
+--R  /
+--R     6b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2241
+
+--S 2242 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                        +---------------------------------------------------+
+--R                        |    2    2         2             2 4          3   2
+--R                  3+-+2 |- 9b %%V0  + 6a b e p %%V0 + (- a e  - 36a b d e)p
+--R           - 3b e \|b   |---------------------------------------------------
+--R                        |                          2
+--R                       \|                        3b
+--R         + 
+--R                  3+-+2           3  3+-+2
+--R           - 3b e \|b  %%V0 + 3a e p \|b
+--R      *
+--R         log
+--R                   2                  3     2 3
+--R                (9b e %%V0 + (- 3a b e  - 9b d )p)
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |    2    2         2             2 4          3   2
+--R                 |- 9b %%V0  + 6a b e p %%V0 + (- a e  - 36a b d e)p
+--R                 |---------------------------------------------------
+--R                 |                          2
+--R                \|                        3b
+--R            + 
+--R                  2      2          3     2 3                  2 3      2 5  2
+--R              - 9b e %%V0  + (6a b e  - 9b d )p %%V0 + (18a b d e  + 18b d )p x
+--R            + 
+--R                  2 5          3 2  2
+--R              (- a e  - 15a b d e )p
+--R     + 
+--R                      +---------------------------------------------------+
+--R                      |    2    2         2             2 4          3   2
+--R                3+-+2 |- 9b %%V0  + 6a b e p %%V0 + (- a e  - 36a b d e)p
+--R           3b e \|b   |---------------------------------------------------
+--R                      |                          2
+--R                     \|                        3b
+--R         + 
+--R                  3+-+2           3  3+-+2
+--R           - 3b e \|b  %%V0 + 3a e p \|b
+--R      *
+--R         log
+--R                     2                3     2 3
+--R                (- 9b e %%V0 + (3a b e  + 9b d )p)
+--R             *
+--R                 +---------------------------------------------------+
+--R                 |    2    2         2             2 4          3   2
+--R                 |- 9b %%V0  + 6a b e p %%V0 + (- a e  - 36a b d e)p
+--R                 |---------------------------------------------------
+--R                 |                          2
+--R                \|                        3b
+--R            + 
+--R                  2      2          3     2 3                  2 3      2 5  2
+--R              - 9b e %%V0  + (6a b e  - 9b d )p %%V0 + (18a b d e  + 18b d )p x
+--R            + 
+--R                  2 5          3 2  2
+--R              (- a e  - 15a b d e )p
+--R     + 
+--R              3+-+2
+--R         6b e \|b  %%V0
+--R      *
+--R         log
+--R                2      2            3     2 3                 2 3     2 5  2
+--R              9b e %%V0  + (- 6a b e  + 9b d )p %%V0 + (9a b d e  + 9b d )p x
+--R            + 
+--R                2 5          3 2  2
+--R              (a e  + 15a b d e )p
+--R     + 
+--R            2   3+-+3+-+         2  3+-+2      2 3+-+2   3+-+3+-+   3+-+2
+--R       (3b d e p\|a \|b  - 3b d e p \|a  )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              2   3+-+3+-+         2  3+-+2      3+-+   3+-+
+--R       (- 6b d e p\|a \|b  + 6b d e p \|a  )log(x\|b  + \|a )
+--R     + 
+--R              3 3         2 2       2          3 3+-+2          3     p
+--R       (- 2b e x  - 6b d e x  - 6b d e x - 2b d )\|b  log(c (b x  + a) )
+--R     + 
+--R                                                          3+-+   3+-+
+--R              2    +-+3+-+3+-+         2  +-+3+-+2      2x\|b  - \|a
+--R       (- 6b d e p\|3 \|a \|b  - 6b d e p\|3 \|a  )atan(-------------)
+--R                                                            +-+3+-+
+--R                                                           \|3 \|a
+--R     + 
+--R                  3   3         2   2       2               3       3
+--R             (2b e p x  + 6b d e p x  + 6b d e p x + (- 2a e  + 2b d )p)
+--R          *
+--R                    3
+--R             log(b x  + a)
+--R         + 
+--R                3 3         2 2       2
+--R           (2b e x  + 6b d e x  + 6b d e x)log(c)
+--R      *
+--R         3+-+2
+--R         \|b
+--R  /
+--R          3+-+2
+--R     6b e \|b
+--R                                                    Type: Expression(Integer)
+--E 2242
+
+--S 2243 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2243
+
+)clear all
+
+--S 2244 of 5341
+t0:=(d+e*x)*log(c*(a+b*x^3)^p)
+--R 
+--R
+--R                           3     p
+--R   (1)  (e x + d)log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2244
+
+--S 2245 of 5341
+r0:=-3*d*p*x-3/4*e*p*x^2+1/2*a^(1/3)*(2*b^(1/3)*d-a^(1/3)*e)*p*log(a^(1/3)+_
+   b^(1/3)*x)/b^(2/3)-1/4*a^(1/3)*(2*b^(1/3)*d-a^(1/3)*e)*p*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/b^(2/3)-1/2*d^2*p*log(a+b*x^3)/e+_
+   1/2*(d+e*x)^2*log(c*(a+b*x^3)^p)/e-1/2*a^(1/3)*(2*b^(1/3)*d+a^(1/3)*e)*p*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/b^(2/3)
+--R 
+--R
+--R   (2)
+--R                3+-+3+-+    2  3+-+2      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- 2d e p\|a \|b  + e p \|a  )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              3+-+3+-+     2  3+-+2      3+-+   3+-+
+--R       (4d e p\|a \|b  - 2e p \|a  )log(x\|b  + \|a )
+--R     + 
+--R          2 2              2 3+-+2          3     p
+--R       (2e x  + 4d e x + 2d )\|b  log(c (b x  + a) )
+--R     + 
+--R                                                  3+-+   3+-+
+--R               +-+3+-+3+-+     2  +-+3+-+2      2x\|b  - \|a
+--R       (4d e p\|3 \|a \|b  + 2e p\|3 \|a  )atan(-------------)
+--R                                                    +-+3+-+
+--R                                                   \|3 \|a
+--R     + 
+--R            2         3          2   2             3+-+2
+--R       (- 2d p log(b x  + a) - 3e p x  - 12d e p x)\|b
+--R  /
+--R        3+-+2
+--R     4e \|b
+--R                                                    Type: Expression(Integer)
+--E 2245
+
+--S 2246 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               +----------------------+
+--R               |         2           2
+--R               |- 3b %%W0  - 6a d e p
+--R         (- 2  |---------------------- - 2%%W0)
+--R              \|           b
+--R      *
+--R         log
+--R                                   +----------------------+
+--R                                   |         2           2
+--R                               2   |- 3b %%W0  - 6a d e p              2
+--R              (2b e %%W0 - 4b d p) |----------------------  - 2b e %%W0
+--R                                  \|           b
+--R            + 
+--R                    2             3       3  2          2 2
+--R              - 4b d p %%W0 + (a e  + 8b d )p x - 2a d e p
+--R     + 
+--R             +----------------------+
+--R             |         2           2
+--R             |- 3b %%W0  - 6a d e p
+--R         (2  |---------------------- - 2%%W0)
+--R            \|           b
+--R      *
+--R         log
+--R                                     +----------------------+
+--R                                     |         2           2
+--R                                 2   |- 3b %%W0  - 6a d e p              2
+--R              (- 2b e %%W0 + 4b d p) |----------------------  - 2b e %%W0
+--R                                    \|           b
+--R            + 
+--R                    2             3       3  2          2 2
+--R              - 4b d p %%W0 + (a e  + 8b d )p x - 2a d e p
+--R     + 
+--R                          2       2             3       3  2          2 2
+--R       4%%W0 log(4b e %%W0  + 8b d p %%W0 + (a e  + 8b d )p x + 4a d e p )
+--R     + 
+--R            2                 3             2                       2
+--R     (2e p x  + 4d p x)log(b x  + a) + (2e x  + 4d x)log(c) - 3e p x  - 12d p x
+--R  /
+--R     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 2246
+
+--S 2247 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                     +----------------------+
+--R                     |         2           2
+--R               3+-+2 |- 3b %%W0  - 6a d e p        3+-+2
+--R         (- 2e \|b   |----------------------  - 2e \|b  %%W0)
+--R                    \|           b
+--R      *
+--R         log
+--R                                   +----------------------+
+--R                                   |         2           2
+--R                               2   |- 3b %%W0  - 6a d e p              2
+--R              (2b e %%W0 - 4b d p) |----------------------  - 2b e %%W0
+--R                                  \|           b
+--R            + 
+--R                    2             3       3  2          2 2
+--R              - 4b d p %%W0 + (a e  + 8b d )p x - 2a d e p
+--R     + 
+--R                   +----------------------+
+--R                   |         2           2
+--R             3+-+2 |- 3b %%W0  - 6a d e p        3+-+2
+--R         (2e \|b   |----------------------  - 2e \|b  %%W0)
+--R                  \|           b
+--R      *
+--R         log
+--R                                     +----------------------+
+--R                                     |         2           2
+--R                                 2   |- 3b %%W0  - 6a d e p              2
+--R              (- 2b e %%W0 + 4b d p) |----------------------  - 2b e %%W0
+--R                                    \|           b
+--R            + 
+--R                    2             3       3  2          2 2
+--R              - 4b d p %%W0 + (a e  + 8b d )p x - 2a d e p
+--R     + 
+--R            3+-+2
+--R         4e \|b  %%W0
+--R      *
+--R                      2       2             3       3  2          2 2
+--R         log(4b e %%W0  + 8b d p %%W0 + (a e  + 8b d )p x + 4a d e p )
+--R     + 
+--R              3+-+3+-+    2  3+-+2      2 3+-+2   3+-+3+-+   3+-+2
+--R       (2d e p\|a \|b  - e p \|a  )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                3+-+3+-+     2  3+-+2      3+-+   3+-+
+--R       (- 4d e p\|a \|b  + 2e p \|a  )log(x\|b  + \|a )
+--R     + 
+--R            2 2              2 3+-+2          3     p
+--R       (- 2e x  - 4d e x - 2d )\|b  log(c (b x  + a) )
+--R     + 
+--R                                                    3+-+   3+-+
+--R                 +-+3+-+3+-+     2  +-+3+-+2      2x\|b  - \|a
+--R       (- 4d e p\|3 \|a \|b  - 2e p\|3 \|a  )atan(-------------)
+--R                                                      +-+3+-+
+--R                                                     \|3 \|a
+--R     + 
+--R           2   2                2         3           2 2                 3+-+2
+--R       ((2e p x  + 4d e p x + 2d p)log(b x  + a) + (2e x  + 4d e x)log(c))\|b
+--R  /
+--R        3+-+2
+--R     4e \|b
+--R                                                    Type: Expression(Integer)
+--E 2247
+
+--S 2248 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2248
+
+)clear all
+
+--S 2249 of 5341
+t0:=log(c*(a+b*x^3)^p)
+--R 
+--R
+--R                  3     p
+--R   (1)  log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2249
+
+--S 2250 of 5341
+r0:=-3*p*x+a^(1/3)*p*log(a^(1/3)+b^(1/3)*x)/b^(1/3)-1/2*a^(1/3)*p*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/b^(1/3)+x*log(c*(a+b*x^3)^p)-_
+   a^(1/3)*p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/b^(1/3)
+--R 
+--R
+--R   (2)
+--R          3+-+     2 3+-+2   3+-+3+-+   3+-+2      3+-+     3+-+   3+-+
+--R       - p\|a log(x  \|b  - x\|a \|b  + \|a  ) + 2p\|a log(x\|b  + \|a )
+--R     + 
+--R                                                   3+-+   3+-+
+--R         3+-+          3     p       +-+3+-+     2x\|b  - \|a         3+-+
+--R       2x\|b log(c (b x  + a) ) + 2p\|3 \|a atan(-------------) - 6p x\|b
+--R                                                     +-+3+-+
+--R                                                    \|3 \|a
+--R  /
+--R      3+-+
+--R     2\|b
+--R                                                    Type: Expression(Integer)
+--E 2250
+
+--S 2251 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +-+     +-+2      +-+           +-+     +-+
+--R            |a      |a        |a    2       |a      |a
+--R       - p 3|- log(3|-   - x 3|- + x  + 2p 3|- log(3|-  + x)
+--R           \|b     \|b       \|b           \|b     \|b
+--R     + 
+--R                              +-+
+--R                         +-+  |a
+--R               +-+      \|3  3|-
+--R          +-+  |a            \|b               3
+--R       2p\|3  3|- atan(--------- + 2p x log(b x  + a) + 2x log(c) - 6p x
+--R              \|b       +-+
+--R                        |a
+--R                       3|-  - 2x
+--R                       \|b
+--R  /
+--R     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 2251
+
+--S 2252 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        3+-+     2 3+-+2   3+-+3+-+   3+-+2      3+-+     3+-+   3+-+
+--R       p\|a log(x  \|b  - x\|a \|b  + \|a  ) - 2p\|a log(x\|b  + \|a )
+--R     + 
+--R            +-+         +-+2      +-+           +-+         +-+
+--R            |a 3+-+     |a        |a    2       |a 3+-+     |a
+--R       - p 3|- \|b log(3|-   - x 3|- + x  + 2p 3|- \|b log(3|-  + x)
+--R           \|b         \|b       \|b           \|b         \|b
+--R     + 
+--R                                                     3+-+   3+-+
+--R           3+-+          3     p       +-+3+-+     2x\|b  - \|a
+--R       - 2x\|b log(c (b x  + a) ) - 2p\|3 \|a atan(-------------)
+--R                                                       +-+3+-+
+--R                                                      \|3 \|a
+--R     + 
+--R                                  +-+
+--R                             +-+  |a
+--R               +-+          \|3  3|-
+--R          +-+  |a 3+-+           \|b                3                  3+-+
+--R       2p\|3  3|- \|b atan(--------- + (2p x log(b x  + a) + 2x log(c))\|b
+--R              \|b           +-+
+--R                            |a
+--R                           3|-  - 2x
+--R                           \|b
+--R  /
+--R      3+-+
+--R     2\|b
+--R                                                    Type: Expression(Integer)
+--E 2252
+
+--S 2253 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2253
+
+)clear all
+
+--S 2254 of 5341
+t0:=log(c*(a+b*x^3)^p)/(d+e*x)
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2254
+
+--S 2255 of 5341
+--r0:=-p*log(-e*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-a^(1/3)*e))*log(d+e*x)/e-_
+--  p*log(-e*((-1)^(2/3)*a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-(-1)^(2/3)*a^(1/3)*_
+--  e))*log(d+e*x)/e-p*log((-1)^(1/3)*e*(a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/_
+--  (b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e))*log(d+e*x)/e+log(d+e*x)*log(c*_
+--  (a+b*x^3)^p)/e-p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-a^(1/3)*e))/e-_
+--  p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e))/e-_
+--  p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-(-1)^(2/3)*a^(1/3)*e))/e
+--E 2255
+
+--S 2256 of 5341
+--a0:=integrate(t0,x)
+--E 2256
+
+--S 2257 of 5341
+--m0:=a0-r0
+--E 2257
+
+--S 2258 of 5341
+--d0:=D(m0,x)
+--E 2258
+
+)clear all
+
+--S 2259 of 5341
+t0:=log(c*(a+b*x^3)^p)/(d+e*x)^2
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 2259
+
+--S 2260 of 5341
+r0:=a^(1/3)*b^(1/3)*(b^(1/3)*d+a^(1/3)*e)*p*log(a^(1/3)+b^(1/3)*x)/(b*d^3-_
+   a*e^3)-3*b*d^2*p*log(d+e*x)/(e*(b*d^3-a*e^3))-1/2*a^(1/3)*b^(1/3)*_
+   (b^(1/3)*d+a^(1/3)*e)*p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (b*d^3-a*e^3)+b*d^2*p*log(a+b*x^3)/(e*(b*d^3-a*e^3))-log(c*(a+b*x^3)^p)/_
+   (e*(d+e*x))-a^(1/3)*b^(1/3)*p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))*sqrt(3)/(b^(2/3)*d^2+a^(1/3)*b^(1/3)*d*e+a^(2/3)*e^2)
+--R 
+--R
+--R   (2)
+--R                  4          2 3  3+-+2
+--R           (2a d e p x + 2a d e p)\|b
+--R         + 
+--R                5      3 2             4      4    3+-+3+-+
+--R           ((a e  + b d e )p x + (a d e  + b d e)p)\|a \|b
+--R         + 
+--R                2 3          3 2  3+-+2
+--R           (2b d e p x + 2b d e p)\|a
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                    4          2 3  3+-+2
+--R           (- 4a d e p x - 4a d e p)\|b
+--R         + 
+--R                   5       3 2                4       4    3+-+3+-+
+--R           ((- 2a e  - 2b d e )p x + (- 2a d e  - 2b d e)p)\|a \|b
+--R         + 
+--R                  2 3          3 2  3+-+2
+--R           (- 4b d e p x - 4b d e p)\|a
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                  2 3       5 3+-+2            4       4  3+-+3+-+
+--R           (- 2a d e  + 2b d )\|b   + (- 2a d e  + 2b d e)\|a \|b
+--R         + 
+--R                  5       3 2 3+-+2
+--R           (- 2a e  + 2b d e )\|a
+--R      *
+--R                   3     p
+--R         log(c (b x  + a) )
+--R     + 
+--R               5       3 2              4       4     +-+3+-+3+-+
+--R         ((2a e  - 2b d e )p x + (2a d e  - 2b d e)p)\|3 \|a \|b
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R                  4            5         3
+--R           (- 2b d e p x - 2b d p)log(b x  + a)
+--R         + 
+--R                4            5
+--R           (6b d e p x + 6b d p)log(e x + d)
+--R      *
+--R         3+-+2
+--R         \|b
+--R     + 
+--R                  3 2          4           3
+--R           (- 2b d e p x - 2b d e p)log(b x  + a)
+--R         + 
+--R                3 2          4
+--R           (6b d e p x + 6b d e p)log(e x + d)
+--R      *
+--R         3+-+3+-+
+--R         \|a \|b
+--R     + 
+--R                  2 3          3 2         3
+--R           (- 2b d e p x - 2b d e p)log(b x  + a)
+--R         + 
+--R                2 3          3 2
+--R           (6b d e p x + 6b d e p)log(e x + d)
+--R      *
+--R         3+-+2
+--R         \|a
+--R  /
+--R             2 5       5 2         3 4       6  3+-+2
+--R       ((2a d e  - 2b d e )x + 2a d e  - 2b d e)\|b
+--R     + 
+--R               6       4 3         2 5       5 2 3+-+3+-+
+--R       ((2a d e  - 2b d e )x + 2a d e  - 2b d e )\|a \|b
+--R     + 
+--R             7       3 4           6       4 3 3+-+2
+--R       ((2a e  - 2b d e )x + 2a d e  - 2b d e )\|a
+--R                                                    Type: Expression(Integer)
+--E 2260
+
+--S 2261 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    5      3 2          4      4
+--R             ((- a e  + b d e )x - a d e  + b d e)
+--R          *
+--R             ROOT
+--R                         2 8         3 5     2 6 2     2
+--R                    (- 3a e  + 6a b d e  - 3b d e )%%Y0
+--R                  + 
+--R                             2 4     2 5                     3     2 4  2
+--R                    (- 6a b d e  + 6b d e)p %%Y0 + (12a b d e  - 3b d )p
+--R               /
+--R                   2 8         3 5    2 6 2
+--R                  a e  - 2a b d e  + b d e
+--R         + 
+--R                  5      3 2          4      4             2            3
+--R           ((- a e  + b d e )x - a d e  + b d e)%%Y0 - 3b d e p x - 3b d p
+--R      *
+--R         log
+--R                    5      3 2
+--R                (a e  - b d e )%%Y0
+--R             *
+--R                ROOT
+--R                            2 8         3 5     2 6 2     2
+--R                       (- 3a e  + 6a b d e  - 3b d e )%%Y0
+--R                     + 
+--R                                2 4     2 5                     3     2 4  2
+--R                       (- 6a b d e  + 6b d e)p %%Y0 + (12a b d e  - 3b d )p
+--R                  /
+--R                      2 8         3 5    2 6 2
+--R                     a e  - 2a b d e  + b d e
+--R            + 
+--R                    5      3 2     2       2                 2          2
+--R              (- a e  + b d e )%%Y0  - 3b d e p %%Y0 + 2b e p x + 2b d p
+--R     + 
+--R                  5      3 2          4      4
+--R             ((a e  - b d e )x + a d e  - b d e)
+--R          *
+--R             ROOT
+--R                         2 8         3 5     2 6 2     2
+--R                    (- 3a e  + 6a b d e  - 3b d e )%%Y0
+--R                  + 
+--R                             2 4     2 5                     3     2 4  2
+--R                    (- 6a b d e  + 6b d e)p %%Y0 + (12a b d e  - 3b d )p
+--R               /
+--R                   2 8         3 5    2 6 2
+--R                  a e  - 2a b d e  + b d e
+--R         + 
+--R                  5      3 2          4      4             2            3
+--R           ((- a e  + b d e )x - a d e  + b d e)%%Y0 - 3b d e p x - 3b d p
+--R      *
+--R         log
+--R                      5      3 2
+--R                (- a e  + b d e )%%Y0
+--R             *
+--R                ROOT
+--R                            2 8         3 5     2 6 2     2
+--R                       (- 3a e  + 6a b d e  - 3b d e )%%Y0
+--R                     + 
+--R                                2 4     2 5                     3     2 4  2
+--R                       (- 6a b d e  + 6b d e)p %%Y0 + (12a b d e  - 3b d )p
+--R                  /
+--R                      2 8         3 5    2 6 2
+--R                     a e  - 2a b d e  + b d e
+--R            + 
+--R                    5      3 2     2       2                 2          2
+--R              (- a e  + b d e )%%Y0  - 3b d e p %%Y0 + 2b e p x + 2b d p
+--R     + 
+--R               5       3 2           4       4
+--R         ((2a e  - 2b d e )x + 2a d e  - 2b d e)%%Y0
+--R      *
+--R                 5      3 2     2       2                2          2
+--R         log((a e  - b d e )%%Y0  + 3b d e p %%Y0 + b e p x - 2b d p )
+--R     + 
+--R              3       3          3             2            3
+--R       (- 2a e  + 2b d )p log(b x  + a) + (6b d e p x + 6b d p)log(e x + d)
+--R     + 
+--R              3       3
+--R       (- 2a e  + 2b d )log(c)
+--R  /
+--R          5       3 2           4       4
+--R     (2a e  - 2b d e )x + 2a d e  - 2b d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 2261
+
+--S 2262 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      2 5      5 2        3 4      6  3+-+2
+--R               ((- a d e  + b d e )x - a d e  + b d e)\|b
+--R             + 
+--R                        6      4 3        2 5      5 2 3+-+3+-+
+--R               ((- a d e  + b d e )x - a d e  + b d e )\|a \|b
+--R             + 
+--R                      7      3 4          6      4 3 3+-+2
+--R               ((- a e  + b d e )x - a d e  + b d e )\|a
+--R          *
+--R             ROOT
+--R                         2 8         3 5     2 6 2     2
+--R                    (- 3a e  + 6a b d e  - 3b d e )%%Y0
+--R                  + 
+--R                             2 4     2 5                     3     2 4  2
+--R                    (- 6a b d e  + 6b d e)p %%Y0 + (12a b d e  - 3b d )p
+--R               /
+--R                   2 8         3 5    2 6 2
+--R                  a e  - 2a b d e  + b d e
+--R         + 
+--R                      2 5      5 2        3 4      6  3+-+2
+--R               ((- a d e  + b d e )x - a d e  + b d e)\|b
+--R             + 
+--R                        6      4 3        2 5      5 2 3+-+3+-+
+--R               ((- a d e  + b d e )x - a d e  + b d e )\|a \|b
+--R             + 
+--R                      7      3 4          6      4 3 3+-+2
+--R               ((- a e  + b d e )x - a d e  + b d e )\|a
+--R          *
+--R             %%Y0
+--R         + 
+--R                  4            5  3+-+2          3 2          4    3+-+3+-+
+--R           (- 3b d e p x - 3b d p)\|b   + (- 3b d e p x - 3b d e p)\|a \|b
+--R         + 
+--R                  2 3          3 2  3+-+2
+--R           (- 3b d e p x - 3b d e p)\|a
+--R      *
+--R         log
+--R                    5      3 2
+--R                (a e  - b d e )%%Y0
+--R             *
+--R                ROOT
+--R                            2 8         3 5     2 6 2     2
+--R                       (- 3a e  + 6a b d e  - 3b d e )%%Y0
+--R                     + 
+--R                                2 4     2 5                     3     2 4  2
+--R                       (- 6a b d e  + 6b d e)p %%Y0 + (12a b d e  - 3b d )p
+--R                  /
+--R                      2 8         3 5    2 6 2
+--R                     a e  - 2a b d e  + b d e
+--R            + 
+--R                    5      3 2     2       2                 2          2
+--R              (- a e  + b d e )%%Y0  - 3b d e p %%Y0 + 2b e p x + 2b d p
+--R     + 
+--R                    2 5      5 2        3 4      6  3+-+2
+--R               ((a d e  - b d e )x + a d e  - b d e)\|b
+--R             + 
+--R                      6      4 3        2 5      5 2 3+-+3+-+
+--R               ((a d e  - b d e )x + a d e  - b d e )\|a \|b
+--R             + 
+--R                    7      3 4          6      4 3 3+-+2
+--R               ((a e  - b d e )x + a d e  - b d e )\|a
+--R          *
+--R             ROOT
+--R                         2 8         3 5     2 6 2     2
+--R                    (- 3a e  + 6a b d e  - 3b d e )%%Y0
+--R                  + 
+--R                             2 4     2 5                     3     2 4  2
+--R                    (- 6a b d e  + 6b d e)p %%Y0 + (12a b d e  - 3b d )p
+--R               /
+--R                   2 8         3 5    2 6 2
+--R                  a e  - 2a b d e  + b d e
+--R         + 
+--R                      2 5      5 2        3 4      6  3+-+2
+--R               ((- a d e  + b d e )x - a d e  + b d e)\|b
+--R             + 
+--R                        6      4 3        2 5      5 2 3+-+3+-+
+--R               ((- a d e  + b d e )x - a d e  + b d e )\|a \|b
+--R             + 
+--R                      7      3 4          6      4 3 3+-+2
+--R               ((- a e  + b d e )x - a d e  + b d e )\|a
+--R          *
+--R             %%Y0
+--R         + 
+--R                  4            5  3+-+2          3 2          4    3+-+3+-+
+--R           (- 3b d e p x - 3b d p)\|b   + (- 3b d e p x - 3b d e p)\|a \|b
+--R         + 
+--R                  2 3          3 2  3+-+2
+--R           (- 3b d e p x - 3b d e p)\|a
+--R      *
+--R         log
+--R                      5      3 2
+--R                (- a e  + b d e )%%Y0
+--R             *
+--R                ROOT
+--R                            2 8         3 5     2 6 2     2
+--R                       (- 3a e  + 6a b d e  - 3b d e )%%Y0
+--R                     + 
+--R                                2 4     2 5                     3     2 4  2
+--R                       (- 6a b d e  + 6b d e)p %%Y0 + (12a b d e  - 3b d )p
+--R                  /
+--R                      2 8         3 5    2 6 2
+--R                     a e  - 2a b d e  + b d e
+--R            + 
+--R                    5      3 2     2       2                 2          2
+--R              (- a e  + b d e )%%Y0  - 3b d e p %%Y0 + 2b e p x + 2b d p
+--R     + 
+--R                 2 5       5 2         3 4       6  3+-+2
+--R           ((2a d e  - 2b d e )x + 2a d e  - 2b d e)\|b
+--R         + 
+--R                   6       4 3         2 5       5 2 3+-+3+-+
+--R           ((2a d e  - 2b d e )x + 2a d e  - 2b d e )\|a \|b
+--R         + 
+--R                 7       3 4           6       4 3 3+-+2
+--R           ((2a e  - 2b d e )x + 2a d e  - 2b d e )\|a
+--R      *
+--R                      5      3 2     2       2                2          2
+--R         %%Y0 log((a e  - b d e )%%Y0  + 3b d e p %%Y0 + b e p x - 2b d p )
+--R     + 
+--R                    4          2 3  3+-+2
+--R           (- 2a d e p x - 2a d e p)\|b
+--R         + 
+--R                  5      3 2               4      4    3+-+3+-+
+--R           ((- a e  - b d e )p x + (- a d e  - b d e)p)\|a \|b
+--R         + 
+--R                  2 3          3 2  3+-+2
+--R           (- 2b d e p x - 2b d e p)\|a
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                  4          2 3  3+-+2
+--R           (4a d e p x + 4a d e p)\|b
+--R         + 
+--R                 5       3 2              4       4    3+-+3+-+
+--R           ((2a e  + 2b d e )p x + (2a d e  + 2b d e)p)\|a \|b
+--R         + 
+--R                2 3          3 2  3+-+2
+--R           (4b d e p x + 4b d e p)\|a
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                2 3       5 3+-+2          4       4  3+-+3+-+
+--R           (2a d e  - 2b d )\|b   + (2a d e  - 2b d e)\|a \|b
+--R         + 
+--R                5       3 2 3+-+2
+--R           (2a e  - 2b d e )\|a
+--R      *
+--R                   3     p
+--R         log(c (b x  + a) )
+--R     + 
+--R                 5       3 2                4       4     +-+3+-+3+-+
+--R         ((- 2a e  + 2b d e )p x + (- 2a d e  + 2b d e)p)\|3 \|a \|b
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R                4               2 3       5          3
+--R           (2b d e p x + (- 2a d e  + 4b d )p)log(b x  + a)
+--R         + 
+--R                  2 3       5
+--R           (- 2a d e  + 2b d )log(c)
+--R      *
+--R         3+-+2
+--R         \|b
+--R     + 
+--R                3 2               4       4           3
+--R           (2b d e p x + (- 2a d e  + 4b d e)p)log(b x  + a)
+--R         + 
+--R                    4       4
+--R           (- 2a d e  + 2b d e)log(c)
+--R      *
+--R         3+-+3+-+
+--R         \|a \|b
+--R     + 
+--R                2 3             5       3 2          3
+--R           (2b d e p x + (- 2a e  + 4b d e )p)log(b x  + a)
+--R         + 
+--R                  5       3 2
+--R           (- 2a e  + 2b d e )log(c)
+--R      *
+--R         3+-+2
+--R         \|a
+--R  /
+--R             2 5       5 2         3 4       6  3+-+2
+--R       ((2a d e  - 2b d e )x + 2a d e  - 2b d e)\|b
+--R     + 
+--R               6       4 3         2 5       5 2 3+-+3+-+
+--R       ((2a d e  - 2b d e )x + 2a d e  - 2b d e )\|a \|b
+--R     + 
+--R             7       3 4           6       4 3 3+-+2
+--R       ((2a e  - 2b d e )x + 2a d e  - 2b d e )\|a
+--R                                                    Type: Expression(Integer)
+--E 2262
+
+--S 2263 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2263
+
+)clear all
+
+--S 2264 of 5341
+t0:=log(c*(a+b*x^3)^p)/(d+e*x)^3
+--R 
+--R
+--R                       3     p
+--R             log(c (b x  + a) )
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 2264
+
+--S 2265 of 5341
+r0:=3/2*b*d^2*p/(e*(b*d^3-a*e^3)*(d+e*x))+1/2*a^(1/3)*b^(2/3)*(2*b*d^3+_
+   3*a^(1/3)*b^(2/3)*d^2*e+a*e^3)*p*log(a^(1/3)+b^(1/3)*x)/(b*d^3-a*e^3)^2-_
+   3/2*b*d*(b*d^3+2*a*e^3)*p*log(d+e*x)/(e*(b*d^3-a*e^3)^2)-1/4*a^(1/3)*_
+   b^(2/3)*(2*b*d^3+3*a^(1/3)*b^(2/3)*d^2*e+a*e^3)*p*log(a^(2/3)-a^(1/3)*_
+   b^(1/3)*x+b^(2/3)*x^2)/(b*d^3-a*e^3)^2+1/2*b*d*(b*d^3+2*a*e^3)*p*_
+   log(a+b*x^3)/(e*(b*d^3-a*e^3)^2)-1/2*log(c*(a+b*x^3)^p)/(e*(d+e*x)^2)-_
+   1/2*a^(1/3)*b^(2/3)*(2*b*d^3-3*a^(1/3)*b^(2/3)*d^2*e+a*e^3)*p*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/(b*d^3-a*e^3)^2
+--R 
+--R
+--R   (2)
+--R                     6       3 3    2            5       4 2
+--R               (- a e  - 2b d e )p x  + (- 2a d e  - 4b d e )p x
+--R             + 
+--R                     2 4       5
+--R               (- a d e  - 2b d e)p
+--R          *
+--R             3+-+3+-+2
+--R             \|a \|b
+--R         + 
+--R                  2 4   2       3 3          4 2  3+-+2 3+-+
+--R           (- 3b d e p x  - 6b d e p x - 3b d e p)\|a   \|b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                    6       3 3    2          5       4 2
+--R               (2a e  + 4b d e )p x  + (4a d e  + 8b d e )p x
+--R             + 
+--R                    2 4       5
+--R               (2a d e  + 4b d e)p
+--R          *
+--R             3+-+3+-+2
+--R             \|a \|b
+--R         + 
+--R                2 4   2        3 3          4 2  3+-+2 3+-+
+--R           (6b d e p x  + 12b d e p x + 6b d e p)\|a   \|b
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R            2 6         3 3     2 6           3     p
+--R       (- 2a e  + 4a b d e  - 2b d )log(c (b x  + a) )
+--R     + 
+--R                    6       3 3    2          5       4 2
+--R               (2a e  + 4b d e )p x  + (4a d e  + 8b d e )p x
+--R             + 
+--R                    2 4       5
+--R               (2a d e  + 4b d e)p
+--R          *
+--R              +-+3+-+3+-+2
+--R             \|3 \|a \|b
+--R         + 
+--R                  2 4   2        3 3          4 2   +-+3+-+2 3+-+
+--R           (- 6b d e p x  - 12b d e p x - 6b d e p)\|3 \|a   \|b
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R                    5     2 4 2    2          2 4     2 5
+--R           (4a b d e  + 2b d e )p x  + (8a b d e  + 4b d e)p x
+--R         + 
+--R                  3 3     2 6
+--R           (4a b d e  + 2b d )p
+--R      *
+--R                3
+--R         log(b x  + a)
+--R     + 
+--R                       5     2 4 2    2             2 4      2 5
+--R           (- 12a b d e  - 6b d e )p x  + (- 24a b d e  - 12b d e)p x
+--R         + 
+--R                     3 3     2 6
+--R           (- 12a b d e  - 6b d )p
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                2 4     2 5                 3 3     2 6
+--R       (- 6a b d e  + 6b d e)p x + (- 6a b d e  + 6b d )p
+--R  /
+--R          2 9         3 6     2 6 3  2      2   8          4 5     2 7 2
+--R       (4a e  - 8a b d e  + 4b d e )x  + (8a d e  - 16a b d e  + 8b d e )x
+--R     + 
+--R         2 2 7         5 4     2 8
+--R       4a d e  - 8a b d e  + 4b d e
+--R                                                    Type: Expression(Integer)
+--E 2265
+
+--S 2266 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                  2 9         3 6     2 6 3  2
+--R               (2a e  - 4a b d e  + 2b d e )x
+--R             + 
+--R                  2   8         4 5     2 7 2       2 2 7         5 4     2 8
+--R               (4a d e  - 8a b d e  + 4b d e )x + 2a d e  - 4a b d e  + 2b d e
+--R          *
+--R             ROOT
+--R                             4 14      3   3 11      2 2 6 8        3 9 5
+--R                        - 12a e   + 48a b d e   - 72a b d e  + 48a b d e
+--R                      + 
+--R                             4 12 2
+--R                        - 12b d  e
+--R                   *
+--R                          2
+--R                      %%Z0
+--R                  + 
+--R                        3     10      2 2 4 7      4 10
+--R                    (24a b d e   - 36a b d e  + 12b d  e)p %%Z0
+--R                  + 
+--R                        2 2 2 6        3 5 3     4 8  2
+--R                    (24a b d e  + 60a b d e  - 3b d )p
+--R               /
+--R                    4 14      3   3 11      2 2 6 8        3 9 5     4 12 2
+--R                  4a e   - 16a b d e   + 24a b d e  - 16a b d e  + 4b d  e
+--R         + 
+--R                    2 9         3 6     2 6 3  2
+--R               (- 2a e  + 4a b d e  - 2b d e )x
+--R             + 
+--R                  2   8         4 5     2 7 2       2 2 7         5 4     2 8
+--R             (- 4a d e  + 8a b d e  - 4b d e )x - 2a d e  + 4a b d e  - 2b d e
+--R          *
+--R             %%Z0
+--R         + 
+--R                    5     2 4 2    2           2 4     2 5
+--R           (6a b d e  + 3b d e )p x  + (12a b d e  + 6b d e)p x
+--R         + 
+--R                  3 3     2 6
+--R           (6a b d e  + 3b d )p
+--R      *
+--R         log
+--R                      2 2 8          5 5      2 8 2
+--R                  (12a d e  - 24a b d e  + 12b d e )%%Z0
+--R                + 
+--R                     2 7         3 4     2 6
+--R                  (2a e  - 4a b d e  + 2b d e)p
+--R             *
+--R                ROOT
+--R                                4 14      3   3 11      2 2 6 8        3 9 5
+--R                           - 12a e   + 48a b d e   - 72a b d e  + 48a b d e
+--R                         + 
+--R                                4 12 2
+--R                           - 12b d  e
+--R                      *
+--R                             2
+--R                         %%Z0
+--R                     + 
+--R                           3     10      2 2 4 7      4 10
+--R                       (24a b d e   - 36a b d e  + 12b d  e)p %%Z0
+--R                     + 
+--R                           2 2 2 6        3 5 3     4 8  2
+--R                       (24a b d e  + 60a b d e  - 3b d )p
+--R                  /
+--R                       4 14      3   3 11      2 2 6 8        3 9 5     4 12 2
+--R                     4a e   - 16a b d e   + 24a b d e  - 16a b d e  + 4b d  e
+--R            + 
+--R                  2 2 8          5 5      2 8 2     2
+--R              (12a d e  - 24a b d e  + 12b d e )%%Z0
+--R            + 
+--R                   2 7          3 4      2 6                  4      2 3   2
+--R              (- 2a e  - 32a b d e  - 20b d e)p %%Z0 + (2a b e  + 16b d e)p x
+--R            + 
+--R                       3     2 4  2
+--R              (2a b d e  + 7b d )p
+--R     + 
+--R                    2 9         3 6     2 6 3  2
+--R               (- 2a e  + 4a b d e  - 2b d e )x
+--R             + 
+--R                  2   8         4 5     2 7 2       2 2 7         5 4     2 8
+--R             (- 4a d e  + 8a b d e  - 4b d e )x - 2a d e  + 4a b d e  - 2b d e
+--R          *
+--R             ROOT
+--R                             4 14      3   3 11      2 2 6 8        3 9 5
+--R                        - 12a e   + 48a b d e   - 72a b d e  + 48a b d e
+--R                      + 
+--R                             4 12 2
+--R                        - 12b d  e
+--R                   *
+--R                          2
+--R                      %%Z0
+--R                  + 
+--R                        3     10      2 2 4 7      4 10
+--R                    (24a b d e   - 36a b d e  + 12b d  e)p %%Z0
+--R                  + 
+--R                        2 2 2 6        3 5 3     4 8  2
+--R                    (24a b d e  + 60a b d e  - 3b d )p
+--R               /
+--R                    4 14      3   3 11      2 2 6 8        3 9 5     4 12 2
+--R                  4a e   - 16a b d e   + 24a b d e  - 16a b d e  + 4b d  e
+--R         + 
+--R                    2 9         3 6     2 6 3  2
+--R               (- 2a e  + 4a b d e  - 2b d e )x
+--R             + 
+--R                  2   8         4 5     2 7 2       2 2 7         5 4     2 8
+--R             (- 4a d e  + 8a b d e  - 4b d e )x - 2a d e  + 4a b d e  - 2b d e
+--R          *
+--R             %%Z0
+--R         + 
+--R                    5     2 4 2    2           2 4     2 5
+--R           (6a b d e  + 3b d e )p x  + (12a b d e  + 6b d e)p x
+--R         + 
+--R                  3 3     2 6
+--R           (6a b d e  + 3b d )p
+--R      *
+--R         log
+--R                        2 2 8          5 5      2 8 2
+--R                  (- 12a d e  + 24a b d e  - 12b d e )%%Z0
+--R                + 
+--R                       2 7         3 4     2 6
+--R                  (- 2a e  + 4a b d e  - 2b d e)p
+--R             *
+--R                ROOT
+--R                                4 14      3   3 11      2 2 6 8        3 9 5
+--R                           - 12a e   + 48a b d e   - 72a b d e  + 48a b d e
+--R                         + 
+--R                                4 12 2
+--R                           - 12b d  e
+--R                      *
+--R                             2
+--R                         %%Z0
+--R                     + 
+--R                           3     10      2 2 4 7      4 10
+--R                       (24a b d e   - 36a b d e  + 12b d  e)p %%Z0
+--R                     + 
+--R                           2 2 2 6        3 5 3     4 8  2
+--R                       (24a b d e  + 60a b d e  - 3b d )p
+--R                  /
+--R                       4 14      3   3 11      2 2 6 8        3 9 5     4 12 2
+--R                     4a e   - 16a b d e   + 24a b d e  - 16a b d e  + 4b d  e
+--R            + 
+--R                  2 2 8          5 5      2 8 2     2
+--R              (12a d e  - 24a b d e  + 12b d e )%%Z0
+--R            + 
+--R                   2 7          3 4      2 6                  4      2 3   2
+--R              (- 2a e  - 32a b d e  - 20b d e)p %%Z0 + (2a b e  + 16b d e)p x
+--R            + 
+--R                       3     2 4  2
+--R              (2a b d e  + 7b d )p
+--R     + 
+--R              2 9         3 6     2 6 3  2      2   8          4 5     2 7 2
+--R           (4a e  - 8a b d e  + 4b d e )x  + (8a d e  - 16a b d e  + 8b d e )x
+--R         + 
+--R             2 2 7         5 4     2 8
+--R           4a d e  - 8a b d e  + 4b d e
+--R      *
+--R         %%Z0
+--R      *
+--R         log
+--R                    2 2 8          5 5      2 8 2     2
+--R              (- 12a d e  + 24a b d e  - 12b d e )%%Z0
+--R            + 
+--R                 2 7          3 4      2 6                 4     2 3   2
+--R              (2a e  + 32a b d e  + 20b d e)p %%Z0 + (a b e  + 8b d e)p x
+--R            + 
+--R                         3     2 4  2
+--R              (- 2a b d e  - 7b d )p
+--R     + 
+--R            2 6         3 3     2 6          3
+--R       (- 2a e  + 4a b d e  - 2b d )p log(b x  + a)
+--R     + 
+--R                       5     2 4 2    2             2 4      2 5
+--R           (- 12a b d e  - 6b d e )p x  + (- 24a b d e  - 12b d e)p x
+--R         + 
+--R                     3 3     2 6
+--R           (- 12a b d e  - 6b d )p
+--R      *
+--R         log(e x + d)
+--R     + 
+--R            2 6         3 3     2 6                   2 4     2 5
+--R       (- 2a e  + 4a b d e  - 2b d )log(c) + (- 6a b d e  + 6b d e)p x
+--R     + 
+--R                3 3     2 6
+--R       (- 6a b d e  + 6b d )p
+--R  /
+--R          2 9         3 6     2 6 3  2      2   8          4 5     2 7 2
+--R       (4a e  - 8a b d e  + 4b d e )x  + (8a d e  - 16a b d e  + 8b d e )x
+--R     + 
+--R         2 2 7         5 4     2 8
+--R       4a d e  - 8a b d e  + 4b d e
+--R                                         Type: Union(Expression(Integer),...)
+--E 2266
+
+--S 2267 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                  2 9         3 6     2 6 3  2
+--R               (2a e  - 4a b d e  + 2b d e )x
+--R             + 
+--R                  2   8         4 5     2 7 2       2 2 7         5 4     2 8
+--R               (4a d e  - 8a b d e  + 4b d e )x + 2a d e  - 4a b d e  + 2b d e
+--R          *
+--R             ROOT
+--R                             4 14      3   3 11      2 2 6 8        3 9 5
+--R                        - 12a e   + 48a b d e   - 72a b d e  + 48a b d e
+--R                      + 
+--R                             4 12 2
+--R                        - 12b d  e
+--R                   *
+--R                          2
+--R                      %%Z0
+--R                  + 
+--R                        3     10      2 2 4 7      4 10
+--R                    (24a b d e   - 36a b d e  + 12b d  e)p %%Z0
+--R                  + 
+--R                        2 2 2 6        3 5 3     4 8  2
+--R                    (24a b d e  + 60a b d e  - 3b d )p
+--R               /
+--R                    4 14      3   3 11      2 2 6 8        3 9 5     4 12 2
+--R                  4a e   - 16a b d e   + 24a b d e  - 16a b d e  + 4b d  e
+--R         + 
+--R                    2 9         3 6     2 6 3  2
+--R               (- 2a e  + 4a b d e  - 2b d e )x
+--R             + 
+--R                  2   8         4 5     2 7 2       2 2 7         5 4     2 8
+--R             (- 4a d e  + 8a b d e  - 4b d e )x - 2a d e  + 4a b d e  - 2b d e
+--R          *
+--R             %%Z0
+--R         + 
+--R                    5     2 4 2    2           2 4     2 5
+--R           (6a b d e  + 3b d e )p x  + (12a b d e  + 6b d e)p x
+--R         + 
+--R                  3 3     2 6
+--R           (6a b d e  + 3b d )p
+--R      *
+--R         log
+--R                      2 2 8          5 5      2 8 2
+--R                  (12a d e  - 24a b d e  + 12b d e )%%Z0
+--R                + 
+--R                     2 7         3 4     2 6
+--R                  (2a e  - 4a b d e  + 2b d e)p
+--R             *
+--R                ROOT
+--R                                4 14      3   3 11      2 2 6 8        3 9 5
+--R                           - 12a e   + 48a b d e   - 72a b d e  + 48a b d e
+--R                         + 
+--R                                4 12 2
+--R                           - 12b d  e
+--R                      *
+--R                             2
+--R                         %%Z0
+--R                     + 
+--R                           3     10      2 2 4 7      4 10
+--R                       (24a b d e   - 36a b d e  + 12b d  e)p %%Z0
+--R                     + 
+--R                           2 2 2 6        3 5 3     4 8  2
+--R                       (24a b d e  + 60a b d e  - 3b d )p
+--R                  /
+--R                       4 14      3   3 11      2 2 6 8        3 9 5     4 12 2
+--R                     4a e   - 16a b d e   + 24a b d e  - 16a b d e  + 4b d  e
+--R            + 
+--R                  2 2 8          5 5      2 8 2     2
+--R              (12a d e  - 24a b d e  + 12b d e )%%Z0
+--R            + 
+--R                   2 7          3 4      2 6                  4      2 3   2
+--R              (- 2a e  - 32a b d e  - 20b d e)p %%Z0 + (2a b e  + 16b d e)p x
+--R            + 
+--R                       3     2 4  2
+--R              (2a b d e  + 7b d )p
+--R     + 
+--R                    2 9         3 6     2 6 3  2
+--R               (- 2a e  + 4a b d e  - 2b d e )x
+--R             + 
+--R                  2   8         4 5     2 7 2       2 2 7         5 4     2 8
+--R             (- 4a d e  + 8a b d e  - 4b d e )x - 2a d e  + 4a b d e  - 2b d e
+--R          *
+--R             ROOT
+--R                             4 14      3   3 11      2 2 6 8        3 9 5
+--R                        - 12a e   + 48a b d e   - 72a b d e  + 48a b d e
+--R                      + 
+--R                             4 12 2
+--R                        - 12b d  e
+--R                   *
+--R                          2
+--R                      %%Z0
+--R                  + 
+--R                        3     10      2 2 4 7      4 10
+--R                    (24a b d e   - 36a b d e  + 12b d  e)p %%Z0
+--R                  + 
+--R                        2 2 2 6        3 5 3     4 8  2
+--R                    (24a b d e  + 60a b d e  - 3b d )p
+--R               /
+--R                    4 14      3   3 11      2 2 6 8        3 9 5     4 12 2
+--R                  4a e   - 16a b d e   + 24a b d e  - 16a b d e  + 4b d  e
+--R         + 
+--R                    2 9         3 6     2 6 3  2
+--R               (- 2a e  + 4a b d e  - 2b d e )x
+--R             + 
+--R                  2   8         4 5     2 7 2       2 2 7         5 4     2 8
+--R             (- 4a d e  + 8a b d e  - 4b d e )x - 2a d e  + 4a b d e  - 2b d e
+--R          *
+--R             %%Z0
+--R         + 
+--R                    5     2 4 2    2           2 4     2 5
+--R           (6a b d e  + 3b d e )p x  + (12a b d e  + 6b d e)p x
+--R         + 
+--R                  3 3     2 6
+--R           (6a b d e  + 3b d )p
+--R      *
+--R         log
+--R                        2 2 8          5 5      2 8 2
+--R                  (- 12a d e  + 24a b d e  - 12b d e )%%Z0
+--R                + 
+--R                       2 7         3 4     2 6
+--R                  (- 2a e  + 4a b d e  - 2b d e)p
+--R             *
+--R                ROOT
+--R                                4 14      3   3 11      2 2 6 8        3 9 5
+--R                           - 12a e   + 48a b d e   - 72a b d e  + 48a b d e
+--R                         + 
+--R                                4 12 2
+--R                           - 12b d  e
+--R                      *
+--R                             2
+--R                         %%Z0
+--R                     + 
+--R                           3     10      2 2 4 7      4 10
+--R                       (24a b d e   - 36a b d e  + 12b d  e)p %%Z0
+--R                     + 
+--R                           2 2 2 6        3 5 3     4 8  2
+--R                       (24a b d e  + 60a b d e  - 3b d )p
+--R                  /
+--R                       4 14      3   3 11      2 2 6 8        3 9 5     4 12 2
+--R                     4a e   - 16a b d e   + 24a b d e  - 16a b d e  + 4b d  e
+--R            + 
+--R                  2 2 8          5 5      2 8 2     2
+--R              (12a d e  - 24a b d e  + 12b d e )%%Z0
+--R            + 
+--R                   2 7          3 4      2 6                  4      2 3   2
+--R              (- 2a e  - 32a b d e  - 20b d e)p %%Z0 + (2a b e  + 16b d e)p x
+--R            + 
+--R                       3     2 4  2
+--R              (2a b d e  + 7b d )p
+--R     + 
+--R                     6       3 3    2          5       4 2
+--R                 (a e  + 2b d e )p x  + (2a d e  + 4b d e )p x
+--R               + 
+--R                     2 4       5
+--R                 (a d e  + 2b d e)p
+--R          *
+--R             3+-+3+-+2
+--R             \|a \|b
+--R         + 
+--R                2 4   2       3 3          4 2  3+-+2 3+-+
+--R           (3b d e p x  + 6b d e p x + 3b d e p)\|a   \|b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                      6       3 3    2            5       4 2
+--R               (- 2a e  - 4b d e )p x  + (- 4a d e  - 8b d e )p x
+--R             + 
+--R                      2 4       5
+--R               (- 2a d e  - 4b d e)p
+--R          *
+--R             3+-+3+-+2
+--R             \|a \|b
+--R         + 
+--R                  2 4   2        3 3          4 2  3+-+2 3+-+
+--R           (- 6b d e p x  - 12b d e p x - 6b d e p)\|a   \|b
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R          2 6         3 3     2 6           3     p
+--R       (2a e  - 4a b d e  + 2b d )log(c (b x  + a) )
+--R     + 
+--R              2 9         3 6     2 6 3  2      2   8          4 5     2 7 2
+--R           (4a e  - 8a b d e  + 4b d e )x  + (8a d e  - 16a b d e  + 8b d e )x
+--R         + 
+--R             2 2 7         5 4     2 8
+--R           4a d e  - 8a b d e  + 4b d e
+--R      *
+--R         %%Z0
+--R      *
+--R         log
+--R                    2 2 8          5 5      2 8 2     2
+--R              (- 12a d e  + 24a b d e  - 12b d e )%%Z0
+--R            + 
+--R                 2 7          3 4      2 6                 4     2 3   2
+--R              (2a e  + 32a b d e  + 20b d e)p %%Z0 + (a b e  + 8b d e)p x
+--R            + 
+--R                         3     2 4  2
+--R              (- 2a b d e  - 7b d )p
+--R     + 
+--R                      6       3 3    2            5       4 2
+--R               (- 2a e  - 4b d e )p x  + (- 4a d e  - 8b d e )p x
+--R             + 
+--R                      2 4       5
+--R               (- 2a d e  - 4b d e)p
+--R          *
+--R              +-+3+-+3+-+2
+--R             \|3 \|a \|b
+--R         + 
+--R                2 4   2        3 3          4 2   +-+3+-+2 3+-+
+--R           (6b d e p x  + 12b d e p x + 6b d e p)\|3 \|a   \|b
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R                      5     2 4 2    2            2 4     2 5
+--R           (- 4a b d e  - 2b d e )p x  + (- 8a b d e  - 4b d e)p x
+--R         + 
+--R                2 6     2 6
+--R           (- 2a e  - 4b d )p
+--R      *
+--R                3
+--R         log(b x  + a)
+--R     + 
+--R            2 6         3 3     2 6
+--R       (- 2a e  + 4a b d e  - 2b d )log(c)
+--R  /
+--R          2 9         3 6     2 6 3  2      2   8          4 5     2 7 2
+--R       (4a e  - 8a b d e  + 4b d e )x  + (8a d e  - 16a b d e  + 8b d e )x
+--R     + 
+--R         2 2 7         5 4     2 8
+--R       4a d e  - 8a b d e  + 4b d e
+--R                                                    Type: Expression(Integer)
+--E 2267
+
+--S 2268 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2268
+
+)clear all
+
+--S 2269 of 5341
+t0:=log(a+b/x)/(c+d*x)
+--R 
+--R
+--R            a x + b
+--R        log(-------)
+--R               x
+--R   (1)  ------------
+--R           d x + c
+--R                                                    Type: Expression(Integer)
+--E 2269
+
+--S 2270 of 5341
+--r0:=log(a+b/x)*log(c+d*x)/d+log(-d*x/c)*log(c+d*x)/d-log(-d*(b+a*x)/_
+--  (a*c-b*d))*log(c+d*x)/d+polylog(2,(c+d*x)/c)/d-polylog(2,a*(c+d*x)/_
+--  (a*c-b*d))/d
+--E 2270
+
+--S 2271 of 5341
+--a0:=integrate(t0,x)
+--E 2271
+
+--S 2272 of 5341
+--m0:=a0-r0
+--E 2272
+
+--S 2273 of 5341
+--d0:=D(m0,x)
+--E 2273
+
+)clear all
+
+--S 2274 of 5341
+t0:=log(a+b*x^n)/(c+d*x)
+--R 
+--R
+--R               n
+--R        log(b x  + a)
+--R   (1)  -------------
+--R           d x + c
+--R                                                    Type: Expression(Integer)
+--E 2274
+
+--S 2275 of 5341
+--r0:=a*n*Int(log(c+d*x)/(x*(a+b*x^n)),x)/d-n*log(-d*x/c)*log(c+d*x)/d+_
+--  log(c+d*x)*log(a+b*x^n)/d-n*polylog(2,(c+d*x)/c)/d
+--E 2275
+
+--S 2276 of 5341
+--a0:=integrate(t0,x)
+--E 2276
+
+--S 2277 of 5341
+--m0:=a0-r0
+--E 2277
+
+--S 2278 of 5341
+--d0:=D(m0,x)
+--E 2278
+
+)clear all
+
+--S 2279 of 5341
+t0:=log(a*x)/(c+d*x)
+--R 
+--R
+--R        log(a x)
+--R   (1)  --------
+--R         d x + c
+--R                                                    Type: Expression(Integer)
+--E 2279
+
+--S 2280 of 5341
+--r0:=log(a*x)*log((c+d*x)/c)/d+polylog(2,-d*x/c)/d
+--E 2280
+
+--S 2281 of 5341
+--a0:=integrate(t0,x)
+--E 2281
+
+--S 2282 of 5341
+--m0:=a0-r0
+--E 2282
+
+--S 2283 of 5341
+--d0:=D(m0,x)
+--E 2283
+
+)clear all
+
+--S 2284 of 5341
+t0:=log(a/x)/(c+d*x)
+--R 
+--R
+--R             a
+--R         log(-)
+--R             x
+--R   (1)  -------
+--R        d x + c
+--R                                                    Type: Expression(Integer)
+--E 2284
+
+--S 2285 of 5341
+--r0:=log(a/x)*log((c+d*x)/c)/d-polylog(2,-d*x/c)/d
+--E 2285
+
+--S 2286 of 5341
+--a0:=integrate(t0,x)
+--E 2286
+
+--S 2287 of 5341
+--m0:=a0-r0
+--E 2287
+
+--S 2288 of 5341
+--d0:=D(m0,x)
+--E 2288
+
+)clear all
+
+--S 2289 of 5341
+t0:=log(a*x^n)/(c+d*x)
+--R 
+--R
+--R               n
+--R        log(a x )
+--R   (1)  ---------
+--R         d x + c
+--R                                                    Type: Expression(Integer)
+--E 2289
+
+--S 2290 of 5341
+--r0:=log(a*x^n)*log((c+d*x)/c)/d+n*polylog(2,-d*x/c)/d
+--E 2290
+
+--S 2291 of 5341
+--a0:=integrate(t0,x)
+--E 2291
+
+--S 2292 of 5341
+--m0:=a0-r0
+--E 2292
+
+--S 2293 of 5341
+--d0:=D(m0,x)
+--E 2293
+
+)clear all
+
+--S 2294 of 5341
+t0:=log(x^n)/(a+b*x)
+--R 
+--R
+--R             n
+--R        log(x )
+--R   (1)  -------
+--R        b x + a
+--R                                                    Type: Expression(Integer)
+--E 2294
+
+--S 2295 of 5341
+--r0:=log(x^n)*log((a+b*x)/a)/b+n*polylog(2,-b*x/a)/b
+--E 2295
+
+--S 2296 of 5341
+--a0:=integrate(t0,x)
+--E 2296
+
+--S 2297 of 5341
+--m0:=a0-r0
+--E 2297
+
+--S 2298 of 5341
+--d0:=D(m0,x)
+--E 2298
+
+)clear all
+
+--S 2299 of 5341
+t0:=x^3*log(c*(a+b*x)^p)/(d+e*x)
+--R 
+--R
+--R         3               p
+--R        x log(c (b x + a) )
+--R   (1)  -------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2299
+
+--S 2300 of 5341
+--r0:=-d^2*p*x/e^3-1/2*a*d*p*x/(b*e^2)-1/3*a^2*p*x/(b^2*e)+1/4*d*p*x^2/e^2+_
+--  1/6*a*p*x^2/(b*e)-1/9*p*x^3/e+1/2*a^2*d*p*log(a+b*x)/(b^2*e^2)+_
+--  1/3*a^3*p*log(a+b*x)/(b^3*e)-1/2*d*x^2*log(c*(a+b*x)^p)/e^2+1/3*x^3*_
+--  log(c*(a+b*x)^p)/e+d^2*(a+b*x)*log(c*(a+b*x)^p)/(b*e^3)-d^3*_
+--  log(c*(a+b*x)^p)*log(b*(d+e*x)/(b*d-a*e))/e^4-d^3*p*_
+--  polylog(2,-e*(a+b*x)/(b*d-a*e))/e^4
+--E 2300
+
+--S 2301 of 5341
+--a0:=integrate(t0,x)
+--E 2301
+
+--S 2302 of 5341
+--m0:=a0-r0
+--E 2302
+
+--S 2303 of 5341
+--d0:=D(m0,x)
+--E 2303
+
+)clear all
+
+--S 2304 of 5341
+t0:=x^2*log(c*(a+b*x)^p)/(d+e*x)
+--R 
+--R
+--R         2               p
+--R        x log(c (b x + a) )
+--R   (1)  -------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2304
+
+--S 2305 of 5341
+--r0:=d*p*x/e^2+1/2*a*p*x/(b*e)-1/4*p*x^2/e-1/2*a^2*p*log(a+b*x)/(b^2*e)+_
+--  1/2*x^2*log(c*(a+b*x)^p)/e-d*(a+b*x)*log(c*(a+b*x)^p)/(b*e^2)+d^2*_
+--  log(c*(a+b*x)^p)*log(b*(d+e*x)/(b*d-a*e))/e^3+d^2*p*_
+--  polylog(2,-e*(a+b*x)/(b*d-a*e))/e^3
+--E 2305
+
+--S 2306 of 5341
+--a0:=integrate(t0,x)
+--E 2306
+
+--S 2307 of 5341
+--m0:=a0-r0
+--E 2307
+
+--S 2308 of 5341
+--d0:=D(m0,x)
+--E 2308
+
+)clear all
+
+--S 2309 of 5341
+t0:=x*log(c*(a+b*x)^p)/(d+e*x)
+--R 
+--R
+--R                         p
+--R        x log(c (b x + a) )
+--R   (1)  -------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2309
+
+--S 2310 of 5341
+--r0:=-p*x/e+(a+b*x)*log(c*(a+b*x)^p)/(b*e)-d*log(c*(a+b*x)^p)*_
+--  log(b*(d+e*x)/(b*d-a*e))/e^2-d*p*polylog(2,-e*(a+b*x)/(b*d-a*e))/e^2
+--E 2310
+
+--S 2311 of 5341
+--a0:=integrate(t0,x)
+--E 2311
+
+--S 2312 of 5341
+--m0:=a0-r0
+--E 2312
+
+--S 2313 of 5341
+--d0:=D(m0,x)
+--E 2313
+
+)clear all
+
+--S 2314 of 5341
+t0:=log(c*(a+b*x)^p)/(d+e*x)
+--R 
+--R
+--R                       p
+--R        log(c (b x + a) )
+--R   (1)  -----------------
+--R             e x + d
+--R                                                    Type: Expression(Integer)
+--E 2314
+
+--S 2315 of 5341
+--r0:=log(c*(a+b*x)^p)*log(b*(d+e*x)/(b*d-a*e))/e+_
+--  p*polylog(2,-e*(a+b*x)/(b*d-a*e))/e
+--E 2315
+
+--S 2316 of 5341
+--a0:=integrate(t0,x)
+--E 2316
+
+--S 2317 of 5341
+--m0:=a0-r0
+--E 2317
+
+--S 2318 of 5341
+--d0:=D(m0,x)
+--E 2318
+
+)clear all
+
+--S 2319 of 5341
+t0:=log(c*(a+b*x)^p)/(x*(d+e*x))
+--R 
+--R
+--R                       p
+--R        log(c (b x + a) )
+--R   (1)  -----------------
+--R               2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2319
+
+--S 2320 of 5341
+--r0:=log(-b*x/a)*log(c*(a+b*x)^p)/d-log(c*(a+b*x)^p)*log(b*(d+e*x)/_
+--  (b*d-a*e))/d+p*polylog(2,(a+b*x)/a)/d-p*polylog(2,-e*(a+b*x)/(b*d-a*e))/d
+--E 2320
+
+--S 2321 of 5341
+--a0:=integrate(t0,x)
+--E 2321
+
+--S 2322 of 5341
+--m0:=a0-r0
+--E 2322
+
+--S 2323 of 5341
+--d0:=D(m0,x)
+--E 2323
+
+)clear all
+
+--S 2324 of 5341
+t0:=log(c*(a+b*x)^p)/(x^2*(d+e*x))
+--R 
+--R
+--R                       p
+--R        log(c (b x + a) )
+--R   (1)  -----------------
+--R              3      2
+--R           e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2324
+
+--S 2325 of 5341
+--r0:=b*p*log(x)/(a*d)-b*p*log(a+b*x)/(a*d)-log(c*(a+b*x)^p)/(d*x)-_
+--  e*log(-b*x/a)*log(c*(a+b*x)^p)/d^2+e*log(c*(a+b*x)^p)*log(b*(d+e*x)/_
+--  (b*d-a*e))/d^2-e*p*polylog(2,(a+b*x)/a)/d^2+e*p*polylog(2,-e*(a+b*x)/_
+--  (b*d-a*e))/d^2
+--E 2325
+
+--S 2326 of 5341
+--a0:=integrate(t0,x)
+--E 2326
+
+--S 2327 of 5341
+--m0:=a0-r0
+--E 2327
+
+--S 2328 of 5341
+--d0:=D(m0,x)
+--E 2328
+
+)clear all
+
+--S 2329 of 5341
+t0:=log(c*(a+b*x)^p)/(x^3*(d+e*x))
+--R 
+--R
+--R                       p
+--R        log(c (b x + a) )
+--R   (1)  -----------------
+--R              4      3
+--R           e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2329
+
+--S 2330 of 5341
+--r0:=-1/2*b*p/(a*d*x)-1/2*b^2*p*log(x)/(a^2*d)-b*e*p*log(x)/(a*d^2)+_
+--  1/2*b^2*p*log(a+b*x)/(a^2*d)+b*e*p*log(a+b*x)/(a*d^2)-1/2*log(c*(a+_
+--  b*x)^p)/(d*x^2)+e*log(c*(a+b*x)^p)/(d^2*x)+e^2*log(-b*x/a)*log(c*(a+_
+--  b*x)^p)/d^3-e^2*log(c*(a+b*x)^p)*log(b*(d+e*x)/(b*d-a*e))/d^3+e^2*p*_
+--  polylog(2,(a+b*x)/a)/d^3-e^2*p*polylog(2,-e*(a+b*x)/(b*d-a*e))/d^3
+--E 2330
+
+--S 2331 of 5341
+--a0:=integrate(t0,x)
+--E 2331
+
+--S 2332 of 5341
+--m0:=a0-r0
+--E 2332
+
+--S 2333 of 5341
+--d0:=D(m0,x)
+--E 2333
+
+)clear all
+
+--S 2334 of 5341
+t0:=x^3*log(c*(a+b*x^2)^p)/(d+e*x)
+--R 
+--R
+--R         3          2     p
+--R        x log(c (b x  + a) )
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2334
+
+--S 2335 of 5341
+--r0:=-2*d^2*p*x/e^3+2/3*a*p*x/(b*e)+1/2*d*p*x^2/e^2-2/9*p*x^3/e-_
+--  2/3*a^(3/2)*p*atan(x*sqrt(b)/sqrt(a))/(b^(3/2)*e)+d^2*x*log(c*(a+_
+--  b*x^2)^p)/e^3+1/3*x^3*log(c*(a+b*x^2)^p)/e-1/2*d*(a+b*x^2)*log(c*_
+--  (a+b*x^2)^p)/(b*e^2)-d^3*log(d+e*x)*log(c*(a+b*x^2)^p)/e^4+d^3*p*_
+--  log(d+e*x)*log(e*(sqrt(-a)-x*sqrt(b))/(e*sqrt(-a)+d*sqrt(b)))/e^4+_
+--  d^3*p*log(d+e*x)*log(-e*(sqrt(-a)+x*sqrt(b))/(-e*sqrt(-a)+d*sqrt(b)))/_
+--  e^4+d^3*p*polylog(2,(d+e*x)*sqrt(b)/(-e*sqrt(-a)+d*sqrt(b)))/e^4+_
+--  d^3*p*polylog(2,(d+e*x)*sqrt(b)/(e*sqrt(-a)+d*sqrt(b)))/e^4+2*d^2*p*_
+--  atan(x*sqrt(b)/sqrt(a))*sqrt(a)/(e^3*sqrt(b))
+--E 2335
+
+--S 2336 of 5341
+--a0:=integrate(t0,x)
+--E 2336
+
+--S 2337 of 5341
+--m0:=a0-r0
+--E 2337
+
+--S 2338 of 5341
+--d0:=D(m0,x)
+--E 2338
+
+)clear all
+
+--S 2339 of 5341
+t0:=x^2*log(c*(a+b*x^2)^p)/(d+e*x)
+--R 
+--R
+--R         2          2     p
+--R        x log(c (b x  + a) )
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2339
+
+--S 2340 of 5341
+--r0:=2*d*p*x/e^2-1/2*p*x^2/e-d*x*log(c*(a+b*x^2)^p)/e^2+1/2*(a+b*x^2)*_
+--  log(c*(a+b*x^2)^p)/(b*e)+d^2*log(d+e*x)*log(c*(a+b*x^2)^p)/e^3-_
+--  d^2*p*log(d+e*x)*log(e*(sqrt(-a)-x*sqrt(b))/(e*sqrt(-a)+d*sqrt(b)))/e^3-_
+--  d^2*p*log(d+e*x)*log(-e*(sqrt(-a)+x*sqrt(b))/(-e*sqrt(-a)+d*sqrt(b)))/_
+--  e^3-d^2*p*polylog(2,(d+e*x)*sqrt(b)/(-e*sqrt(-a)+d*sqrt(b)))/e^3-_
+--  d^2*p*polylog(2,(d+e*x)*sqrt(b)/(e*sqrt(-a)+d*sqrt(b)))/e^3-2*d*p*_
+--  atan(x*sqrt(b)/sqrt(a))*sqrt(a)/(e^2*sqrt(b))
+--E 2340
+
+--S 2341 of 5341
+--a0:=integrate(t0,x)
+--E 2341
+
+--S 2342 of 5341
+--m0:=a0-r0
+--E 2342
+
+--S 2343 of 5341
+--d0:=D(m0,x)
+--E 2343
+
+)clear all
+
+--S 2344 of 5341
+t0:=x*log(c*(a+b*x^2)^p)/(d+e*x)
+--R 
+--R
+--R                    2     p
+--R        x log(c (b x  + a) )
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2344
+
+--S 2345 of 5341
+--r0:=-2*p*x/e+x*log(c*(a+b*x^2)^p)/e-d*log(d+e*x)*log(c*(a+b*x^2)^p)/e^2+_
+--  d*p*log(d+e*x)*log(e*(sqrt(-a)-x*sqrt(b))/(e*sqrt(-a)+d*sqrt(b)))/e^2+_
+--  d*p*log(d+e*x)*log(-e*(sqrt(-a)+x*sqrt(b))/(-e*sqrt(-a)+d*sqrt(b)))/e^2+_
+--  d*p*polylog(2,(d+e*x)*sqrt(b)/(-e*sqrt(-a)+d*sqrt(b)))/e^2+d*p*_
+--  polylog(2,(d+e*x)*sqrt(b)/(e*sqrt(-a)+d*sqrt(b)))/e^2+2*p*atan(x*_
+--  sqrt(b)/sqrt(a))*sqrt(a)/(e*sqrt(b))
+--E 2345
+
+--S 2346 of 5341
+--a0:=integrate(t0,x)
+--E 2346
+
+--S 2347 of 5341
+--m0:=a0-r0
+--E 2347
+
+--S 2348 of 5341
+--d0:=D(m0,x)
+--E 2348
+
+)clear all
+
+--S 2349 of 5341
+t0:=log(c*(a+b*x^2)^p)/(d+e*x)
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2349
+
+--S 2350 of 5341
+--r0:=log(d+e*x)*log(c*(a+b*x^2)^p)/e-p*log(d+e*x)*log(e*(sqrt(-a)-_
+--  x*sqrt(b))/(e*sqrt(-a)+d*sqrt(b)))/e-p*log(d+e*x)*log(-e*(sqrt(-a)+_
+--  x*sqrt(b))/(-e*sqrt(-a)+d*sqrt(b)))/e-p*polylog(2,(d+e*x)*sqrt(b)/_
+--  (-e*sqrt(-a)+d*sqrt(b)))/e-p*polylog(2,(d+e*x)*sqrt(b)/(e*sqrt(-a)+_
+--  d*sqrt(b)))/e
+--E 2350
+
+--S 2351 of 5341
+--a0:=integrate(t0,x)
+--E 2351
+
+--S 2352 of 5341
+--m0:=a0-r0
+--E 2352
+
+--S 2353 of 5341
+--d0:=D(m0,x)
+--E 2353
+
+)clear all
+
+--S 2354 of 5341
+t0:=log(c*(a+b*x^2)^p)/(x*(d+e*x))
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R               2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2354
+
+--S 2355 of 5341
+--r0:=1/2*log(-b*x^2/a)*log(c*(a+b*x^2)^p)/d-log(d+e*x)*log(c*(a+b*x^2)^p)/d+_
+--  p*log(d+e*x)*log(e*(sqrt(-a)-x*sqrt(b))/(e*sqrt(-a)+d*sqrt(b)))/d+_
+--  p*log(d+e*x)*log(-e*(sqrt(-a)+x*sqrt(b))/(-e*sqrt(-a)+d*sqrt(b)))/d+_
+--  1/2*p*polylog(2,(a+b*x^2)/a)/d+p*polylog(2,(d+e*x)*sqrt(b)/(-e*_
+--  sqrt(-a)+d*sqrt(b)))/d+p*polylog(2,(d+e*x)*sqrt(b)/(e*sqrt(-a)+_
+--  d*sqrt(b)))/d
+--E 2355
+
+--S 2356 of 5341
+--a0:=integrate(t0,x)
+--E 2356
+
+--S 2357 of 5341
+--m0:=a0-r0
+--E 2357
+
+--S 2358 of 5341
+--d0:=D(m0,x)
+--E 2358
+
+)clear all
+
+--S 2359 of 5341
+t0:=log(c*(a+b*x^2)^p)/(x^2*(d+e*x))
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R               3      2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2359
+
+--S 2360 of 5341
+--r0:=-log(c*(a+b*x^2)^p)/(d*x)-1/2*e*log(-b*x^2/a)*log(c*(a+b*x^2)^p)/d^2+_
+--  e*log(d+e*x)*log(c*(a+b*x^2)^p)/d^2-e*p*log(d+e*x)*log(e*(sqrt(-a)-_
+--  x*sqrt(b))/(e*sqrt(-a)+d*sqrt(b)))/d^2-e*p*log(d+e*x)*log(-e*(sqrt(-a)+_
+--  x*sqrt(b))/(-e*sqrt(-a)+d*sqrt(b)))/d^2-1/2*e*p*polylog(2,(a+b*x^2)/a)/_
+--  d^2-e*p*polylog(2,(d+e*x)*sqrt(b)/(-e*sqrt(-a)+d*sqrt(b)))/d^2-_
+--  e*p*polylog(2,(d+e*x)*sqrt(b)/(e*sqrt(-a)+d*sqrt(b)))/d^2+2*p*_
+--  atan(x*sqrt(b)/sqrt(a))*sqrt(b)/(d*sqrt(a))
+--E 2360
+
+--S 2361 of 5341
+--a0:=integrate(t0,x)
+--E 2361
+
+--S 2362 of 5341
+--m0:=a0-r0
+--E 2362
+
+--S 2363 of 5341
+--d0:=D(m0,x)
+--E 2363
+
+)clear all
+
+--S 2364 of 5341
+t0:=log(c*(a+b*x^2)^p)/(x^3*(d+e*x))
+--R 
+--R
+--R                  2     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R               4      3
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2364
+
+--S 2365 of 5341
+--r0:=b*p*log(x)/(a*d)-1/2*b*p*log(a+b*x^2)/(a*d)-1/2*log(c*(a+b*x^2)^p)/_
+--  (d*x^2)+e*log(c*(a+b*x^2)^p)/(d^2*x)+1/2*e^2*log(-b*x^2/a)*log(c*_
+--  (a+b*x^2)^p)/d^3-e^2*log(d+e*x)*log(c*(a+b*x^2)^p)/d^3+e^2*p*_
+--  log(d+e*x)*log(e*(sqrt(-a)-x*sqrt(b))/(e*sqrt(-a)+d*sqrt(b)))/d^3+_
+--  e^2*p*log(d+e*x)*log(-e*(sqrt(-a)+x*sqrt(b))/(-e*sqrt(-a)+d*_
+--  sqrt(b)))/d^3+1/2*e^2*p*polylog(2,(a+b*x^2)/a)/d^3+e^2*p*_
+--  polylog(2,(d+e*x)*sqrt(b)/(-e*sqrt(-a)+d*sqrt(b)))/d^3+e^2*p*_
+--  polylog(2,(d+e*x)*sqrt(b)/(e*sqrt(-a)+d*sqrt(b)))/d^3-2*e*p*_
+--  atan(x*sqrt(b)/sqrt(a))*sqrt(b)/(d^2*sqrt(a))
+--E 2365
+
+--S 2366 of 5341
+--a0:=integrate(t0,x)
+--E 2366
+
+--S 2367 of 5341
+--m0:=a0-r0
+--E 2367
+
+--S 2368 of 5341
+--d0:=D(m0,x)
+--E 2368
+
+)clear all
+
+--S 2369 of 5341
+t0:=x^3*log(c*(a+b*x^3)^p)/(d+e*x)
+--R 
+--R
+--R         3          3     p
+--R        x log(c (b x  + a) )
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2369
+
+--S 2370 of 5341
+--r0:=-3*d^2*p*x/e^3+3/4*d*p*x^2/e^2-1/3*p*x^3/e+a^(1/3)*d^2*p*log(a^(1/3)+_
+--  b^(1/3)*x)/(b^(1/3)*e^3)+1/2*a^(2/3)*d*p*log(a^(1/3)+b^(1/3)*x)/_
+--  (b^(2/3)*e^2)+d^3*p*log(-e*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-a^(1/3)*e))*_
+--  log(d+e*x)/e^4+d^3*p*log(-e*((-1)^(2/3)*a^(1/3)+b^(1/3)*x)/(b^(1/3)*_
+--  d-(-1)^(2/3)*a^(1/3)*e))*log(d+e*x)/e^4+d^3*p*log((-1)^(1/3)*e*_
+--  (a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/(b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e))*_
+--  log(d+e*x)/e^4-1/2*a^(1/3)*d^2*p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+_
+--  b^(2/3)*x^2)/(b^(1/3)*e^3)-1/4*a^(2/3)*d*p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+_
+--  b^(2/3)*x^2)/(b^(2/3)*e^2)+d^2*x*log(c*(a+b*x^3)^p)/e^3-1/2*d*x^2*_
+--  log(c*(a+b*x^3)^p)/e^2+1/3*(a+b*x^3)*log(c*(a+b*x^3)^p)/(b*e)-d^3*_
+--  log(d+e*x)*log(c*(a+b*x^3)^p)/e^4+d^3*p*polylog(2,b^(1/3)*(d+e*x)/_
+--  (b^(1/3)*d-a^(1/3)*e))/e^4+d^3*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d+_
+--  (-1)^(1/3)*a^(1/3)*e))/e^4+d^3*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-_
+--  (-1)^(2/3)*a^(1/3)*e))/e^4-a^(1/3)*d^2*p*atan((a^(1/3)-2*b^(1/3)*x)/_
+--  (a^(1/3)*sqrt(3)))*sqrt(3)/(b^(1/3)*e^3)+1/2*a^(2/3)*d*p*atan((a^(1/3)-_
+--  2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/(b^(2/3)*e^2)
+--E 2370
+
+--S 2371 of 5341
+--a0:=integrate(t0,x)
+--E 2371
+
+--S 2372 of 5341
+--m0:=a0-r0
+--E 2372
+
+--S 2373 of 5341
+--d0:=D(m0,x)
+--E 2373
+
+)clear all
+
+--S 2374 of 5341
+t0:=x^2*log(c*(a+b*x^3)^p)/(d+e*x)
+--R 
+--R
+--R         2          3     p
+--R        x log(c (b x  + a) )
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2374
+
+--S 2375 of 5341
+--r0:=3*d*p*x/e^2-3/4*p*x^2/e-a^(1/3)*d*p*log(a^(1/3)+b^(1/3)*x)/(b^(1/3)*_
+--  e^2)-1/2*a^(2/3)*p*log(a^(1/3)+b^(1/3)*x)/(b^(2/3)*e)-d^2*p*_
+--  log(-e*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-a^(1/3)*e))*log(d+e*x)/e^3-_
+--  d^2*p*log(-e*((-1)^(2/3)*a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-(-1)^(2/3)*_
+--  a^(1/3)*e))*log(d+e*x)/e^3-d^2*p*log((-1)^(1/3)*e*(a^(1/3)+(-1)^(2/3)*_
+--  b^(1/3)*x)/(b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e))*log(d+e*x)/e^3+1/2*_
+--  a^(1/3)*d*p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(b^(1/3)*e^2)+_
+--  1/4*a^(2/3)*p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(b^(2/3)*e)-_
+--  d*x*log(c*(a+b*x^3)^p)/e^2+1/2*x^2*log(c*(a+b*x^3)^p)/e+d^2*log(d+e*x)*_
+--  log(c*(a+b*x^3)^p)/e^3-d^2*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-_
+--  a^(1/3)*e))/e^3-d^2*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d+(-1)^(1/3)*_
+--  a^(1/3)*e))/e^3-d^2*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-(-1)^(2/3)*_
+--  a^(1/3)*e))/e^3+a^(1/3)*d*p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+--  sqrt(3)))*sqrt(3)/(b^(1/3)*e^2)-1/2*a^(2/3)*p*atan((a^(1/3)-_
+--  2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/(b^(2/3)*e)
+--E 2375
+
+--S 2376 of 5341
+--a0:=integrate(t0,x)
+--E 2376
+
+--S 2377 of 5341
+--m0:=a0-r0
+--E 2377
+
+--S 2378 of 5341
+--d0:=D(m0,x)
+--E 2378
+
+)clear all
+
+--S 2379 of 5341
+t0:=x*log(c*(a+b*x^3)^p)/(d+e*x)
+--R 
+--R
+--R                    3     p
+--R        x log(c (b x  + a) )
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2379
+
+--S 2380 of 5341
+--r0:=-3*p*x/e+a^(1/3)*p*log(a^(1/3)+b^(1/3)*x)/(b^(1/3)*e)+d*p*_
+--  log(-e*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-a^(1/3)*e))*log(d+e*x)/e^2+_
+--  d*p*log(-e*((-1)^(2/3)*a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-(-1)^(2/3)*_
+--  a^(1/3)*e))*log(d+e*x)/e^2+d*p*log((-1)^(1/3)*e*(a^(1/3)+(-1)^(2/3)*_
+--  b^(1/3)*x)/(b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e))*log(d+e*x)/e^2-1/2*_
+--  a^(1/3)*p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(b^(1/3)*e)+_
+--  x*log(c*(a+b*x^3)^p)/e-d*log(d+e*x)*log(c*(a+b*x^3)^p)/e^2+d*p*_
+--  polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-a^(1/3)*e))/e^2+d*p*_
+--  polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e))/e^2+d*p*_
+--  polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-(-1)^(2/3)*a^(1/3)*e))/e^2-_
+--  a^(1/3)*p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/_
+--  (b^(1/3)*e)
+--E 2380
+
+--S 2381 of 5341
+--a0:=integrate(t0,x)
+--E 2381
+
+--S 2382 of 5341
+--m0:=a0-r0
+--E 2382
+
+--S 2383 of 5341
+--d0:=D(m0,x)
+--E 2383
+
+)clear all
+
+--S 2384 of 5341
+t0:=log(c*(a+b*x^3)^p)/(d+e*x)
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2384
+
+--S 2385 of 5341
+--r0:=-p*log(-e*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-a^(1/3)*e))*log(d+e*x)/e-_
+--  p*log(-e*((-1)^(2/3)*a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-(-1)^(2/3)*_
+--  a^(1/3)*e))*log(d+e*x)/e-p*log((-1)^(1/3)*e*(a^(1/3)+(-1)^(2/3)*_
+--  b^(1/3)*x)/(b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e))*log(d+e*x)/e+log(d+e*x)*_
+--  log(c*(a+b*x^3)^p)/e-p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-_
+--  a^(1/3)*e))/e-p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d+(-1)^(1/3)*_
+--  a^(1/3)*e))/e-p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-(-1)^(2/3)*_
+--  a^(1/3)*e))/e
+--E 2385
+
+--S 2386 of 5341
+--a0:=integrate(t0,x)
+--E 2386
+
+--S 2387 of 5341
+--m0:=a0-r0
+--E 2387
+
+--S 2388 of 5341
+--d0:=D(m0,x)
+--E 2388
+
+)clear all
+
+--S 2389 of 5341
+t0:=log(c*(a+b*x^3)^p)/(x*(d+e*x))
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R               2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2389
+
+--S 2390 of 5341
+--r0:=p*log(-e*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-a^(1/3)*e))*log(d+e*x)/d+_
+--  p*log(-e*((-1)^(2/3)*a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-(-1)^(2/3)*_
+--  a^(1/3)*e))*log(d+e*x)/d+p*log((-1)^(1/3)*e*(a^(1/3)+(-1)^(2/3)*_
+--  b^(1/3)*x)/(b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e))*log(d+e*x)/d+1/3*_
+--  log(-b*x^3/a)*log(c*(a+b*x^3)^p)/d-log(d+e*x)*log(c*(a+b*x^3)^p)/d+_
+--  p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-a^(1/3)*e))/d+_
+--  p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e))/d+_
+--  p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-(-1)^(2/3)*a^(1/3)*e))/d+_
+--  1/3*p*polylog(2,(a+b*x^3)/a)/d
+--E 2390
+
+--S 2391 of 5341
+--a0:=integrate(t0,x)
+--E 2391
+
+--S 2392 of 5341
+--m0:=a0-r0
+--E 2392
+
+--S 2393 of 5341
+--d0:=D(m0,x)
+--E 2393
+
+)clear all
+
+--S 2394 of 5341
+t0:=log(c*(a+b*x^3)^p)/(x^2*(d+e*x))
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R               3      2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2394
+
+--S 2395 of 5341
+--r0:=-b^(1/3)*p*log(a^(1/3)+b^(1/3)*x)/(a^(1/3)*d)-e*p*log(-e*(a^(1/3)+_
+--  b^(1/3)*x)/(b^(1/3)*d-a^(1/3)*e))*log(d+e*x)/d^2-e*p*log(-e*((-1)^(2/3)*_
+--  a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-(-1)^(2/3)*a^(1/3)*e))*log(d+e*x)/d^2-_
+--  e*p*log((-1)^(1/3)*e*(a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/(b^(1/3)*d+_
+--  (-1)^(1/3)*a^(1/3)*e))*log(d+e*x)/d^2+1/2*b^(1/3)*p*log(a^(2/3)-_
+--  a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(1/3)*d)-log(c*(a+b*x^3)^p)/(d*x)-_
+--  1/3*e*log(-b*x^3/a)*log(c*(a+b*x^3)^p)/d^2+e*log(d+e*x)*log(c*_
+--  (a+b*x^3)^p)/d^2-e*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-_
+--  a^(1/3)*e))/d^2-e*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d+(-1)^(1/3)*_
+--  a^(1/3)*e))/d^2-e*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-(-1)^(2/3)*_
+--  a^(1/3)*e))/d^2-1/3*e*p*polylog(2,(a+b*x^3)/a)/d^2-b^(1/3)*p*_
+--  atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/(a^(1/3)*d)
+--E 2395
+
+--S 2396 of 5341
+--a0:=integrate(t0,x)
+--E 2396
+
+--S 2397 of 5341
+--m0:=a0-r0
+--E 2397
+
+--S 2398 of 5341
+--d0:=D(m0,x)
+--E 2398
+
+)clear all
+
+--S 2399 of 5341
+t0:=log(c*(a+b*x^3)^p)/(x^3*(d+e*x))
+--R 
+--R
+--R                  3     p
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R               4      3
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2399
+
+--S 2400 of 5341
+--r0:=1/2*b^(2/3)*p*log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*d)+b^(1/3)*e*p*_
+--  log(a^(1/3)+b^(1/3)*x)/(a^(1/3)*d^2)+e^2*p*log(-e*(a^(1/3)+_
+--  b^(1/3)*x)/(b^(1/3)*d-a^(1/3)*e))*log(d+e*x)/d^3+e^2*p*log(-e*_
+--  ((-1)^(2/3)*a^(1/3)+b^(1/3)*x)/(b^(1/3)*d-(-1)^(2/3)*a^(1/3)*e))*_
+--  log(d+e*x)/d^3+e^2*p*log((-1)^(1/3)*e*(a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/_
+--  (b^(1/3)*d+(-1)^(1/3)*a^(1/3)*e))*log(d+e*x)/d^3-1/4*b^(2/3)*p*_
+--  log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(2/3)*d)-1/2*b^(1/3)*_
+--  e*p*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(1/3)*d^2)-_
+--  1/2*log(c*(a+b*x^3)^p)/(d*x^2)+e*log(c*(a+b*x^3)^p)/(d^2*x)+_
+--  1/3*e^2*log(-b*x^3/a)*log(c*(a+b*x^3)^p)/d^3-e^2*log(d+e*x)*_
+--  log(c*(a+b*x^3)^p)/d^3+e^2*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-_
+--  a^(1/3)*e))/d^3+e^2*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d+(-1)^(1/3)*_
+--  a^(1/3)*e))/d^3+e^2*p*polylog(2,b^(1/3)*(d+e*x)/(b^(1/3)*d-(-1)^(2/3)*_
+--  a^(1/3)*e))/d^3+1/3*e^2*p*polylog(2,(a+b*x^3)/a)/d^3-1/2*b^(2/3)*_
+--  p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*sqrt(3)/(a^(2/3)*d)+_
+--  b^(1/3)*e*p*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))*_
+--  sqrt(3)/(a^(1/3)*d^2)
+--E 2400
+
+--S 2401 of 5341
+--a0:=integrate(t0,x)
+--E 2401
+
+--S 2402 of 5341
+--m0:=a0-r0
+--E 2402
+
+--S 2403 of 5341
+--d0:=D(m0,x)
+--E 2403
+
+)clear all
+
+--S 2404 of 5341
+t0:=x^3*log(c*(a+b/x)^p)/(d+e*x)
+--R 
+--R
+--R         3       a x + b p
+--R        x log(c (-------) )
+--R                    x
+--R   (1)  -------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2404
+
+--S 2405 of 5341
+--r0:=-1/2*b*d*p*x/(a*e^2)-1/3*b^2*p*x/(a^2*e)+1/6*b*p*x^2/(a*e)+d^2*x*_
+--  log(c*(a+b/x)^p)/e^3-1/2*d*x^2*log(c*(a+b/x)^p)/e^2+1/3*x^3*_
+--  log(c*(a+b/x)^p)/e+b*d^2*p*log(b+a*x)/(a*e^3)+1/2*b^2*d*p*log(b+_
+--  a*x)/(a^2*e^2)+1/3*b^3*p*log(b+a*x)/(a^3*e)-d^3*log(c*(a+b/x)^p)*_
+--  log(d+e*x)/e^4-d^3*p*log(-e*x/d)*log(d+e*x)/e^4+d^3*p*_
+--  log(-e*(b+a*x)/(a*d-b*e))*log(d+e*x)/e^4-d^3*p*polylog(2,(d+e*x)/d)/e^4+_
+--  d^3*p*polylog(2,a*(d+e*x)/(a*d-b*e))/e^4
+--E 2405
+
+--S 2406 of 5341
+--a0:=integrate(t0,x)
+--E 2406
+
+--S 2407 of 5341
+--m0:=a0-r0
+--E 2407
+
+--S 2408 of 5341
+--d0:=D(m0,x)
+--E 2408
+
+)clear all
+
+--S 2409 of 5341
+t0:=x^2*log(c*(a+b/x)^p)/(d+e*x)
+--R 
+--R
+--R         2       a x + b p
+--R        x log(c (-------) )
+--R                    x
+--R   (1)  -------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2409
+
+--S 2410 of 5341
+--r0:=1/2*b*p*x/(a*e)-d*x*log(c*(a+b/x)^p)/e^2+1/2*x^2*log(c*(a+b/x)^p)/e-_
+--  b*d*p*log(b+a*x)/(a*e^2)-1/2*b^2*p*log(b+a*x)/(a^2*e)+d^2*log(c*(a+_
+--  b/x)^p)*log(d+e*x)/e^3+d^2*p*log(-e*x/d)*log(d+e*x)/e^3-d^2*p*log(-e*_
+--  (b+a*x)/(a*d-b*e))*log(d+e*x)/e^3+d^2*p*polylog(2,(d+e*x)/d)/e^3-_
+--  d^2*p*polylog(2,a*(d+e*x)/(a*d-b*e))/e^3
+--E 2410
+
+--S 2411 of 5341
+--a0:=integrate(t0,x)
+--E 2411
+
+--S 2412 of 5341
+--m0:=a0-r0
+--E 2412
+
+--S 2413 of 5341
+--d0:=D(m0,x)
+--E 2413
+
+)clear all
+
+--S 2414 of 5341
+t0:=x*log(c*(a+b/x)^p)/(d+e*x)
+--R 
+--R
+--R                 a x + b p
+--R        x log(c (-------) )
+--R                    x
+--R   (1)  -------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2414
+
+--S 2415 of 5341
+--r0:=x*log(c*(a+b/x)^p)/e+b*p*log(b+a*x)/(a*e)-d*log(c*(a+b/x)^p)*_
+--  log(d+e*x)/e^2-d*p*log(-e*x/d)*log(d+e*x)/e^2+d*p*log(-e*(b+a*x)/_
+--  (a*d-b*e))*log(d+e*x)/e^2-d*p*polylog(2,(d+e*x)/d)/e^2+d*p*_
+--  polylog(2,a*(d+e*x)/(a*d-b*e))/e^2
+--E 2415
+
+--S 2416 of 5341
+--a0:=integrate(t0,x)
+--E 2416
+
+--S 2417 of 5341
+--m0:=a0-r0
+--E 2417
+
+--S 2418 of 5341
+--d0:=D(m0,x)
+--E 2418
+
+)clear all
+
+--S 2419 of 5341
+t0:=log(c*(a+b/x)^p)/(d+e*x)
+--R 
+--R
+--R               a x + b p
+--R        log(c (-------) )
+--R                  x
+--R   (1)  -----------------
+--R             e x + d
+--R                                                    Type: Expression(Integer)
+--E 2419
+
+--S 2420 of 5341
+--r0:=log(c*(a+b/x)^p)*log(d+e*x)/e+p*log(-e*x/d)*log(d+e*x)/e-_
+--  p*log(-e*(b+a*x)/(a*d-b*e))*log(d+e*x)/e+p*polylog(2,(d+e*x)/d)/e-_
+--  p*polylog(2,a*(d+e*x)/(a*d-b*e))/e
+--E 2420
+
+--S 2421 of 5341
+--a0:=integrate(t0,x)
+--E 2421
+
+--S 2422 of 5341
+--m0:=a0-r0
+--E 2422
+
+--S 2423 of 5341
+--d0:=D(m0,x)
+--E 2423
+
+)clear all
+
+--S 2424 of 5341
+t0:=log(c*(a+b/x)^p)/(x*(d+e*x))
+--R 
+--R
+--R               a x + b p
+--R        log(c (-------) )
+--R                  x
+--R   (1)  -----------------
+--R               2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2424
+
+--S 2425 of 5341
+--r0:=-log(c*(a+b/x)^p)*log(-b/(a*x))/d-log(c*(a+b/x)^p)*log(d+e*x)/d-_
+--  p*log(-e*x/d)*log(d+e*x)/d+p*log(-e*(b+a*x)/(a*d-b*e))*log(d+e*x)/d-_
+--  p*polylog(2,(a+b/x)/a)/d-p*polylog(2,(d+e*x)/d)/d+p*_
+--  polylog(2,a*(d+e*x)/(a*d-b*e))/d
+--E 2425
+
+--S 2426 of 5341
+--a0:=integrate(t0,x)
+--E 2426
+
+--S 2427 of 5341
+--m0:=a0-r0
+--E 2427
+
+--S 2428 of 5341
+--d0:=D(m0,x)
+--E 2428
+
+)clear all
+
+--S 2429 of 5341
+t0:=log(c*(a+b/x)^p)/(x^2*(d+e*x))
+--R 
+--R
+--R               a x + b p
+--R        log(c (-------) )
+--R                  x
+--R   (1)  -----------------
+--R              3      2
+--R           e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2429
+
+--S 2430 of 5341
+--r0:=p/(d*x)-(a+b/x)*log(c*(a+b/x)^p)/(b*d)+e*log(c*(a+b/x)^p)*_
+--  log(-b/(a*x))/d^2+e*log(c*(a+b/x)^p)*log(d+e*x)/d^2+e*p*log(-e*x/d)*_
+--  log(d+e*x)/d^2-e*p*log(-e*(b+a*x)/(a*d-b*e))*log(d+e*x)/d^2+e*p*_
+--  polylog(2,(a+b/x)/a)/d^2+e*p*polylog(2,(d+e*x)/d)/d^2-e*p*_
+--  polylog(2,a*(d+e*x)/(a*d-b*e))/d^2
+--E 2430
+
+--S 2431 of 5341
+--a0:=integrate(t0,x)
+--E 2431
+
+--S 2432 of 5341
+--m0:=a0-r0
+--E 2432
+
+--S 2433 of 5341
+--d0:=D(m0,x)
+--E 2433
+
+)clear all
+
+--S 2434 of 5341
+t0:=log(c*(a+b/x)^p)/(x^3*(d+e*x))
+--R 
+--R
+--R               a x + b p
+--R        log(c (-------) )
+--R                  x
+--R   (1)  -----------------
+--R              4      3
+--R           e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2434
+
+--S 2435 of 5341
+--r0:=1/4*p/(d*x^2)-1/2*a*p/(b*d*x)-e*p/(d^2*x)+e*(a+b/x)*log(c*_
+--  (a+b/x)^p)/(b*d^2)-1/2*log(c*(a+b/x)^p)/(d*x^2)-e^2*log(c*(a+b/x)^p)*_
+--  log(-b/(a*x))/d^3-1/2*a^2*p*log(x)/(b^2*d)+1/2*a^2*p*log(b+a*x)/_
+--  (b^2*d)-e^2*log(c*(a+b/x)^p)*log(d+e*x)/d^3-e^2*p*log(-e*x/d)*_
+--  log(d+e*x)/d^3+e^2*p*log(-e*(b+a*x)/(a*d-b*e))*log(d+e*x)/d^3-_
+--  e^2*p*polylog(2,(a+b/x)/a)/d^3-e^2*p*polylog(2,(d+e*x)/d)/d^3+_
+--  e^2*p*polylog(2,a*(d+e*x)/(a*d-b*e))/d^3
+--E 2435
+
+--S 2436 of 5341
+--a0:=integrate(t0,x)
+--E 2436
+
+--S 2437 of 5341
+--m0:=a0-r0
+--E 2437
+
+--S 2438 of 5341
+--d0:=D(m0,x)
+--E 2438
+
+)clear all
+
+--S 2439 of 5341
+t0:=x^3*log(c*(a+b/x^2)^p)/(d+e*x)
+--R 
+--R
+--R                    2     p
+--R         3       a x  + b
+--R        x log(c (--------) )
+--R                     2
+--R                    x
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2439
+
+--S 2440 of 5341
+--r0:=2/3*b*p*x/(a*e)-2/3*b^(3/2)*p*atan(x*sqrt(a)/sqrt(b))/(a^(3/2)*e)+_
+--  d^2*x*log(c*(a+b/x^2)^p)/e^3-1/2*d*x^2*log(c*(a+b/x^2)^p)/e^2+_
+--  1/3*x^3*log(c*(a+b/x^2)^p)/e-d^3*log(c*(a+b/x^2)^p)*log(d+e*x)/e^4-_
+--  2*d^3*p*log(-e*x/d)*log(d+e*x)/e^4-1/2*b*d*p*log(b+a*x^2)/(a*e^2)+_
+--  d^3*p*log(d+e*x)*log(-e*(x*sqrt(a)+sqrt(-b))/(d*sqrt(a)-e*sqrt(-b)))/_
+--  e^4+d^3*p*log(d+e*x)*log(e*(-x*sqrt(a)+sqrt(-b))/(d*sqrt(a)+_
+--  e*sqrt(-b)))/e^4-2*d^3*p*polylog(2,(d+e*x)/d)/e^4+d^3*p*_
+--  polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)-e*sqrt(-b)))/e^4+d^3*p*_
+--  polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)+e*sqrt(-b)))/e^4+2*d^2*p*_
+--  atan(x*sqrt(a)/sqrt(b))*sqrt(b)/(e^3*sqrt(a))
+--E 2440
+
+--S 2441 of 5341
+--a0:=integrate(t0,x)
+--E 2441
+
+--S 2442 of 5341
+--m0:=a0-r0
+--E 2442
+
+--S 2443 of 5341
+--d0:=D(m0,x)
+--E 2443
+
+)clear all
+
+--S 2444 of 5341
+t0:=x^2*log(c*(a+b/x^2)^p)/(d+e*x)
+--R 
+--R
+--R                    2     p
+--R         2       a x  + b
+--R        x log(c (--------) )
+--R                     2
+--R                    x
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2444
+
+--S 2445 of 5341
+--r0:=-d*x*log(c*(a+b/x^2)^p)/e^2+1/2*x^2*log(c*(a+b/x^2)^p)/e+d^2*_
+--  log(c*(a+b/x^2)^p)*log(d+e*x)/e^3+2*d^2*p*log(-e*x/d)*log(d+e*x)/e^3+_
+--  1/2*b*p*log(b+a*x^2)/(a*e)-d^2*p*log(d+e*x)*log(-e*(x*sqrt(a)+_
+--  sqrt(-b))/(d*sqrt(a)-e*sqrt(-b)))/e^3-d^2*p*log(d+e*x)*log(e*(-x*_
+--  sqrt(a)+sqrt(-b))/(d*sqrt(a)+e*sqrt(-b)))/e^3+2*d^2*p*polylog(2,_
+--  (d+e*x)/d)/e^3-d^2*p*polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)-_
+--  e*sqrt(-b)))/e^3-d^2*p*polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)+_
+--  e*sqrt(-b)))/e^3-2*d*p*atan(x*sqrt(a)/sqrt(b))*sqrt(b)/(e^2*sqrt(a))
+--E 2445
+
+--S 2446 of 5341
+--a0:=integrate(t0,x)
+--E 2446
+
+--S 2447 of 5341
+--m0:=a0-r0
+--E 2447
+
+--S 2448 of 5341
+--d0:=D(m0,x)
+--E 2448
+
+)clear all
+
+--S 2449 of 5341
+t0:=x*log(c*(a+b/x^2)^p)/(d+e*x)
+--R 
+--R
+--R                    2     p
+--R                 a x  + b
+--R        x log(c (--------) )
+--R                     2
+--R                    x
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2449
+
+--S 2450 of 5341
+--r0:=x*log(c*(a+b/x^2)^p)/e-d*log(c*(a+b/x^2)^p)*log(d+e*x)/e^2-2*d*p*_
+--  log(-e*x/d)*log(d+e*x)/e^2+d*p*log(d+e*x)*log(-e*(x*sqrt(a)+sqrt(-b))/_
+--  (d*sqrt(a)-e*sqrt(-b)))/e^2+d*p*log(d+e*x)*log(e*(-x*sqrt(a)+_
+--  sqrt(-b))/(d*sqrt(a)+e*sqrt(-b)))/e^2-2*d*p*polylog(2,(d+e*x)/d)/e^2+_
+--  d*p*polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)-e*sqrt(-b)))/e^2+d*p*_
+--  polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)+e*sqrt(-b)))/e^2+2*p*atan(x*_
+--  sqrt(a)/sqrt(b))*sqrt(b)/(e*sqrt(a))
+--E 2450
+
+--S 2451 of 5341
+--a0:=integrate(t0,x)
+--E 2451
+
+--S 2452 of 5341
+--m0:=a0-r0
+--E 2452
+
+--S 2453 of 5341
+--d0:=D(m0,x)
+--E 2453
+
+)clear all
+
+--S 2454 of 5341
+t0:=log(c*(a+b/x^2)^p)/(d+e*x)
+--R 
+--R
+--R                  2     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   2
+--R                  x
+--R   (1)  ------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2454
+
+--S 2455 of 5341
+--r0:=log(c*(a+b/x^2)^p)*log(d+e*x)/e+2*p*log(-e*x/d)*log(d+e*x)/e-_
+--  p*log(d+e*x)*log(-e*(x*sqrt(a)+sqrt(-b))/(d*sqrt(a)-e*sqrt(-b)))/e-_
+--  p*log(d+e*x)*log(e*(-x*sqrt(a)+sqrt(-b))/(d*sqrt(a)+e*sqrt(-b)))/e+2*_
+--  p*polylog(2,(d+e*x)/d)/e-p*polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)-_
+--  e*sqrt(-b)))/e-p*polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)+e*sqrt(-b)))/e
+--E 2455
+
+--S 2456 of 5341
+--a0:=integrate(t0,x)
+--E 2456
+
+--S 2457 of 5341
+--m0:=a0-r0
+--E 2457
+
+--S 2458 of 5341
+--d0:=D(m0,x)
+--E 2458
+
+)clear all
+
+--S 2459 of 5341
+t0:=log(c*(a+b/x^2)^p)/(x*(d+e*x))
+--R 
+--R
+--R                  2     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   2
+--R                  x
+--R   (1)  ------------------
+--R               2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2459
+
+--S 2460 of 5341
+--r0:=-1/2*log(c*(a+b/x^2)^p)*log(-b/(a*x^2))/d-log(c*(a+b/x^2)^p)*_
+--  log(d+e*x)/d-2*p*log(-e*x/d)*log(d+e*x)/d+p*log(d+e*x)*log(-e*(x*_
+--  sqrt(a)+sqrt(-b))/(d*sqrt(a)-e*sqrt(-b)))/d+p*log(d+e*x)*log(e*(-x*_
+--  sqrt(a)+sqrt(-b))/(d*sqrt(a)+e*sqrt(-b)))/d-1/2*p*polylog(2,(a+_
+--  b/x^2)/a)/d-2*p*polylog(2,(d+e*x)/d)/d+p*polylog(2,(d+e*x)*sqrt(a)/_
+--  (d*sqrt(a)-e*sqrt(-b)))/d+p*polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)+_
+--  e*sqrt(-b)))/d
+--E 2460
+
+--S 2461 of 5341
+--a0:=integrate(t0,x)
+--E 2461
+
+--S 2462 of 5341
+--m0:=a0-r0
+--E 2462
+
+--S 2463 of 5341
+--d0:=D(m0,x)
+--E 2463
+
+)clear all
+
+--S 2464 of 5341
+t0:=log(c*(a+b/x^2)^p)/(x^2*(d+e*x))
+--R 
+--R
+--R                  2     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   2
+--R                  x
+--R   (1)  ------------------
+--R               3      2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2464
+
+--S 2465 of 5341
+--r0:=2*p/(d*x)-log(c*(a+b/x^2)^p)/(d*x)+1/2*e*log(c*(a+b/x^2)^p)*_
+--  log(-b/(a*x^2))/d^2+e*log(c*(a+b/x^2)^p)*log(d+e*x)/d^2+2*e*p*_
+--  log(-e*x/d)*log(d+e*x)/d^2-e*p*log(d+e*x)*log(-e*(x*sqrt(a)+_
+--  sqrt(-b))/(d*sqrt(a)-e*sqrt(-b)))/d^2-e*p*log(d+e*x)*log(e*(-x*_
+--  sqrt(a)+sqrt(-b))/(d*sqrt(a)+e*sqrt(-b)))/d^2+1/2*e*p*polylog(2,_
+--  (a+b/x^2)/a)/d^2+2*e*p*polylog(2,(d+e*x)/d)/d^2-e*p*polylog(2,_
+--  (d+e*x)*sqrt(a)/(d*sqrt(a)-e*sqrt(-b)))/d^2-e*p*polylog(2,(d+e*x)*_
+--  sqrt(a)/(d*sqrt(a)+e*sqrt(-b)))/d^2+2*p*atan(x*sqrt(a)/sqrt(b))*_
+--  sqrt(a)/(d*sqrt(b))
+--E 2465
+
+--S 2466 of 5341
+--a0:=integrate(t0,x)
+--E 2466
+
+--S 2467 of 5341
+--m0:=a0-r0
+--E 2467
+
+--S 2468 of 5341
+--d0:=D(m0,x)
+--E 2468
+
+)clear all
+
+--S 2469 of 5341
+t0:=log(c*(a+b/x^2)^p)/(x^3*(d+e*x))
+--R 
+--R
+--R                  2     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   2
+--R                  x
+--R   (1)  ------------------
+--R               4      3
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2469
+
+--S 2470 of 5341
+--r0:=1/2*p/(d*x^2)-2*e*p/(d^2*x)-1/2*(a+b/x^2)*log(c*(a+b/x^2)^p)/(b*d)+_
+--  e*log(c*(a+b/x^2)^p)/(d^2*x)-1/2*e^2*log(c*(a+b/x^2)^p)*log(-b/_
+--  (a*x^2))/d^3-e^2*log(c*(a+b/x^2)^p)*log(d+e*x)/d^3-2*e^2*p*_
+--  log(-e*x/d)*log(d+e*x)/d^3+e^2*p*log(d+e*x)*log(-e*(x*sqrt(a)+_
+--  sqrt(-b))/(d*sqrt(a)-e*sqrt(-b)))/d^3+e^2*p*log(d+e*x)*log(e*_
+--  (-x*sqrt(a)+sqrt(-b))/(d*sqrt(a)+e*sqrt(-b)))/d^3-1/2*e^2*p*_
+--  polylog(2,(a+b/x^2)/a)/d^3-2*e^2*p*polylog(2,(d+e*x)/d)/d^3+e^2*_
+--  p*polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)-e*sqrt(-b)))/d^3+e^2*p*_
+--  polylog(2,(d+e*x)*sqrt(a)/(d*sqrt(a)+e*sqrt(-b)))/d^3-2*e*p*_
+--  atan(x*sqrt(a)/sqrt(b))*sqrt(a)/(d^2*sqrt(b))
+--E 2470
+
+--S 2471 of 5341
+--a0:=integrate(t0,x)
+--E 2471
+
+--S 2472 of 5341
+--m0:=a0-r0
+--E 2472
+
+--S 2473 of 5341
+--d0:=D(m0,x)
+--E 2473
+
+)clear all
+
+--S 2474 of 5341
+t0:=x^3*log(c*(a+b/x^3)^p)/(d+e*x)
+--R 
+--R
+--R                    3     p
+--R         3       a x  + b
+--R        x log(c (--------) )
+--R                     3
+--R                    x
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2474
+
+--S 2475 of 5341
+--r0:=d^2*x*log(c*(a+b/x^3)^p)/e^3-1/2*d*x^2*log(c*(a+b/x^3)^p)/e^2+_
+--  1/3*x^3*log(c*(a+b/x^3)^p)/e+b^(1/3)*d^2*p*log(b^(1/3)+a^(1/3)*x)/_
+--  (a^(1/3)*e^3)+1/2*b^(2/3)*d*p*log(b^(1/3)+a^(1/3)*x)/(a^(2/3)*e^2)-_
+--  d^3*log(c*(a+b/x^3)^p)*log(d+e*x)/e^4-3*d^3*p*log(-e*x/d)*log(d+e*x)/e^4+_
+--  d^3*p*log(-e*(b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-b^(1/3)*e))*log(d+e*x)/e^4+_
+--  d^3*p*log(-e*((-1)^(2/3)*b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-(-1)^(2/3)*_
+--  b^(1/3)*e))*log(d+e*x)/e^4+d^3*p*log((-1)^(1/3)*e*(b^(1/3)+(-1)^(2/3)*_
+--  a^(1/3)*x)/(a^(1/3)*d+(-1)^(1/3)*b^(1/3)*e))*log(d+e*x)/e^4-1/2*_
+--  b^(1/3)*d^2*p*log(b^(2/3)-a^(1/3)*b^(1/3)*x+a^(2/3)*x^2)/(a^(1/3)*e^3)-_
+--  1/4*b^(2/3)*d*p*log(b^(2/3)-a^(1/3)*b^(1/3)*x+a^(2/3)*x^2)/(a^(2/3)*_
+--  e^2)+1/3*b*p*log(b+a*x^3)/(a*e)-3*d^3*p*polylog(2,(d+e*x)/d)/e^4+d^3*p*_
+--  polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-b^(1/3)*e))/e^4+d^3*p*_
+--  polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d+(-1)^(1/3)*b^(1/3)*e))/e^4+_
+--  d^3*p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-(-1)^(2/3)*b^(1/3)*e))/e^4-_
+--  b^(1/3)*d^2*p*atan((b^(1/3)-2*a^(1/3)*x)/(b^(1/3)*sqrt(3)))*sqrt(3)/_
+--  (a^(1/3)*e^3)+1/2*b^(2/3)*d*p*atan((b^(1/3)-2*a^(1/3)*x)/(b^(1/3)*_
+--  sqrt(3)))*sqrt(3)/(a^(2/3)*e^2)
+--E 2475
+
+--S 2476 of 5341
+--a0:=integrate(t0,x)
+--E 2476
+
+--S 2477 of 5341
+--m0:=a0-r0
+--E 2477
+
+--S 2478 of 5341
+--d0:=D(m0,x)
+--E 2478
+
+)clear all
+
+--S 2479 of 5341
+t0:=x^2*log(c*(a+b/x^3)^p)/(d+e*x)
+--R 
+--R
+--R                    3     p
+--R         2       a x  + b
+--R        x log(c (--------) )
+--R                     3
+--R                    x
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2479
+
+--S 2480 of 5341
+--r0:=-d*x*log(c*(a+b/x^3)^p)/e^2+1/2*x^2*log(c*(a+b/x^3)^p)/e-b^(1/3)*d*p*_
+--  log(b^(1/3)+a^(1/3)*x)/(a^(1/3)*e^2)-1/2*b^(2/3)*p*log(b^(1/3)+_
+--  a^(1/3)*x)/(a^(2/3)*e)+d^2*log(c*(a+b/x^3)^p)*log(d+e*x)/e^3+3*d^2*p*_
+--  log(-e*x/d)*log(d+e*x)/e^3-d^2*p*log(-e*(b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-_
+--  b^(1/3)*e))*log(d+e*x)/e^3-d^2*p*log(-e*((-1)^(2/3)*b^(1/3)+a^(1/3)*x)/_
+--  (a^(1/3)*d-(-1)^(2/3)*b^(1/3)*e))*log(d+e*x)/e^3-d^2*p*log((-1)^(1/3)*_
+--  e*(b^(1/3)+(-1)^(2/3)*a^(1/3)*x)/(a^(1/3)*d+(-1)^(1/3)*b^(1/3)*e))*_
+--  log(d+e*x)/e^3+1/2*b^(1/3)*d*p*log(b^(2/3)-a^(1/3)*b^(1/3)*x+a^(2/3)*_
+--  x^2)/(a^(1/3)*e^2)+1/4*b^(2/3)*p*log(b^(2/3)-a^(1/3)*b^(1/3)*x+a^(2/3)*_
+--  x^2)/(a^(2/3)*e)+3*d^2*p*polylog(2,(d+e*x)/d)/e^3-d^2*p*_
+--  polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-b^(1/3)*e))/e^3-d^2*p*_
+--  polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d+(-1)^(1/3)*b^(1/3)*e))/e^3-d^2*p*_
+--  polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-(-1)^(2/3)*b^(1/3)*e))/e^3+_
+--  b^(1/3)*d*p*atan((b^(1/3)-2*a^(1/3)*x)/(b^(1/3)*sqrt(3)))*sqrt(3)/_
+--  (a^(1/3)*e^2)-1/2*b^(2/3)*p*atan((b^(1/3)-2*a^(1/3)*x)/(b^(1/3)*_
+--  sqrt(3)))*sqrt(3)/(a^(2/3)*e)
+--E 2480
+
+--S 2481 of 5341
+--a0:=integrate(t0,x)
+--E 2481
+
+--S 2482 of 5341
+--m0:=a0-r0
+--E 2482
+
+--S 2483 of 5341
+--d0:=D(m0,x)
+--E 2483
+
+)clear all
+
+--S 2484 of 5341
+t0:=x*log(c*(a+b/x^3)^p)/(d+e*x)
+--R 
+--R
+--R                    3     p
+--R                 a x  + b
+--R        x log(c (--------) )
+--R                     3
+--R                    x
+--R   (1)  --------------------
+--R               e x + d
+--R                                                    Type: Expression(Integer)
+--E 2484
+
+--S 2485 of 5341
+--r0:=x*log(c*(a+b/x^3)^p)/e+b^(1/3)*p*log(b^(1/3)+a^(1/3)*x)/(a^(1/3)*e)-_
+--  d*log(c*(a+b/x^3)^p)*log(d+e*x)/e^2-3*d*p*log(-e*x/d)*log(d+e*x)/e^2+_
+--  d*p*log(-e*(b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-b^(1/3)*e))*log(d+e*x)/e^2+_
+--  d*p*log(-e*((-1)^(2/3)*b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-(-1)^(2/3)*_
+--  b^(1/3)*e))*log(d+e*x)/e^2+d*p*log((-1)^(1/3)*e*(b^(1/3)+(-1)^(2/3)*_
+--  a^(1/3)*x)/(a^(1/3)*d+(-1)^(1/3)*b^(1/3)*e))*log(d+e*x)/e^2-1/2*_
+--  b^(1/3)*p*log(b^(2/3)-a^(1/3)*b^(1/3)*x+a^(2/3)*x^2)/(a^(1/3)*e)-_
+--  3*d*p*polylog(2,(d+e*x)/d)/e^2+d*p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-_
+--  b^(1/3)*e))/e^2+d*p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d+(-1)^(1/3)*_
+--  b^(1/3)*e))/e^2+d*p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-(-1)^(2/3)*_
+--  b^(1/3)*e))/e^2-b^(1/3)*p*atan((b^(1/3)-2*a^(1/3)*x)/(b^(1/3)*sqrt(3)))*_
+--  sqrt(3)/(a^(1/3)*e)
+--E 2485
+
+--S 2486 of 5341
+--a0:=integrate(t0,x)
+--E 2486
+
+--S 2487 of 5341
+--m0:=a0-r0
+--E 2487
+
+--S 2488 of 5341
+--d0:=D(m0,x)
+--E 2488
+
+)clear all
+
+--S 2489 of 5341
+t0:=log(c*(a+b/x^3)^p)/(d+e*x)
+--R 
+--R
+--R                  3     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   3
+--R                  x
+--R   (1)  ------------------
+--R              e x + d
+--R                                                    Type: Expression(Integer)
+--E 2489
+
+--S 2490 of 5341
+--r0:=log(c*(a+b/x^3)^p)*log(d+e*x)/e+3*p*log(-e*x/d)*log(d+e*x)/e-_
+--  p*log(-e*(b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-b^(1/3)*e))*log(d+e*x)/e-_
+--  p*log(-e*((-1)^(2/3)*b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-(-1)^(2/3)*_
+--  b^(1/3)*e))*log(d+e*x)/e-p*log((-1)^(1/3)*e*(b^(1/3)+(-1)^(2/3)*_
+--  a^(1/3)*x)/(a^(1/3)*d+(-1)^(1/3)*b^(1/3)*e))*log(d+e*x)/e+3*p*_
+--  polylog(2,(d+e*x)/d)/e-p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-_
+--  b^(1/3)*e))/e-p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d+(-1)^(1/3)*_
+--  b^(1/3)*e))/e-p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-(-1)^(2/3)*_
+--  b^(1/3)*e))/e
+--E 2490
+
+--S 2491 of 5341
+--a0:=integrate(t0,x)
+--E 2491
+
+--S 2492 of 5341
+--m0:=a0-r0
+--E 2492
+
+--S 2493 of 5341
+--d0:=D(m0,x)
+--E 2493
+
+)clear all
+
+--S 2494 of 5341
+t0:=log(c*(a+b/x^3)^p)/(x*(d+e*x))
+--R 
+--R
+--R                  3     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   3
+--R                  x
+--R   (1)  ------------------
+--R               2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2494
+
+--S 2495 of 5341
+--r0:=-1/3*log(c*(a+b/x^3)^p)*log(-b/(a*x^3))/d-log(c*(a+b/x^3)^p)*_
+--  log(d+e*x)/d-3*p*log(-e*x/d)*log(d+e*x)/d+p*log(-e*(b^(1/3)+a^(1/3)*_
+--  x)/(a^(1/3)*d-b^(1/3)*e))*log(d+e*x)/d+p*log(-e*((-1)^(2/3)*b^(1/3)+_
+--  a^(1/3)*x)/(a^(1/3)*d-(-1)^(2/3)*b^(1/3)*e))*log(d+e*x)/d+_
+--  p*log((-1)^(1/3)*e*(b^(1/3)+(-1)^(2/3)*a^(1/3)*x)/(a^(1/3)*d+_
+--  (-1)^(1/3)*b^(1/3)*e))*log(d+e*x)/d-1/3*p*polylog(2,(a+b/x^3)/a)/d-_
+--  3*p*polylog(2,(d+e*x)/d)/d+p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-_
+--  b^(1/3)*e))/d+p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d+(-1)^(1/3)*_
+--  b^(1/3)*e))/d+p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-(-1)^(2/3)*_
+--  b^(1/3)*e))/d
+--E 2495
+
+--S 2496 of 5341
+--a0:=integrate(t0,x)
+--E 2496
+
+--S 2497 of 5341
+--m0:=a0-r0
+--E 2497
+
+--S 2498 of 5341
+--d0:=D(m0,x)
+--E 2498
+
+)clear all
+
+--S 2499 of 5341
+t0:=log(c*(a+b/x^3)^p)/(x^2*(d+e*x))
+--R 
+--R
+--R                  3     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   3
+--R                  x
+--R   (1)  ------------------
+--R               3      2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2499
+
+--S 2500 of 5341
+--r0:=3*p/(d*x)-log(c*(a+b/x^3)^p)/(d*x)+1/3*e*log(c*(a+b/x^3)^p)*_
+--  log(-b/(a*x^3))/d^2-a^(1/3)*p*log(b^(1/3)+a^(1/3)*x)/(b^(1/3)*d)+_
+--  e*log(c*(a+b/x^3)^p)*log(d+e*x)/d^2+3*e*p*log(-e*x/d)*log(d+e*x)/d^2-_
+--  e*p*log(-e*(b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-b^(1/3)*e))*log(d+e*x)/d^2-_
+--  e*p*log(-e*((-1)^(2/3)*b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-(-1)^(2/3)*_
+--  b^(1/3)*e))*log(d+e*x)/d^2-e*p*log((-1)^(1/3)*e*(b^(1/3)+(-1)^(2/3)*_
+--  a^(1/3)*x)/(a^(1/3)*d+(-1)^(1/3)*b^(1/3)*e))*log(d+e*x)/d^2+1/2*_
+--  a^(1/3)*p*log(b^(2/3)-a^(1/3)*b^(1/3)*x+a^(2/3)*x^2)/(b^(1/3)*d)+_
+--  1/3*e*p*polylog(2,(a+b/x^3)/a)/d^2+3*e*p*polylog(2,(d+e*x)/d)/d^2-_
+--  e*p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-b^(1/3)*e))/d^2-e*p*_
+--  polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d+(-1)^(1/3)*b^(1/3)*e))/d^2-_
+--  e*p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-(-1)^(2/3)*b^(1/3)*e))/d^2-_
+--  a^(1/3)*p*atan((b^(1/3)-2*a^(1/3)*x)/(b^(1/3)*sqrt(3)))*sqrt(3)/(b^(1/3)*d)
+--E 2500
+
+--S 2501 of 5341
+--a0:=integrate(t0,x)
+--E 2501
+
+--S 2502 of 5341
+--m0:=a0-r0
+--E 2502
+
+--S 2503 of 5341
+--d0:=D(m0,x)
+--E 2503
+
+)clear all
+
+--S 2504 of 5341
+t0:=log(c*(a+b/x^3)^p)/(x^3*(d+e*x))
+--R 
+--R
+--R                  3     p
+--R               a x  + b
+--R        log(c (--------) )
+--R                   3
+--R                  x
+--R   (1)  ------------------
+--R               4      3
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 2504
+
+--S 2505 of 5341
+--r0:=3/4*p/(d*x^2)-3*e*p/(d^2*x)-1/2*log(c*(a+b/x^3)^p)/(d*x^2)+_
+--  e*log(c*(a+b/x^3)^p)/(d^2*x)-1/3*e^2*log(c*(a+b/x^3)^p)*log(-b/_
+--  (a*x^3))/d^3+1/2*a^(2/3)*p*log(b^(1/3)+a^(1/3)*x)/(b^(2/3)*d)+a^(1/3)*_
+--  e*p*log(b^(1/3)+a^(1/3)*x)/(b^(1/3)*d^2)-e^2*log(c*(a+b/x^3)^p)*_
+--  log(d+e*x)/d^3-3*e^2*p*log(-e*x/d)*log(d+e*x)/d^3+e^2*p*log(-e*_
+--  (b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-b^(1/3)*e))*log(d+e*x)/d^3+e^2*p*_
+--  log(-e*((-1)^(2/3)*b^(1/3)+a^(1/3)*x)/(a^(1/3)*d-(-1)^(2/3)*_
+--  b^(1/3)*e))*log(d+e*x)/d^3+e^2*p*log((-1)^(1/3)*e*(b^(1/3)+(-1)^(2/3)*_
+--  a^(1/3)*x)/(a^(1/3)*d+(-1)^(1/3)*b^(1/3)*e))*log(d+e*x)/d^3-1/4*_
+--  a^(2/3)*p*log(b^(2/3)-a^(1/3)*b^(1/3)*x+a^(2/3)*x^2)/(b^(2/3)*d)-_
+--  1/2*a^(1/3)*e*p*log(b^(2/3)-a^(1/3)*b^(1/3)*x+a^(2/3)*x^2)/_
+--  (b^(1/3)*d^2)-1/3*e^2*p*polylog(2,(a+b/x^3)/a)/d^3-3*e^2*p*_
+--  polylog(2,(d+e*x)/d)/d^3+e^2*p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-_
+--  b^(1/3)*e))/d^3+e^2*p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d+(-1)^(1/3)*_
+--  b^(1/3)*e))/d^3+e^2*p*polylog(2,a^(1/3)*(d+e*x)/(a^(1/3)*d-(-1)^(2/3)*_
+--  b^(1/3)*e))/d^3-1/2*a^(2/3)*p*atan((b^(1/3)-2*a^(1/3)*x)/(b^(1/3)*_
+--  sqrt(3)))*sqrt(3)/(b^(2/3)*d)+a^(1/3)*e*p*atan((b^(1/3)-2*a^(1/3)*x)/_
+--  (b^(1/3)*sqrt(3)))*sqrt(3)/(b^(1/3)*d^2)
+--E 2505
+
+--S 2506 of 5341
+--a0:=integrate(t0,x)
+--E 2506
+
+--S 2507 of 5341
+--m0:=a0-r0
+--E 2507
+
+--S 2508 of 5341
+--d0:=D(m0,x)
+--E 2508
+
+)clear all
+
+--S 2509 of 5341
+t0:=x^5*log(c*(a+b*x^2)^n)^2
+--R 
+--R
+--R         5          2     n 2
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2509
+
+--S 2510 of 5341
+r0:=11/18*a^2*n^2*x^2/b^2-5/36*a*n^2*x^4/b+1/27*n^2*x^6-5/18*a^3*n^2*_
+   log(a+b*x^2)/b^3+1/6*a*n*x^4*log(c*(a+b*x^2)^n)/b-1/9*n*x^6*log(c*(a+_
+   b*x^2)^n)-1/3*a^2*n*(a+b*x^2)*log(c*(a+b*x^2)^n)/b^3+1/6*a^2*(a+b*x^2)*_
+   log(c*(a+b*x^2)^n)^2/b^3-1/6*a*x^2*(a+b*x^2)*log(c*(a+b*x^2)^n)^2/b^2+_
+   1/6*x^4*(a+b*x^2)*log(c*(a+b*x^2)^n)^2/b
+--R 
+--R
+--R   (2)
+--R           3 6      3           2     n 2
+--R       (18b x  + 18a )log(c (b x  + a) )
+--R     + 
+--R             3   6        2   4      2     2      3            2     n
+--R       (- 12b n x  + 18a b n x  - 36a b n x  - 36a n)log(c (b x  + a) )
+--R     + 
+--R            3 2       2          3 2 6        2 2 4      2   2 2
+--R       - 30a n log(b x  + a) + 4b n x  - 15a b n x  + 66a b n x
+--R  /
+--R         3
+--R     108b
+--R                                                    Type: Expression(Integer)
+--E 2510
+
+--S 2511 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 2 6      3 2        2     2
+--R       (18b n x  + 18a n )log(b x  + a)
+--R     + 
+--R                 3   6      3              3 2 6        2 2 4      2   2 2
+--R             (36b n x  + 36a n)log(c) - 12b n x  + 18a b n x  - 36a b n x
+--R           + 
+--R                  3 2
+--R             - 66a n
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R          3 6      2         3   6        2   4      2     2            3 2 6
+--R       18b x log(c)  + (- 12b n x  + 18a b n x  - 36a b n x )log(c) + 4b n x
+--R     + 
+--R              2 2 4      2   2 2
+--R       - 15a b n x  + 66a b n x
+--R  /
+--R         3
+--R     108b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2511
+
+--S 2512 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3 6     3           2     n 2
+--R       (- 3b x  - 3a )log(c (b x  + a) )
+--R     + 
+--R          3   6       2   4     2     2     3            2     n
+--R       (2b n x  - 3a b n x  + 6a b n x  + 6a n)log(c (b x  + a) )
+--R     + 
+--R          3 2 6     3 2        2     2
+--R       (3b n x  + 3a n )log(b x  + a)
+--R     + 
+--R             3   6     3             3 2 6       2 2 4     2   2 2     3 2
+--R         ((6b n x  + 6a n)log(c) - 2b n x  + 3a b n x  - 6a b n x  - 6a n )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R         3 6      2        3   6       2   4     2     2
+--R       3b x log(c)  + (- 2b n x  + 3a b n x  - 6a b n x )log(c)
+--R  /
+--R        3
+--R     18b
+--R                                                    Type: Expression(Integer)
+--E 2512
+
+--S 2513 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2513
+
+)clear all
+
+--S 2514 of 5341
+t0:=x^3*log(c*(a+b*x^2)^n)^2
+--R 
+--R
+--R         3          2     n 2
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2514
+
+--S 2515 of 5341
+r0:=-3/4*a*n^2*x^2/b+1/8*n^2*x^4+1/4*a^2*n^2*log(a+b*x^2)/b^2-1/4*n*x^4*_
+   log(c*(a+b*x^2)^n)+1/2*a*n*(a+b*x^2)*log(c*(a+b*x^2)^n)/b^2-1/4*a*(a+_
+   b*x^2)*log(c*(a+b*x^2)^n)^2/b^2+1/4*x^2*(a+b*x^2)*log(c*(a+b*x^2)^n)^2/b
+--R 
+--R
+--R   (2)
+--R          2 4     2           2     n 2
+--R       (2b x  - 2a )log(c (b x  + a) )
+--R     + 
+--R            2   4           2     2            2     n      2 2       2
+--R       (- 2b n x  + 4a b n x  + 4a n)log(c (b x  + a) ) + 2a n log(b x  + a)
+--R     + 
+--R        2 2 4         2 2
+--R       b n x  - 6a b n x
+--R  /
+--R       2
+--R     8b
+--R                                                    Type: Expression(Integer)
+--E 2515
+
+--S 2516 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2 4     2 2        2     2
+--R       (2b n x  - 2a n )log(b x  + a)
+--R     + 
+--R           2   4     2             2 2 4         2 2     2 2        2
+--R       ((4b n x  - 4a n)log(c) - 2b n x  + 4a b n x  + 6a n )log(b x  + a)
+--R     + 
+--R         2 4      2        2   4           2           2 2 4         2 2
+--R       2b x log(c)  + (- 2b n x  + 4a b n x )log(c) + b n x  - 6a b n x
+--R  /
+--R       2
+--R     8b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2516
+
+--S 2517 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2 4    2           2     n 2
+--R       (- b x  + a )log(c (b x  + a) )
+--R     + 
+--R         2   4           2     2            2     n
+--R       (b n x  - 2a b n x  - 2a n)log(c (b x  + a) )
+--R     + 
+--R         2 2 4    2 2        2     2
+--R       (b n x  - a n )log(b x  + a)
+--R     + 
+--R           2   4     2            2 2 4         2 2     2 2        2
+--R       ((2b n x  - 2a n)log(c) - b n x  + 2a b n x  + 2a n )log(b x  + a)
+--R     + 
+--R        2 4      2       2   4           2
+--R       b x log(c)  + (- b n x  + 2a b n x )log(c)
+--R  /
+--R       2
+--R     4b
+--R                                                    Type: Expression(Integer)
+--E 2517
+
+--S 2518 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2518
+
+)clear all
+
+--S 2519 of 5341
+t0:=x*log(c*(a+b*x^2)^n)^2
+--R 
+--R
+--R                    2     n 2
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2519
+
+--S 2520 of 5341
+r0:=n^2*x^2-n*(a+b*x^2)*log(c*(a+b*x^2)^n)/b+1/2*(a+b*x^2)*_
+   log(c*(a+b*x^2)^n)^2/b
+--R 
+--R
+--R   (2)
+--R           2               2     n 2            2                  2     n
+--R       (b x  + a)log(c (b x  + a) )  + (- 2b n x  - 2a n)log(c (b x  + a) )
+--R     + 
+--R           2 2
+--R       2b n x
+--R  /
+--R     2b
+--R                                                    Type: Expression(Integer)
+--E 2520
+
+--S 2521 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2 2      2        2     2
+--R       (b n x  + a n )log(b x  + a)
+--R     + 
+--R               2                     2 2       2        2           2      2
+--R       ((2b n x  + 2a n)log(c) - 2b n x  - 2a n )log(b x  + a) + b x log(c)
+--R     + 
+--R               2             2 2
+--R       - 2b n x log(c) + 2b n x
+--R  /
+--R     2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2521
+
+--S 2522 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2               2     n 2          2                  2     n
+--R       (- b x  - a)log(c (b x  + a) )  + (2b n x  + 2a n)log(c (b x  + a) )
+--R     + 
+--R           2 2      2        2     2
+--R       (b n x  + a n )log(b x  + a)
+--R     + 
+--R               2                     2 2       2        2           2      2
+--R       ((2b n x  + 2a n)log(c) - 2b n x  - 2a n )log(b x  + a) + b x log(c)
+--R     + 
+--R               2
+--R       - 2b n x log(c)
+--R  /
+--R     2b
+--R                                                    Type: Expression(Integer)
+--E 2522
+
+--S 2523 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2523
+
+)clear all
+
+--S 2524 of 5341
+t0:=log(c*(a+b*x^2)^n)^2/x
+--R 
+--R
+--R                  2     n 2
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2524
+
+--S 2525 of 5341
+--r0:=1/2*log(-b*x^2/a)*log(c*(a+b*x^2)^n)^2+n*log(c*(a+b*x^2)^n)*_
+--  polylog(2,(a+b*x^2)/a)-n^2*polylog(3,(a+b*x^2)/a)
+--E 2525
+
+--S 2526 of 5341
+--a0:=integrate(t0,x)
+--E 2526
+
+--S 2527 of 5341
+--m0:=a0-r0
+--E 2527
+
+--S 2528 of 5341
+--d0:=D(m0,x)
+--E 2528
+
+)clear all
+
+--S 2529 of 5341
+t0:=log(c*(a+b*x^2)^n)^2/x^3
+--R 
+--R
+--R                  2     n 2
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2529
+
+--S 2530 of 5341
+--r0:=b*n*log(-b*x^2/a)*log(c*(a+b*x^2)^n)/a-1/2*(a+b*x^2)*_
+--  log(c*(a+b*x^2)^n)^2/(a*x^2)+b*n^2*polylog(2,(a+b*x^2)/a)/a
+--E 2530
+
+--S 2531 of 5341
+--a0:=integrate(t0,x)
+--E 2531
+
+--S 2532 of 5341
+--m0:=a0-r0
+--E 2532
+
+--S 2533 of 5341
+--d0:=D(m0,x)
+--E 2533
+
+)clear all
+
+--S 2534 of 5341
+t0:=log(c*(a+b*x^2)^n)^2/x^5
+--R 
+--R
+--R                  2     n 2
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                  5
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2534
+
+--S 2535 of 5341
+--r0:=b^2*n^2*log(x)/a^2-1/2*b^2*n^2*log(a+b*x^2)/a^2-1/2*b*n*log(c*_
+--  (a+b*x^2)^n)/(a*x^2)-1/2*b^2*n*log(-b*x^2/a)*log(c*(a+b*x^2)^n)/a^2-_
+--  1/4*(a+b*x^2)*log(c*(a+b*x^2)^n)^2/(a*x^4)+1/4*b*(a+b*x^2)*log(c*_
+--  (a+b*x^2)^n)^2/(a^2*x^2)-1/2*b^2*n^2*polylog(2,(a+b*x^2)/a)/a^2
+--E 2535
+
+--S 2536 of 5341
+--a0:=integrate(t0,x)
+--E 2536
+
+--S 2537 of 5341
+--m0:=a0-r0
+--E 2537
+
+--S 2538 of 5341
+--d0:=D(m0,x)
+--E 2538
+
+)clear all
+
+--S 2539 of 5341
+t0:=x^4*log(c*(a+b*x^2)^n)^2
+--R 
+--R
+--R         4          2     n 2
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2539
+
+--S 2540 of 5341
+--r0:=184/75*a^2*n^2*x/b^2-64/225*a*n^2*x^3/b+8/125*n^2*x^5-184/75*a^(5/2)*_
+--  n^2*atan(x*sqrt(b)/sqrt(a))/b^(5/2)+4/5*%i*a^(5/2)*n^2*atan(x*sqrt(b)/_
+--  sqrt(a))^2/b^(5/2)-4/5*a^2*n*x*log(c*(a+b*x^2)^n)/b^2+4/15*a*n*x^3*_
+--  log(c*(a+b*x^2)^n)/b-4/25*n*x^5*log(c*(a+b*x^2)^n)+4/5*a^(5/2)*n*_
+--  atan(x*sqrt(b)/sqrt(a))*log(c*(a+b*x^2)^n)/b^(5/2)+1/5*x^5*log(c*_
+--  (a+b*x^2)^n)^2+8/5*a^(5/2)*n^2*atan(x*sqrt(b)/sqrt(a))*log(2*%i*_
+--  sqrt(a)/(%i*sqrt(a)-x*sqrt(b)))/b^(5/2)+4/5*%i*a^(5/2)*n^2*_
+--  polylog(2,(-sqrt(a)+%i*x*sqrt(b))/(sqrt(a)+%i*x*sqrt(b)))/b^(5/2)
+--E 2540
+
+--S 2541 of 5341
+--a0:=integrate(t0,x)
+--E 2541
+
+--S 2542 of 5341
+--m0:=a0-r0
+--E 2542
+
+--S 2543 of 5341
+--d0:=D(m0,x)
+--E 2543
+
+)clear all
+
+--S 2544 of 5341
+t0:=x^2*log(c*(a+b*x^2)^n)^2
+--R 
+--R
+--R         2          2     n 2
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2544
+
+--S 2545 of 5341
+--r0:=-32/9*a*n^2*x/b+8/27*n^2*x^3+32/9*a^(3/2)*n^2*atan(x*sqrt(b)/_
+--  sqrt(a))/b^(3/2)-4/3*%i*a^(3/2)*n^2*atan(x*sqrt(b)/sqrt(a))^2/b^(3/2)+_
+--  4/3*a*n*x*log(c*(a+b*x^2)^n)/b-4/9*n*x^3*log(c*(a+b*x^2)^n)-_
+--  4/3*a^(3/2)*n*atan(x*sqrt(b)/sqrt(a))*log(c*(a+b*x^2)^n)/b^(3/2)+_
+--  1/3*x^3*log(c*(a+b*x^2)^n)^2-8/3*a^(3/2)*n^2*atan(x*sqrt(b)/sqrt(a))*_
+--  log(2*%i*sqrt(a)/(%i*sqrt(a)-x*sqrt(b)))/b^(3/2)-4/3*%i*a^(3/2)*_
+--  n^2*polylog(2,(-sqrt(a)+%i*x*sqrt(b))/(sqrt(a)+%i*x*sqrt(b)))/b^(3/2)
+--E 2545
+
+--S 2546 of 5341
+--a0:=integrate(t0,x)
+--E 2546
+
+--S 2547 of 5341
+--m0:=a0-r0
+--E 2547
+
+--S 2548 of 5341
+--d0:=D(m0,x)
+--E 2548
+
+)clear all
+
+--S 2549 of 5341
+t0:=log(c*(a+b*x^2)^n)^2
+--R 
+--R
+--R                  2     n 2
+--R   (1)  log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2549
+
+--S 2550 of 5341
+--r0:=8*n^2*x-4*n*x*log(c*(a+b*x^2)^n)+x*log(c*(a+b*x^2)^n)^2-_
+--  8*n^2*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/sqrt(b)+4*%i*n^2*atan(x*_
+--  sqrt(b)/sqrt(a))^2*sqrt(a)/sqrt(b)+4*n*atan(x*sqrt(b)/sqrt(a))*_
+--  log(c*(a+b*x^2)^n)*sqrt(a)/sqrt(b)+8*n^2*atan(x*sqrt(b)/sqrt(a))*_
+--  log(2*%i*sqrt(a)/(%i*sqrt(a)-x*sqrt(b)))*sqrt(a)/sqrt(b)+4*%i*n^2*_
+--  polylog(2,(-sqrt(a)+%i*x*sqrt(b))/(sqrt(a)+%i*x*sqrt(b)))*sqrt(a)/sqrt(b)
+--E 2550
+
+--S 2551 of 5341
+--a0:=integrate(t0,x)
+--E 2551
+
+--S 2552 of 5341
+--m0:=a0-r0
+--E 2552
+
+--S 2553 of 5341
+--d0:=D(m0,x)
+--E 2553
+
+)clear all
+
+--S 2554 of 5341
+t0:=log(c*(a+b*x^2)^n)^2/x^2
+--R 
+--R
+--R                  2     n 2
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2554
+
+--S 2555 of 5341
+--r0:=-log(c*(a+b*x^2)^n)^2/x+4*%i*n^2*atan(x*sqrt(b)/sqrt(a))^2*sqrt(b)/_
+--  sqrt(a)+4*n*atan(x*sqrt(b)/sqrt(a))*log(c*(a+b*x^2)^n)*sqrt(b)/_
+--  sqrt(a)+8*n^2*atan(x*sqrt(b)/sqrt(a))*log(2*%i*sqrt(a)/(%i*sqrt(a)-_
+--  x*sqrt(b)))*sqrt(b)/sqrt(a)+4*%i*n^2*polylog(2,(-sqrt(a)+%i*x*_
+--  sqrt(b))/(sqrt(a)+%i*x*sqrt(b)))*sqrt(b)/sqrt(a)
+--E 2555
+
+--S 2556 of 5341
+--a0:=integrate(t0,x)
+--E 2556
+
+--S 2557 of 5341
+--m0:=a0-r0
+--E 2557
+
+--S 2558 of 5341
+--d0:=D(m0,x)
+--E 2558
+
+)clear all
+
+--S 2559 of 5341
+t0:=log(c*(a+b*x^2)^n)^2/x^4
+--R 
+--R
+--R                  2     n 2
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                  4
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2559
+
+--S 2560 of 5341
+--r0:=8/3*b^(3/2)*n^2*atan(x*sqrt(b)/sqrt(a))/a^(3/2)-4/3*%i*b^(3/2)*n^2*_
+--  atan(x*sqrt(b)/sqrt(a))^2/a^(3/2)-4/3*b*n*log(c*(a+b*x^2)^n)/(a*x)-_
+--  4/3*b^(3/2)*n*atan(x*sqrt(b)/sqrt(a))*log(c*(a+b*x^2)^n)/a^(3/2)-_
+--  1/3*log(c*(a+b*x^2)^n)^2/x^3-8/3*b^(3/2)*n^2*atan(x*sqrt(b)/sqrt(a))*_
+--  log(2*%i*sqrt(a)/(%i*sqrt(a)-x*sqrt(b)))/a^(3/2)-4/3*%i*b^(3/2)*_
+--  n^2*polylog(2,(-sqrt(a)+%i*x*sqrt(b))/(sqrt(a)+%i*x*sqrt(b)))/a^(3/2)
+--E 2560
+
+--S 2561 of 5341
+--a0:=integrate(t0,x)
+--E 2561
+
+--S 2562 of 5341
+--m0:=a0-r0
+--E 2562
+
+--S 2563 of 5341
+--d0:=D(m0,x)
+--E 2563
+
+)clear all
+
+--S 2564 of 5341
+t0:=log(c*(a+b*x^2)^n)^2/x^6
+--R 
+--R
+--R                  2     n 2
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                  6
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2564
+
+--S 2565 of 5341
+--r0:=-8/15*b^2*n^2/(a^2*x)-32/15*b^(5/2)*n^2*atan(x*sqrt(b)/sqrt(a))/_
+--  a^(5/2)+4/5*%i*b^(5/2)*n^2*atan(x*sqrt(b)/sqrt(a))^2/a^(5/2)-_
+--  4/15*b*n*log(c*(a+b*x^2)^n)/(a*x^3)+4/5*b^2*n*log(c*(a+b*x^2)^n)/_
+--  (a^2*x)+4/5*b^(5/2)*n*atan(x*sqrt(b)/sqrt(a))*log(c*(a+b*x^2)^n)/_
+--  a^(5/2)-1/5*log(c*(a+b*x^2)^n)^2/x^5+8/5*b^(5/2)*n^2*_
+--  atan(x*sqrt(b)/sqrt(a))*log(2*%i*sqrt(a)/(%i*sqrt(a)-x*sqrt(b)))/_
+--  a^(5/2)+4/5*%i*b^(5/2)*n^2*polylog(2,(-sqrt(a)+%i*x*sqrt(b))/_
+--  (sqrt(a)+%i*x*sqrt(b)))/a^(5/2)
+--E 2565
+
+--S 2566 of 5341
+--a0:=integrate(t0,x)
+--E 2566
+
+--S 2567 of 5341
+--m0:=a0-r0
+--E 2567
+
+--S 2568 of 5341
+--d0:=D(m0,x)
+--E 2568
+
+)clear all
+
+--S 2569 of 5341
+t0:=log(c*(a+b*x^2)^n)^2/x^8
+--R 
+--R
+--R                  2     n 2
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                  8
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2569
+
+--S 2570 of 5341
+--r0:=-8/105*b^2*n^2/(a^2*x^3)+64/105*b^3*n^2/(a^3*x)+184/105*b^(7/2)*n^2*_
+--  atan(x*sqrt(b)/sqrt(a))/a^(7/2)-4/7*%i*b^(7/2)*n^2*atan(x*sqrt(b)/_
+--  sqrt(a))^2/a^(7/2)-4/35*b*n*log(c*(a+b*x^2)^n)/(a*x^5)+4/21*b^2*_
+--  n*log(c*(a+b*x^2)^n)/(a^2*x^3)-4/7*b^3*n*log(c*(a+b*x^2)^n)/(a^3*x)-_
+--  4/7*b^(7/2)*n*atan(x*sqrt(b)/sqrt(a))*log(c*(a+b*x^2)^n)/a^(7/2)-_
+--  1/7*log(c*(a+b*x^2)^n)^2/x^7-8/7*b^(7/2)*n^2*atan(x*sqrt(b)/sqrt(a))*_
+--  log(2*%i*sqrt(a)/(%i*sqrt(a)-x*sqrt(b)))/a^(7/2)-4/7*%i*b^(7/2)*_
+--  n^2*polylog(2,(-sqrt(a)+%i*x*sqrt(b))/(sqrt(a)+%i*x*sqrt(b)))/a^(7/2)
+--E 2570
+
+--S 2571 of 5341
+--a0:=integrate(t0,x)
+--E 2571
+
+--S 2572 of 5341
+--m0:=a0-r0
+--E 2572
+
+--S 2573 of 5341
+--d0:=D(m0,x)
+--E 2573
+
+)clear all
+
+--S 2574 of 5341
+t0:=x^5*log(c*(a+b*x^2)^n)^3
+--R 
+--R
+--R         5          2     n 3
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2574
+
+--S 2575 of 5341
+r0:=-85/36*a^2*n^3*x^2/b^2+19/72*a*n^3*x^4/b-1/27*n^3*x^6+19/36*a^3*n^3*_
+   log(a+b*x^2)/b^3-5/12*a*n^2*x^4*log(c*(a+b*x^2)^n)/b+1/9*n^2*x^6*_
+   log(c*(a+b*x^2)^n)+11/6*a^2*n^2*(a+b*x^2)*log(c*(a+b*x^2)^n)/b^3-_
+   11/12*a^2*n*(a+b*x^2)*log(c*(a+b*x^2)^n)^2/b^3+5/12*a*n*x^2*(a+b*x^2)*_
+   log(c*(a+b*x^2)^n)^2/b^2-1/6*n*x^4*(a+b*x^2)*log(c*(a+b*x^2)^n)^2/b+_
+   1/6*a^2*(a+b*x^2)*log(c*(a+b*x^2)^n)^3/b^3-1/6*a*x^2*(a+b*x^2)*log(c*_
+   (a+b*x^2)^n)^3/b^2+1/6*x^4*(a+b*x^2)*log(c*(a+b*x^2)^n)^3/b
+--R 
+--R
+--R   (2)
+--R           3 6      3           2     n 3
+--R       (36b x  + 36a )log(c (b x  + a) )
+--R     + 
+--R             3   6        2   4       2     2       3            2     n 2
+--R       (- 36b n x  + 54a b n x  - 108a b n x  - 198a n)log(c (b x  + a) )
+--R     + 
+--R           3 2 6        2 2 4       2   2 2       3 2           2     n
+--R       (24b n x  - 90a b n x  + 396a b n x  + 396a n )log(c (b x  + a) )
+--R     + 
+--R           3 3       2          3 3 6        2 3 4       2   3 2
+--R       114a n log(b x  + a) - 8b n x  + 57a b n x  - 510a b n x
+--R  /
+--R         3
+--R     216b
+--R                                                    Type: Expression(Integer)
+--E 2575
+
+--S 2576 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 3 6      3 3        2     3
+--R       (36b n x  + 36a n )log(b x  + a)
+--R     + 
+--R                3 2 6       3 2             3 3 6        2 3 4       2   3 2
+--R           (108b n x  + 108a n )log(c) - 36b n x  + 54a b n x  - 108a b n x
+--R         + 
+--R                 3 3
+--R           - 198a n
+--R      *
+--R                2     2
+--R         log(b x  + a)
+--R     + 
+--R                3   6       3        2
+--R           (108b n x  + 108a n)log(c)
+--R         + 
+--R                 3 2 6         2 2 4       2   2 2       3 2             3 3 6
+--R           (- 72b n x  + 108a b n x  - 216a b n x  - 396a n )log(c) + 24b n x
+--R         + 
+--R                  2 3 4       2   3 2       3 3
+--R           - 90a b n x  + 396a b n x  + 510a n
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R          3 6      3         3   6        2   4       2     2       2
+--R       36b x log(c)  + (- 36b n x  + 54a b n x  - 108a b n x )log(c)
+--R     + 
+--R           3 2 6        2 2 4       2   2 2            3 3 6        2 3 4
+--R       (24b n x  - 90a b n x  + 396a b n x )log(c) - 8b n x  + 57a b n x
+--R     + 
+--R             2   3 2
+--R       - 510a b n x
+--R  /
+--R         3
+--R     216b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2576
+
+--S 2577 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            3 6     3           2     n 3
+--R       (- 6b x  - 6a )log(c (b x  + a) )
+--R     + 
+--R          3   6       2   4      2     2      3            2     n 2
+--R       (6b n x  - 9a b n x  + 18a b n x  + 33a n)log(c (b x  + a) )
+--R     + 
+--R            3 2 6        2 2 4      2   2 2      3 2           2     n
+--R       (- 4b n x  + 15a b n x  - 66a b n x  - 66a n )log(c (b x  + a) )
+--R     + 
+--R          3 3 6     3 3        2     3
+--R       (6b n x  + 6a n )log(b x  + a)
+--R     + 
+--R              3 2 6      3 2            3 3 6       2 3 4      2   3 2      3 3
+--R         ((18b n x  + 18a n )log(c) - 6b n x  + 9a b n x  - 18a b n x  - 33a n )
+--R      *
+--R                2     2
+--R         log(b x  + a)
+--R     + 
+--R               3   6      3        2
+--R           (18b n x  + 18a n)log(c)
+--R         + 
+--R                 3 2 6        2 2 4      2   2 2      3 2            3 3 6
+--R           (- 12b n x  + 18a b n x  - 36a b n x  - 66a n )log(c) + 4b n x
+--R         + 
+--R                  2 3 4      2   3 2      3 3
+--R           - 15a b n x  + 66a b n x  + 66a n
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R         3 6      3        3   6       2   4      2     2       2
+--R       6b x log(c)  + (- 6b n x  + 9a b n x  - 18a b n x )log(c)
+--R     + 
+--R          3 2 6        2 2 4      2   2 2
+--R       (4b n x  - 15a b n x  + 66a b n x )log(c)
+--R  /
+--R        3
+--R     36b
+--R                                                    Type: Expression(Integer)
+--E 2577
+
+--S 2578 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2578
+
+)clear all
+
+--S 2579 of 5341
+t0:=x^3*log(c*(a+b*x^2)^n)^3
+--R 
+--R
+--R         3          2     n 3
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2579
+
+--S 2580 of 5341
+r0:=21/8*a*n^3*x^2/b-3/16*n^3*x^4-3/8*a^2*n^3*log(a+b*x^2)/b^2+3/8*n^2*x^4*_
+   log(c*(a+b*x^2)^n)-9/4*a*n^2*(a+b*x^2)*log(c*(a+b*x^2)^n)/b^2+9/8*a*n*_
+   (a+b*x^2)*log(c*(a+b*x^2)^n)^2/b^2-3/8*n*x^2*(a+b*x^2)*log(c*(a+_
+   b*x^2)^n)^2/b-1/4*a*(a+b*x^2)*log(c*(a+b*x^2)^n)^3/b^2+1/4*x^2*(a+_
+   b*x^2)*log(c*(a+b*x^2)^n)^3/b
+--R 
+--R
+--R   (2)
+--R          2 4     2           2     n 3
+--R       (4b x  - 4a )log(c (b x  + a) )
+--R     + 
+--R            2   4            2      2            2     n 2
+--R       (- 6b n x  + 12a b n x  + 18a n)log(c (b x  + a) )
+--R     + 
+--R          2 2 4          2 2      2 2           2     n      2 3       2
+--R       (6b n x  - 36a b n x  - 36a n )log(c (b x  + a) ) - 6a n log(b x  + a)
+--R     + 
+--R           2 3 4          3 2
+--R       - 3b n x  + 42a b n x
+--R  /
+--R        2
+--R     16b
+--R                                                    Type: Expression(Integer)
+--E 2580
+
+--S 2581 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 3 4     2 3        2     3
+--R       (4b n x  - 4a n )log(b x  + a)
+--R     + 
+--R            2 2 4      2 2            2 3 4          3 2      2 3        2     2
+--R       ((12b n x  - 12a n )log(c) - 6b n x  + 12a b n x  + 18a n )log(b x  + a)
+--R     + 
+--R               2   4      2        2         2 2 4          2 2      2 2
+--R           (12b n x  - 12a n)log(c)  + (- 12b n x  + 24a b n x  + 36a n )log(c)
+--R         + 
+--R             2 3 4          3 2      2 3
+--R           6b n x  - 36a b n x  - 42a n
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R         2 4      3        2   4            2       2
+--R       4b x log(c)  + (- 6b n x  + 12a b n x )log(c)
+--R     + 
+--R          2 2 4          2 2            2 3 4          3 2
+--R       (6b n x  - 36a b n x )log(c) - 3b n x  + 42a b n x
+--R  /
+--R        2
+--R     16b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2581
+
+--S 2582 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            2 4     2           2     n 3
+--R       (- 2b x  + 2a )log(c (b x  + a) )
+--R     + 
+--R          2   4           2     2            2     n 2
+--R       (3b n x  - 6a b n x  - 9a n)log(c (b x  + a) )
+--R     + 
+--R            2 2 4          2 2      2 2           2     n
+--R       (- 3b n x  + 18a b n x  + 18a n )log(c (b x  + a) )
+--R     + 
+--R          2 3 4     2 3        2     3
+--R       (2b n x  - 2a n )log(b x  + a)
+--R     + 
+--R           2 2 4     2 2            2 3 4         3 2     2 3        2     2
+--R       ((6b n x  - 6a n )log(c) - 3b n x  + 6a b n x  + 9a n )log(b x  + a)
+--R     + 
+--R              2   4     2        2        2 2 4          2 2      2 2
+--R           (6b n x  - 6a n)log(c)  + (- 6b n x  + 12a b n x  + 18a n )log(c)
+--R         + 
+--R             2 3 4          3 2      2 3
+--R           3b n x  - 18a b n x  - 18a n
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R         2 4      3        2   4           2       2
+--R       2b x log(c)  + (- 3b n x  + 6a b n x )log(c)
+--R     + 
+--R          2 2 4          2 2
+--R       (3b n x  - 18a b n x )log(c)
+--R  /
+--R       2
+--R     8b
+--R                                                    Type: Expression(Integer)
+--E 2582
+
+--S 2583 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2583
+
+)clear all
+
+--S 2584 of 5341
+t0:=x*log(c*(a+b*x^2)^n)^3
+--R 
+--R
+--R                    2     n 3
+--R   (1)  x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2584
+
+--S 2585 of 5341
+r0:=-3*n^3*x^2+3*n^2*(a+b*x^2)*log(c*(a+b*x^2)^n)/b-3/2*n*(a+b*x^2)*_
+   log(c*(a+b*x^2)^n)^2/b+1/2*(a+b*x^2)*log(c*(a+b*x^2)^n)^3/b
+--R 
+--R
+--R   (2)
+--R           2               2     n 3            2                  2     n 2
+--R       (b x  + a)log(c (b x  + a) )  + (- 3b n x  - 3a n)log(c (b x  + a) )
+--R     + 
+--R            2 2       2           2     n        3 2
+--R       (6b n x  + 6a n )log(c (b x  + a) ) - 6b n x
+--R  /
+--R     2b
+--R                                                    Type: Expression(Integer)
+--E 2585
+
+--S 2586 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 2      3        2     3
+--R       (b n x  + a n )log(b x  + a)
+--R     + 
+--R             2 2       2              3 2       3        2     2
+--R       ((3b n x  + 3a n )log(c) - 3b n x  - 3a n )log(b x  + a)
+--R     + 
+--R                 2              2          2 2       2              3 2       3
+--R         ((3b n x  + 3a n)log(c)  + (- 6b n x  - 6a n )log(c) + 6b n x  + 6a n )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R          2      3         2      2       2 2             3 2
+--R       b x log(c)  - 3b n x log(c)  + 6b n x log(c) - 6b n x
+--R  /
+--R     2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 2586
+
+--S 2587 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             2               2     n 3          2                  2     n 2
+--R       (- b x  - a)log(c (b x  + a) )  + (3b n x  + 3a n)log(c (b x  + a) )
+--R     + 
+--R              2 2       2           2     n        3 2      3        2     3
+--R       (- 6b n x  - 6a n )log(c (b x  + a) ) + (b n x  + a n )log(b x  + a)
+--R     + 
+--R             2 2       2              3 2       3        2     2
+--R       ((3b n x  + 3a n )log(c) - 3b n x  - 3a n )log(b x  + a)
+--R     + 
+--R                 2              2          2 2       2              3 2       3
+--R         ((3b n x  + 3a n)log(c)  + (- 6b n x  - 6a n )log(c) + 6b n x  + 6a n )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R          2      3         2      2       2 2
+--R       b x log(c)  - 3b n x log(c)  + 6b n x log(c)
+--R  /
+--R     2b
+--R                                                    Type: Expression(Integer)
+--E 2587
+
+--S 2588 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2588
+
+)clear all
+
+--S 2589 of 5341
+t0:=log(c*(a+b*x^2)^n)^3/x
+--R 
+--R
+--R                  2     n 3
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2589
+
+--S 2590 of 5341
+--r0:=1/2*log(-b*x^2/a)*log(c*(a+b*x^2)^n)^3+3/2*n*log(c*(a+b*x^2)^n)^2*_
+--  polylog(2,(a+b*x^2)/a)-3*n^2*log(c*(a+b*x^2)^n)*_
+--  polylog(3,(a+b*x^2)/a)+3*n^3*polylog(4,(a+b*x^2)/a)
+--E 2590
+
+--S 2591 of 5341
+--a0:=integrate(t0,x)
+--E 2591
+
+--S 2592 of 5341
+--m0:=a0-r0
+--E 2592
+
+--S 2593 of 5341
+--d0:=D(m0,x)
+--E 2593
+
+)clear all
+
+--S 2594 of 5341
+t0:=log(c*(a+b*x^2)^n)^3/x^3
+--R 
+--R
+--R                  2     n 3
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2594
+
+--S 2595 of 5341
+--r0:=3/2*b*n*log(-b*x^2/a)*log(c*(a+b*x^2)^n)^2/a-1/2*(a+b*x^2)*_
+--  log(c*(a+b*x^2)^n)^3/(a*x^2)+3*b*n^2*log(c*(a+b*x^2)^n)*_
+--  polylog(2,(a+b*x^2)/a)/a-3*b*n^3*polylog(3,(a+b*x^2)/a)/a
+--E 2595
+
+--S 2596 of 5341
+--a0:=integrate(t0,x)
+--E 2596
+
+--S 2597 of 5341
+--m0:=a0-r0
+--E 2597
+
+--S 2598 of 5341
+--d0:=D(m0,x)
+--E 2598
+
+)clear all
+
+--S 2599 of 5341
+t0:=log(c*(a+b*x^2)^n)^3/x^5
+--R 
+--R
+--R                  2     n 3
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                  5
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2599
+
+--S 2600 of 5341
+--r0:=3/2*b^2*n^2*log(-b*x^2/a)*log(c*(a+b*x^2)^n)/a^2-3/4*b*n*(a+b*x^2)*_
+--  log(c*(a+b*x^2)^n)^2/(a^2*x^2)-3/4*b^2*n*log(-b*x^2/a)*log(c*(a+_
+--  b*x^2)^n)^2/a^2-1/4*(a+b*x^2)*log(c*(a+b*x^2)^n)^3/(a*x^4)+1/4*b*_
+--  (a+b*x^2)*log(c*(a+b*x^2)^n)^3/(a^2*x^2)+3/2*b^2*n^3*_
+--  polylog(2,(a+b*x^2)/a)/a^2-3/2*b^2*n^2*log(c*(a+b*x^2)^n)*_
+--  polylog(2,(a+b*x^2)/a)/a^2+3/2*b^2*n^3*polylog(3,(a+b*x^2)/a)/a^2
+--E 2600
+
+--S 2601 of 5341
+--a0:=integrate(t0,x)
+--E 2601
+
+--S 2602 of 5341
+--m0:=a0-r0
+--E 2602
+
+--S 2603 of 5341
+--d0:=D(m0,x)
+--E 2603
+
+)clear all
+
+--S 2604 of 5341
+t0:=x^3/log(c*(a+b*x^2)^n)
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  ------------------
+--R                  2     n
+--R        log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2604
+
+--S 2605 of 5341
+--r0:=-1/2*a*(a+b*x^2)*Ei(log(c*(a+b*x^2)^n)/n)/(b^2*n*(c*(a+_
+--  b*x^2)^n)^(1/n))+1/2*(a+b*x^2)^2*Ei(2*log(c*(a+b*x^2)^n)/n)/(b^2*_
+--  n*(c*(a+b*x^2)^n)^(2/n))
+--E 2605
+
+--S 2606 of 5341
+--a0:=integrate(t0,x)
+--E 2606
+
+--S 2607 of 5341
+--m0:=a0-r0
+--E 2607
+
+--S 2608 of 5341
+--d0:=D(m0,x)
+--E 2608
+
+)clear all
+
+--S 2609 of 5341
+t0:=x/log(c*(a+b*x^2)^n)
+--R 
+--R
+--R                 x
+--R   (1)  ------------------
+--R                  2     n
+--R        log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2609
+
+--S 2610 of 5341
+--r0:=1/2*(a+b*x^2)*Ei(log(c*(a+b*x^2)^n)/n)/(b*n*(c*(a+b*x^2)^n)^(1/n))
+--E 2610
+
+--S 2611 of 5341
+--a0:=integrate(t0,x)
+--E 2611
+
+--S 2612 of 5341
+--m0:=a0-r0
+--E 2612
+
+--S 2613 of 5341
+--d0:=D(m0,x)
+--E 2613
+
+)clear all
+
+--S 2614 of 5341
+t0:=1/(x*log(c*(a+b*x^2)^n))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                    2     n
+--R        x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2614
+
+--S 2615 of 5341
+--r0:=1/2*my_subst(Int(1/(x*log(c*(a+b*x)^n)),x),x,x^2)
+--E 2615
+
+--S 2616 of 5341
+--a0:=integrate(t0,x)
+--E 2616
+
+--S 2617 of 5341
+--m0:=a0-r0
+--E 2617
+
+--S 2618 of 5341
+--d0:=D(m0,x)
+--E 2618
+
+)clear all
+
+--S 2619 of 5341
+t0:=1/(x^3*log(c*(a+b*x^2)^n))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         3          2     n
+--R        x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2619
+
+--S 2620 of 5341
+--r0:=1/2*my_subst(Int(1/(x^2*log(c*(a+b*x)^n)),x),x,x^2)
+--E 2620
+
+--S 2621 of 5341
+--a0:=integrate(t0,x)
+--E 2621
+
+--S 2622 of 5341
+--m0:=a0-r0
+--E 2622
+
+--S 2623 of 5341
+--d0:=D(m0,x)
+--E 2623
+
+)clear all
+
+--S 2624 of 5341
+t0:=x^3/log(c*(a+b*x^2)^n)^2
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  -------------------
+--R                  2     n 2
+--R        log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2624
+
+--S 2625 of 5341
+--r0:=-1/2*a*(a+b*x^2)*Ei(log(c*(a+b*x^2)^n)/n)/(b^2*n^2*(c*(a+_
+--  b*x^2)^n)^(1/n))+(a+b*x^2)^2*Ei(2*log(c*(a+b*x^2)^n)/n)/(b^2*n^2*_
+--  (c*(a+b*x^2)^n)^(2/n))-1/2*x^2*(a+b*x^2)/(b*n*log(c*(a+b*x^2)^n))
+--E 2625
+
+--S 2626 of 5341
+--a0:=integrate(t0,x)
+--E 2626
+
+--S 2627 of 5341
+--m0:=a0-r0
+--E 2627
+
+--S 2628 of 5341
+--d0:=D(m0,x)
+--E 2628
+
+)clear all
+
+--S 2629 of 5341
+t0:=x/log(c*(a+b*x^2)^n)^2
+--R 
+--R
+--R                 x
+--R   (1)  -------------------
+--R                  2     n 2
+--R        log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2629
+
+--S 2630 of 5341
+--r0:=1/2*(a+b*x^2)*Ei(log(c*(a+b*x^2)^n)/n)/(b*n^2*(c*(a+b*x^2)^n)^(1/n))+_
+--  1/2*(-a-b*x^2)/(b*n*log(c*(a+b*x^2)^n))
+--E 2630
+
+--S 2631 of 5341
+--a0:=integrate(t0,x)
+--E 2631
+
+--S 2632 of 5341
+--m0:=a0-r0
+--E 2632
+
+--S 2633 of 5341
+--d0:=D(m0,x)
+--E 2633
+
+)clear all
+
+--S 2634 of 5341
+t0:=1/(x*log(c*(a+b*x^2)^n)^2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R                    2     n 2
+--R        x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2634
+
+--S 2635 of 5341
+--r0:=1/2*my_subst(Int(1/(x*log(c*(a+b*x)^n)^2),x),x,x^2)
+--E 2635
+
+--S 2636 of 5341
+--a0:=integrate(t0,x)
+--E 2636
+
+--S 2637 of 5341
+--m0:=a0-r0
+--E 2637
+
+--S 2638 of 5341
+--d0:=D(m0,x)
+--E 2638
+
+)clear all
+
+--S 2639 of 5341
+t0:=1/(x^3*log(c*(a+b*x^2)^n)^2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         3          2     n 2
+--R        x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2639
+
+--S 2640 of 5341
+--r0:=1/2*my_subst(Int(1/(x^2*log(c*(a+b*x)^n)^2),x),x,x^2)
+--E 2640
+
+--S 2641 of 5341
+--a0:=integrate(t0,x)
+--E 2641
+
+--S 2642 of 5341
+--m0:=a0-r0
+--E 2642
+
+--S 2643 of 5341
+--d0:=D(m0,x)
+--E 2643
+
+)clear all
+
+--S 2644 of 5341
+t0:=x^3/log(c*(a+b*x^2)^n)^3
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  -------------------
+--R                  2     n 3
+--R        log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2644
+
+--S 2645 of 5341
+--r0:=-1/4*a*(a+b*x^2)*Ei(log(c*(a+b*x^2)^n)/n)/(b^2*n^3*(c*(a+_
+--  b*x^2)^n)^(1/n))+(a+b*x^2)^2*Ei(2*log(c*(a+b*x^2)^n)/n)/(b^2*n^3*_
+--  (c*(a+b*x^2)^n)^(2/n))-1/4*x^2*(a+b*x^2)/(b*n*log(c*(a+b*x^2)^n)^2)-_
+--  1/4*a*(a+b*x^2)/(b^2*n^2*log(c*(a+b*x^2)^n))-1/2*x^2*(a+b*x^2)/_
+--  (b*n^2*log(c*(a+b*x^2)^n))
+--E 2645
+
+--S 2646 of 5341
+--a0:=integrate(t0,x)
+--E 2646
+
+--S 2647 of 5341
+--m0:=a0-r0
+--E 2647
+
+--S 2648 of 5341
+--d0:=D(m0,x)
+--E 2648
+
+)clear all
+
+--S 2649 of 5341
+t0:=x/log(c*(a+b*x^2)^n)^3
+--R 
+--R
+--R                 x
+--R   (1)  -------------------
+--R                  2     n 3
+--R        log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2649
+
+--S 2650 of 5341
+--r0:=1/4*(a+b*x^2)*Ei(log(c*(a+b*x^2)^n)/n)/(b*n^3*(c*(a+b*x^2)^n)^(1/n))+_
+--  1/4*(-a-b*x^2)/(b*n*log(c*(a+b*x^2)^n)^2)+1/4*(-a-b*x^2)/(b*n^2*_
+--  log(c*(a+b*x^2)^n))
+--E 2650
+
+--S 2651 of 5341
+--a0:=integrate(t0,x)
+--E 2651
+
+--S 2652 of 5341
+--m0:=a0-r0
+--E 2652
+
+--S 2653 of 5341
+--d0:=D(m0,x)
+--E 2653
+
+)clear all
+
+--S 2654 of 5341
+t0:=1/(x*log(c*(a+b*x^2)^n)^3)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R                    2     n 3
+--R        x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2654
+
+--S 2655 of 5341
+--r0:=1/2*my_subst(Int(1/(x*log(c*(a+b*x)^n)^3),x),x,x^2)
+--E 2655
+
+--S 2656 of 5341
+--a0:=integrate(t0,x)
+--E 2656
+
+--S 2657 of 5341
+--m0:=a0-r0
+--E 2657
+
+--S 2658 of 5341
+--d0:=D(m0,x)
+--E 2658
+
+)clear all
+
+--S 2659 of 5341
+t0:=1/(x^3*log(c*(a+b*x^2)^n)^3)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         3          2     n 3
+--R        x log(c (b x  + a) )
+--R                                                    Type: Expression(Integer)
+--E 2659
+
+--S 2660 of 5341
+--r0:=1/2*my_subst(Int(1/(x^2*log(c*(a+b*x)^n)^3),x),x,x^2)
+--E 2660
+
+--S 2661 of 5341
+--a0:=integrate(t0,x)
+--E 2661
+
+--S 2662 of 5341
+--m0:=a0-r0
+--E 2662
+
+--S 2663 of 5341
+--d0:=D(m0,x)
+--E 2663
+
+)clear all
+
+--S 2664 of 5341
+t0:=x^m/log(c*(a+b*x^2))
+--R 
+--R
+--R                 m
+--R                x
+--R   (1)  -----------------
+--R                 2
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2664
+
+--S 2665 of 5341
+--r0:=Int(x^m/log(c*(a+b*x^2)),x)
+--E 2665
+
+--S 2666 of 5341
+--a0:=integrate(t0,x)
+--E 2666
+
+--S 2667 of 5341
+--m0:=a0-r0
+--E 2667
+
+--S 2668 of 5341
+--d0:=D(m0,x)
+--E 2668
+
+)clear all
+
+--S 2669 of 5341
+t0:=x^3/log(c*(a+b*x^2))
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  -----------------
+--R                 2
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2669
+
+--S 2670 of 5341
+--r0:=1/2*Ei(2*log(a*c+b*c*x^2))/(b^2*c^2)-1/2*a*Li(a*c+b*c*x^2)/(b^2*c)
+--E 2670
+
+--S 2671 of 5341
+--a0:=integrate(t0,x)
+--E 2671
+
+--S 2672 of 5341
+--m0:=a0-r0
+--E 2672
+
+--S 2673 of 5341
+--d0:=D(m0,x)
+--E 2673
+
+)clear all
+
+--S 2674 of 5341
+t0:=x^2/log(c*(a+b*x^2))
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  -----------------
+--R                 2
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2674
+
+--S 2675 of 5341
+--r0:=Int(x^2/log(c*(a+b*x^2)),x)
+--E 2675
+
+--S 2676 of 5341
+--a0:=integrate(t0,x)
+--E 2676
+
+--S 2677 of 5341
+--m0:=a0-r0
+--E 2677
+
+--S 2678 of 5341
+--d0:=D(m0,x)
+--E 2678
+
+)clear all
+
+--S 2679 of 5341
+t0:=x/log(c*(a+b*x^2))
+--R 
+--R
+--R                x
+--R   (1)  -----------------
+--R                 2
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2679
+
+--S 2680 of 5341
+--r0:=1/2*Li(c*(a+b*x^2))/(b*c)
+--E 2680
+
+--S 2681 of 5341
+--a0:=integrate(t0,x)
+--E 2681
+
+--S 2682 of 5341
+--m0:=a0-r0
+--E 2682
+
+--S 2683 of 5341
+--d0:=D(m0,x)
+--E 2683
+
+)clear all
+
+--S 2684 of 5341
+t0:=1/log(c*(a+b*x^2))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R                 2
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2684
+
+--S 2685 of 5341
+--r0:=Int(1/log(c*(a+b*x^2)),x)
+--E 2685
+
+--S 2686 of 5341
+--a0:=integrate(t0,x)
+--E 2686
+
+--S 2687 of 5341
+--m0:=a0-r0
+--E 2687
+
+--S 2688 of 5341
+--d0:=D(m0,x)
+--E 2688
+
+)clear all
+
+--S 2689 of 5341
+t0:=1/(x*log(c*(a+b*x^2)))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R                   2
+--R        x log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2689
+
+--S 2690 of 5341
+--r0:=1/2*my_subst(Int(1/(x*log(a*c+b*c*x)),x),x,x^2)
+--E 2690
+
+--S 2691 of 5341
+--a0:=integrate(t0,x)
+--E 2691
+
+--S 2692 of 5341
+--m0:=a0-r0
+--E 2692
+
+--S 2693 of 5341
+--d0:=D(m0,x)
+--E 2693
+
+)clear all
+
+--S 2694 of 5341
+t0:=1/(x^2*log(c*(a+b*x^2)))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         2         2
+--R        x log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2694
+
+--S 2695 of 5341
+--r0:=Int(1/(x^2*log(c*(a+b*x^2))),x)
+--E 2695
+
+--S 2696 of 5341
+--a0:=integrate(t0,x)
+--E 2696
+
+--S 2697 of 5341
+--m0:=a0-r0
+--E 2697
+
+--S 2698 of 5341
+--d0:=D(m0,x)
+--E 2698
+
+)clear all
+
+--S 2699 of 5341
+t0:=1/(x^3*log(c*(a+b*x^2)))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         3         2
+--R        x log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2699
+
+--S 2700 of 5341
+--r0:=1/2*my_subst(Int(1/(x^2*log(a*c+b*c*x)),x),x,x^2)
+--E 2700
+
+--S 2701 of 5341
+--a0:=integrate(t0,x)
+--E 2701
+
+--S 2702 of 5341
+--m0:=a0-r0
+--E 2702
+
+--S 2703 of 5341
+--d0:=D(m0,x)
+--E 2703
+
+)clear all
+
+--S 2704 of 5341
+t0:=x^m/log(c*(a+b*x^2))^2
+--R 
+--R
+--R                 m
+--R                x
+--R   (1)  ------------------
+--R                 2       2
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2704
+
+--S 2705 of 5341
+--r0:=Int(x^m/log(c*(a+b*x^2))^2,x)
+--E 2705
+
+--S 2706 of 5341
+--a0:=integrate(t0,x)
+--E 2706
+
+--S 2707 of 5341
+--m0:=a0-r0
+--E 2707
+
+--S 2708 of 5341
+--d0:=D(m0,x)
+--E 2708
+
+)clear all
+
+--S 2709 of 5341
+t0:=x^3/log(c*(a+b*x^2))^2
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  ------------------
+--R                 2       2
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2709
+
+--S 2710 of 5341
+--r0:=Ei(2*log(a*c+b*c*x^2))/(b^2*c^2)-1/2*a*Li(a*c+b*c*x^2)/(b^2*c)-_
+--  1/2*x^2*(a+b*x^2)/(b*log(a*c+b*c*x^2))
+--E 2710
+
+--S 2711 of 5341
+--a0:=integrate(t0,x)
+--E 2711
+
+--S 2712 of 5341
+--m0:=a0-r0
+--E 2712
+
+--S 2713 of 5341
+--d0:=D(m0,x)
+--E 2713
+
+)clear all
+
+--S 2714 of 5341
+t0:=x^2/log(c*(a+b*x^2))^2
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  ------------------
+--R                 2       2
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2714
+
+--S 2715 of 5341
+--r0:=Int(x^2/log(c*(a+b*x^2))^2,x)
+--E 2715
+
+--S 2716 of 5341
+--a0:=integrate(t0,x)
+--E 2716
+
+--S 2717 of 5341
+--m0:=a0-r0
+--E 2717
+
+--S 2718 of 5341
+--d0:=D(m0,x)
+--E 2718
+
+)clear all
+
+--S 2719 of 5341
+t0:=x/log(c*(a+b*x^2))^2
+--R 
+--R
+--R                 x
+--R   (1)  ------------------
+--R                 2       2
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2719
+
+--S 2720 of 5341
+--r0:=1/2*Li(c*(a+b*x^2))/(b*c)+1/2*(-a-b*x^2)/(b*log(c*(a+b*x^2)))
+--E 2720
+
+--S 2721 of 5341
+--a0:=integrate(t0,x)
+--E 2721
+
+--S 2722 of 5341
+--m0:=a0-r0
+--E 2722
+
+--S 2723 of 5341
+--d0:=D(m0,x)
+--E 2723
+
+)clear all
+
+--S 2724 of 5341
+t0:=1/log(c*(a+b*x^2))^2
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R                 2       2
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2724
+
+--S 2725 of 5341
+--r0:=Int(1/log(c*(a+b*x^2))^2,x)
+--E 2725
+
+--S 2726 of 5341
+--a0:=integrate(t0,x)
+--E 2726
+
+--S 2727 of 5341
+--m0:=a0-r0
+--E 2727
+
+--S 2728 of 5341
+--d0:=D(m0,x)
+--E 2728
+
+)clear all
+
+--S 2729 of 5341
+t0:=1/(x*log(c*(a+b*x^2))^2)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                   2       2
+--R        x log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2729
+
+--S 2730 of 5341
+--r0:=1/2*my_subst(Int(1/(x*log(a*c+b*c*x)^2),x),x,x^2)
+--E 2730
+
+--S 2731 of 5341
+--a0:=integrate(t0,x)
+--E 2731
+
+--S 2732 of 5341
+--m0:=a0-r0
+--E 2732
+
+--S 2733 of 5341
+--d0:=D(m0,x)
+--E 2733
+
+)clear all
+
+--S 2734 of 5341
+t0:=1/(x^2*log(c*(a+b*x^2))^2)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         2         2       2
+--R        x log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2734
+
+--S 2735 of 5341
+--r0:=Int(1/(x^2*log(c*(a+b*x^2))^2),x)
+--E 2735
+
+--S 2736 of 5341
+--a0:=integrate(t0,x)
+--E 2736
+
+--S 2737 of 5341
+--m0:=a0-r0
+--E 2737
+
+--S 2738 of 5341
+--d0:=D(m0,x)
+--E 2738
+
+)clear all
+
+--S 2739 of 5341
+t0:=1/(x^3*log(c*(a+b*x^2))^2)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         3         2       2
+--R        x log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2739
+
+--S 2740 of 5341
+--r0:=1/2*my_subst(Int(1/(x^2*log(a*c+b*c*x)^2),x),x,x^2)
+--E 2740
+
+--S 2741 of 5341
+--a0:=integrate(t0,x)
+--E 2741
+
+--S 2742 of 5341
+--m0:=a0-r0
+--E 2742
+
+--S 2743 of 5341
+--d0:=D(m0,x)
+--E 2743
+
+)clear all
+
+--S 2744 of 5341
+t0:=x^m/log(c*(a+b*x^2))^3
+--R 
+--R
+--R                 m
+--R                x
+--R   (1)  ------------------
+--R                 2       3
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2744
+
+--S 2745 of 5341
+--r0:=Int(x^m/log(c*(a+b*x^2))^3,x)
+--E 2745
+
+--S 2746 of 5341
+--a0:=integrate(t0,x)
+--E 2746
+
+--S 2747 of 5341
+--m0:=a0-r0
+--E 2747
+
+--S 2748 of 5341
+--d0:=D(m0,x)
+--E 2748
+
+)clear all
+
+--S 2749 of 5341
+t0:=x^3/log(c*(a+b*x^2))^3
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  ------------------
+--R                 2       3
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2749
+
+--S 2750 of 5341
+--r0:=Ei(2*log(a*c+b*c*x^2))/(b^2*c^2)-1/4*a*Li(a*c+b*c*x^2)/(b^2*c)-_
+--  1/4*x^2*(a+b*x^2)/(b*log(a*c+b*c*x^2)^2)-1/4*a*(a+b*x^2)/_
+--  (b^2*log(a*c+b*c*x^2))-1/2*x^2*(a+b*x^2)/(b*log(a*c+b*c*x^2))
+--E 2750
+
+--S 2751 of 5341
+--a0:=integrate(t0,x)
+--E 2751
+
+--S 2752 of 5341
+--m0:=a0-r0
+--E 2752
+
+--S 2753 of 5341
+--d0:=D(m0,x)
+--E 2753
+
+)clear all
+
+--S 2754 of 5341
+t0:=x^2/log(c*(a+b*x^2))^3
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  ------------------
+--R                 2       3
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2754
+
+--S 2755 of 5341
+--r0:=Int(x^2/log(c*(a+b*x^2))^3,x)
+--E 2755
+
+--S 2756 of 5341
+--a0:=integrate(t0,x)
+--E 2756
+
+--S 2757 of 5341
+--m0:=a0-r0
+--E 2757
+
+--S 2758 of 5341
+--d0:=D(m0,x)
+--E 2758
+
+)clear all
+
+--S 2759 of 5341
+t0:=x/log(c*(a+b*x^2))^3
+--R 
+--R
+--R                 x
+--R   (1)  ------------------
+--R                 2       3
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2759
+
+--S 2760 of 5341
+--r0:=1/4*Li(c*(a+b*x^2))/(b*c)+1/4*(-a-b*x^2)/(b*log(c*(a+b*x^2))^2)+_
+--  1/4*(-a-b*x^2)/(b*log(c*(a+b*x^2)))
+--E 2760
+
+--S 2761 of 5341
+--a0:=integrate(t0,x)
+--E 2761
+
+--S 2762 of 5341
+--m0:=a0-r0
+--E 2762
+
+--S 2763 of 5341
+--d0:=D(m0,x)
+--E 2763
+
+)clear all
+
+--S 2764 of 5341
+t0:=1/log(c*(a+b*x^2))^3
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R                 2       3
+--R        log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2764
+
+--S 2765 of 5341
+--r0:=Int(1/log(c*(a+b*x^2))^3,x)
+--E 2765
+
+--S 2766 of 5341
+--a0:=integrate(t0,x)
+--E 2766
+
+--S 2767 of 5341
+--m0:=a0-r0
+--E 2767
+
+--S 2768 of 5341
+--d0:=D(m0,x)
+--E 2768
+
+)clear all
+
+--S 2769 of 5341
+t0:=1/(x*log(c*(a+b*x^2))^3)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                   2       3
+--R        x log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2769
+
+--S 2770 of 5341
+--r0:=1/2*my_subst(Int(1/(x*log(a*c+b*c*x)^3),x),x,x^2)
+--E 2770
+
+--S 2771 of 5341
+--a0:=integrate(t0,x)
+--E 2771
+
+--S 2772 of 5341
+--m0:=a0-r0
+--E 2772
+
+--S 2773 of 5341
+--d0:=D(m0,x)
+--E 2773
+
+)clear all
+
+--S 2774 of 5341
+t0:=1/(x^2*log(c*(a+b*x^2))^3)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         2         2       3
+--R        x log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2774
+
+--S 2775 of 5341
+--r0:=Int(1/(x^2*log(c*(a+b*x^2))^3),x)
+--E 2775
+
+--S 2776 of 5341
+--a0:=integrate(t0,x)
+--E 2776
+
+--S 2777 of 5341
+--m0:=a0-r0
+--E 2777
+
+--S 2778 of 5341
+--d0:=D(m0,x)
+--E 2778
+
+)clear all
+
+--S 2779 of 5341
+t0:=1/(x^3*log(c*(a+b*x^2))^3)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         3         2       3
+--R        x log(b c x  + a c)
+--R                                                    Type: Expression(Integer)
+--E 2779
+
+--S 2780 of 5341
+--r0:=1/2*my_subst(Int(1/(x^2*log(a*c+b*c*x)^3),x),x,x^2)
+--E 2780
+
+--S 2781 of 5341
+--a0:=integrate(t0,x)
+--E 2781
+
+--S 2782 of 5341
+--m0:=a0-r0
+--E 2782
+
+--S 2783 of 5341
+--d0:=D(m0,x)
+--E 2783
+
+)clear all
+
+--S 2784 of 5341
+t0:=log(c*(a+b/x)^n)^2
+--R 
+--R
+--R               a x + b n 2
+--R   (1)  log(c (-------) )
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 2784
+
+--S 2785 of 5341
+--r0:=(b+a*x)*log(c*(a+b/x)^n)^2/a-2*b*n*log(c*(a+b/x)^n)*log(-b/(a*x))/a-_
+--  2*b*n^2*polylog(2,(a+b/x)/a)/a
+--E 2785
+
+--S 2786 of 5341
+--a0:=integrate(t0,x)
+--E 2786
+
+--S 2787 of 5341
+--m0:=a0-r0
+--E 2787
+
+--S 2788 of 5341
+--d0:=D(m0,x)
+--E 2788
+
+)clear all
+
+--S 2789 of 5341
+t0:=log(c*(a+b/x)^n)^3
+--R 
+--R
+--R               a x + b n 3
+--R   (1)  log(c (-------) )
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 2789
+
+--S 2790 of 5341
+--r0:=(b+a*x)*log(c*(a+b/x)^n)^3/a-3*b*n*log(c*(a+b/x)^n)^2*log(-b/(a*x))/a-_
+--  6*b*n^2*log(c*(a+b/x)^n)*polylog(2,(a+b/x)/a)/a+6*b*n^3*_
+--  polylog(3,(a+b/x)/a)/a
+--E 2790
+
+--S 2791 of 5341
+--a0:=integrate(t0,x)
+--E 2791
+
+--S 2792 of 5341
+--m0:=a0-r0
+--E 2792
+
+--S 2793 of 5341
+--d0:=D(m0,x)
+--E 2793
+
+)clear all
+
+--S 2794 of 5341
+t0:=log(1+b*x^m)/x
+--R 
+--R
+--R               m
+--R        log(b x  + 1)
+--R   (1)  -------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 2794
+
+--S 2795 of 5341
+--r0:=-polylog(2,-b*x^m)/m
+--E 2795
+
+--S 2796 of 5341
+--a0:=integrate(t0,x)
+--E 2796
+
+--S 2797 of 5341
+--m0:=a0-r0
+--E 2797
+
+--S 2798 of 5341
+--d0:=D(m0,x)
+--E 2798
+
+)clear all
+
+--S 2799 of 5341
+t0:=log(2+b*x^m)/x
+--R 
+--R
+--R               m
+--R        log(b x  + 2)
+--R   (1)  -------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 2799
+
+--S 2800 of 5341
+--r0:=log(2)*log(x)-polylog(2,-1/2*b*x^m)/m
+--E 2800
+
+--S 2801 of 5341
+--a0:=integrate(t0,x)
+--E 2801
+
+--S 2802 of 5341
+--m0:=a0-r0
+--E 2802
+
+--S 2803 of 5341
+--d0:=D(m0,x)
+--E 2803
+
+)clear all
+
+--S 2804 of 5341
+t0:=log(2*(3+b*x^m))/x
+--R 
+--R
+--R                m
+--R        log(2b x  + 6)
+--R   (1)  --------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 2804
+
+--S 2805 of 5341
+--r0:=log(6)*log(x)-polylog(2,-1/3*b*x^m)/m
+--E 2805
+
+--S 2806 of 5341
+--a0:=integrate(t0,x)
+--E 2806
+
+--S 2807 of 5341
+--m0:=a0-r0
+--E 2807
+
+--S 2808 of 5341
+--d0:=D(m0,x)
+--E 2808
+
+)clear all
+
+--S 2809 of 5341
+t0:=log(c*(a+b*x^m))/x
+--R 
+--R
+--R                 m
+--R        log(b c x  + a c)
+--R   (1)  -----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 2809
+
+--S 2810 of 5341
+--r0:=log(-b*x^m/a)*log(c*(a+b*x^m))/m+polylog(2,(a+b*x^m)/a)/m
+--E 2810
+
+--S 2811 of 5341
+--a0:=integrate(t0,x)
+--E 2811
+
+--S 2812 of 5341
+--m0:=a0-r0
+--E 2812
+
+--S 2813 of 5341
+--d0:=D(m0,x)
+--E 2813
+
+)clear all
+
+--S 2814 of 5341
+t0:=log(c*(a+b*x^m)^n)/x
+--R 
+--R
+--R                  m     n
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2814
+
+--S 2815 of 5341
+--r0:=log(-b*x^m/a)*log(c*(a+b*x^m)^n)/m+n*polylog(2,(a+b*x^m)/a)/m
+--E 2815
+
+--S 2816 of 5341
+--a0:=integrate(t0,x)
+--E 2816
+
+--S 2817 of 5341
+--m0:=a0-r0
+--E 2817
+
+--S 2818 of 5341
+--d0:=D(m0,x)
+--E 2818
+
+)clear all
+
+--S 2819 of 5341
+t0:=log(c*(a+b*x^m)^n)^2/x
+--R 
+--R
+--R                  m     n 2
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2819
+
+--S 2820 of 5341
+--r0:=log(-b*x^m/a)*log(c*(a+b*x^m)^n)^2/m+2*n*log(c*(a+b*x^m)^n)*_
+--  polylog(2,(a+b*x^m)/a)/m-2*n^2*polylog(3,(a+b*x^m)/a)/m
+--E 2820
+
+--S 2821 of 5341
+--a0:=integrate(t0,x)
+--E 2821
+
+--S 2822 of 5341
+--m0:=a0-r0
+--E 2822
+
+--S 2823 of 5341
+--d0:=D(m0,x)
+--E 2823
+
+)clear all
+
+--S 2824 of 5341
+t0:=log(c*(a+b*x^m)^n)^3/x
+--R 
+--R
+--R                  m     n 3
+--R        log(c (b x  + a) )
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 2824
+
+--S 2825 of 5341
+--r0:=log(-b*x^m/a)*log(c*(a+b*x^m)^n)^3/m+3*n*log(c*(a+b*x^m)^n)^2*_
+--  polylog(2,(a+b*x^m)/a)/m-6*n^2*log(c*(a+b*x^m)^n)*_
+--  polylog(3,(a+b*x^m)/a)/m+6*n^3*polylog(4,(a+b*x^m)/a)/m
+--E 2825
+
+--S 2826 of 5341
+--a0:=integrate(t0,x)
+--E 2826
+
+--S 2827 of 5341
+--m0:=a0-r0
+--E 2827
+
+--S 2828 of 5341
+--d0:=D(m0,x)
+--E 2828
+
+)clear all
+
+--S 2829 of 5341
+t0:=log((a+x)/x)/x
+--R 
+--R
+--R            x + a
+--R        log(-----)
+--R              x
+--R   (1)  ----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 2829
+
+--S 2830 of 5341
+--r0:=polylog(2,-a/x)
+--E 2830
+
+--S 2831 of 5341
+--a0:=integrate(t0,x)
+--E 2831
+
+--S 2832 of 5341
+--m0:=a0-r0
+--E 2832
+
+--S 2833 of 5341
+--d0:=D(m0,x)
+--E 2833
+
+)clear all
+
+--S 2834 of 5341
+t0:=log((a+x^2)/x^2)/x
+--R 
+--R
+--R             2
+--R            x  + a
+--R        log(------)
+--R               2
+--R              x
+--R   (1)  -----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 2834
+
+--S 2835 of 5341
+--r0:=1/2*polylog(2,-a/x^2)
+--E 2835
+
+--S 2836 of 5341
+--a0:=integrate(t0,x)
+--E 2836
+
+--S 2837 of 5341
+--m0:=a0-r0
+--E 2837
+
+--S 2838 of 5341
+--d0:=D(m0,x)
+--E 2838
+
+)clear all
+
+--S 2839 of 5341
+t0:=log((a+x^n)/x^n)/x
+--R 
+--R
+--R             n
+--R            x  + a
+--R        log(------)
+--R               n
+--R              x
+--R   (1)  -----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 2839
+
+--S 2840 of 5341
+--r0:=polylog(2,-a/x^n)/n
+--E 2840
+
+--S 2841 of 5341
+--a0:=integrate(t0,x)
+--E 2841
+
+--S 2842 of 5341
+--m0:=a0-r0
+--E 2842
+
+--S 2843 of 5341
+--d0:=D(m0,x)
+--E 2843
+
+)clear all
+
+--S 2844 of 5341
+t0:=log((a+b*x)/x)/x
+--R 
+--R
+--R            b x + a
+--R        log(-------)
+--R               x
+--R   (1)  ------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 2844
+
+--S 2845 of 5341
+--r0:=-log(b+a/x)*log(-a/(b*x))-polylog(2,(b+a/x)/b)
+--E 2845
+
+--S 2846 of 5341
+--a0:=integrate(t0,x)
+--E 2846
+
+--S 2847 of 5341
+--m0:=a0-r0
+--E 2847
+
+--S 2848 of 5341
+--d0:=D(m0,x)
+--E 2848
+
+)clear all
+
+--S 2849 of 5341
+t0:=log((a+b*x^2)/x^2)/x
+--R 
+--R
+--R               2
+--R            b x  + a
+--R        log(--------)
+--R                2
+--R               x
+--R   (1)  -------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 2849
+
+--S 2850 of 5341
+--r0:=-1/2*log(b+a/x^2)*log(-a/(b*x^2))-1/2*polylog(2,(b+a/x^2)/b)
+--E 2850
+
+--S 2851 of 5341
+--a0:=integrate(t0,x)
+--E 2851
+
+--S 2852 of 5341
+--m0:=a0-r0
+--E 2852
+
+--S 2853 of 5341
+--d0:=D(m0,x)
+--E 2853
+
+)clear all
+
+--S 2854 of 5341
+t0:=log((a+b*x^n)/x^n)/x
+--R 
+--R
+--R               n
+--R            b x  + a
+--R        log(--------)
+--R                n
+--R               x
+--R   (1)  -------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 2854
+
+--S 2855 of 5341
+--r0:=-log(-a/(b*x^n))*log(b+a/x^n)/n-polylog(2,(b+a/x^n)/b)/n
+--E 2855
+
+--S 2856 of 5341
+--a0:=integrate(t0,x)
+--E 2856
+
+--S 2857 of 5341
+--m0:=a0-r0
+--E 2857
+
+--S 2858 of 5341
+--d0:=D(m0,x)
+--E 2858
+
+)clear all
+
+--S 2859 of 5341
+t0:=log((a+b*x)/x)/(c+d*x)
+--R 
+--R
+--R            b x + a
+--R        log(-------)
+--R               x
+--R   (1)  ------------
+--R           d x + c
+--R                                                    Type: Expression(Integer)
+--E 2859
+
+--S 2860 of 5341
+--r0:=log(b+a/x)*log(c+d*x)/d+log(-d*x/c)*log(c+d*x)/d-log(-d*(a+b*x)/_
+--  (b*c-a*d))*log(c+d*x)/d+polylog(2,(c+d*x)/c)/d-_
+--  polylog(2,b*(c+d*x)/(b*c-a*d))/d
+--E 2860
+
+--S 2861 of 5341
+--a0:=integrate(t0,x)
+--E 2861
+
+--S 2862 of 5341
+--m0:=a0-r0
+--E 2862
+
+--S 2863 of 5341
+--d0:=D(m0,x)
+--E 2863
+
+)clear all
+
+--S 2864 of 5341
+t0:=log((a+b*x^2)/x^2)/(c+d*x)
+--R 
+--R
+--R               2
+--R            b x  + a
+--R        log(--------)
+--R                2
+--R               x
+--R   (1)  -------------
+--R           d x + c
+--R                                                    Type: Expression(Integer)
+--E 2864
+
+--S 2865 of 5341
+--r0:=log(b+a/x^2)*log(c+d*x)/d+2*log(-d*x/c)*log(c+d*x)/d-log(c+d*x)*_
+--  log(d*(sqrt(-a)-x*sqrt(b))/(d*sqrt(-a)+c*sqrt(b)))/d-log(c+d*x)*_
+--  log(-d*(sqrt(-a)+x*sqrt(b))/(-d*sqrt(-a)+c*sqrt(b)))/d+_
+--  2*polylog(2,(c+d*x)/c)/d-polylog(2,(c+d*x)*sqrt(b)/(-d*sqrt(-a)+_
+--  c*sqrt(b)))/d-polylog(2,(c+d*x)*sqrt(b)/(d*sqrt(-a)+c*sqrt(b)))/d
+--E 2865
+
+--S 2866 of 5341
+--a0:=integrate(t0,x)
+--E 2866
+
+--S 2867 of 5341
+--m0:=a0-r0
+--E 2867
+
+--S 2868 of 5341
+--d0:=D(m0,x)
+--E 2868
+
+)clear all
+
+--S 2869 of 5341
+t0:=log((a+b*x^n)/x^n)/(c+d*x)
+--R 
+--R
+--R               n
+--R            b x  + a
+--R        log(--------)
+--R                n
+--R               x
+--R   (1)  -------------
+--R           d x + c
+--R                                                    Type: Expression(Integer)
+--E 2869
+
+--S 2870 of 5341
+--r0:=a*n*Int(x^(-1-n)*log(c+d*x)/(b+a/x^n),x)/d+log(c+d*x)*log(b+a/x^n)/d
+--E 2870
+
+--S 2871 of 5341
+--a0:=integrate(t0,x)
+--E 2871
+
+--S 2872 of 5341
+--m0:=a0-r0
+--E 2872
+
+--S 2873 of 5341
+--d0:=D(m0,x)
+--E 2873
+
+)clear all
+
+--S 2874 of 5341
+t0:=(c+d*x)^3*log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R          3 3       2 2     2       3     b e x + a e
+--R   (1)  (d x  + 3c d x  + 3c d x + c )log(-----------)
+--R                                            d x + c
+--R                                                    Type: Expression(Integer)
+--E 2874
+
+--S 2875 of 5341
+r0:=-1/4*(b*c-a*d)^3*x/b^3-1/8*(b*c-a*d)^2*(c+d*x)^2/(b^2*d)-_
+   1/12*(b*c-a*d)*(c+d*x)^3/(b*d)-1/4*(b*c-a*d)^4*log(a+b*x)/(b^4*d)+_
+   1/4*(c+d*x)^4*log(e*(a+b*x)/(c+d*x))/d
+--R 
+--R
+--R   (2)
+--R            4 4      3     3      2 2 2 2        3 3      4 4
+--R       (- 6a d  + 24a b c d  - 36a b c d  + 24a b c d - 6b c )log(b x + a)
+--R     + 
+--R          4 4 4      4   3 3      4 2 2 2      4 3        4 4     b e x + a e
+--R       (6b d x  + 24b c d x  + 36b c d x  + 24b c d x + 6b c )log(-----------)
+--R                                                                    d x + c
+--R     + 
+--R            3 4     4   3  3        2 2 4        3   3     4 2 2  2
+--R       (2a b d  - 2b c d )x  + (- 3a b d  + 12a b c d  - 9b c d )x
+--R     + 
+--R          3   4      2 2   3        3 2 2      4 3        2 2 2 2       3 3
+--R       (6a b d  - 24a b c d  + 36a b c d  - 18b c d)x - 3a b c d  + 8a b c d
+--R     + 
+--R           4 4
+--R       - 5b c
+--R  /
+--R        4
+--R     24b d
+--R                                                    Type: Expression(Integer)
+--E 2875
+
+--S 2876 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4 4
+--R       - 6b c log(d x + c)
+--R     + 
+--R            4 4      3     3      2 2 2 2        3 3
+--R       (- 6a d  + 24a b c d  - 36a b c d  + 24a b c d)log(b x + a)
+--R     + 
+--R          4 4 4      4   3 3      4 2 2 2      4 3        b e x + a e
+--R       (6b d x  + 24b c d x  + 36b c d x  + 24b c d x)log(-----------)
+--R                                                            d x + c
+--R     + 
+--R            3 4     4   3  3        2 2 4        3   3     4 2 2  2
+--R       (2a b d  - 2b c d )x  + (- 3a b d  + 12a b c d  - 9b c d )x
+--R     + 
+--R          3   4      2 2   3        3 2 2      4 3
+--R       (6a b d  - 24a b c d  + 36a b c d  - 18b c d)x
+--R  /
+--R        4
+--R     24b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2876
+
+--S 2877 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2 4                 2 4                 2 4    b e x + a e      2 2 2
+--R       - 6b c log(d x + c) + 6b c log(b x + a) - 6b c log(-----------) + 3a c d
+--R                                                            d x + c
+--R     + 
+--R               3      2 4
+--R       - 8a b c d + 5b c
+--R  /
+--R        2
+--R     24b d
+--R                                                    Type: Expression(Integer)
+--E 2877
+
+--S 2878 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2878
+
+)clear all
+
+--S 2879 of 5341
+t0:=(c+d*x)^2*log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R          2 2             2     b e x + a e
+--R   (1)  (d x  + 2c d x + c )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 2879
+
+--S 2880 of 5341
+r0:=-1/3*(b*c-a*d)^2*x/b^2-1/6*(b*c-a*d)*(c+d*x)^2/(b*d)-_
+   1/3*(b*c-a*d)^3*log(a+b*x)/(b^3*d)+1/3*(c+d*x)^3*log(e*(a+b*x)/(c+d*x))/d
+--R 
+--R
+--R   (2)
+--R          3 3     2     2       2 2      3 3
+--R       (2a d  - 6a b c d  + 6a b c d - 2b c )log(b x + a)
+--R     + 
+--R          3 3 3     3   2 2     3 2        3 3     b e x + a e
+--R       (2b d x  + 6b c d x  + 6b c d x + 2b c )log(-----------)
+--R                                                     d x + c
+--R     + 
+--R           2 3    3   2  2        2   3       2   2     3 2         2 2     3 3
+--R       (a b d  - b c d )x  + (- 2a b d  + 6a b c d  - 4b c d)x + a b c d - b c
+--R  /
+--R       3
+--R     6b d
+--R                                                    Type: Expression(Integer)
+--E 2880
+
+--S 2881 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 3                  3 3     2     2       2 2
+--R       - 2b c log(d x + c) + (2a d  - 6a b c d  + 6a b c d)log(b x + a)
+--R     + 
+--R          3 3 3     3   2 2     3 2        b e x + a e        2 3    3   2  2
+--R       (2b d x  + 6b c d x  + 6b c d x)log(-----------) + (a b d  - b c d )x
+--R                                             d x + c
+--R     + 
+--R            2   3       2   2     3 2
+--R       (- 2a b d  + 6a b c d  - 4b c d)x
+--R  /
+--R       3
+--R     6b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2881
+
+--S 2882 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             3                   3                   3    b e x + a e       2
+--R       - 2b c log(d x + c) + 2b c log(b x + a) - 2b c log(-----------) - a c d
+--R                                                            d x + c
+--R     + 
+--R          3
+--R       b c
+--R  /
+--R     6b d
+--R                                                    Type: Expression(Integer)
+--E 2882
+
+--S 2883 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2883
+
+)clear all
+
+--S 2884 of 5341
+t0:=(c+d*x)*log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R                     b e x + a e
+--R   (1)  (d x + c)log(-----------)
+--R                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 2884
+
+--S 2885 of 5341
+r0:=-1/2*(b*c-a*d)*x/b-1/2*(b*c-a*d)^2*log(a+b*x)/(b^2*d)+1/2*(c+d*x)^2*_
+   log(e*(a+b*x)/(c+d*x))/d
+--R 
+--R
+--R   (2)
+--R           2 2               2 2
+--R       (- a d  + 2a b c d - b c )log(b x + a)
+--R     + 
+--R         2 2 2     2         2 2     b e x + a e          2    2
+--R       (b d x  + 2b c d x + b c )log(-----------) + (a b d  - b c d)x
+--R                                       d x + c
+--R  /
+--R       2
+--R     2b d
+--R                                                    Type: Expression(Integer)
+--E 2885
+
+--S 2886 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2                   2 2
+--R       - b c log(d x + c) + (- a d  + 2a b c d)log(b x + a)
+--R     + 
+--R         2 2 2     2          b e x + a e          2    2
+--R       (b d x  + 2b c d x)log(-----------) + (a b d  - b c d)x
+--R                                d x + c
+--R  /
+--R       2
+--R     2b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2886
+
+--S 2887 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           2                2                2    b e x + a e
+--R        - c log(d x + c) + c log(b x + a) - c log(-----------)
+--R                                                    d x + c
+--R   (4)  ------------------------------------------------------
+--R                                  2d
+--R                                                    Type: Expression(Integer)
+--E 2887
+
+--S 2888 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2888
+
+)clear all
+
+--S 2889 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R            b e x + a e
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 2889
+
+--S 2890 of 5341
+r0:=(a+b*x)*log(e*(a+b*x)/(c+d*x))/b-(b*c-a*d)*log(c+d*x)/(b*d)
+--R 
+--R
+--R                                                   b e x + a e
+--R        (a d - b c)log(d x + c) + (b d x + a d)log(-----------)
+--R                                                     d x + c
+--R   (2)  -------------------------------------------------------
+--R                                  b d
+--R                                                    Type: Expression(Integer)
+--E 2890
+
+--S 2891 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                          b e x + a e
+--R        - b c log(d x + c) + a d log(b x + a) + b d x log(-----------)
+--R                                                            d x + c
+--R   (3)  --------------------------------------------------------------
+--R                                      b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2891
+
+--S 2892 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                                                  b e x + a e
+--R        - a log(d x + c) + a log(b x + a) - a log(-----------)
+--R                                                    d x + c
+--R   (4)  ------------------------------------------------------
+--R                                   b
+--R                                                    Type: Expression(Integer)
+--E 2892
+
+--S 2893 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2893
+
+)clear all
+
+--S 2894 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))/(c+d*x)
+--R 
+--R
+--R            b e x + a e
+--R        log(-----------)
+--R              d x + c
+--R   (1)  ----------------
+--R             d x + c
+--R                                                    Type: Expression(Integer)
+--E 2894
+
+--S 2895 of 5341
+--r0:=-log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/d-_
+--  polylog(2,d*(a+b*x)/(b*(c+d*x)))/d
+--E 2895
+
+--S 2896 of 5341
+--a0:=integrate(t0,x)
+--E 2896
+
+--S 2897 of 5341
+--m0:=a0-r0
+--E 2897
+
+--S 2898 of 5341
+--d0:=D(m0,x)
+--E 2898
+
+)clear all
+
+--S 2899 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))/(c+d*x)^2
+--R 
+--R
+--R             b e x + a e
+--R         log(-----------)
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 2899
+
+--S 2900 of 5341
+r0:=1/(d*(c+d*x))+(a+b*x)*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)*(c+d*x))
+--R 
+--R
+--R                           b e x + a e
+--R        (- b d x - a d)log(-----------) + a d - b c
+--R                             d x + c
+--R   (2)  -------------------------------------------
+--R                 3        2          2      2
+--R             (a d  - b c d )x + a c d  - b c d
+--R                                                    Type: Expression(Integer)
+--E 2900
+
+--S 2901 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                           b e x + a e
+--R        (- b d x - a d)log(-----------) + a d - b c
+--R                             d x + c
+--R   (3)  -------------------------------------------
+--R                 3        2          2      2
+--R             (a d  - b c d )x + a c d  - b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2901
+
+--S 2902 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2902
+
+--S 2903 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2903
+
+)clear all
+
+--S 2904 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))/(c+d*x)^3
+--R 
+--R
+--R                  b e x + a e
+--R              log(-----------)
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 2904
+
+--S 2905 of 5341
+r0:=1/4/(d*(c+d*x)^2)+1/2*b/(d*(b*c-a*d)*(c+d*x))+1/2*b^2*log(a+b*x)/(d*_
+   (b*c-a*d)^2)-1/2*log(e*(a+b*x)/(c+d*x))/(d*(c+d*x)^2)-1/2*b^2*log(c+d*x)/_
+   (d*(b*c-a*d)^2)
+--R 
+--R
+--R   (2)
+--R            2 2 2     2          2 2
+--R       (- 2b d x  - 4b c d x - 2b c )log(d x + c)
+--R     + 
+--R          2 2 2     2          2 2
+--R       (2b d x  + 4b c d x + 2b c )log(b x + a)
+--R     + 
+--R            2 2                2 2     b e x + a e             2     2
+--R       (- 2a d  + 4a b c d - 2b c )log(-----------) + (- 2a b d  + 2b c d)x
+--R                                         d x + c
+--R     + 
+--R        2 2                2 2
+--R       a d  - 4a b c d + 3b c
+--R  /
+--R          2 5           4     2 2 3  2      2   4          2 3     2 3 2
+--R       (4a d  - 8a b c d  + 4b c d )x  + (8a c d  - 16a b c d  + 8b c d )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       4a c d  - 8a b c d  + 4b c d
+--R                                                    Type: Expression(Integer)
+--E 2905
+
+--S 2906 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2 2     2          2 2                b e x + a e
+--R       (2b d x  + 4b c d x - 2a d  + 4a b c d)log(-----------)
+--R                                                    d x + c
+--R     + 
+--R                2     2         2 2                2 2
+--R       (- 2a b d  + 2b c d)x + a d  - 4a b c d + 3b c
+--R  /
+--R          2 5           4     2 2 3  2      2   4          2 3     2 3 2
+--R       (4a d  - 8a b c d  + 4b c d )x  + (8a c d  - 16a b c d  + 8b c d )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       4a c d  - 8a b c d  + 4b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2906
+
+--S 2907 of 5341
+m0:=a0-r0
+--R 
+--R
+--R         2                2                2    b e x + a e
+--R        b log(d x + c) - b log(b x + a) + b log(-----------)
+--R                                                  d x + c
+--R   (4)  ----------------------------------------------------
+--R                       2 3           2     2 2
+--R                     2a d  - 4a b c d  + 2b c d
+--R                                                    Type: Expression(Integer)
+--E 2907
+
+--S 2908 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2908
+
+)clear all
+
+--S 2909 of 5341
+t0:=(c+d*x)^3*log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R          3 3       2 2     2       3     b e x + a e 2
+--R   (1)  (d x  + 3c d x  + 3c d x + c )log(-----------)
+--R                                            d x + c
+--R                                                    Type: Expression(Integer)
+--E 2909
+
+--S 2910 of 5341
+--r0:=5/12*(b*c-a*d)^3*x/b^3+1/12*(b*c-a*d)^2*(c+d*x)^2/(b^2*d)+_
+--  5/12*(b*c-a*d)^4*log(a+b*x)/(b^4*d)-1/2*(b*c-a*d)^3*(a+b*x)*_
+--  log(e*(a+b*x)/(c+d*x))/b^4-1/4*(b*c-a*d)^2*(c+d*x)^2*log(e*(a+b*x)/_
+--  (c+d*x))/(b^2*d)-1/6*(b*c-a*d)*(c+d*x)^3*log(e*(a+b*x)/(c+d*x))/_
+--  (b*d)+1/2*(b*c-a*d)^4*log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/_
+--  (c+d*x))/(b^4*d)+1/4*(c+d*x)^4*log(e*(a+b*x)/(c+d*x))^2/d+1/2*_
+--  (b*c-a*d)^4*log(c+d*x)/(b^4*d)-1/2*(b*c-a*d)^4*polylog(2,_
+--  b*(c+d*x)/(d*(a+b*x)))/(b^4*d)
+--E 2910
+
+--S 2911 of 5341
+--a0:=integrate(t0,x)
+--E 2911
+
+--S 2912 of 5341
+--m0:=a0-r0
+--E 2912
+
+--S 2913 of 5341
+--d0:=D(m0,x)
+--E 2913
+
+)clear all
+
+--S 2914 of 5341
+t0:=(c+d*x)^2*log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R          2 2             2     b e x + a e 2
+--R   (1)  (d x  + 2c d x + c )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 2914
+
+--S 2915 of 5341
+--r0:=1/3*(b*c-a*d)^2*x/b^2+1/3*(b*c-a*d)^3*log(a+b*x)/(b^3*d)-_
+--  2/3*(b*c-a*d)^2*(a+b*x)*log(e*(a+b*x)/(c+d*x))/b^3-1/3*(b*c-a*d)*_
+--  (c+d*x)^2*log(e*(a+b*x)/(c+d*x))/(b*d)+2/3*(b*c-a*d)^3*log((-b*c+a*d)/_
+--  (d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))/(b^3*d)+1/3*(c+d*x)^3*log(e*_
+--  (a+b*x)/(c+d*x))^2/d+2/3*(b*c-a*d)^3*log(c+d*x)/(b^3*d)-_
+--  2/3*(b*c-a*d)^3*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^3*d)
+--E 2915
+
+--S 2916 of 5341
+--a0:=integrate(t0,x)
+--E 2916
+
+--S 2917 of 5341
+--m0:=a0-r0
+--E 2917
+
+--S 2918 of 5341
+--d0:=D(m0,x)
+--E 2918
+
+)clear all
+
+--S 2919 of 5341
+t0:=(c+d*x)*log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R                     b e x + a e 2
+--R   (1)  (d x + c)log(-----------)
+--R                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 2919
+
+--S 2920 of 5341
+--r0:=-(b*c-a*d)*(a+b*x)*log(e*(a+b*x)/(c+d*x))/b^2+(b*c-a*d)^2*_
+--  log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))/(b^2*d)+_
+--  1/2*(c+d*x)^2*log(e*(a+b*x)/(c+d*x))^2/d+(b*c-a*d)^2*log(c+d*x)/_
+--  (b^2*d)-(b*c-a*d)^2*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^2*d)
+--E 2920
+
+--S 2921 of 5341
+--a0:=integrate(t0,x)
+--E 2921
+
+--S 2922 of 5341
+--m0:=a0-r0
+--E 2922
+
+--S 2923 of 5341
+--d0:=D(m0,x)
+--E 2923
+
+)clear all
+
+--S 2924 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R            b e x + a e 2
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 2924
+
+--S 2925 of 5341
+--r0:=2*(b*c-a*d)*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/(b*d)+_
+--  (a+b*x)*log(e*(a+b*x)/(c+d*x))^2/b+2*(b*c-a*d)*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(b*d)
+--E 2925
+
+--S 2926 of 5341
+--a0:=integrate(t0,x)
+--E 2926
+
+--S 2927 of 5341
+--m0:=a0-r0
+--E 2927
+
+--S 2928 of 5341
+--d0:=D(m0,x)
+--E 2928
+
+)clear all
+
+--S 2929 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2/(c+d*x)
+--R 
+--R
+--R            b e x + a e 2
+--R        log(-----------)
+--R              d x + c
+--R   (1)  -----------------
+--R             d x + c
+--R                                                    Type: Expression(Integer)
+--E 2929
+
+--S 2930 of 5341
+--r0:=-log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^2/d-_
+--  2*log(e*(a+b*x)/(c+d*x))*polylog(2,d*(a+b*x)/(b*(c+d*x)))/d+_
+--  2*polylog(3,d*(a+b*x)/(b*(c+d*x)))/d
+--E 2930
+
+--S 2931 of 5341
+--a0:=integrate(t0,x)
+--E 2931
+
+--S 2932 of 5341
+--m0:=a0-r0
+--E 2932
+
+--S 2933 of 5341
+--d0:=D(m0,x)
+--E 2933
+
+)clear all
+
+--S 2934 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2/(c+d*x)^2
+--R 
+--R
+--R             b e x + a e 2
+--R         log(-----------)
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 2934
+
+--S 2935 of 5341
+r0:=(-2)/(d*(c+d*x))-2*(a+b*x)*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)*(c+d*x))+_
+   (a+b*x)*log(e*(a+b*x)/(c+d*x))^2/((b*c-a*d)*(c+d*x))
+--R 
+--R
+--R   (2)
+--R                          b e x + a e 2                      b e x + a e
+--R       (- b d x - a d)log(-----------)  + (2b d x + 2a d)log(-----------) - 2a d
+--R                            d x + c                            d x + c
+--R     + 
+--R       2b c
+--R  /
+--R         3        2          2      2
+--R     (a d  - b c d )x + a c d  - b c d
+--R                                                    Type: Expression(Integer)
+--E 2935
+
+--S 2936 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          b e x + a e 2                      b e x + a e
+--R       (- b d x - a d)log(-----------)  + (2b d x + 2a d)log(-----------) - 2a d
+--R                            d x + c                            d x + c
+--R     + 
+--R       2b c
+--R  /
+--R         3        2          2      2
+--R     (a d  - b c d )x + a c d  - b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2936
+
+--S 2937 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2937
+
+--S 2938 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2938
+
+)clear all
+
+--S 2939 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2/(c+d*x)^3
+--R 
+--R
+--R                  b e x + a e 2
+--R              log(-----------)
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 2939
+
+--S 2940 of 5341
+r0:=-1/4*d*(a+b*x)^2/((b*c-a*d)^2*(c+d*x)^2)-2*b/(d*(b*c-a*d)*(c+d*x))+_
+   1/2*d*(a+b*x)^2*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)^2*(c+d*x)^2)-2*b*(a+_
+   b*x)*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)^2*(c+d*x))-1/2*d*(a+b*x)^2*log(e*_
+   (a+b*x)/(c+d*x))^2/((b*c-a*d)^2*(c+d*x)^2)+b*(a+b*x)*log(e*(a+b*x)/_
+   (c+d*x))^2/((b*c-a*d)^2*(c+d*x))
+--R 
+--R
+--R   (2)
+--R          2 2 2     2          2 2                b e x + a e 2
+--R       (2b d x  + 4b c d x - 2a d  + 4a b c d)log(-----------)
+--R                                                    d x + c
+--R     + 
+--R            2 2 2            2     2          2 2                b e x + a e
+--R       (- 6b d x  + (- 4a b d  - 8b c d)x + 2a d  - 8a b c d)log(-----------)
+--R                                                                   d x + c
+--R     + 
+--R          2 2 2          2     2         2 2                2 2
+--R       - b d x  + (6a b d  - 8b c d)x - a d  + 8a b c d - 8b c
+--R  /
+--R          2 5           4     2 2 3  2      2   4          2 3     2 3 2
+--R       (4a d  - 8a b c d  + 4b c d )x  + (8a c d  - 16a b c d  + 8b c d )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       4a c d  - 8a b c d  + 4b c d
+--R                                                    Type: Expression(Integer)
+--E 2940
+
+--S 2941 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2 2     2          2 2                b e x + a e 2
+--R       (2b d x  + 4b c d x - 2a d  + 4a b c d)log(-----------)
+--R                                                    d x + c
+--R     + 
+--R            2 2 2            2     2          2 2                b e x + a e
+--R       (- 6b d x  + (- 4a b d  - 8b c d)x + 2a d  - 8a b c d)log(-----------)
+--R                                                                   d x + c
+--R     + 
+--R              2     2         2 2                2 2
+--R       (6a b d  - 6b c d)x - a d  + 8a b c d - 7b c
+--R  /
+--R          2 5           4     2 2 3  2      2   4          2 3     2 3 2
+--R       (4a d  - 8a b c d  + 4b c d )x  + (8a c d  - 16a b c d  + 8b c d )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       4a c d  - 8a b c d  + 4b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2941
+
+--S 2942 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                     2
+--R                    b
+--R   (4)  --------------------------
+--R          2 3           2     2 2
+--R        4a d  - 8a b c d  + 4b c d
+--R                                                    Type: Expression(Integer)
+--E 2942
+
+--S 2943 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2943
+
+)clear all
+
+--S 2944 of 5341
+t0:=(c+d*x)^2*log(e*(a+b*x)/(c+d*x))^3
+--R 
+--R
+--R          2 2             2     b e x + a e 3
+--R   (1)  (d x  + 2c d x + c )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 2944
+
+--S 2945 of 5341
+--r0:=(b*c-a*d)^2*(a+b*x)*log(e*(a+b*x)/(c+d*x))/b^3-(b*c-a*d)^3*_
+--  log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))/(b^3*d)-_
+--  2*(b*c-a*d)^3*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/_
+--  (b^3*d)-(b*c-a*d)^2*(a+b*x)*log(e*(a+b*x)/(c+d*x))^2/b^3-_
+--  1/2*(b*c-a*d)*(c+d*x)^2*log(e*(a+b*x)/(c+d*x))^2/(b*d)+(b*c-a*d)^3*_
+--  log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))^2/(b^3*d)+_
+--  1/3*(c+d*x)^3*log(e*(a+b*x)/(c+d*x))^3/d-(b*c-a*d)^3*log(c+d*x)/_
+--  (b^3*d)-2*(b*c-a*d)^3*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b^3*d)+_
+--  (b*c-a*d)^3*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^3*d)-2*(b*c-a*d)^3*_
+--  log(e*(a+b*x)/(c+d*x))*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^3*d)-_
+--  2*(b*c-a*d)^3*polylog(3,b*(c+d*x)/(d*(a+b*x)))/(b^3*d)
+--E 2945
+
+--S 2946 of 5341
+--a0:=integrate(t0,x)
+--E 2946
+
+--S 2947 of 5341
+--m0:=a0-r0
+--E 2947
+
+--S 2948 of 5341
+--d0:=D(m0,x)
+--E 2948
+
+)clear all
+
+--S 2949 of 5341
+t0:=(c+d*x)*log(e*(a+b*x)/(c+d*x))^3
+--R 
+--R
+--R                     b e x + a e 3
+--R   (1)  (d x + c)log(-----------)
+--R                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 2949
+
+--S 2950 of 5341
+--r0:=-3*(b*c-a*d)^2*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/_
+--  (b^2*d)-3/2*(b*c-a*d)*(a+b*x)*log(e*(a+b*x)/(c+d*x))^2/b^2+3/2*_
+--  (b*c-a*d)^2*log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))^2/_
+--  (b^2*d)+1/2*(c+d*x)^2*log(e*(a+b*x)/(c+d*x))^3/d-3*(b*c-a*d)^2*_
+--  polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b^2*d)-3*(b*c-a*d)^2*log(e*_
+--  (a+b*x)/(c+d*x))*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^2*d)-_
+--  3*(b*c-a*d)^2*polylog(3,b*(c+d*x)/(d*(a+b*x)))/(b^2*d)
+--E 2950
+
+--S 2951 of 5341
+--a0:=integrate(t0,x)
+--E 2951
+
+--S 2952 of 5341
+--m0:=a0-r0
+--E 2952
+
+--S 2953 of 5341
+--d0:=D(m0,x)
+--E 2953
+
+)clear all
+
+--S 2954 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3
+--R 
+--R
+--R            b e x + a e 3
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 2954
+
+--S 2955 of 5341
+--r0:=3*(b*c-a*d)*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/_
+--  (c+d*x))^2/(b*d)+(a+b*x)*log(e*(a+b*x)/(c+d*x))^3/b+6*(b*c-a*d)*_
+--  log(e*(a+b*x)/(c+d*x))*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d)-_
+--  6*(b*c-a*d)*polylog(3,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 2955
+
+--S 2956 of 5341
+--a0:=integrate(t0,x)
+--E 2956
+
+--S 2957 of 5341
+--m0:=a0-r0
+--E 2957
+
+--S 2958 of 5341
+--d0:=D(m0,x)
+--E 2958
+
+)clear all
+
+--S 2959 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3/(c+d*x)
+--R 
+--R
+--R            b e x + a e 3
+--R        log(-----------)
+--R              d x + c
+--R   (1)  -----------------
+--R             d x + c
+--R                                                    Type: Expression(Integer)
+--E 2959
+
+--S 2960 of 5341
+--r0:=-log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^3/d-_
+--  3*log(e*(a+b*x)/(c+d*x))^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/d+_
+--  6*log(e*(a+b*x)/(c+d*x))*polylog(3,d*(a+b*x)/(b*(c+d*x)))/d-_
+--  6*polylog(4,d*(a+b*x)/(b*(c+d*x)))/d
+--E 2960
+
+--S 2961 of 5341
+--a0:=integrate(t0,x)
+--E 2961
+
+--S 2962 of 5341
+--m0:=a0-r0
+--E 2962
+
+--S 2963 of 5341
+--d0:=D(m0,x)
+--E 2963
+
+)clear all
+
+--S 2964 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3/(c+d*x)^2
+--R 
+--R
+--R             b e x + a e 3
+--R         log(-----------)
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 2964
+
+--S 2965 of 5341
+r0:=6/(d*(c+d*x))+6*(a+b*x)*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)*(c+d*x))-_
+   3*(a+b*x)*log(e*(a+b*x)/(c+d*x))^2/((b*c-a*d)*(c+d*x))+(a+b*x)*_
+   log(e*(a+b*x)/(c+d*x))^3/((b*c-a*d)*(c+d*x))
+--R 
+--R
+--R   (2)
+--R                          b e x + a e 3                      b e x + a e 2
+--R       (- b d x - a d)log(-----------)  + (3b d x + 3a d)log(-----------)
+--R                            d x + c                            d x + c
+--R     + 
+--R                            b e x + a e
+--R       (- 6b d x - 6a d)log(-----------) + 6a d - 6b c
+--R                              d x + c
+--R  /
+--R         3        2          2      2
+--R     (a d  - b c d )x + a c d  - b c d
+--R                                                    Type: Expression(Integer)
+--E 2965
+
+--S 2966 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                          b e x + a e 3                      b e x + a e 2
+--R       (- b d x - a d)log(-----------)  + (3b d x + 3a d)log(-----------)
+--R                            d x + c                            d x + c
+--R     + 
+--R                            b e x + a e
+--R       (- 6b d x - 6a d)log(-----------) + 6a d - 6b c
+--R                              d x + c
+--R  /
+--R         3        2          2      2
+--R     (a d  - b c d )x + a c d  - b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2966
+
+--S 2967 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 2967
+
+--S 2968 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2968
+
+)clear all
+
+--S 2969 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3/(c+d*x)^3
+--R 
+--R
+--R                  b e x + a e 3
+--R              log(-----------)
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 2969
+
+--S 2970 of 5341
+r0:=3/8*d*(a+b*x)^2/((b*c-a*d)^2*(c+d*x)^2)+6*b/(d*(b*c-a*d)*(c+d*x))-_
+   3/4*d*(a+b*x)^2*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)^2*(c+d*x)^2)+6*b*(a+_
+   b*x)*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)^2*(c+d*x))+3/4*d*(a+b*x)^2*log(e*_
+   (a+b*x)/(c+d*x))^2/((b*c-a*d)^2*(c+d*x)^2)-3*b*(a+b*x)*log(e*(a+b*x)/_
+   (c+d*x))^2/((b*c-a*d)^2*(c+d*x))-1/2*d*(a+b*x)^2*log(e*(a+b*x)/(c+_
+   d*x))^3/((b*c-a*d)^2*(c+d*x)^2)+b*(a+b*x)*log(e*(a+b*x)/(c+d*x))^3/_
+   ((b*c-a*d)^2*(c+d*x))
+--R 
+--R
+--R   (2)
+--R          2 2 2     2          2 2                b e x + a e 3
+--R       (4b d x  + 8b c d x - 4a d  + 8a b c d)log(-----------)
+--R                                                    d x + c
+--R     + 
+--R               2 2 2             2      2          2 2
+--R         (- 18b d x  + (- 12a b d  - 24b c d)x + 6a d  - 24a b c d)
+--R      *
+--R             b e x + a e 2
+--R         log(-----------)
+--R               d x + c
+--R     + 
+--R           2 2 2           2      2          2 2                 b e x + a e
+--R       (42b d x  + (36a b d  + 48b c d)x - 6a d  + 48a b c d)log(-----------)
+--R                                                                   d x + c
+--R     + 
+--R         2 2 2             2      2          2 2                  2 2
+--R       3b d x  + (- 42a b d  + 48b c d)x + 3a d  - 48a b c d + 48b c
+--R  /
+--R          2 5            4     2 2 3  2       2   4          2 3      2 3 2
+--R       (8a d  - 16a b c d  + 8b c d )x  + (16a c d  - 32a b c d  + 16b c d )x
+--R     + 
+--R         2 2 3          3 2     2 4
+--R       8a c d  - 16a b c d  + 8b c d
+--R                                                    Type: Expression(Integer)
+--E 2970
+
+--S 2971 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2 2     2          2 2                b e x + a e 3
+--R       (4b d x  + 8b c d x - 4a d  + 8a b c d)log(-----------)
+--R                                                    d x + c
+--R     + 
+--R               2 2 2             2      2          2 2
+--R         (- 18b d x  + (- 12a b d  - 24b c d)x + 6a d  - 24a b c d)
+--R      *
+--R             b e x + a e 2
+--R         log(-----------)
+--R               d x + c
+--R     + 
+--R           2 2 2           2      2          2 2                 b e x + a e
+--R       (42b d x  + (36a b d  + 48b c d)x - 6a d  + 48a b c d)log(-----------)
+--R                                                                   d x + c
+--R     + 
+--R                 2      2          2 2                  2 2
+--R       (- 42a b d  + 42b c d)x + 3a d  - 48a b c d + 45b c
+--R  /
+--R          2 5            4     2 2 3  2       2   4          2 3      2 3 2
+--R       (8a d  - 16a b c d  + 8b c d )x  + (16a c d  - 32a b c d  + 16b c d )x
+--R     + 
+--R         2 2 3          3 2     2 4
+--R       8a c d  - 16a b c d  + 8b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 2971
+
+--S 2972 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                        2
+--R                      3b
+--R   (4)  - ---------------------------
+--R            2 3            2     2 2
+--R          8a d  - 16a b c d  + 8b c d
+--R                                                    Type: Expression(Integer)
+--E 2972
+
+--S 2973 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 2973
+
+)clear all
+
+--S 2974 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^4
+--R 
+--R
+--R            b e x + a e 4
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 2974
+
+--S 2975 of 5341
+--r0:=4*(b*c-a*d)*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/_
+--  (c+d*x))^3/(b*d)+(a+b*x)*log(e*(a+b*x)/(c+d*x))^4/b+12*(b*c-a*d)*_
+--  log(e*(a+b*x)/(c+d*x))^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d)-24*_
+--  (b*c-a*d)*log(e*(a+b*x)/(c+d*x))*polylog(3,d*(a+b*x)/(b*(c+d*x)))/_
+--  (b*d)+24*(b*c-a*d)*polylog(4,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 2975
+
+--S 2976 of 5341
+--a0:=integrate(t0,x)
+--E 2976
+
+--S 2977 of 5341
+--m0:=a0-r0
+--E 2977
+
+--S 2978 of 5341
+--d0:=D(m0,x)
+--E 2978
+
+)clear all
+
+--S 2979 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^5
+--R 
+--R
+--R            b e x + a e 5
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 2979
+
+--S 2980 of 5341
+--r0:=5*(b*c-a*d)*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^4/(b*d)+_
+--  (a+b*x)*log(e*(a+b*x)/(c+d*x))^5/b+20*(b*c-a*d)*log(e*(a+b*x)/(c+_
+--  d*x))^3*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d)-60*(b*c-a*d)*_
+--  log(e*(a+b*x)/(c+d*x))^2*polylog(3,d*(a+b*x)/(b*(c+d*x)))/(b*d)+_
+--  120*(b*c-a*d)*log(e*(a+b*x)/(c+d*x))*polylog(4,d*(a+b*x)/_
+--  (b*(c+d*x)))/(b*d)-120*(b*c-a*d)*polylog(5,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 2980
+
+--S 2981 of 5341
+--a0:=integrate(t0,x)
+--E 2981
+
+--S 2982 of 5341
+--m0:=a0-r0
+--E 2982
+
+--S 2983 of 5341
+--d0:=D(m0,x)
+--E 2983
+
+)clear all
+
+--S 2984 of 5341
+t0:=log(d*(a+b*x)/(b*(c+d*x)))/(c*f+d*f*x)
+--R 
+--R
+--R            b d x + a d
+--R        log(-----------)
+--R            b d x + b c
+--R   (1)  ----------------
+--R           d f x + c f
+--R                                                    Type: Expression(Integer)
+--E 2984
+
+--S 2985 of 5341
+--r0:=polylog(2,(b*c-a*d)/(b*(c+d*x)))/(d*f)
+--E 2985
+
+--S 2986 of 5341
+--a0:=integrate(t0,x)
+--E 2986
+
+--S 2987 of 5341
+--m0:=a0-r0
+--E 2987
+
+--S 2988 of 5341
+--d0:=D(m0,x)
+--E 2988
+
+)clear all
+
+--S 2989 of 5341
+t0:=log(1+1/(a+b*x))/(a+b*x)
+--R 
+--R
+--R            b x + a + 1
+--R        log(-----------)
+--R              b x + a
+--R   (1)  ----------------
+--R             b x + a
+--R                                                    Type: Expression(Integer)
+--E 2989
+
+--S 2990 of 5341
+--r0:=polylog(2,(-1)/(a+b*x))/b
+--E 2990
+
+--S 2991 of 5341
+--a0:=integrate(t0,x)
+--E 2991
+
+--S 2992 of 5341
+--m0:=a0-r0
+--E 2992
+
+--S 2993 of 5341
+--d0:=D(m0,x)
+--E 2993
+
+)clear all
+
+--S 2994 of 5341
+t0:=log(1+(-1)/(a+b*x))/(a+b*x)
+--R 
+--R
+--R            b x + a - 1
+--R        log(-----------)
+--R              b x + a
+--R   (1)  ----------------
+--R             b x + a
+--R                                                    Type: Expression(Integer)
+--E 2994
+
+--S 2995 of 5341
+--r0:=polylog(2,1/(a+b*x))/b
+--E 2995
+
+--S 2996 of 5341
+--a0:=integrate(t0,x)
+--E 2996
+
+--S 2997 of 5341
+--m0:=a0-r0
+--E 2997
+
+--S 2998 of 5341
+--d0:=D(m0,x)
+--E 2998
+
+)clear all
+
+--S 2999 of 5341
+t0:=(a+b*x)^3*log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R          3 3       2 2     2       3     b e x + a e
+--R   (1)  (b x  + 3a b x  + 3a b x + a )log(-----------)
+--R                                            d x + c
+--R                                                    Type: Expression(Integer)
+--E 2999
+
+--S 3000 of 5341
+r0:=-1/4*(b*c-a*d)^3*x/d^3+1/8*(b*c-a*d)^2*(a+b*x)^2/(b*d^2)-_
+   1/12*(b*c-a*d)*(a+b*x)^3/(b*d)+1/4*(a+b*x)^4*log(e*(a+b*x)/(c+d*x))/b+_
+   1/4*(b*c-a*d)^4*log(c+d*x)/(b*d^4)
+--R 
+--R
+--R   (2)
+--R          4 4      3     3      2 2 2 2        3 3      4 4
+--R       (6a d  - 24a b c d  + 36a b c d  - 24a b c d + 6b c )log(d x + c)
+--R     + 
+--R          4 4 4        3 4 3      2 2 4 2      3   4      4 4     b e x + a e
+--R       (6b d x  + 24a b d x  + 36a b d x  + 24a b d x + 6a d )log(-----------)
+--R                                                                    d x + c
+--R     + 
+--R            3 4     4   3  3      2 2 4        3   3     4 2 2  2
+--R       (2a b d  - 2b c d )x  + (9a b d  - 12a b c d  + 3b c d )x
+--R     + 
+--R           3   4      2 2   3        3 2 2     4 3        4 4     3     3
+--R       (18a b d  - 36a b c d  + 24a b c d  - 6b c d)x + 5a d  - 8a b c d
+--R     + 
+--R         2 2 2 2
+--R       3a b c d
+--R  /
+--R          4
+--R     24b d
+--R                                                    Type: Expression(Integer)
+--E 3000
+
+--S 3001 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R             3     3      2 2 2 2        3 3      4 4
+--R       (- 24a b c d  + 36a b c d  - 24a b c d + 6b c )log(d x + c)
+--R     + 
+--R         4 4
+--R       6a d log(b x + a)
+--R     + 
+--R          4 4 4        3 4 3      2 2 4 2      3   4      b e x + a e
+--R       (6b d x  + 24a b d x  + 36a b d x  + 24a b d x)log(-----------)
+--R                                                            d x + c
+--R     + 
+--R            3 4     4   3  3      2 2 4        3   3     4 2 2  2
+--R       (2a b d  - 2b c d )x  + (9a b d  - 12a b c d  + 3b c d )x
+--R     + 
+--R           3   4      2 2   3        3 2 2     4 3
+--R       (18a b d  - 36a b c d  + 24a b c d  - 6b c d)x
+--R  /
+--R          4
+--R     24b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3001
+
+--S 3002 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           4 2                 4 2                 4 2    b e x + a e      4 2
+--R       - 6a d log(d x + c) + 6a d log(b x + a) - 6a d log(-----------) - 5a d
+--R                                                            d x + c
+--R     + 
+--R         3          2 2 2
+--R       8a b c d - 3a b c
+--R  /
+--R          2
+--R     24b d
+--R                                                    Type: Expression(Integer)
+--E 3002
+
+--S 3003 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3003
+
+)clear all
+
+--S 3004 of 5341
+t0:=(a+b*x)^2*log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R          2 2             2     b e x + a e
+--R   (1)  (b x  + 2a b x + a )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 3004
+
+--S 3005 of 5341
+r0:=1/3*(b*c-a*d)^2*x/d^2-1/6*(b*c-a*d)*(a+b*x)^2/(b*d)+1/3*(a+b*x)^3*_
+   log(e*(a+b*x)/(c+d*x))/b-1/3*(b*c-a*d)^3*log(c+d*x)/(b*d^3)
+--R 
+--R
+--R   (2)
+--R          3 3     2     2       2 2      3 3
+--R       (2a d  - 6a b c d  + 6a b c d - 2b c )log(d x + c)
+--R     + 
+--R          3 3 3       2 3 2     2   3      3 3     b e x + a e
+--R       (2b d x  + 6a b d x  + 6a b d x + 2a d )log(-----------)
+--R                                                     d x + c
+--R     + 
+--R           2 3    3   2  2      2   3       2   2     3 2       3 3    2     2
+--R       (a b d  - b c d )x  + (4a b d  - 6a b c d  + 2b c d)x + a d  - a b c d
+--R  /
+--R         3
+--R     6b d
+--R                                                    Type: Expression(Integer)
+--E 3005
+
+--S 3006 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2     2       2 2      3 3                  3 3
+--R       (- 6a b c d  + 6a b c d - 2b c )log(d x + c) + 2a d log(b x + a)
+--R     + 
+--R          3 3 3       2 3 2     2   3      b e x + a e        2 3    3   2  2
+--R       (2b d x  + 6a b d x  + 6a b d x)log(-----------) + (a b d  - b c d )x
+--R                                             d x + c
+--R     + 
+--R          2   3       2   2     3 2
+--R       (4a b d  - 6a b c d  + 2b c d)x
+--R  /
+--R         3
+--R     6b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3006
+
+--S 3007 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       3                   3                   3      b e x + a e     3     2
+--R   - 2a d log(d x + c) + 2a d log(b x + a) - 2a d log(-----------) - a d + a b c
+--R                                                        d x + c
+--R   -----------------------------------------------------------------------------
+--R                                        6b d
+--R                                                    Type: Expression(Integer)
+--E 3007
+
+--S 3008 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3008
+
+)clear all
+
+--S 3009 of 5341
+t0:=(a+b*x)*log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R                     b e x + a e
+--R   (1)  (b x + a)log(-----------)
+--R                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 3009
+
+--S 3010 of 5341
+r0:=-1/2*(b*c-a*d)*x/d+1/2*(a+b*x)^2*log(e*(a+b*x)/(c+d*x))/b+1/2*(b*c-_
+   a*d)^2*log(c+d*x)/(b*d^2)
+--R 
+--R
+--R   (2)
+--R         2 2               2 2
+--R       (a d  - 2a b c d + b c )log(d x + c)
+--R     + 
+--R         2 2 2         2     2 2     b e x + a e          2    2
+--R       (b d x  + 2a b d x + a d )log(-----------) + (a b d  - b c d)x
+--R                                       d x + c
+--R  /
+--R         2
+--R     2b d
+--R                                                    Type: Expression(Integer)
+--E 3010
+
+--S 3011 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      2 2                 2 2
+--R       (- 2a b c d + b c )log(d x + c) + a d log(b x + a)
+--R     + 
+--R         2 2 2         2      b e x + a e          2    2
+--R       (b d x  + 2a b d x)log(-----------) + (a b d  - b c d)x
+--R                                d x + c
+--R  /
+--R         2
+--R     2b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3011
+
+--S 3012 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           2                2                2    b e x + a e
+--R        - a log(d x + c) + a log(b x + a) - a log(-----------)
+--R                                                    d x + c
+--R   (4)  ------------------------------------------------------
+--R                                  2b
+--R                                                    Type: Expression(Integer)
+--E 3012
+
+--S 3013 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3013
+
+)clear all
+
+--S 3014 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R            b e x + a e
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 3014
+
+--S 3015 of 5341
+r0:=(a+b*x)*log(e*(a+b*x)/(c+d*x))/b-(b*c-a*d)*log(c+d*x)/(b*d)
+--R 
+--R
+--R                                                   b e x + a e
+--R        (a d - b c)log(d x + c) + (b d x + a d)log(-----------)
+--R                                                     d x + c
+--R   (2)  -------------------------------------------------------
+--R                                  b d
+--R                                                    Type: Expression(Integer)
+--E 3015
+
+--S 3016 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                          b e x + a e
+--R        - b c log(d x + c) + a d log(b x + a) + b d x log(-----------)
+--R                                                            d x + c
+--R   (3)  --------------------------------------------------------------
+--R                                      b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3016
+
+--S 3017 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                                                  b e x + a e
+--R        - a log(d x + c) + a log(b x + a) - a log(-----------)
+--R                                                    d x + c
+--R   (4)  ------------------------------------------------------
+--R                                   b
+--R                                                    Type: Expression(Integer)
+--E 3017
+
+--S 3018 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3018
+
+)clear all
+
+--S 3019 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))/(a+b*x)
+--R 
+--R
+--R            b e x + a e
+--R        log(-----------)
+--R              d x + c
+--R   (1)  ----------------
+--R             b x + a
+--R                                                    Type: Expression(Integer)
+--E 3019
+
+--S 3020 of 5341
+--r0:=-log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))/b+_
+--  polylog(2,b*(c+d*x)/(d*(a+b*x)))/b
+--E 3020
+
+--S 3021 of 5341
+--a0:=integrate(t0,x)
+--E 3021
+
+--S 3022 of 5341
+--m0:=a0-r0
+--E 3022
+
+--S 3023 of 5341
+--d0:=D(m0,x)
+--E 3023
+
+)clear all
+
+--S 3024 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))/(a+b*x)^2
+--R 
+--R
+--R             b e x + a e
+--R         log(-----------)
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 3024
+
+--S 3025 of 5341
+r0:=(-1)/(b*(a+b*x))-(c+d*x)*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)*(a+b*x))
+--R 
+--R
+--R                         b e x + a e
+--R        (b d x + b c)log(-----------) - a d + b c
+--R                           d x + c
+--R   (2)  -----------------------------------------
+--R                  2     3       2         2
+--R              (a b d - b c)x + a b d - a b c
+--R                                                    Type: Expression(Integer)
+--E 3025
+
+--S 3026 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         b e x + a e
+--R        (b d x + b c)log(-----------) - a d + b c
+--R                           d x + c
+--R   (3)  -----------------------------------------
+--R                  2     3       2         2
+--R              (a b d - b c)x + a b d - a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3026
+
+--S 3027 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 3027
+
+--S 3028 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3028
+
+)clear all
+
+--S 3029 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))/(a+b*x)^3
+--R 
+--R
+--R                  b e x + a e
+--R              log(-----------)
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        b x  + 3a b x  + 3a b x + a
+--R                                                    Type: Expression(Integer)
+--E 3029
+
+--S 3030 of 5341
+r0:=(-1/4)/(b*(a+b*x)^2)+1/2*d/(b*(b*c-a*d)*(a+b*x))+1/2*d^2*log(a+b*x)/_
+   (b*(b*c-a*d)^2)-1/2*log(e*(a+b*x)/(c+d*x))/(b*(a+b*x)^2)-1/2*d^2*_
+   log(c+d*x)/(b*(b*c-a*d)^2)
+--R 
+--R
+--R   (2)
+--R            2 2 2         2      2 2
+--R       (- 2b d x  - 4a b d x - 2a d )log(d x + c)
+--R     + 
+--R          2 2 2         2      2 2
+--R       (2b d x  + 4a b d x + 2a d )log(b x + a)
+--R     + 
+--R            2 2                2 2     b e x + a e             2     2
+--R       (- 2a d  + 4a b c d - 2b c )log(-----------) + (- 2a b d  + 2b c d)x
+--R                                         d x + c
+--R     + 
+--R           2 2               2 2
+--R       - 3a d  + 4a b c d - b c
+--R  /
+--R          2 3 2       4        5 2  2      3 2 2      2 3          4 2
+--R       (4a b d  - 8a b c d + 4b c )x  + (8a b d  - 16a b c d + 8a b c )x
+--R     + 
+--R         4   2     3 2        2 3 2
+--R       4a b d  - 8a b c d + 4a b c
+--R                                                    Type: Expression(Integer)
+--E 3030
+
+--S 3031 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2 2         2                 2 2     b e x + a e
+--R       (2b d x  + 4a b d x + 4a b c d - 2b c )log(-----------)
+--R                                                    d x + c
+--R     + 
+--R                2     2          2 2               2 2
+--R       (- 2a b d  + 2b c d)x - 3a d  + 4a b c d - b c
+--R  /
+--R          2 3 2       4        5 2  2      3 2 2      2 3          4 2
+--R       (4a b d  - 8a b c d + 4b c )x  + (8a b d  - 16a b c d + 8a b c )x
+--R     + 
+--R         4   2     3 2        2 3 2
+--R       4a b d  - 8a b c d + 4a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3031
+
+--S 3032 of 5341
+m0:=a0-r0
+--R 
+--R
+--R         2                2                2    b e x + a e
+--R        d log(d x + c) - d log(b x + a) + d log(-----------)
+--R                                                  d x + c
+--R   (4)  ----------------------------------------------------
+--R                       2   2       2        3 2
+--R                     2a b d  - 4a b c d + 2b c
+--R                                                    Type: Expression(Integer)
+--E 3032
+
+--S 3033 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3033
+
+)clear all
+
+--S 3034 of 5341
+t0:=(a+b*x)^3*log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R          3 3       2 2     2       3     b e x + a e 2
+--R   (1)  (b x  + 3a b x  + 3a b x + a )log(-----------)
+--R                                            d x + c
+--R                                                    Type: Expression(Integer)
+--E 3034
+
+--S 3035 of 5341
+--r0:=-5/12*(b*c-a*d)^3*x/d^3+1/12*(b*c-a*d)^2*(a+b*x)^2/(b*d^2)-_
+--  1/2*(b*c-a*d)^3*(a+b*x)*log(e*(a+b*x)/(c+d*x))/(b*d^3)+1/4*(b*c-a*d)^2*_
+--  (a+b*x)^2*log(e*(a+b*x)/(c+d*x))/(b*d^2)-1/6*(b*c-a*d)*(a+b*x)^3*_
+--  log(e*(a+b*x)/(c+d*x))/(b*d)-1/2*(b*c-a*d)^4*log((b*c-a*d)/(b*_
+--  (c+d*x)))*log(e*(a+b*x)/(c+d*x))/(b*d^4)+1/4*(a+b*x)^4*log(e*_
+--  (a+b*x)/(c+d*x))^2/b+11/12*(b*c-a*d)^4*log(c+d*x)/(b*d^4)-_
+--  1/2*(b*c-a*d)^4*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d^4)
+--E 3035
+
+--S 3036 of 5341
+--a0:=integrate(t0,x)
+--E 3036
+
+--S 3037 of 5341
+--m0:=a0-r0
+--E 3037
+
+--S 3038 of 5341
+--d0:=D(m0,x)
+--E 3038
+
+)clear all
+
+--S 3039 of 5341
+t0:=(a+b*x)^2*log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R          2 2             2     b e x + a e 2
+--R   (1)  (b x  + 2a b x + a )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 3039
+
+--S 3040 of 5341
+--r0:=1/3*(b*c-a*d)^2*x/d^2+2/3*(b*c-a*d)^2*(a+b*x)*log(e*(a+b*x)/_
+--  (c+d*x))/(b*d^2)-1/3*(b*c-a*d)*(a+b*x)^2*log(e*(a+b*x)/(c+d*x))/_
+--  (b*d)+2/3*(b*c-a*d)^3*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/_
+--  (c+d*x))/(b*d^3)+1/3*(a+b*x)^3*log(e*(a+b*x)/(c+d*x))^2/b-_
+--  (b*c-a*d)^3*log(c+d*x)/(b*d^3)+2/3*(b*c-a*d)^3*_
+--  polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d^3)
+--E 3040
+
+--S 3041 of 5341
+--a0:=integrate(t0,x)
+--E 3041
+
+--S 3042 of 5341
+--m0:=a0-r0
+--E 3042
+
+--S 3043 of 5341
+--d0:=D(m0,x)
+--E 3043
+
+)clear all
+
+--S 3044 of 5341
+t0:=(a+b*x)*log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R                     b e x + a e 2
+--R   (1)  (b x + a)log(-----------)
+--R                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 3044
+
+--S 3045 of 5341
+--r0:=-(b*c-a*d)*(a+b*x)*log(e*(a+b*x)/(c+d*x))/(b*d)-(b*c-a*d)^2*_
+--  log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/(b*d^2)+_
+--  1/2*(a+b*x)^2*log(e*(a+b*x)/(c+d*x))^2/b+(b*c-a*d)^2*log(c+d*x)/_
+--  (b*d^2)-(b*c-a*d)^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d^2)
+--E 3045
+
+--S 3046 of 5341
+--a0:=integrate(t0,x)
+--E 3046
+
+--S 3047 of 5341
+--m0:=a0-r0
+--E 3047
+
+--S 3048 of 5341
+--d0:=D(m0,x)
+--E 3048
+
+)clear all
+
+--S 3049 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R            b e x + a e 2
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 3049
+
+--S 3050 of 5341
+--r0:=2*(b*c-a*d)*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/(b*d)+_
+--  (a+b*x)*log(e*(a+b*x)/(c+d*x))^2/b+2*(b*c-a*d)*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(b*d)
+--E 3050
+
+--S 3051 of 5341
+--a0:=integrate(t0,x)
+--E 3051
+
+--S 3052 of 5341
+--m0:=a0-r0
+--E 3052
+
+--S 3053 of 5341
+--d0:=D(m0,x)
+--E 3053
+
+)clear all
+
+--S 3054 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2/(a+b*x)
+--R 
+--R
+--R            b e x + a e 2
+--R        log(-----------)
+--R              d x + c
+--R   (1)  -----------------
+--R             b x + a
+--R                                                    Type: Expression(Integer)
+--E 3054
+
+--S 3055 of 5341
+--r0:=-log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))^2/b+_
+--  2*log(e*(a+b*x)/(c+d*x))*polylog(2,b*(c+d*x)/(d*(a+b*x)))/b+_
+--  2*polylog(3,b*(c+d*x)/(d*(a+b*x)))/b
+--E 3055
+
+--S 3056 of 5341
+--a0:=integrate(t0,x)
+--E 3056
+
+--S 3057 of 5341
+--m0:=a0-r0
+--E 3057
+
+--S 3058 of 5341
+--d0:=D(m0,x)
+--E 3058
+
+)clear all
+
+--S 3059 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2/(a+b*x)^2
+--R 
+--R
+--R             b e x + a e 2
+--R         log(-----------)
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 3059
+
+--S 3060 of 5341
+r0:=(-2)/(b*(a+b*x))-2*(c+d*x)*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)*(a+b*x))-_
+   (c+d*x)*log(e*(a+b*x)/(c+d*x))^2/((b*c-a*d)*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                        b e x + a e 2                      b e x + a e
+--R       (b d x + b c)log(-----------)  + (2b d x + 2b c)log(-----------) - 2a d
+--R                          d x + c                            d x + c
+--R     + 
+--R       2b c
+--R  /
+--R         2     3       2         2
+--R     (a b d - b c)x + a b d - a b c
+--R                                                    Type: Expression(Integer)
+--E 3060
+
+--S 3061 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        b e x + a e 2                      b e x + a e
+--R       (b d x + b c)log(-----------)  + (2b d x + 2b c)log(-----------) - 2a d
+--R                          d x + c                            d x + c
+--R     + 
+--R       2b c
+--R  /
+--R         2     3       2         2
+--R     (a b d - b c)x + a b d - a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3061
+
+--S 3062 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 3062
+
+--S 3063 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3063
+
+)clear all
+
+--S 3064 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2/(a+b*x)^3
+--R 
+--R
+--R                  b e x + a e 2
+--R              log(-----------)
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        b x  + 3a b x  + 3a b x + a
+--R                                                    Type: Expression(Integer)
+--E 3064
+
+--S 3065 of 5341
+r0:=2*d/(b*(b*c-a*d)*(a+b*x))-1/4*b*(c+d*x)^2/((b*c-a*d)^2*(a+b*x)^2)+2*d*_
+   (c+d*x)*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)^2*(a+b*x))-1/2*b*(c+d*x)^2*_
+   log(e*(a+b*x)/(c+d*x))/((b*c-a*d)^2*(a+b*x)^2)+d*(c+d*x)*log(e*(a+b*x)/_
+   (c+d*x))^2/((b*c-a*d)^2*(a+b*x))-1/2*b*(c+d*x)^2*log(e*(a+b*x)/(c+_
+   d*x))^2/((b*c-a*d)^2*(a+b*x)^2)
+--R 
+--R
+--R   (2)
+--R          2 2 2         2                 2 2     b e x + a e 2
+--R       (2b d x  + 4a b d x + 4a b c d - 2b c )log(-----------)
+--R                                                    d x + c
+--R     + 
+--R          2 2 2          2     2                     2 2     b e x + a e
+--R       (6b d x  + (8a b d  + 4b c d)x + 8a b c d - 2b c )log(-----------)
+--R                                                               d x + c
+--R     + 
+--R          2 2 2            2     2          2 2               2 2
+--R       - b d x  + (- 8a b d  + 6b c d)x - 8a d  + 8a b c d - b c
+--R  /
+--R          2 3 2       4        5 2  2      3 2 2      2 3          4 2
+--R       (4a b d  - 8a b c d + 4b c )x  + (8a b d  - 16a b c d + 8a b c )x
+--R     + 
+--R         4   2     3 2        2 3 2
+--R       4a b d  - 8a b c d + 4a b c
+--R                                                    Type: Expression(Integer)
+--E 3065
+
+--S 3066 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2 2         2                 2 2     b e x + a e 2
+--R       (2b d x  + 4a b d x + 4a b c d - 2b c )log(-----------)
+--R                                                    d x + c
+--R     + 
+--R          2 2 2          2     2                     2 2     b e x + a e
+--R       (6b d x  + (8a b d  + 4b c d)x + 8a b c d - 2b c )log(-----------)
+--R                                                               d x + c
+--R     + 
+--R                2     2          2 2               2 2
+--R       (- 6a b d  + 6b c d)x - 7a d  + 8a b c d - b c
+--R  /
+--R          2 3 2       4        5 2  2      3 2 2      2 3          4 2
+--R       (4a b d  - 8a b c d + 4b c )x  + (8a b d  - 16a b c d + 8a b c )x
+--R     + 
+--R         4   2     3 2        2 3 2
+--R       4a b d  - 8a b c d + 4a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3066
+
+--S 3067 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                     2
+--R                    d
+--R   (4)  --------------------------
+--R          2   2       2        3 2
+--R        4a b d  - 8a b c d + 4b c
+--R                                                    Type: Expression(Integer)
+--E 3067
+
+--S 3068 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3068
+
+)clear all
+
+--S 3069 of 5341
+t0:=(a+b*x)^2*log(e*(a+b*x)/(c+d*x))^3
+--R 
+--R
+--R          2 2             2     b e x + a e 3
+--R   (1)  (b x  + 2a b x + a )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 3069
+
+--S 3070 of 5341
+--r0:=(b*c-a*d)^2*(a+b*x)*log(e*(a+b*x)/(c+d*x))/(b*d^2)+3*(b*c-a*d)^3*_
+--  log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/(b*d^3)+(b*c-a*d)^2*_
+--  (a+b*x)*log(e*(a+b*x)/(c+d*x))^2/(b*d^2)-1/2*(b*c-a*d)*(a+b*x)^2*_
+--  log(e*(a+b*x)/(c+d*x))^2/(b*d)+(b*c-a*d)^3*log((b*c-a*d)/(b*(c+d*x)))*_
+--  log(e*(a+b*x)/(c+d*x))^2/(b*d^3)+1/3*(a+b*x)^3*log(e*(a+b*x)/_
+--  (c+d*x))^3/b-(b*c-a*d)^3*log(c+d*x)/(b*d^3)+3*(b*c-a*d)^3*_
+--  polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d^3)+2*(b*c-a*d)^3*log(e*_
+--  (a+b*x)/(c+d*x))*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d^3)-_
+--  2*(b*c-a*d)^3*polylog(3,d*(a+b*x)/(b*(c+d*x)))/(b*d^3)
+--E 3070
+
+--S 3071 of 5341
+--a0:=integrate(t0,x)
+--E 3071
+
+--S 3072 of 5341
+--m0:=a0-r0
+--E 3072
+
+--S 3073 of 5341
+--d0:=D(m0,x)
+--E 3073
+
+)clear all
+
+--S 3074 of 5341
+t0:=(a+b*x)*log(e*(a+b*x)/(c+d*x))^3
+--R 
+--R
+--R                     b e x + a e 3
+--R   (1)  (b x + a)log(-----------)
+--R                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 3074
+
+--S 3075 of 5341
+--r0:=-3*(b*c-a*d)^2*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/_
+--  (b*d^2)-3/2*(b*c-a*d)*(a+b*x)*log(e*(a+b*x)/(c+d*x))^2/(b*d)-_
+--  3/2*(b*c-a*d)^2*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^2/_
+--  (b*d^2)+1/2*(a+b*x)^2*log(e*(a+b*x)/(c+d*x))^3/b-3*(b*c-a*d)^2*_
+--  polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d^2)-3*(b*c-a*d)^2*_
+--  log(e*(a+b*x)/(c+d*x))*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d^2)+_
+--  3*(b*c-a*d)^2*polylog(3,d*(a+b*x)/(b*(c+d*x)))/(b*d^2)
+--E 3075
+
+--S 3076 of 5341
+--a0:=integrate(t0,x)
+--E 3076
+
+--S 3077 of 5341
+--m0:=a0-r0
+--E 3077
+
+--S 3078 of 5341
+--d0:=D(m0,x)
+--E 3078
+
+)clear all
+
+--S 3079 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3
+--R 
+--R
+--R            b e x + a e 3
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 3079
+
+--S 3080 of 5341
+--r0:=3*(b*c-a*d)*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^2/(b*d)+_
+--  (a+b*x)*log(e*(a+b*x)/(c+d*x))^3/b+6*(b*c-a*d)*log(e*(a+b*x)/(c+d*x))*_
+--  polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d)-6*(b*c-a*d)*_
+--  polylog(3,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 3080
+
+--S 3081 of 5341
+--a0:=integrate(t0,x)
+--E 3081
+
+--S 3082 of 5341
+--m0:=a0-r0
+--E 3082
+
+--S 3083 of 5341
+--d0:=D(m0,x)
+--E 3083
+
+)clear all
+
+--S 3084 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3/(a+b*x)
+--R 
+--R
+--R            b e x + a e 3
+--R        log(-----------)
+--R              d x + c
+--R   (1)  -----------------
+--R             b x + a
+--R                                                    Type: Expression(Integer)
+--E 3084
+
+--S 3085 of 5341
+--r0:=-log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))^3/b+_
+--  3*log(e*(a+b*x)/(c+d*x))^2*polylog(2,b*(c+d*x)/(d*(a+b*x)))/b+_
+--  6*log(e*(a+b*x)/(c+d*x))*polylog(3,b*(c+d*x)/(d*(a+b*x)))/b+_
+--  6*polylog(4,b*(c+d*x)/(d*(a+b*x)))/b
+--E 3085
+
+--S 3086 of 5341
+--a0:=integrate(t0,x)
+--E 3086
+
+--S 3087 of 5341
+--m0:=a0-r0
+--E 3087
+
+--S 3088 of 5341
+--d0:=D(m0,x)
+--E 3088
+
+)clear all
+
+--S 3089 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3/(a+b*x)^2
+--R 
+--R
+--R             b e x + a e 3
+--R         log(-----------)
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 3089
+
+--S 3090 of 5341
+r0:=(-6)/(b*(a+b*x))-6*(c+d*x)*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)*(a+b*x))-_
+   3*(c+d*x)*log(e*(a+b*x)/(c+d*x))^2/((b*c-a*d)*(a+b*x))-(c+d*x)*_
+   log(e*(a+b*x)/(c+d*x))^3/((b*c-a*d)*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                        b e x + a e 3                      b e x + a e 2
+--R       (b d x + b c)log(-----------)  + (3b d x + 3b c)log(-----------)
+--R                          d x + c                            d x + c
+--R     + 
+--R                          b e x + a e
+--R       (6b d x + 6b c)log(-----------) - 6a d + 6b c
+--R                            d x + c
+--R  /
+--R         2     3       2         2
+--R     (a b d - b c)x + a b d - a b c
+--R                                                    Type: Expression(Integer)
+--E 3090
+
+--S 3091 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                        b e x + a e 3                      b e x + a e 2
+--R       (b d x + b c)log(-----------)  + (3b d x + 3b c)log(-----------)
+--R                          d x + c                            d x + c
+--R     + 
+--R                          b e x + a e
+--R       (6b d x + 6b c)log(-----------) - 6a d + 6b c
+--R                            d x + c
+--R  /
+--R         2     3       2         2
+--R     (a b d - b c)x + a b d - a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3091
+
+--S 3092 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 3092
+
+--S 3093 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3093
+
+)clear all
+
+--S 3094 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3/(a+b*x)^3
+--R 
+--R
+--R                  b e x + a e 3
+--R              log(-----------)
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        b x  + 3a b x  + 3a b x + a
+--R                                                    Type: Expression(Integer)
+--E 3094
+
+--S 3095 of 5341
+r0:=6*d/(b*(b*c-a*d)*(a+b*x))-3/8*b*(c+d*x)^2/((b*c-a*d)^2*(a+b*x)^2)+_
+   6*d*(c+d*x)*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)^2*(a+b*x))-3/4*b*(c+_
+   d*x)^2*log(e*(a+b*x)/(c+d*x))/((b*c-a*d)^2*(a+b*x)^2)+3*d*(c+d*x)*_
+   log(e*(a+b*x)/(c+d*x))^2/((b*c-a*d)^2*(a+b*x))-3/4*b*(c+d*x)^2*_
+   log(e*(a+b*x)/(c+d*x))^2/((b*c-a*d)^2*(a+b*x)^2)+d*(c+d*x)*_
+   log(e*(a+b*x)/(c+d*x))^3/((b*c-a*d)^2*(a+b*x))-1/2*b*(c+d*x)^2*_
+   log(e*(a+b*x)/(c+d*x))^3/((b*c-a*d)^2*(a+b*x)^2)
+--R 
+--R
+--R   (2)
+--R          2 2 2         2                 2 2     b e x + a e 3
+--R       (4b d x  + 8a b d x + 8a b c d - 4b c )log(-----------)
+--R                                                    d x + c
+--R     + 
+--R           2 2 2           2      2                      2 2     b e x + a e 2
+--R       (18b d x  + (24a b d  + 12b c d)x + 24a b c d - 6b c )log(-----------)
+--R                                                                   d x + c
+--R     + 
+--R           2 2 2           2      2                      2 2     b e x + a e
+--R       (42b d x  + (48a b d  + 36b c d)x + 48a b c d - 6b c )log(-----------)
+--R                                                                   d x + c
+--R     + 
+--R           2 2 2             2      2           2 2                 2 2
+--R       - 3b d x  + (- 48a b d  + 42b c d)x - 48a d  + 48a b c d - 3b c
+--R  /
+--R          2 3 2        4        5 2  2       3 2 2      2 3           4 2
+--R       (8a b d  - 16a b c d + 8b c )x  + (16a b d  - 32a b c d + 16a b c )x
+--R     + 
+--R         4   2      3 2        2 3 2
+--R       8a b d  - 16a b c d + 8a b c
+--R                                                    Type: Expression(Integer)
+--E 3095
+
+--S 3096 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2 2         2                 2 2     b e x + a e 3
+--R       (4b d x  + 8a b d x + 8a b c d - 4b c )log(-----------)
+--R                                                    d x + c
+--R     + 
+--R           2 2 2           2      2                      2 2     b e x + a e 2
+--R       (18b d x  + (24a b d  + 12b c d)x + 24a b c d - 6b c )log(-----------)
+--R                                                                   d x + c
+--R     + 
+--R           2 2 2           2      2                      2 2     b e x + a e
+--R       (42b d x  + (48a b d  + 36b c d)x + 48a b c d - 6b c )log(-----------)
+--R                                                                   d x + c
+--R     + 
+--R                 2      2           2 2                 2 2
+--R       (- 42a b d  + 42b c d)x - 45a d  + 48a b c d - 3b c
+--R  /
+--R          2 3 2        4        5 2  2       3 2 2      2 3           4 2
+--R       (8a b d  - 16a b c d + 8b c )x  + (16a b d  - 32a b c d + 16a b c )x
+--R     + 
+--R         4   2      3 2        2 3 2
+--R       8a b d  - 16a b c d + 8a b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3096
+
+--S 3097 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                      2
+--R                    3d
+--R   (4)  ---------------------------
+--R          2   2        2        3 2
+--R        8a b d  - 16a b c d + 8b c
+--R                                                    Type: Expression(Integer)
+--E 3097
+
+--S 3098 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3098
+
+)clear all
+
+--S 3099 of 5341
+t0:=(f+g*x)^3*log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R          3 3       2 2     2       3     b e x + a e
+--R   (1)  (g x  + 3f g x  + 3f g x + f )log(-----------)
+--R                                            d x + c
+--R                                                    Type: Expression(Integer)
+--E 3099
+
+--S 3100 of 5341
+r0:=-1/4*(b*c-a*d)*g*(a^2*d^2*g^2-a*b*d*g*(4*d*f-c*g)+b^2*(6*d^2*f^2-_
+   4*c*d*f*g+c^2*g^2))*x/(b^3*d^3)-1/8*(b*c-a*d)*g^2*(4*b*d*f-b*c*g-_
+   a*d*g)*x^2/(b^2*d^2)-1/12*(b*c-a*d)*g^3*x^3/(b*d)-1/4*(b*f-a*g)^4*_
+   log(a+b*x)/(b^4*g)+1/4*(f+g*x)^4*log(e*(a+b*x)/(c+d*x))/g+_
+   1/4*(d*f-c*g)^4*log(c+d*x)/(d^4*g)
+--R 
+--R
+--R   (2)
+--R            4 4 4      4 3     3      4 2 2 2 2      4   3 3      4 4 4
+--R         (6b c g  - 24b c d f g  + 36b c d f g  - 24b c d f g + 6b d f )
+--R      *
+--R         log(d x + c)
+--R     + 
+--R              4 4 4      3   4   3      2 2 4 2 2        3 4 3      4 4 4
+--R         (- 6a d g  + 24a b d f g  - 36a b d f g  + 24a b d f g - 6b d f )
+--R      *
+--R         log(b x + a)
+--R     + 
+--R            4 4 4 4      4 4   3 3      4 4 2 2 2      4 4 3        4 4 4
+--R         (6b d g x  + 24b d f g x  + 36b d f g x  + 24b d f g x + 6b d f )
+--R      *
+--R             b e x + a e
+--R         log(-----------)
+--R               d x + c
+--R     + 
+--R            3 4     4   3  4 3
+--R       (2a b d  - 2b c d )g x
+--R     + 
+--R             2 2 4     4 2 2  4         3 4      4   3    3  2
+--R       ((- 3a b d  + 3b c d )g  + (12a b d  - 12b c d )f g )x
+--R     + 
+--R              3   4     4 3   4         2 2 4      4 2 2    3
+--R           (6a b d  - 6b c d)g  + (- 24a b d  + 24b c d )f g
+--R         + 
+--R                 3 4      4   3  2 2
+--R           (36a b d  - 36b c d )f g
+--R      *
+--R         x
+--R  /
+--R        4 4
+--R     24b d g
+--R                                                    Type: Expression(Integer)
+--E 3100
+
+--S 3101 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          4 4 3      4 3     2      4 2 2 2       4   3 3
+--R       (6b c g  - 24b c d f g  + 36b c d f g - 24b c d f )log(d x + c)
+--R     + 
+--R            4 4 3      3   4   2      2 2 4 2         3 4 3
+--R       (- 6a d g  + 24a b d f g  - 36a b d f g + 24a b d f )log(b x + a)
+--R     + 
+--R          4 4 3 4      4 4   2 3      4 4 2   2      4 4 3      b e x + a e
+--R       (6b d g x  + 24b d f g x  + 36b d f g x  + 24b d f x)log(-----------)
+--R                                                                  d x + c
+--R     + 
+--R            3 4     4   3  3 3
+--R       (2a b d  - 2b c d )g x
+--R     + 
+--R             2 2 4     4 2 2  3         3 4      4   3    2  2
+--R       ((- 3a b d  + 3b c d )g  + (12a b d  - 12b c d )f g )x
+--R     + 
+--R              3   4     4 3   3         2 2 4      4 2 2    2
+--R           (6a b d  - 6b c d)g  + (- 24a b d  + 24b c d )f g
+--R         + 
+--R                 3 4      4   3  2
+--R           (36a b d  - 36b c d )f g
+--R      *
+--R         x
+--R  /
+--R        4 4
+--R     24b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3101
+
+--S 3102 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           4                4                4    b e x + a e
+--R        - f log(d x + c) + f log(b x + a) - f log(-----------)
+--R                                                    d x + c
+--R   (4)  ------------------------------------------------------
+--R                                  4g
+--R                                                    Type: Expression(Integer)
+--E 3102
+
+--S 3103 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3103
+
+)clear all
+
+--S 3104 of 5341
+t0:=(f+g*x)^2*log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R          2 2             2     b e x + a e
+--R   (1)  (g x  + 2f g x + f )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 3104
+
+--S 3105 of 5341
+r0:=-1/3*(b*c-a*d)*g*(3*b*d*f-b*c*g-a*d*g)*x/(b^2*d^2)-1/6*(b*c-a*d)*_
+   g^2*x^2/(b*d)-1/3*(b*f-a*g)^3*log(a+b*x)/(b^3*g)+1/3*(f+g*x)^3*_
+   log(e*(a+b*x)/(c+d*x))/g+1/3*(d*f-c*g)^3*log(c+d*x)/(d^3*g)
+--R 
+--R
+--R   (2)
+--R            3 3 3     3 2     2     3   2 2      3 3 3
+--R       (- 2b c g  + 6b c d f g  - 6b c d f g + 2b d f )log(d x + c)
+--R     + 
+--R          3 3 3     2   3   2       2 3 2      3 3 3
+--R       (2a d g  - 6a b d f g  + 6a b d f g - 2b d f )log(b x + a)
+--R     + 
+--R          3 3 3 3     3 3   2 2     3 3 2        3 3 3     b e x + a e
+--R       (2b d g x  + 6b d f g x  + 6b d f g x + 2b d f )log(-----------)
+--R                                                             d x + c
+--R     + 
+--R         2 3    3   2  3 2         2   3     3 2   3        2 3     3   2    2
+--R     (a b d  - b c d )g x  + ((- 2a b d  + 2b c d)g  + (6a b d  - 6b c d )f g )x
+--R  /
+--R       3 3
+--R     6b d g
+--R                                                    Type: Expression(Integer)
+--E 3105
+
+--S 3106 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 3 2     3 2          3   2 2
+--R       (- 2b c g  + 6b c d f g - 6b c d f )log(d x + c)
+--R     + 
+--R          3 3 2     2   3          2 3 2
+--R       (2a d g  - 6a b d f g + 6a b d f )log(b x + a)
+--R     + 
+--R          3 3 2 3     3 3     2     3 3 2      b e x + a e
+--R       (2b d g x  + 6b d f g x  + 6b d f x)log(-----------)
+--R                                                 d x + c
+--R     + 
+--R         2 3    3   2  2 2         2   3     3 2   2        2 3     3   2
+--R     (a b d  - b c d )g x  + ((- 2a b d  + 2b c d)g  + (6a b d  - 6b c d )f g)x
+--R  /
+--R       3 3
+--R     6b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3106
+
+--S 3107 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           3                3                3    b e x + a e
+--R        - f log(d x + c) + f log(b x + a) - f log(-----------)
+--R                                                    d x + c
+--R   (4)  ------------------------------------------------------
+--R                                  3g
+--R                                                    Type: Expression(Integer)
+--E 3107
+
+--S 3108 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3108
+
+)clear all
+
+--S 3109 of 5341
+t0:=(f+g*x)*log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R                     b e x + a e
+--R   (1)  (g x + f)log(-----------)
+--R                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 3109
+
+--S 3110 of 5341
+r0:=-1/2*(b*c-a*d)*g*x/(b*d)-1/2*(b*f-a*g)^2*log(a+b*x)/(b^2*g)+_
+   1/2*(f+g*x)^2*log(e*(a+b*x)/(c+d*x))/g+1/2*(d*f-c*g)^2*log(c+d*x)/(d^2*g)
+--R 
+--R
+--R   (2)
+--R         2 2 2     2           2 2 2
+--R       (b c g  - 2b c d f g + b d f )log(d x + c)
+--R     + 
+--R           2 2 2         2       2 2 2
+--R       (- a d g  + 2a b d f g - b d f )log(b x + a)
+--R     + 
+--R         2 2 2 2     2 2         2 2 2     b e x + a e          2    2     2
+--R       (b d g x  + 2b d f g x + b d f )log(-----------) + (a b d  - b c d)g x
+--R                                             d x + c
+--R  /
+--R       2 2
+--R     2b d g
+--R                                                    Type: Expression(Integer)
+--E 3110
+
+--S 3111 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2 2      2                         2 2          2
+--R       (b c g - 2b c d f)log(d x + c) + (- a d g + 2a b d f)log(b x + a)
+--R     + 
+--R         2 2   2     2 2        b e x + a e          2    2
+--R       (b d g x  + 2b d f x)log(-----------) + (a b d  - b c d)g x
+--R                                  d x + c
+--R  /
+--R       2 2
+--R     2b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3111
+
+--S 3112 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           2                2                2    b e x + a e
+--R        - f log(d x + c) + f log(b x + a) - f log(-----------)
+--R                                                    d x + c
+--R   (4)  ------------------------------------------------------
+--R                                  2g
+--R                                                    Type: Expression(Integer)
+--E 3112
+
+--S 3113 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3113
+
+)clear all
+
+--S 3114 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R            b e x + a e
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 3114
+
+--S 3115 of 5341
+r0:=(a+b*x)*log(e*(a+b*x)/(c+d*x))/b-(b*c-a*d)*log(c+d*x)/(b*d)
+--R 
+--R
+--R                                                   b e x + a e
+--R        (a d - b c)log(d x + c) + (b d x + a d)log(-----------)
+--R                                                     d x + c
+--R   (2)  -------------------------------------------------------
+--R                                  b d
+--R                                                    Type: Expression(Integer)
+--E 3115
+
+--S 3116 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                          b e x + a e
+--R        - b c log(d x + c) + a d log(b x + a) + b d x log(-----------)
+--R                                                            d x + c
+--R   (3)  --------------------------------------------------------------
+--R                                      b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3116
+
+--S 3117 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                                                  b e x + a e
+--R        - a log(d x + c) + a log(b x + a) - a log(-----------)
+--R                                                    d x + c
+--R   (4)  ------------------------------------------------------
+--R                                   b
+--R                                                    Type: Expression(Integer)
+--E 3117
+
+--S 3118 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3118
+
+)clear all
+
+--S 3119 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))/(f+g*x)
+--R 
+--R
+--R            b e x + a e
+--R        log(-----------)
+--R              d x + c
+--R   (1)  ----------------
+--R             g x + f
+--R                                                    Type: Expression(Integer)
+--E 3119
+
+--S 3120 of 5341
+--r0:=-log(-g*(a+b*x)/(b*f-a*g))*log(f+g*x)/g+log(e*(a+b*x)/(c+d*x))*_
+--  log(f+g*x)/g+log(-g*(c+d*x)/(d*f-c*g))*log(f+g*x)/g-_
+--  polylog(2,b*(f+g*x)/(b*f-a*g))/g+polylog(2,d*(f+g*x)/(d*f-c*g))/g
+--E 3120
+
+--S 3121 of 5341
+--a0:=integrate(t0,x)
+--E 3121
+
+--S 3122 of 5341
+--m0:=a0-r0
+--E 3122
+
+--S 3123 of 5341
+--d0:=D(m0,x)
+--E 3123
+
+)clear all
+
+--S 3124 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))/(f+g*x)^2
+--R 
+--R
+--R             b e x + a e
+--R         log(-----------)
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        g x  + 2f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3124
+
+--S 3125 of 5341
+r0:=(a+b*x)*log(e*(a+b*x)/(c+d*x))/((b*f-a*g)*(f+g*x))-(b*c-a*d)*_
+   log(c+d*x)/((b*f-a*g)*(d*f-c*g))+(b*c-a*d)*log(f+g*x)/((b*f-a*g)*(d*f-c*g))
+--R 
+--R
+--R   (2)
+--R       ((- a d + b c)g x + (- a d + b c)f)log(g x + f)
+--R     + 
+--R       ((a d - b c)g x + (a d - b c)f)log(d x + c)
+--R     + 
+--R                                               b e x + a e
+--R       ((- b c g + b d f)x - a c g + a d f)log(-----------)
+--R                                                 d x + c
+--R  /
+--R             3                   2        2             2                 2
+--R       (a c g  + (- a d - b c)f g  + b d f g)x + a c f g  + (- a d - b c)f g
+--R     + 
+--R            3
+--R       b d f
+--R                                                    Type: Expression(Integer)
+--E 3125
+
+--S 3126 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      2
+--R       ((- a d + b c)g x + (- a d + b c)f g)log(g x + f)
+--R     + 
+--R              2                              2
+--R       ((a d g  - b d f g)x + a d f g - b d f )log(d x + c)
+--R     + 
+--R                2                              2
+--R       ((- b c g  + b d f g)x - b c f g + b d f )log(b x + a)
+--R     + 
+--R               2                         2     b e x + a e
+--R       (- a c g  + (a d + b c)f g - b d f )log(-----------)
+--R                                                 d x + c
+--R  /
+--R             4                   3        2 2            3                 2 2
+--R       (a c g  + (- a d - b c)f g  + b d f g )x + a c f g  + (- a d - b c)f g
+--R     + 
+--R            3
+--R       b d f g
+--R                                         Type: Union(Expression(Integer),...)
+--E 3126
+
+--S 3127 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                                                b e x + a e
+--R        b log(d x + c) - b log(b x + a) + b log(-----------)
+--R                                                  d x + c
+--R   (4)  ----------------------------------------------------
+--R                               2
+--R                            a g  - b f g
+--R                                                    Type: Expression(Integer)
+--E 3127
+
+--S 3128 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3128
+
+)clear all
+
+--S 3129 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))/(f+g*x)^3
+--R 
+--R
+--R                  b e x + a e
+--R              log(-----------)
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        g x  + 3f g x  + 3f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3129
+
+--S 3130 of 5341
+r0:=1/2*(-b*c+a*d)/((b*f-a*g)*(d*f-c*g)*(f+g*x))+1/2*b^2*log(a+b*x)/(g*_
+   (b*f-a*g)^2)-1/2*log(e*(a+b*x)/(c+d*x))/(g*(f+g*x)^2)-1/2*d^2*log(c+_
+   d*x)/(g*(d*f-c*g)^2)+1/2*(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*log(f+g*x)/_
+   ((b*f-a*g)^2*(d*f-c*g)^2)
+--R 
+--R
+--R   (2)
+--R              2 2    2 2  4            2     2       3  2
+--R           ((a d  - b c )g  + (- 2a b d  + 2b c d)f g )x
+--R         + 
+--R               2 2     2 2    3            2     2     2 2       2 2    2 2  2 2
+--R           ((2a d  - 2b c )f g  + (- 4a b d  + 4b c d)f g )x + (a d  - b c )f g
+--R         + 
+--R                    2     2     3
+--R           (- 2a b d  + 2b c d)f g
+--R      *
+--R         log(g x + f)
+--R     + 
+--R               2 2 4         2   3    2 2 2 2  2
+--R           (- a d g  + 2a b d f g  - b d f g )x
+--R         + 
+--R                2 2   3         2 2 2     2 2 3       2 2 2 2         2 3
+--R           (- 2a d f g  + 4a b d f g  - 2b d f g)x - a d f g  + 2a b d f g
+--R         + 
+--R              2 2 4
+--R           - b d f
+--R      *
+--R         log(d x + c)
+--R     + 
+--R             2 2 4     2       3    2 2 2 2  2
+--R           (b c g  - 2b c d f g  + b d f g )x
+--R         + 
+--R            2 2   3     2     2 2     2 2 3       2 2 2 2     2     3     2 2 4
+--R         (2b c f g  - 4b c d f g  + 2b d f g)x + b c f g  - 2b c d f g + b d f
+--R      *
+--R         log(b x + a)
+--R     + 
+--R              2 2 4      2            2    3       2 2               2 2  2 2
+--R           - a c g  + (2a c d + 2a b c )f g  + (- a d  - 4a b c d - b c )f g
+--R         + 
+--R                  2     2     3     2 2 4
+--R           (2a b d  + 2b c d)f g - b d f
+--R      *
+--R             b e x + a e
+--R         log(-----------)
+--R               d x + c
+--R     + 
+--R          2           2  4       2 2    2 2    3         2    2     2 2
+--R       ((a c d - a b c )g  + (- a d  + b c )f g  + (a b d  - b c d)f g )x
+--R     + 
+--R         2           2    3       2 2    2 2  2 2         2    2     3
+--R       (a c d - a b c )f g  + (- a d  + b c )f g  + (a b d  - b c d)f g
+--R  /
+--R             2 2 7        2            2    6      2 2                2 2  2 5
+--R           2a c g  + (- 4a c d - 4a b c )f g  + (2a d  + 8a b c d + 2b c )f g
+--R         + 
+--R                    2     2     3 4     2 2 4 3
+--R           (- 4a b d  - 4b c d)f g  + 2b d f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R             2 2   6        2            2  2 5
+--R           4a c f g  + (- 8a c d - 8a b c )f g
+--R         + 
+--R            2 2                 2 2  3 4            2     2     4 3     2 2 5 2
+--R         (4a d  + 16a b c d + 4b c )f g  + (- 8a b d  - 8b c d)f g  + 4b d f g
+--R      *
+--R         x
+--R     + 
+--R         2 2 2 5        2            2  3 4      2 2                2 2  4 3
+--R       2a c f g  + (- 4a c d - 4a b c )f g  + (2a d  + 8a b c d + 2b c )f g
+--R     + 
+--R                2     2     5 2     2 2 6
+--R       (- 4a b d  - 4b c d)f g  + 2b d f g
+--R                                                    Type: Expression(Integer)
+--E 3130
+
+--S 3131 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 2    2 2  4            2     2       3  2
+--R           ((a d  - b c )g  + (- 2a b d  + 2b c d)f g )x
+--R         + 
+--R               2 2     2 2    3            2     2     2 2       2 2    2 2  2 2
+--R           ((2a d  - 2b c )f g  + (- 4a b d  + 4b c d)f g )x + (a d  - b c )f g
+--R         + 
+--R                    2     2     3
+--R           (- 2a b d  + 2b c d)f g
+--R      *
+--R         log(g x + f)
+--R     + 
+--R               2 2 4         2   3    2 2 2 2  2
+--R           (- a d g  + 2a b d f g  - b d f g )x
+--R         + 
+--R                2 2   3         2 2 2     2 2 3       2 2 2 2         2 3
+--R           (- 2a d f g  + 4a b d f g  - 2b d f g)x - a d f g  + 2a b d f g
+--R         + 
+--R              2 2 4
+--R           - b d f
+--R      *
+--R         log(d x + c)
+--R     + 
+--R             2 2 4     2       3    2 2 2 2  2
+--R           (b c g  - 2b c d f g  + b d f g )x
+--R         + 
+--R            2 2   3     2     2 2     2 2 3       2 2 2 2     2     3     2 2 4
+--R         (2b c f g  - 4b c d f g  + 2b d f g)x + b c f g  - 2b c d f g + b d f
+--R      *
+--R         log(b x + a)
+--R     + 
+--R              2 2 4      2            2    3       2 2               2 2  2 2
+--R           - a c g  + (2a c d + 2a b c )f g  + (- a d  - 4a b c d - b c )f g
+--R         + 
+--R                  2     2     3     2 2 4
+--R           (2a b d  + 2b c d)f g - b d f
+--R      *
+--R             b e x + a e
+--R         log(-----------)
+--R               d x + c
+--R     + 
+--R          2           2  4       2 2    2 2    3         2    2     2 2
+--R       ((a c d - a b c )g  + (- a d  + b c )f g  + (a b d  - b c d)f g )x
+--R     + 
+--R         2           2    3       2 2    2 2  2 2         2    2     3
+--R       (a c d - a b c )f g  + (- a d  + b c )f g  + (a b d  - b c d)f g
+--R  /
+--R             2 2 7        2            2    6      2 2                2 2  2 5
+--R           2a c g  + (- 4a c d - 4a b c )f g  + (2a d  + 8a b c d + 2b c )f g
+--R         + 
+--R                    2     2     3 4     2 2 4 3
+--R           (- 4a b d  - 4b c d)f g  + 2b d f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R             2 2   6        2            2  2 5
+--R           4a c f g  + (- 8a c d - 8a b c )f g
+--R         + 
+--R            2 2                 2 2  3 4            2     2     4 3     2 2 5 2
+--R         (4a d  + 16a b c d + 4b c )f g  + (- 8a b d  - 8b c d)f g  + 4b d f g
+--R      *
+--R         x
+--R     + 
+--R         2 2 2 5        2            2  3 4      2 2                2 2  4 3
+--R       2a c f g  + (- 4a c d - 4a b c )f g  + (2a d  + 8a b c d + 2b c )f g
+--R     + 
+--R                2     2     5 2     2 2 6
+--R       (- 4a b d  - 4b c d)f g  + 2b d f g
+--R                                         Type: Union(Expression(Integer),...)
+--E 3131
+
+--S 3132 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 3132
+
+--S 3133 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3133
+
+)clear all
+
+--S 3134 of 5341
+t0:=(f+g*x)^3*log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R          3 3       2 2     2       3     b e x + a e 2
+--R   (1)  (g x  + 3f g x  + 3f g x + f )log(-----------)
+--R                                            d x + c
+--R                                                    Type: Expression(Integer)
+--E 3134
+
+--S 3135 of 5341
+--r0:=-1/6*(b*c-a*d)^2*(b*c+a*d)*g^3*x/(b^3*d^3)+1/4*(b*c-a*d)^2*g^2*_
+--  (4*b*d*f-b*c*g-a*d*g)*x/(b^3*d^3)+1/12*(b*c-a*d)^2*g^3*x^2/(b^2*d^2)-_
+--  1/6*a^3*(b*c-a*d)*g^3*log(a+b*x)/(b^4*d)+1/4*a^2*(b*c-a*d)*g^2*_
+--  (4*b*d*f-b*c*g-a*d*g)*log(a+b*x)/(b^4*d^2)-1/4*(b*c-a*d)*g^2*_
+--  (4*b*d*f-b*c*g-a*d*g)*x^2*log(e*(a+b*x)/(c+d*x))/(b^2*d^2)-_
+--  1/6*(b*c-a*d)*g^3*x^3*log(e*(a+b*x)/(c+d*x))/(b*d)-1/2*(b*c-a*d)*_
+--  g*(a^2*d^2*g^2-a*b*d*g*(4*d*f-c*g)+b^2*(6*d^2*f^2-4*c*d*f*g+c^2*g^2))*_
+--  (a+b*x)*log(e*(a+b*x)/(c+d*x))/(b^4*d^3)+1/2*(b*f-a*g)^4*_
+--  log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))/(b^4*g)-_
+--  1/2*(d*f-c*g)^4*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/_
+--  (d^4*g)+1/4*(f+g*x)^4*log(e*(a+b*x)/(c+d*x))^2/g+1/6*c^3*(b*c-a*d)*_
+--  g^3*log(c+d*x)/(b*d^4)-1/4*c^2*(b*c-a*d)*g^2*(4*b*d*f-b*c*g-a*d*g)*_
+--  log(c+d*x)/(b^2*d^4)+1/2*(b*c-a*d)^2*g*(a^2*d^2*g^2-a*b*d*g*_
+--  (4*d*f-c*g)+b^2*(6*d^2*f^2-4*c*d*f*g+c^2*g^2))*log(c+d*x)/(b^4*d^4)-_
+--  1/2*(d*f-c*g)^4*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(d^4*g)-_
+--  1/2*(b*f-a*g)^4*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^4*g)
+--E 3135
+
+--S 3136 of 5341
+--a0:=integrate(t0,x)
+--E 3136
+
+--S 3137 of 5341
+--m0:=a0-r0
+--E 3137
+
+--S 3138 of 5341
+--d0:=D(m0,x)
+--E 3138
+
+)clear all
+
+--S 3139 of 5341
+t0:=(f+g*x)^2*log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R          2 2             2     b e x + a e 2
+--R   (1)  (g x  + 2f g x + f )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 3139
+
+--S 3140 of 5341
+--r0:=1/3*(b*c-a*d)^2*g^2*x/(b^2*d^2)+1/3*a^2*(b*c-a*d)*g^2*log(a+b*x)/_
+--  (b^3*d)-1/3*(b*c-a*d)*g^2*x^2*log(e*(a+b*x)/(c+d*x))/(b*d)-_
+--  2/3*(b*c-a*d)*g*(3*b*d*f-b*c*g-a*d*g)*(a+b*x)*log(e*(a+b*x)/_
+--  (c+d*x))/(b^3*d^2)+2/3*(b*f-a*g)^3*log((-b*c+a*d)/(d*(a+b*x)))*_
+--  log(e*(a+b*x)/(c+d*x))/(b^3*g)-2/3*(d*f-c*g)^3*log((b*c-a*d)/_
+--  (b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/(d^3*g)+1/3*(f+g*x)^3*log(e*_
+--  (a+b*x)/(c+d*x))^2/g-1/3*c^2*(b*c-a*d)*g^2*log(c+d*x)/(b*d^3)+_
+--  2/3*(b*c-a*d)^2*g*(3*b*d*f-b*c*g-a*d*g)*log(c+d*x)/(b^3*d^3)-_
+--  2/3*(d*f-c*g)^3*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(d^3*g)-_
+--  2/3*(b*f-a*g)^3*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^3*g)
+--E 3140
+
+--S 3141 of 5341
+--a0:=integrate(t0,x)
+--E 3141
+
+--S 3142 of 5341
+--m0:=a0-r0
+--E 3142
+
+--S 3143 of 5341
+--d0:=D(m0,x)
+--E 3143
+
+)clear all
+
+--S 3144 of 5341
+t0:=(f+g*x)*log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R                     b e x + a e 2
+--R   (1)  (g x + f)log(-----------)
+--R                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 3144
+
+--S 3145 of 5341
+--r0:=-(b*c-a*d)*g*(a+b*x)*log(e*(a+b*x)/(c+d*x))/(b^2*d)+(b*f-a*g)^2*_
+--  log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))/(b^2*g)-(d*f-c*g)^2*_
+--  log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/(d^2*g)+1/2*(f+g*x)^2*_
+--  log(e*(a+b*x)/(c+d*x))^2/g+(b*c-a*d)^2*g*log(c+d*x)/(b^2*d^2)-_
+--  (d*f-c*g)^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(d^2*g)-(b*f-a*g)^2*_
+--  polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^2*g)
+--E 3145
+
+--S 3146 of 5341
+--a0:=integrate(t0,x)
+--E 3146
+
+--S 3147 of 5341
+--m0:=a0-r0
+--E 3147
+
+--S 3148 of 5341
+--d0:=D(m0,x)
+--E 3148
+
+)clear all
+
+--S 3149 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2
+--R 
+--R
+--R            b e x + a e 2
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 3149
+
+--S 3150 of 5341
+--r0:=2*(b*c-a*d)*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/(b*d)+_
+--  (a+b*x)*log(e*(a+b*x)/(c+d*x))^2/b+2*(b*c-a*d)*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(b*d)
+--E 3150
+
+--S 3151 of 5341
+--a0:=integrate(t0,x)
+--E 3151
+
+--S 3152 of 5341
+--m0:=a0-r0
+--E 3152
+
+--S 3153 of 5341
+--d0:=D(m0,x)
+--E 3153
+
+)clear all
+
+--S 3154 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2/(f+g*x)
+--R 
+--R
+--R            b e x + a e 2
+--R        log(-----------)
+--R              d x + c
+--R   (1)  -----------------
+--R             g x + f
+--R                                                    Type: Expression(Integer)
+--E 3154
+
+--S 3155 of 5341
+--r0:=-log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^2/g+_
+--  log(e*(a+b*x)/(c+d*x))^2*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*(c+d*x)))/g-_
+--  2*log(e*(a+b*x)/(c+d*x))*polylog(2,d*(a+b*x)/(b*(c+d*x)))/g+_
+--  2*log(e*(a+b*x)/(c+d*x))*polylog(2,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/_
+--  ((b*f-a*g)*(c+d*x)))/g+2*polylog(3,d*(a+b*x)/(b*(c+d*x)))/g-_
+--  2*polylog(3,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/g
+--E 3155
+
+--S 3156 of 5341
+--a0:=integrate(t0,x)
+--E 3156
+
+--S 3157 of 5341
+--m0:=a0-r0
+--E 3157
+
+--S 3158 of 5341
+--d0:=D(m0,x)
+--E 3158
+
+)clear all
+
+--S 3159 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2/(f+g*x)^2
+--R 
+--R
+--R             b e x + a e 2
+--R         log(-----------)
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        g x  + 2f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3159
+
+--S 3160 of 5341
+--r0:=(a+b*x)*log(e*(a+b*x)/(c+d*x))^2/((b*f-a*g)*(f+g*x))+2*(b*c-a*d)*_
+--  log(e*(a+b*x)/(c+d*x))*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*(c+d*x)))/_
+--  ((b*f-a*g)*(d*f-c*g))+2*(b*c-a*d)*polylog(2,(d*f-c*g)*(a+b*x)/_
+--  ((b*f-a*g)*(c+d*x)))/((b*f-a*g)*(d*f-c*g))
+--E 3160
+
+--S 3161 of 5341
+--a0:=integrate(t0,x)
+--E 3161
+
+--S 3162 of 5341
+--m0:=a0-r0
+--E 3162
+
+--S 3163 of 5341
+--d0:=D(m0,x)
+--E 3163
+
+)clear all
+
+--S 3164 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2/(f+g*x)^3
+--R 
+--R
+--R                  b e x + a e 2
+--R              log(-----------)
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        g x  + 3f g x  + 3f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3164
+
+--S 3165 of 5341
+--r0:=(b*c-a*d)*g*(a+b*x)*log(e*(a+b*x)/(c+d*x))/((b*f-a*g)^2*(d*f-c*g)*_
+--  (f+g*x))-b^2*log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))/_
+--  (g*(b*f-a*g)^2)+d^2*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/_
+--  (g*(d*f-c*g)^2)-1/2*log(e*(a+b*x)/(c+d*x))^2/(g*(f+g*x)^2)-(b*c-a*d)^2*_
+--  g*log(c+d*x)/((b*f-a*g)^2*(d*f-c*g)^2)+(b*c-a*d)^2*g*log(f+g*x)/_
+--  ((b*f-a*g)^2*(d*f-c*g)^2)-(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*_
+--  log(-g*(a+b*x)/(b*f-a*g))*log(f+g*x)/((b*f-a*g)^2*(d*f-c*g)^2)+_
+--  (b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*log(e*(a+b*x)/(c+d*x))*log(f+g*x)/_
+--  ((b*f-a*g)^2*(d*f-c*g)^2)+(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*_
+--  log(-g*(c+d*x)/(d*f-c*g))*log(f+g*x)/((b*f-a*g)^2*(d*f-c*g)^2)+d^2*_
+--  polylog(2,d*(a+b*x)/(b*(c+d*x)))/(g*(d*f-c*g)^2)+b^2*_
+--  polylog(2,b*(c+d*x)/(d*(a+b*x)))/(g*(b*f-a*g)^2)-(b*c-a*d)*_
+--  (2*b*d*f-b*c*g-a*d*g)*polylog(2,b*(f+g*x)/(b*f-a*g))/((b*f-a*g)^2*_
+--  (d*f-c*g)^2)+(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*polylog(2,d*(f+g*x)/_
+--  (d*f-c*g))/((b*f-a*g)^2*(d*f-c*g)^2)
+--E 3165
+
+--S 3166 of 5341
+--a0:=integrate(t0,x)
+--E 3166
+
+--S 3167 of 5341
+--m0:=a0-r0
+--E 3167
+
+--S 3168 of 5341
+--d0:=D(m0,x)
+--E 3168
+
+)clear all
+
+--S 3169 of 5341
+t0:=(f+g*x)^2*log(e*(a+b*x)/(c+d*x))^3
+--R 
+--R
+--R          2 2             2     b e x + a e 3
+--R   (1)  (g x  + 2f g x + f )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 3169
+
+--S 3170 of 5341
+--r0:=(b*c-a*d)^2*g^2*(a+b*x)*log(e*(a+b*x)/(c+d*x))/(b^3*d^2)-_
+--  a^2*(b*c-a*d)*g^2*log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))/_
+--  (b^3*d)+c^2*(b*c-a*d)*g^2*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/_
+--  (c+d*x))/(b*d^3)-2*(b*c-a*d)^2*g*(3*b*d*f-b*c*g-a*d*g)*log((b*c-a*d)/_
+--  (b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/(b^3*d^3)-1/2*(b*c-a*d)*g^2*x^2*_
+--  log(e*(a+b*x)/(c+d*x))^2/(b*d)-(b*c-a*d)*g*(3*b*d*f-b*c*g-a*d*g)*_
+--  (a+b*x)*log(e*(a+b*x)/(c+d*x))^2/(b^3*d^2)+(b*f-a*g)^3*log((-b*c+a*d)/_
+--  (d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))^2/(b^3*g)-(d*f-c*g)^3*_
+--  log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^2/(d^3*g)+_
+--  1/3*(f+g*x)^3*log(e*(a+b*x)/(c+d*x))^3/g-(b*c-a*d)^3*g^2*log(c+d*x)/_
+--  (b^3*d^3)+c^2*(b*c-a*d)*g^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d^3)-_
+--  2*(b*c-a*d)^2*g*(3*b*d*f-b*c*g-a*d*g)*polylog(2,d*(a+b*x)/(b*(c+d*x)))/_
+--  (b^3*d^3)-2*(d*f-c*g)^3*log(e*(a+b*x)/(c+d*x))*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(d^3*g)+a^2*(b*c-a*d)*g^2*polylog(2,b*(c+d*x)/_
+--  (d*(a+b*x)))/(b^3*d)-2*(b*f-a*g)^3*log(e*(a+b*x)/(c+d*x))*_
+--  polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^3*g)+2*(d*f-c*g)^3*_
+--  polylog(3,d*(a+b*x)/(b*(c+d*x)))/(d^3*g)-2*(b*f-a*g)^3*_
+--  polylog(3,b*(c+d*x)/(d*(a+b*x)))/(b^3*g)
+--E 3170
+
+--S 3171 of 5341
+--a0:=integrate(t0,x)
+--E 3171
+
+--S 3172 of 5341
+--m0:=a0-r0
+--E 3172
+
+--S 3173 of 5341
+--d0:=D(m0,x)
+--E 3173
+
+)clear all
+
+--S 3174 of 5341
+t0:=(f+g*x)*log(e*(a+b*x)/(c+d*x))^3
+--R 
+--R
+--R                     b e x + a e 3
+--R   (1)  (g x + f)log(-----------)
+--R                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 3174
+
+--S 3175 of 5341
+--r0:=-3*(b*c-a*d)^2*g*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))/_
+--  (b^2*d^2)-3/2*(b*c-a*d)*g*(a+b*x)*log(e*(a+b*x)/(c+d*x))^2/(b^2*d)+_
+--  3/2*(b*f-a*g)^2*log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/(c+d*x))^2/_
+--  (b^2*g)-3/2*(d*f-c*g)^2*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/_
+--  (c+d*x))^2/(d^2*g)+1/2*(f+g*x)^2*log(e*(a+b*x)/(c+d*x))^3/g-_
+--  3*(b*c-a*d)^2*g*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b^2*d^2)-_
+--  3*(d*f-c*g)^2*log(e*(a+b*x)/(c+d*x))*polylog(2,d*(a+b*x)/(b*(c+d*x)))/_
+--  (d^2*g)-3*(b*f-a*g)^2*log(e*(a+b*x)/(c+d*x))*polylog(2,b*(c+d*x)/_
+--  (d*(a+b*x)))/(b^2*g)+3*(d*f-c*g)^2*polylog(3,d*(a+b*x)/(b*(c+d*x)))/_
+--  (d^2*g)-3*(b*f-a*g)^2*polylog(3,b*(c+d*x)/(d*(a+b*x)))/(b^2*g)
+--E 3175
+
+--S 3176 of 5341
+--a0:=integrate(t0,x)
+--E 3176
+
+--S 3177 of 5341
+--m0:=a0-r0
+--E 3177
+
+--S 3178 of 5341
+--d0:=D(m0,x)
+--E 3178
+
+)clear all
+
+--S 3179 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3
+--R 
+--R
+--R            b e x + a e 3
+--R   (1)  log(-----------)
+--R              d x + c
+--R                                                    Type: Expression(Integer)
+--E 3179
+
+--S 3180 of 5341
+--r0:=3*(b*c-a*d)*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^2/(b*d)+_
+--  (a+b*x)*log(e*(a+b*x)/(c+d*x))^3/b+6*(b*c-a*d)*log(e*(a+b*x)/(c+d*x))*_
+--  polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d)-6*(b*c-a*d)*polylog(3,d*_
+--  (a+b*x)/(b*(c+d*x)))/(b*d)
+--E 3180
+
+--S 3181 of 5341
+--a0:=integrate(t0,x)
+--E 3181
+
+--S 3182 of 5341
+--m0:=a0-r0
+--E 3182
+
+--S 3183 of 5341
+--d0:=D(m0,x)
+--E 3183
+
+)clear all
+
+--S 3184 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3/(f+g*x)
+--R 
+--R
+--R            b e x + a e 3
+--R        log(-----------)
+--R              d x + c
+--R   (1)  -----------------
+--R             g x + f
+--R                                                    Type: Expression(Integer)
+--E 3184
+
+--S 3185 of 5341
+--r0:=-log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^3/g+_
+--  log(e*(a+b*x)/(c+d*x))^3*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*(c+d*x)))/g-_
+--  3*log(e*(a+b*x)/(c+d*x))^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/g+_
+--  3*log(e*(a+b*x)/(c+d*x))^2*polylog(2,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/_
+--  ((b*f-a*g)*(c+d*x)))/g+6*log(e*(a+b*x)/(c+d*x))*polylog(3,d*(a+b*x)/_
+--  (b*(c+d*x)))/g-6*log(e*(a+b*x)/(c+d*x))*polylog(3,(a*(d*f-c*g)+b*d*f*x-_
+--  b*c*g*x)/((b*f-a*g)*(c+d*x)))/g-6*polylog(4,d*(a+b*x)/(b*(c+d*x)))/g+_
+--  6*polylog(4,(d*f-c*g)*(a+b*x)/((b*f-a*g)*(c+d*x)))/g
+--E 3185
+
+--S 3186 of 5341
+--a0:=integrate(t0,x)
+--E 3186
+
+--S 3187 of 5341
+--m0:=a0-r0
+--E 3187
+
+--S 3188 of 5341
+--d0:=D(m0,x)
+--E 3188
+
+)clear all
+
+--S 3189 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3/(f+g*x)^2
+--R 
+--R
+--R             b e x + a e 3
+--R         log(-----------)
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        g x  + 2f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3189
+
+--S 3190 of 5341
+--r0:=(a+b*x)*log(e*(a+b*x)/(c+d*x))^3/((b*f-a*g)*(f+g*x))+3*(b*c-a*d)*_
+--  log(e*(a+b*x)/(c+d*x))^2*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*(c+d*x)))/_
+--  ((b*f-a*g)*(d*f-c*g))+6*(b*c-a*d)*log(e*(a+b*x)/(c+d*x))*polylog(2,_
+--  (a*(d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/((b*f-a*g)*_
+--  (d*f-c*g))-6*(b*c-a*d)*polylog(3,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/_
+--  ((b*f-a*g)*(c+d*x)))/((b*f-a*g)*(d*f-c*g))
+--E 3190
+
+--S 3191 of 5341
+--a0:=integrate(t0,x)
+--E 3191
+
+--S 3192 of 5341
+--m0:=a0-r0
+--E 3192
+
+--S 3193 of 5341
+--d0:=D(m0,x)
+--E 3193
+
+)clear all
+
+--S 3194 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3/(f+g*x)^3
+--R 
+--R
+--R                  b e x + a e 3
+--R              log(-----------)
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        g x  + 3f g x  + 3f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3194
+
+--S 3195 of 5341
+--r0:=3/2*(b*c-a*d)*g*(a+b*x)*log(e*(a+b*x)/(c+d*x))^2/((b*f-a*g)^2*_
+--  (d*f-c*g)*(f+g*x))-3/2*b^2*log((-b*c+a*d)/(d*(a+b*x)))*log(e*(a+b*x)/_
+--  (c+d*x))^2/(g*(b*f-a*g)^2)+3/2*d^2*log((b*c-a*d)/(b*(c+d*x)))*_
+--  log(e*(a+b*x)/(c+d*x))^2/(g*(d*f-c*g)^2)-3/2*(b*c-a*d)*(2*b*d*f-_
+--  b*c*g-a*d*g)*log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^2/_
+--  ((b*f-a*g)^2*(d*f-c*g)^2)-1/2*log(e*(a+b*x)/(c+d*x))^3/(g*(f+g*x)^2)+_
+--  3*(b*c-a*d)^2*g*log(e*(a+b*x)/(c+d*x))*log((b*c-a*d)*(f+g*x)/_
+--  ((b*f-a*g)*(c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)+3/2*(b*c-a*d)*(2*b*d*f-_
+--  b*c*g-a*d*g)*log(e*(a+b*x)/(c+d*x))^2*log((b*c-a*d)*(f+g*x)/_
+--  ((b*f-a*g)*(c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)+3*d^2*log(e*(a+b*x)/_
+--  (c+d*x))*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(g*(d*f-c*g)^2)-3*(b*c-a*d)*_
+--  (2*b*d*f-b*c*g-a*d*g)*log(e*(a+b*x)/(c+d*x))*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)+3*(b*c-a*d)^2*g*polylog(2,_
+--  (d*f-c*g)*(a+b*x)/((b*f-a*g)*(c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)+_
+--  3*b^2*log(e*(a+b*x)/(c+d*x))*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(g*_
+--  (b*f-a*g)^2)+3*(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*log(e*(a+b*x)/_
+--  (c+d*x))*polylog(2,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/_
+--  ((b*f-a*g)^2*(d*f-c*g)^2)-3*d^2*polylog(3,d*(a+b*x)/(b*(c+d*x)))/_
+--  (g*(d*f-c*g)^2)+3*(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*polylog(3,_
+--  d*(a+b*x)/(b*(c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)+3*b^2*polylog(3,_
+--  b*(c+d*x)/(d*(a+b*x)))/(g*(b*f-a*g)^2)-3*(b*c-a*d)*(2*b*d*f-_
+--  b*c*g-a*d*g)*polylog(3,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*_
+--  (c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)
+--E 3195
+
+--S 3196 of 5341
+--a0:=integrate(t0,x)
+--E 3196
+
+--S 3197 of 5341
+--m0:=a0-r0
+--E 3197
+
+--S 3198 of 5341
+--d0:=D(m0,x)
+--E 3198
+
+)clear all
+
+--S 3199 of 5341
+t0:=(a+b*x)^m*(c+d*x)^(-2-m)/log(e*(a+b*x)/(c+d*x))
+--R 
+--R
+--R                 m         - m - 2
+--R        (b x + a) (d x + c)
+--R   (1)  --------------------------
+--R                 b e x + a e
+--R             log(-----------)
+--R                   d x + c
+--R                                                    Type: Expression(Integer)
+--E 3199
+
+--S 3200 of 5341
+--r0:=(a+b*x)^(1+m)*(e*(a+b*x)/(c+d*x))^(-1-m)*(c+d*x)^(-1-m)*Ei((1+m)*_
+--  log(e*(a+b*x)/(c+d*x)))/(b*c-a*d)
+--E 3200
+
+--S 3201 of 5341
+--a0:=integrate(t0,x)
+--E 3201
+
+--S 3202 of 5341
+--m0:=a0-r0
+--E 3202
+
+--S 3203 of 5341
+--d0:=D(m0,x)
+--E 3203
+
+)clear all
+
+--S 3204 of 5341
+t0:=(a+b*x)^3/((c+d*x)^5*log(e*(a+b*x)/(c+d*x)))
+--R 
+--R
+--R                             3 3       2 2     2       3
+--R                            b x  + 3a b x  + 3a b x + a
+--R   (1)  --------------------------------------------------------------------
+--R          5 5       4 4      2 3 3      3 2 2     4       5     b e x + a e
+--R        (d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c )log(-----------)
+--R                                                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 3204
+
+--S 3205 of 5341
+--r0:=Ei(4*log(e*(a+b*x)/(c+d*x)))/((b*c-a*d)*e^4)
+--E 3205
+
+--S 3206 of 5341
+--a0:=integrate(t0,x)
+--E 3206
+
+--S 3207 of 5341
+--m0:=a0-r0
+--E 3207
+
+--S 3208 of 5341
+--d0:=D(m0,x)
+--E 3208
+
+)clear all
+
+--S 3209 of 5341
+t0:=(a+b*x)^2/((c+d*x)^4*log(e*(a+b*x)/(c+d*x)))
+--R 
+--R
+--R                            2 2             2
+--R                           b x  + 2a b x + a
+--R   (1)  --------------------------------------------------------
+--R          4 4       3 3     2 2 2     3       4     b e x + a e
+--R        (d x  + 4c d x  + 6c d x  + 4c d x + c )log(-----------)
+--R                                                      d x + c
+--R                                                    Type: Expression(Integer)
+--E 3209
+
+--S 3210 of 5341
+--r0:=Ei(3*log(e*(a+b*x)/(c+d*x)))/((b*c-a*d)*e^3)
+--E 3210
+
+--S 3211 of 5341
+--a0:=integrate(t0,x)
+--E 3211
+
+--S 3212 of 5341
+--m0:=a0-r0
+--E 3212
+
+--S 3213 of 5341
+--d0:=D(m0,x)
+--E 3213
+
+)clear all
+
+--S 3214 of 5341
+t0:=(a+b*x)/((c+d*x)^3*log(e*(a+b*x)/(c+d*x)))
+--R 
+--R
+--R                            b x + a
+--R   (1)  ----------------------------------------------
+--R          3 3       2 2     2       3     b e x + a e
+--R        (d x  + 3c d x  + 3c d x + c )log(-----------)
+--R                                            d x + c
+--R                                                    Type: Expression(Integer)
+--E 3214
+
+--S 3215 of 5341
+--r0:=Ei(2*log(e*(a+b*x)/(c+d*x)))/((b*c-a*d)*e^2)
+--E 3215
+
+--S 3216 of 5341
+--a0:=integrate(t0,x)
+--E 3216
+
+--S 3217 of 5341
+--m0:=a0-r0
+--E 3217
+
+--S 3218 of 5341
+--d0:=D(m0,x)
+--E 3218
+
+)clear all
+
+--S 3219 of 5341
+t0:=1/((c+d*x)^2*log(e*(a+b*x)/(c+d*x)))
+--R 
+--R
+--R                          1
+--R   (1)  ------------------------------------
+--R          2 2             2     b e x + a e
+--R        (d x  + 2c d x + c )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 3219
+
+--S 3220 of 5341
+--r0:=Li(e*(a+b*x)/(c+d*x))/((b*c-a*d)*e)
+--E 3220
+
+--S 3221 of 5341
+--a0:=integrate(t0,x)
+--E 3221
+
+--S 3222 of 5341
+--m0:=a0-r0
+--E 3222
+
+--S 3223 of 5341
+--d0:=D(m0,x)
+--E 3223
+
+)clear all
+
+--S 3224 of 5341
+t0:=1/((a+b*x)*(c+d*x)*log(e*(a+b*x)/(c+d*x)))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R              2                          b e x + a e
+--R        (b d x  + (a d + b c)x + a c)log(-----------)
+--R                                           d x + c
+--R                                                    Type: Expression(Integer)
+--E 3224
+
+--S 3225 of 5341
+r0:=log(log(e*(a+b*x)/(c+d*x)))/(b*c-a*d)
+--R 
+--R
+--R                  b e x + a e
+--R          log(log(-----------))
+--R                    d x + c
+--R   (2)  - ---------------------
+--R                a d - b c
+--R                                                    Type: Expression(Integer)
+--E 3225
+
+--S 3226 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  b e x + a e
+--R          log(log(-----------))
+--R                    d x + c
+--R   (3)  - ---------------------
+--R                a d - b c
+--R                                         Type: Union(Expression(Integer),...)
+--E 3226
+
+--S 3227 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 3227
+
+--S 3228 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3228
+
+)clear all
+
+--S 3229 of 5341
+t0:=1/((a+b*x)^2*log(e*(a+b*x)/(c+d*x)))
+--R 
+--R
+--R                          1
+--R   (1)  ------------------------------------
+--R          2 2             2     b e x + a e
+--R        (b x  + 2a b x + a )log(-----------)
+--R                                  d x + c
+--R                                                    Type: Expression(Integer)
+--E 3229
+
+--S 3230 of 5341
+--r0:=e*Ei(-log(e*(a+b*x)/(c+d*x)))/(b*c-a*d)
+--E 3230
+
+--S 3231 of 5341
+--a0:=integrate(t0,x)
+--E 3231
+
+--S 3232 of 5341
+--m0:=a0-r0
+--E 3232
+
+--S 3233 of 5341
+--d0:=D(m0,x)
+--E 3233
+
+)clear all
+
+--S 3234 of 5341
+t0:=(c+d*x)/((a+b*x)^3*log(e*(a+b*x)/(c+d*x)))
+--R 
+--R
+--R                            d x + c
+--R   (1)  ----------------------------------------------
+--R          3 3       2 2     2       3     b e x + a e
+--R        (b x  + 3a b x  + 3a b x + a )log(-----------)
+--R                                            d x + c
+--R                                                    Type: Expression(Integer)
+--E 3234
+
+--S 3235 of 5341
+--r0:=e^2*Ei(-2*log(e*(a+b*x)/(c+d*x)))/(b*c-a*d)
+--E 3235
+
+--S 3236 of 5341
+--a0:=integrate(t0,x)
+--E 3236
+
+--S 3237 of 5341
+--m0:=a0-r0
+--E 3237
+
+--S 3238 of 5341
+--d0:=D(m0,x)
+--E 3238
+
+)clear all
+
+--S 3239 of 5341
+t0:=(c+d*x)^2/((a+b*x)^4*log(e*(a+b*x)/(c+d*x)))
+--R 
+--R
+--R                            2 2             2
+--R                           d x  + 2c d x + c
+--R   (1)  --------------------------------------------------------
+--R          4 4       3 3     2 2 2     3       4     b e x + a e
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )log(-----------)
+--R                                                      d x + c
+--R                                                    Type: Expression(Integer)
+--E 3239
+
+--S 3240 of 5341
+--r0:=e^3*Ei(-3*log(e*(a+b*x)/(c+d*x)))/(b*c-a*d)
+--E 3240
+
+--S 3241 of 5341
+--a0:=integrate(t0,x)
+--E 3241
+
+--S 3242 of 5341
+--m0:=a0-r0
+--E 3242
+
+--S 3243 of 5341
+--d0:=D(m0,x)
+--E 3243
+
+)clear all
+
+--S 3244 of 5341
+t0:=log(c*x/(a+b*x))/(a+b*x)
+--R 
+--R
+--R              c x
+--R        log(-------)
+--R            b x + a
+--R   (1)  ------------
+--R           b x + a
+--R                                                    Type: Expression(Integer)
+--E 3244
+
+--S 3245 of 5341
+--r0:=-log(a/(a+b*x))*log(c*x/(a+b*x))/b-polylog(2,b*x/(a+b*x))/b
+--E 3245
+
+--S 3246 of 5341
+--a0:=integrate(t0,x)
+--E 3246
+
+--S 3247 of 5341
+--m0:=a0-r0
+--E 3247
+
+--S 3248 of 5341
+--d0:=D(m0,x)
+--E 3248
+
+)clear all
+
+--S 3249 of 5341
+t0:=log(c*x/(a+b*x))^2/(x*(a+b*x))
+--R 
+--R
+--R              c x   2
+--R        log(-------)
+--R            b x + a
+--R   (1)  -------------
+--R             2
+--R          b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3249
+
+--S 3250 of 5341
+r0:=1/3*log(c*x/(a+b*x))^3/a
+--R 
+--R
+--R              c x   3
+--R        log(-------)
+--R            b x + a
+--R   (2)  -------------
+--R              3a
+--R                                                    Type: Expression(Integer)
+--E 3250
+
+--S 3251 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R              c x   3
+--R        log(-------)
+--R            b x + a
+--R   (3)  -------------
+--R              3a
+--R                                         Type: Union(Expression(Integer),...)
+--E 3251
+
+--S 3252 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 3252
+
+--S 3253 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3253
+
+)clear all
+
+--S 3254 of 5341
+t0:=log(a/(a+b*x))*log(c*x/(a+b*x))^2/(x*(a+b*x))
+--R 
+--R
+--R               a          c x   2
+--R        log(-------)log(-------)
+--R            b x + a     b x + a
+--R   (1)  -------------------------
+--R                   2
+--R                b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3254
+
+--S 3255 of 5341
+--r0:=-log(c*x/(a+b*x))^2*polylog(2,b*x/(a+b*x))/a+2*log(c*x/(a+b*x))*_
+--  polylog(3,b*x/(a+b*x))/a-2*polylog(4,b*x/(a+b*x))/a
+--E 3255
+
+--S 3256 of 5341
+--a0:=integrate(t0,x)
+--E 3256
+
+--S 3257 of 5341
+--m0:=a0-r0
+--E 3257
+
+--S 3258 of 5341
+--d0:=D(m0,x)
+--E 3258
+
+)clear all
+
+--S 3259 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))/((c+d*x)*(f+g*x))
+--R 
+--R
+--R                  b e x + a e
+--R              log(-----------)
+--R                    d x + c
+--R   (1)  ---------------------------
+--R             2
+--R        d g x  + (c g + d f)x + c f
+--R                                                    Type: Expression(Integer)
+--E 3259
+
+--S 3260 of 5341
+--r0:=-log(e*(a+b*x)/(c+d*x))*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*(c+d*x)))/_
+--  (d*f-c*g)-polylog(2,(d*f-c*g)*(a+b*x)/((b*f-a*g)*(c+d*x)))/(d*f-c*g)
+--E 3260
+
+--S 3261 of 5341
+--a0:=integrate(t0,x)
+--E 3261
+
+--S 3262 of 5341
+--m0:=a0-r0
+--E 3262
+
+--S 3263 of 5341
+--d0:=D(m0,x)
+--E 3263
+
+)clear all
+
+--S 3264 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^2/((c+d*x)*(f+g*x))
+--R 
+--R
+--R                 b e x + a e 2
+--R             log(-----------)
+--R                   d x + c
+--R   (1)  ---------------------------
+--R             2
+--R        d g x  + (c g + d f)x + c f
+--R                                                    Type: Expression(Integer)
+--E 3264
+
+--S 3265 of 5341
+--r0:=-log(e*(a+b*x)/(c+d*x))^2*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*_
+--  (c+d*x)))/(d*f-c*g)-2*log(e*(a+b*x)/(c+d*x))*polylog(2,(a*(d*f-c*g)+_
+--  b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/(d*f-c*g)+2*polylog(3,(a*(d*f-_
+--  c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/(d*f-c*g)
+--E 3265
+
+--S 3266 of 5341
+--a0:=integrate(t0,x)
+--E 3266
+
+--S 3267 of 5341
+--m0:=a0-r0
+--E 3267
+
+--S 3268 of 5341
+--d0:=D(m0,x)
+--E 3268
+
+)clear all
+
+--S 3269 of 5341
+t0:=log(e*(a+b*x)/(c+d*x))^3/((c+d*x)*(f+g*x))
+--R 
+--R
+--R                 b e x + a e 3
+--R             log(-----------)
+--R                   d x + c
+--R   (1)  ---------------------------
+--R             2
+--R        d g x  + (c g + d f)x + c f
+--R                                                    Type: Expression(Integer)
+--E 3269
+
+--S 3270 of 5341
+--r0:=-log(e*(a+b*x)/(c+d*x))^3*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*_
+--  (c+d*x)))/(d*f-c*g)-3*log(e*(a+b*x)/(c+d*x))^2*polylog(2,(a*(d*f-_
+--  c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/(d*f-c*g)+6*log(e*_
+--  (a+b*x)/(c+d*x))*polylog(3,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-_
+--  a*g)*(c+d*x)))/(d*f-c*g)-6*polylog(4,(d*f-c*g)*(a+b*x)/((b*f-a*g)*_
+--  (c+d*x)))/(d*f-c*g)
+--E 3270
+
+--S 3271 of 5341
+--a0:=integrate(t0,x)
+--E 3271
+
+--S 3272 of 5341
+--m0:=a0-r0
+--E 3272
+
+--S 3273 of 5341
+--d0:=D(m0,x)
+--E 3273
+
+)clear all
+
+--S 3274 of 5341
+t0:=log((b*c-a*d)/(b*(c+d*x)))*log(e*(a+b*x)/(c+d*x))^2/((c+d*x)*(a*g+b*g*x))
+--R 
+--R
+--R            - a d + b c     b e x + a e 2
+--R        log(-----------)log(-----------)
+--R            b d x + b c       d x + c
+--R   (1)  ---------------------------------
+--R               2
+--R        b d g x  + (a d + b c)g x + a c g
+--R                                                    Type: Expression(Integer)
+--E 3274
+
+--S 3275 of 5341
+--r0:=-log(e*(a+b*x)/(c+d*x))^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/_
+--  ((b*c-a*d)*g)+2*log(e*(a+b*x)/(c+d*x))*polylog(3,d*(a+b*x)/_
+--  (b*(c+d*x)))/((b*c-a*d)*g)-2*polylog(4,d*(a+b*x)/(b*(c+d*x)))/_
+--  ((b*c-a*d)*g)
+--E 3275
+
+--S 3276 of 5341
+--a0:=integrate(t0,x)
+--E 3276
+
+--S 3277 of 5341
+--m0:=a0-r0
+--E 3277
+
+--S 3278 of 5341
+--d0:=D(m0,x)
+--E 3278
+
+)clear all
+
+--S 3279 of 5341
+t0:=log(c*(b+a*x)/x)
+--R 
+--R
+--R            a c x + b c
+--R   (1)  log(-----------)
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 3279
+
+--S 3280 of 5341
+r0:=x*log(a*c+b*c/x)+b*log(b+a*x)/a
+--R 
+--R
+--R                                 a c x + b c
+--R        b log(a x + b) + a x log(-----------)
+--R                                      x
+--R   (2)  -------------------------------------
+--R                          a
+--R                                                    Type: Expression(Integer)
+--E 3280
+
+--S 3281 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                 a c x + b c
+--R        b log(a x + b) + a x log(-----------)
+--R                                      x
+--R   (3)  -------------------------------------
+--R                          a
+--R                                         Type: Union(Expression(Integer),...)
+--E 3281
+
+--S 3282 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 3282
+
+--S 3283 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3283
+
+)clear all
+
+--S 3284 of 5341
+t0:=log(c*(b+a*x)/x)^2
+--R 
+--R
+--R            a c x + b c 2
+--R   (1)  log(-----------)
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 3284
+
+--S 3285 of 5341
+--r0:=-2*b*log(a*c+b*c/x)*log(-b/(a*x))/a+(b+a*x)*_
+--  log(c*(b+a*x)/x)^2/a-2*b*polylog(2,(a+b/x)/a)/a
+--E 3285
+
+--S 3286 of 5341
+--a0:=integrate(t0,x)
+--E 3286
+
+--S 3287 of 5341
+--m0:=a0-r0
+--E 3287
+
+--S 3288 of 5341
+--d0:=D(m0,x)
+--E 3288
+
+)clear all
+
+--S 3289 of 5341
+t0:=log(c*(b+a*x)/x)^3
+--R 
+--R
+--R            a c x + b c 3
+--R   (1)  log(-----------)
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 3289
+
+--S 3290 of 5341
+--r0:=-3*b*log(-b/(a*x))*log(c*(b+a*x)/x)^2/a+(b+a*x)*log(c*(b+a*x)/x)^3/a-_
+--  6*b*log(a*c+b*c/x)*polylog(2,(b+a*x)/(a*x))/a+_
+--  6*b*polylog(3,(b+a*x)/(a*x))/a
+--E 3290
+
+--S 3291 of 5341
+--a0:=integrate(t0,x)
+--E 3291
+
+--S 3292 of 5341
+--m0:=a0-r0
+--E 3292
+
+--S 3293 of 5341
+--d0:=D(m0,x)
+--E 3293
+
+)clear all
+
+--S 3294 of 5341
+t0:=log(c*(b+a*x)^2/x^2)
+--R 
+--R
+--R             2   2               2
+--R            a c x  + 2a b c x + b c
+--R   (1)  log(-----------------------)
+--R                        2
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 3294
+
+--S 3295 of 5341
+r0:=2*b*log(b+a*x)/a+x*log(c*(b+a*x)^2/x^2)
+--R 
+--R
+--R                                   2   2               2
+--R                                  a c x  + 2a b c x + b c
+--R        2b log(a x + b) + a x log(-----------------------)
+--R                                              2
+--R                                             x
+--R   (2)  --------------------------------------------------
+--R                                 a
+--R                                                    Type: Expression(Integer)
+--E 3295
+
+--S 3296 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   2   2               2
+--R                                  a c x  + 2a b c x + b c
+--R        2b log(a x + b) + a x log(-----------------------)
+--R                                              2
+--R                                             x
+--R   (3)  --------------------------------------------------
+--R                                 a
+--R                                         Type: Union(Expression(Integer),...)
+--E 3296
+
+--S 3297 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 3297
+
+--S 3298 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3298
+
+)clear all
+
+--S 3299 of 5341
+t0:=log(c*(b+a*x)^2/x^2)^2
+--R 
+--R
+--R             2   2               2  2
+--R            a c x  + 2a b c x + b c
+--R   (1)  log(-----------------------)
+--R                        2
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 3299
+
+--S 3300 of 5341
+--r0:=-4*b*log(b/(b+a*x))*log(c*(b+a*x)^2/x^2)/a+x*log(c*(b+a*x)^2/x^2)^2+_
+--  8*b*polylog(2,a*x/(b+a*x))/a
+--E 3300
+
+--S 3301 of 5341
+--a0:=integrate(t0,x)
+--E 3301
+
+--S 3302 of 5341
+--m0:=a0-r0
+--E 3302
+
+--S 3303 of 5341
+--d0:=D(m0,x)
+--E 3303
+
+)clear all
+
+--S 3304 of 5341
+t0:=log(c*(b+a*x)^2/x^2)^3
+--R 
+--R
+--R             2   2               2  3
+--R            a c x  + 2a b c x + b c
+--R   (1)  log(-----------------------)
+--R                        2
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 3304
+
+--S 3305 of 5341
+--r0:=-6*b*log(b/(b+a*x))*log(c*(b+a*x)^2/x^2)^2/a+x*log(c*(b+a*x)^2/x^2)^3+_
+--  24*b*log(c*(b+a*x)^2/x^2)*polylog(2,a*x/(b+a*x))/a+_
+--  48*b*polylog(3,a*x/(b+a*x))/a
+--E 3305
+
+--S 3306 of 5341
+--a0:=integrate(t0,x)
+--E 3306
+
+--S 3307 of 5341
+--m0:=a0-r0
+--E 3307
+
+--S 3308 of 5341
+--d0:=D(m0,x)
+--E 3308
+
+)clear all
+
+--S 3309 of 5341
+t0:=log(c*x^2/(b+a*x)^2)
+--R 
+--R
+--R                      2
+--R                   c x
+--R   (1)  log(------------------)
+--R             2 2             2
+--R            a x  + 2a b x + b
+--R                                                    Type: Expression(Integer)
+--E 3309
+
+--S 3310 of 5341
+r0:=x*log(c*x^2/(b+a*x)^2)-2*b*log(b+a*x)/a
+--R 
+--R
+--R                                              2
+--R                                           c x
+--R        - 2b log(a x + b) + a x log(------------------)
+--R                                     2 2             2
+--R                                    a x  + 2a b x + b
+--R   (2)  -----------------------------------------------
+--R                               a
+--R                                                    Type: Expression(Integer)
+--E 3310
+
+--S 3311 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                              2
+--R                                           c x
+--R        - 2b log(a x + b) + a x log(------------------)
+--R                                     2 2             2
+--R                                    a x  + 2a b x + b
+--R   (3)  -----------------------------------------------
+--R                               a
+--R                                         Type: Union(Expression(Integer),...)
+--E 3311
+
+--S 3312 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 3312
+
+--S 3313 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3313
+
+)clear all
+
+--S 3314 of 5341
+t0:=log(c*x^2/(b+a*x)^2)^2
+--R 
+--R
+--R                      2        2
+--R                   c x
+--R   (1)  log(------------------)
+--R             2 2             2
+--R            a x  + 2a b x + b
+--R                                                    Type: Expression(Integer)
+--E 3314
+
+--S 3315 of 5341
+--r0:=x*log(c*x^2/(b+a*x)^2)^2+4*b*log(c*x^2/(b+a*x)^2)*log(b/(b+a*x))/a+_
+--  8*b*polylog(2,a*x/(b+a*x))/a
+--E 3315
+
+--S 3316 of 5341
+--a0:=integrate(t0,x)
+--E 3316
+
+--S 3317 of 5341
+--m0:=a0-r0
+--E 3317
+
+--S 3318 of 5341
+--d0:=D(m0,x)
+--E 3318
+
+)clear all
+
+--S 3319 of 5341
+t0:=log(c*x^2/(b+a*x)^2)^3
+--R 
+--R
+--R                      2        3
+--R                   c x
+--R   (1)  log(------------------)
+--R             2 2             2
+--R            a x  + 2a b x + b
+--R                                                    Type: Expression(Integer)
+--E 3319
+
+--S 3320 of 5341
+--r0:=x*log(c*x^2/(b+a*x)^2)^3+6*b*log(c*x^2/(b+a*x)^2)^2*log(b/(b+a*x))/a+_
+--  24*b*log(c*x^2/(b+a*x)^2)*polylog(2,a*x/(b+a*x))/a-_
+--  48*b*polylog(3,a*x/(b+a*x))/a
+--E 3320
+
+--S 3321 of 5341
+--a0:=integrate(t0,x)
+--E 3321
+
+--S 3322 of 5341
+--m0:=a0-r0
+--E 3322
+
+--S 3323 of 5341
+--d0:=D(m0,x)
+--E 3323
+
+)clear all
+
+--S 3324 of 5341
+t0:=log(a+b/x)/(d+e*x^2)
+--R 
+--R
+--R            a x + b
+--R        log(-------)
+--R               x
+--R   (1)  ------------
+--R             2
+--R          e x  + d
+--R                                                    Type: Expression(Integer)
+--E 3324
+
+--S 3325 of 5341
+--r0:=atan(x*sqrt(e)/sqrt(d))*log(a+b/x)/(sqrt(d)*sqrt(e))-_
+--  1/2*%i*log(-(b+a*x)*sqrt(e)/(%i*a*sqrt(d)-b*sqrt(e)))*log(1-_
+--  %i*x*sqrt(e)/sqrt(d))/(sqrt(d)*sqrt(e))+1/2*%i*log((b+a*x)*_
+--  sqrt(e)/(%i*a*sqrt(d)+b*sqrt(e)))*log(1+%i*x*sqrt(e)/sqrt(d))/_
+--  (sqrt(d)*sqrt(e))+1/2*%i*polylog(2,-%i*x*sqrt(e)/sqrt(d))/(sqrt(d)*_
+--  sqrt(e))-1/2*%i*polylog(2,%i*x*sqrt(e)/sqrt(d))/(sqrt(d)*sqrt(e))-_
+--  1/2*%i*polylog(2,a*(sqrt(d)-%i*x*sqrt(e))/(a*sqrt(d)+%i*b*sqrt(e)))/_
+--  (sqrt(d)*sqrt(e))+1/2*%i*polylog(2,a*(sqrt(d)+%i*x*sqrt(e))/_
+--  (a*sqrt(d)-%i*b*sqrt(e)))/(sqrt(d)*sqrt(e))
+--E 3325
+
+--S 3326 of 5341
+--a0:=integrate(t0,x)
+--E 3326
+
+--S 3327 of 5341
+--m0:=a0-r0
+--E 3327
+
+--S 3328 of 5341
+--d0:=D(m0,x)
+--E 3328
+
+)clear all
+
+--S 3329 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^4
+--R 
+--R
+--R               b x + a n 4
+--R   (1)  log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3329
+
+--S 3330 of 5341
+--r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^4/b+4*(b*c-a*d)*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)^3*log((b*c-a*d)/(b*(c+d*x)))/(b*d)+_
+--  12*(b*c-a*d)*n^2*log(e*((a+b*x)/(c+d*x))^n)^2*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(b*d)-24*(b*c-a*d)*n^3*log(e*((a+b*x)/(c+d*x))^n)*_
+--  polylog(3,d*(a+b*x)/(b*(c+d*x)))/(b*d)+24*(b*c-a*d)*n^4*_
+--  polylog(4,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 3330
+
+--S 3331 of 5341
+--a0:=integrate(t0,x)
+--E 3331
+
+--S 3332 of 5341
+--m0:=a0-r0
+--E 3332
+
+--S 3333 of 5341
+--d0:=D(m0,x)
+--E 3333
+
+)clear all
+
+--S 3334 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^3
+--R 
+--R
+--R               b x + a n 3
+--R   (1)  log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3334
+
+--S 3335 of 5341
+--r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^3/b+3*(b*c-a*d)*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)^2*log((b*c-a*d)/(b*(c+d*x)))/(b*d)+_
+--  6*(b*c-a*d)*n^2*log(e*((a+b*x)/(c+d*x))^n)*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(b*d)-6*(b*c-a*d)*n^3*polylog(3,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 3335
+
+--S 3336 of 5341
+--a0:=integrate(t0,x)
+--E 3336
+
+--S 3337 of 5341
+--m0:=a0-r0
+--E 3337
+
+--S 3338 of 5341
+--d0:=D(m0,x)
+--E 3338
+
+)clear all
+
+--S 3339 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^2
+--R 
+--R
+--R               b x + a n 2
+--R   (1)  log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3339
+
+--S 3340 of 5341
+--r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^2/b+2*(b*c-a*d)*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)*log((b*c-a*d)/(b*(c+d*x)))/(b*d)+_
+--  2*(b*c-a*d)*n^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 3340
+
+--S 3341 of 5341
+--a0:=integrate(t0,x)
+--E 3341
+
+--S 3342 of 5341
+--m0:=a0-r0
+--E 3342
+
+--S 3343 of 5341
+--d0:=D(m0,x)
+--E 3343
+
+)clear all
+
+--S 3344 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R               b x + a n
+--R   (1)  log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3344
+
+--S 3345 of 5341
+r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)/b-(b*c-a*d)*n*log(c+d*x)/(b*d)
+--R 
+--R
+--R                            b x + a n
+--R        (b d x + a d)log(e (-------) ) + (a d - b c)n log(d x + c)
+--R                            d x + c
+--R   (2)  ----------------------------------------------------------
+--R                                    b d
+--R                                                    Type: Expression(Integer)
+--E 3345
+
+--S 3346 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       - b c n log(d x + c) + a d n log(b x + a) + b d x log(e)
+--R     + 
+--R                   b x + a
+--R       b d n x log(-------)
+--R                   d x + c
+--R  /
+--R     b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3346
+
+--S 3347 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         b x + a n
+--R       (- b x - a)log(e (-------) ) - a n log(d x + c) + a n log(b x + a)
+--R                         d x + c
+--R     + 
+--R                              b x + a
+--R       b x log(e) + b n x log(-------)
+--R                              d x + c
+--R  /
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 3347
+
+--S 3348 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3348
+
+)clear all
+
+--S 3349 of 5341
+t0:=1/log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R               b x + a n
+--R        log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3349
+
+--S 3350 of 5341
+--r0:=Int(1/log(e*((a+b*x)/(c+d*x))^n),x)
+--E 3350
+
+--S 3351 of 5341
+--a0:=integrate(t0,x)
+--E 3351
+
+--S 3352 of 5341
+--m0:=a0-r0
+--E 3352
+
+--S 3353 of 5341
+--d0:=D(m0,x)
+--E 3353
+
+)clear all
+
+--S 3354 of 5341
+t0:=1/log(e*((a+b*x)/(c+d*x))^n)^2
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R               b x + a n 2
+--R        log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3354
+
+--S 3355 of 5341
+--r0:=Int(1/log(e*((a+b*x)/(c+d*x))^n)^2,x)
+--E 3355
+
+--S 3356 of 5341
+--a0:=integrate(t0,x)
+--E 3356
+
+--S 3357 of 5341
+--m0:=a0-r0
+--E 3357
+
+--S 3358 of 5341
+--d0:=D(m0,x)
+--E 3358
+
+)clear all
+
+--S 3359 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^3/x
+--R 
+--R
+--R               b x + a n 3
+--R        log(e (-------) )
+--R               d x + c
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 3359
+
+--S 3360 of 5341
+--r0:=-log(e*((a+b*x)/(c+d*x))^n)^3*log((b*c-a*d)/(b*(c+d*x)))+_
+--  log(e*((a+b*x)/(c+d*x))^n)^3*log(-(b*c-a*d)*x/(a*(c+d*x)))+3*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)^2*polylog(2,c*(a+b*x)/(a*(c+d*x)))-3*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))-6*n^2*_
+--  log(e*((a+b*x)/(c+d*x))^n)*polylog(3,c*(a+b*x)/(a*(c+d*x)))+6*n^2*_
+--  log(e*((a+b*x)/(c+d*x))^n)*polylog(3,d*(a+b*x)/(b*(c+d*x)))+6*n^3*_
+--  polylog(4,c*(a+b*x)/(a*(c+d*x)))-6*n^3*polylog(4,d*(a+b*x)/(b*(c+d*x)))
+--E 3360
+
+--S 3361 of 5341
+--a0:=integrate(t0,x)
+--E 3361
+
+--S 3362 of 5341
+--m0:=a0-r0
+--E 3362
+
+--S 3363 of 5341
+--d0:=D(m0,x)
+--E 3363
+
+)clear all
+
+--S 3364 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^2/x
+--R 
+--R
+--R               b x + a n 2
+--R        log(e (-------) )
+--R               d x + c
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 3364
+
+--S 3365 of 5341
+--r0:=-log(e*((a+b*x)/(c+d*x))^n)^2*log((b*c-a*d)/(b*(c+d*x)))+_
+--  log(e*((a+b*x)/(c+d*x))^n)^2*log(-(b*c-a*d)*x/(a*(c+d*x)))+2*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)*polylog(2,c*(a+b*x)/(a*(c+d*x)))-2*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)*polylog(2,d*(a+b*x)/(b*(c+d*x)))-2*n^2*_
+--  polylog(3,c*(a+b*x)/(a*(c+d*x)))+2*n^2*polylog(3,d*(a+b*x)/(b*(c+d*x)))
+--E 3365
+
+--S 3366 of 5341
+--a0:=integrate(t0,x)
+--E 3366
+
+--S 3367 of 5341
+--m0:=a0-r0
+--E 3367
+
+--S 3368 of 5341
+--d0:=D(m0,x)
+--E 3368
+
+)clear all
+
+--S 3369 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)/x
+--R 
+--R
+--R               b x + a n
+--R        log(e (-------) )
+--R               d x + c
+--R   (1)  -----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 3369
+
+--S 3370 of 5341
+--r0:=-n*log(x)*log((a+b*x)/a)+log(x)*log(e*((a+b*x)/(c+d*x))^n)+_
+--  n*log(x)*log((c+d*x)/c)-n*polylog(2,-b*x/a)+n*polylog(2,-d*x/c)
+--E 3370
+
+--S 3371 of 5341
+--a0:=integrate(t0,x)
+--E 3371
+
+--S 3372 of 5341
+--m0:=a0-r0
+--E 3372
+
+--S 3373 of 5341
+--d0:=D(m0,x)
+--E 3373
+
+)clear all
+
+--S 3374 of 5341
+t0:=1/(x*log(e*((a+b*x)/(c+d*x))^n))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R                 b x + a n
+--R        x log(e (-------) )
+--R                 d x + c
+--R                                                    Type: Expression(Integer)
+--E 3374
+
+--S 3375 of 5341
+--r0:=Int(1/(x*log(e*((a+b*x)/(c+d*x))^n)),x)
+--E 3375
+
+--S 3376 of 5341
+--a0:=integrate(t0,x)
+--E 3376
+
+--S 3377 of 5341
+--m0:=a0-r0
+--E 3377
+
+--S 3378 of 5341
+--d0:=D(m0,x)
+--E 3378
+
+)clear all
+
+--S 3379 of 5341
+t0:=1/(x*log(e*((a+b*x)/(c+d*x))^n)^2)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                 b x + a n 2
+--R        x log(e (-------) )
+--R                 d x + c
+--R                                                    Type: Expression(Integer)
+--E 3379
+
+--S 3380 of 5341
+--r0:=Int(1/(x*log(e*((a+b*x)/(c+d*x))^n)^2),x)
+--E 3380
+
+--S 3381 of 5341
+--a0:=integrate(t0,x)
+--E 3381
+
+--S 3382 of 5341
+--m0:=a0-r0
+--E 3382
+
+--S 3383 of 5341
+--d0:=D(m0,x)
+--E 3383
+
+)clear all
+
+--S 3384 of 5341
+t0:=(c+d*x)^3*log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R          3 3       2 2     2       3        b x + a n
+--R   (1)  (d x  + 3c d x  + 3c d x + c )log(e (-------) )
+--R                                             d x + c
+--R                                                    Type: Expression(Integer)
+--E 3384
+
+--S 3385 of 5341
+r0:=-1/4*(b*c-a*d)^3*n*x/b^3-1/8*(b*c-a*d)^2*n*(c+d*x)^2/(b^2*d)-_
+   1/12*(b*c-a*d)*n*(c+d*x)^3/(b*d)-1/4*(b*c-a*d)^4*n*log(a+b*x)/(b^4*d)+_
+   1/4*(c+d*x)^4*log(e*((a+b*x)/(c+d*x))^n)/d
+--R 
+--R
+--R   (2)
+--R          4 4 4      4   3 3      4 2 2 2      4 3        4 4        b x + a n
+--R       (6b d x  + 24b c d x  + 36b c d x  + 24b c d x + 6b c )log(e (-------) )
+--R                                                                     d x + c
+--R     + 
+--R            4 4      3     3      2 2 2 2        3 3      4 4
+--R       (- 6a d  + 24a b c d  - 36a b c d  + 24a b c d - 6b c )n log(b x + a)
+--R     + 
+--R            3 4     4   3    3        2 2 4        3   3     4 2 2    2
+--R       (2a b d  - 2b c d )n x  + (- 3a b d  + 12a b c d  - 9b c d )n x
+--R     + 
+--R          3   4      2 2   3        3 2 2      4 3
+--R       (6a b d  - 24a b c d  + 36a b c d  - 18b c d)n x
+--R     + 
+--R            2 2 2 2       3 3      4 4
+--R       (- 3a b c d  + 8a b c d - 5b c )n
+--R  /
+--R        4
+--R     24b d
+--R                                                    Type: Expression(Integer)
+--E 3385
+
+--S 3386 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           4 4
+--R       - 6b c n log(d x + c)
+--R     + 
+--R            4 4      3     3      2 2 2 2        3 3
+--R       (- 6a d  + 24a b c d  - 36a b c d  + 24a b c d)n log(b x + a)
+--R     + 
+--R          4 4 4      4   3 3      4 2 2 2      4 3
+--R       (6b d x  + 24b c d x  + 36b c d x  + 24b c d x)log(e)
+--R     + 
+--R          4 4   4      4   3   3      4 2 2   2      4 3          b x + a
+--R       (6b d n x  + 24b c d n x  + 36b c d n x  + 24b c d n x)log(-------)
+--R                                                                  d x + c
+--R     + 
+--R            3 4     4   3    3        2 2 4        3   3     4 2 2    2
+--R       (2a b d  - 2b c d )n x  + (- 3a b d  + 12a b c d  - 9b c d )n x
+--R     + 
+--R          3   4      2 2   3        3 2 2      4 3
+--R       (6a b d  - 24a b c d  + 36a b c d  - 18b c d)n x
+--R  /
+--R        4
+--R     24b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3386
+
+--S 3387 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              2 4 4      2   3 3      2 2 2 2      2 3        2 4
+--R         (- 6b d x  - 24b c d x  - 36b c d x  - 24b c d x - 6b c )
+--R      *
+--R                b x + a n
+--R         log(e (-------) )
+--R                d x + c
+--R     + 
+--R           2 4                   2 4
+--R       - 6b c n log(d x + c) + 6b c n log(b x + a)
+--R     + 
+--R          2 4 4      2   3 3      2 2 2 2      2 3
+--R       (6b d x  + 24b c d x  + 36b c d x  + 24b c d x)log(e)
+--R     + 
+--R          2 4   4      2   3   3      2 2 2   2      2 3          b x + a
+--R       (6b d n x  + 24b c d n x  + 36b c d n x  + 24b c d n x)log(-------)
+--R                                                                  d x + c
+--R     + 
+--R          2 2 2         3      2 4
+--R       (3a c d  - 8a b c d + 5b c )n
+--R  /
+--R        2
+--R     24b d
+--R                                                    Type: Expression(Integer)
+--E 3387
+
+--S 3388 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3388
+
+)clear all
+
+--S 3389 of 5341
+t0:=(c+d*x)^2*log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R          2 2             2        b x + a n
+--R   (1)  (d x  + 2c d x + c )log(e (-------) )
+--R                                   d x + c
+--R                                                    Type: Expression(Integer)
+--E 3389
+
+--S 3390 of 5341
+r0:=-1/3*(b*c-a*d)^2*n*x/b^2-1/6*(b*c-a*d)*n*(c+d*x)^2/(b*d)-_
+   1/3*(b*c-a*d)^3*n*log(a+b*x)/(b^3*d)+1/3*(c+d*x)^3*_
+   log(e*((a+b*x)/(c+d*x))^n)/d
+--R 
+--R
+--R   (2)
+--R          3 3 3     3   2 2     3 2        3 3        b x + a n
+--R       (2b d x  + 6b c d x  + 6b c d x + 2b c )log(e (-------) )
+--R                                                      d x + c
+--R     + 
+--R          3 3     2     2       2 2      3 3
+--R       (2a d  - 6a b c d  + 6a b c d - 2b c )n log(b x + a)
+--R     + 
+--R           2 3    3   2    2        2   3       2   2     3 2
+--R       (a b d  - b c d )n x  + (- 2a b d  + 6a b c d  - 4b c d)n x
+--R     + 
+--R           2 2     3 3
+--R       (a b c d - b c )n
+--R  /
+--R       3
+--R     6b d
+--R                                                    Type: Expression(Integer)
+--E 3390
+
+--S 3391 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3 3                    3 3     2     2       2 2
+--R       - 2b c n log(d x + c) + (2a d  - 6a b c d  + 6a b c d)n log(b x + a)
+--R     + 
+--R          3 3 3     3   2 2     3 2
+--R       (2b d x  + 6b c d x  + 6b c d x)log(e)
+--R     + 
+--R          3 3   3     3   2   2     3 2          b x + a
+--R       (2b d n x  + 6b c d n x  + 6b c d n x)log(-------)
+--R                                                 d x + c
+--R     + 
+--R           2 3    3   2    2        2   3       2   2     3 2
+--R       (a b d  - b c d )n x  + (- 2a b d  + 6a b c d  - 4b c d)n x
+--R  /
+--R       3
+--R     6b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3391
+
+--S 3392 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              3 3         2 2       2          3        b x + a n
+--R       (- 2b d x  - 6b c d x  - 6b c d x - 2b c )log(e (-------) )
+--R                                                        d x + c
+--R     + 
+--R             3                     3
+--R       - 2b c n log(d x + c) + 2b c n log(b x + a)
+--R     + 
+--R            3 3         2 2       2
+--R       (2b d x  + 6b c d x  + 6b c d x)log(e)
+--R     + 
+--R            3   3         2   2       2          b x + a          2       3
+--R       (2b d n x  + 6b c d n x  + 6b c d n x)log(-------) + (- a c d + b c )n
+--R                                                 d x + c
+--R  /
+--R     6b d
+--R                                                    Type: Expression(Integer)
+--E 3392
+
+--S 3393 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3393
+
+)clear all
+
+--S 3394 of 5341
+t0:=(c+d*x)*log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R                        b x + a n
+--R   (1)  (d x + c)log(e (-------) )
+--R                        d x + c
+--R                                                    Type: Expression(Integer)
+--E 3394
+
+--S 3395 of 5341
+r0:=-1/2*(b*c-a*d)*n*x/b-1/2*(b*c-a*d)^2*n*log(a+b*x)/(b^2*d)+1/2*(c+d*x)^2*_
+   log(e*((a+b*x)/(c+d*x))^n)/d
+--R 
+--R
+--R   (2)
+--R         2 2 2     2         2 2        b x + a n
+--R       (b d x  + 2b c d x + b c )log(e (-------) )
+--R                                        d x + c
+--R     + 
+--R           2 2               2 2                        2    2
+--R       (- a d  + 2a b c d - b c )n log(b x + a) + (a b d  - b c d)n x
+--R  /
+--R       2
+--R     2b d
+--R                                                    Type: Expression(Integer)
+--E 3395
+
+--S 3396 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          2 2                     2 2
+--R       - b c n log(d x + c) + (- a d  + 2a b c d)n log(b x + a)
+--R     + 
+--R         2 2 2     2                 2 2   2     2            b x + a
+--R       (b d x  + 2b c d x)log(e) + (b d n x  + 2b c d n x)log(-------)
+--R                                                              d x + c
+--R     + 
+--R             2    2
+--R       (a b d  - b c d)n x
+--R  /
+--R       2
+--R     2b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3396
+
+--S 3397 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2 2             2        b x + a n     2
+--R       (- d x  - 2c d x - c )log(e (-------) ) - c n log(d x + c)
+--R                                    d x + c
+--R     + 
+--R      2                   2 2                     2   2                b x + a
+--R     c n log(b x + a) + (d x  + 2c d x)log(e) + (d n x  + 2c d n x)log(-------)
+--R                                                                       d x + c
+--R  /
+--R     2d
+--R                                                    Type: Expression(Integer)
+--E 3397
+
+--S 3398 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3398
+
+)clear all
+
+--S 3399 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R               b x + a n
+--R   (1)  log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3399
+
+--S 3400 of 5341
+r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)/b-(b*c-a*d)*n*log(c+d*x)/(b*d)
+--R 
+--R
+--R                            b x + a n
+--R        (b d x + a d)log(e (-------) ) + (a d - b c)n log(d x + c)
+--R                            d x + c
+--R   (2)  ----------------------------------------------------------
+--R                                    b d
+--R                                                    Type: Expression(Integer)
+--E 3400
+
+--S 3401 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       - b c n log(d x + c) + a d n log(b x + a) + b d x log(e)
+--R     + 
+--R                   b x + a
+--R       b d n x log(-------)
+--R                   d x + c
+--R  /
+--R     b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3401
+
+--S 3402 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         b x + a n
+--R       (- b x - a)log(e (-------) ) - a n log(d x + c) + a n log(b x + a)
+--R                         d x + c
+--R     + 
+--R                              b x + a
+--R       b x log(e) + b n x log(-------)
+--R                              d x + c
+--R  /
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 3402
+
+--S 3403 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3403
+
+)clear all
+
+--S 3404 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)/(c+d*x)
+--R 
+--R
+--R               b x + a n
+--R        log(e (-------) )
+--R               d x + c
+--R   (1)  -----------------
+--R             d x + c
+--R                                                    Type: Expression(Integer)
+--E 3404
+
+--S 3405 of 5341
+--r0:=-log(e*((a+b*x)/(c+d*x))^n)*log((b*c-a*d)/(b*(c+d*x)))/d-_
+--  n*polylog(2,d*(a+b*x)/(b*(c+d*x)))/d
+--E 3405
+
+--S 3406 of 5341
+--a0:=integrate(t0,x)
+--E 3406
+
+--S 3407 of 5341
+--m0:=a0-r0
+--E 3407
+
+--S 3408 of 5341
+--d0:=D(m0,x)
+--E 3408
+
+)clear all
+
+--S 3409 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)/(c+d*x)^2
+--R 
+--R
+--R                b x + a n
+--R         log(e (-------) )
+--R                d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 3409
+
+--S 3410 of 5341
+r0:=n/(d*(c+d*x))+(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)/((b*c-a*d)*(c+d*x))
+--R 
+--R
+--R                              b x + a n
+--R        (- b d x - a d)log(e (-------) ) + (a d - b c)n
+--R                              d x + c
+--R   (2)  -----------------------------------------------
+--R                   3        2          2      2
+--R               (a d  - b c d )x + a c d  - b c d
+--R                                                    Type: Expression(Integer)
+--E 3410
+
+--S 3411 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                     b x + a
+--R        (- a d + b c)log(e) + (- b d n x - a d n)log(-------) + (a d - b c)n
+--R                                                     d x + c
+--R   (3)  --------------------------------------------------------------------
+--R                              3        2          2      2
+--R                          (a d  - b c d )x + a c d  - b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3411
+
+--S 3412 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           b x + a n
+--R       (b d x + a d)log(e (-------) ) + (- a d + b c)log(e)
+--R                           d x + c
+--R     + 
+--R                              b x + a
+--R       (- b d n x - a d n)log(-------)
+--R                              d x + c
+--R  /
+--R         3        2          2      2
+--R     (a d  - b c d )x + a c d  - b c d
+--R                                                    Type: Expression(Integer)
+--E 3412
+
+--S 3413 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3413
+
+)clear all
+
+--S 3414 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)/(c+d*x)^3
+--R 
+--R
+--R                     b x + a n
+--R              log(e (-------) )
+--R                     d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 3414
+
+--S 3415 of 5341
+r0:=1/4*n/(d*(c+d*x)^2)+1/2*b*n/(d*(b*c-a*d)*(c+d*x))+1/2*b^2*n*log(a+b*x)/_
+   (d*(b*c-a*d)^2)-1/2*log(e*((a+b*x)/(c+d*x))^n)/(d*(c+d*x)^2)-_
+   1/2*b^2*n*log(c+d*x)/(d*(b*c-a*d)^2)
+--R 
+--R
+--R   (2)
+--R            2 2                2 2        b x + a n
+--R       (- 2a d  + 4a b c d - 2b c )log(e (-------) )
+--R                                          d x + c
+--R     + 
+--R            2 2   2     2            2 2
+--R       (- 2b d n x  - 4b c d n x - 2b c n)log(d x + c)
+--R     + 
+--R          2 2   2     2            2 2                          2     2
+--R       (2b d n x  + 4b c d n x + 2b c n)log(b x + a) + (- 2a b d  + 2b c d)n x
+--R     + 
+--R         2 2                2 2
+--R       (a d  - 4a b c d + 3b c )n
+--R  /
+--R          2 5           4     2 2 3  2      2   4          2 3     2 3 2
+--R       (4a d  - 8a b c d  + 4b c d )x  + (8a c d  - 16a b c d  + 8b c d )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       4a c d  - 8a b c d  + 4b c d
+--R                                                    Type: Expression(Integer)
+--E 3415
+
+--S 3416 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            2 2                2 2
+--R       (- 2a d  + 4a b c d - 2b c )log(e)
+--R     + 
+--R          2 2   2     2               2 2                  b x + a
+--R       (2b d n x  + 4b c d n x + (- 2a d  + 4a b c d)n)log(-------)
+--R                                                           d x + c
+--R     + 
+--R                2     2            2 2                2 2
+--R       (- 2a b d  + 2b c d)n x + (a d  - 4a b c d + 3b c )n
+--R  /
+--R          2 5           4     2 2 3  2      2   4          2 3     2 3 2
+--R       (4a d  - 8a b c d  + 4b c d )x  + (8a c d  - 16a b c d  + 8b c d )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       4a c d  - 8a b c d  + 4b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3416
+
+--S 3417 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         2 2               2 2        b x + a n
+--R       (a d  - 2a b c d + b c )log(e (-------) )
+--R                                      d x + c
+--R     + 
+--R         2 2   2     2           2 2
+--R       (b d n x  + 2b c d n x + b c n)log(d x + c)
+--R     + 
+--R           2 2   2     2           2 2
+--R       (- b d n x  - 2b c d n x - b c n)log(b x + a)
+--R     + 
+--R           2 2               2 2
+--R       (- a d  + 2a b c d - b c )log(e)
+--R     + 
+--R         2 2   2     2              2 2                  b x + a
+--R       (b d n x  + 2b c d n x + (- a d  + 2a b c d)n)log(-------)
+--R                                                         d x + c
+--R  /
+--R          2 5           4     2 2 3  2      2   4         2 3     2 3 2
+--R       (2a d  - 4a b c d  + 2b c d )x  + (4a c d  - 8a b c d  + 4b c d )x
+--R     + 
+--R         2 2 3         3 2     2 4
+--R       2a c d  - 4a b c d  + 2b c d
+--R                                                    Type: Expression(Integer)
+--E 3417
+
+--S 3418 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3418
+
+)clear all
+
+--S 3419 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)/(c+d*x)^4
+--R 
+--R
+--R                          b x + a n
+--R                   log(e (-------) )
+--R                          d x + c
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        d x  + 4c d x  + 6c d x  + 4c d x + c
+--R                                                    Type: Expression(Integer)
+--E 3419
+
+--S 3420 of 5341
+r0:=1/9*n/(d*(c+d*x)^3)+1/6*b*n/(d*(b*c-a*d)*(c+d*x)^2)+1/3*b^2*n/_
+   (d*(b*c-a*d)^2*(c+d*x))+1/3*b^3*n*log(a+b*x)/(d*(b*c-a*d)^3)-_
+   1/3*log(e*((a+b*x)/(c+d*x))^n)/(d*(c+d*x)^3)-1/3*b^3*n*log(c+d*x)/_
+   (d*(b*c-a*d)^3)
+--R 
+--R
+--R   (2)
+--R            3 3      2     2        2 2      3 3        b x + a n
+--R       (- 6a d  + 18a b c d  - 18a b c d + 6b c )log(e (-------) )
+--R                                                        d x + c
+--R     + 
+--R          3 3   3      3   2   2      3 2          3 3
+--R       (6b d n x  + 18b c d n x  + 18b c d n x + 6b c n)log(d x + c)
+--R     + 
+--R            3 3   3      3   2   2      3 2          3 3
+--R       (- 6b d n x  - 18b c d n x  - 18b c d n x - 6b c n)log(b x + a)
+--R     + 
+--R            2 3     3   2    2        2   3        2   2      3 2
+--R       (6a b d  - 6b c d )n x  + (- 3a b d  + 18a b c d  - 15b c d)n x
+--R     + 
+--R          3 3     2     2        2 2       3 3
+--R       (2a d  - 9a b c d  + 18a b c d - 11b c )n
+--R  /
+--R           3 7      2     6        2 2 5      3 3 4  3
+--R       (18a d  - 54a b c d  + 54a b c d  - 18b c d )x
+--R     + 
+--R           3   6       2   2 5         2 3 4      3 4 3  2
+--R       (54a c d  - 162a b c d  + 162a b c d  - 54b c d )x
+--R     + 
+--R           3 2 5       2   3 4         2 4 3      3 5 2        3 3 4
+--R       (54a c d  - 162a b c d  + 162a b c d  - 54b c d )x + 18a c d
+--R     + 
+--R            2   4 3        2 5 2      3 6
+--R       - 54a b c d  + 54a b c d  - 18b c d
+--R                                                    Type: Expression(Integer)
+--E 3420
+
+--S 3421 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 3      2     2        2 2      3 3
+--R       (- 6a d  + 18a b c d  - 18a b c d + 6b c )log(e)
+--R     + 
+--R               3 3   3      3   2   2      3 2
+--R           - 6b d n x  - 18b c d n x  - 18b c d n x
+--R         + 
+--R                3 3      2     2        2 2
+--R           (- 6a d  + 18a b c d  - 18a b c d)n
+--R      *
+--R             b x + a
+--R         log(-------)
+--R             d x + c
+--R     + 
+--R            2 3     3   2    2        2   3        2   2      3 2
+--R       (6a b d  - 6b c d )n x  + (- 3a b d  + 18a b c d  - 15b c d)n x
+--R     + 
+--R          3 3     2     2        2 2       3 3
+--R       (2a d  - 9a b c d  + 18a b c d - 11b c )n
+--R  /
+--R           3 7      2     6        2 2 5      3 3 4  3
+--R       (18a d  - 54a b c d  + 54a b c d  - 18b c d )x
+--R     + 
+--R           3   6       2   2 5         2 3 4      3 4 3  2
+--R       (54a c d  - 162a b c d  + 162a b c d  - 54b c d )x
+--R     + 
+--R           3 2 5       2   3 4         2 4 3      3 5 2        3 3 4
+--R       (54a c d  - 162a b c d  + 162a b c d  - 54b c d )x + 18a c d
+--R     + 
+--R            2   4 3        2 5 2      3 6
+--R       - 54a b c d  + 54a b c d  - 18b c d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3421
+
+--S 3422 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         3 3     2     2       2 2     3 3        b x + a n
+--R       (a d  - 3a b c d  + 3a b c d - b c )log(e (-------) )
+--R                                                  d x + c
+--R     + 
+--R           3 3   3     3   2   2     3 2         3 3
+--R       (- b d n x  - 3b c d n x  - 3b c d n x - b c n)log(d x + c)
+--R     + 
+--R         3 3   3     3   2   2     3 2         3 3
+--R       (b d n x  + 3b c d n x  + 3b c d n x + b c n)log(b x + a)
+--R     + 
+--R           3 3     2     2       2 2     3 3
+--R       (- a d  + 3a b c d  - 3a b c d + b c )log(e)
+--R     + 
+--R              3 3   3     3   2   2     3 2
+--R           - b d n x  - 3b c d n x  - 3b c d n x
+--R         + 
+--R               3 3     2     2       2 2
+--R           (- a d  + 3a b c d  - 3a b c d)n
+--R      *
+--R             b x + a
+--R         log(-------)
+--R             d x + c
+--R  /
+--R          3 7     2     6       2 2 5     3 3 4  3
+--R       (3a d  - 9a b c d  + 9a b c d  - 3b c d )x
+--R     + 
+--R          3   6      2   2 5        2 3 4     3 4 3  2
+--R       (9a c d  - 27a b c d  + 27a b c d  - 9b c d )x
+--R     + 
+--R          3 2 5      2   3 4        2 4 3     3 5 2       3 3 4     2   4 3
+--R       (9a c d  - 27a b c d  + 27a b c d  - 9b c d )x + 3a c d  - 9a b c d
+--R     + 
+--R           2 5 2     3 6
+--R       9a b c d  - 3b c d
+--R                                                    Type: Expression(Integer)
+--E 3422
+
+--S 3423 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3423
+
+)clear all
+
+--S 3424 of 5341
+t0:=(f+g*x)^3*log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R          3 3       2 2     2       3        b x + a n
+--R   (1)  (g x  + 3f g x  + 3f g x + f )log(e (-------) )
+--R                                             d x + c
+--R                                                    Type: Expression(Integer)
+--E 3424
+
+--S 3425 of 5341
+r0:=-1/4*(b*c-a*d)*g*(a^2*d^2*g^2-a*b*d*g*(4*d*f-c*g)+b^2*(6*d^2*f^2-_
+   4*c*d*f*g+c^2*g^2))*n*x/(b^3*d^3)-1/8*(b*c-a*d)*g^2*(4*b*d*f-b*c*g-_
+   a*d*g)*n*x^2/(b^2*d^2)-1/12*(b*c-a*d)*g^3*n*x^3/(b*d)-1/4*(b*f-a*g)^4*_
+   n*log(a+b*x)/(b^4*g)+1/4*(f+g*x)^4*log(e*((a+b*x)/(c+d*x))^n)/g+_
+   1/4*(d*f-c*g)^4*n*log(c+d*x)/(d^4*g)
+--R 
+--R
+--R   (2)
+--R            4 4 4 4      4 4   3 3      4 4 2 2 2      4 4 3        4 4 4
+--R         (6b d g x  + 24b d f g x  + 36b d f g x  + 24b d f g x + 6b d f )
+--R      *
+--R                b x + a n
+--R         log(e (-------) )
+--R                d x + c
+--R     + 
+--R            4 4 4      4 3     3      4 2 2 2 2      4   3 3      4 4 4
+--R         (6b c g  - 24b c d f g  + 36b c d f g  - 24b c d f g + 6b d f )n
+--R      *
+--R         log(d x + c)
+--R     + 
+--R              4 4 4      3   4   3      2 2 4 2 2        3 4 3      4 4 4
+--R         (- 6a d g  + 24a b d f g  - 36a b d f g  + 24a b d f g - 6b d f )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R            3 4     4   3  4   3
+--R       (2a b d  - 2b c d )g n x
+--R     + 
+--R             2 2 4     4 2 2  4         3 4      4   3    3    2
+--R       ((- 3a b d  + 3b c d )g  + (12a b d  - 12b c d )f g )n x
+--R     + 
+--R              3   4     4 3   4         2 2 4      4 2 2    3
+--R           (6a b d  - 6b c d)g  + (- 24a b d  + 24b c d )f g
+--R         + 
+--R                 3 4      4   3  2 2
+--R           (36a b d  - 36b c d )f g
+--R      *
+--R         n x
+--R  /
+--R        4 4
+--R     24b d g
+--R                                                    Type: Expression(Integer)
+--E 3425
+
+--S 3426 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          4 4 3      4 3     2      4 2 2 2       4   3 3
+--R       (6b c g  - 24b c d f g  + 36b c d f g - 24b c d f )n log(d x + c)
+--R     + 
+--R            4 4 3      3   4   2      2 2 4 2         3 4 3
+--R       (- 6a d g  + 24a b d f g  - 36a b d f g + 24a b d f )n log(b x + a)
+--R     + 
+--R          4 4 3 4      4 4   2 3      4 4 2   2      4 4 3
+--R       (6b d g x  + 24b d f g x  + 36b d f g x  + 24b d f x)log(e)
+--R     + 
+--R          4 4 3   4      4 4   2   3      4 4 2     2      4 4 3        b x + a
+--R       (6b d g n x  + 24b d f g n x  + 36b d f g n x  + 24b d f n x)log(-------)
+--R                                                                        d x + c
+--R     + 
+--R            3 4     4   3  3   3
+--R       (2a b d  - 2b c d )g n x
+--R     + 
+--R             2 2 4     4 2 2  3         3 4      4   3    2    2
+--R       ((- 3a b d  + 3b c d )g  + (12a b d  - 12b c d )f g )n x
+--R     + 
+--R              3   4     4 3   3         2 2 4      4 2 2    2
+--R           (6a b d  - 6b c d)g  + (- 24a b d  + 24b c d )f g
+--R         + 
+--R                 3 4      4   3  2
+--R           (36a b d  - 36b c d )f g
+--R      *
+--R         n x
+--R  /
+--R        4 4
+--R     24b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3426
+
+--S 3427 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           4 4       3 3     2 2 2     3       4        b x + a n
+--R       (- g x  - 4f g x  - 6f g x  - 4f g x - f )log(e (-------) )
+--R                                                        d x + c
+--R     + 
+--R          4                  4
+--R       - f n log(d x + c) + f n log(b x + a)
+--R     + 
+--R         4 4       3 3     2 2 2     3
+--R       (g x  + 4f g x  + 6f g x  + 4f g x)log(e)
+--R     + 
+--R         4   4       3   3     2 2   2     3          b x + a
+--R       (g n x  + 4f g n x  + 6f g n x  + 4f g n x)log(-------)
+--R                                                      d x + c
+--R  /
+--R     4g
+--R                                                    Type: Expression(Integer)
+--E 3427
+
+--S 3428 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3428
+
+)clear all
+
+--S 3429 of 5341
+t0:=(f+g*x)^2*log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R          2 2             2        b x + a n
+--R   (1)  (g x  + 2f g x + f )log(e (-------) )
+--R                                   d x + c
+--R                                                    Type: Expression(Integer)
+--E 3429
+
+--S 3430 of 5341
+r0:=-1/3*(b*c-a*d)*g*(3*b*d*f-b*c*g-a*d*g)*n*x/(b^2*d^2)-1/6*(b*c-a*d)*_
+   g^2*n*x^2/(b*d)-1/3*(b*f-a*g)^3*n*log(a+b*x)/(b^3*g)+1/3*(f+g*x)^3*_
+   log(e*((a+b*x)/(c+d*x))^n)/g+1/3*(d*f-c*g)^3*n*log(c+d*x)/(d^3*g)
+--R 
+--R
+--R   (2)
+--R          3 3 3 3     3 3   2 2     3 3 2        3 3 3        b x + a n
+--R       (2b d g x  + 6b d f g x  + 6b d f g x + 2b d f )log(e (-------) )
+--R                                                              d x + c
+--R     + 
+--R            3 3 3     3 2     2     3   2 2      3 3 3
+--R       (- 2b c g  + 6b c d f g  - 6b c d f g + 2b d f )n log(d x + c)
+--R     + 
+--R          3 3 3     2   3   2       2 3 2      3 3 3
+--R       (2a d g  - 6a b d f g  + 6a b d f g - 2b d f )n log(b x + a)
+--R     + 
+--R           2 3    3   2  3   2
+--R       (a b d  - b c d )g n x
+--R     + 
+--R             2   3     3 2   3        2 3     3   2    2
+--R       ((- 2a b d  + 2b c d)g  + (6a b d  - 6b c d )f g )n x
+--R  /
+--R       3 3
+--R     6b d g
+--R                                                    Type: Expression(Integer)
+--E 3430
+
+--S 3431 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            3 3 2     3 2          3   2 2
+--R       (- 2b c g  + 6b c d f g - 6b c d f )n log(d x + c)
+--R     + 
+--R          3 3 2     2   3          2 3 2
+--R       (2a d g  - 6a b d f g + 6a b d f )n log(b x + a)
+--R     + 
+--R          3 3 2 3     3 3     2     3 3 2
+--R       (2b d g x  + 6b d f g x  + 6b d f x)log(e)
+--R     + 
+--R          3 3 2   3     3 3       2     3 3 2        b x + a
+--R       (2b d g n x  + 6b d f g n x  + 6b d f n x)log(-------)
+--R                                                     d x + c
+--R     + 
+--R           2 3    3   2  2   2
+--R       (a b d  - b c d )g n x
+--R     + 
+--R             2   3     3 2   2        2 3     3   2
+--R       ((- 2a b d  + 2b c d)g  + (6a b d  - 6b c d )f g)n x
+--R  /
+--R       3 3
+--R     6b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3431
+
+--S 3432 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3 3       2 2     2       3        b x + a n     3
+--R       (- g x  - 3f g x  - 3f g x - f )log(e (-------) ) - f n log(d x + c)
+--R                                              d x + c
+--R     + 
+--R        3                   3 3       2 2     2
+--R       f n log(b x + a) + (g x  + 3f g x  + 3f g x)log(e)
+--R     + 
+--R         3   3       2   2     2          b x + a
+--R       (g n x  + 3f g n x  + 3f g n x)log(-------)
+--R                                          d x + c
+--R  /
+--R     3g
+--R                                                    Type: Expression(Integer)
+--E 3432
+
+--S 3433 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3433
+
+)clear all
+
+--S 3434 of 5341
+t0:=(f+g*x)*log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R                        b x + a n
+--R   (1)  (g x + f)log(e (-------) )
+--R                        d x + c
+--R                                                    Type: Expression(Integer)
+--E 3434
+
+--S 3435 of 5341
+r0:=-1/2*(b*c-a*d)*g*n*x/(b*d)-1/2*(b*f-a*g)^2*n*log(a+b*x)/(b^2*g)+_
+   1/2*(f+g*x)^2*log(e*((a+b*x)/(c+d*x))^n)/g+1/2*(d*f-c*g)^2*n*_
+   log(c+d*x)/(d^2*g)
+--R 
+--R
+--R   (2)
+--R         2 2 2 2     2 2         2 2 2        b x + a n
+--R       (b d g x  + 2b d f g x + b d f )log(e (-------) )
+--R                                              d x + c
+--R     + 
+--R         2 2 2     2           2 2 2
+--R       (b c g  - 2b c d f g + b d f )n log(d x + c)
+--R     + 
+--R           2 2 2         2       2 2 2                        2    2     2
+--R       (- a d g  + 2a b d f g - b d f )n log(b x + a) + (a b d  - b c d)g n x
+--R  /
+--R       2 2
+--R     2b d g
+--R                                                    Type: Expression(Integer)
+--E 3435
+
+--S 3436 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2 2      2                           2 2          2
+--R       (b c g - 2b c d f)n log(d x + c) + (- a d g + 2a b d f)n log(b x + a)
+--R     + 
+--R         2 2   2     2 2               2 2     2     2 2          b x + a
+--R       (b d g x  + 2b d f x)log(e) + (b d g n x  + 2b d f n x)log(-------)
+--R                                                                  d x + c
+--R     + 
+--R             2    2
+--R       (a b d  - b c d)g n x
+--R  /
+--R       2 2
+--R     2b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3436
+
+--S 3437 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2 2             2        b x + a n     2
+--R       (- g x  - 2f g x - f )log(e (-------) ) - f n log(d x + c)
+--R                                    d x + c
+--R     + 
+--R      2                   2 2                     2   2                b x + a
+--R     f n log(b x + a) + (g x  + 2f g x)log(e) + (g n x  + 2f g n x)log(-------)
+--R                                                                       d x + c
+--R  /
+--R     2g
+--R                                                    Type: Expression(Integer)
+--E 3437
+
+--S 3438 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3438
+
+)clear all
+
+--S 3439 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R               b x + a n
+--R   (1)  log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3439
+
+--S 3440 of 5341
+r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)/b-(b*c-a*d)*n*log(c+d*x)/(b*d)
+--R 
+--R
+--R                            b x + a n
+--R        (b d x + a d)log(e (-------) ) + (a d - b c)n log(d x + c)
+--R                            d x + c
+--R   (2)  ----------------------------------------------------------
+--R                                    b d
+--R                                                    Type: Expression(Integer)
+--E 3440
+
+--S 3441 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       - b c n log(d x + c) + a d n log(b x + a) + b d x log(e)
+--R     + 
+--R                   b x + a
+--R       b d n x log(-------)
+--R                   d x + c
+--R  /
+--R     b d
+--R                                         Type: Union(Expression(Integer),...)
+--E 3441
+
+--S 3442 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         b x + a n
+--R       (- b x - a)log(e (-------) ) - a n log(d x + c) + a n log(b x + a)
+--R                         d x + c
+--R     + 
+--R                              b x + a
+--R       b x log(e) + b n x log(-------)
+--R                              d x + c
+--R  /
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 3442
+
+--S 3443 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3443
+
+)clear all
+
+--S 3444 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)/(f+g*x)
+--R 
+--R
+--R               b x + a n
+--R        log(e (-------) )
+--R               d x + c
+--R   (1)  -----------------
+--R             g x + f
+--R                                                    Type: Expression(Integer)
+--E 3444
+
+--S 3445 of 5341
+--r0:=-n*log(-g*(a+b*x)/(b*f-a*g))*log(f+g*x)/g+log(e*((a+b*x)/(c+d*x))^n)*_
+--  log(f+g*x)/g+n*log(-g*(c+d*x)/(d*f-c*g))*log(f+g*x)/g-_
+--  n*polylog(2,b*(f+g*x)/(b*f-a*g))/g+n*polylog(2,d*(f+g*x)/(d*f-c*g))/g
+--E 3445
+
+--S 3446 of 5341
+--a0:=integrate(t0,x)
+--E 3446
+
+--S 3447 of 5341
+--m0:=a0-r0
+--E 3447
+
+--S 3448 of 5341
+--d0:=D(m0,x)
+--E 3448
+
+)clear all
+
+--S 3449 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)/(f+g*x)^2
+--R 
+--R
+--R                b x + a n
+--R         log(e (-------) )
+--R                d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        g x  + 2f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3449
+
+--S 3450 of 5341
+r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)/((b*f-a*g)*(f+g*x))-(b*c-a*d)*n*_
+   log(c+d*x)/((b*f-a*g)*(d*f-c*g))+(b*c-a*d)*n*log(f+g*x)/((b*f-a*g)*_
+   (d*f-c*g))
+--R 
+--R
+--R   (2)
+--R                                                  b x + a n
+--R       ((- b c g + b d f)x - a c g + a d f)log(e (-------) )
+--R                                                  d x + c
+--R     + 
+--R       ((- a d + b c)g n x + (- a d + b c)f n)log(g x + f)
+--R     + 
+--R       ((a d - b c)g n x + (a d - b c)f n)log(d x + c)
+--R  /
+--R             3                   2        2             2                 2
+--R       (a c g  + (- a d - b c)f g  + b d f g)x + a c f g  + (- a d - b c)f g
+--R     + 
+--R            3
+--R       b d f
+--R                                                    Type: Expression(Integer)
+--E 3450
+
+--S 3451 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                      2
+--R       ((- a d + b c)g n x + (- a d + b c)f g n)log(g x + f)
+--R     + 
+--R              2                                 2
+--R       ((a d g  - b d f g)n x + (a d f g - b d f )n)log(d x + c)
+--R     + 
+--R                2                                   2
+--R       ((- b c g  + b d f g)n x + (- b c f g + b d f )n)log(b x + a)
+--R     + 
+--R               2                         2
+--R       (- a c g  + (a d + b c)f g - b d f )log(e)
+--R     + 
+--R               2                         2       b x + a
+--R       (- a c g  + (a d + b c)f g - b d f )n log(-------)
+--R                                                 d x + c
+--R  /
+--R             4                   3        2 2            3                 2 2
+--R       (a c g  + (- a d - b c)f g  + b d f g )x + a c f g  + (- a d - b c)f g
+--R     + 
+--R            3
+--R       b d f g
+--R                                         Type: Union(Expression(Integer),...)
+--E 3451
+
+--S 3452 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                           b x + a n
+--R       (b g x + a g)log(e (-------) ) + (b g n x + b f n)log(d x + c)
+--R                           d x + c
+--R     + 
+--R       (- b g n x - b f n)log(b x + a) + (- a g + b f)log(e)
+--R     + 
+--R                          b x + a
+--R       (- a g + b f)n log(-------)
+--R                          d x + c
+--R  /
+--R         3        2          2      2
+--R     (a g  - b f g )x + a f g  - b f g
+--R                                                    Type: Expression(Integer)
+--E 3452
+
+--S 3453 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3453
+
+)clear all
+
+--S 3454 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)/(f+g*x)^3
+--R 
+--R
+--R                     b x + a n
+--R              log(e (-------) )
+--R                     d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        g x  + 3f g x  + 3f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3454
+
+--S 3455 of 5341
+r0:=-1/2*(b*c-a*d)*n/((b*f-a*g)*(d*f-c*g)*(f+g*x))+1/2*b^2*n*log(a+b*x)/_
+   (g*(b*f-a*g)^2)-1/2*log(e*((a+b*x)/(c+d*x))^n)/(g*(f+g*x)^2)-_
+   1/2*d^2*n*log(c+d*x)/(g*(d*f-c*g)^2)+1/2*(b*c-a*d)*(2*b*d*f-b*c*g-_
+   a*d*g)*n*log(f+g*x)/((b*f-a*g)^2*(d*f-c*g)^2)
+--R 
+--R
+--R   (2)
+--R              2 2 4      2            2    3       2 2               2 2  2 2
+--R           - a c g  + (2a c d + 2a b c )f g  + (- a d  - 4a b c d - b c )f g
+--R         + 
+--R                  2     2     3     2 2 4
+--R           (2a b d  + 2b c d)f g - b d f
+--R      *
+--R                b x + a n
+--R         log(e (-------) )
+--R                d x + c
+--R     + 
+--R              2 2    2 2  4            2     2       3    2
+--R           ((a d  - b c )g  + (- 2a b d  + 2b c d)f g )n x
+--R         + 
+--R               2 2     2 2    3            2     2     2 2
+--R           ((2a d  - 2b c )f g  + (- 4a b d  + 4b c d)f g )n x
+--R         + 
+--R              2 2    2 2  2 2            2     2     3
+--R           ((a d  - b c )f g  + (- 2a b d  + 2b c d)f g)n
+--R      *
+--R         log(g x + f)
+--R     + 
+--R               2 2 4         2   3    2 2 2 2    2
+--R           (- a d g  + 2a b d f g  - b d f g )n x
+--R         + 
+--R                2 2   3         2 2 2     2 2 3
+--R           (- 2a d f g  + 4a b d f g  - 2b d f g)n x
+--R         + 
+--R               2 2 2 2         2 3     2 2 4
+--R           (- a d f g  + 2a b d f g - b d f )n
+--R      *
+--R         log(d x + c)
+--R     + 
+--R             2 2 4     2       3    2 2 2 2    2
+--R           (b c g  - 2b c d f g  + b d f g )n x
+--R         + 
+--R              2 2   3     2     2 2     2 2 3
+--R           (2b c f g  - 4b c d f g  + 2b d f g)n x
+--R         + 
+--R             2 2 2 2     2     3     2 2 4
+--R           (b c f g  - 2b c d f g + b d f )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R          2           2  4       2 2    2 2    3         2    2     2 2
+--R       ((a c d - a b c )g  + (- a d  + b c )f g  + (a b d  - b c d)f g )n x
+--R     + 
+--R          2           2    3       2 2    2 2  2 2         2    2     3
+--R       ((a c d - a b c )f g  + (- a d  + b c )f g  + (a b d  - b c d)f g)n
+--R  /
+--R             2 2 7        2            2    6      2 2                2 2  2 5
+--R           2a c g  + (- 4a c d - 4a b c )f g  + (2a d  + 8a b c d + 2b c )f g
+--R         + 
+--R                    2     2     3 4     2 2 4 3
+--R           (- 4a b d  - 4b c d)f g  + 2b d f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R             2 2   6        2            2  2 5
+--R           4a c f g  + (- 8a c d - 8a b c )f g
+--R         + 
+--R            2 2                 2 2  3 4            2     2     4 3     2 2 5 2
+--R         (4a d  + 16a b c d + 4b c )f g  + (- 8a b d  - 8b c d)f g  + 4b d f g
+--R      *
+--R         x
+--R     + 
+--R         2 2 2 5        2            2  3 4      2 2                2 2  4 3
+--R       2a c f g  + (- 4a c d - 4a b c )f g  + (2a d  + 8a b c d + 2b c )f g
+--R     + 
+--R                2     2     5 2     2 2 6
+--R       (- 4a b d  - 4b c d)f g  + 2b d f g
+--R                                                    Type: Expression(Integer)
+--E 3455
+
+--S 3456 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R              2 2    2 2  4            2     2       3    2
+--R           ((a d  - b c )g  + (- 2a b d  + 2b c d)f g )n x
+--R         + 
+--R               2 2     2 2    3            2     2     2 2
+--R           ((2a d  - 2b c )f g  + (- 4a b d  + 4b c d)f g )n x
+--R         + 
+--R              2 2    2 2  2 2            2     2     3
+--R           ((a d  - b c )f g  + (- 2a b d  + 2b c d)f g)n
+--R      *
+--R         log(g x + f)
+--R     + 
+--R               2 2 4         2   3    2 2 2 2    2
+--R           (- a d g  + 2a b d f g  - b d f g )n x
+--R         + 
+--R                2 2   3         2 2 2     2 2 3
+--R           (- 2a d f g  + 4a b d f g  - 2b d f g)n x
+--R         + 
+--R               2 2 2 2         2 3     2 2 4
+--R           (- a d f g  + 2a b d f g - b d f )n
+--R      *
+--R         log(d x + c)
+--R     + 
+--R             2 2 4     2       3    2 2 2 2    2
+--R           (b c g  - 2b c d f g  + b d f g )n x
+--R         + 
+--R              2 2   3     2     2 2     2 2 3
+--R           (2b c f g  - 4b c d f g  + 2b d f g)n x
+--R         + 
+--R             2 2 2 2     2     3     2 2 4
+--R           (b c f g  - 2b c d f g + b d f )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R              2 2 4      2            2    3       2 2               2 2  2 2
+--R           - a c g  + (2a c d + 2a b c )f g  + (- a d  - 4a b c d - b c )f g
+--R         + 
+--R                  2     2     3     2 2 4
+--R           (2a b d  + 2b c d)f g - b d f
+--R      *
+--R         log(e)
+--R     + 
+--R              2 2 4      2            2    3       2 2               2 2  2 2
+--R           - a c g  + (2a c d + 2a b c )f g  + (- a d  - 4a b c d - b c )f g
+--R         + 
+--R                  2     2     3     2 2 4
+--R           (2a b d  + 2b c d)f g - b d f
+--R      *
+--R               b x + a
+--R         n log(-------)
+--R               d x + c
+--R     + 
+--R          2           2  4       2 2    2 2    3         2    2     2 2
+--R       ((a c d - a b c )g  + (- a d  + b c )f g  + (a b d  - b c d)f g )n x
+--R     + 
+--R          2           2    3       2 2    2 2  2 2         2    2     3
+--R       ((a c d - a b c )f g  + (- a d  + b c )f g  + (a b d  - b c d)f g)n
+--R  /
+--R             2 2 7        2            2    6      2 2                2 2  2 5
+--R           2a c g  + (- 4a c d - 4a b c )f g  + (2a d  + 8a b c d + 2b c )f g
+--R         + 
+--R                    2     2     3 4     2 2 4 3
+--R           (- 4a b d  - 4b c d)f g  + 2b d f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R             2 2   6        2            2  2 5
+--R           4a c f g  + (- 8a c d - 8a b c )f g
+--R         + 
+--R            2 2                 2 2  3 4            2     2     4 3     2 2 5 2
+--R         (4a d  + 16a b c d + 4b c )f g  + (- 8a b d  - 8b c d)f g  + 4b d f g
+--R      *
+--R         x
+--R     + 
+--R         2 2 2 5        2            2  3 4      2 2                2 2  4 3
+--R       2a c f g  + (- 4a c d - 4a b c )f g  + (2a d  + 8a b c d + 2b c )f g
+--R     + 
+--R                2     2     5 2     2 2 6
+--R       (- 4a b d  - 4b c d)f g  + 2b d f g
+--R                                         Type: Union(Expression(Integer),...)
+--E 3456
+
+--S 3457 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               b x + a n                   b x + a
+--R        log(e (-------) ) - log(e) - n log(-------)
+--R               d x + c                     d x + c
+--R   (4)  -------------------------------------------
+--R                     3 2       2      2
+--R                   2g x  + 4f g x + 2f g
+--R                                                    Type: Expression(Integer)
+--E 3457
+
+--S 3458 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3458
+
+)clear all
+
+--S 3459 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)/(f+g*x)^4
+--R 
+--R
+--R                          b x + a n
+--R                   log(e (-------) )
+--R                          d x + c
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        g x  + 4f g x  + 6f g x  + 4f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3459
+
+--S 3460 of 5341
+r0:=-1/6*(b*c-a*d)*n/((b*f-a*g)*(d*f-c*g)*(f+g*x)^2)-1/3*(b*c-a*d)*_
+   (2*b*d*f-b*c*g-a*d*g)*n/((b*f-a*g)^2*(d*f-c*g)^2*(f+g*x))+1/3*b^3*n*_
+   log(a+b*x)/(g*(b*f-a*g)^3)-1/3*log(e*((a+b*x)/(c+d*x))^n)/(g*(f+g*x)^3)-_
+   1/3*d^3*n*log(c+d*x)/(g*(d*f-c*g)^3)+1/3*(b*c-a*d)*(a^2*d^2*g^2-_
+   a*b*d*g*(3*d*f-c*g)+b^2*(3*d^2*f^2-3*c*d*f*g+c^2*g^2))*n*log(f+g*x)/_
+   ((b*f-a*g)^3*(d*f-c*g)^3)
+--R 
+--R
+--R   (2)
+--R               3 3 6      3 2      2   3    5
+--R           - 2a c g  + (6a c d + 6a b c )f g
+--R         + 
+--R                3   2      2   2        2 3  2 4
+--R           (- 6a c d  - 18a b c d - 6a b c )f g
+--R         + 
+--R              3 3      2     2        2 2      3 3  3 3
+--R           (2a d  + 18a b c d  + 18a b c d + 2b c )f g
+--R         + 
+--R                2   3        2   2     3 2   4 2        2 3     3   2  5
+--R           (- 6a b d  - 18a b c d  - 6b c d)f g  + (6a b d  + 6b c d )f g
+--R         + 
+--R               3 3 6
+--R           - 2b d f
+--R      *
+--R                b x + a n
+--R         log(e (-------) )
+--R                d x + c
+--R     + 
+--R                    3 3     3 3  6      2   3     3 2     5
+--R               (- 2a d  + 2b c )g  + (6a b d  - 6b c d)f g
+--R             + 
+--R                      2 3     3   2  2 4
+--R               (- 6a b d  + 6b c d )f g
+--R          *
+--R                3
+--R             n x
+--R         + 
+--R                    3 3     3 3    5       2   3      3 2   2 4
+--R               (- 6a d  + 6b c )f g  + (18a b d  - 18b c d)f g
+--R             + 
+--R                       2 3      3   2  3 3
+--R               (- 18a b d  + 18b c d )f g
+--R          *
+--R                2
+--R             n x
+--R         + 
+--R                    3 3     3 3  2 4       2   3      3 2   3 3
+--R               (- 6a d  + 6b c )f g  + (18a b d  - 18b c d)f g
+--R             + 
+--R                       2 3      3   2  4 2
+--R               (- 18a b d  + 18b c d )f g
+--R          *
+--R             n x
+--R         + 
+--R                    3 3     3 3  3 3      2   3     3 2   4 2
+--R               (- 2a d  + 2b c )f g  + (6a b d  - 6b c d)f g
+--R             + 
+--R                      2 3     3   2  5
+--R               (- 6a b d  + 6b c d )f g
+--R          *
+--R             n
+--R      *
+--R         log(g x + f)
+--R     + 
+--R              3 3 6     2   3   5       2 3 2 4     3 3 3 3    3
+--R           (2a d g  - 6a b d f g  + 6a b d f g  - 2b d f g )n x
+--R         + 
+--R              3 3   5      2   3 2 4        2 3 3 3     3 3 4 2    2
+--R           (6a d f g  - 18a b d f g  + 18a b d f g  - 6b d f g )n x
+--R         + 
+--R              3 3 2 4      2   3 3 3        2 3 4 2     3 3 5
+--R           (6a d f g  - 18a b d f g  + 18a b d f g  - 6b d f g)n x
+--R         + 
+--R              3 3 3 3     2   3 4 2       2 3 5      3 3 6
+--R           (2a d f g  - 6a b d f g  + 6a b d f g - 2b d f )n
+--R      *
+--R         log(d x + c)
+--R     + 
+--R                3 3 6     3 2     5     3   2 2 4     3 3 3 3    3
+--R           (- 2b c g  + 6b c d f g  - 6b c d f g  + 2b d f g )n x
+--R         + 
+--R                3 3   5      3 2   2 4      3   2 3 3     3 3 4 2    2
+--R           (- 6b c f g  + 18b c d f g  - 18b c d f g  + 6b d f g )n x
+--R         + 
+--R                3 3 2 4      3 2   3 3      3   2 4 2     3 3 5
+--R           (- 6b c f g  + 18b c d f g  - 18b c d f g  + 6b d f g)n x
+--R         + 
+--R                3 3 3 3     3 2   4 2     3   2 5      3 3 6
+--R           (- 2b c f g  + 6b c d f g  - 6b c d f g + 2b d f )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R                3   2       2 3  6      3 3     2     2       2 2      3 3    5
+--R           (- 2a c d  + 2a b c )g  + (2a d  + 6a b c d  - 6a b c d - 2b c )f g
+--R         + 
+--R                2   3     3 2   2 4        2 3     3   2  3 3
+--R           (- 6a b d  + 6b c d)f g  + (4a b d  - 4b c d )f g
+--R      *
+--R            2
+--R         n x
+--R     + 
+--R             3 2     2   3  6        3   2       2 3    5
+--R           (a c d - a b c )g  + (- 6a c d  + 6a b c )f g
+--R         + 
+--R              3 3      2     2        2 2      3 3  2 4
+--R           (5a d  + 15a b c d  - 15a b c d - 5b c )f g
+--R         + 
+--R                 2   3      3 2   3 3        2 3     3   2  4 2
+--R           (- 14a b d  + 14b c d)f g  + (9a b d  - 9b c d )f g
+--R      *
+--R         n x
+--R     + 
+--R             3 2     2   3    5        3   2       2 3  2 4
+--R           (a c d - a b c )f g  + (- 4a c d  + 4a b c )f g
+--R         + 
+--R              3 3     2     2       2 2      3 3  3 3        2   3     3 2   4 2
+--R           (3a d  + 9a b c d  - 9a b c d - 3b c )f g  + (- 8a b d  + 8b c d)f g
+--R         + 
+--R                2 3     3   2  5
+--R           (5a b d  - 5b c d )f g
+--R      *
+--R         n
+--R  /
+--R             3 3 10         3 2       2   3    9
+--R           6a c g   + (- 18a c d - 18a b c )f g
+--R         + 
+--R               3   2      2   2         2 3  2 8
+--R           (18a c d  + 54a b c d + 18a b c )f g
+--R         + 
+--R                3 3      2     2        2 2      3 3  3 7
+--R           (- 6a d  - 54a b c d  - 54a b c d - 6b c )f g
+--R         + 
+--R               2   3        2   2      3 2   4 6           2 3      3   2  5 5
+--R           (18a b d  + 54a b c d  + 18b c d)f g  + (- 18a b d  - 18b c d )f g
+--R         + 
+--R             3 3 6 4
+--R           6b d f g
+--R      *
+--R          3
+--R         x
+--R     + 
+--R              3 3   9         3 2       2   3  2 8
+--R           18a c f g  + (- 54a c d - 54a b c )f g
+--R         + 
+--R               3   2       2   2         2 3  3 7
+--R           (54a c d  + 162a b c d + 54a b c )f g
+--R         + 
+--R                 3 3       2     2         2 2       3 3  4 6
+--R           (- 18a d  - 162a b c d  - 162a b c d - 18b c )f g
+--R         + 
+--R               2   3         2   2      3 2   5 5           2 3      3   2  6 4
+--R           (54a b d  + 162a b c d  + 54b c d)f g  + (- 54a b d  - 54b c d )f g
+--R         + 
+--R              3 3 7 3
+--R           18b d f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              3 3 2 8         3 2       2   3  3 7
+--R           18a c f g  + (- 54a c d - 54a b c )f g
+--R         + 
+--R               3   2       2   2         2 3  4 6
+--R           (54a c d  + 162a b c d + 54a b c )f g
+--R         + 
+--R                 3 3       2     2         2 2       3 3  5 5
+--R           (- 18a d  - 162a b c d  - 162a b c d - 18b c )f g
+--R         + 
+--R               2   3         2   2      3 2   6 4           2 3      3   2  7 3
+--R           (54a b d  + 162a b c d  + 54b c d)f g  + (- 54a b d  - 54b c d )f g
+--R         + 
+--R              3 3 8 2
+--R           18b d f g
+--R      *
+--R         x
+--R     + 
+--R         3 3 3 7         3 2       2   3  4 6
+--R       6a c f g  + (- 18a c d - 18a b c )f g
+--R     + 
+--R           3   2      2   2         2 3  5 5
+--R       (18a c d  + 54a b c d + 18a b c )f g
+--R     + 
+--R            3 3      2     2        2 2      3 3  6 4
+--R       (- 6a d  - 54a b c d  - 54a b c d - 6b c )f g
+--R     + 
+--R           2   3        2   2      3 2   7 3           2 3      3   2  8 2
+--R       (18a b d  + 54a b c d  + 18b c d)f g  + (- 18a b d  - 18b c d )f g
+--R     + 
+--R         3 3 9
+--R       6b d f g
+--R                                                    Type: Expression(Integer)
+--E 3460
+
+--S 3461 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    3 3     3 3  6      2   3     3 2     5
+--R               (- 2a d  + 2b c )g  + (6a b d  - 6b c d)f g
+--R             + 
+--R                      2 3     3   2  2 4
+--R               (- 6a b d  + 6b c d )f g
+--R          *
+--R                3
+--R             n x
+--R         + 
+--R                    3 3     3 3    5       2   3      3 2   2 4
+--R               (- 6a d  + 6b c )f g  + (18a b d  - 18b c d)f g
+--R             + 
+--R                       2 3      3   2  3 3
+--R               (- 18a b d  + 18b c d )f g
+--R          *
+--R                2
+--R             n x
+--R         + 
+--R                    3 3     3 3  2 4       2   3      3 2   3 3
+--R               (- 6a d  + 6b c )f g  + (18a b d  - 18b c d)f g
+--R             + 
+--R                       2 3      3   2  4 2
+--R               (- 18a b d  + 18b c d )f g
+--R          *
+--R             n x
+--R         + 
+--R                    3 3     3 3  3 3      2   3     3 2   4 2
+--R               (- 2a d  + 2b c )f g  + (6a b d  - 6b c d)f g
+--R             + 
+--R                      2 3     3   2  5
+--R               (- 6a b d  + 6b c d )f g
+--R          *
+--R             n
+--R      *
+--R         log(g x + f)
+--R     + 
+--R              3 3 6     2   3   5       2 3 2 4     3 3 3 3    3
+--R           (2a d g  - 6a b d f g  + 6a b d f g  - 2b d f g )n x
+--R         + 
+--R              3 3   5      2   3 2 4        2 3 3 3     3 3 4 2    2
+--R           (6a d f g  - 18a b d f g  + 18a b d f g  - 6b d f g )n x
+--R         + 
+--R              3 3 2 4      2   3 3 3        2 3 4 2     3 3 5
+--R           (6a d f g  - 18a b d f g  + 18a b d f g  - 6b d f g)n x
+--R         + 
+--R              3 3 3 3     2   3 4 2       2 3 5      3 3 6
+--R           (2a d f g  - 6a b d f g  + 6a b d f g - 2b d f )n
+--R      *
+--R         log(d x + c)
+--R     + 
+--R                3 3 6     3 2     5     3   2 2 4     3 3 3 3    3
+--R           (- 2b c g  + 6b c d f g  - 6b c d f g  + 2b d f g )n x
+--R         + 
+--R                3 3   5      3 2   2 4      3   2 3 3     3 3 4 2    2
+--R           (- 6b c f g  + 18b c d f g  - 18b c d f g  + 6b d f g )n x
+--R         + 
+--R                3 3 2 4      3 2   3 3      3   2 4 2     3 3 5
+--R           (- 6b c f g  + 18b c d f g  - 18b c d f g  + 6b d f g)n x
+--R         + 
+--R                3 3 3 3     3 2   4 2     3   2 5      3 3 6
+--R           (- 2b c f g  + 6b c d f g  - 6b c d f g + 2b d f )n
+--R      *
+--R         log(b x + a)
+--R     + 
+--R               3 3 6      3 2      2   3    5
+--R           - 2a c g  + (6a c d + 6a b c )f g
+--R         + 
+--R                3   2      2   2        2 3  2 4
+--R           (- 6a c d  - 18a b c d - 6a b c )f g
+--R         + 
+--R              3 3      2     2        2 2      3 3  3 3
+--R           (2a d  + 18a b c d  + 18a b c d + 2b c )f g
+--R         + 
+--R                2   3        2   2     3 2   4 2        2 3     3   2  5
+--R           (- 6a b d  - 18a b c d  - 6b c d)f g  + (6a b d  + 6b c d )f g
+--R         + 
+--R               3 3 6
+--R           - 2b d f
+--R      *
+--R         log(e)
+--R     + 
+--R               3 3 6      3 2      2   3    5
+--R           - 2a c g  + (6a c d + 6a b c )f g
+--R         + 
+--R                3   2      2   2        2 3  2 4
+--R           (- 6a c d  - 18a b c d - 6a b c )f g
+--R         + 
+--R              3 3      2     2        2 2      3 3  3 3
+--R           (2a d  + 18a b c d  + 18a b c d + 2b c )f g
+--R         + 
+--R                2   3        2   2     3 2   4 2        2 3     3   2  5
+--R           (- 6a b d  - 18a b c d  - 6b c d)f g  + (6a b d  + 6b c d )f g
+--R         + 
+--R               3 3 6
+--R           - 2b d f
+--R      *
+--R               b x + a
+--R         n log(-------)
+--R               d x + c
+--R     + 
+--R                3   2       2 3  6      3 3     2     2       2 2      3 3    5
+--R           (- 2a c d  + 2a b c )g  + (2a d  + 6a b c d  - 6a b c d - 2b c )f g
+--R         + 
+--R                2   3     3 2   2 4        2 3     3   2  3 3
+--R           (- 6a b d  + 6b c d)f g  + (4a b d  - 4b c d )f g
+--R      *
+--R            2
+--R         n x
+--R     + 
+--R             3 2     2   3  6        3   2       2 3    5
+--R           (a c d - a b c )g  + (- 6a c d  + 6a b c )f g
+--R         + 
+--R              3 3      2     2        2 2      3 3  2 4
+--R           (5a d  + 15a b c d  - 15a b c d - 5b c )f g
+--R         + 
+--R                 2   3      3 2   3 3        2 3     3   2  4 2
+--R           (- 14a b d  + 14b c d)f g  + (9a b d  - 9b c d )f g
+--R      *
+--R         n x
+--R     + 
+--R             3 2     2   3    5        3   2       2 3  2 4
+--R           (a c d - a b c )f g  + (- 4a c d  + 4a b c )f g
+--R         + 
+--R              3 3     2     2       2 2      3 3  3 3        2   3     3 2   4 2
+--R           (3a d  + 9a b c d  - 9a b c d - 3b c )f g  + (- 8a b d  + 8b c d)f g
+--R         + 
+--R                2 3     3   2  5
+--R           (5a b d  - 5b c d )f g
+--R      *
+--R         n
+--R  /
+--R             3 3 10         3 2       2   3    9
+--R           6a c g   + (- 18a c d - 18a b c )f g
+--R         + 
+--R               3   2      2   2         2 3  2 8
+--R           (18a c d  + 54a b c d + 18a b c )f g
+--R         + 
+--R                3 3      2     2        2 2      3 3  3 7
+--R           (- 6a d  - 54a b c d  - 54a b c d - 6b c )f g
+--R         + 
+--R               2   3        2   2      3 2   4 6           2 3      3   2  5 5
+--R           (18a b d  + 54a b c d  + 18b c d)f g  + (- 18a b d  - 18b c d )f g
+--R         + 
+--R             3 3 6 4
+--R           6b d f g
+--R      *
+--R          3
+--R         x
+--R     + 
+--R              3 3   9         3 2       2   3  2 8
+--R           18a c f g  + (- 54a c d - 54a b c )f g
+--R         + 
+--R               3   2       2   2         2 3  3 7
+--R           (54a c d  + 162a b c d + 54a b c )f g
+--R         + 
+--R                 3 3       2     2         2 2       3 3  4 6
+--R           (- 18a d  - 162a b c d  - 162a b c d - 18b c )f g
+--R         + 
+--R               2   3         2   2      3 2   5 5           2 3      3   2  6 4
+--R           (54a b d  + 162a b c d  + 54b c d)f g  + (- 54a b d  - 54b c d )f g
+--R         + 
+--R              3 3 7 3
+--R           18b d f g
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              3 3 2 8         3 2       2   3  3 7
+--R           18a c f g  + (- 54a c d - 54a b c )f g
+--R         + 
+--R               3   2       2   2         2 3  4 6
+--R           (54a c d  + 162a b c d + 54a b c )f g
+--R         + 
+--R                 3 3       2     2         2 2       3 3  5 5
+--R           (- 18a d  - 162a b c d  - 162a b c d - 18b c )f g
+--R         + 
+--R               2   3         2   2      3 2   6 4           2 3      3   2  7 3
+--R           (54a b d  + 162a b c d  + 54b c d)f g  + (- 54a b d  - 54b c d )f g
+--R         + 
+--R              3 3 8 2
+--R           18b d f g
+--R      *
+--R         x
+--R     + 
+--R         3 3 3 7         3 2       2   3  4 6
+--R       6a c f g  + (- 18a c d - 18a b c )f g
+--R     + 
+--R           3   2      2   2         2 3  5 5
+--R       (18a c d  + 54a b c d + 18a b c )f g
+--R     + 
+--R            3 3      2     2        2 2      3 3  6 4
+--R       (- 6a d  - 54a b c d  - 54a b c d - 6b c )f g
+--R     + 
+--R           2   3        2   2      3 2   7 3           2 3      3   2  8 2
+--R       (18a b d  + 54a b c d  + 18b c d)f g  + (- 18a b d  - 18b c d )f g
+--R     + 
+--R         3 3 9
+--R       6b d f g
+--R                                         Type: Union(Expression(Integer),...)
+--E 3461
+
+--S 3462 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               b x + a n                   b x + a
+--R        log(e (-------) ) - log(e) - n log(-------)
+--R               d x + c                     d x + c
+--R   (4)  -------------------------------------------
+--R                4 3       3 2     2 2      3
+--R              3g x  + 9f g x  + 9f g x + 3f g
+--R                                                    Type: Expression(Integer)
+--E 3462
+
+--S 3463 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3463
+
+)clear all
+
+--S 3464 of 5341
+t0:=(f+g*x)^3*log(e*((a+b*x)/(c+d*x))^n)^2
+--R 
+--R
+--R          3 3       2 2     2       3        b x + a n 2
+--R   (1)  (g x  + 3f g x  + 3f g x + f )log(e (-------) )
+--R                                             d x + c
+--R                                                    Type: Expression(Integer)
+--E 3464
+
+--S 3465 of 5341
+--r0:=-1/6*(b*c-a*d)^2*(b*c+a*d)*g^3*n^2*x/(b^3*d^3)+1/4*(b*c-a*d)^2*g^2*_
+--  (4*b*d*f-b*c*g-a*d*g)*n^2*x/(b^3*d^3)+1/12*(b*c-a*d)^2*g^3*n^2*x^2/_
+--  (b^2*d^2)-1/6*a^3*(b*c-a*d)*g^3*n^2*log(a+b*x)/(b^4*d)+1/4*a^2*_
+--  (b*c-a*d)*g^2*(4*b*d*f-b*c*g-a*d*g)*n^2*log(a+b*x)/(b^4*d^2)-_
+--  1/4*(b*c-a*d)*g^2*(4*b*d*f-b*c*g-a*d*g)*n*x^2*log(e*((a+b*x)/_
+--  (c+d*x))^n)/(b^2*d^2)-1/6*(b*c-a*d)*g^3*n*x^3*log(e*((a+b*x)/_
+--  (c+d*x))^n)/(b*d)-1/2*(b*c-a*d)*g*(a^2*d^2*g^2-a*b*d*g*(4*d*f-c*g)+_
+--  b^2*(6*d^2*f^2-4*c*d*f*g+c^2*g^2))*n*(a+b*x)*log(e*((a+b*x)/_
+--  (c+d*x))^n)/(b^4*d^3)+1/2*(b*f-a*g)^4*n*log((-b*c+a*d)/(d*(a+b*x)))*_
+--  log(e*((a+b*x)/(c+d*x))^n)/(b^4*g)+1/4*(f+g*x)^4*log(e*((a+b*x)/_
+--  (c+d*x))^n)^2/g-1/2*(d*f-c*g)^4*n*log(e*((a+b*x)/(c+d*x))^n)*_
+--  log((b*c-a*d)/(b*(c+d*x)))/(d^4*g)+1/6*c^3*(b*c-a*d)*g^3*n^2*_
+--  log(c+d*x)/(b*d^4)-1/4*c^2*(b*c-a*d)*g^2*(4*b*d*f-b*c*g-a*d*g)*n^2*_
+--  log(c+d*x)/(b^2*d^4)+1/2*(b*c-a*d)^2*g*(a^2*d^2*g^2-a*b*d*g*(4*d*f-_
+--  c*g)+b^2*(6*d^2*f^2-4*c*d*f*g+c^2*g^2))*n^2*log(c+d*x)/(b^4*d^4)-_
+--  1/2*(d*f-c*g)^4*n^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(d^4*g)-_
+--  1/2*(b*f-a*g)^4*n^2*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^4*g)
+--E 3465
+
+--S 3466 of 5341
+--a0:=integrate(t0,x)
+--E 3466
+
+--S 3467 of 5341
+--m0:=a0-r0
+--E 3467
+
+--S 3468 of 5341
+--d0:=D(m0,x)
+--E 3468
+
+)clear all
+
+--S 3469 of 5341
+t0:=(f+g*x)^2*log(e*((a+b*x)/(c+d*x))^n)^2
+--R 
+--R
+--R          2 2             2        b x + a n 2
+--R   (1)  (g x  + 2f g x + f )log(e (-------) )
+--R                                   d x + c
+--R                                                    Type: Expression(Integer)
+--E 3469
+
+--S 3470 of 5341
+--r0:=1/3*(b*c-a*d)^2*g^2*n^2*x/(b^2*d^2)+1/3*a^2*(b*c-a*d)*g^2*n^2*_
+--  log(a+b*x)/(b^3*d)-1/3*(b*c-a*d)*g^2*n*x^2*log(e*((a+b*x)/(c+d*x))^n)/_
+--  (b*d)-2/3*(b*c-a*d)*g*(3*b*d*f-b*c*g-a*d*g)*n*(a+b*x)*log(e*((a+b*x)/_
+--  (c+d*x))^n)/(b^3*d^2)+2/3*(b*f-a*g)^3*n*log((-b*c+a*d)/(d*(a+b*x)))*_
+--  log(e*((a+b*x)/(c+d*x))^n)/(b^3*g)+1/3*(f+g*x)^3*log(e*((a+b*x)/_
+--  (c+d*x))^n)^2/g-2/3*(d*f-c*g)^3*n*log(e*((a+b*x)/(c+d*x))^n)*_
+--  log((b*c-a*d)/(b*(c+d*x)))/(d^3*g)-1/3*c^2*(b*c-a*d)*g^2*n^2*_
+--  log(c+d*x)/(b*d^3)+2/3*(b*c-a*d)^2*g*(3*b*d*f-b*c*g-a*d*g)*n^2*_
+--  log(c+d*x)/(b^3*d^3)-2/3*(d*f-c*g)^3*n^2*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(d^3*g)-2/3*(b*f-a*g)^3*n^2*polylog(2,b*(c+d*x)/_
+--  (d*(a+b*x)))/(b^3*g)
+--E 3470
+
+--S 3471 of 5341
+--a0:=integrate(t0,x)
+--E 3471
+
+--S 3472 of 5341
+--m0:=a0-r0
+--E 3472
+
+--S 3473 of 5341
+--d0:=D(m0,x)
+--E 3473
+
+)clear all
+
+--S 3474 of 5341
+t0:=(f+g*x)*log(e*((a+b*x)/(c+d*x))^n)^2
+--R 
+--R
+--R                        b x + a n 2
+--R   (1)  (g x + f)log(e (-------) )
+--R                        d x + c
+--R                                                    Type: Expression(Integer)
+--E 3474
+
+--S 3475 of 5341
+--r0:=-(b*c-a*d)*g*n*(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)/(b^2*d)+_
+--  (b*f-a*g)^2*n*log((-b*c+a*d)/(d*(a+b*x)))*log(e*((a+b*x)/(c+d*x))^n)/_
+--  (b^2*g)+1/2*(f+g*x)^2*log(e*((a+b*x)/(c+d*x))^n)^2/g-(d*f-c*g)^2*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)*log((b*c-a*d)/(b*(c+d*x)))/(d^2*g)+_
+--  (b*c-a*d)^2*g*n^2*log(c+d*x)/(b^2*d^2)-(d*f-c*g)^2*n^2*_
+--  polylog(2,d*(a+b*x)/(b*(c+d*x)))/(d^2*g)-(b*f-a*g)^2*n^2*_
+--  polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^2*g)
+--E 3475
+
+--S 3476 of 5341
+--a0:=integrate(t0,x)
+--E 3476
+
+--S 3477 of 5341
+--m0:=a0-r0
+--E 3477
+
+--S 3478 of 5341
+--d0:=D(m0,x)
+--E 3478
+
+)clear all
+
+--S 3479 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^2
+--R 
+--R
+--R               b x + a n 2
+--R   (1)  log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3479
+
+--S 3480 of 5341
+--r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^2/b+2*(b*c-a*d)*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)*log((b*c-a*d)/(b*(c+d*x)))/(b*d)+_
+--  2*(b*c-a*d)*n^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 3480
+
+--S 3481 of 5341
+--a0:=integrate(t0,x)
+--E 3481
+
+--S 3482 of 5341
+--m0:=a0-r0
+--E 3482
+
+--S 3483 of 5341
+--d0:=D(m0,x)
+--E 3483
+
+)clear all
+
+--S 3484 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^2/(f+g*x)
+--R 
+--R
+--R               b x + a n 2
+--R        log(e (-------) )
+--R               d x + c
+--R   (1)  ------------------
+--R              g x + f
+--R                                                    Type: Expression(Integer)
+--E 3484
+
+--S 3485 of 5341
+--r0:=-log(e*((a+b*x)/(c+d*x))^n)^2*log((b*c-a*d)/(b*(c+d*x)))/g+_
+--  log(e*((a+b*x)/(c+d*x))^n)^2*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*_
+--  (c+d*x)))/g-2*n*log(e*((a+b*x)/(c+d*x))^n)*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/g+2*n*log(e*((a+b*x)/(c+d*x))^n)*polylog(2,(a*_
+--  (d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/g+2*n^2*_
+--  polylog(3,d*(a+b*x)/(b*(c+d*x)))/g-2*n^2*polylog(3,(a*(d*f-c*g)+_
+--  b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/g
+--E 3485
+
+--S 3486 of 5341
+--a0:=integrate(t0,x)
+--E 3486
+
+--S 3487 of 5341
+--m0:=a0-r0
+--E 3487
+
+--S 3488 of 5341
+--d0:=D(m0,x)
+--E 3488
+
+)clear all
+
+--S 3489 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^2/(f+g*x)^2
+--R 
+--R
+--R               b x + a n 2
+--R        log(e (-------) )
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        g x  + 2f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3489
+
+--S 3490 of 5341
+--r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^2/((b*f-a*g)*(f+g*x))+_
+--  2*(b*c-a*d)*n*log(e*((a+b*x)/(c+d*x))^n)*log((b*c-a*d)*(f+g*x)/_
+--  ((b*f-a*g)*(c+d*x)))/((b*f-a*g)*(d*f-c*g))+2*(b*c-a*d)*n^2*_
+--  polylog(2,(d*f-c*g)*(a+b*x)/((b*f-a*g)*(c+d*x)))/((b*f-a*g)*(d*f-c*g))
+--E 3490
+
+--S 3491 of 5341
+--a0:=integrate(t0,x)
+--E 3491
+
+--S 3492 of 5341
+--m0:=a0-r0
+--E 3492
+
+--S 3493 of 5341
+--d0:=D(m0,x)
+--E 3493
+
+)clear all
+
+--S 3494 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^2/(f+g*x)^3
+--R 
+--R
+--R                    b x + a n 2
+--R             log(e (-------) )
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        g x  + 3f g x  + 3f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3494
+
+--S 3495 of 5341
+--r0:=(b*c-a*d)*g*n*(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)/((b*f-a*g)^2*_
+--  (d*f-c*g)*(f+g*x))-b^2*n*log((-b*c+a*d)/(d*(a+b*x)))*log(e*((a+b*x)/_
+--  (c+d*x))^n)/(g*(b*f-a*g)^2)-1/2*log(e*((a+b*x)/(c+d*x))^n)^2/(g*_
+--  (f+g*x)^2)+d^2*n*log(e*((a+b*x)/(c+d*x))^n)*log((b*c-a*d)/(b*(c+d*x)))/_
+--  (g*(d*f-c*g)^2)-(b*c-a*d)^2*g*n^2*log(c+d*x)/((b*f-a*g)^2*(d*f-c*g)^2)+_
+--  (b*c-a*d)^2*g*n^2*log(f+g*x)/((b*f-a*g)^2*(d*f-c*g)^2)-(b*c-a*d)*_
+--  (2*b*d*f-b*c*g-a*d*g)*n^2*log(-g*(a+b*x)/(b*f-a*g))*log(f+g*x)/_
+--  ((b*f-a*g)^2*(d*f-c*g)^2)+(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)*log(f+g*x)/((b*f-a*g)^2*(d*f-c*g)^2)+_
+--  (b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*n^2*log(-g*(c+d*x)/(d*f-c*g))*_
+--  log(f+g*x)/((b*f-a*g)^2*(d*f-c*g)^2)+d^2*n^2*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(g*(d*f-c*g)^2)+b^2*n^2*polylog(2,b*(c+d*x)/(d*(a+b*x)))/_
+--  (g*(b*f-a*g)^2)-(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*n^2*polylog(2,b*_
+--  (f+g*x)/(b*f-a*g))/((b*f-a*g)^2*(d*f-c*g)^2)+(b*c-a*d)*(2*b*d*f-_
+--  b*c*g-a*d*g)*n^2*polylog(2,d*(f+g*x)/(d*f-c*g))/((b*f-a*g)^2*(d*f-c*g)^2)
+--E 3495
+
+--S 3496 of 5341
+--a0:=integrate(t0,x)
+--E 3496
+
+--S 3497 of 5341
+--m0:=a0-r0
+--E 3497
+
+--S 3498 of 5341
+--d0:=D(m0,x)
+--E 3498
+
+)clear all
+
+--S 3499 of 5341
+t0:=(f+g*x)^2*log(e*((a+b*x)/(c+d*x))^n)^3
+--R 
+--R
+--R          2 2             2        b x + a n 3
+--R   (1)  (g x  + 2f g x + f )log(e (-------) )
+--R                                   d x + c
+--R                                                    Type: Expression(Integer)
+--E 3499
+
+--S 3500 of 5341
+--r0:=(b*c-a*d)^2*g^2*n^2*(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)/(b^3*d^2)-_
+--  a^2*(b*c-a*d)*g^2*n^2*log((-b*c+a*d)/(d*(a+b*x)))*log(e*((a+b*x)/_
+--  (c+d*x))^n)/(b^3*d)-1/2*(b*c-a*d)*g^2*n*x^2*log(e*((a+b*x)/_
+--  (c+d*x))^n)^2/(b*d)-(b*c-a*d)*g*(3*b*d*f-b*c*g-a*d*g)*n*(a+b*x)*_
+--  log(e*((a+b*x)/(c+d*x))^n)^2/(b^3*d^2)+(b*f-a*g)^3*n*log((-b*c+a*d)/_
+--  (d*(a+b*x)))*log(e*((a+b*x)/(c+d*x))^n)^2/(b^3*g)+1/3*(f+g*x)^3*_
+--  log(e*((a+b*x)/(c+d*x))^n)^3/g+c^2*(b*c-a*d)*g^2*n^2*log(e*((a+b*x)/_
+--  (c+d*x))^n)*log((b*c-a*d)/(b*(c+d*x)))/(b*d^3)-2*(b*c-a*d)^2*g*_
+--  (3*b*d*f-b*c*g-a*d*g)*n^2*log(e*((a+b*x)/(c+d*x))^n)*log((b*c-a*d)/_
+--  (b*(c+d*x)))/(b^3*d^3)-(d*f-c*g)^3*n*log(e*((a+b*x)/(c+d*x))^n)^2*_
+--  log((b*c-a*d)/(b*(c+d*x)))/(d^3*g)-(b*c-a*d)^3*g^2*n^3*log(c+d*x)/_
+--  (b^3*d^3)+c^2*(b*c-a*d)*g^2*n^3*polylog(2,d*(a+b*x)/(b*(c+d*x)))/_
+--  (b*d^3)-2*(b*c-a*d)^2*g*(3*b*d*f-b*c*g-a*d*g)*n^3*polylog(2,_
+--  d*(a+b*x)/(b*(c+d*x)))/(b^3*d^3)-2*(d*f-c*g)^3*n^2*log(e*((a+b*x)/_
+--  (c+d*x))^n)*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(d^3*g)+a^2*(b*c-a*d)*_
+--  g^2*n^3*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^3*d)-2*(b*f-a*g)^3*n^2*_
+--  log(e*((a+b*x)/(c+d*x))^n)*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(b^3*g)+_
+--  2*(d*f-c*g)^3*n^3*polylog(3,d*(a+b*x)/(b*(c+d*x)))/(d^3*g)-_
+--  2*(b*f-a*g)^3*n^3*polylog(3,b*(c+d*x)/(d*(a+b*x)))/(b^3*g)
+--E 3500
+
+--S 3501 of 5341
+--a0:=integrate(t0,x)
+--E 3501
+
+--S 3502 of 5341
+--m0:=a0-r0
+--E 3502
+
+--S 3503 of 5341
+--d0:=D(m0,x)
+--E 3503
+
+)clear all
+
+--S 3504 of 5341
+t0:=(f+g*x)*log(e*((a+b*x)/(c+d*x))^n)^3
+--R 
+--R
+--R                        b x + a n 3
+--R   (1)  (g x + f)log(e (-------) )
+--R                        d x + c
+--R                                                    Type: Expression(Integer)
+--E 3504
+
+--S 3505 of 5341
+--r0:=-3/2*(b*c-a*d)*g*n*(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^2/(b^2*d)+_
+--  3/2*(b*f-a*g)^2*n*log((-b*c+a*d)/(d*(a+b*x)))*log(e*((a+b*x)/_
+--  (c+d*x))^n)^2/(b^2*g)+1/2*(f+g*x)^2*log(e*((a+b*x)/(c+d*x))^n)^3/g-_
+--  3*(b*c-a*d)^2*g*n^2*log(e*((a+b*x)/(c+d*x))^n)*log((b*c-a*d)/(b*_
+--  (c+d*x)))/(b^2*d^2)-3/2*(d*f-c*g)^2*n*log(e*((a+b*x)/(c+d*x))^n)^2*_
+--  log((b*c-a*d)/(b*(c+d*x)))/(d^2*g)-3*(b*c-a*d)^2*g*n^3*polylog(2,_
+--  d*(a+b*x)/(b*(c+d*x)))/(b^2*d^2)-3*(d*f-c*g)^2*n^2*log(e*((a+b*x)/_
+--  (c+d*x))^n)*polylog(2,d*(a+b*x)/(b*(c+d*x)))/(d^2*g)-3*(b*f-a*g)^2*_
+--  n^2*log(e*((a+b*x)/(c+d*x))^n)*polylog(2,b*(c+d*x)/(d*(a+b*x)))/_
+--  (b^2*g)+3*(d*f-c*g)^2*n^3*polylog(3,d*(a+b*x)/(b*(c+d*x)))/(d^2*g)-_
+--  3*(b*f-a*g)^2*n^3*polylog(3,b*(c+d*x)/(d*(a+b*x)))/(b^2*g)
+--E 3505
+
+--S 3506 of 5341
+--a0:=integrate(t0,x)
+--E 3506
+
+--S 3507 of 5341
+--m0:=a0-r0
+--E 3507
+
+--S 3508 of 5341
+--d0:=D(m0,x)
+--E 3508
+
+)clear all
+
+--S 3509 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^3
+--R 
+--R
+--R               b x + a n 3
+--R   (1)  log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3509
+
+--S 3510 of 5341
+--r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^3/b+3*(b*c-a*d)*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)^2*log((b*c-a*d)/(b*(c+d*x)))/(b*d)+_
+--  6*(b*c-a*d)*n^2*log(e*((a+b*x)/(c+d*x))^n)*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(b*d)-6*(b*c-a*d)*n^3*polylog(3,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 3510
+
+--S 3511 of 5341
+--a0:=integrate(t0,x)
+--E 3511
+
+--S 3512 of 5341
+--m0:=a0-r0
+--E 3512
+
+--S 3513 of 5341
+--d0:=D(m0,x)
+--E 3513
+
+)clear all
+
+--S 3514 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^3/(f+g*x)
+--R 
+--R
+--R               b x + a n 3
+--R        log(e (-------) )
+--R               d x + c
+--R   (1)  ------------------
+--R              g x + f
+--R                                                    Type: Expression(Integer)
+--E 3514
+
+--S 3515 of 5341
+--r0:=-log(e*((a+b*x)/(c+d*x))^n)^3*log((b*c-a*d)/(b*(c+d*x)))/g+_
+--  log(e*((a+b*x)/(c+d*x))^n)^3*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*_
+--  (c+d*x)))/g-3*n*log(e*((a+b*x)/(c+d*x))^n)^2*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/g+3*n*log(e*((a+b*x)/(c+d*x))^n)^2*polylog(2,(a*(d*f-c*g)+_
+--  b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/g+6*n^2*log(e*((a+b*x)/_
+--  (c+d*x))^n)*polylog(3,d*(a+b*x)/(b*(c+d*x)))/g-6*n^2*log(e*((a+b*x)/_
+--  (c+d*x))^n)*polylog(3,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*_
+--  (c+d*x)))/g-6*n^3*polylog(4,d*(a+b*x)/(b*(c+d*x)))/g+6*n^3*_
+--  polylog(4,(d*f-c*g)*(a+b*x)/((b*f-a*g)*(c+d*x)))/g
+--E 3515
+
+--S 3516 of 5341
+--a0:=integrate(t0,x)
+--E 3516
+
+--S 3517 of 5341
+--m0:=a0-r0
+--E 3517
+
+--S 3518 of 5341
+--d0:=D(m0,x)
+--E 3518
+
+)clear all
+
+--S 3519 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^3/(f+g*x)^2
+--R 
+--R
+--R               b x + a n 3
+--R        log(e (-------) )
+--R               d x + c
+--R   (1)  ------------------
+--R         2 2             2
+--R        g x  + 2f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3519
+
+--S 3520 of 5341
+--r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^3/((b*f-a*g)*(f+g*x))+_
+--  3*(b*c-a*d)*n*log(e*((a+b*x)/(c+d*x))^n)^2*log((b*c-a*d)*(f+g*x)/_
+--  ((b*f-a*g)*(c+d*x)))/((b*f-a*g)*(d*f-c*g))+6*(b*c-a*d)*n^2*_
+--  log(e*((a+b*x)/(c+d*x))^n)*polylog(2,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/_
+--  ((b*f-a*g)*(c+d*x)))/((b*f-a*g)*(d*f-c*g))-6*(b*c-a*d)*n^3*_
+--  polylog(3,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/_
+--  ((b*f-a*g)*(d*f-c*g))
+--E 3520
+
+--S 3521 of 5341
+--a0:=integrate(t0,x)
+--E 3521
+
+--S 3522 of 5341
+--m0:=a0-r0
+--E 3522
+
+--S 3523 of 5341
+--d0:=D(m0,x)
+--E 3523
+
+)clear all
+
+--S 3524 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^3/(f+g*x)^3
+--R 
+--R
+--R                    b x + a n 3
+--R             log(e (-------) )
+--R                    d x + c
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        g x  + 3f g x  + 3f g x + f
+--R                                                    Type: Expression(Integer)
+--E 3524
+
+--S 3525 of 5341
+--r0:=3/2*(b*c-a*d)*g*n*(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^2/((b*f-a*g)^2*_
+--  (d*f-c*g)*(f+g*x))-3/2*b^2*n*log((-b*c+a*d)/(d*(a+b*x)))*log(e*_
+--  ((a+b*x)/(c+d*x))^n)^2/(g*(b*f-a*g)^2)-1/2*log(e*((a+b*x)/(c+_
+--  d*x))^n)^3/(g*(f+g*x)^2)+3/2*d^2*n*log(e*((a+b*x)/(c+d*x))^n)^2*_
+--  log((b*c-a*d)/(b*(c+d*x)))/(g*(d*f-c*g)^2)-3/2*(b*c-a*d)*_
+--  (2*b*d*f-b*c*g-a*d*g)*n*log(e*((a+b*x)/(c+d*x))^n)^2*log((b*c-a*d)/_
+--  (b*(c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)+3*(b*c-a*d)^2*g*n^2*_
+--  log(e*((a+b*x)/(c+d*x))^n)*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*_
+--  (c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)+3/2*(b*c-a*d)*(2*b*d*f-b*c*g-_
+--  a*d*g)*n*log(e*((a+b*x)/(c+d*x))^n)^2*log((b*c-a*d)*(f+g*x)/_
+--  ((b*f-a*g)*(c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)+3*d^2*n^2*_
+--  log(e*((a+b*x)/(c+d*x))^n)*polylog(2,d*(a+b*x)/(b*(c+d*x)))/_
+--  (g*(d*f-c*g)^2)-3*(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*n^2*log(e*_
+--  ((a+b*x)/(c+d*x))^n)*polylog(2,d*(a+b*x)/(b*(c+d*x)))/((b*f-a*g)^2*_
+--  (d*f-c*g)^2)+3*(b*c-a*d)^2*g*n^3*polylog(2,(d*f-c*g)*(a+b*x)/_
+--  ((b*f-a*g)*(c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)+3*b^2*n^2*log(e*_
+--  ((a+b*x)/(c+d*x))^n)*polylog(2,b*(c+d*x)/(d*(a+b*x)))/(g*(b*f-_
+--  a*g)^2)+3*(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*n^2*log(e*((a+b*x)/_
+--  (c+d*x))^n)*polylog(2,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*_
+--  (c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)-3*d^2*n^3*polylog(3,d*(a+b*x)/_
+--  (b*(c+d*x)))/(g*(d*f-c*g)^2)+3*(b*c-a*d)*(2*b*d*f-b*c*g-a*d*g)*n^3*_
+--  polylog(3,d*(a+b*x)/(b*(c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)+3*b^2*n^3*_
+--  polylog(3,b*(c+d*x)/(d*(a+b*x)))/(g*(b*f-a*g)^2)-3*(b*c-a*d)*(2*b*d*f-_
+--  b*c*g-a*d*g)*n^3*polylog(3,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*_
+--  (c+d*x)))/((b*f-a*g)^2*(d*f-c*g)^2)
+--E 3525
+
+--S 3526 of 5341
+--a0:=integrate(t0,x)
+--E 3526
+
+--S 3527 of 5341
+--m0:=a0-r0
+--E 3527
+
+--S 3528 of 5341
+--d0:=D(m0,x)
+--E 3528
+
+)clear all
+
+--S 3529 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^4
+--R 
+--R
+--R               b x + a n 4
+--R   (1)  log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3529
+
+--S 3530 of 5341
+--r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^4/b+4*(b*c-a*d)*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)^3*log((b*c-a*d)/(b*(c+d*x)))/(b*d)+_
+--  12*(b*c-a*d)*n^2*log(e*((a+b*x)/(c+d*x))^n)^2*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(b*d)-24*(b*c-a*d)*n^3*log(e*((a+b*x)/(c+d*x))^n)*_
+--  polylog(3,d*(a+b*x)/(b*(c+d*x)))/(b*d)+24*(b*c-a*d)*n^4*_
+--  polylog(4,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 3530
+
+--S 3531 of 5341
+--a0:=integrate(t0,x)
+--E 3531
+
+--S 3532 of 5341
+--m0:=a0-r0
+--E 3532
+
+--S 3533 of 5341
+--d0:=D(m0,x)
+--E 3533
+
+)clear all
+
+--S 3534 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^5
+--R 
+--R
+--R               b x + a n 5
+--R   (1)  log(e (-------) )
+--R               d x + c
+--R                                                    Type: Expression(Integer)
+--E 3534
+
+--S 3535 of 5341
+--r0:=(a+b*x)*log(e*((a+b*x)/(c+d*x))^n)^5/b+5*(b*c-a*d)*n*_
+--  log(e*((a+b*x)/(c+d*x))^n)^4*log((b*c-a*d)/(b*(c+d*x)))/(b*d)+_
+--  20*(b*c-a*d)*n^2*log(e*((a+b*x)/(c+d*x))^n)^3*polylog(2,d*(a+b*x)/_
+--  (b*(c+d*x)))/(b*d)-60*(b*c-a*d)*n^3*log(e*((a+b*x)/(c+d*x))^n)^2*_
+--  polylog(3,d*(a+b*x)/(b*(c+d*x)))/(b*d)+120*(b*c-a*d)*n^4*_
+--  log(e*((a+b*x)/(c+d*x))^n)*polylog(4,d*(a+b*x)/(b*(c+d*x)))/(b*d)-_
+--  120*(b*c-a*d)*n^5*polylog(5,d*(a+b*x)/(b*(c+d*x)))/(b*d)
+--E 3535
+
+--S 3536 of 5341
+--a0:=integrate(t0,x)
+--E 3536
+
+--S 3537 of 5341
+--m0:=a0-r0
+--E 3537
+
+--S 3538 of 5341
+--d0:=D(m0,x)
+--E 3538
+
+)clear all
+
+--S 3539 of 5341
+t0:=(a+b*x)^m*(c+d*x)^(-2-m)/log(e*((a+b*x)/(c+d*x))^n)
+--R 
+--R
+--R                 m         - m - 2
+--R        (b x + a) (d x + c)
+--R   (1)  --------------------------
+--R                    b x + a n
+--R             log(e (-------) )
+--R                    d x + c
+--R                                                    Type: Expression(Integer)
+--E 3539
+
+--S 3540 of 5341
+--r0:=(a+b*x)^(1+m)*(c+d*x)^(-1-m)*Ei((1+m)*log(e*((a+b*x)/_
+--  (c+d*x))^n)/n)/((b*c-a*d)*n*(e*((a+b*x)/(c+d*x))^n)^((1+m)/n))
+--E 3540
+
+--S 3541 of 5341
+--a0:=integrate(t0,x)
+--E 3541
+
+--S 3542 of 5341
+--m0:=a0-r0
+--E 3542
+
+--S 3543 of 5341
+--d0:=D(m0,x)
+--E 3543
+
+)clear all
+
+--S 3544 of 5341
+t0:=(a+b*x)^3/((c+d*x)^5*log(e*((a+b*x)/(c+d*x))^n))
+--R 
+--R
+--R                              3 3       2 2     2       3
+--R                             b x  + 3a b x  + 3a b x + a
+--R   (1)  ---------------------------------------------------------------------
+--R          5 5       4 4      2 3 3      3 2 2     4       5        b x + a n
+--R        (d x  + 5c d x  + 10c d x  + 10c d x  + 5c d x + c )log(e (-------) )
+--R                                                                   d x + c
+--R                                                    Type: Expression(Integer)
+--E 3544
+
+--S 3545 of 5341
+--r0:=(a+b*x)^4*Ei(4*log(e*((a+b*x)/(c+d*x))^n)/n)/((b*c-a*d)*n*_
+--  (e*((a+b*x)/(c+d*x))^n)^(4/n)*(c+d*x)^4)
+--E 3545
+
+--S 3546 of 5341
+--a0:=integrate(t0,x)
+--E 3546
+
+--S 3547 of 5341
+--m0:=a0-r0
+--E 3547
+
+--S 3548 of 5341
+--d0:=D(m0,x)
+--E 3548
+
+)clear all
+
+--S 3549 of 5341
+t0:=(a+b*x)^2/((c+d*x)^4*log(e*((a+b*x)/(c+d*x))^n))
+--R 
+--R
+--R                             2 2             2
+--R                            b x  + 2a b x + a
+--R   (1)  ---------------------------------------------------------
+--R          4 4       3 3     2 2 2     3       4        b x + a n
+--R        (d x  + 4c d x  + 6c d x  + 4c d x + c )log(e (-------) )
+--R                                                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 3549
+
+--S 3550 of 5341
+--r0:=(a+b*x)^3*Ei(3*log(e*((a+b*x)/(c+d*x))^n)/n)/((b*c-a*d)*n*_
+--  (e*((a+b*x)/(c+d*x))^n)^(3/n)*(c+d*x)^3)
+--E 3550
+
+--S 3551 of 5341
+--a0:=integrate(t0,x)
+--E 3551
+
+--S 3552 of 5341
+--m0:=a0-r0
+--E 3552
+
+--S 3553 of 5341
+--d0:=D(m0,x)
+--E 3553
+
+)clear all
+
+--S 3554 of 5341
+t0:=(a+b*x)/((c+d*x)^3*log(e*((a+b*x)/(c+d*x))^n))
+--R 
+--R
+--R                            b x + a
+--R   (1)  -----------------------------------------------
+--R          3 3       2 2     2       3        b x + a n
+--R        (d x  + 3c d x  + 3c d x + c )log(e (-------) )
+--R                                             d x + c
+--R                                                    Type: Expression(Integer)
+--E 3554
+
+--S 3555 of 5341
+--r0:=(a+b*x)^2*Ei(2*log(e*((a+b*x)/(c+d*x))^n)/n)/((b*c-a*d)*n*_
+--  (e*((a+b*x)/(c+d*x))^n)^(2/n)*(c+d*x)^2)
+--E 3555
+
+--S 3556 of 5341
+--a0:=integrate(t0,x)
+--E 3556
+
+--S 3557 of 5341
+--m0:=a0-r0
+--E 3557
+
+--S 3558 of 5341
+--d0:=D(m0,x)
+--E 3558
+
+)clear all
+
+--S 3559 of 5341
+t0:=1/((c+d*x)^2*log(e*((a+b*x)/(c+d*x))^n))
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R          2 2             2        b x + a n
+--R        (d x  + 2c d x + c )log(e (-------) )
+--R                                   d x + c
+--R                                                    Type: Expression(Integer)
+--E 3559
+
+--S 3560 of 5341
+--r0:=(a+b*x)*Ei(log(e*((a+b*x)/(c+d*x))^n)/n)/((b*c-a*d)*n*_
+--  (e*((a+b*x)/(c+d*x))^n)^(1/n)*(c+d*x))
+--E 3560
+
+--S 3561 of 5341
+--a0:=integrate(t0,x)
+--E 3561
+
+--S 3562 of 5341
+--m0:=a0-r0
+--E 3562
+
+--S 3563 of 5341
+--d0:=D(m0,x)
+--E 3563
+
+)clear all
+
+--S 3564 of 5341
+t0:=1/((a+b*x)*(c+d*x)*log(e*((a+b*x)/(c+d*x))^n))
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R              2                             b x + a n
+--R        (b d x  + (a d + b c)x + a c)log(e (-------) )
+--R                                            d x + c
+--R                                                    Type: Expression(Integer)
+--E 3564
+
+--S 3565 of 5341
+r0:=log(log(e*((a+b*x)/(c+d*x))^n))/((b*c-a*d)*n)
+--R 
+--R
+--R                     b x + a n
+--R          log(log(e (-------) ))
+--R                     d x + c
+--R   (2)  - ----------------------
+--R               (a d - b c)n
+--R                                                    Type: Expression(Integer)
+--E 3565
+
+--S 3566 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             b x + a
+--R          log(log(e) + n log(-------))
+--R                             d x + c
+--R   (3)  - ----------------------------
+--R                  (a d - b c)n
+--R                                         Type: Union(Expression(Integer),...)
+--E 3566
+
+--S 3567 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                   b x + a n                        b x + a
+--R        log(log(e (-------) )) - log(log(e) + n log(-------))
+--R                   d x + c                          d x + c
+--R   (4)  -----------------------------------------------------
+--R                             (a d - b c)n
+--R                                                    Type: Expression(Integer)
+--E 3567
+
+--S 3568 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3568
+
+)clear all
+
+--S 3569 of 5341
+t0:=1/((a+b*x)^2*log(e*((a+b*x)/(c+d*x))^n))
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R          2 2             2        b x + a n
+--R        (b x  + 2a b x + a )log(e (-------) )
+--R                                   d x + c
+--R                                                    Type: Expression(Integer)
+--E 3569
+
+--S 3570 of 5341
+--r0:=(e*((a+b*x)/(c+d*x))^n)^(1/n)*(c+d*x)*Ei(-log(e*((a+b*x)/_
+--  (c+d*x))^n)/n)/((b*c-a*d)*n*(a+b*x))
+--E 3570
+
+--S 3571 of 5341
+--a0:=integrate(t0,x)
+--E 3571
+
+--S 3572 of 5341
+--m0:=a0-r0
+--E 3572
+
+--S 3573 of 5341
+--d0:=D(m0,x)
+--E 3573
+
+)clear all
+
+--S 3574 of 5341
+t0:=(c+d*x)/((a+b*x)^3*log(e*((a+b*x)/(c+d*x))^n))
+--R 
+--R
+--R                            d x + c
+--R   (1)  -----------------------------------------------
+--R          3 3       2 2     2       3        b x + a n
+--R        (b x  + 3a b x  + 3a b x + a )log(e (-------) )
+--R                                             d x + c
+--R                                                    Type: Expression(Integer)
+--E 3574
+
+--S 3575 of 5341
+--r0:=(e*((a+b*x)/(c+d*x))^n)^(2/n)*(c+d*x)^2*Ei(-2*log(e*((a+b*x)/_
+--  (c+d*x))^n)/n)/((b*c-a*d)*n*(a+b*x)^2)
+--E 3575
+
+--S 3576 of 5341
+--a0:=integrate(t0,x)
+--E 3576
+
+--S 3577 of 5341
+--m0:=a0-r0
+--E 3577
+
+--S 3578 of 5341
+--d0:=D(m0,x)
+--E 3578
+
+)clear all
+
+--S 3579 of 5341
+t0:=(c+d*x)^2/((a+b*x)^4*log(e*((a+b*x)/(c+d*x))^n))
+--R 
+--R
+--R                             2 2             2
+--R                            d x  + 2c d x + c
+--R   (1)  ---------------------------------------------------------
+--R          4 4       3 3     2 2 2     3       4        b x + a n
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )log(e (-------) )
+--R                                                       d x + c
+--R                                                    Type: Expression(Integer)
+--E 3579
+
+--S 3580 of 5341
+--r0:=(e*((a+b*x)/(c+d*x))^n)^(3/n)*(c+d*x)^3*Ei(-3*log(e*((a+b*x)/_
+--  (c+d*x))^n)/n)/((b*c-a*d)*n*(a+b*x)^3)
+--E 3580
+
+--S 3581 of 5341
+--a0:=integrate(t0,x)
+--E 3581
+
+--S 3582 of 5341
+--m0:=a0-r0
+--E 3582
+
+--S 3583 of 5341
+--d0:=D(m0,x)
+--E 3583
+
+)clear all
+
+--S 3584 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)/((c+d*x)*(f+g*x))
+--R 
+--R
+--R                    b x + a n
+--R             log(e (-------) )
+--R                    d x + c
+--R   (1)  ---------------------------
+--R             2
+--R        d g x  + (c g + d f)x + c f
+--R                                                    Type: Expression(Integer)
+--E 3584
+
+--S 3585 of 5341
+--r0:=-log(e*((a+b*x)/(c+d*x))^n)*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*_
+--  (c+d*x)))/(d*f-c*g)-n*polylog(2,(d*f-c*g)*(a+b*x)/((b*f-a*g)*_
+--  (c+d*x)))/(d*f-c*g)
+--E 3585
+
+--S 3586 of 5341
+--a0:=integrate(t0,x)
+--E 3586
+
+--S 3587 of 5341
+--m0:=a0-r0
+--E 3587
+
+--S 3588 of 5341
+--d0:=D(m0,x)
+--E 3588
+
+)clear all
+
+--S 3589 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^2/((c+d*x)*(f+g*x))
+--R 
+--R
+--R                    b x + a n 2
+--R             log(e (-------) )
+--R                    d x + c
+--R   (1)  ---------------------------
+--R             2
+--R        d g x  + (c g + d f)x + c f
+--R                                                    Type: Expression(Integer)
+--E 3589
+
+--S 3590 of 5341
+--r0:=-log(e*((a+b*x)/(c+d*x))^n)^2*log((b*c-a*d)*(f+g*x)/((b*f-a*g)*_
+--  (c+d*x)))/(d*f-c*g)-2*n*log(e*((a+b*x)/(c+d*x))^n)*polylog(2,(a*_
+--  (d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/(d*f-c*g)+2*n^2*_
+--  polylog(3,(a*(d*f-c*g)+b*d*f*x-b*c*g*x)/((b*f-a*g)*(c+d*x)))/(d*f-c*g)
+--E 3590
+
+--S 3591 of 5341
+--a0:=integrate(t0,x)
+--E 3591
+
+--S 3592 of 5341
+--m0:=a0-r0
+--E 3592
+
+--S 3593 of 5341
+--d0:=D(m0,x)
+--E 3593
+
+)clear all
+
+--S 3594 of 5341
+t0:=log(e*((a+b*x)/(c+d*x))^n)^2*log((b*c-a*d)/(b*(c+d*x)))/_
+   ((c+d*x)*(a*g+b*g*x))
+--R 
+--R
+--R            - a d + b c        b x + a n 2
+--R        log(-----------)log(e (-------) )
+--R            b d x + b c        d x + c
+--R   (1)  ----------------------------------
+--R                2
+--R         b d g x  + (a d + b c)g x + a c g
+--R                                                    Type: Expression(Integer)
+--E 3594
+
+--S 3595 of 5341
+--r0:=-log(e*((a+b*x)/(c+d*x))^n)^2*polylog(2,d*(a+b*x)/(b*(c+d*x)))/_
+--  ((b*c-a*d)*g)+2*n*log(e*((a+b*x)/(c+d*x))^n)*polylog(3,d*(a+b*x)/_
+--  (b*(c+d*x)))/((b*c-a*d)*g)-2*n^2*polylog(4,d*(a+b*x)/(b*(c+d*x)))/_
+--  ((b*c-a*d)*g)
+--E 3595
+
+--S 3596 of 5341
+--a0:=integrate(t0,x)
+--E 3596
+
+--S 3597 of 5341
+--m0:=a0-r0
+--E 3597
+
+--S 3598 of 5341
+--d0:=D(m0,x)
+--E 3598
+
+)clear all
+
+--S 3599 of 5341
+t0:=(a+b*log(c*x^n))^3
+--R 
+--R
+--R         3       n 3       2       n 2     2         n     3
+--R   (1)  b log(c x )  + 3a b log(c x )  + 3a b log(c x ) + a
+--R                                                    Type: Expression(Integer)
+--E 3599
+
+--S 3600 of 5341
+r0:=6*a*b^2*n^2*x-6*b^3*n^3*x+6*b^3*n^2*x*log(c*x^n)-_
+   3*b*n*x*(a+b*log(c*x^n))^2+x*(a+b*log(c*x^n))^3
+--R 
+--R
+--R   (2)
+--R      3         n 3        3        2          n 2
+--R     b x log(c x )  + (- 3b n + 3a b )x log(c x )
+--R   + 
+--R        3 2       2      2           n         3 3       2 2     2       3
+--R     (6b n  - 6a b n + 3a b)x log(c x ) + (- 6b n  + 6a b n  - 3a b n + a )x
+--R                                                    Type: Expression(Integer)
+--E 3600
+
+--S 3601 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      3 3        3      3 2                3 3       2 2         2
+--R     b n x log(x)  + (3b n x log(c) + (- 3b n  + 3a b n )x)log(x)
+--R   + 
+--R             3          2        3 2       2
+--R           3b n x log(c)  + (- 6b n  + 6a b n)x log(c)
+--R         + 
+--R              3 3       2 2     2
+--R           (6b n  - 6a b n  + 3a b n)x
+--R    *
+--R       log(x)
+--R   + 
+--R      3        3        3        2         2      3 2       2      2
+--R     b x log(c)  + (- 3b n + 3a b )x log(c)  + (6b n  - 6a b n + 3a b)x log(c)
+--R   + 
+--R          3 3       2 2     2       3
+--R     (- 6b n  + 6a b n  - 3a b n + a )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 3601
+
+--S 3602 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        3         n 3      3        2          n 2
+--R     - b x log(c x )  + (3b n - 3a b )x log(c x )
+--R   + 
+--R          3 2       2      2           n     3 3        3
+--R     (- 6b n  + 6a b n - 3a b)x log(c x ) + b n x log(x)
+--R   + 
+--R        3 2                3 3       2 2         2
+--R     (3b n x log(c) + (- 3b n  + 3a b n )x)log(x)
+--R   + 
+--R             3          2        3 2       2
+--R           3b n x log(c)  + (- 6b n  + 6a b n)x log(c)
+--R         + 
+--R              3 3       2 2     2
+--R           (6b n  - 6a b n  + 3a b n)x
+--R    *
+--R       log(x)
+--R   + 
+--R      3        3        3        2         2      3 2       2      2
+--R     b x log(c)  + (- 3b n + 3a b )x log(c)  + (6b n  - 6a b n + 3a b)x log(c)
+--R                                                    Type: Expression(Integer)
+--E 3602
+
+--S 3603 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3603
+
+)clear all
+
+--S 3604 of 5341
+t0:=(a+b*log(c*x^n))^2
+--R 
+--R
+--R         2       n 2               n     2
+--R   (1)  b log(c x )  + 2a b log(c x ) + a
+--R                                                    Type: Expression(Integer)
+--E 3604
+
+--S 3605 of 5341
+r0:=-2*a*b*n*x+2*b^2*n^2*x-2*b^2*n*x*log(c*x^n)+x*(a+b*log(c*x^n))^2
+--R 
+--R
+--R         2         n 2        2                  n       2 2             2
+--R   (2)  b x log(c x )  + (- 2b n + 2a b)x log(c x ) + (2b n  - 2a b n + a )x
+--R                                                    Type: Expression(Integer)
+--E 3605
+
+--S 3606 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      2 2        2      2                  2 2                      2        2
+--R     b n x log(x)  + (2b n x log(c) + (- 2b n  + 2a b n)x)log(x) + b x log(c)
+--R   + 
+--R          2                       2 2             2
+--R     (- 2b n + 2a b)x log(c) + (2b n  - 2a b n + a )x
+--R                                         Type: Union(Expression(Integer),...)
+--E 3606
+
+--S 3607 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R        2         n 2      2                  n     2 2        2
+--R     - b x log(c x )  + (2b n - 2a b)x log(c x ) + b n x log(x)
+--R   + 
+--R        2                  2 2                      2        2
+--R     (2b n x log(c) + (- 2b n  + 2a b n)x)log(x) + b x log(c)
+--R   + 
+--R          2
+--R     (- 2b n + 2a b)x log(c)
+--R                                                    Type: Expression(Integer)
+--E 3607
+
+--S 3608 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3608
+
+)clear all
+
+--S 3609 of 5341
+t0:=a+b*log(c*x^n)
+--R 
+--R
+--R                 n
+--R   (1)  b log(c x ) + a
+--R                                                    Type: Expression(Integer)
+--E 3609
+
+--S 3610 of 5341
+r0:=a*x-b*n*x+b*x*log(c*x^n)
+--R 
+--R
+--R                   n
+--R   (2)  b x log(c x ) + (- b n + a)x
+--R                                                    Type: Expression(Integer)
+--E 3610
+
+--S 3611 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  b n x log(x) + b x log(c) + (- b n + a)x
+--R                                         Type: Union(Expression(Integer),...)
+--E 3611
+
+--S 3612 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                     n
+--R   (4)  - b x log(c x ) + b n x log(x) + b x log(c)
+--R                                                    Type: Expression(Integer)
+--E 3612
+
+--S 3613 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3613
+
+)clear all
+
+--S 3614 of 5341
+t0:=1/(a+b*log(c*x^n))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R                 n
+--R        b log(c x ) + a
+--R                                                    Type: Expression(Integer)
+--E 3614
+
+--S 3615 of 5341
+--r0:=x*Ei((a+b*log(c*x^n))/(b*n))/(%e^(a/(b*n))*b*n*(c*x^n)^(1/n))
+--E 3615
+
+--S 3616 of 5341
+--a0:=integrate(t0,x)
+--E 3616
+
+--S 3617 of 5341
+--m0:=a0-r0
+--E 3617
+
+--S 3618 of 5341
+--d0:=D(m0,x)
+--E 3618
+
+)clear all
+
+--S 3619 of 5341
+t0:=1/(a+b*log(c*x^n))^2
+--R 
+--R
+--R                         1
+--R   (1)  ----------------------------------
+--R         2       n 2               n     2
+--R        b log(c x )  + 2a b log(c x ) + a
+--R                                                    Type: Expression(Integer)
+--E 3619
+
+--S 3620 of 5341
+--r0:=x*Ei((a+b*log(c*x^n))/(b*n))/(%e^(a/(b*n))*b^2*n^2*(c*x^n)^(1/n))-_
+--  x/(b*n*(a+b*log(c*x^n)))
+--E 3620
+
+--S 3621 of 5341
+--a0:=integrate(t0,x)
+--E 3621
+
+--S 3622 of 5341
+--m0:=a0-r0
+--E 3622
+
+--S 3623 of 5341
+--d0:=D(m0,x)
+--E 3623
+
+)clear all
+
+--S 3624 of 5341
+t0:=1/(a+b*log(c*x^n))^3
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R         3       n 3       2       n 2     2         n     3
+--R        b log(c x )  + 3a b log(c x )  + 3a b log(c x ) + a
+--R                                                    Type: Expression(Integer)
+--E 3624
+
+--S 3625 of 5341
+--r0:=1/2*x*Ei((a+b*log(c*x^n))/(b*n))/(%e^(a/(b*n))*b^3*n^3*(c*x^n)^(1/n))-_
+--  1/2*x/(b*n*(a+b*log(c*x^n))^2)-1/2*x/(b^2*n^2*(a+b*log(c*x^n)))
+--E 3625
+
+--S 3626 of 5341
+--a0:=integrate(t0,x)
+--E 3626
+
+--S 3627 of 5341
+--m0:=a0-r0
+--E 3627
+
+--S 3628 of 5341
+--d0:=D(m0,x)
+--E 3628
+
+)clear all
+
+--S 3629 of 5341
+t0:=(a+b*log(c*x^n))^m
+--R 
+--R
+--R                  n      m
+--R   (1)  (b log(c x ) + a)
+--R                                                    Type: Expression(Integer)
+--E 3629
+
+--S 3630 of 5341
+--r0:=x*GAMMA(1+m,(-a-b*log(c*x^n))/(b*n))*(a+b*log(c*x^n))^m/(%e^(a/(b*n))*_
+--  (c*x^n)^(1/n)*((-a-b*log(c*x^n))/(b*n))^m)
+--E 3630
+
+--S 3631 of 5341
+--a0:=integrate(t0,x)
+--E 3631
+
+--S 3632 of 5341
+--m0:=a0-r0
+--E 3632
+
+--S 3633 of 5341
+--d0:=D(m0,x)
+--E 3633
+
+)clear all
+
+--S 3634 of 5341
+t0:=x^m/(a+b*log(c*x^n))
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ---------------
+--R                 n
+--R        b log(c x ) + a
+--R                                                    Type: Expression(Integer)
+--E 3634
+
+--S 3635 of 5341
+--r0:=x^(1+m)*Ei((1+m)*(a+b*log(c*x^n))/(b*n))/(%e^(a*(1+m)/(b*n))*b*_
+--  n*(c*x^n)^((1+m)/n))
+--E 3635
+
+--S 3636 of 5341
+--a0:=integrate(t0,x)
+--E 3636
+
+--S 3637 of 5341
+--m0:=a0-r0
+--E 3637
+
+--S 3638 of 5341
+--d0:=D(m0,x)
+--E 3638
+
+)clear all
+
+--S 3639 of 5341
+t0:=x^m/(a+b*log(c*x^n))^2
+--R 
+--R
+--R                         m
+--R                        x
+--R   (1)  ----------------------------------
+--R         2       n 2               n     2
+--R        b log(c x )  + 2a b log(c x ) + a
+--R                                                    Type: Expression(Integer)
+--E 3639
+
+--S 3640 of 5341
+--r0:=(1+m)*x^(1+m)*Ei((1+m)*(a+b*log(c*x^n))/(b*n))/(%e^(a*(1+m)/(b*n))*_
+--  b^2*n^2*(c*x^n)^((1+m)/n))-x^(1+m)/(b*n*(a+b*log(c*x^n)))
+--E 3640
+
+--S 3641 of 5341
+--a0:=integrate(t0,x)
+--E 3641
+
+--S 3642 of 5341
+--m0:=a0-r0
+--E 3642
+
+--S 3643 of 5341
+--d0:=D(m0,x)
+--E 3643
+
+)clear all
+
+--S 3644 of 5341
+t0:=x^m*(a+b*log(c*x^n))^p
+--R 
+--R
+--R         m          n      p
+--R   (1)  x (b log(c x ) + a)
+--R                                                    Type: Expression(Integer)
+--E 3644
+
+--S 3645 of 5341
+--r0:=x^(1+m)*GAMMA(1+p,-(1+m)*(a+b*log(c*x^n))/(b*n))*(a+b*_
+--  log(c*x^n))^p/(%e^(a*(1+m)/(b*n))*(1+m)*(c*x^n)^((1+m)/n)*(-(1+m)*_
+--  (a+b*log(c*x^n))/(b*n))^p)
+--E 3645
+
+--S 3646 of 5341
+--a0:=integrate(t0,x)
+--E 3646
+
+--S 3647 of 5341
+--m0:=a0-r0
+--E 3647
+
+--S 3648 of 5341
+--d0:=D(m0,x)
+--E 3648
+
+)clear all
+
+--S 3649 of 5341
+t0:=x^(-1+n)*log(-b*x^n/a)/(a+b*x^n)
+--R 
+--R
+--R                       n
+--R         n - 1      b x
+--R        x     log(- ----)
+--R                      a
+--R   (1)  -----------------
+--R                n
+--R             b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3649
+
+--S 3650 of 5341
+--r0:=-polylog(2,(a+b*x^n)/a)/(b*n)
+--E 3650
+
+--S 3651 of 5341
+--a0:=integrate(t0,x)
+--E 3651
+
+--S 3652 of 5341
+--m0:=a0-r0
+--E 3652
+
+--S 3653 of 5341
+--d0:=D(m0,x)
+--E 3653
+
+)clear all
+
+--S 3654 of 5341
+t0:=x^3*(a+b*log(c*(a+b*x)^p))/(d+e*x)
+--R 
+--R
+--R           3               p       3
+--R        b x log(c (b x + a) ) + a x
+--R   (1)  ----------------------------
+--R                   e x + d
+--R                                                    Type: Expression(Integer)
+--E 3654
+
+--S 3655 of 5341
+--r0:=a*d^2*x/e^3-b*d^2*p*x/e^3-1/2*a*d*p*x/e^2-1/3*a^2*p*x/(b*e)+_
+--  1/4*b*d*p*x^2/e^2+1/6*a*p*x^2/e-1/9*b*p*x^3/e+1/2*a^2*d*p*log(a+b*x)/_
+--  (b*e^2)+1/3*a^3*p*log(a+b*x)/(b^2*e)+d^2*(a+b*x)*log(c*(a+b*x)^p)/e^3-_
+--  1/2*d*x^2*(a+b*log(c*(a+b*x)^p))/e^2+1/3*x^3*(a+b*log(c*(a+b*x)^p))/e-_
+--  d^3*(a+b*log(c*(a+b*x)^p))*log(b*(d+e*x)/(b*d-a*e))/e^4-b*d^3*p*_
+--  polylog(2,-e*(a+b*x)/(b*d-a*e))/e^4
+--E 3655
+
+--S 3656 of 5341
+--a0:=integrate(t0,x)
+--E 3656
+
+--S 3657 of 5341
+--m0:=a0-r0
+--E 3657
+
+--S 3658 of 5341
+--d0:=D(m0,x)
+--E 3658
+
+)clear all
+
+--S 3659 of 5341
+t0:=x^2*(a+b*log(c*(a+b*x)^p))/(d+e*x)
+--R 
+--R
+--R           2               p       2
+--R        b x log(c (b x + a) ) + a x
+--R   (1)  ----------------------------
+--R                   e x + d
+--R                                                    Type: Expression(Integer)
+--E 3659
+
+--S 3660 of 5341
+--r0:=-a*d*x/e^2+b*d*p*x/e^2+1/2*a*p*x/e-1/4*b*p*x^2/e-1/2*a^2*p*_
+--  log(a+b*x)/(b*e)-d*(a+b*x)*log(c*(a+b*x)^p)/e^2+1/2*x^2*(a+_
+--  b*log(c*(a+b*x)^p))/e+d^2*(a+b*log(c*(a+b*x)^p))*log(b*(d+e*x)/_
+--  (b*d-a*e))/e^3+b*d^2*p*polylog(2,-e*(a+b*x)/(b*d-a*e))/e^3
+--E 3660
+
+--S 3661 of 5341
+--a0:=integrate(t0,x)
+--E 3661
+
+--S 3662 of 5341
+--m0:=a0-r0
+--E 3662
+
+--S 3663 of 5341
+--d0:=D(m0,x)
+--E 3663
+
+)clear all
+
+--S 3664 of 5341
+t0:=x*(a+b*log(c*(a+b*x)^p))/(d+e*x)
+--R 
+--R
+--R                           p
+--R        b x log(c (b x + a) ) + a x
+--R   (1)  ---------------------------
+--R                  e x + d
+--R                                                    Type: Expression(Integer)
+--E 3664
+
+--S 3665 of 5341
+--r0:=a*x/e-b*p*x/e+(a+b*x)*log(c*(a+b*x)^p)/e-d*(a+b*log(c*(a+b*x)^p))*_
+--  log(b*(d+e*x)/(b*d-a*e))/e^2-b*d*p*polylog(2,-e*(a+b*x)/(b*d-a*e))/e^2
+--E 3665
+
+--S 3666 of 5341
+--a0:=integrate(t0,x)
+--E 3666
+
+--S 3667 of 5341
+--m0:=a0-r0
+--E 3667
+
+--S 3668 of 5341
+--d0:=D(m0,x)
+--E 3668
+
+)clear all
+
+--S 3669 of 5341
+t0:=(a+b*log(c*(a+b*x)^p))/(d+e*x)
+--R 
+--R
+--R                         p
+--R        b log(c (b x + a) ) + a
+--R   (1)  -----------------------
+--R                e x + d
+--R                                                    Type: Expression(Integer)
+--E 3669
+
+--S 3670 of 5341
+--r0:=(a+b*log(c*(a+b*x)^p))*log(b*(d+e*x)/(b*d-a*e))/e+_
+--  b*p*polylog(2,-e*(a+b*x)/(b*d-a*e))/e
+--E 3670
+
+--S 3671 of 5341
+--a0:=integrate(t0,x)
+--E 3671
+
+--S 3672 of 5341
+--m0:=a0-r0
+--E 3672
+
+--S 3673 of 5341
+--d0:=D(m0,x)
+--E 3673
+
+)clear all
+
+--S 3674 of 5341
+t0:=(a+b*log(c*(a+b*x)^p))/(x*(d+e*x))
+--R 
+--R
+--R                         p
+--R        b log(c (b x + a) ) + a
+--R   (1)  -----------------------
+--R                  2
+--R               e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 3674
+
+--S 3675 of 5341
+--r0:=log(-b*x/a)*(a+b*log(c*(a+b*x)^p))/d-(a+b*log(c*(a+b*x)^p))*_
+--  log(b*(d+e*x)/(b*d-a*e))/d+b*p*polylog(2,(a+b*x)/a)/d-b*p*_
+--  polylog(2,-e*(a+b*x)/(b*d-a*e))/d
+--E 3675
+
+--S 3676 of 5341
+--a0:=integrate(t0,x)
+--E 3676
+
+--S 3677 of 5341
+--m0:=a0-r0
+--E 3677
+
+--S 3678 of 5341
+--d0:=D(m0,x)
+--E 3678
+
+)clear all
+
+--S 3679 of 5341
+t0:=(a+b*log(c*(a+b*x)^p))/(x^2*(d+e*x))
+--R 
+--R
+--R                         p
+--R        b log(c (b x + a) ) + a
+--R   (1)  -----------------------
+--R                 3      2
+--R              e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 3679
+
+--S 3680 of 5341
+--r0:=b^2*p*log(x)/(a*d)-b^2*p*log(a+b*x)/(a*d)+(-a-b*log(c*(a+_
+--  b*x)^p))/(d*x)-e*log(-b*x/a)*(a+b*log(c*(a+b*x)^p))/d^2+e*(a+_
+--  b*log(c*(a+b*x)^p))*log(b*(d+e*x)/(b*d-a*e))/d^2-b*e*p*_
+--  polylog(2,(a+b*x)/a)/d^2+b*e*p*polylog(2,-e*(a+b*x)/(b*d-a*e))/d^2
+--E 3680
+
+--S 3681 of 5341
+--a0:=integrate(t0,x)
+--E 3681
+
+--S 3682 of 5341
+--m0:=a0-r0
+--E 3682
+
+--S 3683 of 5341
+--d0:=D(m0,x)
+--E 3683
+
+)clear all
+
+--S 3684 of 5341
+t0:=(a+b*log(c*(a+b*x)^p))/(x^3*(d+e*x))
+--R 
+--R
+--R                         p
+--R        b log(c (b x + a) ) + a
+--R   (1)  -----------------------
+--R                 4      3
+--R              e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 3684
+
+--S 3685 of 5341
+--r0:=-1/2*b^2*p/(a*d*x)-1/2*b^3*p*log(x)/(a^2*d)-b^2*e*p*log(x)/(a*d^2)+_
+--  1/2*b^3*p*log(a+b*x)/(a^2*d)+b^2*e*p*log(a+b*x)/(a*d^2)+1/2*(-a-b*_
+--  log(c*(a+b*x)^p))/(d*x^2)+e*(a+b*log(c*(a+b*x)^p))/(d^2*x)+e^2*_
+--  log(-b*x/a)*(a+b*log(c*(a+b*x)^p))/d^3-e^2*(a+b*log(c*(a+b*x)^p))*_
+--  log(b*(d+e*x)/(b*d-a*e))/d^3+b*e^2*p*polylog(2,(a+b*x)/a)/d^3-_
+--  b*e^2*p*polylog(2,-e*(a+b*x)/(b*d-a*e))/d^3
+--E 3685
+
+--S 3686 of 5341
+--a0:=integrate(t0,x)
+--E 3686
+
+--S 3687 of 5341
+--m0:=a0-r0
+--E 3687
+
+--S 3688 of 5341
+--d0:=D(m0,x)
+--E 3688
+
+)clear all
+
+--S 3689 of 5341
+t0:=x^3*(a+b*log(c*(a+b*x)^p))^2/(d+e*x)
+--R 
+--R
+--R         2 3               p 2         3               p     2 3
+--R        b x log(c (b x + a) )  + 2a b x log(c (b x + a) ) + a x
+--R   (1)  --------------------------------------------------------
+--R                                 e x + d
+--R                                                    Type: Expression(Integer)
+--E 3689
+
+--S 3690 of 5341
+--r0:=-2*a*b*d^2*p*x/e^3-a^2*d*p*x/e^2-2/3*a^3*p*x/(b*e)+2*b^2*d^2*p^2*_
+--  x/e^3+3/2*a*b*d*p^2*x/e^2+11/9*a^2*p^2*x/e-1/4*b^2*d*p^2*x^2/e^2-_
+--  5/18*a*b*p^2*x^2/e+2/27*b^2*p^2*x^3/e-1/2*a^2*d*p^2*log(a+b*x)/e^2-_
+--  5/9*a^3*p^2*log(a+b*x)/(b*e)-2*b*d^2*p*(a+b*x)*log(c*(a+b*x)^p)/e^3-_
+--  a*d*p*(a+b*x)*log(c*(a+b*x)^p)/e^2-2/3*a^2*p*(a+b*x)*log(c*(a+b*x)^p)/_
+--  (b*e)+1/2*b*d*p*x^2*(a+b*log(c*(a+b*x)^p))/e^2+1/3*a*p*x^2*(a+b*_
+--  log(c*(a+b*x)^p))/e-2/9*b*p*x^3*(a+b*log(c*(a+b*x)^p))/e+d^2*(a+b*x)*_
+--  (a+b*log(c*(a+b*x)^p))^2/(b*e^3)+1/2*a*d*(a+b*x)*(a+b*log(c*_
+--  (a+b*x)^p))^2/(b^2*e^2)+1/3*a^2*(a+b*x)*(a+b*log(c*(a+b*x)^p))^2/_
+--  (b^3*e)-1/2*d*x*(a+b*x)*(a+b*log(c*(a+b*x)^p))^2/(b*e^2)-1/3*a*x*_
+--  (a+b*x)*(a+b*log(c*(a+b*x)^p))^2/(b^2*e)+1/3*x^2*(a+b*x)*(a+_
+--  b*log(c*(a+b*x)^p))^2/(b*e)-d^3*(a+b*log(c*(a+b*x)^p))^2*log(b*_
+--  (d+e*x)/(b*d-a*e))/e^4-2*b*d^3*p*(a+b*log(c*(a+b*x)^p))*_
+--  polylog(2,-e*(a+b*x)/(b*d-a*e))/e^4+2*b^2*d^3*p^2*_
+--  polylog(3,-e*(a+b*x)/(b*d-a*e))/e^4
+--E 3690
+
+--S 3691 of 5341
+--a0:=integrate(t0,x)
+--E 3691
+
+--S 3692 of 5341
+--m0:=a0-r0
+--E 3692
+
+--S 3693 of 5341
+--d0:=D(m0,x)
+--E 3693
+
+)clear all
+
+--S 3694 of 5341
+t0:=x^2*(a+b*log(c*(a+b*x)^p))^2/(d+e*x)
+--R 
+--R
+--R         2 2               p 2         2               p     2 2
+--R        b x log(c (b x + a) )  + 2a b x log(c (b x + a) ) + a x
+--R   (1)  --------------------------------------------------------
+--R                                 e x + d
+--R                                                    Type: Expression(Integer)
+--E 3694
+
+--S 3695 of 5341
+--r0:=2*a*b*d*p*x/e^2+a^2*p*x/e-2*b^2*d*p^2*x/e^2-3/2*a*b*p^2*x/e+1/4*b^2*_
+--  p^2*x^2/e+1/2*a^2*p^2*log(a+b*x)/e+2*b*d*p*(a+b*x)*log(c*(a+b*x)^p)/e^2+_
+--  a*p*(a+b*x)*log(c*(a+b*x)^p)/e-1/2*b*p*x^2*(a+b*log(c*(a+b*x)^p))/e-_
+--  d*(a+b*x)*(a+b*log(c*(a+b*x)^p))^2/(b*e^2)-1/2*a*(a+b*x)*(a+_
+--  b*log(c*(a+b*x)^p))^2/(b^2*e)+1/2*x*(a+b*x)*(a+b*log(c*(a+_
+--  b*x)^p))^2/(b*e)+d^2*(a+b*log(c*(a+b*x)^p))^2*log(b*(d+e*x)/_
+--  (b*d-a*e))/e^3+2*b*d^2*p*(a+b*log(c*(a+b*x)^p))*_
+--  polylog(2,-e*(a+b*x)/(b*d-a*e))/e^3-2*b^2*d^2*p^2*_
+--  polylog(3,-e*(a+b*x)/(b*d-a*e))/e^3
+--E 3695
+
+--S 3696 of 5341
+--a0:=integrate(t0,x)
+--E 3696
+
+--S 3697 of 5341
+--m0:=a0-r0
+--E 3697
+
+--S 3698 of 5341
+--d0:=D(m0,x)
+--E 3698
+
+)clear all
+
+--S 3699 of 5341
+t0:=x*(a+b*log(c*(a+b*x)^p))^2/(d+e*x)
+--R 
+--R
+--R         2                 p 2                         p     2
+--R        b x log(c (b x + a) )  + 2a b x log(c (b x + a) ) + a x
+--R   (1)  -------------------------------------------------------
+--R                                e x + d
+--R                                                    Type: Expression(Integer)
+--E 3699
+
+--S 3700 of 5341
+--r0:=-2*a*b*p*x/e+2*b^2*p^2*x/e-2*b*p*(a+b*x)*log(c*(a+b*x)^p)/e+(a+b*x)*_
+--  (a+b*log(c*(a+b*x)^p))^2/(b*e)-d*(a+b*log(c*(a+b*x)^p))^2*log(b*_
+--  (d+e*x)/(b*d-a*e))/e^2-2*b*d*p*(a+b*log(c*(a+b*x)^p))*_
+--  polylog(2,-e*(a+b*x)/(b*d-a*e))/e^2+2*b^2*d*p^2*_
+--  polylog(3,-e*(a+b*x)/(b*d-a*e))/e^2
+--E 3700
+
+--S 3701 of 5341
+--a0:=integrate(t0,x)
+--E 3701
+
+--S 3702 of 5341
+--m0:=a0-r0
+--E 3702
+
+--S 3703 of 5341
+--d0:=D(m0,x)
+--E 3703
+
+)clear all
+
+--S 3704 of 5341
+t0:=(a+b*log(c*(a+b*x)^p))^2/(d+e*x)
+--R 
+--R
+--R         2               p 2                       p     2
+--R        b log(c (b x + a) )  + 2a b log(c (b x + a) ) + a
+--R   (1)  --------------------------------------------------
+--R                              e x + d
+--R                                                    Type: Expression(Integer)
+--E 3704
+
+--S 3705 of 5341
+--r0:=(a+b*log(c*(a+b*x)^p))^2*log(b*(d+e*x)/(b*d-a*e))/e+2*b*p*(a+_
+--  b*log(c*(a+b*x)^p))*polylog(2,-e*(a+b*x)/(b*d-a*e))/e-2*b^2*p^2*_
+--  polylog(3,-e*(a+b*x)/(b*d-a*e))/e
+--E 3705
+
+--S 3706 of 5341
+--a0:=integrate(t0,x)
+--E 3706
+
+--S 3707 of 5341
+--m0:=a0-r0
+--E 3707
+
+--S 3708 of 5341
+--d0:=D(m0,x)
+--E 3708
+
+)clear all
+
+--S 3709 of 5341
+t0:=(a+b*log(c*(a+b*x)^p))^2/(x*(d+e*x))
+--R 
+--R
+--R         2               p 2                       p     2
+--R        b log(c (b x + a) )  + 2a b log(c (b x + a) ) + a
+--R   (1)  --------------------------------------------------
+--R                               2
+--R                            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 3709
+
+--S 3710 of 5341
+--r0:=log(-b*x/a)*(a+b*log(c*(a+b*x)^p))^2/d-(a+b*log(c*(a+b*x)^p))^2*_
+--  log(b*(d+e*x)/(b*d-a*e))/d+2*b*p*(a+b*log(c*(a+b*x)^p))*_
+--  polylog(2,(a+b*x)/a)/d-2*b*p*(a+b*log(c*(a+b*x)^p))*_
+--  polylog(2,-e*(a+b*x)/(b*d-a*e))/d-2*b^2*p^2*polylog(3,(a+b*x)/a)/d+_
+--  2*b^2*p^2*polylog(3,-e*(a+b*x)/(b*d-a*e))/d
+--E 3710
+
+--S 3711 of 5341
+--a0:=integrate(t0,x)
+--E 3711
+
+--S 3712 of 5341
+--m0:=a0-r0
+--E 3712
+
+--S 3713 of 5341
+--d0:=D(m0,x)
+--E 3713
+
+)clear all
+
+--S 3714 of 5341
+t0:=(a+b*log(c*(a+b*x)^p))^2/(x^2*(d+e*x))
+--R 
+--R
+--R         2               p 2                       p     2
+--R        b log(c (b x + a) )  + 2a b log(c (b x + a) ) + a
+--R   (1)  --------------------------------------------------
+--R                               3      2
+--R                            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 3714
+
+--S 3715 of 5341
+--r0:=2*b^2*p*log(-b*x/a)*(a+b*log(c*(a+b*x)^p))/(a*d)-(a+b*x)*(a+_
+--  b*log(c*(a+b*x)^p))^2/(a*d*x)-e*log(-b*x/a)*(a+b*log(c*(a+b*x)^p))^2/d^2+_
+--  e*(a+b*log(c*(a+b*x)^p))^2*log(b*(d+e*x)/(b*d-a*e))/d^2+2*b^3*p^2*_
+--  polylog(2,(a+b*x)/a)/(a*d)-2*b*e*p*(a+b*log(c*(a+b*x)^p))*_
+--  polylog(2,(a+b*x)/a)/d^2+2*b*e*p*(a+b*log(c*(a+b*x)^p))*_
+--  polylog(2,-e*(a+b*x)/(b*d-a*e))/d^2+2*b^2*e*p^2*polylog(3,(a+b*x)/a)/_
+--  d^2-2*b^2*e*p^2*polylog(3,-e*(a+b*x)/(b*d-a*e))/d^2
+--E 3715
+
+--S 3716 of 5341
+--a0:=integrate(t0,x)
+--E 3716
+
+--S 3717 of 5341
+--m0:=a0-r0
+--E 3717
+
+--S 3718 of 5341
+--d0:=D(m0,x)
+--E 3718
+
+)clear all
+
+--S 3719 of 5341
+t0:=(a+b*log(c*(a+b*x)^p))^2/(x^3*(d+e*x))
+--R 
+--R
+--R         2               p 2                       p     2
+--R        b log(c (b x + a) )  + 2a b log(c (b x + a) ) + a
+--R   (1)  --------------------------------------------------
+--R                               4      3
+--R                            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 3719
+
+--S 3720 of 5341
+--r0:=b^4*p^2*log(x)/(a^2*d)-b^4*p^2*log(a+b*x)/(a^2*d)-b^2*p*(a+b*_
+--  log(c*(a+b*x)^p))/(a*d*x)-b^3*p*log(-b*x/a)*(a+b*log(c*(a+b*x)^p))/_
+--  (a^2*d)-2*b^2*e*p*log(-b*x/a)*(a+b*log(c*(a+b*x)^p))/(a*d^2)-_
+--  1/2*(a+b*x)*(a+b*log(c*(a+b*x)^p))^2/(a*d*x^2)+1/2*b*(a+b*x)*(a+_
+--  b*log(c*(a+b*x)^p))^2/(a^2*d*x)+e*(a+b*x)*(a+b*log(c*(a+b*x)^p))^2/_
+--  (a*d^2*x)+e^2*log(-b*x/a)*(a+b*log(c*(a+b*x)^p))^2/d^3-e^2*(a+_
+--  b*log(c*(a+b*x)^p))^2*log(b*(d+e*x)/(b*d-a*e))/d^3-b^4*p^2*_
+--  polylog(2,(a+b*x)/a)/(a^2*d)-2*b^3*e*p^2*polylog(2,(a+b*x)/a)/_
+--  (a*d^2)+2*b*e^2*p*(a+b*log(c*(a+b*x)^p))*polylog(2,(a+b*x)/a)/d^3-_
+--  2*b*e^2*p*(a+b*log(c*(a+b*x)^p))*polylog(2,-e*(a+b*x)/(b*d-a*e))/d^3-_
+--  2*b^2*e^2*p^2*polylog(3,(a+b*x)/a)/d^3+2*b^2*e^2*p^2*polylog(3,_
+--  -e*(a+b*x)/(b*d-a*e))/d^3
+--E 3720
+
+--S 3721 of 5341
+--a0:=integrate(t0,x)
+--E 3721
+
+--S 3722 of 5341
+--m0:=a0-r0
+--E 3722
+
+--S 3723 of 5341
+--d0:=D(m0,x)
+--E 3723
+
+)clear all
+
+--S 3724 of 5341
+t0:=log(c*(b*(d+e*x)^n)^p)
+--R 
+--R
+--R                          n p
+--R   (1)  log(c (b (e x + d) ) )
+--R                                                    Type: Expression(Integer)
+--E 3724
+
+--S 3725 of 5341
+r0:=-n*p*x+(d+e*x)*log(c*(b*(d+e*x)^n)^p)/e
+--R 
+--R
+--R                                   n p
+--R        (e x + d)log(c (b (e x + d) ) ) - e n p x
+--R   (2)  -----------------------------------------
+--R                            e
+--R                                                    Type: Expression(Integer)
+--E 3725
+
+--S 3726 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (e n p x + d n p)log(e x + d) + e x log(c) + e p x log(b) - e n p x
+--R   (3)  -------------------------------------------------------------------
+--R                                         e
+--R                                         Type: Union(Expression(Integer),...)
+--E 3726
+
+--S 3727 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                    n p
+--R       (- e x - d)log(c (b (e x + d) ) ) + (e n p x + d n p)log(e x + d)
+--R     + 
+--R       e x log(c) + e p x log(b)
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 3727
+
+--S 3728 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3728
+
+)clear all
+
+--S 3729 of 5341
+t0:=log(c*(a+b*(d+e*x)^2)^p)
+--R 
+--R
+--R                  2 2                 2     p
+--R   (1)  log(c (b e x  + 2b d e x + b d  + a) )
+--R                                                    Type: Expression(Integer)
+--E 3729
+
+--S 3730 of 5341
+r0:=-2*p*x+d*p*log(a+b*d^2+2*b*d*e*x+b*e^2*x^2)/e+x*log(c*(a+b*(d+e*x)^2)^p)+_
+   2*p*atan((d+e*x)*sqrt(b)/sqrt(a))*sqrt(a)/(e*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                                                                            +-+
+--R           +-+          2 2                 2     p       +-+     (e x + d)\|b
+--R       e x\|b log(c (b e x  + 2b d e x + b d  + a) ) + 2p\|a atan(-------------)
+--R                                                                        +-+
+--R                                                                       \|a
+--R     + 
+--R                   2 2                 2                +-+
+--R       (d p log(b e x  + 2b d e x + b d  + a) - 2e p x)\|b
+--R  /
+--R       +-+
+--R     e\|b
+--R                                                    Type: Expression(Integer)
+--E 3730
+
+--S 3731 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                    +---+
+--R                                    |  a       2 2                 2
+--R           +---+    (2b e x + 2b d) |- -  + b e x  + 2b d e x + b d  - a
+--R           |  a                    \|  b
+--R         p |- - log(----------------------------------------------------)
+--R          \|  b                    2 2                 2
+--R                                b e x  + 2b d e x + b d  + a
+--R       + 
+--R                             2 2                 2
+--R         (e p x + d p)log(b e x  + 2b d e x + b d  + a) + e x log(c) - 2e p x
+--R    /
+--R       e
+--R     ,
+--R
+--R                         +-+
+--R                         |a
+--R              +-+        |-
+--R              |a        \|b                          2 2                 2
+--R         - 2p |- atan(-------) + (e p x + d p)log(b e x  + 2b d e x + b d  + a)
+--R             \|b      e x + d
+--R       + 
+--R         e x log(c) - 2e p x
+--R    /
+--R       e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 3731
+
+--S 3732 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                      +---+
+--R                                      |  a       2 2                 2
+--R         +---+        (2b e x + 2b d) |- -  + b e x  + 2b d e x + b d  - a
+--R         |  a  +-+                   \|  b
+--R       p |- - \|b log(----------------------------------------------------)
+--R        \|  b                        2 2                 2
+--R                                  b e x  + 2b d e x + b d  + a
+--R     + 
+--R             +-+          2 2                 2     p
+--R       - e x\|b log(c (b e x  + 2b d e x + b d  + a) )
+--R     + 
+--R                              +-+
+--R            +-+     (e x + d)\|b
+--R       - 2p\|a atan(-------------)
+--R                          +-+
+--R                         \|a
+--R     + 
+--R                     2 2                 2                    +-+
+--R       (e p x log(b e x  + 2b d e x + b d  + a) + e x log(c))\|b
+--R  /
+--R       +-+
+--R     e\|b
+--R                                                    Type: Expression(Integer)
+--E 3732
+
+--S 3733 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3733
+
+--S 3734 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             +-+          2 2                 2     p
+--R       - e x\|b log(c (b e x  + 2b d e x + b d  + a) )
+--R     + 
+--R                                                       +-+
+--R                                                       |a
+--R                              +-+       +-+            |-
+--R            +-+     (e x + d)\|b        |a  +-+       \|b
+--R       - 2p\|a atan(-------------) - 2p |- \|b atan(-------)
+--R                          +-+          \|b          e x + d
+--R                         \|a
+--R     + 
+--R                     2 2                 2                    +-+
+--R       (e p x log(b e x  + 2b d e x + b d  + a) + e x log(c))\|b
+--R  /
+--R       +-+
+--R     e\|b
+--R                                                    Type: Expression(Integer)
+--E 3734
+
+--S 3735 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 3735
+
+)clear all
+
+--S 3736 of 5341
+t0:=log(c*(a+b*(d+e*x))^p)
+--R 
+--R
+--R                               p
+--R   (1)  log(c (b e x + b d + a) )
+--R                                                    Type: Expression(Integer)
+--E 3736
+
+--S 3737 of 5341
+r0:=-p*x+(a+b*d+b*e*x)*log(c*(a+b*d+b*e*x)^p)/(b*e)
+--R 
+--R
+--R                                                p
+--R        (b e x + b d + a)log(c (b e x + b d + a) ) - b e p x
+--R   (2)  ----------------------------------------------------
+--R                                 b e
+--R                                                    Type: Expression(Integer)
+--E 3737
+
+--S 3738 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (b e p x + (b d + a)p)log(b e x + b d + a) + b e x log(c) - b e p x
+--R   (3)  -------------------------------------------------------------------
+--R                                        b e
+--R                                         Type: Union(Expression(Integer),...)
+--E 3738
+
+--S 3739 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                 p
+--R       (- b e x - b d - a)log(c (b e x + b d + a) )
+--R     + 
+--R       (b e p x + (b d + a)p)log(b e x + b d + a) + b e x log(c)
+--R  /
+--R     b e
+--R                                                    Type: Expression(Integer)
+--E 3739
+
+--S 3740 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3740
+
+)clear all
+
+--S 3741 of 5341
+t0:=log(c*(a+b/(d+e*x))^p)
+--R 
+--R
+--R               a e x + a d + b p
+--R   (1)  log(c (---------------) )
+--R                   e x + d
+--R                                                    Type: Expression(Integer)
+--E 3741
+
+--S 3742 of 5341
+r0:=(d+e*x)*log(c*(a+b/(d+e*x))^p)/e+b*p*log(b+a*(d+e*x))/(a*e)
+--R 
+--R
+--R                            a e x + a d + b p
+--R        (a e x + a d)log(c (---------------) ) + b p log(a e x + a d + b)
+--R                                e x + d
+--R   (2)  -----------------------------------------------------------------
+--R                                       a e
+--R                                                    Type: Expression(Integer)
+--E 3742
+
+--S 3743 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       (a d + b)p log(a e x + a d + b) - a d p log(e x + d) + a e x log(c)
+--R     + 
+--R                   a e x + a d + b
+--R       a e p x log(---------------)
+--R                       e x + d
+--R  /
+--R     a e
+--R                                         Type: Union(Expression(Integer),...)
+--E 3743
+
+--S 3744 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                         a e x + a d + b p
+--R       (- e x - d)log(c (---------------) ) + d p log(a e x + a d + b)
+--R                             e x + d
+--R     + 
+--R                                                   a e x + a d + b
+--R       - d p log(e x + d) + e x log(c) + e p x log(---------------)
+--R                                                       e x + d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 3744
+
+--S 3745 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3745
+
+)clear all
+
+--S 3746 of 5341
+t0:=log(c*(a+b/(d+e*x)^2)^p)
+--R 
+--R
+--R                  2 2                 2     p
+--R               a e x  + 2a d e x + a d  + b
+--R   (1)  log(c (----------------------------) )
+--R                     2 2             2
+--R                    e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 3746
+
+--S 3747 of 5341
+r0:=(d+e*x)*log(c*(a+b/(d+e*x)^2)^p)/e+2*p*atan((d+e*x)*sqrt(a)/sqrt(b))*_
+   sqrt(b)/(e*sqrt(a))
+--R 
+--R
+--R   (2)
+--R                              2 2                 2     p
+--R                 +-+       a e x  + 2a d e x + a d  + b
+--R       (e x + d)\|a log(c (----------------------------) )
+--R                                 2 2             2
+--R                                e x  + 2d e x + d
+--R     + 
+--R                            +-+
+--R          +-+     (e x + d)\|a
+--R       2p\|b atan(-------------)
+--R                        +-+
+--R                       \|b
+--R  /
+--R       +-+
+--R     e\|a
+--R                                                    Type: Expression(Integer)
+--E 3747
+
+--S 3748 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                    +---+
+--R                                    |  b       2 2                 2
+--R           +---+    (2a e x + 2a d) |- -  + a e x  + 2a d e x + a d  - b
+--R           |  b                    \|  a
+--R         p |- - log(----------------------------------------------------)
+--R          \|  a                    2 2                 2
+--R                                a e x  + 2a d e x + a d  + b
+--R       + 
+--R                    2 2                 2
+--R         d p log(a e x  + 2a d e x + a d  + b) - 2d p log(e x + d) + e x log(c)
+--R       + 
+--R                      2 2                 2
+--R                   a e x  + 2a d e x + a d  + b
+--R         e p x log(----------------------------)
+--R                         2 2             2
+--R                        e x  + 2d e x + d
+--R    /
+--R       e
+--R     ,
+--R
+--R                         +-+
+--R                         |b
+--R              +-+        |-
+--R              |b        \|a                 2 2                 2
+--R         - 2p |- atan(-------) + d p log(a e x  + 2a d e x + a d  + b)
+--R             \|a      e x + d
+--R       + 
+--R         - 2d p log(e x + d) + e x log(c)
+--R       + 
+--R                      2 2                 2
+--R                   a e x  + 2a d e x + a d  + b
+--R         e p x log(----------------------------)
+--R                         2 2             2
+--R                        e x  + 2d e x + d
+--R    /
+--R       e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 3748
+
+--S 3749 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                      +---+
+--R                                      |  b       2 2                 2
+--R         +---+        (2a e x + 2a d) |- -  + a e x  + 2a d e x + a d  - b
+--R         |  b  +-+                   \|  a
+--R       p |- - \|a log(----------------------------------------------------)
+--R        \|  a                        2 2                 2
+--R                                  a e x  + 2a d e x + a d  + b
+--R     + 
+--R                                2 2                 2     p
+--R                   +-+       a e x  + 2a d e x + a d  + b
+--R       (- e x - d)\|a log(c (----------------------------) )
+--R                                   2 2             2
+--R                                  e x  + 2d e x + d
+--R     + 
+--R                              +-+
+--R            +-+     (e x + d)\|a
+--R       - 2p\|b atan(-------------)
+--R                          +-+
+--R                         \|b
+--R     + 
+--R                      2 2                 2
+--R           d p log(a e x  + 2a d e x + a d  + b) - 2d p log(e x + d)
+--R         + 
+--R                                     2 2                 2
+--R                                  a e x  + 2a d e x + a d  + b
+--R           e x log(c) + e p x log(----------------------------)
+--R                                        2 2             2
+--R                                       e x  + 2d e x + d
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R       +-+
+--R     e\|a
+--R                                                    Type: Expression(Integer)
+--E 3749
+
+--S 3750 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3750
+
+--S 3751 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                2 2                 2     p
+--R                   +-+       a e x  + 2a d e x + a d  + b
+--R       (- e x - d)\|a log(c (----------------------------) )
+--R                                   2 2             2
+--R                                  e x  + 2d e x + d
+--R     + 
+--R                           +-+
+--R                           |b
+--R                +-+        |-                           +-+
+--R            +-+ |b        \|a         +-+     (e x + d)\|a
+--R       - 2p\|a  |- atan(-------) - 2p\|b atan(-------------)
+--R               \|a      e x + d                     +-+
+--R                                                   \|b
+--R     + 
+--R                      2 2                 2
+--R           d p log(a e x  + 2a d e x + a d  + b) - 2d p log(e x + d)
+--R         + 
+--R                                     2 2                 2
+--R                                  a e x  + 2a d e x + a d  + b
+--R           e x log(c) + e p x log(----------------------------)
+--R                                        2 2             2
+--R                                       e x  + 2d e x + d
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R       +-+
+--R     e\|a
+--R                                                    Type: Expression(Integer)
+--E 3751
+
+--S 3752 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 3752
+
+)clear all
+
+--S 3753 of 5341
+t0:=log(c*(a+b*(d+e*x)^n)^p)
+--R 
+--R
+--R                          n     p
+--R   (1)  log(c (b (e x + d)  + a) )
+--R                                                    Type: Expression(Integer)
+--E 3753
+
+--S 3754 of 5341
+--r0:=-n*p*x+n*p*(d+e*x)*hypergeometric(1,1/n,1+1/n,-b*(d+e*x)^n/a)/e+_
+--  (d+e*x)*log(c*(a+b*(d+e*x)^n)^p)/e
+--E 3754
+
+--S 3755 of 5341
+--a0:=integrate(t0,x)
+--E 3755
+
+--S 3756 of 5341
+--m0:=a0-r0
+--E 3756
+
+--S 3757 of 5341
+--d0:=D(m0,x)
+--E 3757
+
+)clear all
+
+--S 3758 of 5341
+t0:=x^5*log(c+d*x)/(a+b*x^2)
+--R 
+--R
+--R         5
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              2
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3758
+
+--S 3759 of 5341
+--r0:=1/4*c^3*x/(b*d^3)-1/2*a*c*x/(b^2*d)+1/4*a*x^2/b^2-1/8*c^2*x^2/(b*d^2)+_
+--  1/12*c*x^3/(b*d)-1/16*x^4/b-1/4*c^4*log(c+d*x)/(b*d^4)+1/2*a*c^2*_
+--  log(c+d*x)/(b^2*d^2)-1/2*a*x^2*log(c+d*x)/b^2+1/4*x^4*log(c+d*x)/b+_
+--  1/2*a^2*log(c+d*x)*log(d*(sqrt(-a)-x*sqrt(b))/(d*sqrt(-a)+c*sqrt(b)))/_
+--  b^3+1/2*a^2*log(c+d*x)*log(-d*(sqrt(-a)+x*sqrt(b))/(-d*sqrt(-a)+c*_
+--  sqrt(b)))/b^3+1/2*a^2*polylog(2,(c+d*x)*sqrt(b)/(-d*sqrt(-a)+_
+--  c*sqrt(b)))/b^3+1/2*a^2*polylog(2,(c+d*x)*sqrt(b)/(d*sqrt(-a)+_
+--  c*sqrt(b)))/b^3
+--E 3759
+
+--S 3760 of 5341
+--a0:=integrate(t0,x)
+--E 3760
+
+--S 3761 of 5341
+--m0:=a0-r0
+--E 3761
+
+--S 3762 of 5341
+--d0:=D(m0,x)
+--E 3762
+
+)clear all
+
+--S 3763 of 5341
+t0:=x^4*log(c+d*x)/(a+b*x^2)
+--R 
+--R
+--R         4
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              2
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3763
+
+--S 3764 of 5341
+--r0:=a*x/b^2-1/3*c^2*x/(b*d^2)+1/6*c*x^2/(b*d)-1/9*x^3/b+1/3*c^3*_
+--  log(c+d*x)/(b*d^3)+1/3*x^3*log(c+d*x)/b-a*(c+d*x)*log(c+d*x)/(b^2*d)+_
+--  1/2*(-a)^(3/2)*log(c+d*x)*log(d*(sqrt(-a)-x*sqrt(b))/(d*sqrt(-a)+_
+--  c*sqrt(b)))/b^(5/2)-1/2*(-a)^(3/2)*log(c+d*x)*log(-d*(sqrt(-a)+x*_
+--  sqrt(b))/(-d*sqrt(-a)+c*sqrt(b)))/b^(5/2)-1/2*(-a)^(3/2)*polylog(2,_
+--  (c+d*x)*sqrt(b)/(-d*sqrt(-a)+c*sqrt(b)))/b^(5/2)+1/2*(-a)^(3/2)*_
+--  polylog(2,(c+d*x)*sqrt(b)/(d*sqrt(-a)+c*sqrt(b)))/b^(5/2)
+--E 3764
+
+--S 3765 of 5341
+--a0:=integrate(t0,x)
+--E 3765
+
+--S 3766 of 5341
+--m0:=a0-r0
+--E 3766
+
+--S 3767 of 5341
+--d0:=D(m0,x)
+--E 3767
+
+)clear all
+
+--S 3768 of 5341
+t0:=x^3*log(c+d*x)/(a+b*x^2)
+--R 
+--R
+--R         3
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              2
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3768
+
+--S 3769 of 5341
+--r0:=1/2*c*x/(b*d)-1/4*x^2/b-1/2*c^2*log(c+d*x)/(b*d^2)+1/2*x^2*_
+--  log(c+d*x)/b-1/2*a*log(c+d*x)*log(d*(sqrt(-a)-x*sqrt(b))/(d*sqrt(-a)+_
+--  c*sqrt(b)))/b^2-1/2*a*log(c+d*x)*log(-d*(sqrt(-a)+x*sqrt(b))/_
+--  (-d*sqrt(-a)+c*sqrt(b)))/b^2-1/2*a*polylog(2,(c+d*x)*sqrt(b)/_
+--  (-d*sqrt(-a)+c*sqrt(b)))/b^2-1/2*a*polylog(2,(c+d*x)*sqrt(b)/_
+--  (d*sqrt(-a)+c*sqrt(b)))/b^2
+--E 3769
+
+--S 3770 of 5341
+--a0:=integrate(t0,x)
+--E 3770
+
+--S 3771 of 5341
+--m0:=a0-r0
+--E 3771
+
+--S 3772 of 5341
+--d0:=D(m0,x)
+--E 3772
+
+)clear all
+
+--S 3773 of 5341
+t0:=x^2*log(c+d*x)/(a+b*x^2)
+--R 
+--R
+--R         2
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              2
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3773
+
+--S 3774 of 5341
+--r0:=-x/b+(c+d*x)*log(c+d*x)/(b*d)+1/2*log(c+d*x)*log(d*(sqrt(-a)-_
+--  x*sqrt(b))/(d*sqrt(-a)+c*sqrt(b)))*sqrt(-a)/b^(3/2)-1/2*log(c+d*x)*_
+--  log(-d*(sqrt(-a)+x*sqrt(b))/(-d*sqrt(-a)+c*sqrt(b)))*sqrt(-a)/b^(3/2)-_
+--  1/2*polylog(2,(c+d*x)*sqrt(b)/(-d*sqrt(-a)+c*sqrt(b)))*sqrt(-a)/b^(3/2)+_
+--  1/2*polylog(2,(c+d*x)*sqrt(b)/(d*sqrt(-a)+c*sqrt(b)))*sqrt(-a)/b^(3/2)
+--E 3774
+
+--S 3775 of 5341
+--a0:=integrate(t0,x)
+--E 3775
+
+--S 3776 of 5341
+--m0:=a0-r0
+--E 3776
+
+--S 3777 of 5341
+--d0:=D(m0,x)
+--E 3777
+
+)clear all
+
+--S 3778 of 5341
+t0:=x*log(c+d*x)/(a+b*x^2)
+--R 
+--R
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              2
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3778
+
+--S 3779 of 5341
+--r0:=1/2*log(c+d*x)*log(d*(sqrt(-a)-x*sqrt(b))/(d*sqrt(-a)+c*sqrt(b)))/b+_
+--  1/2*log(c+d*x)*log(-d*(sqrt(-a)+x*sqrt(b))/(-d*sqrt(-a)+c*sqrt(b)))/b+_
+--  1/2*polylog(2,(c+d*x)*sqrt(b)/(-d*sqrt(-a)+c*sqrt(b)))/b+_
+--  1/2*polylog(2,(c+d*x)*sqrt(b)/(d*sqrt(-a)+c*sqrt(b)))/b
+--E 3779
+
+--S 3780 of 5341
+--a0:=integrate(t0,x)
+--E 3780
+
+--S 3781 of 5341
+--m0:=a0-r0
+--E 3781
+
+--S 3782 of 5341
+--d0:=D(m0,x)
+--E 3782
+
+)clear all
+
+--S 3783 of 5341
+t0:=log(c+d*x)/(a+b*x^2)
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R             2
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3783
+
+--S 3784 of 5341
+--r0:=1/2*log(c+d*x)*log(d*(sqrt(-a)-x*sqrt(b))/(d*sqrt(-a)+c*sqrt(b)))/_
+--  (sqrt(-a)*sqrt(b))-1/2*log(c+d*x)*log(-d*(sqrt(-a)+x*sqrt(b))/_
+--  (-d*sqrt(-a)+c*sqrt(b)))/(sqrt(-a)*sqrt(b))-1/2*polylog(2,(c+d*x)*_
+--  sqrt(b)/(-d*sqrt(-a)+c*sqrt(b)))/(sqrt(-a)*sqrt(b))+_
+--  1/2*polylog(2,(c+d*x)*sqrt(b)/(d*sqrt(-a)+c*sqrt(b)))/(sqrt(-a)*sqrt(b))
+--E 3784
+
+--S 3785 of 5341
+--a0:=integrate(t0,x)
+--E 3785
+
+--S 3786 of 5341
+--m0:=a0-r0
+--E 3786
+
+--S 3787 of 5341
+--d0:=D(m0,x)
+--E 3787
+
+)clear all
+
+--S 3788 of 5341
+t0:=log(c+d*x)/(x*(a+b*x^2))
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R            3
+--R         b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3788
+
+--S 3789 of 5341
+--r0:=log(-d*x/c)*log(c+d*x)/a-1/2*log(c+d*x)*log(d*(sqrt(-a)-_
+--  x*sqrt(b))/(d*sqrt(-a)+c*sqrt(b)))/a-1/2*log(c+d*x)*log(-d*_
+--  (sqrt(-a)+x*sqrt(b))/(-d*sqrt(-a)+c*sqrt(b)))/a+polylog(2,(c+d*x)/c)/a-_
+--  1/2*polylog(2,(c+d*x)*sqrt(b)/(-d*sqrt(-a)+c*sqrt(b)))/a-_
+--  1/2*polylog(2,(c+d*x)*sqrt(b)/(d*sqrt(-a)+c*sqrt(b)))/a
+--E 3789
+
+--S 3790 of 5341
+--a0:=integrate(t0,x)
+--E 3790
+
+--S 3791 of 5341
+--m0:=a0-r0
+--E 3791
+
+--S 3792 of 5341
+--d0:=D(m0,x)
+--E 3792
+
+)clear all
+
+--S 3793 of 5341
+t0:=log(c+d*x)/(x^2*(a+b*x^2))
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R            4      2
+--R         b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3793
+
+--S 3794 of 5341
+--r0:=d*log(x)/(a*c)-d*log(c+d*x)/(a*c)-log(c+d*x)/(a*x)+1/2*log(c+d*x)*_
+--  log(d*(sqrt(-a)-x*sqrt(b))/(d*sqrt(-a)+c*sqrt(b)))*sqrt(b)/(-a)^(3/2)-_
+--  1/2*log(c+d*x)*log(-d*(sqrt(-a)+x*sqrt(b))/(-d*sqrt(-a)+c*sqrt(b)))*_
+--  sqrt(b)/(-a)^(3/2)-1/2*polylog(2,(c+d*x)*sqrt(b)/(-d*sqrt(-a)+_
+--  c*sqrt(b)))*sqrt(b)/(-a)^(3/2)+1/2*polylog(2,(c+d*x)*sqrt(b)/(d*_
+--  sqrt(-a)+c*sqrt(b)))*sqrt(b)/(-a)^(3/2)
+--E 3794
+
+--S 3795 of 5341
+--a0:=integrate(t0,x)
+--E 3795
+
+--S 3796 of 5341
+--m0:=a0-r0
+--E 3796
+
+--S 3797 of 5341
+--d0:=D(m0,x)
+--E 3797
+
+)clear all
+
+--S 3798 of 5341
+t0:=log(c+d*x)/(x^3*(a+b*x^2))
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R            5      3
+--R         b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3798
+
+--S 3799 of 5341
+--r0:=-1/2*d/(a*c*x)-1/2*d^2*log(x)/(a*c^2)+1/2*d^2*log(c+d*x)/(a*c^2)-_
+--  1/2*log(c+d*x)/(a*x^2)-b*log(-d*x/c)*log(c+d*x)/a^2+1/2*b*log(c+d*x)*_
+--  log(d*(sqrt(-a)-x*sqrt(b))/(d*sqrt(-a)+c*sqrt(b)))/a^2+1/2*b*_
+--  log(c+d*x)*log(-d*(sqrt(-a)+x*sqrt(b))/(-d*sqrt(-a)+c*sqrt(b)))/a^2-_
+--  b*polylog(2,(c+d*x)/c)/a^2+1/2*b*polylog(2,(c+d*x)*sqrt(b)/(-d*_
+--  sqrt(-a)+c*sqrt(b)))/a^2+1/2*b*polylog(2,(c+d*x)*sqrt(b)/(d*sqrt(-a)+_
+--  c*sqrt(b)))/a^2
+--E 3799
+
+--S 3800 of 5341
+--a0:=integrate(t0,x)
+--E 3800
+
+--S 3801 of 5341
+--m0:=a0-r0
+--E 3801
+
+--S 3802 of 5341
+--d0:=D(m0,x)
+--E 3802
+
+)clear all
+
+--S 3803 of 5341
+t0:=x^5*log(c+d*x)/(a+b*x^3)
+--R 
+--R
+--R         5
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              3
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3803
+
+--S 3804 of 5341
+--r0:=-1/3*c^2*x/(b*d^2)+1/6*c*x^2/(b*d)-1/9*x^3/b+1/3*c^3*log(c+d*x)/_
+--  (b*d^3)+1/3*x^3*log(c+d*x)/b-1/3*a*log(-d*(a^(1/3)+b^(1/3)*x)/_
+--  (b^(1/3)*c-a^(1/3)*d))*log(c+d*x)/b^2-1/3*a*log(-d*((-1)^(2/3)*_
+--  a^(1/3)+b^(1/3)*x)/(b^(1/3)*c-(-1)^(2/3)*a^(1/3)*d))*log(c+d*x)/b^2-_
+--  1/3*a*log((-1)^(1/3)*d*(a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/(b^(1/3)*c+_
+--  (-1)^(1/3)*a^(1/3)*d))*log(c+d*x)/b^2-1/3*a*polylog(2,b^(1/3)*_
+--  (c+d*x)/(b^(1/3)*c-a^(1/3)*d))/b^2-1/3*a*polylog(2,b^(1/3)*(c+d*x)/_
+--  (b^(1/3)*c+(-1)^(1/3)*a^(1/3)*d))/b^2-1/3*a*polylog(2,b^(1/3)*_
+--  (c+d*x)/(b^(1/3)*c-(-1)^(2/3)*a^(1/3)*d))/b^2
+--E 3804
+
+--S 3805 of 5341
+--a0:=integrate(t0,x)
+--E 3805
+
+--S 3806 of 5341
+--m0:=a0-r0
+--E 3806
+
+--S 3807 of 5341
+--d0:=D(m0,x)
+--E 3807
+
+)clear all
+
+--S 3808 of 5341
+t0:=x^4*log(c+d*x)/(a+b*x^3)
+--R 
+--R
+--R         4
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              3
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3808
+
+--S 3809 of 5341
+--r0:=1/2*c*x/(b*d)-1/4*x^2/b-1/2*c^2*log(c+d*x)/(b*d^2)+1/2*x^2*_
+--  log(c+d*x)/b+1/3*a^(2/3)*log(-d*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*c-_
+--  a^(1/3)*d))*log(c+d*x)/b^(5/3)-1/3*(-1)^(1/3)*a^(2/3)*log(d*(a^(1/3)-_
+--  (-1)^(1/3)*b^(1/3)*x)/((-1)^(1/3)*b^(1/3)*c+a^(1/3)*d))*log(c+d*x)/_
+--  b^(5/3)+1/3*(-1)^(2/3)*a^(2/3)*log(-d*(a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/_
+--  ((-1)^(2/3)*b^(1/3)*c-a^(1/3)*d))*log(c+d*x)/b^(5/3)+1/3*a^(2/3)*_
+--  polylog(2,b^(1/3)*(c+d*x)/(b^(1/3)*c-a^(1/3)*d))/b^(5/3)+_
+--  1/3*(-1)^(2/3)*a^(2/3)*polylog(2,(-1)^(2/3)*b^(1/3)*(c+d*x)/_
+--  ((-1)^(2/3)*b^(1/3)*c-a^(1/3)*d))/b^(5/3)-1/3*(-1)^(1/3)*a^(2/3)*_
+--  polylog(2,(-1)^(1/3)*b^(1/3)*(c+d*x)/((-1)^(1/3)*b^(1/3)*c+_
+--  a^(1/3)*d))/b^(5/3)
+--E 3809
+
+--S 3810 of 5341
+--a0:=integrate(t0,x)
+--E 3810
+
+--S 3811 of 5341
+--m0:=a0-r0
+--E 3811
+
+--S 3812 of 5341
+--d0:=D(m0,x)
+--E 3812
+
+)clear all
+
+--S 3813 of 5341
+t0:=x^3*log(c+d*x)/(a+b*x^3)
+--R 
+--R
+--R         3
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              3
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3813
+
+--S 3814 of 5341
+--r0:=-x/b+(c+d*x)*log(c+d*x)/(b*d)-1/3*a^(1/3)*log(-d*(a^(1/3)+_
+--  b^(1/3)*x)/(b^(1/3)*c-a^(1/3)*d))*log(c+d*x)/b^(4/3)-1/3*(-1)^(2/3)*_
+--  a^(1/3)*log(d*(a^(1/3)-(-1)^(1/3)*b^(1/3)*x)/((-1)^(1/3)*b^(1/3)*c+_
+--  a^(1/3)*d))*log(c+d*x)/b^(4/3)+1/3*(-1)^(1/3)*a^(1/3)*log(-d*(a^(1/3)+_
+--  (-1)^(2/3)*b^(1/3)*x)/((-1)^(2/3)*b^(1/3)*c-a^(1/3)*d))*log(c+d*x)/_
+--  b^(4/3)-1/3*a^(1/3)*polylog(2,b^(1/3)*(c+d*x)/(b^(1/3)*c-a^(1/3)*d))/_
+--  b^(4/3)+1/3*(-1)^(1/3)*a^(1/3)*polylog(2,(-1)^(2/3)*b^(1/3)*(c+d*x)/_
+--  ((-1)^(2/3)*b^(1/3)*c-a^(1/3)*d))/b^(4/3)-1/3*(-1)^(2/3)*a^(1/3)*_
+--  polylog(2,(-1)^(1/3)*b^(1/3)*(c+d*x)/((-1)^(1/3)*b^(1/3)*c+_
+--  a^(1/3)*d))/b^(4/3)
+--E 3814
+
+--S 3815 of 5341
+--a0:=integrate(t0,x)
+--E 3815
+
+--S 3816 of 5341
+--m0:=a0-r0
+--E 3816
+
+--S 3817 of 5341
+--d0:=D(m0,x)
+--E 3817
+
+)clear all
+
+--S 3818 of 5341
+t0:=x^2*log(c+d*x)/(a+b*x^3)
+--R 
+--R
+--R         2
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              3
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3818
+
+--S 3819 of 5341
+--r0:=1/3*log(-d*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*c-a^(1/3)*d))*log(c+d*x)/b+_
+--  1/3*log(-d*((-1)^(2/3)*a^(1/3)+b^(1/3)*x)/(b^(1/3)*c-(-1)^(2/3)*_
+--  a^(1/3)*d))*log(c+d*x)/b+1/3*log((-1)^(1/3)*d*(a^(1/3)+(-1)^(2/3)*_
+--  b^(1/3)*x)/(b^(1/3)*c+(-1)^(1/3)*a^(1/3)*d))*log(c+d*x)/b+1/3*_
+--  polylog(2,b^(1/3)*(c+d*x)/(b^(1/3)*c-a^(1/3)*d))/b+_
+--  1/3*polylog(2,b^(1/3)*(c+d*x)/(b^(1/3)*c+(-1)^(1/3)*a^(1/3)*d))/b+_
+--  1/3*polylog(2,b^(1/3)*(c+d*x)/(b^(1/3)*c-(-1)^(2/3)*a^(1/3)*d))/b
+--E 3819
+
+--S 3820 of 5341
+--a0:=integrate(t0,x)
+--E 3820
+
+--S 3821 of 5341
+--m0:=a0-r0
+--E 3821
+
+--S 3822 of 5341
+--d0:=D(m0,x)
+--E 3822
+
+)clear all
+
+--S 3823 of 5341
+t0:=x*log(c+d*x)/(a+b*x^3)
+--R 
+--R
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              3
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3823
+
+--S 3824 of 5341
+--r0:=-1/3*log(-d*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*c-a^(1/3)*d))*_
+--  log(c+d*x)/(a^(1/3)*b^(2/3))+1/3*(-1)^(1/3)*log(d*(a^(1/3)-(-1)^(1/3)*_
+--  b^(1/3)*x)/((-1)^(1/3)*b^(1/3)*c+a^(1/3)*d))*log(c+d*x)/(a^(1/3)*_
+--  b^(2/3))-1/3*(-1)^(2/3)*log(-d*(a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/_
+--  ((-1)^(2/3)*b^(1/3)*c-a^(1/3)*d))*log(c+d*x)/(a^(1/3)*b^(2/3))-_
+--  1/3*polylog(2,b^(1/3)*(c+d*x)/(b^(1/3)*c-a^(1/3)*d))/(a^(1/3)*_
+--  b^(2/3))-1/3*(-1)^(2/3)*polylog(2,(-1)^(2/3)*b^(1/3)*(c+d*x)/_
+--  ((-1)^(2/3)*b^(1/3)*c-a^(1/3)*d))/(a^(1/3)*b^(2/3))+1/3*(-1)^(1/3)*_
+--  polylog(2,(-1)^(1/3)*b^(1/3)*(c+d*x)/((-1)^(1/3)*b^(1/3)*c+_
+--  a^(1/3)*d))/(a^(1/3)*b^(2/3))
+--E 3824
+
+--S 3825 of 5341
+--a0:=integrate(t0,x)
+--E 3825
+
+--S 3826 of 5341
+--m0:=a0-r0
+--E 3826
+
+--S 3827 of 5341
+--d0:=D(m0,x)
+--E 3827
+
+)clear all
+
+--S 3828 of 5341
+t0:=log(c+d*x)/(a+b*x^3)
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3828
+
+--S 3829 of 5341
+--r0:=1/3*log(-d*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*c-a^(1/3)*d))*log(c+d*x)/_
+--  (a^(2/3)*b^(1/3))+1/3*(-1)^(2/3)*log(d*(a^(1/3)-(-1)^(1/3)*b^(1/3)*x)/_
+--  ((-1)^(1/3)*b^(1/3)*c+a^(1/3)*d))*log(c+d*x)/(a^(2/3)*b^(1/3))-_
+--  1/3*(-1)^(1/3)*log(-d*(a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/((-1)^(2/3)*_
+--  b^(1/3)*c-a^(1/3)*d))*log(c+d*x)/(a^(2/3)*b^(1/3))+_
+--  1/3*polylog(2,b^(1/3)*(c+d*x)/(b^(1/3)*c-a^(1/3)*d))/(a^(2/3)*_
+--  b^(1/3))-1/3*(-1)^(1/3)*polylog(2,(-1)^(2/3)*b^(1/3)*(c+d*x)/_
+--  ((-1)^(2/3)*b^(1/3)*c-a^(1/3)*d))/(a^(2/3)*b^(1/3))+1/3*(-1)^(2/3)*_
+--  polylog(2,(-1)^(1/3)*b^(1/3)*(c+d*x)/((-1)^(1/3)*b^(1/3)*c+_
+--  a^(1/3)*d))/(a^(2/3)*b^(1/3))
+--E 3829
+
+--S 3830 of 5341
+--a0:=integrate(t0,x)
+--E 3830
+
+--S 3831 of 5341
+--m0:=a0-r0
+--E 3831
+
+--S 3832 of 5341
+--d0:=D(m0,x)
+--E 3832
+
+)clear all
+
+--S 3833 of 5341
+t0:=log(c+d*x)/(x*(a+b*x^3))
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R            4
+--R         b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3833
+
+--S 3834 of 5341
+--r0:=log(-d*x/c)*log(c+d*x)/a-1/3*log(-d*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*c-_
+--  a^(1/3)*d))*log(c+d*x)/a-1/3*log(-d*((-1)^(2/3)*a^(1/3)+b^(1/3)*x)/_
+--  (b^(1/3)*c-(-1)^(2/3)*a^(1/3)*d))*log(c+d*x)/a-1/3*log((-1)^(1/3)*d*_
+--  (a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/(b^(1/3)*c+(-1)^(1/3)*a^(1/3)*d))*_
+--  log(c+d*x)/a+polylog(2,(c+d*x)/c)/a-1/3*polylog(2,b^(1/3)*(c+d*x)/_
+--  (b^(1/3)*c-a^(1/3)*d))/a-1/3*polylog(2,b^(1/3)*(c+d*x)/(b^(1/3)*_
+--  c+(-1)^(1/3)*a^(1/3)*d))/a-1/3*polylog(2,b^(1/3)*(c+d*x)/(b^(1/3)*_
+--  c-(-1)^(2/3)*a^(1/3)*d))/a
+--E 3834
+
+--S 3835 of 5341
+--a0:=integrate(t0,x)
+--E 3835
+
+--S 3836 of 5341
+--m0:=a0-r0
+--E 3836
+
+--S 3837 of 5341
+--d0:=D(m0,x)
+--E 3837
+
+)clear all
+
+--S 3838 of 5341
+t0:=log(c+d*x)/(x^2*(a+b*x^3))
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R            5      2
+--R         b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3838
+
+--S 3839 of 5341
+--r0:=d*log(x)/(a*c)-d*log(c+d*x)/(a*c)-log(c+d*x)/(a*x)+1/3*b^(1/3)*_
+--  log(-d*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*c-a^(1/3)*d))*log(c+d*x)/a^(4/3)-_
+--  1/3*(-1)^(1/3)*b^(1/3)*log(d*(a^(1/3)-(-1)^(1/3)*b^(1/3)*x)/_
+--  ((-1)^(1/3)*b^(1/3)*c+a^(1/3)*d))*log(c+d*x)/a^(4/3)+1/3*(-1)^(2/3)*_
+--  b^(1/3)*log(-d*(a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/((-1)^(2/3)*b^(1/3)*c-_
+--  a^(1/3)*d))*log(c+d*x)/a^(4/3)+1/3*b^(1/3)*polylog(2,b^(1/3)*_
+--  (c+d*x)/(b^(1/3)*c-a^(1/3)*d))/a^(4/3)+1/3*(-1)^(2/3)*b^(1/3)*_
+--  polylog(2,(-1)^(2/3)*b^(1/3)*(c+d*x)/((-1)^(2/3)*b^(1/3)*c-_
+--  a^(1/3)*d))/a^(4/3)-1/3*(-1)^(1/3)*b^(1/3)*polylog(2,(-1)^(1/3)*_
+--  b^(1/3)*(c+d*x)/((-1)^(1/3)*b^(1/3)*c+a^(1/3)*d))/a^(4/3)
+--E 3839
+
+--S 3840 of 5341
+--a0:=integrate(t0,x)
+--E 3840
+
+--S 3841 of 5341
+--m0:=a0-r0
+--E 3841
+
+--S 3842 of 5341
+--d0:=D(m0,x)
+--E 3842
+
+)clear all
+
+--S 3843 of 5341
+t0:=log(c+d*x)/(x^3*(a+b*x^3))
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R            6      3
+--R         b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3843
+
+--S 3844 of 5341
+--r0:=-1/2*d/(a*c*x)-1/2*d^2*log(x)/(a*c^2)+1/2*d^2*log(c+d*x)/(a*c^2)-_
+--  1/2*log(c+d*x)/(a*x^2)-1/3*b^(2/3)*log(-d*(a^(1/3)+b^(1/3)*x)/(b^(1/3)*c-_
+--  a^(1/3)*d))*log(c+d*x)/a^(5/3)-1/3*(-1)^(2/3)*b^(2/3)*_
+--  log(d*(a^(1/3)-(-1)^(1/3)*b^(1/3)*x)/((-1)^(1/3)*b^(1/3)*c+_
+--  a^(1/3)*d))*log(c+d*x)/a^(5/3)+1/3*(-1)^(1/3)*b^(2/3)*_
+--  log(-d*(a^(1/3)+(-1)^(2/3)*b^(1/3)*x)/((-1)^(2/3)*b^(1/3)*c-_
+--  a^(1/3)*d))*log(c+d*x)/a^(5/3)-1/3*b^(2/3)*polylog(2,b^(1/3)*_
+--  (c+d*x)/(b^(1/3)*c-a^(1/3)*d))/a^(5/3)+1/3*(-1)^(1/3)*b^(2/3)*_
+--  polylog(2,(-1)^(2/3)*b^(1/3)*(c+d*x)/((-1)^(2/3)*b^(1/3)*c-_
+--  a^(1/3)*d))/a^(5/3)-1/3*(-1)^(2/3)*b^(2/3)*polylog(2,(-1)^(1/3)*_
+--  b^(1/3)*(c+d*x)/((-1)^(1/3)*b^(1/3)*c+a^(1/3)*d))/a^(5/3)
+--E 3844
+
+--S 3845 of 5341
+--a0:=integrate(t0,x)
+--E 3845
+
+--S 3846 of 5341
+--m0:=a0-r0
+--E 3846
+
+--S 3847 of 5341
+--d0:=D(m0,x)
+--E 3847
+
+)clear all
+
+--S 3848 of 5341
+t0:=x^4*log(c+d*x)/(a+b*x^4)
+--R 
+--R
+--R         4
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              4
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3848
+
+--S 3849 of 5341
+--r0:=-x/b+(c+d*x)*log(c+d*x)/(b*d)+1/4*(-a)^(1/4)*log(d*((-a)^(1/4)-_
+--  b^(1/4)*x)/(b^(1/4)*c+(-a)^(1/4)*d))*log(c+d*x)/b^(5/4)-_
+--  1/4*%i*(-a)^(1/4)*log(d*((-a)^(1/4)-%i*b^(1/4)*x)/(%i*b^(1/4)*c+_
+--  (-a)^(1/4)*d))*log(c+d*x)/b^(5/4)+1/4*%i*(-a)^(1/4)*log(-d*_
+--  ((-a)^(1/4)+%i*b^(1/4)*x)/(%i*b^(1/4)*c-(-a)^(1/4)*d))*log(c+d*x)/_
+--  b^(5/4)-1/4*(-a)^(1/4)*log(-d*((-a)^(1/4)+b^(1/4)*x)/(b^(1/4)*c-_
+--  (-a)^(1/4)*d))*log(c+d*x)/b^(5/4)-1/4*(-a)^(1/4)*polylog(2,b^(1/4)*_
+--  (c+d*x)/(b^(1/4)*c-(-a)^(1/4)*d))/b^(5/4)-1/4*%i*(-a)^(1/4)*_
+--  polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c-%i*(-a)^(1/4)*d))/b^(5/4)+_
+--  1/4*%i*(-a)^(1/4)*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c+_
+--  %i*(-a)^(1/4)*d))/b^(5/4)+1/4*(-a)^(1/4)*polylog(2,b^(1/4)*_
+--  (c+d*x)/(b^(1/4)*c+(-a)^(1/4)*d))/b^(5/4)
+--E 3849
+
+--S 3850 of 5341
+--a0:=integrate(t0,x)
+--E 3850
+
+--S 3851 of 5341
+--m0:=a0-r0
+--E 3851
+
+--S 3852 of 5341
+--d0:=D(m0,x)
+--E 3852
+
+)clear all
+
+--S 3853 of 5341
+t0:=x^3*log(c+d*x)/(a+b*x^4)
+--R 
+--R
+--R         3
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              4
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3853
+
+--S 3854 of 5341
+--r0:=1/4*log(d*(%i*(-a)^(1/4)-b^(1/4)*x)/(b^(1/4)*c+%i*(-a)^(1/4)*d))*_
+--  log(c+d*x)/b+1/4*log(d*((-a)^(1/4)-b^(1/4)*x)/(b^(1/4)*c+(-a)^(1/4)*d))*_
+--  log(c+d*x)/b+1/4*log(-d*(%i*(-a)^(1/4)+b^(1/4)*x)/(b^(1/4)*c-_
+--  %i*(-a)^(1/4)*d))*log(c+d*x)/b+1/4*log(-d*((-a)^(1/4)+b^(1/4)*x)/_
+--  (b^(1/4)*c-(-a)^(1/4)*d))*log(c+d*x)/b+1/4*polylog(2,b^(1/4)*_
+--  (c+d*x)/(b^(1/4)*c-(-a)^(1/4)*d))/b+1/4*polylog(2,b^(1/4)*(c+d*x)/_
+--  (b^(1/4)*c-%i*(-a)^(1/4)*d))/b+1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--  c+%i*(-a)^(1/4)*d))/b+1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c+_
+--  (-a)^(1/4)*d))/b
+--E 3854
+
+--S 3855 of 5341
+--a0:=integrate(t0,x)
+--E 3855
+
+--S 3856 of 5341
+--m0:=a0-r0
+--E 3856
+
+--S 3857 of 5341
+--d0:=D(m0,x)
+--E 3857
+
+)clear all
+
+--S 3858 of 5341
+t0:=x^2*log(c+d*x)/(a+b*x^4)
+--R 
+--R
+--R         2
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              4
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3858
+
+--S 3859 of 5341
+--r0:=1/4*log(d*((-a)^(1/4)-b^(1/4)*x)/(b^(1/4)*c+(-a)^(1/4)*d))*_
+--  log(c+d*x)/((-a)^(1/4)*b^(3/4))-1/4*log(-d*((-a)^(1/4)+b^(1/4)*x)/_
+--  (b^(1/4)*c-(-a)^(1/4)*d))*log(c+d*x)/((-a)^(1/4)*b^(3/4))-_
+--  1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c-(-a)^(1/4)*d))/((-a)^(1/4)*_
+--  b^(3/4))+1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c+(-a)^(1/4)*d))/_
+--  ((-a)^(1/4)*b^(3/4))-1/4*log(c+d*x)*log(-d*(b^(1/4)*x+sqrt(-sqrt(-a)))/_
+--  (b^(1/4)*c-d*sqrt(-sqrt(-a))))/(b^(3/4)*sqrt(-sqrt(-a)))+_
+--  1/4*log(c+d*x)*log(d*(-b^(1/4)*x+sqrt(-sqrt(-a)))/(b^(1/4)*c+_
+--  d*sqrt(-sqrt(-a))))/(b^(3/4)*sqrt(-sqrt(-a)))-1/4*polylog(2,b^(1/4)*_
+--  (c+d*x)/(b^(1/4)*c-d*sqrt(-sqrt(-a))))/(b^(3/4)*sqrt(-sqrt(-a)))+_
+--  1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c+d*sqrt(-sqrt(-a))))/_
+--  (b^(3/4)*sqrt(-sqrt(-a)))
+--E 3859
+
+--S 3860 of 5341
+--a0:=integrate(t0,x)
+--E 3860
+
+--S 3861 of 5341
+--m0:=a0-r0
+--E 3861
+
+--S 3862 of 5341
+--d0:=D(m0,x)
+--E 3862
+
+)clear all
+
+--S 3863 of 5341
+t0:=x*log(c+d*x)/(a+b*x^4)
+--R 
+--R
+--R        x log(d x + c)
+--R   (1)  --------------
+--R              4
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3863
+
+--S 3864 of 5341
+--r0:=-1/4*log(d*(%i*(-a)^(1/4)-b^(1/4)*x)/(b^(1/4)*c+%i*(-a)^(1/4)*d))*_
+--  log(c+d*x)/(sqrt(-a)*sqrt(b))+1/4*log(d*((-a)^(1/4)-b^(1/4)*x)/(b^(1/4)*_
+--  c+(-a)^(1/4)*d))*log(c+d*x)/(sqrt(-a)*sqrt(b))-1/4*log(-d*(%i*_
+--  (-a)^(1/4)+b^(1/4)*x)/(b^(1/4)*c-%i*(-a)^(1/4)*d))*log(c+d*x)/_
+--  (sqrt(-a)*sqrt(b))+1/4*log(-d*((-a)^(1/4)+b^(1/4)*x)/(b^(1/4)*c-_
+--  (-a)^(1/4)*d))*log(c+d*x)/(sqrt(-a)*sqrt(b))+1/4*polylog(2,b^(1/4)*_
+--  (c+d*x)/(b^(1/4)*c-(-a)^(1/4)*d))/(sqrt(-a)*sqrt(b))-_
+--  1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c-%i*(-a)^(1/4)*d))/_
+--  (sqrt(-a)*sqrt(b))-1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c+_
+--  %i*(-a)^(1/4)*d))/(sqrt(-a)*sqrt(b))+1/4*polylog(2,b^(1/4)*_
+--  (c+d*x)/(b^(1/4)*c+(-a)^(1/4)*d))/(sqrt(-a)*sqrt(b))
+--E 3864
+
+--S 3865 of 5341
+--a0:=integrate(t0,x)
+--E 3865
+
+--S 3866 of 5341
+--m0:=a0-r0
+--E 3866
+
+--S 3867 of 5341
+--d0:=D(m0,x)
+--E 3867
+
+)clear all
+
+--S 3868 of 5341
+t0:=log(c+d*x)/(a+b*x^4)
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R             4
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 3868
+
+--S 3869 of 5341
+--r0:=1/4*log(d*((-a)^(1/4)-b^(1/4)*x)/(b^(1/4)*c+(-a)^(1/4)*d))*_
+--  log(c+d*x)/((-a)^(3/4)*b^(1/4))-1/4*%i*log(d*((-a)^(1/4)-%i*b^(1/4)*_
+--  x)/(%i*b^(1/4)*c+(-a)^(1/4)*d))*log(c+d*x)/((-a)^(3/4)*b^(1/4))+_
+--  1/4*%i*log(-d*((-a)^(1/4)+%i*b^(1/4)*x)/(%i*b^(1/4)*c-(-a)^(1/4)*d))*_
+--  log(c+d*x)/((-a)^(3/4)*b^(1/4))-1/4*log(-d*((-a)^(1/4)+b^(1/4)*x)/_
+--  (b^(1/4)*c-(-a)^(1/4)*d))*log(c+d*x)/((-a)^(3/4)*b^(1/4))-1/4*_
+--  polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c-(-a)^(1/4)*d))/((-a)^(3/4)*_
+--  b^(1/4))-1/4*%i*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c-_
+--  %i*(-a)^(1/4)*d))/((-a)^(3/4)*b^(1/4))+1/4*%i*polylog(2,b^(1/4)*_
+--  (c+d*x)/(b^(1/4)*c+%i*(-a)^(1/4)*d))/((-a)^(3/4)*b^(1/4))+_
+--  1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c+(-a)^(1/4)*d))/((-a)^(3/4)*_
+--  b^(1/4))
+--E 3869
+
+--S 3870 of 5341
+--a0:=integrate(t0,x)
+--E 3870
+
+--S 3871 of 5341
+--m0:=a0-r0
+--E 3871
+
+--S 3872 of 5341
+--d0:=D(m0,x)
+--E 3872
+
+)clear all
+
+--S 3873 of 5341
+t0:=log(c+d*x)/(x*(a+b*x^4))
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R            5
+--R         b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3873
+
+--S 3874 of 5341
+--r0:=log(-d*x/c)*log(c+d*x)/a-1/4*log(d*(%i*(-a)^(1/4)-b^(1/4)*x)/_
+--  (b^(1/4)*c+%i*(-a)^(1/4)*d))*log(c+d*x)/a-1/4*log(d*((-a)^(1/4)-_
+--  b^(1/4)*x)/(b^(1/4)*c+(-a)^(1/4)*d))*log(c+d*x)/a-1/4*log(-d*_
+--  (%i*(-a)^(1/4)+b^(1/4)*x)/(b^(1/4)*c-%i*(-a)^(1/4)*d))*log(c+d*x)/a-_
+--  1/4*log(-d*((-a)^(1/4)+b^(1/4)*x)/(b^(1/4)*c-(-a)^(1/4)*d))*log(c+_
+--  d*x)/a+polylog(2,(c+d*x)/c)/a-1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--  c-(-a)^(1/4)*d))/a-1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c-_
+--  %i*(-a)^(1/4)*d))/a-1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c+_
+--  %i*(-a)^(1/4)*d))/a-1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c+_
+--  (-a)^(1/4)*d))/a
+--E 3874
+
+--S 3875 of 5341
+--a0:=integrate(t0,x)
+--E 3875
+
+--S 3876 of 5341
+--m0:=a0-r0
+--E 3876
+
+--S 3877 of 5341
+--d0:=D(m0,x)
+--E 3877
+
+)clear all
+
+--S 3878 of 5341
+t0:=log(c+d*x)/(x^2*(a+b*x^4))
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R            6      2
+--R         b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3878
+
+--S 3879 of 5341
+--r0:=d*log(x)/(a*c)-d*log(c+d*x)/(a*c)-log(c+d*x)/(a*x)+1/4*b^(1/4)*_
+--  log(d*((-a)^(1/4)-b^(1/4)*x)/(b^(1/4)*c+(-a)^(1/4)*d))*log(c+d*x)/_
+--  (-a)^(5/4)-1/4*b^(1/4)*log(-d*((-a)^(1/4)+b^(1/4)*x)/(b^(1/4)*c-_
+--  (-a)^(1/4)*d))*log(c+d*x)/(-a)^(5/4)-1/4*b^(1/4)*polylog(2,b^(1/4)*_
+--  (c+d*x)/(b^(1/4)*c-(-a)^(1/4)*d))/(-a)^(5/4)+1/4*b^(1/4)*_
+--  polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c+(-a)^(1/4)*d))/(-a)^(5/4)-_
+--  1/4*b^(1/4)*log(c+d*x)*log(-d*(b^(1/4)*x+sqrt(-sqrt(-a)))/(b^(1/4)*c-_
+--  d*sqrt(-sqrt(-a))))/(-sqrt(-a))^(5/2)+1/4*b^(1/4)*log(c+d*x)*log(d*_
+--  (-b^(1/4)*x+sqrt(-sqrt(-a)))/(b^(1/4)*c+d*sqrt(-sqrt(-a))))/_
+--  (-sqrt(-a))^(5/2)-1/4*b^(1/4)*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c-_
+--  d*sqrt(-sqrt(-a))))/(-sqrt(-a))^(5/2)+1/4*b^(1/4)*polylog(2,b^(1/4)*_
+--  (c+d*x)/(b^(1/4)*c+d*sqrt(-sqrt(-a))))/(-sqrt(-a))^(5/2)
+--E 3879
+
+--S 3880 of 5341
+--a0:=integrate(t0,x)
+--E 3880
+
+--S 3881 of 5341
+--m0:=a0-r0
+--E 3881
+
+--S 3882 of 5341
+--d0:=D(m0,x)
+--E 3882
+
+)clear all
+
+--S 3883 of 5341
+t0:=log(c+d*x)/(x^3*(a+b*x^4))
+--R 
+--R
+--R        log(d x + c)
+--R   (1)  ------------
+--R            7      3
+--R         b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3883
+
+--S 3884 of 5341
+--r0:=-1/2*d/(a*c*x)-1/2*d^2*log(x)/(a*c^2)+1/2*d^2*log(c+d*x)/(a*c^2)-_
+--  1/2*log(c+d*x)/(a*x^2)-1/4*log(d*(%i*(-a)^(1/4)-b^(1/4)*x)/(b^(1/4)*_
+--  c+%i*(-a)^(1/4)*d))*log(c+d*x)*sqrt(b)/(-a)^(3/2)+1/4*_
+--  log(d*((-a)^(1/4)-b^(1/4)*x)/(b^(1/4)*c+(-a)^(1/4)*d))*log(c+d*x)*_
+--  sqrt(b)/(-a)^(3/2)-1/4*log(-d*(%i*(-a)^(1/4)+b^(1/4)*x)/(b^(1/4)*c-_
+--  %i*(-a)^(1/4)*d))*log(c+d*x)*sqrt(b)/(-a)^(3/2)+1/4*log(-d*((-a)^(1/4)+_
+--  b^(1/4)*x)/(b^(1/4)*c-(-a)^(1/4)*d))*log(c+d*x)*sqrt(b)/(-a)^(3/2)+_
+--  1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c-(-a)^(1/4)*d))*sqrt(b)/_
+--  (-a)^(3/2)-1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c-%i*(-a)^(1/4)*d))*_
+--  sqrt(b)/(-a)^(3/2)-1/4*polylog(2,b^(1/4)*(c+d*x)/(b^(1/4)*c+_
+--  %i*(-a)^(1/4)*d))*sqrt(b)/(-a)^(3/2)+1/4*polylog(2,b^(1/4)*(c+d*x)/_
+--  (b^(1/4)*c+(-a)^(1/4)*d))*sqrt(b)/(-a)^(3/2)
+--E 3884
+
+--S 3885 of 5341
+--a0:=integrate(t0,x)
+--E 3885
+
+--S 3886 of 5341
+--m0:=a0-r0
+--E 3886
+
+--S 3887 of 5341
+--d0:=D(m0,x)
+--E 3887
+
+)clear all
+
+--S 3888 of 5341
+t0:=log(c*(a+b*x)^n)^3/(d+e*x^2)
+--R 
+--R
+--R                       n 3
+--R        log(c (b x + a) )
+--R   (1)  ------------------
+--R                2
+--R             e x  + d
+--R                                                    Type: Expression(Integer)
+--E 3888
+
+--S 3889 of 5341
+--r0:=1/2*log(c*(a+b*x)^n)^3*log(b*(sqrt(-d)-x*sqrt(e))/(b*sqrt(-d)+_
+--  a*sqrt(e)))/(sqrt(-d)*sqrt(e))-1/2*log(c*(a+b*x)^n)^3*log(b*_
+--  (sqrt(-d)+x*sqrt(e))/(b*sqrt(-d)-a*sqrt(e)))/(sqrt(-d)*sqrt(e))-_
+--  3/2*n*log(c*(a+b*x)^n)^2*polylog(2,-(a+b*x)*sqrt(e)/(b*sqrt(-d)-_
+--  a*sqrt(e)))/(sqrt(-d)*sqrt(e))+3/2*n*log(c*(a+b*x)^n)^2*_
+--  polylog(2,(a+b*x)*sqrt(e)/(b*sqrt(-d)+a*sqrt(e)))/(sqrt(-d)*_
+--  sqrt(e))+3*n^2*log(c*(a+b*x)^n)*polylog(3,-(a+b*x)*sqrt(e)/(b*_
+--  sqrt(-d)-a*sqrt(e)))/(sqrt(-d)*sqrt(e))-3*n^2*log(c*(a+b*x)^n)*_
+--  polylog(3,(a+b*x)*sqrt(e)/(b*sqrt(-d)+a*sqrt(e)))/(sqrt(-d)*_
+--  sqrt(e))-3*n^3*polylog(4,-(a+b*x)*sqrt(e)/(b*sqrt(-d)-a*sqrt(e)))/_
+--  (sqrt(-d)*sqrt(e))+3*n^3*polylog(4,(a+b*x)*sqrt(e)/(b*sqrt(-d)+_
+--  a*sqrt(e)))/(sqrt(-d)*sqrt(e))
+--E 3889
+
+--S 3890 of 5341
+--a0:=integrate(t0,x)
+--E 3890
+
+--S 3891 of 5341
+--m0:=a0-r0
+--E 3891
+
+--S 3892 of 5341
+--d0:=D(m0,x)
+--E 3892
+
+)clear all
+
+--S 3893 of 5341
+t0:=log(c*(a+b*x)^n)^2/(d+e*x^2)
+--R 
+--R
+--R                       n 2
+--R        log(c (b x + a) )
+--R   (1)  ------------------
+--R                2
+--R             e x  + d
+--R                                                    Type: Expression(Integer)
+--E 3893
+
+--S 3894 of 5341
+--r0:=1/2*log(c*(a+b*x)^n)^2*log(b*(sqrt(-d)-x*sqrt(e))/(b*sqrt(-d)+_
+--  a*sqrt(e)))/(sqrt(-d)*sqrt(e))-1/2*log(c*(a+b*x)^n)^2*log(b*_
+--  (sqrt(-d)+x*sqrt(e))/(b*sqrt(-d)-a*sqrt(e)))/(sqrt(-d)*sqrt(e))-_
+--  n*log(c*(a+b*x)^n)*polylog(2,-(a+b*x)*sqrt(e)/(b*sqrt(-d)-_
+--  a*sqrt(e)))/(sqrt(-d)*sqrt(e))+n*log(c*(a+b*x)^n)*polylog(2,_
+--  (a+b*x)*sqrt(e)/(b*sqrt(-d)+a*sqrt(e)))/(sqrt(-d)*sqrt(e))+n^2*_
+--  polylog(3,-(a+b*x)*sqrt(e)/(b*sqrt(-d)-a*sqrt(e)))/(sqrt(-d)*_
+--  sqrt(e))-n^2*polylog(3,(a+b*x)*sqrt(e)/(b*sqrt(-d)+a*sqrt(e)))/_
+--  (sqrt(-d)*sqrt(e))
+--E 3894
+
+--S 3895 of 5341
+--a0:=integrate(t0,x)
+--E 3895
+
+--S 3896 of 5341
+--m0:=a0-r0
+--E 3896
+
+--S 3897 of 5341
+--d0:=D(m0,x)
+--E 3897
+
+)clear all
+
+--S 3898 of 5341
+t0:=log(c*(a+b*x)^n)/(d+e*x^2)
+--R 
+--R
+--R                       n
+--R        log(c (b x + a) )
+--R   (1)  -----------------
+--R                2
+--R             e x  + d
+--R                                                    Type: Expression(Integer)
+--E 3898
+
+--S 3899 of 5341
+--r0:=1/2*log(c*(a+b*x)^n)*log(b*(sqrt(-d)-x*sqrt(e))/(b*sqrt(-d)+_
+--  a*sqrt(e)))/(sqrt(-d)*sqrt(e))-1/2*log(c*(a+b*x)^n)*log(b*(sqrt(-d)+_
+--  x*sqrt(e))/(b*sqrt(-d)-a*sqrt(e)))/(sqrt(-d)*sqrt(e))-_
+--  1/2*n*polylog(2,-(a+b*x)*sqrt(e)/(b*sqrt(-d)-a*sqrt(e)))/_
+--  (sqrt(-d)*sqrt(e))+1/2*n*polylog(2,(a+b*x)*sqrt(e)/(b*sqrt(-d)+_
+--  a*sqrt(e)))/(sqrt(-d)*sqrt(e))
+--E 3899
+
+--S 3900 of 5341
+--a0:=integrate(t0,x)
+--E 3900
+
+--S 3901 of 5341
+--m0:=a0-r0
+--E 3901
+
+--S 3902 of 5341
+--d0:=D(m0,x)
+--E 3902
+
+)clear all
+
+--S 3903 of 5341
+t0:=1/((d+e*x^2)*log(c*(a+b*x)^n))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R            2                    n
+--R        (e x  + d)log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 3903
+
+--S 3904 of 5341
+--r0:=-1/2*Int(1/(log(c*(a+b*x)^n)*(sqrt(-d)-x*sqrt(e))),x)/sqrt(-d)-1/2*_
+--  Int(1/(log(c*(a+b*x)^n)*(sqrt(-d)+x*sqrt(e))),x)/sqrt(-d)
+--E 3904
+
+--S 3905 of 5341
+--a0:=integrate(t0,x)
+--E 3905
+
+--S 3906 of 5341
+--m0:=a0-r0
+--E 3906
+
+--S 3907 of 5341
+--d0:=D(m0,x)
+--E 3907
+
+)clear all
+
+--S 3908 of 5341
+t0:=log(c*(a+b*x)^n)^3/(d*x+e*x^2)
+--R 
+--R
+--R                       n 3
+--R        log(c (b x + a) )
+--R   (1)  ------------------
+--R               2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 3908
+
+--S 3909 of 5341
+--r0:=log(-b*x/a)*log(c*(a+b*x)^n)^3/d-log(c*(a+b*x)^n)^3*log(b*(d+e*x)/_
+--  (b*d-a*e))/d+3*n*log(c*(a+b*x)^n)^2*polylog(2,(a+b*x)/a)/d-3*n*_
+--  log(c*(a+b*x)^n)^2*polylog(2,-e*(a+b*x)/(b*d-a*e))/d-6*n^2*_
+--  log(c*(a+b*x)^n)*polylog(3,(a+b*x)/a)/d+6*n^2*log(c*(a+b*x)^n)*_
+--  polylog(3,-e*(a+b*x)/(b*d-a*e))/d+6*n^3*polylog(4,(a+b*x)/a)/d-_
+--  6*n^3*polylog(4,-e*(a+b*x)/(b*d-a*e))/d
+--E 3909
+
+--S 3910 of 5341
+--a0:=integrate(t0,x)
+--E 3910
+
+--S 3911 of 5341
+--m0:=a0-r0
+--E 3911
+
+--S 3912 of 5341
+--d0:=D(m0,x)
+--E 3912
+
+)clear all
+
+--S 3913 of 5341
+t0:=log(c*(a+b*x)^n)^2/(d*x+e*x^2)
+--R 
+--R
+--R                       n 2
+--R        log(c (b x + a) )
+--R   (1)  ------------------
+--R               2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 3913
+
+--S 3914 of 5341
+--r0:=log(-b*x/a)*log(c*(a+b*x)^n)^2/d-log(c*(a+b*x)^n)^2*log(b*(d+e*x)/_
+--  (b*d-a*e))/d+2*n*log(c*(a+b*x)^n)*polylog(2,(a+b*x)/a)/d-2*n*log(c*_
+--  (a+b*x)^n)*polylog(2,-e*(a+b*x)/(b*d-a*e))/d-2*n^2*polylog(3,_
+--  (a+b*x)/a)/d+2*n^2*polylog(3,-e*(a+b*x)/(b*d-a*e))/d
+--E 3914
+
+--S 3915 of 5341
+--a0:=integrate(t0,x)
+--E 3915
+
+--S 3916 of 5341
+--m0:=a0-r0
+--E 3916
+
+--S 3917 of 5341
+--d0:=D(m0,x)
+--E 3917
+
+)clear all
+
+--S 3918 of 5341
+t0:=log(c*(a+b*x)^n)/(d*x+e*x^2)
+--R 
+--R
+--R                       n
+--R        log(c (b x + a) )
+--R   (1)  -----------------
+--R               2
+--R            e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 3918
+
+--S 3919 of 5341
+--r0:=log(-b*x/a)*log(c*(a+b*x)^n)/d-log(c*(a+b*x)^n)*log(b*(d+e*x)/_
+--  (b*d-a*e))/d+n*polylog(2,(a+b*x)/a)/d-n*polylog(2,-e*(a+b*x)/(b*d-a*e))/d
+--E 3919
+
+--S 3920 of 5341
+--a0:=integrate(t0,x)
+--E 3920
+
+--S 3921 of 5341
+--m0:=a0-r0
+--E 3921
+
+--S 3922 of 5341
+--d0:=D(m0,x)
+--E 3922
+
+)clear all
+
+--S 3923 of 5341
+t0:=1/((d*x+e*x^2)*log(c*(a+b*x)^n))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R            2                      n
+--R        (e x  + d x)log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 3923
+
+--S 3924 of 5341
+--r0:=Int(1/(x*log(c*(a+b*x)^n)),x)/d-e*Int(1/((d+e*x)*log(c*(a+b*x)^n)),x)/d
+--E 3924
+
+--S 3925 of 5341
+--a0:=integrate(t0,x)
+--E 3925
+
+--S 3926 of 5341
+--m0:=a0-r0
+--E 3926
+
+--S 3927 of 5341
+--d0:=D(m0,x)
+--E 3927
+
+)clear all
+
+--S 3928 of 5341
+t0:=log(c*(a+b*x)^n)^3/(d+e*x+f*x^2)
+--R 
+--R
+--R                       n 3
+--R        log(c (b x + a) )
+--R   (1)  ------------------
+--R             2
+--R          f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 3928
+
+--S 3929 of 5341
+--r0:=log(c*(a+b*x)^n)^3*log(-b*(e+2*f*x-sqrt(e^2-4*d*f))/(2*a*f-b*(e-_
+--  sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)-log(c*(a+b*x)^n)^3*log(-b*(e+2*f*x+_
+--  sqrt(e^2-4*d*f))/(2*a*f-b*(e+sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)+3*n*_
+--  log(c*(a+b*x)^n)^2*polylog(2,2*f*(a+b*x)/(2*a*f-b*(e-sqrt(e^2-4*d*f))))/_
+--  sqrt(e^2-4*d*f)-3*n*log(c*(a+b*x)^n)^2*polylog(2,2*f*(a+b*x)/(2*a*f-_
+--  b*(e+sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)-6*n^2*log(c*(a+b*x)^n)*_
+--  polylog(3,2*f*(a+b*x)/(2*a*f-b*(e-sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)+_
+--  6*n^2*log(c*(a+b*x)^n)*polylog(3,2*f*(a+b*x)/(2*a*f-b*(e+sqrt(e^2-_
+--  4*d*f))))/sqrt(e^2-4*d*f)+6*n^3*polylog(4,2*f*(a+b*x)/(2*a*f-b*(e-_
+--  sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)-6*n^3*polylog(4,2*f*(a+b*x)/_
+--  (2*a*f-b*(e+sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)
+--E 3929
+
+--S 3930 of 5341
+--a0:=integrate(t0,x)
+--E 3930
+
+--S 3931 of 5341
+--m0:=a0-r0
+--E 3931
+
+--S 3932 of 5341
+--d0:=D(m0,x)
+--E 3932
+
+)clear all
+
+--S 3933 of 5341
+t0:=log(c*(a+b*x)^n)^2/(d+e*x+f*x^2)
+--R 
+--R
+--R                       n 2
+--R        log(c (b x + a) )
+--R   (1)  ------------------
+--R             2
+--R          f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 3933
+
+--S 3934 of 5341
+--r0:=log(c*(a+b*x)^n)^2*log(-b*(e+2*f*x-sqrt(e^2-4*d*f))/(2*a*f-b*(e-_
+--  sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)-log(c*(a+b*x)^n)^2*log(-b*(e+2*f*x+_
+--  sqrt(e^2-4*d*f))/(2*a*f-b*(e+sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)+2*n*_
+--  log(c*(a+b*x)^n)*polylog(2,2*f*(a+b*x)/(2*a*f-b*(e-sqrt(e^2-4*d*f))))/_
+--  sqrt(e^2-4*d*f)-2*n*log(c*(a+b*x)^n)*polylog(2,2*f*(a+b*x)/(2*a*f-b*_
+--  (e+sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)-2*n^2*polylog(3,2*f*(a+b*x)/_
+--  (2*a*f-b*(e-sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)+2*n^2*_
+--  polylog(3,2*f*(a+b*x)/(2*a*f-b*(e+sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)
+--E 3934
+
+--S 3935 of 5341
+--a0:=integrate(t0,x)
+--E 3935
+
+--S 3936 of 5341
+--m0:=a0-r0
+--E 3936
+
+--S 3937 of 5341
+--d0:=D(m0,x)
+--E 3937
+
+)clear all
+
+--S 3938 of 5341
+t0:=log(c*(a+b*x)^n)/(d+e*x+f*x^2)
+--R 
+--R
+--R                       n
+--R        log(c (b x + a) )
+--R   (1)  -----------------
+--R             2
+--R          f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 3938
+
+--S 3939 of 5341
+--r0:=log(c*(a+b*x)^n)*log(-b*(e+2*f*x-sqrt(e^2-4*d*f))/(2*a*f-_
+--  b*(e-sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)-log(c*(a+b*x)^n)*_
+--  log(-b*(e+2*f*x+sqrt(e^2-4*d*f))/(2*a*f-b*(e+sqrt(e^2-4*d*f))))/_
+--  sqrt(e^2-4*d*f)+n*polylog(2,2*f*(a+b*x)/(2*a*f-b*(e-sqrt(e^2-_
+--  4*d*f))))/sqrt(e^2-4*d*f)-n*polylog(2,2*f*(a+b*x)/(2*a*f-b*(e+_
+--  sqrt(e^2-4*d*f))))/sqrt(e^2-4*d*f)
+--E 3939
+
+--S 3940 of 5341
+--a0:=integrate(t0,x)
+--E 3940
+
+--S 3941 of 5341
+--m0:=a0-r0
+--E 3941
+
+--S 3942 of 5341
+--d0:=D(m0,x)
+--E 3942
+
+)clear all
+
+--S 3943 of 5341
+t0:=1/((d+e*x+f*x^2)*log(c*(a+b*x)^n))
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R            2                          n
+--R        (f x  + e x + d)log(c (b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 3943
+
+--S 3944 of 5341
+--r0:=2*f*Int(1/(log(c*(a+b*x)^n)*(e+2*f*x-sqrt(e^2-4*d*f))),x)/_
+--  sqrt(e^2-4*d*f)-2*f*Int(1/(log(c*(a+b*x)^n)*(e+2*f*x+_
+--  sqrt(e^2-4*d*f))),x)/sqrt(e^2-4*d*f)
+--E 3944
+
+--S 3945 of 5341
+--a0:=integrate(t0,x)
+--E 3945
+
+--S 3946 of 5341
+--m0:=a0-r0
+--E 3946
+
+--S 3947 of 5341
+--d0:=D(m0,x)
+--E 3947
+
+)clear all
+
+--S 3948 of 5341
+t0:=x^3*log(x)/(a+b*x+c*x^2)
+--R 
+--R
+--R            3
+--R           x log(x)
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 3948
+
+--S 3949 of 5341
+--r0:=b*x/c^2-1/4*x^2/c-b*x*log(x)/c^2+1/2*x^2*log(x)/c+1/2*log(x)*_
+--  log((b+2*c*x-sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*(b^2-a*c-b*(b^2-_
+--  3*a*c)/sqrt(b^2-4*a*c))/c^3+1/2*polylog(2,-2*c*x/(b-sqrt(b^2-4*a*c)))*_
+--  (b^2-a*c-b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/c^3+1/2*log(x)*log((b+2*c*x+_
+--  sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-a*c+b*(b^2-3*a*c)/_
+--  sqrt(b^2-4*a*c))/c^3+1/2*polylog(2,-2*c*x/(b+sqrt(b^2-4*a*c)))*_
+--  (b^2-a*c+b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/c^3
+--E 3949
+
+--S 3950 of 5341
+--a0:=integrate(t0,x)
+--E 3950
+
+--S 3951 of 5341
+--m0:=a0-r0
+--E 3951
+
+--S 3952 of 5341
+--d0:=D(m0,x)
+--E 3952
+
+)clear all
+
+--S 3953 of 5341
+t0:=x^2*log(x)/(a+b*x+c*x^2)
+--R 
+--R
+--R            2
+--R           x log(x)
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 3953
+
+--S 3954 of 5341
+--r0:=-x/c+x*log(x)/c-1/2*log(x)*log((b+2*c*x-sqrt(b^2-4*a*c))/_
+--  (b-sqrt(b^2-4*a*c)))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/c^2-1/2*_
+--  polylog(2,-2*c*x/(b-sqrt(b^2-4*a*c)))*(b+(-b^2+2*a*c)/sqrt(b^2-_
+--  4*a*c))/c^2-1/2*log(x)*log((b+2*c*x+sqrt(b^2-4*a*c))/(b+sqrt(b^2-_
+--  4*a*c)))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/c^2-1/2*polylog(2,_
+--  -2*c*x/(b+sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/c^2
+--E 3954
+
+--S 3955 of 5341
+--a0:=integrate(t0,x)
+--E 3955
+
+--S 3956 of 5341
+--m0:=a0-r0
+--E 3956
+
+--S 3957 of 5341
+--d0:=D(m0,x)
+--E 3957
+
+)clear all
+
+--S 3958 of 5341
+t0:=x*log(x)/(a+b*x+c*x^2)
+--R 
+--R
+--R           x log(x)
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 3958
+
+--S 3959 of 5341
+--r0:=1/2*log(x)*log((b+2*c*x-sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*_
+--  (1-b/sqrt(b^2-4*a*c))/c+1/2*polylog(2,-2*c*x/(b-sqrt(b^2-4*a*c)))*_
+--  (1-b/sqrt(b^2-4*a*c))/c+1/2*log(x)*log((b+2*c*x+sqrt(b^2-4*a*c))/_
+--  (b+sqrt(b^2-4*a*c)))*(1+b/sqrt(b^2-4*a*c))/c+1/2*polylog(2,-2*c*x/_
+--  (b+sqrt(b^2-4*a*c)))*(1+b/sqrt(b^2-4*a*c))/c
+--E 3959
+
+--S 3960 of 5341
+--a0:=integrate(t0,x)
+--E 3960
+
+--S 3961 of 5341
+--m0:=a0-r0
+--E 3961
+
+--S 3962 of 5341
+--d0:=D(m0,x)
+--E 3962
+
+)clear all
+
+--S 3963 of 5341
+t0:=log(x)/(a+b*x+c*x^2)
+--R 
+--R
+--R            log(x)
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 3963
+
+--S 3964 of 5341
+--r0:=log(x)*log((b+2*c*x-sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))/sqrt(b^2-_
+--  4*a*c)-log(x)*log((b+2*c*x+sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))/_
+--  sqrt(b^2-4*a*c)+polylog(2,-2*c*x/(b-sqrt(b^2-4*a*c)))/sqrt(b^2-_
+--  4*a*c)-polylog(2,-2*c*x/(b+sqrt(b^2-4*a*c)))/sqrt(b^2-4*a*c)
+--E 3964
+
+--S 3965 of 5341
+--a0:=integrate(t0,x)
+--E 3965
+
+--S 3966 of 5341
+--m0:=a0-r0
+--E 3966
+
+--S 3967 of 5341
+--d0:=D(m0,x)
+--E 3967
+
+)clear all
+
+--S 3968 of 5341
+t0:=log(x)/(x*(a+b*x+c*x^2))
+--R 
+--R
+--R              log(x)
+--R   (1)  -----------------
+--R           3      2
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3968
+
+--S 3969 of 5341
+--r0:=1/2*log(x)^2/a-1/2*log(x)*log((b+2*c*x+sqrt(b^2-4*a*c))/(b+sqrt(b^2-_
+--  4*a*c)))*(1-b/sqrt(b^2-4*a*c))/a-1/2*polylog(2,-2*c*x/(b+sqrt(b^2-_
+--  4*a*c)))*(1-b/sqrt(b^2-4*a*c))/a-1/2*log(x)*log((b+2*c*x-sqrt(b^2-_
+--  4*a*c))/(b-sqrt(b^2-4*a*c)))*(1+b/sqrt(b^2-4*a*c))/a-1/2*polylog(2,_
+--  -2*c*x/(b-sqrt(b^2-4*a*c)))*(1+b/sqrt(b^2-4*a*c))/a
+--E 3969
+
+--S 3970 of 5341
+--a0:=integrate(t0,x)
+--E 3970
+
+--S 3971 of 5341
+--m0:=a0-r0
+--E 3971
+
+--S 3972 of 5341
+--d0:=D(m0,x)
+--E 3972
+
+)clear all
+
+--S 3973 of 5341
+t0:=log(x)/(x^2*(a+b*x+c*x^2))
+--R 
+--R
+--R              log(x)
+--R   (1)  ------------------
+--R           4      3      2
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3973
+
+--S 3974 of 5341
+--r0:=(-1)/(a*x)-log(x)/(a*x)-1/2*b*log(x)^2/a^2+1/2*log(x)*log((b+2*c*x+_
+--  sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/_
+--  a^2+1/2*polylog(2,-2*c*x/(b+sqrt(b^2-4*a*c)))*(b+(-b^2+2*a*c)/_
+--  sqrt(b^2-4*a*c))/a^2+1/2*log(x)*log((b+2*c*x-sqrt(b^2-4*a*c))/(b-_
+--  sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/a^2+1/2*_
+--  polylog(2,-2*c*x/(b-sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/a^2
+--E 3974
+
+--S 3975 of 5341
+--a0:=integrate(t0,x)
+--E 3975
+
+--S 3976 of 5341
+--m0:=a0-r0
+--E 3976
+
+--S 3977 of 5341
+--d0:=D(m0,x)
+--E 3977
+
+)clear all
+
+--S 3978 of 5341
+t0:=log(x)/(x^3*(a+b*x+c*x^2))
+--R 
+--R
+--R              log(x)
+--R   (1)  ------------------
+--R           5      4      3
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 3978
+
+--S 3979 of 5341
+--r0:=(-1/4)/(a*x^2)+b/(a^2*x)-1/2*log(x)/(a*x^2)+b*log(x)/(a^2*x)+_
+--  1/2*(b^2-a*c)*log(x)^2/a^3-1/2*log(x)*log((b+2*c*x+sqrt(b^2-4*a*c))/_
+--  (b+sqrt(b^2-4*a*c)))*(b^2-a*c-b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/a^3-_
+--  1/2*polylog(2,-2*c*x/(b+sqrt(b^2-4*a*c)))*(b^2-a*c-b*(b^2-3*a*c)/_
+--  sqrt(b^2-4*a*c))/a^3-1/2*log(x)*log((b+2*c*x-sqrt(b^2-4*a*c))/(b-_
+--  sqrt(b^2-4*a*c)))*(b^2-a*c+b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/a^3-_
+--  1/2*polylog(2,-2*c*x/(b-sqrt(b^2-4*a*c)))*(b^2-a*c+b*(b^2-3*a*c)/_
+--  sqrt(b^2-4*a*c))/a^3
+--E 3979
+
+--S 3980 of 5341
+--a0:=integrate(t0,x)
+--E 3980
+
+--S 3981 of 5341
+--m0:=a0-r0
+--E 3981
+
+--S 3982 of 5341
+--d0:=D(m0,x)
+--E 3982
+
+)clear all
+
+--S 3983 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^4
+--R 
+--R
+--R   (1)
+--R      4               n 4       3               n 3     2 2               n 2
+--R     b log(c (e x + d) )  + 4a b log(c (e x + d) )  + 6a b log(c (e x + d) )
+--R   + 
+--R       3                 n     4
+--R     4a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 3983
+
+--S 3984 of 5341
+r0:=-24*a*b^3*n^3*x+24*b^4*n^4*x-24*b^4*n^3*(d+e*x)*log(c*(d+e*x)^n)/e+_
+   12*b^2*n^2*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/e-4*b*n*(d+e*x)*(a+_
+   b*log(c*(d+e*x)^n))^3/e+(d+e*x)*(a+b*log(c*(d+e*x)^n))^4/e
+--R 
+--R
+--R   (2)
+--R         4       4                 n 4
+--R       (b e x + b d)log(c (e x + d) )
+--R     + 
+--R             4          3        4          3                 n 3
+--R       ((- 4b e n + 4a b e)x - 4b d n + 4a b d)log(c (e x + d) )
+--R     + 
+--R              4   2        3        2 2         4   2        3        2 2
+--R         ((12b e n  - 12a b e n + 6a b e)x + 12b d n  - 12a b d n + 6a b d)
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R                 4   3        3   2      2 2        3           4   3
+--R           (- 24b e n  + 24a b e n  - 12a b e n + 4a b e)x - 24b d n
+--R         + 
+--R                3   2      2 2        3
+--R           24a b d n  - 12a b d n + 4a b d
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R           4   4        3   3      2 2   2     3         4         2 2   2
+--R       (24b e n  - 24a b e n  + 12a b e n  - 4a b e n + a e)x + 12a b d n
+--R     + 
+--R           3         4
+--R       - 4a b d n + a d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 3984
+
+--S 3985 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         4   4     4   4             4
+--R       (b e n x + b d n )log(e x + d)
+--R     + 
+--R              4   3      4   3               4   4       3   3       4   4
+--R           (4b e n x + 4b d n )log(c) + (- 4b e n  + 4a b e n )x - 4b d n
+--R         + 
+--R               3   3
+--R           4a b d n
+--R      *
+--R                     3
+--R         log(e x + d)
+--R     + 
+--R              4   2      4   2       2
+--R           (6b e n x + 6b d n )log(c)
+--R         + 
+--R                  4   3        3   2        4   3        3   2
+--R           ((- 12b e n  + 12a b e n )x - 12b d n  + 12a b d n )log(c)
+--R         + 
+--R               4   4        3   3     2 2   2        4   4        3   3
+--R           (12b e n  - 12a b e n  + 6a b e n )x + 12b d n  - 12a b d n
+--R         + 
+--R             2 2   2
+--R           6a b d n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R              4          4          3
+--R           (4b e n x + 4b d n)log(c)
+--R         + 
+--R                  4   2        3           4   2        3          2
+--R           ((- 12b e n  + 12a b e n)x - 12b d n  + 12a b d n)log(c)
+--R         + 
+--R                   4   3        3   2      2 2           4   3        3   2
+--R               (24b e n  - 24a b e n  + 12a b e n)x + 24b d n  - 24a b d n
+--R             + 
+--R                  2 2
+--R               12a b d n
+--R          *
+--R             log(c)
+--R         + 
+--R                 4   4        3   3      2 2   2     3             4   4
+--R           (- 24b e n  + 24a b e n  - 12a b e n  + 4a b e n)x - 24b d n
+--R         + 
+--R                3   3      2 2   2     3
+--R           24a b d n  - 12a b d n  + 4a b d n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R        4          4        4          3          3
+--R       b e x log(c)  + (- 4b e n + 4a b e)x log(c)
+--R     + 
+--R           4   2        3        2 2          2
+--R       (12b e n  - 12a b e n + 6a b e)x log(c)
+--R     + 
+--R             4   3        3   2      2 2        3
+--R       (- 24b e n  + 24a b e n  - 12a b e n + 4a b e)x log(c)
+--R     + 
+--R           4   4        3   3      2 2   2     3         4
+--R       (24b e n  - 24a b e n  + 12a b e n  - 4a b e n + a e)x
+--R  /
+--R     e
+--R                                         Type: Union(Expression(Integer),...)
+--E 3985
+
+--S 3986 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           4       4                 n 4
+--R       (- b e x - b d)log(c (e x + d) )
+--R     + 
+--R           4          3        4          3                 n 3
+--R       ((4b e n - 4a b e)x + 4b d n - 4a b d)log(c (e x + d) )
+--R     + 
+--R                4   2        3        2 2         4   2        3        2 2
+--R         ((- 12b e n  + 12a b e n - 6a b e)x - 12b d n  + 12a b d n - 6a b d)
+--R      *
+--R                        n 2
+--R         log(c (e x + d) )
+--R     + 
+--R               4   3        3   2      2 2        3           4   3        3   2
+--R           (24b e n  - 24a b e n  + 12a b e n - 4a b e)x + 24b d n  - 24a b d n
+--R         + 
+--R              2 2        3
+--R           12a b d n - 4a b d
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R         4   4     4   4             4
+--R       (b e n x + b d n )log(e x + d)
+--R     + 
+--R              4   3      4   3               4   4       3   3       4   4
+--R           (4b e n x + 4b d n )log(c) + (- 4b e n  + 4a b e n )x - 4b d n
+--R         + 
+--R               3   3
+--R           4a b d n
+--R      *
+--R                     3
+--R         log(e x + d)
+--R     + 
+--R              4   2      4   2       2
+--R           (6b e n x + 6b d n )log(c)
+--R         + 
+--R                  4   3        3   2        4   3        3   2
+--R           ((- 12b e n  + 12a b e n )x - 12b d n  + 12a b d n )log(c)
+--R         + 
+--R               4   4        3   3     2 2   2        4   4        3   3
+--R           (12b e n  - 12a b e n  + 6a b e n )x + 12b d n  - 12a b d n
+--R         + 
+--R             2 2   2
+--R           6a b d n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R              4          4          3
+--R           (4b e n x + 4b d n)log(c)
+--R         + 
+--R                  4   2        3           4   2        3          2
+--R           ((- 12b e n  + 12a b e n)x - 12b d n  + 12a b d n)log(c)
+--R         + 
+--R                   4   3        3   2      2 2           4   3        3   2
+--R               (24b e n  - 24a b e n  + 12a b e n)x + 24b d n  - 24a b d n
+--R             + 
+--R                  2 2
+--R               12a b d n
+--R          *
+--R             log(c)
+--R         + 
+--R                 4   4        3   3      2 2   2     3             4   4
+--R           (- 24b e n  + 24a b e n  - 12a b e n  + 4a b e n)x - 24b d n
+--R         + 
+--R                3   3      2 2   2     3
+--R           24a b d n  - 12a b d n  + 4a b d n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R        4          4        4          3          3
+--R       b e x log(c)  + (- 4b e n + 4a b e)x log(c)
+--R     + 
+--R           4   2        3        2 2          2
+--R       (12b e n  - 12a b e n + 6a b e)x log(c)
+--R     + 
+--R             4   3        3   2      2 2        3                  2 2   2
+--R       (- 24b e n  + 24a b e n  - 12a b e n + 4a b e)x log(c) - 12a b d n
+--R     + 
+--R         3         4
+--R       4a b d n - a d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 3986
+
+--S 3987 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3987
+
+)clear all
+
+--S 3988 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 3988
+
+--S 3989 of 5341
+r0:=6*a*b^2*n^2*x-6*b^3*n^3*x+6*b^3*n^2*(d+e*x)*log(c*(d+e*x)^n)/e-_
+   3*b*n*(d+e*x)*(a+b*log(c*(d+e*x)^n))^2/e+(d+e*x)*(a+b*log(c*(d+e*x)^n))^3/e
+--R 
+--R
+--R   (2)
+--R         3       3                 n 3
+--R       (b e x + b d)log(c (e x + d) )
+--R     + 
+--R             3          2        3          2                 n 2
+--R       ((- 3b e n + 3a b e)x - 3b d n + 3a b d)log(c (e x + d) )
+--R     + 
+--R             3   2       2        2          3   2       2        2
+--R         ((6b e n  - 6a b e n + 3a b e)x + 6b d n  - 6a b d n + 3a b d)
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R            3   3       2   2     2         3        2         3
+--R       (- 6b e n  + 6a b e n  - 3a b e n + a e)x - 3a b d n + a d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 3989
+
+--S 3990 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3   3     3   3             3
+--R       (b e n x + b d n )log(e x + d)
+--R     + 
+--R              3   2      3   2               3   3       2   2       3   3
+--R           (3b e n x + 3b d n )log(c) + (- 3b e n  + 3a b e n )x - 3b d n
+--R         + 
+--R               2   2
+--R           3a b d n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R              3          3          2
+--R           (3b e n x + 3b d n)log(c)
+--R         + 
+--R                 3   2       2          3   2       2
+--R           ((- 6b e n  + 6a b e n)x - 6b d n  + 6a b d n)log(c)
+--R         + 
+--R              3   3       2   2     2            3   3       2   2     2
+--R           (6b e n  - 6a b e n  + 3a b e n)x + 6b d n  - 6a b d n  + 3a b d n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R        3          3        3          2          2
+--R       b e x log(c)  + (- 3b e n + 3a b e)x log(c)
+--R     + 
+--R          3   2       2        2
+--R       (6b e n  - 6a b e n + 3a b e)x log(c)
+--R     + 
+--R            3   3       2   2     2         3
+--R       (- 6b e n  + 6a b e n  - 3a b e n + a e)x
+--R  /
+--R     e
+--R                                         Type: Union(Expression(Integer),...)
+--E 3990
+
+--S 3991 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           3       3                 n 3
+--R       (- b e x - b d)log(c (e x + d) )
+--R     + 
+--R           3          2        3          2                 n 2
+--R       ((3b e n - 3a b e)x + 3b d n - 3a b d)log(c (e x + d) )
+--R     + 
+--R               3   2       2        2          3   2       2        2
+--R         ((- 6b e n  + 6a b e n - 3a b e)x - 6b d n  + 6a b d n - 3a b d)
+--R      *
+--R                        n
+--R         log(c (e x + d) )
+--R     + 
+--R         3   3     3   3             3
+--R       (b e n x + b d n )log(e x + d)
+--R     + 
+--R              3   2      3   2               3   3       2   2       3   3
+--R           (3b e n x + 3b d n )log(c) + (- 3b e n  + 3a b e n )x - 3b d n
+--R         + 
+--R               2   2
+--R           3a b d n
+--R      *
+--R                     2
+--R         log(e x + d)
+--R     + 
+--R              3          3          2
+--R           (3b e n x + 3b d n)log(c)
+--R         + 
+--R                 3   2       2          3   2       2
+--R           ((- 6b e n  + 6a b e n)x - 6b d n  + 6a b d n)log(c)
+--R         + 
+--R              3   3       2   2     2            3   3       2   2     2
+--R           (6b e n  - 6a b e n  + 3a b e n)x + 6b d n  - 6a b d n  + 3a b d n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R        3          3        3          2          2
+--R       b e x log(c)  + (- 3b e n + 3a b e)x log(c)
+--R     + 
+--R          3   2       2        2                 2         3
+--R       (6b e n  - 6a b e n + 3a b e)x log(c) + 3a b d n - a d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 3991
+
+--S 3992 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3992
+
+)clear all
+
+--S 3993 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R         2               n 2                       n     2
+--R   (1)  b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 3993
+
+--S 3994 of 5341
+r0:=-2*a*b*n*x+2*b^2*n^2*x-2*b^2*n*(d+e*x)*log(c*(d+e*x)^n)/e+(d+e*x)*_
+   (a+b*log(c*(d+e*x)^n))^2/e
+--R 
+--R
+--R   (2)
+--R         2       2                 n 2
+--R       (b e x + b d)log(c (e x + d) )
+--R     + 
+--R             2                   2                            n
+--R       ((- 2b e n + 2a b e)x - 2b d n + 2a b d)log(c (e x + d) )
+--R     + 
+--R          2   2               2       2
+--R       (2b e n  - 2a b e n + a e)x + a d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 3994
+
+--S 3995 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         2   2     2   2             2
+--R       (b e n x + b d n )log(e x + d)
+--R     + 
+--R              2          2                  2   2                  2   2
+--R           (2b e n x + 2b d n)log(c) + (- 2b e n  + 2a b e n)x - 2b d n
+--R         + 
+--R           2a b d n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R      2          2        2                           2   2               2
+--R     b e x log(c)  + (- 2b e n + 2a b e)x log(c) + (2b e n  - 2a b e n + a e)x
+--R  /
+--R     e
+--R                                         Type: Union(Expression(Integer),...)
+--E 3995
+
+--S 3996 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           2       2                 n 2
+--R       (- b e x - b d)log(c (e x + d) )
+--R     + 
+--R           2                   2                            n
+--R       ((2b e n - 2a b e)x + 2b d n - 2a b d)log(c (e x + d) )
+--R     + 
+--R         2   2     2   2             2
+--R       (b e n x + b d n )log(e x + d)
+--R     + 
+--R              2          2                  2   2                  2   2
+--R           (2b e n x + 2b d n)log(c) + (- 2b e n  + 2a b e n)x - 2b d n
+--R         + 
+--R           2a b d n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R        2          2        2                         2
+--R       b e x log(c)  + (- 2b e n + 2a b e)x log(c) - a d
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 3996
+
+--S 3997 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 3997
+
+)clear all
+
+--S 3998 of 5341
+t0:=a+b*log(c*(d+e*x)^n)
+--R 
+--R
+--R                         n
+--R   (1)  b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 3998
+
+--S 3999 of 5341
+r0:=a*x-b*n*x+b*(d+e*x)*log(c*(d+e*x)^n)/e
+--R 
+--R
+--R                                    n
+--R        (b e x + b d)log(c (e x + d) ) + (- b e n + a e)x
+--R   (2)  -------------------------------------------------
+--R                                e
+--R                                                    Type: Expression(Integer)
+--E 3999
+
+--S 4000 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (b e n x + b d n)log(e x + d) + b e x log(c) + (- b e n + a e)x
+--R   (3)  ---------------------------------------------------------------
+--R                                       e
+--R                                         Type: Union(Expression(Integer),...)
+--E 4000
+
+--S 4001 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                     n
+--R       (- b e x - b d)log(c (e x + d) ) + (b e n x + b d n)log(e x + d)
+--R     + 
+--R       b e x log(c)
+--R  /
+--R     e
+--R                                                    Type: Expression(Integer)
+--E 4001
+
+--S 4002 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4002
+
+)clear all
+
+--S 4003 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R                         n
+--R        b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4003
+
+--S 4004 of 5341
+--r0:=(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*b*e*n*_
+--  (c*(d+e*x)^n)^(1/n))
+--E 4004
+
+--S 4005 of 5341
+--a0:=integrate(t0,x)
+--E 4005
+
+--S 4006 of 5341
+--m0:=a0-r0
+--E 4006
+
+--S 4007 of 5341
+--d0:=D(m0,x)
+--E 4007
+
+)clear all
+
+--S 4008 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))^2
+--R 
+--R
+--R                                 1
+--R   (1)  --------------------------------------------------
+--R         2               n 2                       n     2
+--R        b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4008
+
+--S 4009 of 5341
+--r0:=(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*b^2*_
+--  e*n^2*(c*(d+e*x)^n)^(1/n))+(-d-e*x)/(b*e*n*(a+b*log(c*(d+e*x)^n)))
+--E 4009
+
+--S 4010 of 5341
+--a0:=integrate(t0,x)
+--E 4010
+
+--S 4011 of 5341
+--m0:=a0-r0
+--E 4011
+
+--S 4012 of 5341
+--d0:=D(m0,x)
+--E 4012
+
+)clear all
+
+--S 4013 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))^3
+--R 
+--R
+--R   (1)
+--R                                         1
+--R   ----------------------------------------------------------------------------
+--R    3               n 3       2               n 2     2                 n     3
+--R   b log(c (e x + d) )  + 3a b log(c (e x + d) )  + 3a b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4013
+
+--S 4014 of 5341
+--r0:=1/2*(d+e*x)*Ei((a+b*log(c*(d+e*x)^n))/(b*n))/(%e^(a/(b*n))*b^3*e*_
+--  n^3*(c*(d+e*x)^n)^(1/n))+1/2*(-d-e*x)/(b*e*n*(a+b*log(c*(d+e*x)^n))^2)+_
+--  1/2*(-d-e*x)/(b^2*e*n^2*(a+b*log(c*(d+e*x)^n)))
+--E 4014
+
+--S 4015 of 5341
+--a0:=integrate(t0,x)
+--E 4015
+
+--S 4016 of 5341
+--m0:=a0-r0
+--E 4016
+
+--S 4017 of 5341
+--d0:=D(m0,x)
+--E 4017
+
+)clear all
+
+--S 4018 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^(5/2)
+--R 
+--R
+--R   (1)
+--R       2               n 2                       n     2
+--R     (b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a )
+--R  *
+--R      +-----------------------+
+--R      |                 n
+--R     \|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4018
+
+--S 4019 of 5341
+--r0:=-5/2*b*n*(d+e*x)*(a+b*log(c*(d+e*x)^n))^(3/2)/e+(d+e*x)*(a+b*log(c*_
+--  (d+e*x)^n))^(5/2)/e-15/8*b^(5/2)*n^(5/2)*(d+e*x)*erfi(sqrt(a+b*log(c*_
+--  (d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)/(%e^(a/(b*n))*e*(c*(d+_
+--  e*x)^n)^(1/n))+15/4*b^2*n^2*(d+e*x)*sqrt(a+b*log(c*(d+e*x)^n))/e
+--E 4019
+
+--S 4020 of 5341
+--a0:=integrate(t0,x)
+--E 4020
+
+--S 4021 of 5341
+--m0:=a0-r0
+--E 4021
+
+--S 4022 of 5341
+--d0:=D(m0,x)
+--E 4022
+
+)clear all
+
+--S 4023 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R                                  +-----------------------+
+--R                          n       |                 n
+--R   (1)  (b log(c (e x + d) ) + a)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4023
+
+--S 4024 of 5341
+--r0:=(d+e*x)*(a+b*log(c*(d+e*x)^n))^(3/2)/e+3/4*b^(3/2)*n^(3/2)*(d+e*x)*_
+--  erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)/(%e^(a/_
+--  (b*n))*e*(c*(d+e*x)^n)^(1/n))-3/2*b*n*(d+e*x)*sqrt(a+b*log(c*(d+e*x)^n))/e
+--E 4024
+
+--S 4025 of 5341
+--a0:=integrate(t0,x)
+--E 4025
+
+--S 4026 of 5341
+--m0:=a0-r0
+--E 4026
+
+--S 4027 of 5341
+--d0:=D(m0,x)
+--E 4027
+
+)clear all
+
+--S 4028 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R         +-----------------------+
+--R         |                 n
+--R   (1)  \|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4028
+
+--S 4029 of 5341
+--r0:=-1/2*(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(%pi)*sqrt(b)*sqrt(n)/(%e^(a/(b*n))*e*(c*(d+e*x)^n)^(1/n))+_
+--  (d+e*x)*sqrt(a+b*log(c*(d+e*x)^n))/e
+--E 4029
+
+--S 4030 of 5341
+--a0:=integrate(t0,x)
+--E 4030
+
+--S 4031 of 5341
+--m0:=a0-r0
+--E 4031
+
+--S 4032 of 5341
+--d0:=D(m0,x)
+--E 4032
+
+)clear all
+
+--S 4033 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R         +-----------------------+
+--R         |                 n
+--R        \|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4033
+
+--S 4034 of 5341
+--r0:=(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(%pi)/(%e^(a/(b*n))*e*(c*(d+e*x)^n)^(1/n)*sqrt(b)*sqrt(n))
+--E 4034
+
+--S 4035 of 5341
+--a0:=integrate(t0,x)
+--E 4035
+
+--S 4036 of 5341
+--m0:=a0-r0
+--E 4036
+
+--S 4037 of 5341
+--d0:=D(m0,x)
+--E 4037
+
+)clear all
+
+--S 4038 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R                                 1
+--R   (1)  ---------------------------------------------------
+--R                                  +-----------------------+
+--R                          n       |                 n
+--R        (b log(c (e x + d) ) + a)\|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4038
+
+--S 4039 of 5341
+--r0:=2*(d+e*x)*erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+--  sqrt(%pi)/(%e^(a/(b*n))*b^(3/2)*e*n^(3/2)*(c*(d+e*x)^n)^(1/n))-2*_
+--  (d+e*x)/(b*e*n*sqrt(a+b*log(c*(d+e*x)^n)))
+--E 4039
+
+--S 4040 of 5341
+--a0:=integrate(t0,x)
+--E 4040
+
+--S 4041 of 5341
+--m0:=a0-r0
+--E 4041
+
+--S 4042 of 5341
+--d0:=D(m0,x)
+--E 4042
+
+)clear all
+
+--S 4043 of 5341
+t0:=1/(a+b*log(c*(d+e*x)^n))^(5/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R         2               n 2                       n     2
+--R       (b log(c (e x + d) )  + 2a b log(c (e x + d) ) + a )
+--R    *
+--R        +-----------------------+
+--R        |                 n
+--R       \|b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4043
+
+--S 4044 of 5341
+--r0:=-2/3*(d+e*x)/(b*e*n*(a+b*log(c*(d+e*x)^n))^(3/2))+4/3*(d+e*x)*_
+--  erfi(sqrt(a+b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)/_
+--  (%e^(a/(b*n))*b^(5/2)*e*n^(5/2)*(c*(d+e*x)^n)^(1/n))-4/3*(d+e*x)/_
+--  (b^2*e*n^2*sqrt(a+b*log(c*(d+e*x)^n)))
+--E 4044
+
+--S 4045 of 5341
+--a0:=integrate(t0,x)
+--E 4045
+
+--S 4046 of 5341
+--m0:=a0-r0
+--E 4046
+
+--S 4047 of 5341
+--d0:=D(m0,x)
+--E 4047
+
+)clear all
+
+--S 4048 of 5341
+t0:=(a-b*log(c*(d+e*x)^n))^(5/2)
+--R 
+--R
+--R   (1)
+--R       2               n 2                       n     2
+--R     (b log(c (e x + d) )  - 2a b log(c (e x + d) ) + a )
+--R  *
+--R      +-------------------------+
+--R      |                   n
+--R     \|- b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4048
+
+--S 4049 of 5341
+r0:=5/2*b*n*(d+e*x)*(a-b*log(c*(d+e*x)^n))^(3/2)/e+(d+e*x)*(a-b*log(c*_
+   (d+e*x)^n))^(5/2)/e-15/8*%e^(a/(b*n))*b^(5/2)*n^(5/2)*(d+e*x)*_
+   erf(sqrt(a-b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)/_
+   (e*(c*(d+e*x)^n)^(1/n))+15/4*b^2*n^2*(d+e*x)*sqrt(a-b*log(c*(d+e*x)^n))/e
+--R 
+--R
+--R   (2)
+--R                                    a
+--R                                   ---
+--R               2   2       2   2   b n +-+ +-+ +---+
+--R         (- 15b e n x - 15b d n )%e   \|b \|n \|%pi
+--R      *
+--R              +-------------------------+
+--R              |                   n
+--R             \|- b log(c (e x + d) ) + a
+--R         erf(----------------------------)
+--R                        +-+ +-+
+--R                       \|b \|n
+--R     + 
+--R              2        2                 n 2
+--R           (8b e x + 8b d)log(c (e x + d) )
+--R         + 
+--R                  2                     2                             n
+--R           ((- 20b e n - 16a b e)x - 20b d n - 16a b d)log(c (e x + d) )
+--R         + 
+--R               2   2                 2         2   2                 2
+--R           (30b e n  + 20a b e n + 8a e)x + 30b d n  + 20a b d n + 8a d
+--R      *
+--R                       1
+--R                       - +-------------------------+
+--R                     n n |                   n
+--R         (c (e x + d) ) \|- b log(c (e x + d) ) + a
+--R  /
+--R                      1
+--R                      -
+--R                    n n
+--R     8e (c (e x + d) )
+--R                                                    Type: Expression(Integer)
+--E 4049
+
+-- integrate: implementation incomplete (constant residues)
+--S 4050 of 5341
+--a0:=integrate(t0,x)
+--E 4050
+
+--S 4051 of 5341
+--m0:=a0-r0
+--E 4051
+
+--S 4052 of 5341
+--d0:=D(m0,x)
+--E 4052
+
+)clear all
+
+--S 4053 of 5341
+t0:=(a-b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R                                    +-------------------------+
+--R                            n       |                   n
+--R   (1)  (- b log(c (e x + d) ) + a)\|- b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4053
+
+--S 4054 of 5341
+r0:=(d+e*x)*(a-b*log(c*(d+e*x)^n))^(3/2)/e-3/4*%e^(a/(b*n))*b^(3/2)*n^(3/2)*_
+   (d+e*x)*erf(sqrt(a-b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)/_
+   (e*(c*(d+e*x)^n)^(1/n))+3/2*b*n*(d+e*x)*sqrt(a-b*log(c*(d+e*x)^n))/e
+--R 
+--R
+--R   (2)
+--R                               a                    +-------------------------+
+--R                              ---                   |                   n
+--R                              b n +-+ +-+ +---+    \|- b log(c (e x + d) ) + a
+--R       (- 3b e n x - 3b d n)%e   \|b \|n \|%pi erf(----------------------------)
+--R                                                              +-+ +-+
+--R                                                             \|b \|n
+--R     + 
+--R                                          n
+--R         ((- 4b e x - 4b d)log(c (e x + d) ) + (6b e n + 4a e)x + 6b d n + 4a d)
+--R      *
+--R                       1
+--R                       - +-------------------------+
+--R                     n n |                   n
+--R         (c (e x + d) ) \|- b log(c (e x + d) ) + a
+--R  /
+--R                      1
+--R                      -
+--R                    n n
+--R     4e (c (e x + d) )
+--R                                                    Type: Expression(Integer)
+--E 4054
+
+-- integrate: implementation incomplete (constant residues)
+--S 4055 of 5341
+--a0:=integrate(t0,x)
+--E 4055
+
+--S 4056 of 5341
+--m0:=a0-r0
+--E 4056
+
+--S 4057 of 5341
+--d0:=D(m0,x)
+--E 4057
+
+)clear all
+
+--S 4058 of 5341
+t0:=(a-b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R         +-------------------------+
+--R         |                   n
+--R   (1)  \|- b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4058
+
+--S 4059 of 5341
+r0:=-1/2*%e^(a/(b*n))*(d+e*x)*erf(sqrt(a-b*log(c*(d+e*x)^n))/_
+   (sqrt(b)*sqrt(n)))*sqrt(%pi)*sqrt(b)*sqrt(n)/(e*(c*(d+e*x)^n)^(1/n))+_
+   (d+e*x)*sqrt(a-b*log(c*(d+e*x)^n))/e
+--R 
+--R
+--R   (2)
+--R                     a                    +-------------------------+
+--R                    ---                   |                   n
+--R                    b n +-+ +-+ +---+    \|- b log(c (e x + d) ) + a
+--R       (- e x - d)%e   \|b \|n \|%pi erf(----------------------------)
+--R                                                    +-+ +-+
+--R                                                   \|b \|n
+--R     + 
+--R                                1
+--R                                - +-------------------------+
+--R                              n n |                   n
+--R       (2e x + 2d)(c (e x + d) ) \|- b log(c (e x + d) ) + a
+--R  /
+--R                      1
+--R                      -
+--R                    n n
+--R     2e (c (e x + d) )
+--R                                                    Type: Expression(Integer)
+--E 4059
+
+-- integrate: implementation incomplete (constant residues)
+--S 4060 of 5341
+--a0:=integrate(t0,x)
+--E 4060
+
+--S 4061 of 5341
+--m0:=a0-r0
+--E 4061
+
+--S 4062 of 5341
+--d0:=D(m0,x)
+--E 4062
+
+)clear all
+
+--S 4063 of 5341
+t0:=1/(a-b*log(c*(d+e*x)^n))^(1/2)
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R         +-------------------------+
+--R         |                   n
+--R        \|- b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4063
+
+--S 4064 of 5341
+r0:=-%e^(a/(b*n))*(d+e*x)*erf(sqrt(a-b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*_
+   sqrt(%pi)/(e*(c*(d+e*x)^n)^(1/n)*sqrt(b)*sqrt(n))
+--R 
+--R
+--R                      a            +-------------------------+
+--R                     ---           |                   n
+--R                     b n +---+    \|- b log(c (e x + d) ) + a
+--R        (- e x - d)%e   \|%pi erf(----------------------------)
+--R                                             +-+ +-+
+--R                                            \|b \|n
+--R   (2)  -------------------------------------------------------
+--R                                               1
+--R                                               -
+--R                          +-+ +-+            n n
+--R                        e\|b \|n (c (e x + d) )
+--R                                                    Type: Expression(Integer)
+--E 4064
+
+-- integrate: implementation incomplete (constant residues)
+--S 4065 of 5341
+--a0:=integrate(t0,x)
+--E 4065
+
+--S 4066 of 5341
+--m0:=a0-r0
+--E 4066
+
+--S 4067 of 5341
+--d0:=D(m0,x)
+--E 4067
+
+)clear all
+
+--S 4068 of 5341
+t0:=1/(a-b*log(c*(d+e*x)^n))^(3/2)
+--R 
+--R
+--R                                    1
+--R   (1)  - -----------------------------------------------------
+--R                                    +-------------------------+
+--R                            n       |                   n
+--R          (b log(c (e x + d) ) - a)\|- b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4068
+
+--S 4069 of 5341
+r0:=2*%e^(a/(b*n))*(d+e*x)*erf(sqrt(a-b*log(c*(d+e*x)^n))/(sqrt(b)*_
+   sqrt(n)))*sqrt(%pi)/(b^(3/2)*e*n^(3/2)*(c*(d+e*x)^n)^(1/n))+_
+   2*(d+e*x)/(b*e*n*sqrt(a-b*log(c*(d+e*x)^n)))
+--R 
+--R
+--R   (2)
+--R                       a
+--R                      ---       +-------------------------+
+--R                      b n +---+ |                   n
+--R         (2e x + 2d)%e   \|%pi \|- b log(c (e x + d) ) + a
+--R      *
+--R              +-------------------------+
+--R              |                   n
+--R             \|- b log(c (e x + d) ) + a
+--R         erf(----------------------------)
+--R                        +-+ +-+
+--R                       \|b \|n
+--R     + 
+--R                                        1
+--R                                        -
+--R                   +-+ +-+            n n
+--R       (2e x + 2d)\|b \|n (c (e x + d) )
+--R  /
+--R                                1
+--R                                - +-------------------------+
+--R           +-+ +-+            n n |                   n
+--R     b e n\|b \|n (c (e x + d) ) \|- b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4069
+
+-- integrate: implementation incomplete (constant residues)
+--S 4070 of 5341
+--a0:=integrate(t0,x)
+--E 4070
+
+--S 4071 of 5341
+--m0:=a0-r0
+--E 4071
+
+--S 4072 of 5341
+--d0:=D(m0,x)
+--E 4072
+
+)clear all
+
+--S 4073 of 5341
+t0:=1/(a-b*log(c*(d+e*x)^n))^(5/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R         2               n 2                       n     2
+--R       (b log(c (e x + d) )  - 2a b log(c (e x + d) ) + a )
+--R    *
+--R        +-------------------------+
+--R        |                   n
+--R       \|- b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4073
+
+--S 4074 of 5341
+r0:=2/3*(d+e*x)/(b*e*n*(a-b*log(c*(d+e*x)^n))^(3/2))-4/3*%e^(a/(b*n))*_
+   (d+e*x)*erf(sqrt(a-b*log(c*(d+e*x)^n))/(sqrt(b)*sqrt(n)))*sqrt(%pi)/_
+   (b^(5/2)*e*n^(5/2)*(c*(d+e*x)^n)^(1/n))-4/3*(d+e*x)/(b^2*e*n^2*_
+   sqrt(a-b*log(c*(d+e*x)^n)))
+--R 
+--R
+--R   (2)
+--R                               a
+--R                              ---
+--R                              b n +---+               n
+--R           (- 4b e x - 4b d)%e   \|%pi log(c (e x + d) )
+--R         + 
+--R                             a
+--R                            ---
+--R                            b n +---+
+--R           (4a e x + 4a d)%e   \|%pi
+--R      *
+--R                                          +-------------------------+
+--R          +-------------------------+     |                   n
+--R          |                   n          \|- b log(c (e x + d) ) + a
+--R         \|- b log(c (e x + d) ) + a erf(----------------------------)
+--R                                                    +-+ +-+
+--R                                                   \|b \|n
+--R     + 
+--R                             +-+ +-+               n
+--R           (- 4b e x - 4b d)\|b \|n log(c (e x + d) )
+--R         + 
+--R                                                +-+ +-+
+--R           ((- 2b e n + 4a e)x - 2b d n + 4a d)\|b \|n
+--R      *
+--R                       1
+--R                       -
+--R                     n n
+--R         (c (e x + d) )
+--R  /
+--R                                                                           1
+--R                                                                           -
+--R          3   2 +-+ +-+               n        2   2 +-+ +-+             n n
+--R       (3b e n \|b \|n log(c (e x + d) ) - 3a b e n \|b \|n )(c (e x + d) )
+--R    *
+--R        +-------------------------+
+--R        |                   n
+--R       \|- b log(c (e x + d) ) + a
+--R                                                    Type: Expression(Integer)
+--E 4074
+
+-- integrate: implementation incomplete (constant residues)
+--S 4075 of 5341
+--a0:=integrate(t0,x)
+--E 4075
+
+--S 4076 of 5341
+--m0:=a0-r0
+--E 4076
+
+--S 4077 of 5341
+--d0:=D(m0,x)
+--E 4077
+
+)clear all
+
+--S 4078 of 5341
+t0:=(a+b*log(c*(d+e*x)^n))^p
+--R 
+--R
+--R                          n      p
+--R   (1)  (b log(c (e x + d) ) + a)
+--R                                                    Type: Expression(Integer)
+--E 4078
+
+--S 4079 of 5341
+--r0:=(d+e*x)*GAMMA(1+p,(-a-b*log(c*(d+e*x)^n))/(b*n))*(a+b*log(c*_
+--  (d+e*x)^n))^p/(%e^(a/(b*n))*e*(c*(d+e*x)^n)^(1/n)*((-a-b*log(c*_
+--  (d+e*x)^n))/(b*n))^p)
+--E 4079
+
+--S 4080 of 5341
+--a0:=integrate(t0,x)
+--E 4080
+
+--S 4081 of 5341
+--m0:=a0-r0
+--E 4081
+
+--S 4082 of 5341
+--d0:=D(m0,x)
+--E 4082
+
+)clear all
+
+--S 4083 of 5341
+t0:=x^m*log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R         m          2       n
+--R   (1)  x log(d (c x  + b x) )
+--R                                                    Type: Expression(Integer)
+--E 4083
+
+--S 4084 of 5341
+--r0:=-2*n*x^(1+m)/(1+m)^2+n*x^(1+m)*hypergeometric(1,1+m,2+m,-c*x/b)/_
+--  (1+m)^2+x^(1+m)*log(d*(b*x+c*x^2)^n)/(1+m)
+--E 4084
+
+--S 4085 of 5341
+--a0:=integrate(t0,x)
+--E 4085
+
+--S 4086 of 5341
+--m0:=a0-r0
+--E 4086
+
+--S 4087 of 5341
+--d0:=D(m0,x)
+--E 4087
+
+)clear all
+
+--S 4088 of 5341
+t0:=x^4*log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R         4          2       n
+--R   (1)  x log(d (c x  + b x) )
+--R                                                    Type: Expression(Integer)
+--E 4088
+
+--S 4089 of 5341
+r0:=-1/5*b^4*n*x/c^4+1/10*b^3*n*x^2/c^3-1/15*b^2*n*x^3/c^2+1/20*b*n*x^4/c-_
+   2/25*n*x^5+1/5*b^5*n*log(b+c*x)/c^5+1/5*x^5*log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R   (2)
+--R          5 5          2       n       5                    5   5        4   4
+--R       60c x log(d (c x  + b x) ) + 60b n log(c x + b) - 24c n x  + 15b c n x
+--R     + 
+--R            2 3   3      3 2   2      4
+--R       - 20b c n x  + 30b c n x  - 60b c n x
+--R  /
+--R         5
+--R     300c
+--R                                                    Type: Expression(Integer)
+--E 4089
+
+--S 4090 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          5   5       2             5                    5 5            5   5
+--R       60c n x log(c x  + b x) + 60b n log(c x + b) + 60c x log(d) - 24c n x
+--R     + 
+--R            4   4      2 3   3      3 2   2      4
+--R       15b c n x  - 20b c n x  + 30b c n x  - 60b c n x
+--R  /
+--R         5
+--R     300c
+--R                                         Type: Union(Expression(Integer),...)
+--E 4090
+
+--S 4091 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           5          2       n       5       2           5
+--R        - x log(d (c x  + b x) ) + n x log(c x  + b x) + x log(d)
+--R   (4)  ---------------------------------------------------------
+--R                                    5
+--R                                                    Type: Expression(Integer)
+--E 4091
+
+--S 4092 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4092
+
+)clear all
+
+--S 4093 of 5341
+t0:=x^3*log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R         3          2       n
+--R   (1)  x log(d (c x  + b x) )
+--R                                                    Type: Expression(Integer)
+--E 4093
+
+--S 4094 of 5341
+r0:=1/4*b^3*n*x/c^3-1/8*b^2*n*x^2/c^2+1/12*b*n*x^3/c-1/8*n*x^4-_
+   1/4*b^4*n*log(b+c*x)/c^4+1/4*x^4*log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R   (2)
+--R         4 4          2       n      4                   4   4       3   3
+--R       6c x log(d (c x  + b x) ) - 6b n log(c x + b) - 3c n x  + 2b c n x
+--R     + 
+--R           2 2   2     3
+--R       - 3b c n x  + 6b c n x
+--R  /
+--R        4
+--R     24c
+--R                                                    Type: Expression(Integer)
+--E 4094
+
+--S 4095 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         4   4       2            4                   4 4           4   4
+--R       6c n x log(c x  + b x) - 6b n log(c x + b) + 6c x log(d) - 3c n x
+--R     + 
+--R           3   3     2 2   2     3
+--R       2b c n x  - 3b c n x  + 6b c n x
+--R  /
+--R        4
+--R     24c
+--R                                         Type: Union(Expression(Integer),...)
+--E 4095
+
+--S 4096 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           4          2       n       4       2           4
+--R        - x log(d (c x  + b x) ) + n x log(c x  + b x) + x log(d)
+--R   (4)  ---------------------------------------------------------
+--R                                    4
+--R                                                    Type: Expression(Integer)
+--E 4096
+
+--S 4097 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4097
+
+)clear all
+
+--S 4098 of 5341
+t0:=x^2*log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R         2          2       n
+--R   (1)  x log(d (c x  + b x) )
+--R                                                    Type: Expression(Integer)
+--E 4098
+
+--S 4099 of 5341
+r0:=-1/3*b^2*n*x/c^2+1/6*b*n*x^2/c-2/9*n*x^3+1/3*b^3*n*log(b+c*x)/c^3+_
+   1/3*x^3*log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R   (2)
+--R         3 3          2       n      3                   3   3       2   2
+--R       6c x log(d (c x  + b x) ) + 6b n log(c x + b) - 4c n x  + 3b c n x
+--R     + 
+--R           2
+--R       - 6b c n x
+--R  /
+--R        3
+--R     18c
+--R                                                    Type: Expression(Integer)
+--E 4099
+
+--S 4100 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R         3   3       2            3                   3 3           3   3
+--R       6c n x log(c x  + b x) + 6b n log(c x + b) + 6c x log(d) - 4c n x
+--R     + 
+--R           2   2     2
+--R       3b c n x  - 6b c n x
+--R  /
+--R        3
+--R     18c
+--R                                         Type: Union(Expression(Integer),...)
+--E 4100
+
+--S 4101 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           3          2       n       3       2           3
+--R        - x log(d (c x  + b x) ) + n x log(c x  + b x) + x log(d)
+--R   (4)  ---------------------------------------------------------
+--R                                    3
+--R                                                    Type: Expression(Integer)
+--E 4101
+
+--S 4102 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4102
+
+)clear all
+
+--S 4103 of 5341
+t0:=x*log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R                    2       n
+--R   (1)  x log(d (c x  + b x) )
+--R                                                    Type: Expression(Integer)
+--E 4103
+
+--S 4104 of 5341
+r0:=1/2*b*n*x/c-1/2*n*x^2-1/2*b^2*n*log(b+c*x)/c^2+1/2*x^2*log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R         2 2          2       n     2                  2   2
+--R        c x log(d (c x  + b x) ) - b n log(c x + b) - c n x  + b c n x
+--R   (2)  --------------------------------------------------------------
+--R                                        2
+--R                                      2c
+--R                                                    Type: Expression(Integer)
+--E 4104
+
+--S 4105 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R    2   2       2           2                  2 2          2   2
+--R   c n x log(c x  + b x) - b n log(c x + b) + c x log(d) - c n x  + b c n x
+--R   ------------------------------------------------------------------------
+--R                                        2
+--R                                      2c
+--R                                         Type: Union(Expression(Integer),...)
+--E 4105
+
+--S 4106 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           2          2       n       2       2           2
+--R        - x log(d (c x  + b x) ) + n x log(c x  + b x) + x log(d)
+--R   (4)  ---------------------------------------------------------
+--R                                    2
+--R                                                    Type: Expression(Integer)
+--E 4106
+
+--S 4107 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4107
+
+)clear all
+
+--S 4108 of 5341
+t0:=log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R                  2       n
+--R   (1)  log(d (c x  + b x) )
+--R                                                    Type: Expression(Integer)
+--E 4108
+
+--S 4109 of 5341
+r0:=-2*n*x+b*n*log(b+c*x)/c+x*log(d*(b*x+c*x^2)^n)
+--R 
+--R
+--R                      2       n
+--R        c x log(d (c x  + b x) ) + b n log(c x + b) - 2c n x
+--R   (2)  ----------------------------------------------------
+--R                                  c
+--R                                                    Type: Expression(Integer)
+--E 4109
+
+--S 4110 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     2
+--R        c n x log(c x  + b x) + b n log(c x + b) + c x log(d) - 2c n x
+--R   (3)  --------------------------------------------------------------
+--R                                       c
+--R                                         Type: Union(Expression(Integer),...)
+--E 4110
+
+--S 4111 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                      2       n               2
+--R   (4)  - x log(d (c x  + b x) ) + n x log(c x  + b x) + x log(d)
+--R                                                    Type: Expression(Integer)
+--E 4111
+
+--S 4112 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4112
+
+)clear all
+
+--S 4113 of 5341
+t0:=log(d*(b*x+c*x^2)^n)/x
+--R 
+--R
+--R                  2       n
+--R        log(d (c x  + b x) )
+--R   (1)  --------------------
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 4113
+
+--S 4114 of 5341
+--r0:=-1/2*n*log(x)^2-n*log(x)*log((b+c*x)/b)+log(x)*log(d*(b*x+c*x^2)^n)-_
+--  n*polylog(2,-c*x/b)
+--E 4114
+
+--S 4115 of 5341
+--a0:=integrate(t0,x)
+--E 4115
+
+--S 4116 of 5341
+--m0:=a0-r0
+--E 4116
+
+--S 4117 of 5341
+--d0:=D(m0,x)
+--E 4117
+
+)clear all
+
+--S 4118 of 5341
+t0:=log(d*(b*x+c*x^2)^n)/x^2
+--R 
+--R
+--R                  2       n
+--R        log(d (c x  + b x) )
+--R   (1)  --------------------
+--R                  2
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 4118
+
+--S 4119 of 5341
+r0:=-n/x+c*n*log(x)/b-c*n*log(b+c*x)/b-log(d*(b*x+c*x^2)^n)/x
+--R 
+--R
+--R                      2       n
+--R        - b log(d (c x  + b x) ) - c n x log(c x + b) + c n x log(x) - b n
+--R   (2)  ------------------------------------------------------------------
+--R                                        b x
+--R                                                    Type: Expression(Integer)
+--E 4119
+
+--S 4120 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                2
+--R   - b n log(c x  + b x) - c n x log(c x + b) + c n x log(x) - b log(d) - b n
+--R   --------------------------------------------------------------------------
+--R                                       b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4120
+
+--S 4121 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  2       n             2
+--R        log(d (c x  + b x) ) - n log(c x  + b x) - log(d)
+--R   (4)  -------------------------------------------------
+--R                                x
+--R                                                    Type: Expression(Integer)
+--E 4121
+
+--S 4122 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4122
+
+)clear all
+
+--S 4123 of 5341
+t0:=log(d*(b*x+c*x^2)^n)/x^3
+--R 
+--R
+--R                  2       n
+--R        log(d (c x  + b x) )
+--R   (1)  --------------------
+--R                  3
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 4123
+
+--S 4124 of 5341
+r0:=-1/4*n/x^2-1/2*c*n/(b*x)-1/2*c^2*n*log(x)/b^2+1/2*c^2*n*log(b+c*x)/b^2-_
+   1/2*log(d*(b*x+c*x^2)^n)/x^2
+--R 
+--R
+--R   (2)
+--R           2          2       n      2   2                 2   2
+--R       - 2b log(d (c x  + b x) ) + 2c n x log(c x + b) - 2c n x log(x)
+--R     + 
+--R                     2
+--R       - 2b c n x - b n
+--R  /
+--R       2 2
+--R     4b x
+--R                                                    Type: Expression(Integer)
+--E 4124
+
+--S 4125 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           2         2            2   2                 2   2           2
+--R       - 2b n log(c x  + b x) + 2c n x log(c x + b) - 2c n x log(x) - 2b log(d)
+--R     + 
+--R                     2
+--R       - 2b c n x - b n
+--R  /
+--R       2 2
+--R     4b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4125
+
+--S 4126 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  2       n             2
+--R        log(d (c x  + b x) ) - n log(c x  + b x) - log(d)
+--R   (4)  -------------------------------------------------
+--R                                 2
+--R                               2x
+--R                                                    Type: Expression(Integer)
+--E 4126
+
+--S 4127 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4127
+
+)clear all
+
+--S 4128 of 5341
+t0:=log(d*(b*x+c*x^2)^n)/x^4
+--R 
+--R
+--R                  2       n
+--R        log(d (c x  + b x) )
+--R   (1)  --------------------
+--R                  4
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 4128
+
+--S 4129 of 5341
+r0:=-1/9*n/x^3-1/6*c*n/(b*x^2)+1/3*c^2*n/(b^2*x)+1/3*c^3*n*log(x)/b^3-_
+   1/3*c^3*n*log(b+c*x)/b^3-1/3*log(d*(b*x+c*x^2)^n)/x^3
+--R 
+--R
+--R   (2)
+--R           3          2       n      3   3                 3   3
+--R       - 6b log(d (c x  + b x) ) - 6c n x log(c x + b) + 6c n x log(x)
+--R     + 
+--R           2   2     2          3
+--R       6b c n x  - 3b c n x - 2b n
+--R  /
+--R        3 3
+--R     18b x
+--R                                                    Type: Expression(Integer)
+--E 4129
+
+--S 4130 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R           3         2            3   3                 3   3           3
+--R       - 6b n log(c x  + b x) - 6c n x log(c x + b) + 6c n x log(x) - 6b log(d)
+--R     + 
+--R           2   2     2          3
+--R       6b c n x  - 3b c n x - 2b n
+--R  /
+--R        3 3
+--R     18b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4130
+
+--S 4131 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  2       n             2
+--R        log(d (c x  + b x) ) - n log(c x  + b x) - log(d)
+--R   (4)  -------------------------------------------------
+--R                                 3
+--R                               3x
+--R                                                    Type: Expression(Integer)
+--E 4131
+
+--S 4132 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4132
+
+)clear all
+
+--S 4133 of 5341
+t0:=log(d*(b*x+c*x^2)^n)/x^5
+--R 
+--R
+--R                  2       n
+--R        log(d (c x  + b x) )
+--R   (1)  --------------------
+--R                  5
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 4133
+
+--S 4134 of 5341
+r0:=-1/16*n/x^4-1/12*c*n/(b*x^3)+1/8*c^2*n/(b^2*x^2)-1/4*c^3*n/(b^3*x)-_
+   1/4*c^4*n*log(x)/b^4+1/4*c^4*n*log(b+c*x)/b^4-1/4*log(d*(b*x+c*x^2)^n)/x^4
+--R 
+--R
+--R   (2)
+--R            4          2       n       4   4                  4   4
+--R       - 12b log(d (c x  + b x) ) + 12c n x log(c x + b) - 12c n x log(x)
+--R     + 
+--R              3   3     2 2   2     3          4
+--R       - 12b c n x  + 6b c n x  - 4b c n x - 3b n
+--R  /
+--R        4 4
+--R     48b x
+--R                                                    Type: Expression(Integer)
+--E 4134
+
+--S 4135 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            4         2             4   4                  4   4
+--R       - 12b n log(c x  + b x) + 12c n x log(c x + b) - 12c n x log(x)
+--R     + 
+--R            4              3   3     2 2   2     3          4
+--R       - 12b log(d) - 12b c n x  + 6b c n x  - 4b c n x - 3b n
+--R  /
+--R        4 4
+--R     48b x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4135
+
+--S 4136 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  2       n             2
+--R        log(d (c x  + b x) ) - n log(c x  + b x) - log(d)
+--R   (4)  -------------------------------------------------
+--R                                 4
+--R                               4x
+--R                                                    Type: Expression(Integer)
+--E 4136
+
+--S 4137 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4137
+
+)clear all
+
+--S 4138 of 5341
+t0:=log(d*(b*x+c*x^2)^n)^2
+--R 
+--R
+--R                  2       n 2
+--R   (1)  log(d (c x  + b x) )
+--R                                                    Type: Expression(Integer)
+--E 4138
+
+--S 4139 of 5341
+--r0:=8*n^2*x-4*b*n^2*log(b+c*x)/c-2*b*n^2*log(-c*x/b)*log(b+c*x)/c-_
+--  b*n^2*log(b+c*x)^2/c-4*n*x*log(d*(b*x+c*x^2)^n)+2*b*n*log(b+c*x)*_
+--  log(d*(b*x+c*x^2)^n)/c+x*log(d*(b*x+c*x^2)^n)^2-2*b*n^2*polylog(2,_
+--  (b+c*x)/b)/c,8*n^2*x-4*b*n^2*log(-c*x/b)*log(-b-c*x)/c-2*b*n^2*_
+--  log(-b-c*x)^2/c-4*b*n^2*log(b+c*x)/c+2*b*n^2*log(-c*x/b)*log(b+c*x)/c+_
+--  b*n^2*log(b+c*x)^2/c-4*n*x*log(d*(b*x+c*x^2)^n)+4*b*n*log(-b-c*x)*_
+--  log(d*(b*x+c*x^2)^n)/c-2*b*n*log(b+c*x)*log(d*(b*x+c*x^2)^n)/c+_
+--  x*log(d*(b*x+c*x^2)^n)^2-2*b*n^2*polylog(2,(b+c*x)/b)/c
+--E 4139
+
+--S 4140 of 5341
+--a0:=integrate(t0,x)
+--E 4140
+
+--S 4141 of 5341
+--m0:=a0-r0
+--E 4141
+
+--S 4142 of 5341
+--d0:=D(m0,x)
+--E 4142
+
+)clear all
+
+--S 4143 of 5341
+t0:=x^m*log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R         m          2           n
+--R   (1)  x log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4143
+
+--S 4144 of 5341
+--r0:=-2*n*x^(1+m)/(1+m)^2+n*x^(1+m)*hypergeometric(1,1+m,2+m,-2*c*x/_
+--  (b-sqrt(b^2-4*a*c)))/(1+m)^2+n*x^(1+m)*hypergeometric(1,1+m,2+m,_
+--  -2*c*x/(b+sqrt(b^2-4*a*c)))/(1+m)^2+x^(1+m)*log(d*(a+b*x+c*x^2)^n)/(1+m)
+--E 4144
+
+--S 4145 of 5341
+--a0:=integrate(t0,x)
+--E 4145
+
+--S 4146 of 5341
+--m0:=a0-r0
+--E 4146
+
+--S 4147 of 5341
+--d0:=D(m0,x)
+--E 4147
+
+)clear all
+
+--S 4148 of 5341
+t0:=x^4*log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R         4          2           n
+--R   (1)  x log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4148
+
+--S 4149 of 5341
+r0:=-1/5*(b^4-4*a*b^2*c+2*a^2*c^2)*n*x/c^4+1/10*b*(b^2-3*a*c)*n*x^2/c^3-_
+   1/15*(b^2-2*a*c)*n*x^3/c^2+1/20*b*n*x^4/c-2/25*n*x^5+1/10*b*(b^4-_
+   5*a*b^2*c+5*a^2*c^2)*n*log(a+b*x+c*x^2)/c^5+1/5*x^5*log(d*(a+b*x+_
+   c*x^2)^n)+1/5*(b^4-3*a*b^2*c+a^2*c^2)*n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*_
+   sqrt(b^2-4*a*c)/c^5
+--R 
+--R
+--R   (2)
+--R          5 5          2           n
+--R       60c x log(d (c x  + b x + a) )
+--R     + 
+--R                                   +-----------+
+--R           2 2         2       4   |          2          2c x + b
+--R       (60a c  - 180a b c + 60b )n\|- 4a c + b  atanh(--------------)
+--R                                                       +-----------+
+--R                                                       |          2
+--R                                                      \|- 4a c + b
+--R     + 
+--R            2   2         3       5          2                 5   5
+--R       (150a b c  - 150a b c + 30b )n log(c x  + b x + a) - 24c n x
+--R     + 
+--R            4   4         4      2 3    3             3      3 2    2
+--R       15b c n x  + (40a c  - 20b c )n x  + (- 90a b c  + 30b c )n x
+--R     + 
+--R              2 3         2 2      4
+--R       (- 120a c  + 240a b c  - 60b c)n x
+--R  /
+--R         5
+--R     300c
+--R                                                    Type: Expression(Integer)
+--E 4149
+
+--S 4150 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                      +-----------+
+--R               2 2        2       4   |          2
+--R           (30a c  - 90a b c + 30b )n\|- 4a c + b
+--R        *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R               (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-----------------------------------------------------)
+--R                                      2
+--R                                   c x  + b x + a
+--R       + 
+--R             5   5        2   2         3       5          2
+--R         (60c n x  + (150a b c  - 150a b c + 30b )n)log(c x  + b x + a)
+--R       + 
+--R            5 5            5   5        4   4         4      2 3    3
+--R         60c x log(d) - 24c n x  + 15b c n x  + (40a c  - 20b c )n x
+--R       + 
+--R                   3      3 2    2          2 3         2 2      4
+--R         (- 90a b c  + 30b c )n x  + (- 120a c  + 240a b c  - 60b c)n x
+--R    /
+--R           5
+--R       300c
+--R     ,
+--R
+--R                                                        +---------+
+--R                                       +---------+      |        2
+--R               2 2         2       4   |        2      \|4a c - b
+--R         (- 60a c  + 180a b c - 60b )n\|4a c - b  atan(------------)
+--R                                                         2c x + b
+--R       + 
+--R             5   5        2   2         3       5          2
+--R         (60c n x  + (150a b c  - 150a b c + 30b )n)log(c x  + b x + a)
+--R       + 
+--R            5 5            5   5        4   4         4      2 3    3
+--R         60c x log(d) - 24c n x  + 15b c n x  + (40a c  - 20b c )n x
+--R       + 
+--R                   3      3 2    2          2 3         2 2      4
+--R         (- 90a b c  + 30b c )n x  + (- 120a c  + 240a b c  - 60b c)n x
+--R    /
+--R           5
+--R       300c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4150
+
+--S 4151 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                               +-----------+
+--R           2 2       2     4   |          2
+--R         (a c  - 3a b c + b )n\|- 4a c + b
+--R      *
+--R                        +-----------+
+--R                        |          2      2 2                    2
+--R             (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-----------------------------------------------------)
+--R                                    2
+--R                                 c x  + b x + a
+--R     + 
+--R           5 5          2           n
+--R       - 2c x log(d (c x  + b x + a) )
+--R     + 
+--R                                 +-----------+
+--R            2 2       2      4   |          2          2c x + b
+--R       (- 2a c  + 6a b c - 2b )n\|- 4a c + b  atanh(--------------)
+--R                                                     +-----------+
+--R                                                     |          2
+--R                                                    \|- 4a c + b
+--R     + 
+--R         5   5       2                5 5
+--R       2c n x log(c x  + b x + a) + 2c x log(d)
+--R  /
+--R        5
+--R     10c
+--R                                                    Type: Expression(Integer)
+--E 4151
+
+--S 4152 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4152
+
+--S 4153 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          5 5          2           n
+--R       - c x log(d (c x  + b x + a) )
+--R     + 
+--R                               +-----------+
+--R           2 2       2     4   |          2          2c x + b
+--R       (- a c  + 3a b c - b )n\|- 4a c + b  atanh(--------------)
+--R                                                   +-----------+
+--R                                                   |          2
+--R                                                  \|- 4a c + b
+--R     + 
+--R                                                +---------+
+--R                               +---------+      |        2
+--R           2 2       2     4   |        2      \|4a c - b
+--R       (- a c  + 3a b c - b )n\|4a c - b  atan(------------)
+--R                                                 2c x + b
+--R     + 
+--R        5   5       2               5 5
+--R       c n x log(c x  + b x + a) + c x log(d)
+--R  /
+--R       5
+--R     5c
+--R                                                    Type: Expression(Integer)
+--E 4153
+
+--S 4154 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4154
+
+)clear all
+
+--S 4155 of 5341
+t0:=x^3*log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R         3          2           n
+--R   (1)  x log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4155
+
+--S 4156 of 5341
+r0:=1/4*b*(b^2-3*a*c)*n*x/c^3-1/8*(b^2-2*a*c)*n*x^2/c^2+1/12*b*n*x^3/c-_
+   1/8*n*x^4-1/8*(b^4-4*a*b^2*c+2*a^2*c^2)*n*log(a+b*x+c*x^2)/c^4+1/4*x^4*_
+   log(d*(a+b*x+c*x^2)^n)-1/4*b*(b^2-2*a*c)*n*atanh((b+2*c*x)/sqrt(b^2-_
+   4*a*c))*sqrt(b^2-4*a*c)/c^4
+--R 
+--R
+--R   (2)
+--R         4 4          2           n
+--R       6c x log(d (c x  + b x + a) )
+--R     + 
+--R                        +-----------+
+--R                    3   |          2          2c x + b
+--R       (12a b c - 6b )n\|- 4a c + b  atanh(--------------)
+--R                                            +-----------+
+--R                                            |          2
+--R                                           \|- 4a c + b
+--R     + 
+--R            2 2        2      4          2                4   4       3   3
+--R       (- 6a c  + 12a b c - 3b )n log(c x  + b x + a) - 3c n x  + 2b c n x
+--R     + 
+--R            3     2 2    2             2     3
+--R       (6a c  - 3b c )n x  + (- 18a b c  + 6b c)n x
+--R  /
+--R        4
+--R     24c
+--R                                                    Type: Expression(Integer)
+--E 4156
+
+--S 4157 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                           +-----------+
+--R                       3   |          2
+--R           (6a b c - 3b )n\|- 4a c + b
+--R        *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R               (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-----------------------------------------------------)
+--R                                      2
+--R                                   c x  + b x + a
+--R       + 
+--R            4   4        2 2        2      4          2                4 4
+--R         (6c n x  + (- 6a c  + 12a b c - 3b )n)log(c x  + b x + a) + 6c x log(d)
+--R       + 
+--R             4   4       3   3        3     2 2    2             2     3
+--R         - 3c n x  + 2b c n x  + (6a c  - 3b c )n x  + (- 18a b c  + 6b c)n x
+--R    /
+--R          4
+--R       24c
+--R     ,
+--R
+--R                                             +---------+
+--R                            +---------+      |        2
+--R                        3   |        2      \|4a c - b
+--R         (- 12a b c + 6b )n\|4a c - b  atan(------------)
+--R                                              2c x + b
+--R       + 
+--R            4   4        2 2        2      4          2                4 4
+--R         (6c n x  + (- 6a c  + 12a b c - 3b )n)log(c x  + b x + a) + 6c x log(d)
+--R       + 
+--R             4   4       3   3        3     2 2    2             2     3
+--R         - 3c n x  + 2b c n x  + (6a c  - 3b c )n x  + (- 18a b c  + 6b c)n x
+--R    /
+--R          4
+--R       24c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4157
+
+--S 4158 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        +-----------+
+--R                    3   |          2
+--R         (2a b c - b )n\|- 4a c + b
+--R      *
+--R                        +-----------+
+--R                        |          2      2 2                    2
+--R             (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-----------------------------------------------------)
+--R                                    2
+--R                                 c x  + b x + a
+--R     + 
+--R           4 4          2           n
+--R       - 2c x log(d (c x  + b x + a) )
+--R     + 
+--R                         +-----------+
+--R                     3   |          2          2c x + b
+--R       (- 4a b c + 2b )n\|- 4a c + b  atanh(--------------)
+--R                                             +-----------+
+--R                                             |          2
+--R                                            \|- 4a c + b
+--R     + 
+--R         4   4       2                4 4
+--R       2c n x log(c x  + b x + a) + 2c x log(d)
+--R  /
+--R       4
+--R     8c
+--R                                                    Type: Expression(Integer)
+--E 4158
+
+--S 4159 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4159
+
+--S 4160 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          4 4          2           n
+--R       - c x log(d (c x  + b x + a) )
+--R     + 
+--R                        +-----------+
+--R                    3   |          2          2c x + b
+--R       (- 2a b c + b )n\|- 4a c + b  atanh(--------------)
+--R                                            +-----------+
+--R                                            |          2
+--R                                           \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R                        +---------+      |        2
+--R                    3   |        2      \|4a c - b
+--R       (- 2a b c + b )n\|4a c - b  atan(------------)
+--R                                          2c x + b
+--R     + 
+--R        4   4       2               4 4
+--R       c n x log(c x  + b x + a) + c x log(d)
+--R  /
+--R       4
+--R     4c
+--R                                                    Type: Expression(Integer)
+--E 4160
+
+--S 4161 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4161
+
+)clear all
+
+--S 4162 of 5341
+t0:=x^2*log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R         2          2           n
+--R   (1)  x log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4162
+
+--S 4163 of 5341
+r0:=-1/3*(b^2-2*a*c)*n*x/c^2+1/6*b*n*x^2/c-2/9*n*x^3+1/6*b*(b^2-3*a*c)*n*_
+   log(a+b*x+c*x^2)/c^3+1/3*x^3*log(d*(a+b*x+c*x^2)^n)+1/3*(b^2-a*c)*n*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/c^3
+--R 
+--R
+--R   (2)
+--R         3 3          2           n
+--R       6c x log(d (c x  + b x + a) )
+--R     + 
+--R                       +-----------+
+--R                   2   |          2          2c x + b
+--R       (- 6a c + 6b )n\|- 4a c + b  atanh(--------------)
+--R                                           +-----------+
+--R                                           |          2
+--R                                          \|- 4a c + b
+--R     + 
+--R                     3          2                3   3       2   2
+--R       (- 9a b c + 3b )n log(c x  + b x + a) - 4c n x  + 3b c n x
+--R     + 
+--R             2     2
+--R       (12a c  - 6b c)n x
+--R  /
+--R        3
+--R     18c
+--R                                                    Type: Expression(Integer)
+--E 4163
+
+--S 4164 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         +-----------+
+--R                     2   |          2
+--R           (3a c - 3b )n\|- 4a c + b
+--R        *
+--R                            +-----------+
+--R                            |          2      2 2                    2
+--R               (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-------------------------------------------------------)
+--R                                       2
+--R                                    c x  + b x + a
+--R       + 
+--R            3   3                 3          2                3 3
+--R         (6c n x  + (- 9a b c + 3b )n)log(c x  + b x + a) + 6c x log(d)
+--R       + 
+--R             3   3       2   2         2     2
+--R         - 4c n x  + 3b c n x  + (12a c  - 6b c)n x
+--R    /
+--R          3
+--R       18c
+--R     ,
+--R
+--R                                        +---------+
+--R                       +---------+      |        2
+--R                   2   |        2      \|4a c - b
+--R         (6a c - 6b )n\|4a c - b  atan(------------)
+--R                                         2c x + b
+--R       + 
+--R            3   3                 3          2                3 3
+--R         (6c n x  + (- 9a b c + 3b )n)log(c x  + b x + a) + 6c x log(d)
+--R       + 
+--R             3   3       2   2         2     2
+--R         - 4c n x  + 3b c n x  + (12a c  - 6b c)n x
+--R    /
+--R          3
+--R       18c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4164
+
+--S 4165 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           3 3          2           n
+--R       - 2c x log(d (c x  + b x + a) )
+--R     + 
+--R                     +-----------+
+--R                 2   |          2
+--R         (a c - b )n\|- 4a c + b
+--R      *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R             (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-------------------------------------------------------)
+--R                                     2
+--R                                  c x  + b x + a
+--R     + 
+--R                     +-----------+
+--R                 2   |          2          2c x + b
+--R       (2a c - 2b )n\|- 4a c + b  atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R         3   3       2                3 3
+--R       2c n x log(c x  + b x + a) + 2c x log(d)
+--R  /
+--R       3
+--R     6c
+--R                                                    Type: Expression(Integer)
+--E 4165
+
+--S 4166 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4166
+
+--S 4167 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R          3 3          2           n
+--R       - c x log(d (c x  + b x + a) )
+--R     + 
+--R                   +-----------+
+--R               2   |          2          2c x + b
+--R       (a c - b )n\|- 4a c + b  atanh(--------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                      \|- 4a c + b
+--R     + 
+--R                                    +---------+
+--R                   +---------+      |        2
+--R               2   |        2      \|4a c - b       3   3       2
+--R       (a c - b )n\|4a c - b  atan(------------) + c n x log(c x  + b x + a)
+--R                                     2c x + b
+--R     + 
+--R        3 3
+--R       c x log(d)
+--R  /
+--R       3
+--R     3c
+--R                                                    Type: Expression(Integer)
+--E 4167
+
+--S 4168 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4168
+
+)clear all
+
+--S 4169 of 5341
+t0:=x*log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R                    2           n
+--R   (1)  x log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4169
+
+--S 4170 of 5341
+r0:=1/2*b*n*x/c-1/2*n*x^2-1/4*(b^2-2*a*c)*n*log(a+b*x+c*x^2)/c^2+1/2*x^2*_
+   log(d*(a+b*x+c*x^2)^n)-1/2*b*n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*_
+   sqrt(b^2-4*a*c)/c^2
+--R 
+--R
+--R   (2)
+--R                                            +-----------+
+--R         2 2          2           n         |          2          2c x + b
+--R       2c x log(d (c x  + b x + a) ) - 2b n\|- 4a c + b  atanh(--------------)
+--R                                                                +-----------+
+--R                                                                |          2
+--R                                                               \|- 4a c + b
+--R     + 
+--R                2          2                2   2
+--R       (2a c - b )n log(c x  + b x + a) - 2c n x  + 2b c n x
+--R  /
+--R       2
+--R     4c
+--R                                                    Type: Expression(Integer)
+--E 4170
+
+--S 4171 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               +-----------+
+--R               |          2
+--R           b n\|- 4a c + b
+--R        *
+--R                            +-----------+
+--R                            |          2      2 2                    2
+--R               (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-------------------------------------------------------)
+--R                                       2
+--R                                    c x  + b x + a
+--R       + 
+--R            2   2            2          2                2 2           2   2
+--R         (2c n x  + (2a c - b )n)log(c x  + b x + a) + 2c x log(d) - 2c n x
+--R       + 
+--R         2b c n x
+--R    /
+--R         2
+--R       4c
+--R     ,
+--R
+--R                               +---------+
+--R              +---------+      |        2
+--R              |        2      \|4a c - b
+--R         2b n\|4a c - b  atan(------------)
+--R                                2c x + b
+--R       + 
+--R            2   2            2          2                2 2           2   2
+--R         (2c n x  + (2a c - b )n)log(c x  + b x + a) + 2c x log(d) - 2c n x
+--R       + 
+--R         2b c n x
+--R    /
+--R         2
+--R       4c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4171
+
+--S 4172 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R           2 2          2           n
+--R       - 2c x log(d (c x  + b x + a) )
+--R     + 
+--R             +-----------+
+--R             |          2
+--R         b n\|- 4a c + b
+--R      *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R             (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-------------------------------------------------------)
+--R                                     2
+--R                                  c x  + b x + a
+--R     + 
+--R            +-----------+
+--R            |          2          2c x + b         2   2       2
+--R       2b n\|- 4a c + b  atanh(--------------) + 2c n x log(c x  + b x + a)
+--R                                +-----------+
+--R                                |          2
+--R                               \|- 4a c + b
+--R     + 
+--R         2 2
+--R       2c x log(d)
+--R  /
+--R       2
+--R     4c
+--R                                                    Type: Expression(Integer)
+--E 4172
+
+--S 4173 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4173
+
+--S 4174 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                            +-----------+
+--R          2 2          2           n        |          2          2c x + b
+--R       - c x log(d (c x  + b x + a) ) + b n\|- 4a c + b  atanh(--------------)
+--R                                                                +-----------+
+--R                                                                |          2
+--R                                                               \|- 4a c + b
+--R     + 
+--R                          +---------+
+--R         +---------+      |        2
+--R         |        2      \|4a c - b       2   2       2               2 2
+--R     b n\|4a c - b  atan(------------) + c n x log(c x  + b x + a) + c x log(d)
+--R                           2c x + b
+--R  /
+--R       2
+--R     2c
+--R                                                    Type: Expression(Integer)
+--E 4174
+
+--S 4175 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4175
+
+)clear all
+
+--S 4176 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R                  2           n
+--R   (1)  log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4176
+
+--S 4177 of 5341
+r0:=-2*n*x+1/2*b*n*log(a+b*x+c*x^2)/c+x*log(d*(a+b*x+c*x^2)^n)+_
+   n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/c
+--R 
+--R
+--R   (2)
+--R                                          +-----------+
+--R                      2           n       |          2          2c x + b
+--R       2c x log(d (c x  + b x + a) ) + 2n\|- 4a c + b  atanh(--------------)
+--R                                                              +-----------+
+--R                                                              |          2
+--R                                                             \|- 4a c + b
+--R     + 
+--R                  2
+--R       b n log(c x  + b x + a) - 4c n x
+--R  /
+--R     2c
+--R                                                    Type: Expression(Integer)
+--E 4177
+
+--S 4178 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R             +-----------+
+--R             |          2
+--R           n\|- 4a c + b
+--R        *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R               (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-----------------------------------------------------)
+--R                                      2
+--R                                   c x  + b x + a
+--R       + 
+--R                              2
+--R         (2c n x + b n)log(c x  + b x + a) + 2c x log(d) - 4c n x
+--R    /
+--R       2c
+--R     ,
+--R
+--R                               +---------+
+--R              +---------+      |        2
+--R              |        2      \|4a c - b                           2
+--R         - 2n\|4a c - b  atan(------------) + (2c n x + b n)log(c x  + b x + a)
+--R                                2c x + b
+--R       + 
+--R         2c x log(d) - 4c n x
+--R    /
+--R       2c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4178
+
+--S 4179 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                     +-----------+
+--R         +-----------+               |          2      2 2                    2
+--R         |          2     (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R       n\|- 4a c + b  log(-----------------------------------------------------)
+--R                                                 2
+--R                                              c x  + b x + a
+--R     + 
+--R                                            +-----------+
+--R                        2           n       |          2          2c x + b
+--R       - 2c x log(d (c x  + b x + a) ) - 2n\|- 4a c + b  atanh(--------------)
+--R                                                                +-----------+
+--R                                                                |          2
+--R                                                               \|- 4a c + b
+--R     + 
+--R                     2
+--R       2c n x log(c x  + b x + a) + 2c x log(d)
+--R  /
+--R     2c
+--R                                                    Type: Expression(Integer)
+--E 4179
+
+--S 4180 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4180
+
+--S 4181 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                          +-----------+
+--R                       2           n      |          2          2c x + b
+--R       - c x log(d (c x  + b x + a) ) - n\|- 4a c + b  atanh(--------------)
+--R                                                              +-----------+
+--R                                                              |          2
+--R                                                             \|- 4a c + b
+--R     + 
+--R                          +---------+
+--R         +---------+      |        2
+--R         |        2      \|4a c - b                   2
+--R     - n\|4a c - b  atan(------------) + c n x log(c x  + b x + a) + c x log(d)
+--R                           2c x + b
+--R  /
+--R     c
+--R                                                    Type: Expression(Integer)
+--E 4181
+
+--S 4182 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4182
+
+)clear all
+
+--S 4183 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)/x
+--R 
+--R
+--R                  2           n
+--R        log(d (c x  + b x + a) )
+--R   (1)  ------------------------
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 4183
+
+--S 4184 of 5341
+--r0:=log(x)*log(d*(a+b*x+c*x^2)^n)-n*log(x)*log((b+2*c*x-sqrt(b^2-_
+--  4*a*c))/(b-sqrt(b^2-4*a*c)))-n*log(x)*log((b+2*c*x+sqrt(b^2-_
+--  4*a*c))/(b+sqrt(b^2-4*a*c)))-n*polylog(2,-2*c*x/(b-sqrt(b^2-_
+--  4*a*c)))-n*polylog(2,-2*c*x/(b+sqrt(b^2-4*a*c)))
+--E 4184
+
+--S 4185 of 5341
+--a0:=integrate(t0,x)
+--E 4185
+
+--S 4186 of 5341
+--m0:=a0-r0
+--E 4186
+
+--S 4187 of 5341
+--d0:=D(m0,x)
+--E 4187
+
+)clear all
+
+--S 4188 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)/x^2
+--R 
+--R
+--R                  2           n
+--R        log(d (c x  + b x + a) )
+--R   (1)  ------------------------
+--R                    2
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 4188
+
+--S 4189 of 5341
+r0:=b*n*log(x)/a-1/2*b*n*log(a+b*x+c*x^2)/a-log(d*(a+b*x+c*x^2)^n)/x+_
+   n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/a
+--R 
+--R
+--R   (2)
+--R                                            +-----------+
+--R                      2           n         |          2          2c x + b
+--R       - 2a log(d (c x  + b x + a) ) + 2n x\|- 4a c + b  atanh(--------------)
+--R                                                                +-----------+
+--R                                                                |          2
+--R                                                               \|- 4a c + b
+--R     + 
+--R                      2
+--R       - b n x log(c x  + b x + a) + 2b n x log(x)
+--R  /
+--R     2a x
+--R                                                    Type: Expression(Integer)
+--E 4189
+
+--S 4190 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R               +-----------+
+--R               |          2
+--R           n x\|- 4a c + b
+--R        *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R               (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-----------------------------------------------------)
+--R                                      2
+--R                                   c x  + b x + a
+--R       + 
+--R                                2
+--R         (- b n x - 2a n)log(c x  + b x + a) + 2b n x log(x) - 2a log(d)
+--R    /
+--R       2a x
+--R     ,
+--R
+--R                                 +---------+
+--R                +---------+      |        2
+--R                |        2      \|4a c - b
+--R         - 2n x\|4a c - b  atan(------------)
+--R                                  2c x + b
+--R       + 
+--R                                2
+--R         (- b n x - 2a n)log(c x  + b x + a) + 2b n x log(x) - 2a log(d)
+--R    /
+--R       2a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4190
+
+--S 4191 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             +-----------+
+--R             |          2
+--R         n x\|- 4a c + b
+--R      *
+--R                        +-----------+
+--R                        |          2      2 2                    2
+--R             (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-----------------------------------------------------)
+--R                                    2
+--R                                 c x  + b x + a
+--R     + 
+--R                                          +-----------+
+--R                    2           n         |          2          2c x + b
+--R       2a log(d (c x  + b x + a) ) - 2n x\|- 4a c + b  atanh(--------------)
+--R                                                              +-----------+
+--R                                                              |          2
+--R                                                             \|- 4a c + b
+--R     + 
+--R                     2
+--R       - 2a n log(c x  + b x + a) - 2a log(d)
+--R  /
+--R     2a x
+--R                                                    Type: Expression(Integer)
+--E 4191
+
+--S 4192 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4192
+
+--S 4193 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                        +-----------+
+--R                   2           n        |          2          2c x + b
+--R       a log(d (c x  + b x + a) ) - n x\|- 4a c + b  atanh(--------------)
+--R                                                            +-----------+
+--R                                                            |          2
+--R                                                           \|- 4a c + b
+--R     + 
+--R                              +---------+
+--R             +---------+      |        2
+--R             |        2      \|4a c - b                 2
+--R       - n x\|4a c - b  atan(------------) - a n log(c x  + b x + a) - a log(d)
+--R                               2c x + b
+--R  /
+--R     a x
+--R                                                    Type: Expression(Integer)
+--E 4193
+
+--S 4194 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4194
+
+)clear all
+
+--S 4195 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)/x^3
+--R 
+--R
+--R                  2           n
+--R        log(d (c x  + b x + a) )
+--R   (1)  ------------------------
+--R                    3
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 4195
+
+--S 4196 of 5341
+r0:=-1/2*b*n/(a*x)-1/2*(b^2-2*a*c)*n*log(x)/a^2+1/4*(b^2-2*a*c)*n*_
+   log(a+b*x+c*x^2)/a^2-1/2*log(d*(a+b*x+c*x^2)^n)/x^2-1/2*b*n*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/a^2
+--R 
+--R
+--R   (2)
+--R           2          2           n
+--R       - 2a log(d (c x  + b x + a) )
+--R     + 
+--R                 +-----------+
+--R               2 |          2          2c x + b
+--R       - 2b n x \|- 4a c + b  atanh(--------------)
+--R                                     +-----------+
+--R                                     |          2
+--R                                    \|- 4a c + b
+--R     + 
+--R                  2    2       2                        2    2
+--R       (- 2a c + b )n x log(c x  + b x + a) + (4a c - 2b )n x log(x) - 2a b n x
+--R  /
+--R       2 2
+--R     4a x
+--R                                                    Type: Expression(Integer)
+--E 4196
+
+--S 4197 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                  +-----------+
+--R                2 |          2
+--R           b n x \|- 4a c + b
+--R        *
+--R                            +-----------+
+--R                            |          2      2 2                    2
+--R               (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-------------------------------------------------------)
+--R                                       2
+--R                                    c x  + b x + a
+--R       + 
+--R                     2    2     2         2                        2    2
+--R         ((- 2a c + b )n x  - 2a n)log(c x  + b x + a) + (4a c - 2b )n x log(x)
+--R       + 
+--R             2
+--R         - 2a log(d) - 2a b n x
+--R    /
+--R         2 2
+--R       4a x
+--R     ,
+--R
+--R                                  +---------+
+--R                 +---------+      |        2
+--R               2 |        2      \|4a c - b
+--R         2b n x \|4a c - b  atan(------------)
+--R                                   2c x + b
+--R       + 
+--R                     2    2     2         2                        2    2
+--R         ((- 2a c + b )n x  - 2a n)log(c x  + b x + a) + (4a c - 2b )n x log(x)
+--R       + 
+--R             2
+--R         - 2a log(d) - 2a b n x
+--R    /
+--R         2 2
+--R       4a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4197
+
+--S 4198 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         2          2           n
+--R       2a log(d (c x  + b x + a) )
+--R     + 
+--R                +-----------+
+--R              2 |          2
+--R         b n x \|- 4a c + b
+--R      *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R             (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-------------------------------------------------------)
+--R                                     2
+--R                                  c x  + b x + a
+--R     + 
+--R               +-----------+
+--R             2 |          2          2c x + b         2         2
+--R       2b n x \|- 4a c + b  atanh(--------------) - 2a n log(c x  + b x + a)
+--R                                   +-----------+
+--R                                   |          2
+--R                                  \|- 4a c + b
+--R     + 
+--R           2
+--R       - 2a log(d)
+--R  /
+--R       2 2
+--R     4a x
+--R                                                    Type: Expression(Integer)
+--E 4198
+
+--S 4199 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4199
+
+--S 4200 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                           +-----------+
+--R        2          2           n         2 |          2          2c x + b
+--R       a log(d (c x  + b x + a) ) + b n x \|- 4a c + b  atanh(--------------)
+--R                                                               +-----------+
+--R                                                               |          2
+--R                                                              \|- 4a c + b
+--R     + 
+--R                             +---------+
+--R            +---------+      |        2
+--R          2 |        2      \|4a c - b       2         2               2
+--R     b n x \|4a c - b  atan(------------) - a n log(c x  + b x + a) - a log(d)
+--R                              2c x + b
+--R  /
+--R       2 2
+--R     2a x
+--R                                                    Type: Expression(Integer)
+--E 4200
+
+--S 4201 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4201
+
+)clear all
+
+--S 4202 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)/x^4
+--R 
+--R
+--R                  2           n
+--R        log(d (c x  + b x + a) )
+--R   (1)  ------------------------
+--R                    4
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 4202
+
+--S 4203 of 5341
+r0:=-1/6*b*n/(a*x^2)+1/3*(b^2-2*a*c)*n/(a^2*x)+1/3*b*(b^2-3*a*c)*n*_
+   log(x)/a^3-1/6*b*(b^2-3*a*c)*n*log(a+b*x+c*x^2)/a^3-1/3*log(d*(a+_
+   b*x+c*x^2)^n)/x^3+1/3*(b^2-a*c)*n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*_
+   sqrt(b^2-4*a*c)/a^3
+--R 
+--R
+--R   (2)
+--R           3          2           n
+--R       - 2a log(d (c x  + b x + a) )
+--R     + 
+--R                          +-----------+
+--R                   2    3 |          2          2c x + b
+--R       (- 2a c + 2b )n x \|- 4a c + b  atanh(--------------)
+--R                                              +-----------+
+--R                                              |          2
+--R                                             \|- 4a c + b
+--R     + 
+--R                  3    3       2                            3    3
+--R       (3a b c - b )n x log(c x  + b x + a) + (- 6a b c + 2b )n x log(x)
+--R     + 
+--R            2        2    2    2
+--R       (- 4a c + 2a b )n x  - a b n x
+--R  /
+--R       3 3
+--R     6a x
+--R                                                    Type: Expression(Integer)
+--E 4203
+
+--S 4204 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                          +-----------+
+--R                   2    3 |          2
+--R           (a c - b )n x \|- 4a c + b
+--R        *
+--R                            +-----------+
+--R                            |          2      2 2                    2
+--R               (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-------------------------------------------------------)
+--R                                       2
+--R                                    c x  + b x + a
+--R       + 
+--R                     3    3     3         2
+--R         ((3a b c - b )n x  - 2a n)log(c x  + b x + a)
+--R       + 
+--R                     3    3           3              2        2    2    2
+--R       (- 6a b c + 2b )n x log(x) - 2a log(d) + (- 4a c + 2a b )n x  - a b n x
+--R    /
+--R         3 3
+--R       6a x
+--R     ,
+--R
+--R                                           +---------+
+--R                          +---------+      |        2
+--R                   2    3 |        2      \|4a c - b
+--R         (2a c - 2b )n x \|4a c - b  atan(------------)
+--R                                            2c x + b
+--R       + 
+--R                     3    3     3         2
+--R         ((3a b c - b )n x  - 2a n)log(c x  + b x + a)
+--R       + 
+--R                     3    3           3              2        2    2    2
+--R       (- 6a b c + 2b )n x log(x) - 2a log(d) + (- 4a c + 2a b )n x  - a b n x
+--R    /
+--R         3 3
+--R       6a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4204
+
+--S 4205 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R         3          2           n
+--R       2a log(d (c x  + b x + a) )
+--R     + 
+--R                        +-----------+
+--R                 2    3 |          2
+--R         (a c - b )n x \|- 4a c + b
+--R      *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R             (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-------------------------------------------------------)
+--R                                     2
+--R                                  c x  + b x + a
+--R     + 
+--R                        +-----------+
+--R                 2    3 |          2          2c x + b
+--R       (2a c - 2b )n x \|- 4a c + b  atanh(--------------)
+--R                                            +-----------+
+--R                                            |          2
+--R                                           \|- 4a c + b
+--R     + 
+--R           3         2                3
+--R       - 2a n log(c x  + b x + a) - 2a log(d)
+--R  /
+--R       3 3
+--R     6a x
+--R                                                    Type: Expression(Integer)
+--E 4205
+
+--S 4206 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4206
+
+--S 4207 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        3          2           n
+--R       a log(d (c x  + b x + a) )
+--R     + 
+--R                      +-----------+
+--R               2    3 |          2          2c x + b
+--R       (a c - b )n x \|- 4a c + b  atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R     + 
+--R                                       +---------+
+--R                      +---------+      |        2
+--R               2    3 |        2      \|4a c - b       3         2
+--R       (a c - b )n x \|4a c - b  atan(------------) - a n log(c x  + b x + a)
+--R                                        2c x + b
+--R     + 
+--R          3
+--R       - a log(d)
+--R  /
+--R       3 3
+--R     3a x
+--R                                                    Type: Expression(Integer)
+--E 4207
+
+--S 4208 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4208
+
+)clear all
+
+--S 4209 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)/x^5
+--R 
+--R
+--R                  2           n
+--R        log(d (c x  + b x + a) )
+--R   (1)  ------------------------
+--R                    5
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 4209
+
+--S 4210 of 5341
+r0:=-1/12*b*n/(a*x^3)+1/8*(b^2-2*a*c)*n/(a^2*x^2)-1/4*b*(b^2-3*a*c)*_
+   n/(a^3*x)-1/4*(b^4-4*a*b^2*c+2*a^2*c^2)*n*log(x)/a^4+1/8*(b^4-4*a*b^2*c+_
+   2*a^2*c^2)*n*log(a+b*x+c*x^2)/a^4-1/4*log(d*(a+b*x+c*x^2)^n)/x^4-_
+   1/4*b*(b^2-2*a*c)*n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/a^4
+--R 
+--R
+--R   (2)
+--R           4          2           n
+--R       - 6a log(d (c x  + b x + a) )
+--R     + 
+--R                           +-----------+
+--R                    3    4 |          2          2c x + b
+--R       (12a b c - 6b )n x \|- 4a c + b  atanh(--------------)
+--R                                               +-----------+
+--R                                               |          2
+--R                                              \|- 4a c + b
+--R     + 
+--R          2 2        2      4    4       2
+--R       (6a c  - 12a b c + 3b )n x log(c x  + b x + a)
+--R     + 
+--R             2 2        2      4    4             2          3    3
+--R       (- 12a c  + 24a b c - 6b )n x log(x) + (18a b c - 6a b )n x
+--R     + 
+--R            3      2 2    2     3
+--R       (- 6a c + 3a b )n x  - 2a b n x
+--R  /
+--R        4 4
+--R     24a x
+--R                                                    Type: Expression(Integer)
+--E 4210
+
+--S 4211 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                              +-----------+
+--R                       3    4 |          2
+--R           (6a b c - 3b )n x \|- 4a c + b
+--R        *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R               (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-----------------------------------------------------)
+--R                                      2
+--R                                   c x  + b x + a
+--R       + 
+--R             2 2        2      4    4     4         2
+--R         ((6a c  - 12a b c + 3b )n x  - 6a n)log(c x  + b x + a)
+--R       + 
+--R               2 2        2      4    4           4
+--R         (- 12a c  + 24a b c - 6b )n x log(x) - 6a log(d)
+--R       + 
+--R             2          3    3        3      2 2    2     3
+--R         (18a b c - 6a b )n x  + (- 6a c + 3a b )n x  - 2a b n x
+--R    /
+--R          4 4
+--R       24a x
+--R     ,
+--R
+--R                                                +---------+
+--R                               +---------+      |        2
+--R                        3    4 |        2      \|4a c - b
+--R         (- 12a b c + 6b )n x \|4a c - b  atan(------------)
+--R                                                 2c x + b
+--R       + 
+--R             2 2        2      4    4     4         2
+--R         ((6a c  - 12a b c + 3b )n x  - 6a n)log(c x  + b x + a)
+--R       + 
+--R               2 2        2      4    4           4
+--R         (- 12a c  + 24a b c - 6b )n x log(x) - 6a log(d)
+--R       + 
+--R             2          3    3        3      2 2    2     3
+--R         (18a b c - 6a b )n x  + (- 6a c + 3a b )n x  - 2a b n x
+--R    /
+--R          4 4
+--R       24a x
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4211
+
+--S 4212 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                           +-----------+
+--R                    3    4 |          2
+--R         (2a b c - b )n x \|- 4a c + b
+--R      *
+--R                        +-----------+
+--R                        |          2      2 2                    2
+--R             (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-----------------------------------------------------)
+--R                                    2
+--R                                 c x  + b x + a
+--R     + 
+--R         4          2           n
+--R       2a log(d (c x  + b x + a) )
+--R     + 
+--R                            +-----------+
+--R                     3    4 |          2          2c x + b
+--R       (- 4a b c + 2b )n x \|- 4a c + b  atanh(--------------)
+--R                                                +-----------+
+--R                                                |          2
+--R                                               \|- 4a c + b
+--R     + 
+--R           4         2                4
+--R       - 2a n log(c x  + b x + a) - 2a log(d)
+--R  /
+--R       4 4
+--R     8a x
+--R                                                    Type: Expression(Integer)
+--E 4212
+
+--S 4213 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4213
+
+--S 4214 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R        4          2           n
+--R       a log(d (c x  + b x + a) )
+--R     + 
+--R                           +-----------+
+--R                    3    4 |          2          2c x + b
+--R       (- 2a b c + b )n x \|- 4a c + b  atanh(--------------)
+--R                                               +-----------+
+--R                                               |          2
+--R                                              \|- 4a c + b
+--R     + 
+--R                                            +---------+
+--R                           +---------+      |        2
+--R                    3    4 |        2      \|4a c - b
+--R       (- 2a b c + b )n x \|4a c - b  atan(------------)
+--R                                             2c x + b
+--R     + 
+--R          4         2               4
+--R       - a n log(c x  + b x + a) - a log(d)
+--R  /
+--R       4 4
+--R     4a x
+--R                                                    Type: Expression(Integer)
+--E 4214
+
+--S 4215 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4215
+
+)clear all
+
+--S 4216 of 5341
+t0:=log(1+x+x^2)
+--R 
+--R
+--R             2
+--R   (1)  log(x  + x + 1)
+--R                                                    Type: Expression(Integer)
+--E 4216
+
+--S 4217 of 5341
+r0:=-2*x+1/2*log(1+x+x^2)+x*log(1+x+x^2)+atan((1+2*x)/sqrt(3))*sqrt(3)
+--R 
+--R
+--R                                                     +-+
+--R                     2              +-+     (2x + 1)\|3
+--R        (2x + 1)log(x  + x + 1) + 2\|3 atan(------------) - 4x
+--R                                                  3
+--R   (2)  ------------------------------------------------------
+--R                                   2
+--R                                                    Type: Expression(Integer)
+--E 4217
+
+--S 4218 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                              +-+
+--R                     2              +-+      \|3
+--R        (2x + 1)log(x  + x + 1) - 2\|3 atan(------) - 4x
+--R                                            2x + 1
+--R   (3)  ------------------------------------------------
+--R                                2
+--R                                         Type: Union(Expression(Integer),...)
+--E 4218
+
+--S 4219 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                            +-+               +-+
+--R           +-+     (2x + 1)\|3      +-+      \|3
+--R   (4)  - \|3 atan(------------) - \|3 atan(------)
+--R                         3                  2x + 1
+--R                                                    Type: Expression(Integer)
+--E 4219
+
+--S 4220 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4220
+
+)clear all
+
+--S 4221 of 5341
+t0:=x^2*log(1+x+x^2)/(2+3*x+x^2)
+--R 
+--R
+--R         2     2
+--R        x log(x  + x + 1)
+--R   (1)  -----------------
+--R            2
+--R           x  + 3x + 2
+--R                                                    Type: Expression(Integer)
+--E 4221
+
+--S 4222 of 5341
+--r0:=-2*x+1/2*log(1+x+x^2)+x*log(1+x+x^2)+log(1+x)*log(1+x+x^2)-_
+--  4*log(2+x)*log(1+x+x^2)-log(1+x)*log((-1-2*x+%i*sqrt(3))/(1+%i*_
+--  sqrt(3)))+4*log(2+x)*log((-1-2*x+%i*sqrt(3))/(3+%i*sqrt(3)))-_
+--  log(1+x)*log((-1-2*x-%i*sqrt(3))/(1-%i*sqrt(3)))+4*log(2+x)*_
+--  log((-1-2*x-%i*sqrt(3))/(3-%i*sqrt(3)))-polylog(2,2*(1+x)/(1-%i*_
+--  sqrt(3)))+4*polylog(2,2*(2+x)/(3-%i*sqrt(3)))-polylog(2,2*(1+x)/_
+--  (1+%i*sqrt(3)))+4*polylog(2,2*(2+x)/(3+%i*sqrt(3)))+atan((1+2*x)/_
+--  sqrt(3))*sqrt(3)
+--E 4222
+
+--S 4223 of 5341
+--a0:=integrate(t0,x)
+--E 4223
+
+--S 4224 of 5341
+--m0:=a0-r0
+--E 4224
+
+--S 4225 of 5341
+--d0:=D(m0,x)
+--E 4225
+
+)clear all
+
+--S 4226 of 5341
+t0:=log(1+x+x^2)^2
+--R 
+--R
+--R             2         2
+--R   (1)  log(x  + x + 1)
+--R                                                    Type: Expression(Integer)
+--E 4226
+
+--S 4227 of 5341
+--r0:=8*x-8/3*atan(1/sqrt(3)+2*x/sqrt(3))^2-2*log(1+x+x^2)-4*x*log(1+x+_
+--  x^2)+x*log(1+x+x^2)^2-2/3*log(1/3*(3+%i*sqrt(3))+2*%i*x/sqrt(3))^2*_
+--  (1-%i*sqrt(3))+4/3*log(1/3*(3-%i*sqrt(3))-2*%i*x/sqrt(3))*log(1/2*%i*_
+--  (1+2*x-%i*sqrt(3))/sqrt(3))*(1-%i*sqrt(3))+4/3*polylog(2,1/6*(3-%i*_
+--  sqrt(3)-2*%i*x*sqrt(3)))*(1-%i*sqrt(3))+1/3*log(1+x+x^2)*log(1+2*x+_
+--  %i*sqrt(3))*(3-%i*sqrt(3))-1/6*log(1+2*x+%i*sqrt(3))^2*(3-%i*sqrt(3))-_
+--  1/3*log(1+2*x+%i*sqrt(3))*log(1/2*%i*(1+2*x-%i*sqrt(3))/sqrt(3))*(3-_
+--  %i*sqrt(3))-1/3*polylog(2,-1/2*%i*(1+2*x+%i*sqrt(3))/sqrt(3))*(3-_
+--  %i*sqrt(3))-2/3*log(1/3*(3-%i*sqrt(3))-2*%i*x/sqrt(3))^2*(1+%i*_
+--  sqrt(3))+4/3*log(1/3*(3+%i*sqrt(3))+2*%i*x/sqrt(3))*log(-1/2*%i*_
+--  (1+2*x+%i*sqrt(3))/sqrt(3))*(1+%i*sqrt(3))+4/3*polylog(2,1/6*(3+_
+--  %i*sqrt(3)+2*%i*x*sqrt(3)))*(1+%i*sqrt(3))+1/3*log(1+x+x^2)*_
+--  log(1+2*x-%i*sqrt(3))*(3+%i*sqrt(3))-1/6*log(1+2*x-%i*sqrt(3))^2*_
+--  (3+%i*sqrt(3))-1/3*log(1+2*x-%i*sqrt(3))*log(-1/2*%i*(1+2*x+%i*_
+--  sqrt(3))/sqrt(3))*(3+%i*sqrt(3))-1/3*polylog(2,1/2*%i*(1+2*x-%i*_
+--  sqrt(3))/sqrt(3))*(3+%i*sqrt(3))+8*atan((1+2*x)/sqrt(3))*log(1+x+_
+--  x^2)/sqrt(3)-4*atan((1+2*x)/sqrt(3))*sqrt(3)
+--E 4227
+
+--S 4228 of 5341
+--a0:=integrate(t0,x)
+--E 4228
+
+--S 4229 of 5341
+--m0:=a0-r0
+--E 4229
+
+--S 4230 of 5341
+--d0:=D(m0,x)
+--E 4230
+
+)clear all
+
+--S 4231 of 5341
+t0:=log(-1+x+x^2)^2/x^3
+--R 
+--R
+--R             2         2
+--R        log(x  + x - 1)
+--R   (1)  ----------------
+--R                3
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 4231
+
+--S 4232 of 5341
+--r0:=1/20*(-10*log(-1+x+x^2)^2+x*(20*x*log(x)+20*log(-1+x+x^2)-60*x*_
+--  log(x)*log(-1+x+x^2)+60*x*log(x)*log(1/2+x-1/2*sqrt(5))+15*x*log(1/2+x-_
+--  1/2*sqrt(5))^2-60*x*log(1/2+x-1/2*sqrt(5))*log(2*x/(-1+sqrt(5)))-_
+--  10*x*log(-1-2*x+sqrt(5))+30*x*log(-1+x+x^2)*log(-1-2*x+sqrt(5))-_
+--  30*x*log(1/2+x-1/2*sqrt(5))*log(-1-2*x+sqrt(5))-10*x*log(1+2*x+_
+--  sqrt(5))+30*x*log(-1+x+x^2)*log(1+2*x+sqrt(5))-30*x*log(1/2+x-_
+--  1/2*sqrt(5))*log(1+2*x+sqrt(5))+30*x*log(1/2+x-1/2*sqrt(5))*_
+--  log(1/2*(1+2*x+sqrt(5))/sqrt(5))+60*x*log(x)*log(1+2*x/(1+sqrt(5)))-_
+--  30*x*log(-1-2*x+sqrt(5))*log(x+1/2*(1+sqrt(5)))-30*x*log(1+2*x+_
+--  sqrt(5))*log(x+1/2*(1+sqrt(5)))+30*x*log(1/10*(5-sqrt(5)-2*x*_
+--  sqrt(5)))*log(x+1/2*(1+sqrt(5)))+15*x*log(x+1/2*(1+sqrt(5)))^2+_
+--  60*x*polylog(2,-2*x/(1+sqrt(5)))-60*x*polylog(2,(-1-2*x+sqrt(5))/_
+--  (-1+sqrt(5)))+30*x*polylog(2,1/2*(1+2*x+sqrt(5))/sqrt(5))-10*x*_
+--  polylog(2,1/2*(-1-2*x+sqrt(5))/sqrt(5))*(-3+sqrt(5))+2*x*log(100)*_
+--  log(1/2+x-1/2*sqrt(5))*sqrt(5)+5*x*log(1/2+x-1/2*sqrt(5))^2*_
+--  sqrt(5)-10*x*log(-1-2*x+sqrt(5))*sqrt(5)+10*x*log(-1+x+x^2)*_
+--  log(-1-2*x+sqrt(5))*sqrt(5)-10*x*log(1/2+x-1/2*sqrt(5))*log(-1-2*x+_
+--  sqrt(5))*sqrt(5)+10*x*log(1+2*x+sqrt(5))*sqrt(5)-10*x*log(-1+x+x^2)*_
+--  log(1+2*x+sqrt(5))*sqrt(5)+10*x*log(1/2+x-1/2*sqrt(5))*log(1+2*x+_
+--  sqrt(5))*sqrt(5)-6*x*log(1/2+x-1/2*sqrt(5))*log(1/2*(1+2*x+sqrt(5))/_
+--  sqrt(5))*sqrt(5)-4*x*log(1/2+x-1/2*sqrt(5))*log(5+sqrt(5)+2*x*_
+--  sqrt(5))*sqrt(5)+x*log(8)*log(x+1/2*(1+sqrt(5)))*sqrt(5)-10*x*_
+--  log(-1-2*x+sqrt(5))*log(x+1/2*(1+sqrt(5)))*sqrt(5)+7*x*log(1+2*x+_
+--  sqrt(5))*log(x+1/2*(1+sqrt(5)))*sqrt(5)+10*x*log(1/10*(5-sqrt(5)-_
+--  2*x*sqrt(5)))*log(x+1/2*(1+sqrt(5)))*sqrt(5)-2*x*log(x+1/2*(1+_
+--  sqrt(5)))^2*sqrt(5)+10*x*polylog(2,1/2*(1+2*x+sqrt(5))/sqrt(5))*_
+--  sqrt(5)))/x^2
+--E 4232
+
+--S 4233 of 5341
+--a0:=integrate(t0,x)
+--E 4233
+
+--S 4234 of 5341
+--m0:=a0-r0
+--E 4234
+
+--S 4235 of 5341
+--d0:=D(m0,x)
+--E 4235
+
+)clear all
+
+--S 4236 of 5341
+t0:=(d+e*x)^4*log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4           2           n
+--R   (1)  (e x  + 4d e x  + 6d e x  + 4d e x + d )log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4236
+
+--S 4237 of 5341
+r0:=-1/5*(10*c^4*d^4+b^4*e^4-10*c^3*d^2*e*(b*d+2*a*e)-b^2*c*e^3*(5*b*d+_
+   4*a*e)+c^2*e^2*(10*b^2*d^2+15*a*b*d*e+2*a^2*e^2))*n*x/c^4-1/10*e*(20*c^3*_
+   d^3-b^3*e^3-10*c^2*d*e*(b*d+a*e)+b*c*e^2*(5*b*d+3*a*e))*n*x^2/c^3-_
+   1/15*e^2*(20*c^2*d^2+b^2*e^2-c*e*(5*b*d+2*a*e))*n*x^3/c^2-1/20*e^3*_
+   (10*c*d-b*e)*n*x^4/c-2/25*e^4*n*x^5-1/10*(2*c*d-b*e)*(c^4*d^4+b^4*e^4-_
+   2*c^3*d^2*e*(b*d+5*a*e)-b^2*c*e^3*(3*b*d+5*a*e)+c^2*e^2*(4*b^2*d^2+_
+   10*a*b*d*e+5*a^2*e^2))*n*log(a+b*x+c*x^2)/(c^5*e)+1/5*(d+e*x)^5*log(d*_
+   (a+b*x+c*x^2)^n)/e+1/5*(5*c^4*d^4+b^4*e^4-10*c^3*d^2*e*(b*d+a*e)-_
+   b^2*c*e^3*(5*b*d+3*a*e)+c^2*e^2*(10*b^2*d^2+10*a*b*d*e+a^2*e^2))*n*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/c^5
+--R 
+--R
+--R   (2)
+--R              5 5 5       5   4 4       5 2 3 3       5 3 2 2       5 4
+--R           60c e x  + 300c d e x  + 600c d e x  + 600c d e x  + 300c d e x
+--R         + 
+--R              5 5
+--R           60c d
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R               2 2         2       4  5            2       3     4
+--R           (60a c  - 180a b c + 60b )e  + (600a b c  - 300b c)d e
+--R         + 
+--R                    3       2 2  2 3         3 3 2       4 4
+--R           (- 600a c  + 600b c )d e  - 600b c d e  + 300c d e
+--R      *
+--R           +-----------+
+--R           |          2          2c x + b
+--R         n\|- 4a c + b  atanh(--------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R     + 
+--R                2   2         3       5  5
+--R           (150a b c  - 150a b c + 30b )e
+--R         + 
+--R                  2 3         2 2       4     4              3       3 2  2 3
+--R           (- 300a c  + 600a b c  - 150b c)d e  + (- 900a b c  + 300b c )d e
+--R         + 
+--R                  4       2 3  3 2         4 4       5 5
+--R           (600a c  - 300b c )d e  + 150b c d e - 60c d
+--R      *
+--R                  2
+--R         n log(c x  + b x + a)
+--R     + 
+--R            5 5   5         4 5       5   4    4
+--R       - 24c e n x  + (15b c e  - 150c d e )n x
+--R     + 
+--R              4      2 3  5         4   4       5 2 3    3
+--R       ((40a c  - 20b c )e  + 100b c d e  - 400c d e )n x
+--R     + 
+--R                     3      3 2  5          4       2 3    4         4 2 3
+--R           (- 90a b c  + 30b c )e  + (300a c  - 150b c )d e  + 300b c d e
+--R         + 
+--R                 5 3 2
+--R           - 600c d e
+--R      *
+--R            2
+--R         n x
+--R     + 
+--R                  2 3         2 2      4   5              3       3 2    4
+--R           (- 120a c  + 240a b c  - 60b c)e  + (- 900a b c  + 300b c )d e
+--R         + 
+--R                   4       2 3  2 3         4 3 2       5 4
+--R           (1200a c  - 600b c )d e  + 600b c d e  - 600c d e
+--R      *
+--R         n x
+--R  /
+--R         5
+--R     300c e
+--R                                                    Type: Expression(Integer)
+--E 4237
+
+--S 4238 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                 2 2        2       4  4            2       3     3
+--R             (30a c  - 90a b c + 30b )e  + (300a b c  - 150b c)d e
+--R           + 
+--R                      3       2 2  2 2         3 3        4 4
+--R             (- 300a c  + 300b c )d e  - 300b c d e + 150c d
+--R        *
+--R             +-----------+
+--R             |          2
+--R           n\|- 4a c + b
+--R        *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R               (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-----------------------------------------------------)
+--R                                      2
+--R                                   c x  + b x + a
+--R       + 
+--R                5 4   5       5   3   4       5 2 2   3       5 3     2
+--R             60c e n x  + 300c d e n x  + 600c d e n x  + 600c d e n x
+--R           + 
+--R                 5 4
+--R             300c d n x
+--R           + 
+--R                      2   2         3       5  4
+--R                 (150a b c  - 150a b c + 30b )e
+--R               + 
+--R                        2 3         2 2       4     3
+--R                 (- 300a c  + 600a b c  - 150b c)d e
+--R               + 
+--R                          3       3 2  2 2          4       2 3  3          4 4
+--R               (- 900a b c  + 300b c )d e  + (600a c  - 300b c )d e + 150b c d
+--R            *
+--R               n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R             5 4 5       5   3 4       5 2 2 3       5 3   2       5 4
+--R         (60c e x  + 300c d e x  + 600c d e x  + 600c d e x  + 300c d x)log(d)
+--R       + 
+--R              5 4   5         4 4       5   3    4
+--R         - 24c e n x  + (15b c e  - 150c d e )n x
+--R       + 
+--R                4      2 3  4         4   3       5 2 2    3
+--R         ((40a c  - 20b c )e  + 100b c d e  - 400c d e )n x
+--R       + 
+--R                       3      3 2  4          4       2 3    3         4 2 2
+--R             (- 90a b c  + 30b c )e  + (300a c  - 150b c )d e  + 300b c d e
+--R           + 
+--R                   5 3
+--R             - 600c d e
+--R        *
+--R              2
+--R           n x
+--R       + 
+--R                    2 3         2 2      4   4              3       3 2    3
+--R             (- 120a c  + 240a b c  - 60b c)e  + (- 900a b c  + 300b c )d e
+--R           + 
+--R                     4       2 3  2 2         4 3        5 4
+--R             (1200a c  - 600b c )d e  + 600b c d e - 600c d
+--R        *
+--R           n x
+--R    /
+--R           5
+--R       300c
+--R     ,
+--R
+--R                   2 2         2       4  4              2       3     3
+--R             (- 60a c  + 180a b c - 60b )e  + (- 600a b c  + 300b c)d e
+--R           + 
+--R                    3       2 2  2 2         3 3        4 4
+--R             (600a c  - 600b c )d e  + 600b c d e - 300c d
+--R        *
+--R                              +---------+
+--R             +---------+      |        2
+--R             |        2      \|4a c - b
+--R           n\|4a c - b  atan(------------)
+--R                               2c x + b
+--R       + 
+--R                5 4   5       5   3   4       5 2 2   3       5 3     2
+--R             60c e n x  + 300c d e n x  + 600c d e n x  + 600c d e n x
+--R           + 
+--R                 5 4
+--R             300c d n x
+--R           + 
+--R                      2   2         3       5  4
+--R                 (150a b c  - 150a b c + 30b )e
+--R               + 
+--R                        2 3         2 2       4     3
+--R                 (- 300a c  + 600a b c  - 150b c)d e
+--R               + 
+--R                          3       3 2  2 2          4       2 3  3          4 4
+--R               (- 900a b c  + 300b c )d e  + (600a c  - 300b c )d e + 150b c d
+--R            *
+--R               n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R             5 4 5       5   3 4       5 2 2 3       5 3   2       5 4
+--R         (60c e x  + 300c d e x  + 600c d e x  + 600c d e x  + 300c d x)log(d)
+--R       + 
+--R              5 4   5         4 4       5   3    4
+--R         - 24c e n x  + (15b c e  - 150c d e )n x
+--R       + 
+--R                4      2 3  4         4   3       5 2 2    3
+--R         ((40a c  - 20b c )e  + 100b c d e  - 400c d e )n x
+--R       + 
+--R                       3      3 2  4          4       2 3    3         4 2 2
+--R             (- 90a b c  + 30b c )e  + (300a c  - 150b c )d e  + 300b c d e
+--R           + 
+--R                   5 3
+--R             - 600c d e
+--R        *
+--R              2
+--R           n x
+--R       + 
+--R                    2 3         2 2      4   4              3       3 2    3
+--R             (- 120a c  + 240a b c  - 60b c)e  + (- 900a b c  + 300b c )d e
+--R           + 
+--R                     4       2 3  2 2         4 3        5 4
+--R             (1200a c  - 600b c )d e  + 600b c d e - 600c d
+--R        *
+--R           n x
+--R    /
+--R           5
+--R       300c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4238
+
+--S 4239 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             2 2       2     4  5           2     3     4
+--R           (a c  - 3a b c + b )e  + (10a b c  - 5b c)d e
+--R         + 
+--R                   3      2 2  2 3        3 3 2     4 4
+--R           (- 10a c  + 10b c )d e  - 10b c d e  + 5c d e
+--R      *
+--R                                     +-----------+
+--R         +-----------+               |          2      2 2                    2
+--R         |          2     (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R       n\|- 4a c + b  log(-----------------------------------------------------)
+--R                                                 2
+--R                                              c x  + b x + a
+--R     + 
+--R              5 5 5      5   4 4      5 2 3 3      5 3 2 2      5 4        5 5
+--R         (- 2c e x  - 10c d e x  - 20c d e x  - 20c d e x  - 10c d e x - 2c d )
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                2 2       2      4  5             2      3     4
+--R           (- 2a c  + 6a b c - 2b )e  + (- 20a b c  + 10b c)d e
+--R         + 
+--R                 3      2 2  2 3        3 3 2      4 4
+--R           (20a c  - 20b c )d e  + 20b c d e  - 10c d e
+--R      *
+--R           +-----------+
+--R           |          2          2c x + b
+--R         n\|- 4a c + b  atanh(--------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R     + 
+--R             5 5   5      5   4   4      5 2 3   3      5 3 2   2      5 4
+--R           2c e n x  + 10c d e n x  + 20c d e n x  + 20c d e n x  + 10c d e n x
+--R         + 
+--R             5 5
+--R           2c d n
+--R      *
+--R                2
+--R         log(c x  + b x + a)
+--R     + 
+--R          5 5 5      5   4 4      5 2 3 3      5 3 2 2      5 4
+--R       (2c e x  + 10c d e x  + 20c d e x  + 20c d e x  + 10c d e x)log(d)
+--R  /
+--R        5
+--R     10c e
+--R                                                    Type: Expression(Integer)
+--E 4239
+
+--S 4240 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4240
+
+--S 4241 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             5 5 5     5   4 4      5 2 3 3      5 3 2 2     5 4       5 5
+--R         (- c e x  - 5c d e x  - 10c d e x  - 10c d e x  - 5c d e x - c d )
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R               2 2       2     4  5             2     3     4
+--R           (- a c  + 3a b c - b )e  + (- 10a b c  + 5b c)d e
+--R         + 
+--R                 3      2 2  2 3        3 3 2     4 4
+--R           (10a c  - 10b c )d e  + 10b c d e  - 5c d e
+--R      *
+--R           +-----------+
+--R           |          2          2c x + b
+--R         n\|- 4a c + b  atanh(--------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R     + 
+--R               2 2       2     4  5             2     3     4
+--R           (- a c  + 3a b c - b )e  + (- 10a b c  + 5b c)d e
+--R         + 
+--R                 3      2 2  2 3        3 3 2     4 4
+--R           (10a c  - 10b c )d e  + 10b c d e  - 5c d e
+--R      *
+--R                            +---------+
+--R           +---------+      |        2
+--R           |        2      \|4a c - b
+--R         n\|4a c - b  atan(------------)
+--R                             2c x + b
+--R     + 
+--R            5 5   5     5   4   4      5 2 3   3      5 3 2   2     5 4
+--R           c e n x  + 5c d e n x  + 10c d e n x  + 10c d e n x  + 5c d e n x
+--R         + 
+--R            5 5
+--R           c d n
+--R      *
+--R                2
+--R         log(c x  + b x + a)
+--R     + 
+--R         5 5 5     5   4 4      5 2 3 3      5 3 2 2     5 4
+--R       (c e x  + 5c d e x  + 10c d e x  + 10c d e x  + 5c d e x)log(d)
+--R  /
+--R       5
+--R     5c e
+--R                                                    Type: Expression(Integer)
+--E 4241
+
+--S 4242 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4242
+
+)clear all
+
+--S 4243 of 5341
+t0:=(d+e*x)^3*log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R          3 3       2 2     2       3           2           n
+--R   (1)  (e x  + 3d e x  + 3d e x + d )log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4243
+
+--S 4244 of 5341
+r0:=-1/4*(8*c^3*d^3-b^3*e^3+b*c*e^2*(4*b*d+3*a*e)-2*c^2*d*e*(3*b*d+4*a*e))*_
+   n*x/c^3-1/8*e*(12*c^2*d^2+b^2*e^2-2*c*e*(2*b*d+a*e))*n*x^2/c^2-1/12*e^2*_
+   (8*c*d-b*e)*n*x^3/c-1/8*e^3*n*x^4-1/8*(2*c^4*d^4+b^4*e^4-4*b^2*c*e^3*_
+   (b*d+a*e)-4*c^3*d^2*e*(b*d+3*a*e)+2*c^2*e^2*(3*b^2*d^2+6*a*b*d*e+a^2*_
+   e^2))*n*log(a+b*x+c*x^2)/(c^4*e)+1/4*(d+e*x)^4*log(d*(a+b*x+c*x^2)^n)/e+_
+   1/4*(2*c*d-b*e)*(2*c^2*d^2+b^2*e^2-2*c*e*(b*d+a*e))*n*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/c^4
+--R 
+--R
+--R   (2)
+--R            4 4 4      4   3 3      4 2 2 2      4 3        4 4
+--R         (6c e x  + 24c d e x  + 36c d e x  + 24c d e x + 6c d )
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                       3  4           2      2     3        2 2 2      3 3
+--R         ((12a b c - 6b )e  + (- 24a c  + 24b c)d e  - 36b c d e  + 24c d e)n
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                2 2        2      4  4             2      3     3
+--R           (- 6a c  + 12a b c - 3b )e  + (- 36a b c  + 12b c)d e
+--R         + 
+--R                 3      2 2  2 2        3 3      4 4
+--R           (36a c  - 18b c )d e  + 12b c d e - 6c d
+--R      *
+--R                  2
+--R         n log(c x  + b x + a)
+--R     + 
+--R           4 4   4        3 4      4   3    3
+--R       - 3c e n x  + (2b c e  - 16c d e )n x
+--R     + 
+--R             3     2 2  4        3   3      4 2 2    2
+--R       ((6a c  - 3b c )e  + 12b c d e  - 36c d e )n x
+--R     + 
+--R                2     3   4         3      2 2    3        3 2 2      4 3
+--R     ((- 18a b c  + 6b c)e  + (48a c  - 24b c )d e  + 36b c d e  - 48c d e)n x
+--R  /
+--R        4
+--R     24c e
+--R                                                    Type: Expression(Integer)
+--E 4244
+
+--S 4245 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                        3  3           2      2     2        2 2       3 3
+--R           ((6a b c - 3b )e  + (- 12a c  + 12b c)d e  - 18b c d e + 12c d )n
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R        *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R               (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-----------------------------------------------------)
+--R                                      2
+--R                                   c x  + b x + a
+--R       + 
+--R               4 3   4      4   2   3      4 2     2      4 3
+--R             6c e n x  + 24c d e n x  + 36c d e n x  + 24c d n x
+--R           + 
+--R                      2 2        2      4  3             2      3     2
+--R                 (- 6a c  + 12a b c - 3b )e  + (- 36a b c  + 12b c)d e
+--R               + 
+--R                       3      2 2  2         3 3
+--R                 (36a c  - 18b c )d e + 12b c d
+--R            *
+--R               n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R            4 3 4      4   2 3      4 2   2      4 3             4 3   4
+--R         (6c e x  + 24c d e x  + 36c d e x  + 24c d x)log(d) - 3c e n x
+--R       + 
+--R              3 3      4   2    3
+--R         (2b c e  - 16c d e )n x
+--R       + 
+--R               3     2 2  3        3   2      4 2     2
+--R         ((6a c  - 3b c )e  + 12b c d e  - 36c d e)n x
+--R       + 
+--R                  2     3   3         3      2 2    2        3 2       4 3
+--R       ((- 18a b c  + 6b c)e  + (48a c  - 24b c )d e  + 36b c d e - 48c d )n x
+--R    /
+--R          4
+--R       24c
+--R     ,
+--R
+--R                           3  3         2      2     2        2 2       3 3
+--R           ((- 12a b c + 6b )e  + (24a c  - 24b c)d e  + 36b c d e - 24c d )n
+--R        *
+--R                             +---------+
+--R            +---------+      |        2
+--R            |        2      \|4a c - b
+--R           \|4a c - b  atan(------------)
+--R                              2c x + b
+--R       + 
+--R               4 3   4      4   2   3      4 2     2      4 3
+--R             6c e n x  + 24c d e n x  + 36c d e n x  + 24c d n x
+--R           + 
+--R                      2 2        2      4  3             2      3     2
+--R                 (- 6a c  + 12a b c - 3b )e  + (- 36a b c  + 12b c)d e
+--R               + 
+--R                       3      2 2  2         3 3
+--R                 (36a c  - 18b c )d e + 12b c d
+--R            *
+--R               n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R            4 3 4      4   2 3      4 2   2      4 3             4 3   4
+--R         (6c e x  + 24c d e x  + 36c d e x  + 24c d x)log(d) - 3c e n x
+--R       + 
+--R              3 3      4   2    3
+--R         (2b c e  - 16c d e )n x
+--R       + 
+--R               3     2 2  3        3   2      4 2     2
+--R         ((6a c  - 3b c )e  + 12b c d e  - 36c d e)n x
+--R       + 
+--R                  2     3   3         3      2 2    2        3 2       4 3
+--R       ((- 18a b c  + 6b c)e  + (48a c  - 24b c )d e  + 36b c d e - 48c d )n x
+--R    /
+--R          4
+--R       24c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4245
+
+--S 4246 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                     3  4          2     2     3       2 2 2     3 3
+--R         ((2a b c - b )e  + (- 4a c  + 4b c)d e  - 6b c d e  + 4c d e)n
+--R      *
+--R                                    +-----------+
+--R        +-----------+               |          2      2 2                    2
+--R        |          2     (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R       \|- 4a c + b  log(-----------------------------------------------------)
+--R                                                2
+--R                                             c x  + b x + a
+--R     + 
+--R              4 4 4     4   3 3      4 2 2 2     4 3        4 4
+--R         (- 2c e x  - 8c d e x  - 12c d e x  - 8c d e x - 2c d )
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                        3  4        2     2     3        2 2 2     3 3
+--R         ((- 4a b c + 2b )e  + (8a c  - 8b c)d e  + 12b c d e  - 8c d e)n
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R            4 4   4     4   3   3      4 2 2   2     4 3          4 4
+--R         (2c e n x  + 8c d e n x  + 12c d e n x  + 8c d e n x + 2c d n)
+--R      *
+--R                2
+--R         log(c x  + b x + a)
+--R     + 
+--R          4 4 4     4   3 3      4 2 2 2     4 3
+--R       (2c e x  + 8c d e x  + 12c d e x  + 8c d e x)log(d)
+--R  /
+--R       4
+--R     8c e
+--R                                                    Type: Expression(Integer)
+--E 4246
+
+--S 4247 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4247
+
+--S 4248 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R             4 4 4     4   3 3     4 2 2 2     4 3       4 4
+--R         (- c e x  - 4c d e x  - 6c d e x  - 4c d e x - c d )
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                       3  4        2     2     3       2 2 2     3 3
+--R         ((- 2a b c + b )e  + (4a c  - 4b c)d e  + 6b c d e  - 4c d e)n
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                       3  4        2     2     3       2 2 2     3 3
+--R         ((- 2a b c + b )e  + (4a c  - 4b c)d e  + 6b c d e  - 4c d e)n
+--R      *
+--R                           +---------+
+--R          +---------+      |        2
+--R          |        2      \|4a c - b
+--R         \|4a c - b  atan(------------)
+--R                            2c x + b
+--R     + 
+--R           4 4   4     4   3   3     4 2 2   2     4 3         4 4
+--R         (c e n x  + 4c d e n x  + 6c d e n x  + 4c d e n x + c d n)
+--R      *
+--R                2
+--R         log(c x  + b x + a)
+--R     + 
+--R         4 4 4     4   3 3     4 2 2 2     4 3
+--R       (c e x  + 4c d e x  + 6c d e x  + 4c d e x)log(d)
+--R  /
+--R       4
+--R     4c e
+--R                                                    Type: Expression(Integer)
+--E 4248
+
+--S 4249 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4249
+
+)clear all
+
+--S 4250 of 5341
+t0:=(d+e*x)^2*log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R          2 2             2           2           n
+--R   (1)  (e x  + 2d e x + d )log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4250
+
+--S 4251 of 5341
+r0:=-1/3*(6*c^2*d^2+b^2*e^2-c*e*(3*b*d+2*a*e))*n*x/c^2-1/6*e*(6*c*d-b*e)*_
+   n*x^2/c-2/9*e^2*n*x^3-1/6*(2*c*d-b*e)*(c^2*d^2+b^2*e^2-c*e*(b*d+3*a*e))*_
+   n*log(a+b*x+c*x^2)/(c^3*e)+1/3*(d+e*x)^3*log(d*(a+b*x+c*x^2)^n)/e+_
+   1/3*(3*c^2*d^2+b^2*e^2-c*e*(3*b*d+a*e))*n*atanh((b+2*c*x)/sqrt(b^2-_
+   4*a*c))*sqrt(b^2-4*a*c)/c^3
+--R 
+--R
+--R   (2)
+--R          3 3 3      3   2 2      3 2        3 3           2           n
+--R       (6c e x  + 18c d e x  + 18c d e x + 6c d )log(d (c x  + b x + a) )
+--R     + 
+--R                                                    +-----------+
+--R                      2  3            2      2 2    |          2
+--R         ((- 6a c + 6b )e  - 18b c d e  + 18c d e)n\|- 4a c + b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                        3  3         2     2     2       2 2      3 3
+--R         ((- 9a b c + 3b )e  + (18a c  - 9b c)d e  + 9b c d e - 6c d )n
+--R      *
+--R                2
+--R         log(c x  + b x + a)
+--R     + 
+--R           3 3   3        2 3      3   2    2
+--R       - 4c e n x  + (3b c e  - 18c d e )n x
+--R     + 
+--R              2     2   3        2   2      3 2
+--R       ((12a c  - 6b c)e  + 18b c d e  - 36c d e)n x
+--R  /
+--R        3
+--R     18c e
+--R                                                    Type: Expression(Integer)
+--E 4251
+
+--S 4252 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                                                +-----------+
+--R                      2  2                2 2   |          2
+--R           ((3a c - 3b )e  + 9b c d e - 9c d )n\|- 4a c + b
+--R        *
+--R                            +-----------+
+--R                            |          2      2 2                    2
+--R               (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-------------------------------------------------------)
+--R                                       2
+--R                                    c x  + b x + a
+--R       + 
+--R               3 2   3      3       2      3 2
+--R             6c e n x  + 18c d e n x  + 18c d n x
+--R           + 
+--R                            3  2         2     2            2 2
+--R             ((- 9a b c + 3b )e  + (18a c  - 9b c)d e + 9b c d )n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R            3 2 3      3     2      3 2             3 2   3
+--R         (6c e x  + 18c d e x  + 18c d x)log(d) - 4c e n x
+--R       + 
+--R              2 2      3       2          2     2   2        2         3 2
+--R         (3b c e  - 18c d e)n x  + ((12a c  - 6b c)e  + 18b c d e - 36c d )n x
+--R    /
+--R          3
+--R       18c
+--R     ,
+--R
+--R                                                                 +---------+
+--R                                                +---------+      |        2
+--R                    2  2                  2 2   |        2      \|4a c - b
+--R         ((6a c - 6b )e  + 18b c d e - 18c d )n\|4a c - b  atan(------------)
+--R                                                                  2c x + b
+--R       + 
+--R               3 2   3      3       2      3 2
+--R             6c e n x  + 18c d e n x  + 18c d n x
+--R           + 
+--R                            3  2         2     2            2 2
+--R             ((- 9a b c + 3b )e  + (18a c  - 9b c)d e + 9b c d )n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R            3 2 3      3     2      3 2             3 2   3
+--R         (6c e x  + 18c d e x  + 18c d x)log(d) - 4c e n x
+--R       + 
+--R              2 2      3       2          2     2   2        2         3 2
+--R         (3b c e  - 18c d e)n x  + ((12a c  - 6b c)e  + 18b c d e - 36c d )n x
+--R    /
+--R          3
+--R       18c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4252
+
+--S 4253 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            3 3 3     3   2 2     3 2        3 3           2           n
+--R       (- 2c e x  - 6c d e x  - 6c d e x - 2c d )log(d (c x  + b x + a) )
+--R     + 
+--R                                              +-----------+
+--R                  2  3           2     2 2    |          2
+--R         ((a c - b )e  + 3b c d e  - 3c d e)n\|- 4a c + b
+--R      *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R             (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-------------------------------------------------------)
+--R                                     2
+--R                                  c x  + b x + a
+--R     + 
+--R                                              +-----------+
+--R                  2  3           2     2 2    |          2          2c x + b
+--R       ((2a c - 2b )e  + 6b c d e  - 6c d e)n\|- 4a c + b  atanh(--------------)
+--R                                                                  +-----------+
+--R                                                                  |          2
+--R                                                                 \|- 4a c + b
+--R     + 
+--R          3 3   3     3   2   2     3 2          3 3         2
+--R       (2c e n x  + 6c d e n x  + 6c d e n x + 2c d n)log(c x  + b x + a)
+--R     + 
+--R          3 3 3     3   2 2     3 2
+--R       (2c e x  + 6c d e x  + 6c d e x)log(d)
+--R  /
+--R       3
+--R     6c e
+--R                                                    Type: Expression(Integer)
+--E 4253
+
+--S 4254 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4254
+
+--S 4255 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           3 3 3     3   2 2     3 2       3 3           2           n
+--R       (- c e x  - 3c d e x  - 3c d e x - c d )log(d (c x  + b x + a) )
+--R     + 
+--R                                            +-----------+
+--R                2  3           2     2 2    |          2          2c x + b
+--R       ((a c - b )e  + 3b c d e  - 3c d e)n\|- 4a c + b  atanh(--------------)
+--R                                                                +-----------+
+--R                                                                |          2
+--R                                                               \|- 4a c + b
+--R     + 
+--R                                                             +---------+
+--R                                            +---------+      |        2
+--R                2  3           2     2 2    |        2      \|4a c - b
+--R       ((a c - b )e  + 3b c d e  - 3c d e)n\|4a c - b  atan(------------)
+--R                                                              2c x + b
+--R     + 
+--R         3 3   3     3   2   2     3 2         3 3         2
+--R       (c e n x  + 3c d e n x  + 3c d e n x + c d n)log(c x  + b x + a)
+--R     + 
+--R         3 3 3     3   2 2     3 2
+--R       (c e x  + 3c d e x  + 3c d e x)log(d)
+--R  /
+--R       3
+--R     3c e
+--R                                                    Type: Expression(Integer)
+--E 4255
+
+--S 4256 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4256
+
+)clear all
+
+--S 4257 of 5341
+t0:=(d+e*x)*log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R                           2           n
+--R   (1)  (e x + d)log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4257
+
+--S 4258 of 5341
+r0:=-1/2*(4*d-b*e/c)*n*x-1/2*e*n*x^2-1/4*(2*c^2*d^2+b^2*e^2-2*c*e*(b*d+_
+   a*e))*n*log(a+b*x+c*x^2)/(c^2*e)+1/2*(d+e*x)^2*log(d*(a+b*x+c*x^2)^n)/e+_
+   1/2*(2*c*d-b*e)*n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/c^2
+--R 
+--R
+--R   (2)
+--R          2 2 2     2          2 2           2           n
+--R       (2c e x  + 4c d e x + 2c d )log(d (c x  + b x + a) )
+--R     + 
+--R                           +-----------+
+--R              2            |          2          2c x + b
+--R       (- 2b e  + 4c d e)n\|- 4a c + b  atanh(--------------)
+--R                                               +-----------+
+--R                                               |          2
+--R                                              \|- 4a c + b
+--R     + 
+--R                 2  2                2 2          2                2 2   2
+--R       ((2a c - b )e  + 2b c d e - 2c d )n log(c x  + b x + a) - 2c e n x
+--R     + 
+--R              2     2
+--R       (2b c e  - 8c d e)n x
+--R  /
+--R       2
+--R     4c e
+--R                                                    Type: Expression(Integer)
+--E 4258
+
+--S 4259 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                         +-----------+
+--R                         |          2
+--R           (b e - 2c d)n\|- 4a c + b
+--R        *
+--R                            +-----------+
+--R                            |          2      2 2                    2
+--R               (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-------------------------------------------------------)
+--R                                       2
+--R                                    c x  + b x + a
+--R       + 
+--R            2     2     2                  2                     2
+--R         (2c e n x  + 4c d n x + ((2a c - b )e + 2b c d)n)log(c x  + b x + a)
+--R       + 
+--R            2   2     2               2     2               2
+--R         (2c e x  + 4c d x)log(d) - 2c e n x  + (2b c e - 8c d)n x
+--R    /
+--R         2
+--R       4c
+--R     ,
+--R
+--R                                         +---------+
+--R                        +---------+      |        2
+--R                        |        2      \|4a c - b
+--R         (2b e - 4c d)n\|4a c - b  atan(------------)
+--R                                          2c x + b
+--R       + 
+--R            2     2     2                  2                     2
+--R         (2c e n x  + 4c d n x + ((2a c - b )e + 2b c d)n)log(c x  + b x + a)
+--R       + 
+--R            2   2     2               2     2               2
+--R         (2c e x  + 4c d x)log(d) - 2c e n x  + (2b c e - 8c d)n x
+--R    /
+--R         2
+--R       4c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4259
+
+--S 4260 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 2 2     2          2 2           2           n
+--R       (- 2c e x  - 4c d e x - 2c d )log(d (c x  + b x + a) )
+--R     + 
+--R                          +-----------+
+--R             2            |          2
+--R         (b e  - 2c d e)n\|- 4a c + b
+--R      *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R             (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-------------------------------------------------------)
+--R                                     2
+--R                                  c x  + b x + a
+--R     + 
+--R                         +-----------+
+--R            2            |          2          2c x + b
+--R       (2b e  - 4c d e)n\|- 4a c + b  atanh(--------------)
+--R                                             +-----------+
+--R                                             |          2
+--R                                            \|- 4a c + b
+--R     + 
+--R          2 2   2     2            2 2         2
+--R       (2c e n x  + 4c d e n x + 2c d n)log(c x  + b x + a)
+--R     + 
+--R          2 2 2     2
+--R       (2c e x  + 4c d e x)log(d)
+--R  /
+--R       2
+--R     4c e
+--R                                                    Type: Expression(Integer)
+--E 4260
+
+--S 4261 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4261
+
+--S 4262 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           2 2 2     2         2 2           2           n
+--R       (- c e x  - 2c d e x - c d )log(d (c x  + b x + a) )
+--R     + 
+--R                        +-----------+
+--R           2            |          2          2c x + b
+--R       (b e  - 2c d e)n\|- 4a c + b  atanh(--------------)
+--R                                            +-----------+
+--R                                            |          2
+--R                                           \|- 4a c + b
+--R     + 
+--R                                         +---------+
+--R                        +---------+      |        2
+--R           2            |        2      \|4a c - b
+--R       (b e  - 2c d e)n\|4a c - b  atan(------------)
+--R                                          2c x + b
+--R     + 
+--R         2 2   2     2           2 2         2
+--R       (c e n x  + 2c d e n x + c d n)log(c x  + b x + a)
+--R     + 
+--R         2 2 2     2
+--R       (c e x  + 2c d e x)log(d)
+--R  /
+--R       2
+--R     2c e
+--R                                                    Type: Expression(Integer)
+--E 4262
+
+--S 4263 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4263
+
+)clear all
+
+--S 4264 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)
+--R 
+--R
+--R                  2           n
+--R   (1)  log(d (c x  + b x + a) )
+--R                                                    Type: Expression(Integer)
+--E 4264
+
+--S 4265 of 5341
+r0:=-2*n*x+1/2*b*n*log(a+b*x+c*x^2)/c+x*log(d*(a+b*x+c*x^2)^n)+_
+   n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/c
+--R 
+--R
+--R   (2)
+--R                                          +-----------+
+--R                      2           n       |          2          2c x + b
+--R       2c x log(d (c x  + b x + a) ) + 2n\|- 4a c + b  atanh(--------------)
+--R                                                              +-----------+
+--R                                                              |          2
+--R                                                             \|- 4a c + b
+--R     + 
+--R                  2
+--R       b n log(c x  + b x + a) - 4c n x
+--R  /
+--R     2c
+--R                                                    Type: Expression(Integer)
+--E 4265
+
+--S 4266 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R             +-----------+
+--R             |          2
+--R           n\|- 4a c + b
+--R        *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R               (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-----------------------------------------------------)
+--R                                      2
+--R                                   c x  + b x + a
+--R       + 
+--R                              2
+--R         (2c n x + b n)log(c x  + b x + a) + 2c x log(d) - 4c n x
+--R    /
+--R       2c
+--R     ,
+--R
+--R                               +---------+
+--R              +---------+      |        2
+--R              |        2      \|4a c - b                           2
+--R         - 2n\|4a c - b  atan(------------) + (2c n x + b n)log(c x  + b x + a)
+--R                                2c x + b
+--R       + 
+--R         2c x log(d) - 4c n x
+--R    /
+--R       2c
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4266
+
+--S 4267 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                                     +-----------+
+--R         +-----------+               |          2      2 2                    2
+--R         |          2     (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R       n\|- 4a c + b  log(-----------------------------------------------------)
+--R                                                 2
+--R                                              c x  + b x + a
+--R     + 
+--R                                            +-----------+
+--R                        2           n       |          2          2c x + b
+--R       - 2c x log(d (c x  + b x + a) ) - 2n\|- 4a c + b  atanh(--------------)
+--R                                                                +-----------+
+--R                                                                |          2
+--R                                                               \|- 4a c + b
+--R     + 
+--R                     2
+--R       2c n x log(c x  + b x + a) + 2c x log(d)
+--R  /
+--R     2c
+--R                                                    Type: Expression(Integer)
+--E 4267
+
+--S 4268 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4268
+
+--S 4269 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R                                          +-----------+
+--R                       2           n      |          2          2c x + b
+--R       - c x log(d (c x  + b x + a) ) - n\|- 4a c + b  atanh(--------------)
+--R                                                              +-----------+
+--R                                                              |          2
+--R                                                             \|- 4a c + b
+--R     + 
+--R                          +---------+
+--R         +---------+      |        2
+--R         |        2      \|4a c - b                   2
+--R     - n\|4a c - b  atan(------------) + c n x log(c x  + b x + a) + c x log(d)
+--R                           2c x + b
+--R  /
+--R     c
+--R                                                    Type: Expression(Integer)
+--E 4269
+
+--S 4270 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4270
+
+)clear all
+
+--S 4271 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)/(d+e*x)
+--R 
+--R
+--R                  2           n
+--R        log(d (c x  + b x + a) )
+--R   (1)  ------------------------
+--R                 e x + d
+--R                                                    Type: Expression(Integer)
+--E 4271
+
+--S 4272 of 5341
+--r0:=log(d+e*x)*log(d*(a+b*x+c*x^2)^n)/e-n*log(d+e*x)*_
+--  log(-e*(b+2*c*x-sqrt(b^2-4*a*c))/(2*c*d-e*(b-sqrt(b^2-4*a*c))))/e-n*_
+--  log(d+e*x)*log(-e*(b+2*c*x+sqrt(b^2-4*a*c))/(2*c*d-e*(b+_
+--  sqrt(b^2-4*a*c))))/e-n*polylog(2,2*c*(d+e*x)/(2*c*d-b*e+e*_
+--  sqrt(b^2-4*a*c)))/e-n*polylog(2,2*c*(d+e*x)/(2*c*d-e*(b+_
+--  sqrt(b^2-4*a*c))))/e
+--E 4272
+
+--S 4273 of 5341
+--a0:=integrate(t0,x)
+--E 4273
+
+--S 4274 of 5341
+--m0:=a0-r0
+--E 4274
+
+--S 4275 of 5341
+--d0:=D(m0,x)
+--E 4275
+
+)clear all
+
+--S 4276 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)/(d+e*x)^2
+--R 
+--R
+--R                  2           n
+--R        log(d (c x  + b x + a) )
+--R   (1)  ------------------------
+--R            2 2             2
+--R           e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 4276
+
+--S 4277 of 5341
+r0:=-(2*c*d-b*e)*n*log(d+e*x)/(e*(c*d^2-b*d*e+a*e^2))+1/2*(2*c*d-b*e)*_
+   n*log(a+b*x+c*x^2)/(e*(c*d^2-b*d*e+a*e^2))-log(d*(a+b*x+c*x^2)^n)/_
+   (e*(d+e*x))+n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/_
+   (c*d^2-b*d*e+a*e^2)
+--R 
+--R
+--R   (2)
+--R              2                2           2           n
+--R       (- 2a e  + 2b d e - 2c d )log(d (c x  + b x + a) )
+--R     + 
+--R                         +-----------+
+--R          2              |          2          2c x + b
+--R       (2e n x + 2d e n)\|- 4a c + b  atanh(--------------)
+--R                                             +-----------+
+--R                                             |          2
+--R                                            \|- 4a c + b
+--R     + 
+--R              2                               2          2
+--R       ((- b e  + 2c d e)n x + (- b d e + 2c d )n)log(c x  + b x + a)
+--R     + 
+--R             2                              2
+--R       ((2b e  - 4c d e)n x + (2b d e - 4c d )n)log(e x + d)
+--R  /
+--R          4         3       2 2           3       2 2       3
+--R     (2a e  - 2b d e  + 2c d e )x + 2a d e  - 2b d e  + 2c d e
+--R                                                    Type: Expression(Integer)
+--E 4277
+
+--S 4278 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                           +-----------+
+--R             2             |          2
+--R           (e n x + d e n)\|- 4a c + b
+--R        *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R               (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-----------------------------------------------------)
+--R                                      2
+--R                                   c x  + b x + a
+--R       + 
+--R                2                       2                  2
+--R         ((- b e  + 2c d e)n x + (- 2a e  + b d e)n)log(c x  + b x + a)
+--R       + 
+--R               2                              2
+--R         ((2b e  - 4c d e)n x + (2b d e - 4c d )n)log(e x + d)
+--R       + 
+--R                2                2
+--R         (- 2a e  + 2b d e - 2c d )log(d)
+--R    /
+--R            4         3       2 2           3       2 2       3
+--R       (2a e  - 2b d e  + 2c d e )x + 2a d e  - 2b d e  + 2c d e
+--R     ,
+--R
+--R                                              +---------+
+--R                             +---------+      |        2
+--R              2              |        2      \|4a c - b
+--R         (- 2e n x - 2d e n)\|4a c - b  atan(------------)
+--R                                               2c x + b
+--R       + 
+--R                2                       2                  2
+--R         ((- b e  + 2c d e)n x + (- 2a e  + b d e)n)log(c x  + b x + a)
+--R       + 
+--R               2                              2
+--R         ((2b e  - 4c d e)n x + (2b d e - 4c d )n)log(e x + d)
+--R       + 
+--R                2                2
+--R         (- 2a e  + 2b d e - 2c d )log(d)
+--R    /
+--R            4         3       2 2           3       2 2       3
+--R       (2a e  - 2b d e  + 2c d e )x + 2a d e  - 2b d e  + 2c d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4278
+
+--S 4279 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                         +-----------+
+--R           2             |          2
+--R         (e n x + d e n)\|- 4a c + b
+--R      *
+--R                        +-----------+
+--R                        |          2      2 2                    2
+--R             (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-----------------------------------------------------)
+--R                                    2
+--R                                 c x  + b x + a
+--R     + 
+--R            2                2           2           n
+--R       (2a e  - 2b d e + 2c d )log(d (c x  + b x + a) )
+--R     + 
+--R                           +-----------+
+--R            2              |          2          2c x + b
+--R       (- 2e n x - 2d e n)\|- 4a c + b  atanh(--------------)
+--R                                               +-----------+
+--R                                               |          2
+--R                                              \|- 4a c + b
+--R     + 
+--R              2                2          2
+--R       (- 2a e  + 2b d e - 2c d )n log(c x  + b x + a)
+--R     + 
+--R              2                2
+--R       (- 2a e  + 2b d e - 2c d )log(d)
+--R  /
+--R          4         3       2 2           3       2 2       3
+--R     (2a e  - 2b d e  + 2c d e )x + 2a d e  - 2b d e  + 2c d e
+--R                                                    Type: Expression(Integer)
+--E 4279
+
+--S 4280 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4280
+
+--S 4281 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           2              2           2           n
+--R       (a e  - b d e + c d )log(d (c x  + b x + a) )
+--R     + 
+--R                         +-----------+
+--R           2             |          2          2c x + b
+--R       (- e n x - d e n)\|- 4a c + b  atanh(--------------)
+--R                                             +-----------+
+--R                                             |          2
+--R                                            \|- 4a c + b
+--R     + 
+--R                                          +---------+
+--R                         +---------+      |        2
+--R           2             |        2      \|4a c - b
+--R       (- e n x - d e n)\|4a c - b  atan(------------)
+--R                                           2c x + b
+--R     + 
+--R             2              2          2
+--R       (- a e  + b d e - c d )n log(c x  + b x + a)
+--R     + 
+--R             2              2
+--R       (- a e  + b d e - c d )log(d)
+--R  /
+--R         4        3      2 2          3      2 2      3
+--R     (a e  - b d e  + c d e )x + a d e  - b d e  + c d e
+--R                                                    Type: Expression(Integer)
+--E 4281
+
+--S 4282 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4282
+
+)clear all
+
+--S 4283 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)/(d+e*x)^3
+--R 
+--R
+--R                    2           n
+--R          log(d (c x  + b x + a) )
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 4283
+
+--S 4284 of 5341
+r0:=1/2*(2*c*d-b*e)*n/(e*(c*d^2-b*d*e+a*e^2)*(d+e*x))-1/2*(2*c^2*d^2+_
+   b^2*e^2-2*c*e*(b*d+a*e))*n*log(d+e*x)/(e*(c*d^2-b*d*e+a*e^2)^2)+_
+   1/4*(2*c^2*d^2+b^2*e^2-2*c*e*(b*d+a*e))*n*log(a+b*x+c*x^2)/(e*(c*d^2-_
+   b*d*e+a*e^2)^2)-1/2*log(d*(a+b*x+c*x^2)^n)/(e*(d+e*x)^2)+1/2*(2*c*d-_
+   b*e)*n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/(c*d^2-_
+   b*d*e+a*e^2)^2
+--R 
+--R
+--R   (2)
+--R              2 4           3               2  2 2         3      2 4
+--R         (- 2a e  + 4a b d e  + (- 4a c - 2b )d e  + 4b c d e - 2c d )
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                  4         3    2            3       2 2
+--R           (- 2b e  + 4c d e )n x  + (- 4b d e  + 8c d e )n x
+--R         + 
+--R                  2 2       3
+--R           (- 2b d e  + 4c d e)n
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                       2  4           3     2 2 2    2
+--R           ((- 2a c + b )e  - 2b c d e  + 2c d e )n x
+--R         + 
+--R                        2    3         2 2     2 3
+--R           ((- 4a c + 2b )d e  - 4b c d e  + 4c d e)n x
+--R         + 
+--R                       2  2 2         3      2 4
+--R           ((- 2a c + b )d e  - 2b c d e + 2c d )n
+--R      *
+--R                2
+--R         log(c x  + b x + a)
+--R     + 
+--R                      2  4           3     2 2 2    2
+--R           ((4a c - 2b )e  + 4b c d e  - 4c d e )n x
+--R         + 
+--R                      2    3         2 2     2 3
+--R           ((8a c - 4b )d e  + 8b c d e  - 8c d e)n x
+--R         + 
+--R                      2  2 2         3      2 4
+--R           ((4a c - 2b )d e  + 4b c d e - 4c d )n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R                4             2    3         2 2     2 3
+--R       (- 2a b e  + (4a c + 2b )d e  - 6b c d e  + 4c d e)n x
+--R     + 
+--R                  3             2  2 2         3      2 4
+--R       (- 2a b d e  + (4a c + 2b )d e  - 6b c d e + 4c d )n
+--R  /
+--R          2 7           6             2  2 5         3 4     2 4 3  2
+--R       (4a e  - 8a b d e  + (8a c + 4b )d e  - 8b c d e  + 4c d e )x
+--R     + 
+--R          2   6          2 5              2  3 4          4 3     2 5 2
+--R       (8a d e  - 16a b d e  + (16a c + 8b )d e  - 16b c d e  + 8c d e )x
+--R     + 
+--R         2 2 5         3 4             2  4 3         5 2     2 6
+--R       4a d e  - 8a b d e  + (8a c + 4b )d e  - 8b c d e  + 4c d e
+--R                                                    Type: Expression(Integer)
+--E 4284
+
+--S 4285 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                4         3    2          3       2 2           2 2       3
+--R           ((b e  - 2c d e )n x  + (2b d e  - 4c d e )n x + (b d e  - 2c d e)n)
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R        *
+--R                            +-----------+
+--R                            |          2      2 2                    2
+--R               (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-------------------------------------------------------)
+--R                                       2
+--R                                    c x  + b x + a
+--R       + 
+--R                         2  4           3     2 2 2    2
+--R             ((- 2a c + b )e  - 2b c d e  + 2c d e )n x
+--R           + 
+--R                          2    3         2 2     2 3
+--R             ((- 4a c + 2b )d e  - 4b c d e  + 4c d e)n x
+--R           + 
+--R                  2 4           3              2  2 2         3
+--R             (- 2a e  + 4a b d e  + (- 6a c - b )d e  + 2b c d e)n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R                        2  4           3     2 2 2    2
+--R             ((4a c - 2b )e  + 4b c d e  - 4c d e )n x
+--R           + 
+--R                        2    3         2 2     2 3
+--R             ((8a c - 4b )d e  + 8b c d e  - 8c d e)n x
+--R           + 
+--R                        2  2 2         3      2 4
+--R             ((4a c - 2b )d e  + 4b c d e - 4c d )n
+--R        *
+--R           log(e x + d)
+--R       + 
+--R              2 4           3               2  2 2         3      2 4
+--R         (- 2a e  + 4a b d e  + (- 4a c - 2b )d e  + 4b c d e - 2c d )log(d)
+--R       + 
+--R                  4             2    3         2 2     2 3
+--R         (- 2a b e  + (4a c + 2b )d e  - 6b c d e  + 4c d e)n x
+--R       + 
+--R                    3             2  2 2         3      2 4
+--R         (- 2a b d e  + (4a c + 2b )d e  - 6b c d e + 4c d )n
+--R    /
+--R            2 7           6             2  2 5         3 4     2 4 3  2
+--R         (4a e  - 8a b d e  + (8a c + 4b )d e  - 8b c d e  + 4c d e )x
+--R       + 
+--R            2   6          2 5              2  3 4          4 3     2 5 2
+--R         (8a d e  - 16a b d e  + (16a c + 8b )d e  - 16b c d e  + 8c d e )x
+--R       + 
+--R           2 2 5         3 4             2  4 3         5 2     2 6
+--R         4a d e  - 8a b d e  + (8a c + 4b )d e  - 8b c d e  + 4c d e
+--R     ,
+--R
+--R                    4         3    2          3       2 2
+--R               (2b e  - 4c d e )n x  + (4b d e  - 8c d e )n x
+--R             + 
+--R                    2 2       3
+--R               (2b d e  - 4c d e)n
+--R        *
+--R                             +---------+
+--R            +---------+      |        2
+--R            |        2      \|4a c - b
+--R           \|4a c - b  atan(------------)
+--R                              2c x + b
+--R       + 
+--R                         2  4           3     2 2 2    2
+--R             ((- 2a c + b )e  - 2b c d e  + 2c d e )n x
+--R           + 
+--R                          2    3         2 2     2 3
+--R             ((- 4a c + 2b )d e  - 4b c d e  + 4c d e)n x
+--R           + 
+--R                  2 4           3              2  2 2         3
+--R             (- 2a e  + 4a b d e  + (- 6a c - b )d e  + 2b c d e)n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R                        2  4           3     2 2 2    2
+--R             ((4a c - 2b )e  + 4b c d e  - 4c d e )n x
+--R           + 
+--R                        2    3         2 2     2 3
+--R             ((8a c - 4b )d e  + 8b c d e  - 8c d e)n x
+--R           + 
+--R                        2  2 2         3      2 4
+--R             ((4a c - 2b )d e  + 4b c d e - 4c d )n
+--R        *
+--R           log(e x + d)
+--R       + 
+--R              2 4           3               2  2 2         3      2 4
+--R         (- 2a e  + 4a b d e  + (- 4a c - 2b )d e  + 4b c d e - 2c d )log(d)
+--R       + 
+--R                  4             2    3         2 2     2 3
+--R         (- 2a b e  + (4a c + 2b )d e  - 6b c d e  + 4c d e)n x
+--R       + 
+--R                    3             2  2 2         3      2 4
+--R         (- 2a b d e  + (4a c + 2b )d e  - 6b c d e + 4c d )n
+--R    /
+--R            2 7           6             2  2 5         3 4     2 4 3  2
+--R         (4a e  - 8a b d e  + (8a c + 4b )d e  - 8b c d e  + 4c d e )x
+--R       + 
+--R            2   6          2 5              2  3 4          4 3     2 5 2
+--R         (8a d e  - 16a b d e  + (16a c + 8b )d e  - 16b c d e  + 8c d e )x
+--R       + 
+--R           2 2 5         3 4             2  4 3         5 2     2 6
+--R         4a d e  - 8a b d e  + (8a c + 4b )d e  - 8b c d e  + 4c d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4285
+
+--S 4286 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R            2 4           3             2  2 2         3      2 4
+--R         (2a e  - 4a b d e  + (4a c + 2b )d e  - 4b c d e + 2c d )
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R              4         3    2          3       2 2           2 2       3
+--R         ((b e  - 2c d e )n x  + (2b d e  - 4c d e )n x + (b d e  - 2c d e)n)
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R      *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R             (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-------------------------------------------------------)
+--R                                     2
+--R                                  c x  + b x + a
+--R     + 
+--R               4         3    2          3       2 2            2 2       3
+--R         ((2b e  - 4c d e )n x  + (4b d e  - 8c d e )n x + (2b d e  - 4c d e)n)
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R              2 4           3               2  2 2         3      2 4
+--R         (- 2a e  + 4a b d e  + (- 4a c - 2b )d e  + 4b c d e - 2c d )n
+--R      *
+--R                2
+--R         log(c x  + b x + a)
+--R     + 
+--R            2 4           3               2  2 2         3      2 4
+--R       (- 2a e  + 4a b d e  + (- 4a c - 2b )d e  + 4b c d e - 2c d )log(d)
+--R  /
+--R          2 7           6             2  2 5         3 4     2 4 3  2
+--R       (4a e  - 8a b d e  + (8a c + 4b )d e  - 8b c d e  + 4c d e )x
+--R     + 
+--R          2   6          2 5              2  3 4          4 3     2 5 2
+--R       (8a d e  - 16a b d e  + (16a c + 8b )d e  - 16b c d e  + 8c d e )x
+--R     + 
+--R         2 2 5         3 4             2  4 3         5 2     2 6
+--R       4a d e  - 8a b d e  + (8a c + 4b )d e  - 8b c d e  + 4c d e
+--R                                                    Type: Expression(Integer)
+--E 4286
+
+--S 4287 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4287
+
+--S 4288 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R           2 4           3            2  2 2         3     2 4
+--R         (a e  - 2a b d e  + (2a c + b )d e  - 2b c d e + c d )
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R              4         3    2          3       2 2           2 2       3
+--R         ((b e  - 2c d e )n x  + (2b d e  - 4c d e )n x + (b d e  - 2c d e)n)
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R              4         3    2          3       2 2           2 2       3
+--R         ((b e  - 2c d e )n x  + (2b d e  - 4c d e )n x + (b d e  - 2c d e)n)
+--R      *
+--R                           +---------+
+--R          +---------+      |        2
+--R          |        2      \|4a c - b
+--R         \|4a c - b  atan(------------)
+--R                            2c x + b
+--R     + 
+--R             2 4           3              2  2 2         3     2 4
+--R         (- a e  + 2a b d e  + (- 2a c - b )d e  + 2b c d e - c d )n
+--R      *
+--R                2
+--R         log(c x  + b x + a)
+--R     + 
+--R           2 4           3              2  2 2         3     2 4
+--R       (- a e  + 2a b d e  + (- 2a c - b )d e  + 2b c d e - c d )log(d)
+--R  /
+--R          2 7           6             2  2 5         3 4     2 4 3  2
+--R       (2a e  - 4a b d e  + (4a c + 2b )d e  - 4b c d e  + 2c d e )x
+--R     + 
+--R          2   6         2 5             2  3 4         4 3     2 5 2       2 2 5
+--R       (4a d e  - 8a b d e  + (8a c + 4b )d e  - 8b c d e  + 4c d e )x + 2a d e
+--R     + 
+--R               3 4             2  4 3         5 2     2 6
+--R       - 4a b d e  + (4a c + 2b )d e  - 4b c d e  + 2c d e
+--R                                                    Type: Expression(Integer)
+--E 4288
+
+--S 4289 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4289
+
+)clear all
+
+--S 4290 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)/(d+e*x)^4
+--R 
+--R
+--R                         2           n
+--R               log(d (c x  + b x + a) )
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 4290
+
+--S 4291 of 5341
+r0:=1/6*(2*c*d-b*e)*n/(e*(c*d^2-b*d*e+a*e^2)*(d+e*x)^2)+1/3*(2*c^2*d^2+_
+   b^2*e^2-2*c*e*(b*d+a*e))*n/(e*(c*d^2-b*d*e+a*e^2)^2*(d+e*x))-1/3*(2*c*d-_
+   b*e)*(c^2*d^2+b^2*e^2-c*e*(b*d+3*a*e))*n*log(d+e*x)/(e*(c*d^2-b*d*e+_
+   a*e^2)^3)+1/6*(2*c*d-b*e)*(c^2*d^2+b^2*e^2-c*e*(b*d+3*a*e))*n*log(a+b*x+_
+   c*x^2)/(e*(c*d^2-b*d*e+a*e^2)^3)-1/3*log(d*(a+b*x+c*x^2)^n)/(e*(d+e*x)^3)+_
+   1/3*(3*c^2*d^2+b^2*e^2-c*e*(3*b*d+a*e))*n*atanh((b+2*c*x)/sqrt(b^2-_
+   4*a*c))*sqrt(b^2-4*a*c)/(c*d^2-b*d*e+a*e^2)^3
+--R 
+--R
+--R   (2)
+--R               3 6     2     5        2        2  2 4                3  3 3
+--R           - 2a e  + 6a b d e  + (- 6a c - 6a b )d e  + (12a b c + 2b )d e
+--R         + 
+--R                  2     2   4 2       2 5      3 6
+--R           (- 6a c  - 6b c)d e  + 6b c d e - 2c d
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                        2  6           5     2 2 4    3
+--R           ((- 2a c + 2b )e  - 6b c d e  + 6c d e )n x
+--R         + 
+--R                        2    5          2 4      2 3 3    2
+--R           ((- 6a c + 6b )d e  - 18b c d e  + 18c d e )n x
+--R         + 
+--R                        2  2 4          3 3      2 4 2
+--R           ((- 6a c + 6b )d e  - 18b c d e  + 18c d e )n x
+--R         + 
+--R                        2  3 3         4 2     2 5
+--R           ((- 2a c + 2b )d e  - 6b c d e  + 6c d e)n
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                       3  6          2     2     5       2 2 4     3 3 3    3
+--R           ((3a b c - b )e  + (- 6a c  + 3b c)d e  - 3b c d e  + 2c d e )n x
+--R         + 
+--R                          3    5           2     2   2 4       2 3 3     3 4 2
+--R             ((9a b c - 3b )d e  + (- 18a c  + 9b c)d e  - 9b c d e  + 6c d e )n
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        3  2 4           2     2   3 3       2 4 2     3 5
+--R           ((9a b c - 3b )d e  + (- 18a c  + 9b c)d e  - 9b c d e  + 6c d e)n x
+--R         + 
+--R                       3  3 3          2     2   4 2       2 5      3 6
+--R           ((3a b c - b )d e  + (- 6a c  + 3b c)d e  - 3b c d e + 2c d )n
+--R      *
+--R                2
+--R         log(c x  + b x + a)
+--R     + 
+--R                          3  6         2     2     5       2 2 4     3 3 3    3
+--R           ((- 6a b c + 2b )e  + (12a c  - 6b c)d e  + 6b c d e  - 4c d e )n x
+--R         + 
+--R                              3    5         2      2   2 4        2 3 3
+--R               (- 18a b c + 6b )d e  + (36a c  - 18b c)d e  + 18b c d e
+--R             + 
+--R                    3 4 2
+--R               - 12c d e
+--R          *
+--R                2
+--R             n x
+--R         + 
+--R                                3  2 4         2      2   3 3        2 4 2
+--R                 (- 18a b c + 6b )d e  + (36a c  - 18b c)d e  + 18b c d e
+--R               + 
+--R                      3 5
+--R                 - 12c d e
+--R          *
+--R             n x
+--R         + 
+--R                          3  3 3         2     2   4 2       2 5      3 6
+--R           ((- 6a b c + 2b )d e  + (12a c  - 6b c)d e  + 6b c d e - 4c d )n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R             2        2  6     3   5     2   2 4       2 3 3     3 4 2    2
+--R       ((- 4a c + 2a b )e  - 2b d e  + 6b c d e  - 8b c d e  + 4c d e )n x
+--R     + 
+--R              2   6        2        2    5                 3  2 4
+--R           - a b e  + (- 6a c + 6a b )d e  + (- 6a b c - 5b )d e
+--R         + 
+--R                2      2   3 3        2 4 2      3 5
+--R           (4a c  + 16b c)d e  - 21b c d e  + 10c d e
+--R      *
+--R         n x
+--R     + 
+--R              2     5        2        2  2 4                 3  3 3
+--R           - a b d e  + (- 2a c + 4a b )d e  + (- 6a b c - 3b )d e
+--R         + 
+--R                2      2   4 2        2 5      3 6
+--R           (4a c  + 10b c)d e  - 13b c d e + 6c d
+--R      *
+--R         n
+--R  /
+--R             3 10      2     9       2         2  2 8                  3  3 7
+--R           6a e   - 18a b d e  + (18a c + 18a b )d e  + (- 36a b c - 6b )d e
+--R         + 
+--R                 2      2   4 6        2 5 5     3 6 4
+--R           (18a c  + 18b c)d e  - 18b c d e  + 6c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R              3   9      2   2 8       2         2  3 7
+--R           18a d e  - 54a b d e  + (54a c + 54a b )d e
+--R         + 
+--R                          3  4 6         2      2   5 5        2 6 4      3 7 3
+--R         (- 108a b c - 18b )d e  + (54a c  + 54b c)d e  - 54b c d e  + 18c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              3 2 8      2   3 7       2         2  4 6
+--R           18a d e  - 54a b d e  + (54a c + 54a b )d e
+--R         + 
+--R                          3  5 5         2      2   6 4        2 7 3      3 8 2
+--R         (- 108a b c - 18b )d e  + (54a c  + 54b c)d e  - 54b c d e  + 18c d e
+--R      *
+--R         x
+--R     + 
+--R         3 3 7      2   4 6       2         2  5 5                  3  6 4
+--R       6a d e  - 18a b d e  + (18a c + 18a b )d e  + (- 36a b c - 6b )d e
+--R     + 
+--R             2      2   7 3        2 8 2     3 9
+--R       (18a c  + 18b c)d e  - 18b c d e  + 6c d e
+--R                                                    Type: Expression(Integer)
+--E 4291
+
+--S 4292 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                      2  6           5     2 2 4    3
+--R             ((a c - b )e  + 3b c d e  - 3c d e )n x
+--R           + 
+--R                        2    5         2 4     2 3 3    2
+--R             ((3a c - 3b )d e  + 9b c d e  - 9c d e )n x
+--R           + 
+--R                        2  2 4         3 3     2 4 2
+--R             ((3a c - 3b )d e  + 9b c d e  - 9c d e )n x
+--R           + 
+--R                      2  3 3         4 2     2 5
+--R             ((a c - b )d e  + 3b c d e  - 3c d e)n
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R        *
+--R                            +-----------+
+--R                            |          2      2 2                    2
+--R               (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-------------------------------------------------------)
+--R                                       2
+--R                                    c x  + b x + a
+--R       + 
+--R                         3  6          2     2     5       2 2 4     3 3 3    3
+--R             ((3a b c - b )e  + (- 6a c  + 3b c)d e  - 3b c d e  + 2c d e )n x
+--R           + 
+--R                               3    5           2     2   2 4       2 3 3
+--R                   (9a b c - 3b )d e  + (- 18a c  + 9b c)d e  - 9b c d e
+--R                 + 
+--R                     3 4 2
+--R                   6c d e
+--R            *
+--R                  2
+--R               n x
+--R           + 
+--R                            3  2 4           2     2   3 3       2 4 2     3 5
+--R               ((9a b c - 3b )d e  + (- 18a c  + 9b c)d e  - 9b c d e  + 6c d e)
+--R            *
+--R               n x
+--R           + 
+--R                     3 6     2     5        2        2  2 4               3  3 3
+--R                 - 2a e  + 6a b d e  + (- 6a c - 6a b )d e  + (15a b c + b )d e
+--R               + 
+--R                         2     2   4 2       2 5
+--R                 (- 12a c  - 3b c)d e  + 3b c d e
+--R            *
+--R               n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R                              3  6         2     2     5       2 2 4     3 3 3
+--R               ((- 6a b c + 2b )e  + (12a c  - 6b c)d e  + 6b c d e  - 4c d e )n
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                                3    5         2      2   2 4        2 3 3
+--R                 (- 18a b c + 6b )d e  + (36a c  - 18b c)d e  + 18b c d e
+--R               + 
+--R                      3 4 2
+--R                 - 12c d e
+--R            *
+--R                  2
+--R               n x
+--R           + 
+--R                                3  2 4         2      2   3 3        2 4 2
+--R                 (- 18a b c + 6b )d e  + (36a c  - 18b c)d e  + 18b c d e
+--R               + 
+--R                      3 5
+--R                 - 12c d e
+--R            *
+--R               n x
+--R           + 
+--R                            3  3 3         2     2   4 2       2 5      3 6
+--R             ((- 6a b c + 2b )d e  + (12a c  - 6b c)d e  + 6b c d e - 4c d )n
+--R        *
+--R           log(e x + d)
+--R       + 
+--R                 3 6     2     5        2        2  2 4                3  3 3
+--R             - 2a e  + 6a b d e  + (- 6a c - 6a b )d e  + (12a b c + 2b )d e
+--R           + 
+--R                    2     2   4 2       2 5      3 6
+--R             (- 6a c  - 6b c)d e  + 6b c d e - 2c d
+--R        *
+--R           log(d)
+--R       + 
+--R               2        2  6     3   5     2   2 4       2 3 3     3 4 2    2
+--R         ((- 4a c + 2a b )e  - 2b d e  + 6b c d e  - 8b c d e  + 4c d e )n x
+--R       + 
+--R                2   6        2        2    5                 3  2 4
+--R             - a b e  + (- 6a c + 6a b )d e  + (- 6a b c - 5b )d e
+--R           + 
+--R                  2      2   3 3        2 4 2      3 5
+--R             (4a c  + 16b c)d e  - 21b c d e  + 10c d e
+--R        *
+--R           n x
+--R       + 
+--R                2     5        2        2  2 4                 3  3 3
+--R             - a b d e  + (- 2a c + 4a b )d e  + (- 6a b c - 3b )d e
+--R           + 
+--R                  2      2   4 2        2 5      3 6
+--R             (4a c  + 10b c)d e  - 13b c d e + 6c d
+--R        *
+--R           n
+--R    /
+--R               3 10      2     9       2         2  2 8                  3  3 7
+--R             6a e   - 18a b d e  + (18a c + 18a b )d e  + (- 36a b c - 6b )d e
+--R           + 
+--R                   2      2   4 6        2 5 5     3 6 4
+--R             (18a c  + 18b c)d e  - 18b c d e  + 6c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                3   9      2   2 8       2         2  3 7
+--R             18a d e  - 54a b d e  + (54a c + 54a b )d e
+--R           + 
+--R                              3  4 6         2      2   5 5        2 6 4
+--R             (- 108a b c - 18b )d e  + (54a c  + 54b c)d e  - 54b c d e
+--R           + 
+--R                3 7 3
+--R             18c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                3 2 8      2   3 7       2         2  4 6
+--R             18a d e  - 54a b d e  + (54a c + 54a b )d e
+--R           + 
+--R                              3  5 5         2      2   6 4        2 7 3
+--R             (- 108a b c - 18b )d e  + (54a c  + 54b c)d e  - 54b c d e
+--R           + 
+--R                3 8 2
+--R             18c d e
+--R        *
+--R           x
+--R       + 
+--R           3 3 7      2   4 6       2         2  5 5                  3  6 4
+--R         6a d e  - 18a b d e  + (18a c + 18a b )d e  + (- 36a b c - 6b )d e
+--R       + 
+--R               2      2   7 3        2 8 2     3 9
+--R         (18a c  + 18b c)d e  - 18b c d e  + 6c d e
+--R     ,
+--R
+--R                        2  6           5     2 2 4    3
+--R             ((2a c - 2b )e  + 6b c d e  - 6c d e )n x
+--R           + 
+--R                        2    5          2 4      2 3 3    2
+--R             ((6a c - 6b )d e  + 18b c d e  - 18c d e )n x
+--R           + 
+--R                        2  2 4          3 3      2 4 2
+--R             ((6a c - 6b )d e  + 18b c d e  - 18c d e )n x
+--R           + 
+--R                        2  3 3         4 2     2 5
+--R             ((2a c - 2b )d e  + 6b c d e  - 6c d e)n
+--R        *
+--R                             +---------+
+--R            +---------+      |        2
+--R            |        2      \|4a c - b
+--R           \|4a c - b  atan(------------)
+--R                              2c x + b
+--R       + 
+--R                         3  6          2     2     5       2 2 4     3 3 3    3
+--R             ((3a b c - b )e  + (- 6a c  + 3b c)d e  - 3b c d e  + 2c d e )n x
+--R           + 
+--R                               3    5           2     2   2 4       2 3 3
+--R                   (9a b c - 3b )d e  + (- 18a c  + 9b c)d e  - 9b c d e
+--R                 + 
+--R                     3 4 2
+--R                   6c d e
+--R            *
+--R                  2
+--R               n x
+--R           + 
+--R                            3  2 4           2     2   3 3       2 4 2     3 5
+--R               ((9a b c - 3b )d e  + (- 18a c  + 9b c)d e  - 9b c d e  + 6c d e)
+--R            *
+--R               n x
+--R           + 
+--R                     3 6     2     5        2        2  2 4               3  3 3
+--R                 - 2a e  + 6a b d e  + (- 6a c - 6a b )d e  + (15a b c + b )d e
+--R               + 
+--R                         2     2   4 2       2 5
+--R                 (- 12a c  - 3b c)d e  + 3b c d e
+--R            *
+--R               n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R                              3  6         2     2     5       2 2 4     3 3 3
+--R               ((- 6a b c + 2b )e  + (12a c  - 6b c)d e  + 6b c d e  - 4c d e )n
+--R            *
+--R                3
+--R               x
+--R           + 
+--R                                3    5         2      2   2 4        2 3 3
+--R                 (- 18a b c + 6b )d e  + (36a c  - 18b c)d e  + 18b c d e
+--R               + 
+--R                      3 4 2
+--R                 - 12c d e
+--R            *
+--R                  2
+--R               n x
+--R           + 
+--R                                3  2 4         2      2   3 3        2 4 2
+--R                 (- 18a b c + 6b )d e  + (36a c  - 18b c)d e  + 18b c d e
+--R               + 
+--R                      3 5
+--R                 - 12c d e
+--R            *
+--R               n x
+--R           + 
+--R                            3  3 3         2     2   4 2       2 5      3 6
+--R             ((- 6a b c + 2b )d e  + (12a c  - 6b c)d e  + 6b c d e - 4c d )n
+--R        *
+--R           log(e x + d)
+--R       + 
+--R                 3 6     2     5        2        2  2 4                3  3 3
+--R             - 2a e  + 6a b d e  + (- 6a c - 6a b )d e  + (12a b c + 2b )d e
+--R           + 
+--R                    2     2   4 2       2 5      3 6
+--R             (- 6a c  - 6b c)d e  + 6b c d e - 2c d
+--R        *
+--R           log(d)
+--R       + 
+--R               2        2  6     3   5     2   2 4       2 3 3     3 4 2    2
+--R         ((- 4a c + 2a b )e  - 2b d e  + 6b c d e  - 8b c d e  + 4c d e )n x
+--R       + 
+--R                2   6        2        2    5                 3  2 4
+--R             - a b e  + (- 6a c + 6a b )d e  + (- 6a b c - 5b )d e
+--R           + 
+--R                  2      2   3 3        2 4 2      3 5
+--R             (4a c  + 16b c)d e  - 21b c d e  + 10c d e
+--R        *
+--R           n x
+--R       + 
+--R                2     5        2        2  2 4                 3  3 3
+--R             - a b d e  + (- 2a c + 4a b )d e  + (- 6a b c - 3b )d e
+--R           + 
+--R                  2      2   4 2        2 5      3 6
+--R             (4a c  + 10b c)d e  - 13b c d e + 6c d
+--R        *
+--R           n
+--R    /
+--R               3 10      2     9       2         2  2 8                  3  3 7
+--R             6a e   - 18a b d e  + (18a c + 18a b )d e  + (- 36a b c - 6b )d e
+--R           + 
+--R                   2      2   4 6        2 5 5     3 6 4
+--R             (18a c  + 18b c)d e  - 18b c d e  + 6c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                3   9      2   2 8       2         2  3 7
+--R             18a d e  - 54a b d e  + (54a c + 54a b )d e
+--R           + 
+--R                              3  4 6         2      2   5 5        2 6 4
+--R             (- 108a b c - 18b )d e  + (54a c  + 54b c)d e  - 54b c d e
+--R           + 
+--R                3 7 3
+--R             18c d e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                3 2 8      2   3 7       2         2  4 6
+--R             18a d e  - 54a b d e  + (54a c + 54a b )d e
+--R           + 
+--R                              3  5 5         2      2   6 4        2 7 3
+--R             (- 108a b c - 18b )d e  + (54a c  + 54b c)d e  - 54b c d e
+--R           + 
+--R                3 8 2
+--R             18c d e
+--R        *
+--R           x
+--R       + 
+--R           3 3 7      2   4 6       2         2  5 5                  3  6 4
+--R         6a d e  - 18a b d e  + (18a c + 18a b )d e  + (- 36a b c - 6b )d e
+--R       + 
+--R               2      2   7 3        2 8 2     3 9
+--R         (18a c  + 18b c)d e  - 18b c d e  + 6c d e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4292
+
+--S 4293 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R             3 6     2     5      2        2  2 4                  3  3 3
+--R           2a e  - 6a b d e  + (6a c + 6a b )d e  + (- 12a b c - 2b )d e
+--R         + 
+--R                2     2   4 2       2 5      3 6
+--R           (6a c  + 6b c)d e  - 6b c d e + 2c d
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                    2  6           5     2 2 4    3
+--R           ((a c - b )e  + 3b c d e  - 3c d e )n x
+--R         + 
+--R                      2    5         2 4     2 3 3    2
+--R           ((3a c - 3b )d e  + 9b c d e  - 9c d e )n x
+--R         + 
+--R                      2  2 4         3 3     2 4 2
+--R           ((3a c - 3b )d e  + 9b c d e  - 9c d e )n x
+--R         + 
+--R                    2  3 3         4 2     2 5
+--R           ((a c - b )d e  + 3b c d e  - 3c d e)n
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R      *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R             (- 2c x - b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R         log(-------------------------------------------------------)
+--R                                     2
+--R                                  c x  + b x + a
+--R     + 
+--R                      2  6           5     2 2 4    3
+--R           ((2a c - 2b )e  + 6b c d e  - 6c d e )n x
+--R         + 
+--R                      2    5          2 4      2 3 3    2
+--R           ((6a c - 6b )d e  + 18b c d e  - 18c d e )n x
+--R         + 
+--R                      2  2 4          3 3      2 4 2
+--R           ((6a c - 6b )d e  + 18b c d e  - 18c d e )n x
+--R         + 
+--R                      2  3 3         4 2     2 5
+--R           ((2a c - 2b )d e  + 6b c d e  - 6c d e)n
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R               3 6     2     5        2        2  2 4                3  3 3
+--R           - 2a e  + 6a b d e  + (- 6a c - 6a b )d e  + (12a b c + 2b )d e
+--R         + 
+--R                  2     2   4 2       2 5      3 6
+--R           (- 6a c  - 6b c)d e  + 6b c d e - 2c d
+--R      *
+--R                  2
+--R         n log(c x  + b x + a)
+--R     + 
+--R               3 6     2     5        2        2  2 4                3  3 3
+--R           - 2a e  + 6a b d e  + (- 6a c - 6a b )d e  + (12a b c + 2b )d e
+--R         + 
+--R                  2     2   4 2       2 5      3 6
+--R           (- 6a c  - 6b c)d e  + 6b c d e - 2c d
+--R      *
+--R         log(d)
+--R  /
+--R             3 10      2     9       2         2  2 8                  3  3 7
+--R           6a e   - 18a b d e  + (18a c + 18a b )d e  + (- 36a b c - 6b )d e
+--R         + 
+--R                 2      2   4 6        2 5 5     3 6 4
+--R           (18a c  + 18b c)d e  - 18b c d e  + 6c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R              3   9      2   2 8       2         2  3 7
+--R           18a d e  - 54a b d e  + (54a c + 54a b )d e
+--R         + 
+--R                          3  4 6         2      2   5 5        2 6 4      3 7 3
+--R         (- 108a b c - 18b )d e  + (54a c  + 54b c)d e  - 54b c d e  + 18c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              3 2 8      2   3 7       2         2  4 6
+--R           18a d e  - 54a b d e  + (54a c + 54a b )d e
+--R         + 
+--R                          3  5 5         2      2   6 4        2 7 3      3 8 2
+--R         (- 108a b c - 18b )d e  + (54a c  + 54b c)d e  - 54b c d e  + 18c d e
+--R      *
+--R         x
+--R     + 
+--R         3 3 7      2   4 6       2         2  5 5                  3  6 4
+--R       6a d e  - 18a b d e  + (18a c + 18a b )d e  + (- 36a b c - 6b )d e
+--R     + 
+--R             2      2   7 3        2 8 2     3 9
+--R       (18a c  + 18b c)d e  - 18b c d e  + 6c d e
+--R                                                    Type: Expression(Integer)
+--E 4293
+
+--S 4294 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4294
+
+--S 4295 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            3 6     2     5      2        2  2 4                3  3 3
+--R           a e  - 3a b d e  + (3a c + 3a b )d e  + (- 6a b c - b )d e
+--R         + 
+--R                2     2   4 2       2 5     3 6
+--R           (3a c  + 3b c)d e  - 3b c d e + c d
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                    2  6           5     2 2 4    3
+--R           ((a c - b )e  + 3b c d e  - 3c d e )n x
+--R         + 
+--R                      2    5         2 4     2 3 3    2
+--R           ((3a c - 3b )d e  + 9b c d e  - 9c d e )n x
+--R         + 
+--R                      2  2 4         3 3     2 4 2
+--R           ((3a c - 3b )d e  + 9b c d e  - 9c d e )n x
+--R         + 
+--R                    2  3 3         4 2     2 5
+--R           ((a c - b )d e  + 3b c d e  - 3c d e)n
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                    2  6           5     2 2 4    3
+--R           ((a c - b )e  + 3b c d e  - 3c d e )n x
+--R         + 
+--R                      2    5         2 4     2 3 3    2
+--R           ((3a c - 3b )d e  + 9b c d e  - 9c d e )n x
+--R         + 
+--R                      2  2 4         3 3     2 4 2
+--R           ((3a c - 3b )d e  + 9b c d e  - 9c d e )n x
+--R         + 
+--R                    2  3 3         4 2     2 5
+--R           ((a c - b )d e  + 3b c d e  - 3c d e)n
+--R      *
+--R                           +---------+
+--R          +---------+      |        2
+--R          |        2      \|4a c - b
+--R         \|4a c - b  atan(------------)
+--R                            2c x + b
+--R     + 
+--R              3 6     2     5        2        2  2 4              3  3 3
+--R           - a e  + 3a b d e  + (- 3a c - 3a b )d e  + (6a b c + b )d e
+--R         + 
+--R                  2     2   4 2       2 5     3 6
+--R           (- 3a c  - 3b c)d e  + 3b c d e - c d
+--R      *
+--R                  2
+--R         n log(c x  + b x + a)
+--R     + 
+--R              3 6     2     5        2        2  2 4              3  3 3
+--R           - a e  + 3a b d e  + (- 3a c - 3a b )d e  + (6a b c + b )d e
+--R         + 
+--R                  2     2   4 2       2 5     3 6
+--R           (- 3a c  - 3b c)d e  + 3b c d e - c d
+--R      *
+--R         log(d)
+--R  /
+--R             3 10     2     9      2        2  2 8                  3  3 7
+--R           3a e   - 9a b d e  + (9a c + 9a b )d e  + (- 18a b c - 3b )d e
+--R         + 
+--R                2     2   4 6       2 5 5     3 6 4
+--R           (9a c  + 9b c)d e  - 9b c d e  + 3c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R             3   9      2   2 8       2         2  3 7                  3  4 6
+--R           9a d e  - 27a b d e  + (27a c + 27a b )d e  + (- 54a b c - 9b )d e
+--R         + 
+--R                 2      2   5 5        2 6 4     3 7 3
+--R           (27a c  + 27b c)d e  - 27b c d e  + 9c d e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R             3 2 8      2   3 7       2         2  4 6                  3  5 5
+--R           9a d e  - 27a b d e  + (27a c + 27a b )d e  + (- 54a b c - 9b )d e
+--R         + 
+--R                 2      2   6 4        2 7 3     3 8 2
+--R           (27a c  + 27b c)d e  - 27b c d e  + 9c d e
+--R      *
+--R         x
+--R     + 
+--R         3 3 7     2   4 6      2        2  5 5                  3  6 4
+--R       3a d e  - 9a b d e  + (9a c + 9a b )d e  + (- 18a b c - 3b )d e
+--R     + 
+--R            2     2   7 3       2 8 2     3 9
+--R       (9a c  + 9b c)d e  - 9b c d e  + 3c d e
+--R                                                    Type: Expression(Integer)
+--E 4295
+
+--S 4296 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4296
+
+)clear all
+
+--S 4297 of 5341
+t0:=log(d*(a+b*x+c*x^2)^n)/(d+e*x)^5
+--R 
+--R
+--R                               2           n
+--R                     log(d (c x  + b x + a) )
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                                    Type: Expression(Integer)
+--E 4297
+
+--S 4298 of 5341
+r0:=1/12*(2*c*d-b*e)*n/(e*(c*d^2-b*d*e+a*e^2)*(d+e*x)^3)+1/8*(2*c^2*d^2+_
+   b^2*e^2-2*c*e*(b*d+a*e))*n/(e*(c*d^2-b*d*e+a*e^2)^2*(d+e*x)^2)+_
+   1/4*(2*c*d-b*e)*(c^2*d^2+b^2*e^2-c*e*(b*d+3*a*e))*n/(e*(c*d^2-b*d*e+_
+   a*e^2)^3*(d+e*x))-1/4*(2*c^4*d^4+b^4*e^4-4*b^2*c*e^3*(b*d+a*e)-4*c^3*_
+   d^2*e*(b*d+3*a*e)+2*c^2*e^2*(3*b^2*d^2+6*a*b*d*e+a^2*e^2))*n*_
+   log(d+e*x)/(e*(c*d^2-b*d*e+a*e^2)^4)+1/8*(2*c^4*d^4+b^4*e^4-4*b^2*c*_
+   e^3*(b*d+a*e)-4*c^3*d^2*e*(b*d+3*a*e)+2*c^2*e^2*(3*b^2*d^2+6*a*b*d*e+_
+   a^2*e^2))*n*log(a+b*x+c*x^2)/(e*(c*d^2-b*d*e+a*e^2)^4)-1/4*log(d*(a+_
+   b*x+c*x^2)^n)/(e*(d+e*x)^4)+1/4*(2*c*d-b*e)*(2*c^2*d^2+b^2*e^2-_
+   2*c*e*(b*d+a*e))*n*atanh((b+2*c*x)/sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c)/_
+   (c*d^2-b*d*e+a*e^2)^4
+--R 
+--R
+--R   (2)
+--R               4 8      3     7         3       2 2  2 6
+--R           - 6a e  + 24a b d e  + (- 24a c - 36a b )d e
+--R         + 
+--R               2           3  3 5         2 2        2      4  4 4
+--R           (72a b c + 24a b )d e  + (- 36a c  - 72a b c - 6b )d e
+--R         + 
+--R                   2      3   5 3           3      2 2  6 2        3 7      4 8
+--R           (72a b c  + 24b c)d e  + (- 24a c  - 36b c )d e  + 24b c d e - 6c d
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                              3  8           2      2     7        2 2 6
+--R                 (12a b c - 6b )e  + (- 24a c  + 24b c)d e  - 36b c d e
+--R               + 
+--R                    3 3 5
+--R                 24c d e
+--R          *
+--R                4
+--R             n x
+--R         + 
+--R                             3    7           2      2   2 6         2 3 5
+--R               (48a b c - 24b )d e  + (- 96a c  + 96b c)d e  - 144b c d e
+--R             + 
+--R                  3 4 4
+--R               96c d e
+--R          *
+--R                3
+--R             n x
+--R         + 
+--R                             3  2 6            2       2   3 5         2 4 4
+--R               (72a b c - 36b )d e  + (- 144a c  + 144b c)d e  - 216b c d e
+--R             + 
+--R                   3 5 3
+--R               144c d e
+--R          *
+--R                2
+--R             n x
+--R         + 
+--R                             3  3 5           2      2   4 4         2 5 3
+--R               (48a b c - 24b )d e  + (- 96a c  + 96b c)d e  - 144b c d e
+--R             + 
+--R                  3 6 2
+--R               96c d e
+--R          *
+--R             n x
+--R         + 
+--R                       3  4 4           2      2   5 3        2 6 2      3 7
+--R         ((12a b c - 6b )d e  + (- 24a c  + 24b c)d e  - 36b c d e  + 24c d e)n
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                  2 2        2      4  8           2      3     7
+--R               (6a c  - 12a b c + 3b )e  + (36a b c  - 12b c)d e
+--R             + 
+--R                       3      2 2  2 6        3 3 5     4 4 4
+--R               (- 36a c  + 18b c )d e  - 12b c d e  + 6c d e
+--R          *
+--R                4
+--R             n x
+--R         + 
+--R                   2 2        2       4    7            2      3   2 6
+--R               (24a c  - 48a b c + 12b )d e  + (144a b c  - 48b c)d e
+--R             + 
+--R                        3      2 2  3 5        3 4 4      4 5 3
+--R               (- 144a c  + 72b c )d e  - 48b c d e  + 24c d e
+--R          *
+--R                3
+--R             n x
+--R         + 
+--R                   2 2        2       4  2 6            2      3   3 5
+--R               (36a c  - 72a b c + 18b )d e  + (216a b c  - 72b c)d e
+--R             + 
+--R                        3       2 2  4 4        3 5 3      4 6 2
+--R               (- 216a c  + 108b c )d e  - 72b c d e  + 36c d e
+--R          *
+--R                2
+--R             n x
+--R         + 
+--R                   2 2        2       4  3 5            2      3   4 4
+--R               (24a c  - 48a b c + 12b )d e  + (144a b c  - 48b c)d e
+--R             + 
+--R                        3      2 2  5 3        3 6 2      4 7
+--R               (- 144a c  + 72b c )d e  - 48b c d e  + 24c d e
+--R          *
+--R             n x
+--R         + 
+--R                  2 2        2      4  4 4           2      3   5 3
+--R               (6a c  - 12a b c + 3b )d e  + (36a b c  - 12b c)d e
+--R             + 
+--R                       3      2 2  6 2        3 7      4 8
+--R               (- 36a c  + 18b c )d e  - 12b c d e + 6c d
+--R          *
+--R             n
+--R      *
+--R                2
+--R         log(c x  + b x + a)
+--R     + 
+--R                     2 2        2      4  8             2      3     7
+--R               (- 12a c  + 24a b c - 6b )e  + (- 72a b c  + 24b c)d e
+--R             + 
+--R                     3      2 2  2 6        3 3 5      4 4 4
+--R               (72a c  - 36b c )d e  + 24b c d e  - 12c d e
+--R          *
+--R                4
+--R             n x
+--R         + 
+--R                     2 2        2       4    7              2      3   2 6
+--R               (- 48a c  + 96a b c - 24b )d e  + (- 288a b c  + 96b c)d e
+--R             + 
+--R                      3       2 2  3 5        3 4 4      4 5 3
+--R               (288a c  - 144b c )d e  + 96b c d e  - 48c d e
+--R          *
+--R                3
+--R             n x
+--R         + 
+--R                     2 2         2       4  2 6              2       3   3 5
+--R               (- 72a c  + 144a b c - 36b )d e  + (- 432a b c  + 144b c)d e
+--R             + 
+--R                      3       2 2  4 4         3 5 3      4 6 2
+--R               (432a c  - 216b c )d e  + 144b c d e  - 72c d e
+--R          *
+--R                2
+--R             n x
+--R         + 
+--R                     2 2        2       4  3 5              2      3   4 4
+--R               (- 48a c  + 96a b c - 24b )d e  + (- 288a b c  + 96b c)d e
+--R             + 
+--R                      3       2 2  5 3        3 6 2      4 7
+--R               (288a c  - 144b c )d e  + 96b c d e  - 48c d e
+--R          *
+--R             n x
+--R         + 
+--R                     2 2        2      4  4 4             2      3   5 3
+--R               (- 12a c  + 24a b c - 6b )d e  + (- 72a b c  + 24b c)d e
+--R             + 
+--R                     3      2 2  6 2        3 7       4 8
+--R               (72a c  - 36b c )d e  + 24b c d e - 12c d
+--R          *
+--R             n
+--R      *
+--R         log(e x + d)
+--R     + 
+--R               2          3  8         2 2     4    7           2      3   2 6
+--R           (18a b c - 6a b )e  + (- 36a c  + 6b )d e  + (36a b c  - 24b c)d e
+--R         + 
+--R                   3      2 2  3 5        3 4 4      4 5 3
+--R           (- 24a c  + 36b c )d e  - 30b c d e  + 12c d e
+--R      *
+--R            3
+--R         n x
+--R     + 
+--R                3      2 2  8       2           3    7
+--R           (- 6a c + 3a b )e  + (60a b c - 24a b )d e
+--R         + 
+--R                  2 2        2       4  2 6           2      3   3 5
+--R           (- 114a c  + 12a b c + 21b )d e  + (96a b c  - 84b c)d e
+--R         + 
+--R                   3       2 2  4 4         3 5 3      4 6 2
+--R           (- 66a c  + 129b c )d e  - 108b c d e  + 42c d e
+--R      *
+--R            2
+--R         n x
+--R     + 
+--R               3   8        3       2 2    7       2           3  2 6
+--R           - 2a b e  + (- 8a c + 12a b )d e  + (48a b c - 36a b )d e
+--R         + 
+--R                  2 2        2       4  3 5           2       3   4 4
+--R           (- 108a c  + 48a b c + 26b )d e  + (54a b c  - 106b c)d e
+--R         + 
+--R                   3       2 2  5 3         3 6 2      4 7
+--R           (- 48a c  + 168b c )d e  - 140b c d e  + 52c d e
+--R      *
+--R         n x
+--R     + 
+--R               3     7        3      2 2  2 6      2           3  3 5
+--R           - 2a b d e  + (- 2a c + 9a b )d e  + (6a b c - 18a b )d e
+--R         + 
+--R                 2 2        2       4  4 4            2      3   5 3
+--R           (- 30a c  + 36a b c + 11b )d e  + (- 6a b c  - 46b c)d e
+--R         + 
+--R                  3      2 2  6 2        3 7       4 8
+--R           (- 6a c  + 75b c )d e  - 62b c d e + 22c d
+--R      *
+--R         n
+--R  /
+--R              4 13      3     12       3        2 2  2 11
+--R           24a e   - 96a b d e   + (96a c + 144a b )d e
+--R         + 
+--R                  2           3  3 10        2 2         2       4  4 9
+--R           (- 288a b c - 96a b )d e   + (144a c  + 288a b c + 24b )d e
+--R         + 
+--R                      2      3   5 8         3       2 2  6 7        3 7 6
+--R           (- 288a b c  - 96b c)d e  + (96a c  + 144b c )d e  - 96b c d e
+--R         + 
+--R              4 8 5
+--R           24c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R              4   12       3   2 11        3        2 2  3 10
+--R           96a d e   - 384a b d e   + (384a c + 576a b )d e
+--R         + 
+--R                   2            3  4 9        2 2          2       4  5 8
+--R           (- 1152a b c - 384a b )d e  + (576a c  + 1152a b c + 96b )d e
+--R         + 
+--R                       2       3   6 7          3       2 2  7 6         3 8 5
+--R           (- 1152a b c  - 384b c)d e  + (384a c  + 576b c )d e  - 384b c d e
+--R         + 
+--R              4 9 4
+--R           96c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R               4 2 11       3   3 10        3        2 2  4 9
+--R           144a d e   - 576a b d e   + (576a c + 864a b )d e
+--R         + 
+--R                   2            3  5 8        2 2          2        4  6 7
+--R           (- 1728a b c - 576a b )d e  + (864a c  + 1728a b c + 144b )d e
+--R         + 
+--R                       2       3   7 6          3       2 2  8 5         3 9 4
+--R           (- 1728a b c  - 576b c)d e  + (576a c  + 864b c )d e  - 576b c d e
+--R         + 
+--R               4 10 3
+--R           144c d  e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              4 3 10       3   4 9        3        2 2  5 8
+--R           96a d e   - 384a b d e  + (384a c + 576a b )d e
+--R         + 
+--R                   2            3  6 7        2 2          2       4  7 6
+--R           (- 1152a b c - 384a b )d e  + (576a c  + 1152a b c + 96b )d e
+--R         + 
+--R                       2       3   8 5          3       2 2  9 4         3 10 3
+--R           (- 1152a b c  - 384b c)d e  + (384a c  + 576b c )d e  - 384b c d  e
+--R         + 
+--R              4 11 2
+--R           96c d  e
+--R      *
+--R         x
+--R     + 
+--R          4 4 9      3   5 8       3        2 2  6 7          2           3  7 6
+--R       24a d e  - 96a b d e  + (96a c + 144a b )d e  + (- 288a b c - 96a b )d e
+--R     + 
+--R            2 2         2       4  8 5              2      3   9 4
+--R       (144a c  + 288a b c + 24b )d e  + (- 288a b c  - 96b c)d e
+--R     + 
+--R             3       2 2  10 3        3 11 2      4 12
+--R       (96a c  + 144b c )d  e  - 96b c d  e  + 24c d  e
+--R                                                    Type: Expression(Integer)
+--E 4298
+
+--S 4299 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R                               3  8           2      2     7        2 2 6
+--R                   (6a b c - 3b )e  + (- 12a c  + 12b c)d e  - 18b c d e
+--R                 + 
+--R                      3 3 5
+--R                   12c d e
+--R            *
+--R                  4
+--R               n x
+--R           + 
+--R                               3    7           2      2   2 6        2 3 5
+--R                 (24a b c - 12b )d e  + (- 48a c  + 48b c)d e  - 72b c d e
+--R               + 
+--R                    3 4 4
+--R                 48c d e
+--R            *
+--R                  3
+--R               n x
+--R           + 
+--R                               3  2 6           2      2   3 5         2 4 4
+--R                 (36a b c - 18b )d e  + (- 72a c  + 72b c)d e  - 108b c d e
+--R               + 
+--R                    3 5 3
+--R                 72c d e
+--R            *
+--R                  2
+--R               n x
+--R           + 
+--R                               3  3 5           2      2   4 4        2 5 3
+--R                 (24a b c - 12b )d e  + (- 48a c  + 48b c)d e  - 72b c d e
+--R               + 
+--R                    3 6 2
+--R                 48c d e
+--R            *
+--R               n x
+--R           + 
+--R                        3  4 4           2      2   5 3        2 6 2      3 7
+--R           ((6a b c - 3b )d e  + (- 12a c  + 12b c)d e  - 18b c d e  + 12c d e)n
+--R        *
+--R            +-----------+
+--R            |          2
+--R           \|- 4a c + b
+--R        *
+--R                          +-----------+
+--R                          |          2      2 2                    2
+--R               (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R           log(-----------------------------------------------------)
+--R                                      2
+--R                                   c x  + b x + a
+--R       + 
+--R                    2 2        2      4  8           2      3     7
+--R                 (6a c  - 12a b c + 3b )e  + (36a b c  - 12b c)d e
+--R               + 
+--R                         3      2 2  2 6        3 3 5     4 4 4
+--R                 (- 36a c  + 18b c )d e  - 12b c d e  + 6c d e
+--R            *
+--R                  4
+--R               n x
+--R           + 
+--R                     2 2        2       4    7            2      3   2 6
+--R                 (24a c  - 48a b c + 12b )d e  + (144a b c  - 48b c)d e
+--R               + 
+--R                          3      2 2  3 5        3 4 4      4 5 3
+--R                 (- 144a c  + 72b c )d e  - 48b c d e  + 24c d e
+--R            *
+--R                  3
+--R               n x
+--R           + 
+--R                     2 2        2       4  2 6            2      3   3 5
+--R                 (36a c  - 72a b c + 18b )d e  + (216a b c  - 72b c)d e
+--R               + 
+--R                          3       2 2  4 4        3 5 3      4 6 2
+--R                 (- 216a c  + 108b c )d e  - 72b c d e  + 36c d e
+--R            *
+--R                  2
+--R               n x
+--R           + 
+--R                     2 2        2       4  3 5            2      3   4 4
+--R                 (24a c  - 48a b c + 12b )d e  + (144a b c  - 48b c)d e
+--R               + 
+--R                          3      2 2  5 3        3 6 2      4 7
+--R                 (- 144a c  + 72b c )d e  - 48b c d e  + 24c d e
+--R            *
+--R               n x
+--R           + 
+--R                     4 8      3     7         3       2 2  2 6
+--R                 - 6a e  + 24a b d e  + (- 24a c - 36a b )d e
+--R               + 
+--R                     2           3  3 5         2 2        2      4  4 4
+--R                 (72a b c + 24a b )d e  + (- 30a c  - 84a b c - 3b )d e
+--R               + 
+--R                          2      3   5 3           3      2 2  6 2        3 7
+--R                 (108a b c  + 12b c)d e  + (- 60a c  - 18b c )d e  + 12b c d e
+--R            *
+--R               n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R                       2 2        2      4  8             2      3     7
+--R                 (- 12a c  + 24a b c - 6b )e  + (- 72a b c  + 24b c)d e
+--R               + 
+--R                       3      2 2  2 6        3 3 5      4 4 4
+--R                 (72a c  - 36b c )d e  + 24b c d e  - 12c d e
+--R            *
+--R                  4
+--R               n x
+--R           + 
+--R                       2 2        2       4    7              2      3   2 6
+--R                 (- 48a c  + 96a b c - 24b )d e  + (- 288a b c  + 96b c)d e
+--R               + 
+--R                        3       2 2  3 5        3 4 4      4 5 3
+--R                 (288a c  - 144b c )d e  + 96b c d e  - 48c d e
+--R            *
+--R                  3
+--R               n x
+--R           + 
+--R                       2 2         2       4  2 6              2       3   3 5
+--R                 (- 72a c  + 144a b c - 36b )d e  + (- 432a b c  + 144b c)d e
+--R               + 
+--R                        3       2 2  4 4         3 5 3      4 6 2
+--R                 (432a c  - 216b c )d e  + 144b c d e  - 72c d e
+--R            *
+--R                  2
+--R               n x
+--R           + 
+--R                       2 2        2       4  3 5              2      3   4 4
+--R                 (- 48a c  + 96a b c - 24b )d e  + (- 288a b c  + 96b c)d e
+--R               + 
+--R                        3       2 2  5 3        3 6 2      4 7
+--R                 (288a c  - 144b c )d e  + 96b c d e  - 48c d e
+--R            *
+--R               n x
+--R           + 
+--R                       2 2        2      4  4 4             2      3   5 3
+--R                 (- 12a c  + 24a b c - 6b )d e  + (- 72a b c  + 24b c)d e
+--R               + 
+--R                       3      2 2  6 2        3 7       4 8
+--R                 (72a c  - 36b c )d e  + 24b c d e - 12c d
+--R            *
+--R               n
+--R        *
+--R           log(e x + d)
+--R       + 
+--R                 4 8      3     7         3       2 2  2 6
+--R             - 6a e  + 24a b d e  + (- 24a c - 36a b )d e
+--R           + 
+--R                 2           3  3 5         2 2        2      4  4 4
+--R             (72a b c + 24a b )d e  + (- 36a c  - 72a b c - 6b )d e
+--R           + 
+--R                   2      3   5 3           3      2 2  6 2        3 7      4 8
+--R           (72a b c  + 24b c)d e  + (- 24a c  - 36b c )d e  + 24b c d e - 6c d
+--R        *
+--R           log(d)
+--R       + 
+--R                 2          3  8         2 2     4    7           2      3   2 6
+--R             (18a b c - 6a b )e  + (- 36a c  + 6b )d e  + (36a b c  - 24b c)d e
+--R           + 
+--R                     3      2 2  3 5        3 4 4      4 5 3
+--R             (- 24a c  + 36b c )d e  - 30b c d e  + 12c d e
+--R        *
+--R              3
+--R           n x
+--R       + 
+--R                  3      2 2  8       2           3    7
+--R             (- 6a c + 3a b )e  + (60a b c - 24a b )d e
+--R           + 
+--R                    2 2        2       4  2 6           2      3   3 5
+--R             (- 114a c  + 12a b c + 21b )d e  + (96a b c  - 84b c)d e
+--R           + 
+--R                     3       2 2  4 4         3 5 3      4 6 2
+--R             (- 66a c  + 129b c )d e  - 108b c d e  + 42c d e
+--R        *
+--R              2
+--R           n x
+--R       + 
+--R                 3   8        3       2 2    7       2           3  2 6
+--R             - 2a b e  + (- 8a c + 12a b )d e  + (48a b c - 36a b )d e
+--R           + 
+--R                    2 2        2       4  3 5           2       3   4 4
+--R             (- 108a c  + 48a b c + 26b )d e  + (54a b c  - 106b c)d e
+--R           + 
+--R                     3       2 2  5 3         3 6 2      4 7
+--R             (- 48a c  + 168b c )d e  - 140b c d e  + 52c d e
+--R        *
+--R           n x
+--R       + 
+--R                 3     7        3      2 2  2 6      2           3  3 5
+--R             - 2a b d e  + (- 2a c + 9a b )d e  + (6a b c - 18a b )d e
+--R           + 
+--R                   2 2        2       4  4 4            2      3   5 3
+--R             (- 30a c  + 36a b c + 11b )d e  + (- 6a b c  - 46b c)d e
+--R           + 
+--R                    3      2 2  6 2        3 7       4 8
+--R             (- 6a c  + 75b c )d e  - 62b c d e + 22c d
+--R        *
+--R           n
+--R    /
+--R                4 13      3     12       3        2 2  2 11
+--R             24a e   - 96a b d e   + (96a c + 144a b )d e
+--R           + 
+--R                    2           3  3 10        2 2         2       4  4 9
+--R             (- 288a b c - 96a b )d e   + (144a c  + 288a b c + 24b )d e
+--R           + 
+--R                        2      3   5 8         3       2 2  6 7        3 7 6
+--R             (- 288a b c  - 96b c)d e  + (96a c  + 144b c )d e  - 96b c d e
+--R           + 
+--R                4 8 5
+--R             24c d e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                4   12       3   2 11        3        2 2  3 10
+--R             96a d e   - 384a b d e   + (384a c + 576a b )d e
+--R           + 
+--R                     2            3  4 9        2 2          2       4  5 8
+--R             (- 1152a b c - 384a b )d e  + (576a c  + 1152a b c + 96b )d e
+--R           + 
+--R                         2       3   6 7          3       2 2  7 6         3 8 5
+--R             (- 1152a b c  - 384b c)d e  + (384a c  + 576b c )d e  - 384b c d e
+--R           + 
+--R                4 9 4
+--R             96c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                 4 2 11       3   3 10        3        2 2  4 9
+--R             144a d e   - 576a b d e   + (576a c + 864a b )d e
+--R           + 
+--R                     2            3  5 8        2 2          2        4  6 7
+--R             (- 1728a b c - 576a b )d e  + (864a c  + 1728a b c + 144b )d e
+--R           + 
+--R                         2       3   7 6          3       2 2  8 5         3 9 4
+--R             (- 1728a b c  - 576b c)d e  + (576a c  + 864b c )d e  - 576b c d e
+--R           + 
+--R                 4 10 3
+--R             144c d  e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                4 3 10       3   4 9        3        2 2  5 8
+--R             96a d e   - 384a b d e  + (384a c + 576a b )d e
+--R           + 
+--R                     2            3  6 7        2 2          2       4  7 6
+--R             (- 1152a b c - 384a b )d e  + (576a c  + 1152a b c + 96b )d e
+--R           + 
+--R                         2       3   8 5          3       2 2  9 4
+--R             (- 1152a b c  - 384b c)d e  + (384a c  + 576b c )d e
+--R           + 
+--R                     3 10 3      4 11 2
+--R             - 384b c d  e  + 96c d  e
+--R        *
+--R           x
+--R       + 
+--R            4 4 9      3   5 8       3        2 2  6 7
+--R         24a d e  - 96a b d e  + (96a c + 144a b )d e
+--R       + 
+--R                2           3  7 6        2 2         2       4  8 5
+--R         (- 288a b c - 96a b )d e  + (144a c  + 288a b c + 24b )d e
+--R       + 
+--R                    2      3   9 4         3       2 2  10 3        3 11 2
+--R         (- 288a b c  - 96b c)d e  + (96a c  + 144b c )d  e  - 96b c d  e
+--R       + 
+--R            4 12
+--R         24c d  e
+--R     ,
+--R
+--R                                3  8         2      2     7        2 2 6
+--R                 (- 12a b c + 6b )e  + (24a c  - 24b c)d e  + 36b c d e
+--R               + 
+--R                      3 3 5
+--R                 - 24c d e
+--R            *
+--R                  4
+--R               n x
+--R           + 
+--R                                 3    7         2      2   2 6         2 3 5
+--R                 (- 48a b c + 24b )d e  + (96a c  - 96b c)d e  + 144b c d e
+--R               + 
+--R                      3 4 4
+--R                 - 96c d e
+--R            *
+--R                  3
+--R               n x
+--R           + 
+--R                                 3  2 6          2       2   3 5         2 4 4
+--R                 (- 72a b c + 36b )d e  + (144a c  - 144b c)d e  + 216b c d e
+--R               + 
+--R                       3 5 3
+--R                 - 144c d e
+--R            *
+--R                  2
+--R               n x
+--R           + 
+--R                                 3  3 5         2      2   4 4         2 5 3
+--R                 (- 48a b c + 24b )d e  + (96a c  - 96b c)d e  + 144b c d e
+--R               + 
+--R                      3 6 2
+--R                 - 96c d e
+--R            *
+--R               n x
+--R           + 
+--R                                3  4 4         2      2   5 3        2 6 2
+--R                 (- 12a b c + 6b )d e  + (24a c  - 24b c)d e  + 36b c d e
+--R               + 
+--R                      3 7
+--R                 - 24c d e
+--R            *
+--R               n
+--R        *
+--R                             +---------+
+--R            +---------+      |        2
+--R            |        2      \|4a c - b
+--R           \|4a c - b  atan(------------)
+--R                              2c x + b
+--R       + 
+--R                    2 2        2      4  8           2      3     7
+--R                 (6a c  - 12a b c + 3b )e  + (36a b c  - 12b c)d e
+--R               + 
+--R                         3      2 2  2 6        3 3 5     4 4 4
+--R                 (- 36a c  + 18b c )d e  - 12b c d e  + 6c d e
+--R            *
+--R                  4
+--R               n x
+--R           + 
+--R                     2 2        2       4    7            2      3   2 6
+--R                 (24a c  - 48a b c + 12b )d e  + (144a b c  - 48b c)d e
+--R               + 
+--R                          3      2 2  3 5        3 4 4      4 5 3
+--R                 (- 144a c  + 72b c )d e  - 48b c d e  + 24c d e
+--R            *
+--R                  3
+--R               n x
+--R           + 
+--R                     2 2        2       4  2 6            2      3   3 5
+--R                 (36a c  - 72a b c + 18b )d e  + (216a b c  - 72b c)d e
+--R               + 
+--R                          3       2 2  4 4        3 5 3      4 6 2
+--R                 (- 216a c  + 108b c )d e  - 72b c d e  + 36c d e
+--R            *
+--R                  2
+--R               n x
+--R           + 
+--R                     2 2        2       4  3 5            2      3   4 4
+--R                 (24a c  - 48a b c + 12b )d e  + (144a b c  - 48b c)d e
+--R               + 
+--R                          3      2 2  5 3        3 6 2      4 7
+--R                 (- 144a c  + 72b c )d e  - 48b c d e  + 24c d e
+--R            *
+--R               n x
+--R           + 
+--R                     4 8      3     7         3       2 2  2 6
+--R                 - 6a e  + 24a b d e  + (- 24a c - 36a b )d e
+--R               + 
+--R                     2           3  3 5         2 2        2      4  4 4
+--R                 (72a b c + 24a b )d e  + (- 30a c  - 84a b c - 3b )d e
+--R               + 
+--R                          2      3   5 3           3      2 2  6 2        3 7
+--R                 (108a b c  + 12b c)d e  + (- 60a c  - 18b c )d e  + 12b c d e
+--R            *
+--R               n
+--R        *
+--R                  2
+--R           log(c x  + b x + a)
+--R       + 
+--R                       2 2        2      4  8             2      3     7
+--R                 (- 12a c  + 24a b c - 6b )e  + (- 72a b c  + 24b c)d e
+--R               + 
+--R                       3      2 2  2 6        3 3 5      4 4 4
+--R                 (72a c  - 36b c )d e  + 24b c d e  - 12c d e
+--R            *
+--R                  4
+--R               n x
+--R           + 
+--R                       2 2        2       4    7              2      3   2 6
+--R                 (- 48a c  + 96a b c - 24b )d e  + (- 288a b c  + 96b c)d e
+--R               + 
+--R                        3       2 2  3 5        3 4 4      4 5 3
+--R                 (288a c  - 144b c )d e  + 96b c d e  - 48c d e
+--R            *
+--R                  3
+--R               n x
+--R           + 
+--R                       2 2         2       4  2 6              2       3   3 5
+--R                 (- 72a c  + 144a b c - 36b )d e  + (- 432a b c  + 144b c)d e
+--R               + 
+--R                        3       2 2  4 4         3 5 3      4 6 2
+--R                 (432a c  - 216b c )d e  + 144b c d e  - 72c d e
+--R            *
+--R                  2
+--R               n x
+--R           + 
+--R                       2 2        2       4  3 5              2      3   4 4
+--R                 (- 48a c  + 96a b c - 24b )d e  + (- 288a b c  + 96b c)d e
+--R               + 
+--R                        3       2 2  5 3        3 6 2      4 7
+--R                 (288a c  - 144b c )d e  + 96b c d e  - 48c d e
+--R            *
+--R               n x
+--R           + 
+--R                       2 2        2      4  4 4             2      3   5 3
+--R                 (- 12a c  + 24a b c - 6b )d e  + (- 72a b c  + 24b c)d e
+--R               + 
+--R                       3      2 2  6 2        3 7       4 8
+--R                 (72a c  - 36b c )d e  + 24b c d e - 12c d
+--R            *
+--R               n
+--R        *
+--R           log(e x + d)
+--R       + 
+--R                 4 8      3     7         3       2 2  2 6
+--R             - 6a e  + 24a b d e  + (- 24a c - 36a b )d e
+--R           + 
+--R                 2           3  3 5         2 2        2      4  4 4
+--R             (72a b c + 24a b )d e  + (- 36a c  - 72a b c - 6b )d e
+--R           + 
+--R                   2      3   5 3           3      2 2  6 2        3 7      4 8
+--R           (72a b c  + 24b c)d e  + (- 24a c  - 36b c )d e  + 24b c d e - 6c d
+--R        *
+--R           log(d)
+--R       + 
+--R                 2          3  8         2 2     4    7           2      3   2 6
+--R             (18a b c - 6a b )e  + (- 36a c  + 6b )d e  + (36a b c  - 24b c)d e
+--R           + 
+--R                     3      2 2  3 5        3 4 4      4 5 3
+--R             (- 24a c  + 36b c )d e  - 30b c d e  + 12c d e
+--R        *
+--R              3
+--R           n x
+--R       + 
+--R                  3      2 2  8       2           3    7
+--R             (- 6a c + 3a b )e  + (60a b c - 24a b )d e
+--R           + 
+--R                    2 2        2       4  2 6           2      3   3 5
+--R             (- 114a c  + 12a b c + 21b )d e  + (96a b c  - 84b c)d e
+--R           + 
+--R                     3       2 2  4 4         3 5 3      4 6 2
+--R             (- 66a c  + 129b c )d e  - 108b c d e  + 42c d e
+--R        *
+--R              2
+--R           n x
+--R       + 
+--R                 3   8        3       2 2    7       2           3  2 6
+--R             - 2a b e  + (- 8a c + 12a b )d e  + (48a b c - 36a b )d e
+--R           + 
+--R                    2 2        2       4  3 5           2       3   4 4
+--R             (- 108a c  + 48a b c + 26b )d e  + (54a b c  - 106b c)d e
+--R           + 
+--R                     3       2 2  5 3         3 6 2      4 7
+--R             (- 48a c  + 168b c )d e  - 140b c d e  + 52c d e
+--R        *
+--R           n x
+--R       + 
+--R                 3     7        3      2 2  2 6      2           3  3 5
+--R             - 2a b d e  + (- 2a c + 9a b )d e  + (6a b c - 18a b )d e
+--R           + 
+--R                   2 2        2       4  4 4            2      3   5 3
+--R             (- 30a c  + 36a b c + 11b )d e  + (- 6a b c  - 46b c)d e
+--R           + 
+--R                    3      2 2  6 2        3 7       4 8
+--R             (- 6a c  + 75b c )d e  - 62b c d e + 22c d
+--R        *
+--R           n
+--R    /
+--R                4 13      3     12       3        2 2  2 11
+--R             24a e   - 96a b d e   + (96a c + 144a b )d e
+--R           + 
+--R                    2           3  3 10        2 2         2       4  4 9
+--R             (- 288a b c - 96a b )d e   + (144a c  + 288a b c + 24b )d e
+--R           + 
+--R                        2      3   5 8         3       2 2  6 7        3 7 6
+--R             (- 288a b c  - 96b c)d e  + (96a c  + 144b c )d e  - 96b c d e
+--R           + 
+--R                4 8 5
+--R             24c d e
+--R        *
+--R            4
+--R           x
+--R       + 
+--R                4   12       3   2 11        3        2 2  3 10
+--R             96a d e   - 384a b d e   + (384a c + 576a b )d e
+--R           + 
+--R                     2            3  4 9        2 2          2       4  5 8
+--R             (- 1152a b c - 384a b )d e  + (576a c  + 1152a b c + 96b )d e
+--R           + 
+--R                         2       3   6 7          3       2 2  7 6         3 8 5
+--R             (- 1152a b c  - 384b c)d e  + (384a c  + 576b c )d e  - 384b c d e
+--R           + 
+--R                4 9 4
+--R             96c d e
+--R        *
+--R            3
+--R           x
+--R       + 
+--R                 4 2 11       3   3 10        3        2 2  4 9
+--R             144a d e   - 576a b d e   + (576a c + 864a b )d e
+--R           + 
+--R                     2            3  5 8        2 2          2        4  6 7
+--R             (- 1728a b c - 576a b )d e  + (864a c  + 1728a b c + 144b )d e
+--R           + 
+--R                         2       3   7 6          3       2 2  8 5         3 9 4
+--R             (- 1728a b c  - 576b c)d e  + (576a c  + 864b c )d e  - 576b c d e
+--R           + 
+--R                 4 10 3
+--R             144c d  e
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                4 3 10       3   4 9        3        2 2  5 8
+--R             96a d e   - 384a b d e  + (384a c + 576a b )d e
+--R           + 
+--R                     2            3  6 7        2 2          2       4  7 6
+--R             (- 1152a b c - 384a b )d e  + (576a c  + 1152a b c + 96b )d e
+--R           + 
+--R                         2       3   8 5          3       2 2  9 4
+--R             (- 1152a b c  - 384b c)d e  + (384a c  + 576b c )d e
+--R           + 
+--R                     3 10 3      4 11 2
+--R             - 384b c d  e  + 96c d  e
+--R        *
+--R           x
+--R       + 
+--R            4 4 9      3   5 8       3        2 2  6 7
+--R         24a d e  - 96a b d e  + (96a c + 144a b )d e
+--R       + 
+--R                2           3  7 6        2 2         2       4  8 5
+--R         (- 288a b c - 96a b )d e  + (144a c  + 288a b c + 24b )d e
+--R       + 
+--R                    2      3   9 4         3       2 2  10 3        3 11 2
+--R         (- 288a b c  - 96b c)d e  + (96a c  + 144b c )d  e  - 96b c d  e
+--R       + 
+--R            4 12
+--R         24c d  e
+--R     ]
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4299
+
+--S 4300 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                       3  8          2     2     7       2 2 6     3 3 5    4
+--R           ((2a b c - b )e  + (- 4a c  + 4b c)d e  - 6b c d e  + 4c d e )n x
+--R         + 
+--R                             3    7           2      2   2 6        2 3 5
+--R                 (8a b c - 4b )d e  + (- 16a c  + 16b c)d e  - 24b c d e
+--R               + 
+--R                    3 4 4
+--R                 16c d e
+--R          *
+--R                3
+--R             n x
+--R         + 
+--R                            3  2 6           2      2   3 5        2 4 4
+--R               (12a b c - 6b )d e  + (- 24a c  + 24b c)d e  - 36b c d e
+--R             + 
+--R                  3 5 3
+--R               24c d e
+--R          *
+--R                2
+--R             n x
+--R         + 
+--R                             3  3 5           2      2   4 4        2 5 3
+--R                 (8a b c - 4b )d e  + (- 16a c  + 16b c)d e  - 24b c d e
+--R               + 
+--R                    3 6 2
+--R                 16c d e
+--R          *
+--R             n x
+--R         + 
+--R                       3  4 4          2     2   5 3       2 6 2     3 7
+--R           ((2a b c - b )d e  + (- 4a c  + 4b c)d e  - 6b c d e  + 4c d e)n
+--R      *
+--R                                    +-----------+
+--R        +-----------+               |          2      2 2                    2
+--R        |          2     (2c x + b)\|- 4a c + b   + 2c x  + 2b c x - 2a c + b
+--R       \|- 4a c + b  log(-----------------------------------------------------)
+--R                                                2
+--R                                             c x  + b x + a
+--R     + 
+--R             4 8     3     7      3       2 2  2 6         2          3  3 5
+--R           2a e  - 8a b d e  + (8a c + 12a b )d e  + (- 24a b c - 8a b )d e
+--R         + 
+--R               2 2        2      4  4 4             2     3   5 3
+--R           (12a c  + 24a b c + 2b )d e  + (- 24a b c  - 8b c)d e
+--R         + 
+--R                3      2 2  6 2       3 7      4 8
+--R           (8a c  + 12b c )d e  - 8b c d e + 2c d
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                          3  8        2     2     7        2 2 6     3 3 5    4
+--R           ((- 4a b c + 2b )e  + (8a c  - 8b c)d e  + 12b c d e  - 8c d e )n x
+--R         + 
+--R                              3    7         2      2   2 6        2 3 5
+--R               (- 16a b c + 8b )d e  + (32a c  - 32b c)d e  + 48b c d e
+--R             + 
+--R                    3 4 4
+--R               - 32c d e
+--R          *
+--R                3
+--R             n x
+--R         + 
+--R                               3  2 6         2      2   3 5        2 4 4
+--R               (- 24a b c + 12b )d e  + (48a c  - 48b c)d e  + 72b c d e
+--R             + 
+--R                    3 5 3
+--R               - 48c d e
+--R          *
+--R                2
+--R             n x
+--R         + 
+--R                              3  3 5         2      2   4 4        2 5 3
+--R               (- 16a b c + 8b )d e  + (32a c  - 32b c)d e  + 48b c d e
+--R             + 
+--R                    3 6 2
+--R               - 32c d e
+--R          *
+--R             n x
+--R         + 
+--R                          3  4 4        2     2   5 3        2 6 2     3 7
+--R           ((- 4a b c + 2b )d e  + (8a c  - 8b c)d e  + 12b c d e  - 8c d e)n
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R               4 8     3     7        3       2 2  2 6       2          3  3 5
+--R           - 2a e  + 8a b d e  + (- 8a c - 12a b )d e  + (24a b c + 8a b )d e
+--R         + 
+--R                 2 2        2      4  4 4           2     3   5 3
+--R           (- 12a c  - 24a b c - 2b )d e  + (24a b c  + 8b c)d e
+--R         + 
+--R                  3      2 2  6 2       3 7      4 8
+--R           (- 8a c  - 12b c )d e  + 8b c d e - 2c d
+--R      *
+--R                  2
+--R         n log(c x  + b x + a)
+--R     + 
+--R               4 8     3     7        3       2 2  2 6       2          3  3 5
+--R           - 2a e  + 8a b d e  + (- 8a c - 12a b )d e  + (24a b c + 8a b )d e
+--R         + 
+--R                 2 2        2      4  4 4           2     3   5 3
+--R           (- 12a c  - 24a b c - 2b )d e  + (24a b c  + 8b c)d e
+--R         + 
+--R                  3      2 2  6 2       3 7      4 8
+--R           (- 8a c  - 12b c )d e  + 8b c d e - 2c d
+--R      *
+--R         log(d)
+--R  /
+--R             4 13      3     12       3       2 2  2 11
+--R           8a e   - 32a b d e   + (32a c + 48a b )d e
+--R         + 
+--R                 2           3  3 10       2 2        2      4  4 9
+--R           (- 96a b c - 32a b )d e   + (48a c  + 96a b c + 8b )d e
+--R         + 
+--R                   2      3   5 8         3      2 2  6 7        3 7 6     4 8 5
+--R         (- 96a b c  - 32b c)d e  + (32a c  + 48b c )d e  - 32b c d e  + 8c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R              4   12       3   2 11        3        2 2  3 10
+--R           32a d e   - 128a b d e   + (128a c + 192a b )d e
+--R         + 
+--R                  2            3  4 9        2 2         2       4  5 8
+--R           (- 384a b c - 128a b )d e  + (192a c  + 384a b c + 32b )d e
+--R         + 
+--R                      2       3   6 7          3       2 2  7 6         3 8 5
+--R           (- 384a b c  - 128b c)d e  + (128a c  + 192b c )d e  - 128b c d e
+--R         + 
+--R              4 9 4
+--R           32c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R              4 2 11       3   3 10        3        2 2  4 9
+--R           48a d e   - 192a b d e   + (192a c + 288a b )d e
+--R         + 
+--R                  2            3  5 8        2 2         2       4  6 7
+--R           (- 576a b c - 192a b )d e  + (288a c  + 576a b c + 48b )d e
+--R         + 
+--R                      2       3   7 6          3       2 2  8 5         3 9 4
+--R           (- 576a b c  - 192b c)d e  + (192a c  + 288b c )d e  - 192b c d e
+--R         + 
+--R              4 10 3
+--R           48c d  e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              4 3 10       3   4 9        3        2 2  5 8
+--R           32a d e   - 128a b d e  + (128a c + 192a b )d e
+--R         + 
+--R                  2            3  6 7        2 2         2       4  7 6
+--R           (- 384a b c - 128a b )d e  + (192a c  + 384a b c + 32b )d e
+--R         + 
+--R                      2       3   8 5          3       2 2  9 4         3 10 3
+--R           (- 384a b c  - 128b c)d e  + (128a c  + 192b c )d e  - 128b c d  e
+--R         + 
+--R              4 11 2
+--R           32c d  e
+--R      *
+--R         x
+--R     + 
+--R         4 4 9      3   5 8       3       2 2  6 7         2           3  7 6
+--R       8a d e  - 32a b d e  + (32a c + 48a b )d e  + (- 96a b c - 32a b )d e
+--R     + 
+--R           2 2        2      4  8 5             2      3   9 4
+--R       (48a c  + 96a b c + 8b )d e  + (- 96a b c  - 32b c)d e
+--R     + 
+--R             3      2 2  10 3        3 11 2     4 12
+--R       (32a c  + 48b c )d  e  - 32b c d  e  + 8c d  e
+--R                                                    Type: Expression(Integer)
+--E 4300
+
+--S 4301 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4301
+
+--S 4302 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R   (6)
+--R            4 8     3     7      3      2 2  2 6         2          3  3 5
+--R           a e  - 4a b d e  + (4a c + 6a b )d e  + (- 12a b c - 4a b )d e
+--R         + 
+--R              2 2        2     4  4 4             2     3   5 3
+--R           (6a c  + 12a b c + b )d e  + (- 12a b c  - 4b c)d e
+--R         + 
+--R                3     2 2  6 2       3 7     4 8
+--R           (4a c  + 6b c )d e  - 4b c d e + c d
+--R      *
+--R                   2           n
+--R         log(d (c x  + b x + a) )
+--R     + 
+--R                         3  8        2     2     7       2 2 6     3 3 5    4
+--R           ((- 2a b c + b )e  + (4a c  - 4b c)d e  + 6b c d e  - 4c d e )n x
+--R         + 
+--R                               3    7         2      2   2 6        2 3 5
+--R                 (- 8a b c + 4b )d e  + (16a c  - 16b c)d e  + 24b c d e
+--R               + 
+--R                      3 4 4
+--R                 - 16c d e
+--R          *
+--R                3
+--R             n x
+--R         + 
+--R                              3  2 6         2      2   3 5        2 4 4
+--R               (- 12a b c + 6b )d e  + (24a c  - 24b c)d e  + 36b c d e
+--R             + 
+--R                    3 5 3
+--R               - 24c d e
+--R          *
+--R                2
+--R             n x
+--R         + 
+--R                               3  3 5         2      2   4 4        2 5 3
+--R                 (- 8a b c + 4b )d e  + (16a c  - 16b c)d e  + 24b c d e
+--R               + 
+--R                      3 6 2
+--R                 - 16c d e
+--R          *
+--R             n x
+--R         + 
+--R                         3  4 4        2     2   5 3       2 6 2     3 7
+--R           ((- 2a b c + b )d e  + (4a c  - 4b c)d e  + 6b c d e  - 4c d e)n
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                         3  8        2     2     7       2 2 6     3 3 5    4
+--R           ((- 2a b c + b )e  + (4a c  - 4b c)d e  + 6b c d e  - 4c d e )n x
+--R         + 
+--R                               3    7         2      2   2 6        2 3 5
+--R                 (- 8a b c + 4b )d e  + (16a c  - 16b c)d e  + 24b c d e
+--R               + 
+--R                      3 4 4
+--R                 - 16c d e
+--R          *
+--R                3
+--R             n x
+--R         + 
+--R                              3  2 6         2      2   3 5        2 4 4
+--R               (- 12a b c + 6b )d e  + (24a c  - 24b c)d e  + 36b c d e
+--R             + 
+--R                    3 5 3
+--R               - 24c d e
+--R          *
+--R                2
+--R             n x
+--R         + 
+--R                               3  3 5         2      2   4 4        2 5 3
+--R                 (- 8a b c + 4b )d e  + (16a c  - 16b c)d e  + 24b c d e
+--R               + 
+--R                      3 6 2
+--R                 - 16c d e
+--R          *
+--R             n x
+--R         + 
+--R                         3  4 4        2     2   5 3       2 6 2     3 7
+--R           ((- 2a b c + b )d e  + (4a c  - 4b c)d e  + 6b c d e  - 4c d e)n
+--R      *
+--R                           +---------+
+--R          +---------+      |        2
+--R          |        2      \|4a c - b
+--R         \|4a c - b  atan(------------)
+--R                            2c x + b
+--R     + 
+--R              4 8     3     7        3      2 2  2 6       2          3  3 5
+--R           - a e  + 4a b d e  + (- 4a c - 6a b )d e  + (12a b c + 4a b )d e
+--R         + 
+--R                2 2        2     4  4 4           2     3   5 3
+--R           (- 6a c  - 12a b c - b )d e  + (12a b c  + 4b c)d e
+--R         + 
+--R                  3     2 2  6 2       3 7     4 8
+--R           (- 4a c  - 6b c )d e  + 4b c d e - c d
+--R      *
+--R                  2
+--R         n log(c x  + b x + a)
+--R     + 
+--R              4 8     3     7        3      2 2  2 6       2          3  3 5
+--R           - a e  + 4a b d e  + (- 4a c - 6a b )d e  + (12a b c + 4a b )d e
+--R         + 
+--R                2 2        2     4  4 4           2     3   5 3
+--R           (- 6a c  - 12a b c - b )d e  + (12a b c  + 4b c)d e
+--R         + 
+--R                  3     2 2  6 2       3 7     4 8
+--R           (- 4a c  - 6b c )d e  + 4b c d e - c d
+--R      *
+--R         log(d)
+--R  /
+--R             4 13      3     12       3       2 2  2 11
+--R           4a e   - 16a b d e   + (16a c + 24a b )d e
+--R         + 
+--R                 2           3  3 10       2 2        2      4  4 9
+--R           (- 48a b c - 16a b )d e   + (24a c  + 48a b c + 4b )d e
+--R         + 
+--R                   2      3   5 8         3      2 2  6 7        3 7 6     4 8 5
+--R         (- 48a b c  - 16b c)d e  + (16a c  + 24b c )d e  - 16b c d e  + 4c d e
+--R      *
+--R          4
+--R         x
+--R     + 
+--R              4   12      3   2 11       3       2 2  3 10
+--R           16a d e   - 64a b d e   + (64a c + 96a b )d e
+--R         + 
+--R                  2           3  4 9       2 2         2       4  5 8
+--R           (- 192a b c - 64a b )d e  + (96a c  + 192a b c + 16b )d e
+--R         + 
+--R                      2      3   6 7         3      2 2  7 6        3 8 5
+--R           (- 192a b c  - 64b c)d e  + (64a c  + 96b c )d e  - 64b c d e
+--R         + 
+--R              4 9 4
+--R           16c d e
+--R      *
+--R          3
+--R         x
+--R     + 
+--R              4 2 11      3   3 10       3        2 2  4 9
+--R           24a d e   - 96a b d e   + (96a c + 144a b )d e
+--R         + 
+--R                  2           3  5 8        2 2         2       4  6 7
+--R           (- 288a b c - 96a b )d e  + (144a c  + 288a b c + 24b )d e
+--R         + 
+--R                      2      3   7 6         3       2 2  8 5        3 9 4
+--R           (- 288a b c  - 96b c)d e  + (96a c  + 144b c )d e  - 96b c d e
+--R         + 
+--R              4 10 3
+--R           24c d  e
+--R      *
+--R          2
+--R         x
+--R     + 
+--R              4 3 10      3   4 9       3       2 2  5 8
+--R           16a d e   - 64a b d e  + (64a c + 96a b )d e
+--R         + 
+--R                  2           3  6 7       2 2         2       4  7 6
+--R           (- 192a b c - 64a b )d e  + (96a c  + 192a b c + 16b )d e
+--R         + 
+--R                      2      3   8 5         3      2 2  9 4        3 10 3
+--R           (- 192a b c  - 64b c)d e  + (64a c  + 96b c )d e  - 64b c d  e
+--R         + 
+--R              4 11 2
+--R           16c d  e
+--R      *
+--R         x
+--R     + 
+--R         4 4 9      3   5 8       3       2 2  6 7         2           3  7 6
+--R       4a d e  - 16a b d e  + (16a c + 24a b )d e  + (- 48a b c - 16a b )d e
+--R     + 
+--R           2 2        2      4  8 5             2      3   9 4
+--R       (24a c  + 48a b c + 4b )d e  + (- 48a b c  - 16b c)d e
+--R     + 
+--R             3      2 2  10 3        3 11 2     4 12
+--R       (16a c  + 24b c )d  e  - 16b c d  e  + 4c d  e
+--R                                                    Type: Expression(Integer)
+--E 4302
+
+--S 4303 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4303
+
+)clear all
+
+--S 4304 of 5341
+t0:=x^3*log(a+%e^x*b)
+--R 
+--R
+--R         3        x
+--R   (1)  x log(b %e  + a)
+--R                                                    Type: Expression(Integer)
+--E 4304
+
+--S 4305 of 5341
+--r0:=1/4*x^4*log(a+%e^x*b)-1/4*x^4*log(1+%e^x*b/a)-_
+--  x^3*polylog(2,-%e^x*b/a)+3*x^2*polylog(3,-%e^x*b/a)-_
+--  6*x*polylog(4,-%e^x*b/a)+6*polylog(5,-%e^x*b/a)
+--E 4305
+
+--S 4306 of 5341
+--a0:=integrate(t0,x)
+--E 4306
+
+--S 4307 of 5341
+--m0:=a0-r0
+--E 4307
+
+--S 4308 of 5341
+--d0:=D(m0,x)
+--E 4308
+
+)clear all
+
+--S 4309 of 5341
+t0:=x^2*log(a+%e^x*b)
+--R 
+--R
+--R         2        x
+--R   (1)  x log(b %e  + a)
+--R                                                    Type: Expression(Integer)
+--E 4309
+
+--S 4310 of 5341
+--r0:=1/3*x^3*log(a+%e^x*b)-1/3*x^3*log(1+%e^x*b/a)-x^2*_
+--  polylog(2,-%e^x*b/a)+2*x*polylog(3,-%e^x*b/a)-2*polylog(4,-%e^x*b/a)
+--E 4310
+
+--S 4311 of 5341
+--a0:=integrate(t0,x)
+--E 4311
+
+--S 4312 of 5341
+--m0:=a0-r0
+--E 4312
+
+--S 4313 of 5341
+--d0:=D(m0,x)
+--E 4313
+
+)clear all
+
+--S 4314 of 5341
+t0:=x*log(a+%e^x*b)
+--R 
+--R
+--R                  x
+--R   (1)  x log(b %e  + a)
+--R                                                    Type: Expression(Integer)
+--E 4314
+
+--S 4315 of 5341
+--r0:=1/2*x^2*log(a+%e^x*b)-1/2*x^2*log(1+%e^x*b/a)-_
+--  x*polylog(2,-%e^x*b/a)+polylog(3,-%e^x*b/a)
+--E 4315
+
+--S 4316 of 5341
+--a0:=integrate(t0,x)
+--E 4316
+
+--S 4317 of 5341
+--m0:=a0-r0
+--E 4317
+
+--S 4318 of 5341
+--d0:=D(m0,x)
+--E 4318
+
+)clear all
+
+--S 4319 of 5341
+t0:=log(a+%e^x*b)
+--R 
+--R
+--R                x
+--R   (1)  log(b %e  + a)
+--R                                                    Type: Expression(Integer)
+--E 4319
+
+--S 4320 of 5341
+--r0:=x*log(a+%e^x*b)-x*log(1+%e^x*b/a)-polylog(2,-%e^x*b/a)
+--E 4320
+
+--S 4321 of 5341
+--a0:=integrate(t0,x)
+--E 4321
+
+--S 4322 of 5341
+--m0:=a0-r0
+--E 4322
+
+--S 4323 of 5341
+--d0:=D(m0,x)
+--E 4323
+
+)clear all
+
+--S 4324 of 5341
+t0:=log(a+%e^x*b)/x
+--R 
+--R
+--R                x
+--R        log(b %e  + a)
+--R   (1)  --------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 4324
+
+--S 4325 of 5341
+--r0:=Int(log(a+%e^x*b)/x,x)
+--E 4325
+
+--S 4326 of 5341
+--a0:=integrate(t0,x)
+--E 4326
+
+--S 4327 of 5341
+--m0:=a0-r0
+--E 4327
+
+--S 4328 of 5341
+--d0:=D(m0,x)
+--E 4328
+
+)clear all
+
+--S 4329 of 5341
+t0:=x^3*log(1+e*(f^(c*(a+b*x)))^n)
+--R 
+--R
+--R         3       b c n x + a c n
+--R   (1)  x log(e f                + 1)
+--R                                                    Type: Expression(Integer)
+--E 4329
+
+--S 4330 of 5341
+--r0:=-x^3*polylog(2,-e*(f^(c*(a+b*x)))^n)/(b*c*n*log(f))+3*x^2*_
+--  polylog(3,-e*(f^(c*(a+b*x)))^n)/(b^2*c^2*n^2*log(f)^2)-6*x*_
+--  polylog(4,-e*(f^(c*(a+b*x)))^n)/(b^3*c^3*n^3*log(f)^3)+6*_
+--  polylog(5,-e*(f^(c*(a+b*x)))^n)/(b^4*c^4*n^4*log(f)^4)
+--E 4330
+
+--S 4331 of 5341
+--a0:=integrate(t0,x)
+--E 4331
+
+--S 4332 of 5341
+--m0:=a0-r0
+--E 4332
+
+--S 4333 of 5341
+--d0:=D(m0,x)
+--E 4333
+
+)clear all
+
+--S 4334 of 5341
+t0:=x^2*log(1+e*(f^(c*(a+b*x)))^n)
+--R 
+--R
+--R         2       b c n x + a c n
+--R   (1)  x log(e f                + 1)
+--R                                                    Type: Expression(Integer)
+--E 4334
+
+--S 4335 of 5341
+--r0:=-x^2*polylog(2,-e*(f^(c*(a+b*x)))^n)/(b*c*n*log(f))+2*x*_
+--  polylog(3,-e*(f^(c*(a+b*x)))^n)/(b^2*c^2*n^2*log(f)^2)-_
+--  2*polylog(4,-e*(f^(c*(a+b*x)))^n)/(b^3*c^3*n^3*log(f)^3)
+--E 4335
+
+--S 4336 of 5341
+--a0:=integrate(t0,x)
+--E 4336
+
+--S 4337 of 5341
+--m0:=a0-r0
+--E 4337
+
+--S 4338 of 5341
+--d0:=D(m0,x)
+--E 4338
+
+)clear all
+
+--S 4339 of 5341
+t0:=x*log(1+e*(f^(c*(a+b*x)))^n)
+--R 
+--R
+--R                 b c n x + a c n
+--R   (1)  x log(e f                + 1)
+--R                                                    Type: Expression(Integer)
+--E 4339
+
+--S 4340 of 5341
+--r0:=-x*polylog(2,-e*(f^(c*(a+b*x)))^n)/(b*c*n*log(f))+polylog(3,_
+--  -e*(f^(c*(a+b*x)))^n)/(b^2*c^2*n^2*log(f)^2)
+--E 4340
+
+--S 4341 of 5341
+--a0:=integrate(t0,x)
+--E 4341
+
+--S 4342 of 5341
+--m0:=a0-r0
+--E 4342
+
+--S 4343 of 5341
+--d0:=D(m0,x)
+--E 4343
+
+)clear all
+
+--S 4344 of 5341
+t0:=log(1+e*(f^(c*(a+b*x)))^n)
+--R 
+--R
+--R               b c n x + a c n
+--R   (1)  log(e f                + 1)
+--R                                                    Type: Expression(Integer)
+--E 4344
+
+--S 4345 of 5341
+--r0:=-polylog(2,-e*(f^(c*(a+b*x)))^n)/(b*c*n*log(f))
+--E 4345
+
+--S 4346 of 5341
+--a0:=integrate(t0,x)
+--E 4346
+
+--S 4347 of 5341
+--m0:=a0-r0
+--E 4347
+
+--S 4348 of 5341
+--d0:=D(m0,x)
+--E 4348
+
+)clear all
+
+--S 4349 of 5341
+t0:=log(1+e*(f^(c*(a+b*x)))^n)/x
+--R 
+--R
+--R               b c n x + a c n
+--R        log(e f                + 1)
+--R   (1)  ---------------------------
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 4349
+
+--S 4350 of 5341
+--r0:=Int(log(1+e*(f^(c*(a+b*x)))^n)/x,x)
+--E 4350
+
+--S 4351 of 5341
+--a0:=integrate(t0,x)
+--E 4351
+
+--S 4352 of 5341
+--m0:=a0-r0
+--E 4352
+
+--S 4353 of 5341
+--d0:=D(m0,x)
+--E 4353
+
+)clear all
+
+--S 4354 of 5341
+t0:=x^3*log(d+e*(f^(c*(a+b*x)))^n)
+--R 
+--R
+--R         3       b c n x + a c n
+--R   (1)  x log(e f                + d)
+--R                                                    Type: Expression(Integer)
+--E 4354
+
+--S 4355 of 5341
+--r0:=1/4*x^4*log(d+e*(f^(c*(a+b*x)))^n)-1/4*x^4*log(1+e*(f^(c*(a+_
+--  b*x)))^n/d)-x^3*polylog(2,-e*(f^(c*(a+b*x)))^n/d)/(b*c*n*log(f))+_
+--  3*x^2*polylog(3,-e*(f^(c*(a+b*x)))^n/d)/(b^2*c^2*n^2*log(f)^2)-_
+--  6*x*polylog(4,-e*(f^(c*(a+b*x)))^n/d)/(b^3*c^3*n^3*log(f)^3)+6*_
+--  polylog(5,-e*(f^(c*(a+b*x)))^n/d)/(b^4*c^4*n^4*log(f)^4)
+--E 4355
+
+--S 4356 of 5341
+--a0:=integrate(t0,x)
+--E 4356
+
+--S 4357 of 5341
+--m0:=a0-r0
+--E 4357
+
+--S 4358 of 5341
+--d0:=D(m0,x)
+--E 4358
+
+)clear all
+
+--S 4359 of 5341
+t0:=x^2*log(d+e*(f^(c*(a+b*x)))^n)
+--R 
+--R
+--R         2       b c n x + a c n
+--R   (1)  x log(e f                + d)
+--R                                                    Type: Expression(Integer)
+--E 4359
+
+--S 4360 of 5341
+--r0:=1/3*x^3*log(d+e*(f^(c*(a+b*x)))^n)-1/3*x^3*log(1+e*(f^(c*_
+--  (a+b*x)))^n/d)-x^2*polylog(2,-e*(f^(c*(a+b*x)))^n/d)/(b*c*n*_
+--  log(f))+2*x*polylog(3,-e*(f^(c*(a+b*x)))^n/d)/(b^2*c^2*n^2*_
+--  log(f)^2)-2*polylog(4,-e*(f^(c*(a+b*x)))^n/d)/(b^3*c^3*n^3*log(f)^3)
+--E 4360
+
+--S 4361 of 5341
+--a0:=integrate(t0,x)
+--E 4361
+
+--S 4362 of 5341
+--m0:=a0-r0
+--E 4362
+
+--S 4363 of 5341
+--d0:=D(m0,x)
+--E 4363
+
+)clear all
+
+--S 4364 of 5341
+t0:=x*log(d+e*(f^(c*(a+b*x)))^n)
+--R 
+--R
+--R                 b c n x + a c n
+--R   (1)  x log(e f                + d)
+--R                                                    Type: Expression(Integer)
+--E 4364
+
+--S 4365 of 5341
+--r0:=1/2*x^2*log(d+e*(f^(c*(a+b*x)))^n)-1/2*x^2*log(1+_
+--  e*(f^(c*(a+b*x)))^n/d)-x*polylog(2,-e*(f^(c*(a+b*x)))^n/d)/_
+--  (b*c*n*log(f))+polylog(3,-e*(f^(c*(a+b*x)))^n/d)/(b^2*c^2*n^2*log(f)^2)
+--E 4365
+
+--S 4366 of 5341
+--a0:=integrate(t0,x)
+--E 4366
+
+--S 4367 of 5341
+--m0:=a0-r0
+--E 4367
+
+--S 4368 of 5341
+--d0:=D(m0,x)
+--E 4368
+
+)clear all
+
+--S 4369 of 5341
+t0:=log(d+e*(f^(c*(a+b*x)))^n)
+--R 
+--R
+--R               b c n x + a c n
+--R   (1)  log(e f                + d)
+--R                                                    Type: Expression(Integer)
+--E 4369
+
+--S 4370 of 5341
+--r0:=x*log(d+e*(f^(c*(a+b*x)))^n)-x*log(1+e*(f^(c*(a+b*x)))^n/d)-_
+--  polylog(2,-e*(f^(c*(a+b*x)))^n/d)/(b*c*n*log(f))
+--E 4370
+
+--S 4371 of 5341
+--a0:=integrate(t0,x)
+--E 4371
+
+--S 4372 of 5341
+--m0:=a0-r0
+--E 4372
+
+--S 4373 of 5341
+--d0:=D(m0,x)
+--E 4373
+
+)clear all
+
+--S 4374 of 5341
+t0:=log(d+e*(f^(c*(a+b*x)))^n)/x
+--R 
+--R
+--R               b c n x + a c n
+--R        log(e f                + d)
+--R   (1)  ---------------------------
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 4374
+
+--S 4375 of 5341
+--r0:=Int(log(d+e*(f^(c*(a+b*x)))^n)/x,x)
+--E 4375
+
+--S 4376 of 5341
+--a0:=integrate(t0,x)
+--E 4376
+
+--S 4377 of 5341
+--m0:=a0-r0
+--E 4377
+
+--S 4378 of 5341
+--d0:=D(m0,x)
+--E 4378
+
+)clear all
+
+--S 4379 of 5341
+t0:=log(x)*sin(a+b*x)
+--R 
+--R
+--R   (1)  log(x)sin(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 4379
+
+--S 4380 of 5341
+r0:=Ci(b*x)*cos(a)/b-cos(a+b*x)*log(x)/b-Si(b*x)*sin(a)/b
+--R 
+--R
+--R        - Si(b x)sin(a) - cos(b x + a)log(x) + Ci(b x)cos(a)
+--R   (2)  ----------------------------------------------------
+--R                                  b
+--R                                                    Type: Expression(Integer)
+--E 4380
+
+--S 4381 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x
+--R         ++
+--R   (3)   |   log(%H)sin(%H b + a)d%H
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 4381
+
+--S 4382 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           x
+--R         ++
+--R       b |   log(%H)sin(%H b + a)d%H  + Si(b x)sin(a) + cos(b x + a)log(x)
+--R        ++
+--R     + 
+--R       - Ci(b x)cos(a)
+--R  /
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 4382
+
+--S 4383 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4383
+
+)clear all
+
+--S 4384 of 5341
+t0:=log(x)*sin(a+b*x)^2
+--R 
+--R
+--R                          2
+--R   (1)  log(x)sin(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 4384
+
+--S 4385 of 5341
+r0:=-1/2*x+1/2*x*log(x)+1/4*cos(2*a)*Si(2*b*x)/b+1/4*Ci(2*b*x)*sin(2*a)/b-_
+   1/2*cos(a+b*x)*log(x)*sin(a+b*x)/b
+--R 
+--R
+--R   (2)
+--R       - 2cos(b x + a)log(x)sin(b x + a) + Ci(2b x)sin(2a) + 2b x log(x)
+--R     + 
+--R       Si(2b x)cos(2a) - 2b x
+--R  /
+--R     4b
+--R                                                    Type: Expression(Integer)
+--E 4385
+
+--S 4386 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x
+--R         ++                      2
+--R   (3)   |   log(%H)sin(%H b + a) d%H
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 4386
+
+--S 4387 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            x
+--R          ++                      2
+--R       4b |   log(%H)sin(%H b + a) d%H  + 2cos(b x + a)log(x)sin(b x + a)
+--R         ++
+--R     + 
+--R       - Ci(2b x)sin(2a) - 2b x log(x) - Si(2b x)cos(2a) + 2b x
+--R  /
+--R     4b
+--R                                                    Type: Expression(Integer)
+--E 4387
+
+--S 4388 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4388
+
+)clear all
+
+--S 4389 of 5341
+t0:=log(x)*sin(a+b*x)^3
+--R 
+--R
+--R                          3
+--R   (1)  log(x)sin(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 4389
+
+--S 4390 of 5341
+r0:=3/4*Ci(b*x)*cos(a)/b-1/12*Ci(3*b*x)*cos(3*a)/b-cos(a+b*x)*log(x)/b+_
+   1/3*cos(a+b*x)^3*log(x)/b-3/4*Si(b*x)*sin(a)/b+1/12*Si(3*b*x)*sin(3*a)/b
+--R 
+--R
+--R   (2)
+--R       Si(3b x)sin(3a) - 9Si(b x)sin(a)
+--R     + 
+--R                   3
+--R     (4cos(b x + a)  - 12cos(b x + a))log(x) - Ci(3b x)cos(3a) + 9Ci(b x)cos(a)
+--R  /
+--R     12b
+--R                                                    Type: Expression(Integer)
+--E 4390
+
+--S 4391 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x
+--R         ++                      3
+--R   (3)   |   log(%H)sin(%H b + a) d%H
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 4391
+
+--S 4392 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             x
+--R           ++                      3
+--R       12b |   log(%H)sin(%H b + a) d%H  - Si(3b x)sin(3a) + 9Si(b x)sin(a)
+--R          ++
+--R     + 
+--R                       3
+--R       (- 4cos(b x + a)  + 12cos(b x + a))log(x) + Ci(3b x)cos(3a)
+--R     + 
+--R       - 9Ci(b x)cos(a)
+--R  /
+--R     12b
+--R                                                    Type: Expression(Integer)
+--E 4392
+
+--S 4393 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                 a 4        a 2         3a 2
+--R           (9tan(-)  - 6tan(-)  + 1)tan(--)
+--R                 2          2            2
+--R         + 
+--R                   a 5         a 3        a      3a        a 6        a 4
+--R           (- 6tan(-)  + 20tan(-)  - 6tan(-))tan(--) + tan(-)  - 6tan(-)
+--R                   2           2          2       2        2          2
+--R         + 
+--R                a 2
+--R           9tan(-)
+--R                2
+--R      *
+--R             b x + a 6
+--R         tan(-------)
+--R                2
+--R     + 
+--R                  a 5         a 3         a      3a 2
+--R           (18tan(-)  - 60tan(-)  + 18tan(-))tan(--)
+--R                  2           2           2       2
+--R         + 
+--R                   a 6         a 4         a 2         3a          a 5
+--R           (- 6tan(-)  + 90tan(-)  - 90tan(-)  + 6)tan(--) - 18tan(-)
+--R                   2           2           2            2          2
+--R         + 
+--R                 a 3         a
+--R           60tan(-)  - 18tan(-)
+--R                 2           2
+--R      *
+--R             b x + a 5
+--R         tan(-------)
+--R                2
+--R     + 
+--R                     a 4         a 2          3a 2
+--R           (- 135tan(-)  + 90tan(-)  - 15)tan(--)
+--R                     2           2             2
+--R         + 
+--R                  a 5          a 3         a      3a          a 6         a 4
+--R           (90tan(-)  - 300tan(-)  + 90tan(-))tan(--) - 15tan(-)  + 90tan(-)
+--R                  2            2           2       2          2           2
+--R         + 
+--R                    a 2
+--R           - 135tan(-)
+--R                    2
+--R      *
+--R             b x + a 4
+--R         tan(-------)
+--R                2
+--R     + 
+--R                    a 5          a 3         a      3a 2
+--R           (- 60tan(-)  + 200tan(-)  - 60tan(-))tan(--)
+--R                    2            2           2       2
+--R         + 
+--R                  a 6          a 4          a 2          3a          a 5
+--R           (20tan(-)  - 300tan(-)  + 300tan(-)  - 20)tan(--) + 60tan(-)
+--R                  2            2            2             2          2
+--R         + 
+--R                    a 3         a
+--R           - 200tan(-)  + 60tan(-)
+--R                    2           2
+--R      *
+--R             b x + a 3
+--R         tan(-------)
+--R                2
+--R     + 
+--R                   a 4         a 2          3a 2
+--R           (135tan(-)  - 90tan(-)  + 15)tan(--)
+--R                   2           2             2
+--R         + 
+--R                    a 5          a 3         a      3a          a 6         a 4
+--R           (- 90tan(-)  + 300tan(-)  - 90tan(-))tan(--) + 15tan(-)  - 90tan(-)
+--R                    2            2           2       2          2           2
+--R         + 
+--R                  a 2
+--R           135tan(-)
+--R                  2
+--R      *
+--R             b x + a 2
+--R         tan(-------)
+--R                2
+--R     + 
+--R                  a 5         a 3         a      3a 2
+--R           (18tan(-)  - 60tan(-)  + 18tan(-))tan(--)
+--R                  2           2           2       2
+--R         + 
+--R                   a 6         a 4         a 2         3a          a 5
+--R           (- 6tan(-)  + 90tan(-)  - 90tan(-)  + 6)tan(--) - 18tan(-)
+--R                   2           2           2            2          2
+--R         + 
+--R                 a 3         a
+--R           60tan(-)  - 18tan(-)
+--R                 2           2
+--R      *
+--R             b x + a
+--R         tan(-------)
+--R                2
+--R     + 
+--R               a 4        a 2         3a 2
+--R       (- 9tan(-)  + 6tan(-)  - 1)tan(--)
+--R               2          2            2
+--R     + 
+--R             a 5         a 3        a      3a        a 6        a 4        a 2
+--R       (6tan(-)  - 20tan(-)  + 6tan(-))tan(--) - tan(-)  + 6tan(-)  - 9tan(-)
+--R             2           2          2       2        2          2          2
+--R  /
+--R                     a 6             a 4             a 2            3a 2
+--R           (6b x tan(-)  + 18b x tan(-)  + 18b x tan(-)  + 6b x)tan(--)
+--R                     2               2               2               2
+--R         + 
+--R                    a 6             a 4             a 2
+--R           6b x tan(-)  + 18b x tan(-)  + 18b x tan(-)  + 6b x
+--R                    2               2               2
+--R      *
+--R             b x + a 6
+--R         tan(-------)
+--R                2
+--R     + 
+--R                      a 6             a 4             a 2             3a 2
+--R           (18b x tan(-)  + 54b x tan(-)  + 54b x tan(-)  + 18b x)tan(--)
+--R                      2               2               2                2
+--R         + 
+--R                     a 6             a 4             a 2
+--R           18b x tan(-)  + 54b x tan(-)  + 54b x tan(-)  + 18b x
+--R                     2               2               2
+--R      *
+--R             b x + a 4
+--R         tan(-------)
+--R                2
+--R     + 
+--R                      a 6             a 4             a 2             3a 2
+--R           (18b x tan(-)  + 54b x tan(-)  + 54b x tan(-)  + 18b x)tan(--)
+--R                      2               2               2                2
+--R         + 
+--R                     a 6             a 4             a 2
+--R           18b x tan(-)  + 54b x tan(-)  + 54b x tan(-)  + 18b x
+--R                     2               2               2
+--R      *
+--R             b x + a 2
+--R         tan(-------)
+--R                2
+--R     + 
+--R                 a 6             a 4             a 2            3a 2
+--R       (6b x tan(-)  + 18b x tan(-)  + 18b x tan(-)  + 6b x)tan(--)
+--R                 2               2               2               2
+--R     + 
+--R                a 6             a 4             a 2
+--R       6b x tan(-)  + 18b x tan(-)  + 18b x tan(-)  + 6b x
+--R                2               2               2
+--R                                                    Type: Expression(Integer)
+--E 4393
+
+)clear all
+
+--S 4394 of 5341
+t0:=cos(a+b*x)*log(x)
+--R 
+--R
+--R   (1)  cos(b x + a)log(x)
+--R                                                    Type: Expression(Integer)
+--E 4394
+
+--S 4395 of 5341
+r0:=-cos(a)*Si(b*x)/b-Ci(b*x)*sin(a)/b+log(x)*sin(a+b*x)/b
+--R 
+--R
+--R        log(x)sin(b x + a) - Ci(b x)sin(a) - Si(b x)cos(a)
+--R   (2)  --------------------------------------------------
+--R                                 b
+--R                                                    Type: Expression(Integer)
+--E 4395
+
+--S 4396 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x
+--R         ++
+--R   (3)   |   cos(%H b + a)log(%H)d%H
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 4396
+
+--S 4397 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R           x
+--R         ++
+--R       b |   cos(%H b + a)log(%H)d%H  - log(x)sin(b x + a) + Ci(b x)sin(a)
+--R        ++
+--R     + 
+--R       Si(b x)cos(a)
+--R  /
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 4397
+
+--S 4398 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4398
+
+)clear all
+
+--S 4399 of 5341
+t0:=cos(a+b*x)^2*log(x)
+--R 
+--R
+--R                    2
+--R   (1)  cos(b x + a) log(x)
+--R                                                    Type: Expression(Integer)
+--E 4399
+
+--S 4400 of 5341
+r0:=-1/2*x+1/2*x*log(x)-1/4*cos(2*a)*Si(2*b*x)/b-1/4*Ci(2*b*x)*sin(2*a)/b+_
+   1/2*cos(a+b*x)*log(x)*sin(a+b*x)/b
+--R 
+--R
+--R   (2)
+--R       2cos(b x + a)log(x)sin(b x + a) - Ci(2b x)sin(2a) + 2b x log(x)
+--R     + 
+--R       - Si(2b x)cos(2a) - 2b x
+--R  /
+--R     4b
+--R                                                    Type: Expression(Integer)
+--E 4400
+
+--S 4401 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x
+--R         ++               2
+--R   (3)   |   cos(%H b + a) log(%H)d%H
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 4401
+
+--S 4402 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            x
+--R          ++               2
+--R       4b |   cos(%H b + a) log(%H)d%H  - 2cos(b x + a)log(x)sin(b x + a)
+--R         ++
+--R     + 
+--R       Ci(2b x)sin(2a) - 2b x log(x) + Si(2b x)cos(2a) + 2b x
+--R  /
+--R     4b
+--R                                                    Type: Expression(Integer)
+--E 4402
+
+--S 4403 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4403
+
+)clear all
+
+--S 4404 of 5341
+t0:=cos(a+b*x)^3*log(x)
+--R 
+--R
+--R                    3
+--R   (1)  cos(b x + a) log(x)
+--R                                                    Type: Expression(Integer)
+--E 4404
+
+--S 4405 of 5341
+r0:=-3/4*cos(a)*Si(b*x)/b-1/12*cos(3*a)*Si(3*b*x)/b-3/4*Ci(b*x)*sin(a)/b-_
+   1/12*Ci(3*b*x)*sin(3*a)/b+log(x)*sin(a+b*x)/b-1/3*log(x)*sin(a+b*x)^3/b
+--R 
+--R
+--R   (2)
+--R                            3
+--R       - 4log(x)sin(b x + a)  + 12log(x)sin(b x + a) - Ci(3b x)sin(3a)
+--R     + 
+--R       - 9Ci(b x)sin(a) - Si(3b x)cos(3a) - 9Si(b x)cos(a)
+--R  /
+--R     12b
+--R                                                    Type: Expression(Integer)
+--E 4405
+
+--S 4406 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           x
+--R         ++               3
+--R   (3)   |   cos(%H b + a) log(%H)d%H
+--R        ++
+--R                                         Type: Union(Expression(Integer),...)
+--E 4406
+
+--S 4407 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R             x
+--R           ++               3                                 3
+--R       12b |   cos(%H b + a) log(%H)d%H  + 4log(x)sin(b x + a)
+--R          ++
+--R     + 
+--R       - 12log(x)sin(b x + a) + Ci(3b x)sin(3a) + 9Ci(b x)sin(a)
+--R     + 
+--R       Si(3b x)cos(3a) + 9Si(b x)cos(a)
+--R  /
+--R     12b
+--R                                                    Type: Expression(Integer)
+--E 4407
+
+--S 4408 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                 a 5         a 3        a      3a 2
+--R           (3tan(-)  - 10tan(-)  + 3tan(-))tan(--)
+--R                 2           2          2       2
+--R         + 
+--R                  a 6         a 4         a 2         3a         a 5         a 3
+--R           (- tan(-)  + 15tan(-)  - 15tan(-)  + 1)tan(--) - 3tan(-)  + 10tan(-)
+--R                  2           2           2            2         2           2
+--R         + 
+--R                  a
+--R           - 3tan(-)
+--R                  2
+--R      *
+--R             b x + a 6
+--R         tan(-------)
+--R                2
+--R     + 
+--R                    a 4         a 2         3a 2
+--R           (- 54tan(-)  + 36tan(-)  - 6)tan(--)
+--R                    2           2            2
+--R         + 
+--R                  a 5          a 3         a      3a         a 6         a 4
+--R           (36tan(-)  - 120tan(-)  + 36tan(-))tan(--) - 6tan(-)  + 36tan(-)
+--R                  2            2           2       2         2           2
+--R         + 
+--R                   a 2
+--R           - 54tan(-)
+--R                   2
+--R      *
+--R             b x + a 5
+--R         tan(-------)
+--R                2
+--R     + 
+--R                    a 5          a 3         a      3a 2
+--R           (- 45tan(-)  + 150tan(-)  - 45tan(-))tan(--)
+--R                    2            2           2       2
+--R         + 
+--R                  a 6          a 4          a 2          3a          a 5
+--R           (15tan(-)  - 225tan(-)  + 225tan(-)  - 15)tan(--) + 45tan(-)
+--R                  2            2            2             2          2
+--R         + 
+--R                    a 3         a
+--R           - 150tan(-)  + 45tan(-)
+--R                    2           2
+--R      *
+--R             b x + a 4
+--R         tan(-------)
+--R                2
+--R     + 
+--R                   a 4          a 2          3a 2
+--R           (180tan(-)  - 120tan(-)  + 20)tan(--)
+--R                   2            2             2
+--R         + 
+--R                     a 5          a 3          a      3a          a 6
+--R           (- 120tan(-)  + 400tan(-)  - 120tan(-))tan(--) + 20tan(-)
+--R                     2            2            2       2          2
+--R         + 
+--R                    a 4          a 2
+--R           - 120tan(-)  + 180tan(-)
+--R                    2            2
+--R      *
+--R             b x + a 3
+--R         tan(-------)
+--R                2
+--R     + 
+--R                  a 5          a 3         a      3a 2
+--R           (45tan(-)  - 150tan(-)  + 45tan(-))tan(--)
+--R                  2            2           2       2
+--R         + 
+--R                    a 6          a 4          a 2          3a          a 5
+--R           (- 15tan(-)  + 225tan(-)  - 225tan(-)  + 15)tan(--) - 45tan(-)
+--R                    2            2            2             2          2
+--R         + 
+--R                  a 3         a
+--R           150tan(-)  - 45tan(-)
+--R                  2           2
+--R      *
+--R             b x + a 2
+--R         tan(-------)
+--R                2
+--R     + 
+--R                    a 4         a 2         3a 2
+--R           (- 54tan(-)  + 36tan(-)  - 6)tan(--)
+--R                    2           2            2
+--R         + 
+--R                  a 5          a 3         a      3a         a 6         a 4
+--R           (36tan(-)  - 120tan(-)  + 36tan(-))tan(--) - 6tan(-)  + 36tan(-)
+--R                  2            2           2       2         2           2
+--R         + 
+--R                   a 2
+--R           - 54tan(-)
+--R                   2
+--R      *
+--R             b x + a
+--R         tan(-------)
+--R                2
+--R     + 
+--R               a 5         a 3        a      3a 2
+--R       (- 3tan(-)  + 10tan(-)  - 3tan(-))tan(--)
+--R               2           2          2       2
+--R     + 
+--R            a 6         a 4         a 2         3a         a 5         a 3
+--R       (tan(-)  - 15tan(-)  + 15tan(-)  - 1)tan(--) + 3tan(-)  - 10tan(-)
+--R            2           2           2            2         2           2
+--R     + 
+--R            a
+--R       3tan(-)
+--R            2
+--R  /
+--R                     a 6             a 4             a 2            3a 2
+--R           (6b x tan(-)  + 18b x tan(-)  + 18b x tan(-)  + 6b x)tan(--)
+--R                     2               2               2               2
+--R         + 
+--R                    a 6             a 4             a 2
+--R           6b x tan(-)  + 18b x tan(-)  + 18b x tan(-)  + 6b x
+--R                    2               2               2
+--R      *
+--R             b x + a 6
+--R         tan(-------)
+--R                2
+--R     + 
+--R                      a 6             a 4             a 2             3a 2
+--R           (18b x tan(-)  + 54b x tan(-)  + 54b x tan(-)  + 18b x)tan(--)
+--R                      2               2               2                2
+--R         + 
+--R                     a 6             a 4             a 2
+--R           18b x tan(-)  + 54b x tan(-)  + 54b x tan(-)  + 18b x
+--R                     2               2               2
+--R      *
+--R             b x + a 4
+--R         tan(-------)
+--R                2
+--R     + 
+--R                      a 6             a 4             a 2             3a 2
+--R           (18b x tan(-)  + 54b x tan(-)  + 54b x tan(-)  + 18b x)tan(--)
+--R                      2               2               2                2
+--R         + 
+--R                     a 6             a 4             a 2
+--R           18b x tan(-)  + 54b x tan(-)  + 54b x tan(-)  + 18b x
+--R                     2               2               2
+--R      *
+--R             b x + a 2
+--R         tan(-------)
+--R                2
+--R     + 
+--R                 a 6             a 4             a 2            3a 2
+--R       (6b x tan(-)  + 18b x tan(-)  + 18b x tan(-)  + 6b x)tan(--)
+--R                 2               2               2               2
+--R     + 
+--R                a 6             a 4             a 2
+--R       6b x tan(-)  + 18b x tan(-)  + 18b x tan(-)  + 6b x
+--R                2               2               2
+--R                                                    Type: Expression(Integer)
+--E 4408
+
+)clear all
+
+--S 4409 of 5341
+t0:=cos(x)*log(x)+sin(x)/x
+--R 
+--R
+--R        sin(x) + x cos(x)log(x)
+--R   (1)  -----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 4409
+
+--S 4410 of 5341
+r0:=log(x)*sin(x)
+--R 
+--R
+--R   (2)  log(x)sin(x)
+--R                                                    Type: Expression(Integer)
+--E 4410
+
+--S 4411 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  log(x)sin(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 4411
+
+--S 4412 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4412
+
+--S 4413 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4413
+
+)clear all
+
+--S 4414 of 5341
+t0:=log(a*sin(x))
+--R 
+--R
+--R   (1)  log(a sin(x))
+--R                                                    Type: Expression(Integer)
+--E 4414
+
+--S 4415 of 5341
+--r0:=1/2*%i*x^2-x*log(1-%e^(2*%i*x))+x*log(a*sin(x))+_
+--  1/2*%i*polylog(2,%e^(2*%i*x))
+--E 4415
+
+--S 4416 of 5341
+--a0:=integrate(t0,x)
+--E 4416
+
+--S 4417 of 5341
+--m0:=a0-r0
+--E 4417
+
+--S 4418 of 5341
+--d0:=D(m0,x)
+--E 4418
+
+)clear all
+
+--S 4419 of 5341
+t0:=log(a*sin(x)^2)
+--R 
+--R
+--R                    2
+--R   (1)  log(a sin(x) )
+--R                                                    Type: Expression(Integer)
+--E 4419
+
+--S 4420 of 5341
+--r0:=%i*x^2-2*x*log(1-%e^(2*%i*x))+x*log(a*sin(x)^2)+%i*polylog(2,%e^(2*%i*x))
+--E 4420
+
+--S 4421 of 5341
+--a0:=integrate(t0,x)
+--E 4421
+
+--S 4422 of 5341
+--m0:=a0-r0
+--E 4422
+
+--S 4423 of 5341
+--d0:=D(m0,x)
+--E 4423
+
+)clear all
+
+--S 4424 of 5341
+t0:=log(a*sin(x)^n)
+--R 
+--R
+--R                    n
+--R   (1)  log(a sin(x) )
+--R                                                    Type: Expression(Integer)
+--E 4424
+
+--S 4425 of 5341
+--r0:=1/2*%i*n*x^2-n*x*log(1-%e^(2*%i*x))+x*log(a*sin(x)^n)+_
+--  1/2*%i*n*polylog(2,%e^(2*%i*x))
+--E 4425
+
+--S 4426 of 5341
+--a0:=integrate(t0,x)
+--E 4426
+
+--S 4427 of 5341
+--m0:=a0-r0
+--E 4427
+
+--S 4428 of 5341
+--d0:=D(m0,x)
+--E 4428
+
+)clear all
+
+--S 4429 of 5341
+t0:=log(a*cos(x))
+--R 
+--R
+--R   (1)  log(a cos(x))
+--R                                                    Type: Expression(Integer)
+--E 4429
+
+--S 4430 of 5341
+--r0:=1/2*%i*x^2-x*log(1+%e^(2*%i*x))+x*log(a*cos(x))+1/2*%i*_
+--  polylog(2,-%e^(2*%i*x))
+--E 4430
+
+--S 4431 of 5341
+--a0:=integrate(t0,x)
+--E 4431
+
+--S 4432 of 5341
+--m0:=a0-r0
+--E 4432
+
+--S 4433 of 5341
+--d0:=D(m0,x)
+--E 4433
+
+)clear all
+
+--S 4434 of 5341
+t0:=log(a*cos(x)^2)
+--R 
+--R
+--R                    2
+--R   (1)  log(a cos(x) )
+--R                                                    Type: Expression(Integer)
+--E 4434
+
+--S 4435 of 5341
+--r0:=%i*x^2-2*x*log(1+%e^(2*%i*x))+x*log(a*cos(x)^2)+%i*_
+--  polylog(2,-%e^(2*%i*x))
+--E 4435
+
+--S 4436 of 5341
+--a0:=integrate(t0,x)
+--E 4436
+
+--S 4437 of 5341
+--m0:=a0-r0
+--E 4437
+
+--S 4438 of 5341
+--d0:=D(m0,x)
+--E 4438
+
+)clear all
+
+--S 4439 of 5341
+t0:=log(a*cos(x)^n)
+--R 
+--R
+--R                    n
+--R   (1)  log(a cos(x) )
+--R                                                    Type: Expression(Integer)
+--E 4439
+
+--S 4440 of 5341
+--r0:=1/2*%i*n*x^2-n*x*log(1+%e^(2*%i*x))+x*log(a*cos(x)^n)+_
+--  1/2*%i*n*polylog(2,-%e^(2*%i*x))
+--E 4440
+
+--S 4441 of 5341
+--a0:=integrate(t0,x)
+--E 4441
+
+--S 4442 of 5341
+--m0:=a0-r0
+--E 4442
+
+--S 4443 of 5341
+--d0:=D(m0,x)
+--E 4443
+
+)clear all
+
+--S 4444 of 5341
+t0:=log(a*tan(x))
+--R 
+--R
+--R   (1)  log(a tan(x))
+--R                                                    Type: Expression(Integer)
+--E 4444
+
+--S 4445 of 5341
+--r0:=2*x*atanh(%e^(2*%i*x))+x*log(a*tan(x))-1/2*%i*polylog(2,_
+--  -%e^(2*%i*x))+1/2*%i*polylog(2,%e^(2*%i*x))
+--E 4445
+
+--S 4446 of 5341
+--a0:=integrate(t0,x)
+--E 4446
+
+--S 4447 of 5341
+--m0:=a0-r0
+--E 4447
+
+--S 4448 of 5341
+--d0:=D(m0,x)
+--E 4448
+
+)clear all
+
+--S 4449 of 5341
+t0:=log(a*tan(x)^2)
+--R 
+--R
+--R                    2
+--R   (1)  log(a tan(x) )
+--R                                                    Type: Expression(Integer)
+--E 4449
+
+--S 4450 of 5341
+--r0:=4*x*atanh(%e^(2*%i*x))+x*log(a*tan(x)^2)-%i*polylog(2,-%e^(2*%i*x))+_
+--  %i*polylog(2,%e^(2*%i*x))
+--E 4450
+
+--S 4451 of 5341
+--a0:=integrate(t0,x)
+--E 4451
+
+--S 4452 of 5341
+--m0:=a0-r0
+--E 4452
+
+--S 4453 of 5341
+--d0:=D(m0,x)
+--E 4453
+
+)clear all
+
+--S 4454 of 5341
+t0:=log(a*tan(x)^n)
+--R 
+--R
+--R                    n
+--R   (1)  log(a tan(x) )
+--R                                                    Type: Expression(Integer)
+--E 4454
+
+--S 4455 of 5341
+--r0:=2*n*x*atanh(%e^(2*%i*x))+x*log(a*tan(x)^n)-1/2*%i*n*_
+--  polylog(2,-%e^(2*%i*x))+1/2*%i*n*polylog(2,%e^(2*%i*x))
+--E 4455
+
+--S 4456 of 5341
+--a0:=integrate(t0,x)
+--E 4456
+
+--S 4457 of 5341
+--m0:=a0-r0
+--E 4457
+
+--S 4458 of 5341
+--d0:=D(m0,x)
+--E 4458
+
+)clear all
+
+--S 4459 of 5341
+t0:=log(a*cot(x))
+--R 
+--R
+--R   (1)  log(a cot(x))
+--R                                                    Type: Expression(Integer)
+--E 4459
+
+--S 4460 of 5341
+--r0:=-2*x*atanh(%e^(2*%i*x))+x*log(a*cot(x))+1/2*%i*_
+--  polylog(2,-%e^(2*%i*x))-1/2*%i*polylog(2,%e^(2*%i*x))
+--E 4460
+
+--S 4461 of 5341
+--a0:=integrate(t0,x)
+--E 4461
+
+--S 4462 of 5341
+--m0:=a0-r0
+--E 4462
+
+--S 4463 of 5341
+--d0:=D(m0,x)
+--E 4463
+
+)clear all
+
+--S 4464 of 5341
+t0:=log(a*cot(x)^2)
+--R 
+--R
+--R                    2
+--R   (1)  log(a cot(x) )
+--R                                                    Type: Expression(Integer)
+--E 4464
+
+--S 4465 of 5341
+--r0:=-4*x*atanh(%e^(2*%i*x))+x*log(a*cot(x)^2)+%i*polylog(2,-%e^(2*%i*x))-_
+--  %i*polylog(2,%e^(2*%i*x))
+--E 4465
+
+--S 4466 of 5341
+--a0:=integrate(t0,x)
+--E 4466
+
+--S 4467 of 5341
+--m0:=a0-r0
+--E 4467
+
+--S 4468 of 5341
+--d0:=D(m0,x)
+--E 4468
+
+)clear all
+
+--S 4469 of 5341
+t0:=log(a*cot(x)^n)
+--R 
+--R
+--R                    n
+--R   (1)  log(a cot(x) )
+--R                                                    Type: Expression(Integer)
+--E 4469
+
+--S 4470 of 5341
+--r0:=-2*n*x*atanh(%e^(2*%i*x))+x*log(a*cot(x)^n)+1/2*%i*n*_
+--  polylog(2,-%e^(2*%i*x))-1/2*%i*n*polylog(2,%e^(2*%i*x))
+--E 4470
+
+--S 4471 of 5341
+--a0:=integrate(t0,x)
+--E 4471
+
+--S 4472 of 5341
+--m0:=a0-r0
+--E 4472
+
+--S 4473 of 5341
+--d0:=D(m0,x)
+--E 4473
+
+)clear all
+
+--S 4474 of 5341
+t0:=log(a*sec(x))
+--R 
+--R
+--R   (1)  log(a sec(x))
+--R                                                    Type: Expression(Integer)
+--E 4474
+
+--S 4475 of 5341
+--r0:=-1/2*%i*x^2+x*log(1+%e^(2*%i*x))+x*log(a*sec(x))-_
+--  1/2*%i*polylog(2,-%e^(2*%i*x))
+--E 4475
+
+--S 4476 of 5341
+--a0:=integrate(t0,x)
+--E 4476
+
+--S 4477 of 5341
+--m0:=a0-r0
+--E 4477
+
+--S 4478 of 5341
+--d0:=D(m0,x)
+--E 4478
+
+)clear all
+
+--S 4479 of 5341
+t0:=log(a*sec(x)^2)
+--R 
+--R
+--R                    2
+--R   (1)  log(a sec(x) )
+--R                                                    Type: Expression(Integer)
+--E 4479
+
+--S 4480 of 5341
+--r0:=-%i*x^2+2*x*log(1+%e^(2*%i*x))+x*log(a*sec(x)^2)-_
+--  %i*polylog(2,-%e^(2*%i*x))
+--E 4480
+
+--S 4481 of 5341
+--a0:=integrate(t0,x)
+--E 4481
+
+--S 4482 of 5341
+--m0:=a0-r0
+--E 4482
+
+--S 4483 of 5341
+--d0:=D(m0,x)
+--E 4483
+
+)clear all
+
+--S 4484 of 5341
+t0:=log(a*sec(x)^n)
+--R 
+--R
+--R                    n
+--R   (1)  log(a sec(x) )
+--R                                                    Type: Expression(Integer)
+--E 4484
+
+--S 4485 of 5341
+--r0:=-1/2*%i*n*x^2+n*x*log(1+%e^(2*%i*x))+x*log(a*sec(x)^n)-_
+--  1/2*%i*n*polylog(2,-%e^(2*%i*x))
+--E 4485
+
+--S 4486 of 5341
+--a0:=integrate(t0,x)
+--E 4486
+
+--S 4487 of 5341
+--m0:=a0-r0
+--E 4487
+
+--S 4488 of 5341
+--d0:=D(m0,x)
+--E 4488
+
+)clear all
+
+--S 4489 of 5341
+t0:=log(a*csc(x))
+--R 
+--R
+--R   (1)  log(a csc(x))
+--R                                                    Type: Expression(Integer)
+--E 4489
+
+--S 4490 of 5341
+--r0:=-1/2*%i*x^2+x*log(1-%e^(2*%i*x))+x*log(a*csc(x))-_
+--  1/2*%i*polylog(2,%e^(2*%i*x))
+--E 4490
+
+--S 4491 of 5341
+--a0:=integrate(t0,x)
+--E 4491
+
+--S 4492 of 5341
+--m0:=a0-r0
+--E 4492
+
+--S 4493 of 5341
+--d0:=D(m0,x)
+--E 4493
+
+)clear all
+
+--S 4494 of 5341
+t0:=log(a*csc(x)^2)
+--R 
+--R
+--R                    2
+--R   (1)  log(a csc(x) )
+--R                                                    Type: Expression(Integer)
+--E 4494
+
+--S 4495 of 5341
+--r0:=-%i*x^2+2*x*log(1-%e^(2*%i*x))+x*log(a*csc(x)^2)-_
+--  %i*polylog(2,%e^(2*%i*x))
+--E 4495
+
+--S 4496 of 5341
+--a0:=integrate(t0,x)
+--E 4496
+
+--S 4497 of 5341
+--m0:=a0-r0
+--E 4497
+
+--S 4498 of 5341
+--d0:=D(m0,x)
+--E 4498
+
+)clear all
+
+--S 4499 of 5341
+t0:=log(a*csc(x)^n)
+--R 
+--R
+--R                    n
+--R   (1)  log(a csc(x) )
+--R                                                    Type: Expression(Integer)
+--E 4499
+
+--S 4500 of 5341
+--r0:=-1/2*%i*n*x^2+n*x*log(1-%e^(2*%i*x))+x*log(a*csc(x)^n)-_
+--  1/2*%i*n*polylog(2,%e^(2*%i*x))
+--E 4500
+
+--S 4501 of 5341
+--a0:=integrate(t0,x)
+--E 4501
+
+--S 4502 of 5341
+--m0:=a0-r0
+--E 4502
+
+--S 4503 of 5341
+--d0:=D(m0,x)
+--E 4503
+
+)clear all
+
+--S 4504 of 5341
+t0:=cos(x)*log(1/2*(1-cos(2*x)))
+--R 
+--R
+--R                  - cos(2x) + 1
+--R   (1)  cos(x)log(-------------)
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 4504
+
+--S 4505 of 5341
+r0:=-2*sin(x)+log(1/2*(1-cos(2*x)))*sin(x)
+--R 
+--R
+--R                  - cos(2x) + 1
+--R   (2)  sin(x)log(-------------) - 2sin(x)
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 4505
+
+--S 4506 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          2
+--R   (3)  sin(x)log(- cos(x)  + 1) - 2sin(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 4506
+
+--S 4507 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                          2                  - cos(2x) + 1
+--R   (4)  sin(x)log(- cos(x)  + 1) - sin(x)log(-------------)
+--R                                                   2
+--R                                                    Type: Expression(Integer)
+--E 4507
+
+--S 4508 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4508
+
+)clear all
+
+--S 4509 of 5341
+t0:=cot(x)/log(%e*sin(x))
+--R 
+--R
+--R            cot(x)
+--R   (1)  --------------
+--R        log(%e sin(x))
+--R                                                    Type: Expression(Integer)
+--E 4509
+
+--S 4510 of 5341
+r0:=log(log(%e*sin(x))),log(1+log(sin(x)))
+--R 
+--R
+--R   (2)  [log(log(%e sin(x))),log(log(sin(x)) + 1)]
+--R                                             Type: Tuple(Expression(Integer))
+--E 4510
+
+--S 4511 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    4      2     4 2      2
+--R        log(log(- %e cos(x)  + %e )  + %pi )
+--R   (3)  ------------------------------------
+--R                          2
+--R                                         Type: Union(Expression(Integer),...)
+--E 4511
+
+--S 4512 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                                             4      2     4 2      2
+--R        - 2log(log(%e sin(x))) + log(log(- %e cos(x)  + %e )  + %pi )
+--R   (4)  -------------------------------------------------------------
+--R                                      2
+--R                                                    Type: Expression(Integer)
+--E 4512
+
+--S 4513 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R 
+--R   >> System error:
+--R   Value stack overflow.
+--R
+--R   Continuing to read the file...
+--R
+--E 4513
+
+)clear all
+
+--S 4514 of 5341
+t0:=cot(x)/log(%e^sin(x))
+--R 
+--R
+--R        cot(x)
+--R   (1)  ------
+--R        sin(x)
+--R                                                    Type: Expression(Integer)
+--E 4514
+
+-- catdef: division by zero
+--S 4515 of 5341
+--r0:=log(log(%e^sin(x)))/(-log(%e^sin(x))+sin(x))-log(sin(x))/_
+--  (-log(%e^sin(x))+sin(x))
+--E 4515
+
+--S 4516 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R             1
+--R   (2)  - ------
+--R          sin(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 4516
+
+--S 4517 of 5341
+--m0:=a0-r0
+--E 4517
+
+--S 4518 of 5341
+--d0:=D(m0,x)
+--E 4518
+
+)clear all
+
+--S 4519 of 5341
+t0:=log(cos(x))*sec(x)^2
+--R 
+--R
+--R              2
+--R   (1)  sec(x) log(cos(x))
+--R                                                    Type: Expression(Integer)
+--E 4519
+
+--S 4520 of 5341
+r0:=-x+tan(x)+log(cos(x))*tan(x)
+--R 
+--R
+--R   (2)  tan(x)log(cos(x)) + tan(x) - x
+--R                                                    Type: Expression(Integer)
+--E 4520
+
+--S 4521 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        sin(x)log(cos(x)) + sin(x) - x cos(x)
+--R   (3)  -------------------------------------
+--R                        cos(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 4521
+
+--S 4522 of 5341
+m0:=a0-r0
+--R 
+--R
+--R        (- cos(x)tan(x) + sin(x))log(cos(x)) - cos(x)tan(x) + sin(x)
+--R   (4)  ------------------------------------------------------------
+--R                                   cos(x)
+--R                                                    Type: Expression(Integer)
+--E 4522
+
+--S 4523 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4523
+
+)clear all
+
+--S 4524 of 5341
+t0:=cot(x)*log(sin(x))
+--R 
+--R
+--R   (1)  cot(x)log(sin(x))
+--R                                                    Type: Expression(Integer)
+--E 4524
+
+--S 4525 of 5341
+r0:=1/2*log(sin(x))^2
+--R 
+--R
+--R                   2
+--R        log(sin(x))
+--R   (2)  ------------
+--R              2
+--R                                                    Type: Expression(Integer)
+--E 4525
+
+--S 4526 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   2
+--R        log(sin(x))
+--R   (3)  ------------
+--R              2
+--R                                         Type: Union(Expression(Integer),...)
+--E 4526
+
+--S 4527 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4527
+
+--S 4528 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4528
+
+)clear all
+
+--S 4529 of 5341
+t0:=cos(x)*log(sin(x))*sin(x)^2
+--R 
+--R
+--R                    2
+--R   (1)  cos(x)sin(x) log(sin(x))
+--R                                                    Type: Expression(Integer)
+--E 4529
+
+--S 4530 of 5341
+r0:=-1/9*sin(x)^3+1/3*log(sin(x))*sin(x)^3
+--R 
+--R
+--R               3                    3
+--R        3sin(x) log(sin(x)) - sin(x)
+--R   (2)  -----------------------------
+--R                      9
+--R                                                    Type: Expression(Integer)
+--E 4530
+
+--S 4531 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  2                                2
+--R        (- 3cos(x)  + 3)sin(x)log(sin(x)) + (cos(x)  - 1)sin(x)
+--R   (3)  -------------------------------------------------------
+--R                                   9
+--R                                         Type: Union(Expression(Integer),...)
+--E 4531
+
+--S 4532 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                 3             2                                3
+--R       (- 3sin(x)  + (- 3cos(x)  + 3)sin(x))log(sin(x)) + sin(x)
+--R     + 
+--R              2
+--R       (cos(x)  - 1)sin(x)
+--R  /
+--R     9
+--R                                                    Type: Expression(Integer)
+--E 4532
+
+--S 4533 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4533
+
+)clear all
+
+--S 4534 of 5341
+t0:=cos(a+b*x)*log(cos(1/2*a+1/2*b*x)*sin(1/2*a+1/2*b*x))
+--R 
+--R
+--R                            b x + a     b x + a
+--R   (1)  cos(b x + a)log(cos(-------)sin(-------))
+--R                               2           2
+--R                                                    Type: Expression(Integer)
+--E 4534
+
+--S 4535 of 5341
+r0:=-sin(a+b*x)/b+log(cos(1/2*a+1/2*b*x)*sin(1/2*a+1/2*b*x))*sin(a+b*x)/b
+--R 
+--R
+--R                            b x + a     b x + a
+--R        sin(b x + a)log(cos(-------)sin(-------)) - sin(b x + a)
+--R                               2           2
+--R   (2)  --------------------------------------------------------
+--R                                    b
+--R                                                    Type: Expression(Integer)
+--E 4535
+
+--S 4536 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            b x + a     b x + a         b x + a     b x + a
+--R       2cos(-------)sin(-------)log(cos(-------)sin(-------))
+--R               2           2               2           2
+--R     + 
+--R              b x + a     b x + a
+--R       - 2cos(-------)sin(-------)
+--R                 2           2
+--R  /
+--R     b
+--R                                         Type: Union(Expression(Integer),...)
+--E 4536
+
+--S 4537 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              b x + a     b x + a          b x + a     b x + a
+--R       (- sin(b x + a) + 2cos(-------)sin(-------))log(cos(-------)sin(-------))
+--R                                 2           2                2           2
+--R     + 
+--R                           b x + a     b x + a
+--R       sin(b x + a) - 2cos(-------)sin(-------)
+--R                              2           2
+--R  /
+--R     b
+--R                                                    Type: Expression(Integer)
+--E 4537
+
+--S 4538 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4538
+
+)clear all
+
+--S 4539 of 5341
+t0:=tan(x)/log(cos(x))
+--R 
+--R
+--R           tan(x)
+--R   (1)  -----------
+--R        log(cos(x))
+--R                                                    Type: Expression(Integer)
+--E 4539
+
+--S 4540 of 5341
+r0:=-log(log(cos(x)))
+--R 
+--R
+--R   (2)  - log(log(cos(x)))
+--R                                                    Type: Expression(Integer)
+--E 4540
+
+--S 4541 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  - log(log(cos(x)))
+--R                                         Type: Union(Expression(Integer),...)
+--E 4541
+
+--S 4542 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4542
+
+--S 4543 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4543
+
+)clear all
+
+--S 4544 of 5341
+t0:=log(cos(x))*tan(x)
+--R 
+--R
+--R   (1)  tan(x)log(cos(x))
+--R                                                    Type: Expression(Integer)
+--E 4544
+
+--S 4545 of 5341
+r0:=-1/2*log(cos(x))^2
+--R 
+--R
+--R                     2
+--R          log(cos(x))
+--R   (2)  - ------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 4545
+
+--S 4546 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     2
+--R          log(cos(x))
+--R   (3)  - ------------
+--R                2
+--R                                         Type: Union(Expression(Integer),...)
+--E 4546
+
+--S 4547 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4547
+
+--S 4548 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4548
+
+)clear all
+
+--S 4549 of 5341
+t0:=log(cos(x))*sin(x)
+--R 
+--R
+--R   (1)  sin(x)log(cos(x))
+--R                                                    Type: Expression(Integer)
+--E 4549
+
+--S 4550 of 5341
+r0:=cos(x)-cos(x)*log(cos(x))
+--R 
+--R
+--R   (2)  - cos(x)log(cos(x)) + cos(x)
+--R                                                    Type: Expression(Integer)
+--E 4550
+
+--S 4551 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  - cos(x)log(cos(x)) + cos(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 4551
+
+--S 4552 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4552
+
+--S 4553 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4553
+
+)clear all
+
+--S 4554 of 5341
+t0:=cos(x)*log(cos(x))
+--R 
+--R
+--R   (1)  cos(x)log(cos(x))
+--R                                                    Type: Expression(Integer)
+--E 4554
+
+--S 4555 of 5341
+r0:=atanh(sin(x))-sin(x)+log(cos(x))*sin(x)
+--R 
+--R
+--R   (2)  sin(x)log(cos(x)) + atanh(sin(x)) - sin(x)
+--R                                                    Type: Expression(Integer)
+--E 4555
+
+--S 4556 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(sin(x) + 1) - log(sin(x) - 1) + 2sin(x)log(cos(x)) - 2sin(x)
+--R   (3)  ----------------------------------------------------------------
+--R                                        2
+--R                                         Type: Union(Expression(Integer),...)
+--E 4556
+
+--S 4557 of 5341
+m0:=a0-r0
+--R 
+--R
+--R        log(sin(x) + 1) - log(sin(x) - 1) - 2atanh(sin(x))
+--R   (4)  --------------------------------------------------
+--R                                 2
+--R                                                    Type: Expression(Integer)
+--E 4557
+
+--S 4558 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4558
+
+)clear all
+
+--S 4559 of 5341
+t0:=cos(x)*log(sin(x))
+--R 
+--R
+--R   (1)  cos(x)log(sin(x))
+--R                                                    Type: Expression(Integer)
+--E 4559
+
+--S 4560 of 5341
+r0:=-sin(x)+log(sin(x))*sin(x)
+--R 
+--R
+--R   (2)  sin(x)log(sin(x)) - sin(x)
+--R                                                    Type: Expression(Integer)
+--E 4560
+
+--S 4561 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  sin(x)log(sin(x)) - sin(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 4561
+
+--S 4562 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4562
+
+--S 4563 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4563
+
+)clear all
+
+--S 4564 of 5341
+t0:=log(sin(x))*sin(x)^2
+--R 
+--R
+--R              2
+--R   (1)  sin(x) log(sin(x))
+--R                                                    Type: Expression(Integer)
+--E 4564
+
+--S 4565 of 5341
+--r0:=1/4*x+1/4*%i*x^2-1/2*x*log(1-%e^(2*%i*x))+1/2*x*log(sin(x))+_
+--  1/4*%i*polylog(2,%e^(2*%i*x))+1/4*cos(x)*sin(x)-1/2*cos(x)*_
+--  log(sin(x))*sin(x)
+--E 4565
+
+--S 4566 of 5341
+--a0:=integrate(t0,x)
+--E 4566
+
+--S 4567 of 5341
+--m0:=a0-r0
+--E 4567
+
+--S 4568 of 5341
+--d0:=D(m0,x)
+--E 4568
+
+)clear all
+
+--S 4569 of 5341
+t0:=log(sin(x))*sin(x)^3
+--R 
+--R
+--R              3
+--R   (1)  sin(x) log(sin(x))
+--R                                                    Type: Expression(Integer)
+--E 4569
+
+--S 4570 of 5341
+r0:=-2/3*atanh(cos(x))+2/3*cos(x)-1/9*cos(x)^3-cos(x)*log(sin(x))+_
+   1/3*cos(x)^3*log(sin(x))
+--R 
+--R
+--R                3                                                3
+--R        (3cos(x)  - 9cos(x))log(sin(x)) - 6atanh(cos(x)) - cos(x)  + 6cos(x)
+--R   (2)  --------------------------------------------------------------------
+--R                                          9
+--R                                                    Type: Expression(Integer)
+--E 4570
+
+--S 4571 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R               3
+--R       (3cos(x)  - 9cos(x))log(sin(x)) - 3log(cos(x) + 1) + 3log(cos(x) - 1)
+--R     + 
+--R               3
+--R       - cos(x)  + 6cos(x)
+--R  /
+--R     9
+--R                                         Type: Union(Expression(Integer),...)
+--E 4571
+
+--S 4572 of 5341
+m0:=a0-r0
+--R 
+--R
+--R        - log(cos(x) + 1) + log(cos(x) - 1) + 2atanh(cos(x))
+--R   (4)  ----------------------------------------------------
+--R                                  3
+--R                                                    Type: Expression(Integer)
+--E 4572
+
+--S 4573 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4573
+
+)clear all
+
+--S 4574 of 5341
+t0:=log(sin(sqrt(x)))
+--R 
+--R
+--R                 +-+
+--R   (1)  log(sin(\|x ))
+--R                                                    Type: Expression(Integer)
+--E 4574
+
+--S 4575 of 5341
+--r0:=1/3*%i*x^(3/2)-x*log(1-%e^(2*%i*sqrt(x)))+x*log(sin(sqrt(x)))-_
+--  1/2*polylog(3,%e^(2*%i*sqrt(x)))+%i*polylog(2,%e^(2*%i*sqrt(x)))*sqrt(x)
+--E 4575
+
+--S 4576 of 5341
+--a0:=integrate(t0,x)
+--E 4576
+
+--S 4577 of 5341
+--m0:=a0-r0
+--E 4577
+
+--S 4578 of 5341
+--d0:=D(m0,x)
+--E 4578
+
+)clear all
+
+--S 4579 of 5341
+t0:=csc(x)^2*log(sin(x))
+--R 
+--R
+--R              2
+--R   (1)  csc(x) log(sin(x))
+--R                                                    Type: Expression(Integer)
+--E 4579
+
+--S 4580 of 5341
+r0:=-x-cot(x)-cot(x)*log(sin(x))
+--R 
+--R
+--R   (2)  - cot(x)log(sin(x)) - cot(x) - x
+--R                                                    Type: Expression(Integer)
+--E 4580
+
+--S 4581 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                         2
+--R        cos(x)sin(x)log(sin(x)) + cos(x)sin(x) - x cos(x)  + x
+--R   (3)  ------------------------------------------------------
+--R                                    2
+--R                              cos(x)  - 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 4581
+
+--S 4582 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                              2
+--R       (cos(x)sin(x) + (cos(x)  - 1)cot(x))log(sin(x)) + cos(x)sin(x)
+--R     + 
+--R              2
+--R       (cos(x)  - 1)cot(x)
+--R  /
+--R           2
+--R     cos(x)  - 1
+--R                                                    Type: Expression(Integer)
+--E 4582
+
+--S 4583 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4583
+
+)clear all
+
+--S 4584 of 5341
+t0:=log(x)*sinh(a+b*x)
+--R 
+--R
+--R   (1)  log(x)sinh(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 4584
+
+--S 4585 of 5341
+--r0:=-Chi(b*x)*cosh(a)/b+cosh(a+b*x)*log(x)/b-Shi(b*x)*sinh(a)/b
+--E 4585
+
+--S 4586 of 5341
+--a0:=integrate(t0,x)
+--E 4586
+
+--S 4587 of 5341
+--m0:=a0-r0
+--E 4587
+
+--S 4588 of 5341
+--d0:=D(m0,x)
+--E 4588
+
+)clear all
+
+--S 4589 of 5341
+t0:=log(x)*sinh(a+b*x)^2
+--R 
+--R
+--R                           2
+--R   (1)  log(x)sinh(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 4589
+
+--S 4590 of 5341
+--r0:=1/2*x-1/2*x*log(x)-1/4*cosh(2*a)*Shi(2*b*x)/b-1/4*Chi(2*b*x)*_
+--  sinh(2*a)/b+1/2*cosh(a+b*x)*log(x)*sinh(a+b*x)/b
+--E 4590
+
+--S 4591 of 5341
+--a0:=integrate(t0,x)
+--E 4591
+
+--S 4592 of 5341
+--m0:=a0-r0
+--E 4592
+
+--S 4593 of 5341
+--d0:=D(m0,x)
+--E 4593
+
+)clear all
+
+--S 4594 of 5341
+t0:=log(x)*sinh(a+b*x)^3
+--R 
+--R
+--R                           3
+--R   (1)  log(x)sinh(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 4594
+
+--S 4595 of 5341
+--r0:=3/4*Chi(b*x)*cosh(a)/b-1/12*Chi(3*b*x)*cosh(3*a)/b-cosh(a+b*x)*_
+--  log(x)/b+1/3*cosh(a+b*x)^3*log(x)/b+3/4*Shi(b*x)*sinh(a)/b-_
+--  1/12*Shi(3*b*x)*sinh(3*a)/b
+--E 4595
+
+--S 4596 of 5341
+--a0:=integrate(t0,x)
+--E 4596
+
+--S 4597 of 5341
+--m0:=a0-r0
+--E 4597
+
+--S 4598 of 5341
+--d0:=D(m0,x)
+--E 4598
+
+)clear all
+
+--S 4599 of 5341
+t0:=cosh(a+b*x)*log(x)
+--R 
+--R
+--R   (1)  cosh(b x + a)log(x)
+--R                                                    Type: Expression(Integer)
+--E 4599
+
+--S 4600 of 5341
+--r0:=-cosh(a)*Shi(b*x)/b-Chi(b*x)*sinh(a)/b+log(x)*sinh(a+b*x)/b
+--E 4600
+
+--S 4601 of 5341
+--a0:=integrate(t0,x)
+--E 4601
+
+--S 4602 of 5341
+--m0:=a0-r0
+--E 4602
+
+--S 4603 of 5341
+--d0:=D(m0,x)
+--E 4603
+
+)clear all
+
+--S 4604 of 5341
+t0:=cosh(a+b*x)^2*log(x)
+--R 
+--R
+--R                     2
+--R   (1)  cosh(b x + a) log(x)
+--R                                                    Type: Expression(Integer)
+--E 4604
+
+--S 4605 of 5341
+--r0:=-1/2*x+1/2*x*log(x)-1/4*cosh(2*a)*Shi(2*b*x)/b-1/4*Chi(2*b*x)*_
+--  sinh(2*a)/b+1/2*cosh(a+b*x)*log(x)*sinh(a+b*x)/b
+--E 4605
+
+--S 4606 of 5341
+--a0:=integrate(t0,x)
+--E 4606
+
+--S 4607 of 5341
+--m0:=a0-r0
+--E 4607
+
+--S 4608 of 5341
+--d0:=D(m0,x)
+--E 4608
+
+)clear all
+
+--S 4609 of 5341
+t0:=cosh(a+b*x)^3*log(x)
+--R 
+--R
+--R                     3
+--R   (1)  cosh(b x + a) log(x)
+--R                                                    Type: Expression(Integer)
+--E 4609
+
+--S 4610 of 5341
+--r0:=-3/4*cosh(a)*Shi(b*x)/b-1/12*cosh(3*a)*Shi(3*b*x)/b-_
+--  3/4*Chi(b*x)*sinh(a)/b-1/12*Chi(3*b*x)*sinh(3*a)/b+log(x)*_
+--  sinh(a+b*x)/b+1/3*log(x)*sinh(a+b*x)^3/b
+--E 4610
+
+--S 4611 of 5341
+--a0:=integrate(t0,x)
+--E 4611
+
+--S 4612 of 5341
+--m0:=a0-r0
+--E 4612
+
+--S 4613 of 5341
+--d0:=D(m0,x)
+--E 4613
+
+)clear all
+
+--S 4614 of 5341
+t0:=log(a*sinh(x))
+--R 
+--R
+--R   (1)  log(a sinh(x))
+--R                                                    Type: Expression(Integer)
+--E 4614
+
+--S 4615 of 5341
+--r0:=1/2*x^2-x*log(1-%e^(2*x))+x*log(a*sinh(x))-1/2*polylog(2,%e^(2*x))
+--E 4615
+
+--S 4616 of 5341
+--a0:=integrate(t0,x)
+--E 4616
+
+--S 4617 of 5341
+--m0:=a0-r0
+--E 4617
+
+--S 4618 of 5341
+--d0:=D(m0,x)
+--E 4618
+
+)clear all
+
+--S 4619 of 5341
+t0:=log(a*sinh(x)^2)
+--R 
+--R
+--R                     2
+--R   (1)  log(a sinh(x) )
+--R                                                    Type: Expression(Integer)
+--E 4619
+
+--S 4620 of 5341
+--r0:=x^2-2*x*log(1-%e^(2*x))+x*log(a*sinh(x)^2)-polylog(2,%e^(2*x))
+--E 4620
+
+--S 4621 of 5341
+--a0:=integrate(t0,x)
+--E 4621
+
+--S 4622 of 5341
+--m0:=a0-r0
+--E 4622
+
+--S 4623 of 5341
+--d0:=D(m0,x)
+--E 4623
+
+)clear all
+
+--S 4624 of 5341
+t0:=log(a*sinh(x)^n)
+--R 
+--R
+--R                     n
+--R   (1)  log(a sinh(x) )
+--R                                                    Type: Expression(Integer)
+--E 4624
+
+--S 4625 of 5341
+--r0:=1/2*n*x^2-n*x*log(1-%e^(2*x))+x*log(a*sinh(x)^n)-_
+--  1/2*n*polylog(2,%e^(2*x))
+--E 4625
+
+--S 4626 of 5341
+--a0:=integrate(t0,x)
+--E 4626
+
+--S 4627 of 5341
+--m0:=a0-r0
+--E 4627
+
+--S 4628 of 5341
+--d0:=D(m0,x)
+--E 4628
+
+)clear all
+
+--S 4629 of 5341
+t0:=log(a*cosh(x))
+--R 
+--R
+--R   (1)  log(a cosh(x))
+--R                                                    Type: Expression(Integer)
+--E 4629
+
+--S 4630 of 5341
+--r0:=1/2*x^2-x*log(1+%e^(2*x))+x*log(a*cosh(x))-1/2*polylog(2,-%e^(2*x))
+--E 4630
+
+--S 4631 of 5341
+--a0:=integrate(t0,x)
+--E 4631
+
+--S 4632 of 5341
+--m0:=a0-r0
+--E 4632
+
+--S 4633 of 5341
+--d0:=D(m0,x)
+--E 4633
+
+)clear all
+
+--S 4634 of 5341
+t0:=log(a*cosh(x)^2)
+--R 
+--R
+--R                     2
+--R   (1)  log(a cosh(x) )
+--R                                                    Type: Expression(Integer)
+--E 4634
+
+--S 4635 of 5341
+--r0:=x^2-2*x*log(1+%e^(2*x))+x*log(a*cosh(x)^2)-polylog(2,-%e^(2*x))
+--E 4635
+
+--S 4636 of 5341
+--a0:=integrate(t0,x)
+--E 4636
+
+--S 4637 of 5341
+--m0:=a0-r0
+--E 4637
+
+--S 4638 of 5341
+--d0:=D(m0,x)
+--E 4638
+
+)clear all
+
+--S 4639 of 5341
+t0:=log(a*cosh(x)^n)
+--R 
+--R
+--R                     n
+--R   (1)  log(a cosh(x) )
+--R                                                    Type: Expression(Integer)
+--E 4639
+
+--S 4640 of 5341
+--r0:=1/2*n*x^2-n*x*log(1+%e^(2*x))+x*log(a*cosh(x)^n)-_
+--  1/2*n*polylog(2,-%e^(2*x))
+--E 4640
+
+--S 4641 of 5341
+--a0:=integrate(t0,x)
+--E 4641
+
+--S 4642 of 5341
+--m0:=a0-r0
+--E 4642
+
+--S 4643 of 5341
+--d0:=D(m0,x)
+--E 4643
+
+)clear all
+
+--S 4644 of 5341
+t0:=log(tanh(x))
+--R 
+--R
+--R   (1)  log(tanh(x))
+--R                                                    Type: Expression(Integer)
+--E 4644
+
+--S 4645 of 5341
+--r0:=2*x*atanh(%e^(2*x))+x*log(tanh(x))+1/2*polylog(2,-%e^(2*x))-_
+--  1/2*polylog(2,%e^(2*x))
+--E 4645
+
+--S 4646 of 5341
+--a0:=integrate(t0,x)
+--E 4646
+
+--S 4647 of 5341
+--m0:=a0-r0
+--E 4647
+
+--S 4648 of 5341
+--d0:=D(m0,x)
+--E 4648
+
+)clear all
+
+--S 4649 of 5341
+t0:=log(a*tanh(x))
+--R 
+--R
+--R   (1)  log(a tanh(x))
+--R                                                    Type: Expression(Integer)
+--E 4649
+
+--S 4650 of 5341
+--r0:=2*x*atanh(%e^(2*x))+x*log(a*tanh(x))+1/2*polylog(2,-%e^(2*x))-_
+--  1/2*polylog(2,%e^(2*x))
+--E 4650
+
+--S 4651 of 5341
+--a0:=integrate(t0,x)
+--E 4651
+
+--S 4652 of 5341
+--m0:=a0-r0
+--E 4652
+
+--S 4653 of 5341
+--d0:=D(m0,x)
+--E 4653
+
+)clear all
+
+--S 4654 of 5341
+t0:=log(a*tanh(x)^2)
+--R 
+--R
+--R                     2
+--R   (1)  log(a tanh(x) )
+--R                                                    Type: Expression(Integer)
+--E 4654
+
+--S 4655 of 5341
+--r0:=4*x*atanh(%e^(2*x))+x*log(a*tanh(x)^2)+polylog(2,-%e^(2*x))-_
+--  polylog(2,%e^(2*x))
+--E 4655
+
+--S 4656 of 5341
+--a0:=integrate(t0,x)
+--E 4656
+
+--S 4657 of 5341
+--m0:=a0-r0
+--E 4657
+
+--S 4658 of 5341
+--d0:=D(m0,x)
+--E 4658
+
+)clear all
+
+--S 4659 of 5341
+t0:=log(a*tanh(x)^n)
+--R 
+--R
+--R                     n
+--R   (1)  log(a tanh(x) )
+--R                                                    Type: Expression(Integer)
+--E 4659
+
+--S 4660 of 5341
+--r0:=2*n*x*atanh(%e^(2*x))+x*log(a*tanh(x)^n)+1/2*n*polylog(2,-%e^(2*x))-_
+--  1/2*n*polylog(2,%e^(2*x))
+--E 4660
+
+--S 4661 of 5341
+--a0:=integrate(t0,x)
+--E 4661
+
+--S 4662 of 5341
+--m0:=a0-r0
+--E 4662
+
+--S 4663 of 5341
+--d0:=D(m0,x)
+--E 4663
+
+)clear all
+
+--S 4664 of 5341
+t0:=log(coth(x))
+--R 
+--R
+--R   (1)  log(coth(x))
+--R                                                    Type: Expression(Integer)
+--E 4664
+
+--S 4665 of 5341
+--r0:=-2*x*atanh(%e^(2*x))+x*log(coth(x))-1/2*polylog(2,-%e^(2*x))+_
+--  1/2*polylog(2,%e^(2*x))
+--E 4665
+
+--S 4666 of 5341
+--a0:=integrate(t0,x)
+--E 4666
+
+--S 4667 of 5341
+--m0:=a0-r0
+--E 4667
+
+--S 4668 of 5341
+--d0:=D(m0,x)
+--E 4668
+
+)clear all
+
+--S 4669 of 5341
+t0:=log(a*coth(x))
+--R 
+--R
+--R   (1)  log(a coth(x))
+--R                                                    Type: Expression(Integer)
+--E 4669
+
+--S 4670 of 5341
+--r0:=-2*x*atanh(%e^(2*x))+x*log(a*coth(x))-1/2*polylog(2,-%e^(2*x))+_
+--  1/2*polylog(2,%e^(2*x))
+--E 4670
+
+--S 4671 of 5341
+--a0:=integrate(t0,x)
+--E 4671
+
+--S 4672 of 5341
+--m0:=a0-r0
+--E 4672
+
+--S 4673 of 5341
+--d0:=D(m0,x)
+--E 4673
+
+)clear all
+
+--S 4674 of 5341
+t0:=log(a*coth(x)^2)
+--R 
+--R
+--R                     2
+--R   (1)  log(a coth(x) )
+--R                                                    Type: Expression(Integer)
+--E 4674
+
+--S 4675 of 5341
+--r0:=-4*x*atanh(%e^(2*x))+x*log(a*coth(x)^2)-polylog(2,-%e^(2*x))+_
+--  polylog(2,%e^(2*x))
+--E 4675
+
+--S 4676 of 5341
+--a0:=integrate(t0,x)
+--E 4676
+
+--S 4677 of 5341
+--m0:=a0-r0
+--E 4677
+
+--S 4678 of 5341
+--d0:=D(m0,x)
+--E 4678
+
+)clear all
+
+--S 4679 of 5341
+t0:=log(a*coth(x)^n)
+--R 
+--R
+--R                     n
+--R   (1)  log(a coth(x) )
+--R                                                    Type: Expression(Integer)
+--E 4679
+
+--S 4680 of 5341
+--r0:=-2*n*x*atanh(%e^(2*x))+x*log(a*coth(x)^n)-1/2*n*polylog(2,-%e^(2*x))+_
+--  1/2*n*polylog(2,%e^(2*x))
+--E 4680
+
+--S 4681 of 5341
+--a0:=integrate(t0,x)
+--E 4681
+
+--S 4682 of 5341
+--m0:=a0-r0
+--E 4682
+
+--S 4683 of 5341
+--d0:=D(m0,x)
+--E 4683
+
+)clear all
+
+--S 4684 of 5341
+t0:=log(a*sech(x))
+--R 
+--R
+--R   (1)  log(a sech(x))
+--R                                                    Type: Expression(Integer)
+--E 4684
+
+--S 4685 of 5341
+--r0:=-1/2*x^2+x*log(1+%e^(2*x))+x*log(a*sech(x))+1/2*polylog(2,-%e^(2*x))
+--E 4685
+
+--S 4686 of 5341
+--a0:=integrate(t0,x)
+--E 4686
+
+--S 4687 of 5341
+--m0:=a0-r0
+--E 4687
+
+--S 4688 of 5341
+--d0:=D(m0,x)
+--E 4688
+
+)clear all
+
+--S 4689 of 5341
+t0:=log(a*sech(x)^2)
+--R 
+--R
+--R                     2
+--R   (1)  log(a sech(x) )
+--R                                                    Type: Expression(Integer)
+--E 4689
+
+--S 4690 of 5341
+--r0:=-x^2+2*x*log(1+%e^(2*x))+x*log(a*sech(x)^2)+polylog(2,-%e^(2*x))
+--E 4690
+
+--S 4691 of 5341
+--a0:=integrate(t0,x)
+--E 4691
+
+--S 4692 of 5341
+--m0:=a0-r0
+--E 4692
+
+--S 4693 of 5341
+--d0:=D(m0,x)
+--E 4693
+
+)clear all
+
+--S 4694 of 5341
+t0:=log(a*sech(x)^n)
+--R 
+--R
+--R                     n
+--R   (1)  log(a sech(x) )
+--R                                                    Type: Expression(Integer)
+--E 4694
+
+--S 4695 of 5341
+--r0:=-1/2*n*x^2+n*x*log(1+%e^(2*x))+x*log(a*sech(x)^n)+_
+--  1/2*n*polylog(2,-%e^(2*x))
+--E 4695
+
+--S 4696 of 5341
+--a0:=integrate(t0,x)
+--E 4696
+
+--S 4697 of 5341
+--m0:=a0-r0
+--E 4697
+
+--S 4698 of 5341
+--d0:=D(m0,x)
+--E 4698
+
+)clear all
+
+--S 4699 of 5341
+t0:=log(a*csch(x))
+--R 
+--R
+--R   (1)  log(a csch(x))
+--R                                                    Type: Expression(Integer)
+--E 4699
+
+--S 4700 of 5341
+--r0:=-1/2*x^2+x*log(1-%e^(2*x))+x*log(a*csch(x))+1/2*polylog(2,%e^(2*x))
+--E 4700
+
+--S 4701 of 5341
+--a0:=integrate(t0,x)
+--E 4701
+
+--S 4702 of 5341
+--m0:=a0-r0
+--E 4702
+
+--S 4703 of 5341
+--d0:=D(m0,x)
+--E 4703
+
+)clear all
+
+--S 4704 of 5341
+t0:=log(a*csch(x)^2)
+--R 
+--R
+--R                     2
+--R   (1)  log(a csch(x) )
+--R                                                    Type: Expression(Integer)
+--E 4704
+
+--S 4705 of 5341
+--r0:=-x^2+2*x*log(1-%e^(2*x))+x*log(a*csch(x)^2)+polylog(2,%e^(2*x))
+--E 4705
+
+--S 4706 of 5341
+--a0:=integrate(t0,x)
+--E 4706
+
+--S 4707 of 5341
+--m0:=a0-r0
+--E 4707
+
+--S 4708 of 5341
+--d0:=D(m0,x)
+--E 4708
+
+)clear all
+
+--S 4709 of 5341
+t0:=log(a*csch(x)^n)
+--R 
+--R
+--R                     n
+--R   (1)  log(a csch(x) )
+--R                                                    Type: Expression(Integer)
+--E 4709
+
+--S 4710 of 5341
+--r0:=-1/2*n*x^2+n*x*log(1-%e^(2*x))+x*log(a*csch(x)^n)+_
+--  1/2*n*polylog(2,%e^(2*x))
+--E 4710
+
+--S 4711 of 5341
+--a0:=integrate(t0,x)
+--E 4711
+
+--S 4712 of 5341
+--m0:=a0-r0
+--E 4712
+
+--S 4713 of 5341
+--d0:=D(m0,x)
+--E 4713
+
+)clear all
+
+--S 4714 of 5341
+t0:=cosh(a+b*x)*log(cosh(1/2*a+1/2*b*x)*sinh(1/2*a+1/2*b*x))
+--R 
+--R
+--R                              b x + a      b x + a
+--R   (1)  cosh(b x + a)log(cosh(-------)sinh(-------))
+--R                                 2            2
+--R                                                    Type: Expression(Integer)
+--E 4714
+
+--S 4715 of 5341
+r0:=-sinh(a+b*x)/b+log(cosh(1/2*a+1/2*b*x)*sinh(1/2*a+1/2*b*x))*sinh(a+b*x)/b
+--R 
+--R
+--R                              b x + a      b x + a
+--R        sinh(b x + a)log(cosh(-------)sinh(-------)) - sinh(b x + a)
+--R                                 2            2
+--R   (2)  ------------------------------------------------------------
+--R                                      b
+--R                                                    Type: Expression(Integer)
+--E 4715
+
+--S 4716 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                b x + a 4         b x + a      b x + a 3
+--R           sinh(-------)  + 4cosh(-------)sinh(-------)
+--R                   2                 2            2
+--R         + 
+--R                 b x + a 2     b x + a 2         b x + a 3     b x + a
+--R           6cosh(-------) sinh(-------)  + 4cosh(-------) sinh(-------)
+--R                    2             2                 2             2
+--R         + 
+--R                b x + a 4
+--R           cosh(-------)  - 1
+--R                   2
+--R      *
+--R                  b x + a      b x + a
+--R         log(cosh(-------)sinh(-------))
+--R                     2            2
+--R     + 
+--R              b x + a 4         b x + a      b x + a 3
+--R       - sinh(-------)  - 4cosh(-------)sinh(-------)
+--R                 2                 2            2
+--R     + 
+--R               b x + a 2     b x + a 2         b x + a 3     b x + a
+--R       - 6cosh(-------) sinh(-------)  - 4cosh(-------) sinh(-------)
+--R                  2             2                 2             2
+--R     + 
+--R              b x + a 4
+--R       - cosh(-------)  + 1
+--R                 2
+--R  /
+--R             b x + a 2           b x + a      b x + a            b x + a 2
+--R     2b sinh(-------)  + 4b cosh(-------)sinh(-------) + 2b cosh(-------)
+--R                2                   2            2                  2
+--R                                         Type: Union(Expression(Integer),...)
+--E 4716
+
+--S 4717 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                      b x + a 2         b x + a      b x + a          b x + a 2
+--R             (- 2sinh(-------)  - 4cosh(-------)sinh(-------) - 2cosh(-------) )
+--R                         2                 2            2                2
+--R          *
+--R             sinh(b x + a)
+--R         + 
+--R                b x + a 4         b x + a      b x + a 3
+--R           sinh(-------)  + 4cosh(-------)sinh(-------)
+--R                   2                 2            2
+--R         + 
+--R                 b x + a 2     b x + a 2         b x + a 3     b x + a
+--R           6cosh(-------) sinh(-------)  + 4cosh(-------) sinh(-------)
+--R                    2             2                 2             2
+--R         + 
+--R                b x + a 4
+--R           cosh(-------)  - 1
+--R                   2
+--R      *
+--R                  b x + a      b x + a
+--R         log(cosh(-------)sinh(-------))
+--R                     2            2
+--R     + 
+--R                b x + a 2         b x + a      b x + a          b x + a 2
+--R         (2sinh(-------)  + 4cosh(-------)sinh(-------) + 2cosh(-------) )
+--R                   2                 2            2                2
+--R      *
+--R         sinh(b x + a)
+--R     + 
+--R              b x + a 4         b x + a      b x + a 3
+--R       - sinh(-------)  - 4cosh(-------)sinh(-------)
+--R                 2                 2            2
+--R     + 
+--R               b x + a 2     b x + a 2         b x + a 3     b x + a
+--R       - 6cosh(-------) sinh(-------)  - 4cosh(-------) sinh(-------)
+--R                  2             2                 2             2
+--R     + 
+--R              b x + a 4
+--R       - cosh(-------)  + 1
+--R                 2
+--R  /
+--R             b x + a 2           b x + a      b x + a            b x + a 2
+--R     2b sinh(-------)  + 4b cosh(-------)sinh(-------) + 2b cosh(-------)
+--R                2                   2            2                  2
+--R                                                    Type: Expression(Integer)
+--E 4717
+
+--S 4718 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4718
+
+)clear all
+
+--S 4719 of 5341
+t0:=log(cosh(x)^2)*sinh(x)
+--R 
+--R
+--R                          2
+--R   (1)  sinh(x)log(cosh(x) )
+--R                                                    Type: Expression(Integer)
+--E 4719
+
+--S 4720 of 5341
+r0:=-2*cosh(x)+cosh(x)*log(cosh(x)^2)
+--R 
+--R
+--R                          2
+--R   (2)  cosh(x)log(cosh(x) ) - 2cosh(x)
+--R                                                    Type: Expression(Integer)
+--E 4720
+
+--S 4721 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                             2          2
+--R               2                            2         sinh(x)  + cosh(x)  + 1
+--R       (sinh(x)  + 2cosh(x)sinh(x) + cosh(x)  + 1)log(-----------------------)
+--R                                                                 2
+--R     + 
+--R                 2                             2
+--R       - 2sinh(x)  - 4cosh(x)sinh(x) - 2cosh(x)  - 2
+--R  /
+--R     2sinh(x) + 2cosh(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 4721
+
+--S 4722 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                             2          2
+--R               2                            2         sinh(x)  + cosh(x)  + 1
+--R       (sinh(x)  + 2cosh(x)sinh(x) + cosh(x)  + 1)log(-----------------------)
+--R                                                                 2
+--R     + 
+--R                                    2            2            2           2
+--R       (- 2cosh(x)sinh(x) - 2cosh(x) )log(cosh(x) ) - 2sinh(x)  + 2cosh(x)  - 2
+--R  /
+--R     2sinh(x) + 2cosh(x)
+--R                                                    Type: Expression(Integer)
+--E 4722
+
+--S 4723 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4723
+
+)clear all
+
+--S 4724 of 5341
+t0:=log(x)/sqrt(x)
+--R 
+--R
+--R        log(x)
+--R   (1)  ------
+--R          +-+
+--R         \|x
+--R                                                    Type: Expression(Integer)
+--E 4724
+
+--S 4725 of 5341
+r0:=-4*sqrt(x)+2*log(x)*sqrt(x)
+--R 
+--R
+--R                      +-+
+--R   (2)  (2log(x) - 4)\|x
+--R                                                    Type: Expression(Integer)
+--E 4725
+
+--S 4726 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +-+
+--R   (3)  (2log(x) - 4)\|x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4726
+
+--S 4727 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4727
+
+--S 4728 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4728
+
+)clear all
+
+--S 4729 of 5341
+t0:=x*log(2-3*x^2)
+--R 
+--R
+--R                  2
+--R   (1)  x log(- 3x  + 2)
+--R                                                    Type: Expression(Integer)
+--E 4729
+
+--S 4730 of 5341
+r0:=-1/2*x^2-1/6*(2-3*x^2)*log(2-3*x^2)
+--R 
+--R
+--R           2             2          2
+--R        (3x  - 2)log(- 3x  + 2) - 3x
+--R   (2)  -----------------------------
+--R                      6
+--R                                                    Type: Expression(Integer)
+--E 4730
+
+--S 4731 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2             2          2
+--R        (3x  - 2)log(- 3x  + 2) - 3x
+--R   (3)  -----------------------------
+--R                      6
+--R                                         Type: Union(Expression(Integer),...)
+--E 4731
+
+--S 4732 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4732
+
+--S 4733 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4733
+
+)clear all
+
+--S 4734 of 5341
+t0:=log(x)^2
+--R 
+--R
+--R              2
+--R   (1)  log(x)
+--R                                                    Type: Expression(Integer)
+--E 4734
+
+--S 4735 of 5341
+r0:=2*x-2*x*log(x)+x*log(x)^2
+--R 
+--R
+--R                2
+--R   (2)  x log(x)  - 2x log(x) + 2x
+--R                                                    Type: Expression(Integer)
+--E 4735
+
+--S 4736 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2
+--R   (3)  x log(x)  - 2x log(x) + 2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4736
+
+--S 4737 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4737
+
+--S 4738 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4738
+
+)clear all
+
+--S 4739 of 5341
+t0:=x*log(x)
+--R 
+--R
+--R   (1)  x log(x)
+--R                                                    Type: Expression(Integer)
+--E 4739
+
+--S 4740 of 5341
+r0:=-1/4*x^2+1/2*x^2*log(x)
+--R 
+--R
+--R          2          2
+--R        2x log(x) - x
+--R   (2)  --------------
+--R               4
+--R                                                    Type: Expression(Integer)
+--E 4740
+
+--S 4741 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2          2
+--R        2x log(x) - x
+--R   (3)  --------------
+--R               4
+--R                                         Type: Union(Expression(Integer),...)
+--E 4741
+
+--S 4742 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4742
+
+--S 4743 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4743
+
+)clear all
+
+--S 4744 of 5341
+t0:=x*log(x)^2
+--R 
+--R
+--R                2
+--R   (1)  x log(x)
+--R                                                    Type: Expression(Integer)
+--E 4744
+
+--S 4745 of 5341
+r0:=1/4*x^2-1/2*x^2*log(x)+1/2*x^2*log(x)^2
+--R 
+--R
+--R          2      2     2          2
+--R        2x log(x)  - 2x log(x) + x
+--R   (2)  ---------------------------
+--R                     4
+--R                                                    Type: Expression(Integer)
+--E 4745
+
+--S 4746 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2      2     2          2
+--R        2x log(x)  - 2x log(x) + x
+--R   (3)  ---------------------------
+--R                     4
+--R                                         Type: Union(Expression(Integer),...)
+--E 4746
+
+--S 4747 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4747
+
+--S 4748 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4748
+
+)clear all
+
+--S 4749 of 5341
+t0:=x^m*log(x)
+--R 
+--R
+--R               m
+--R   (1)  log(x)x
+--R                                                    Type: Expression(Integer)
+--E 4749
+
+--S 4750 of 5341
+r0:=-x^(1+m)/(1+m)^2+x^(1+m)*log(x)/(1+m)
+--R 
+--R
+--R                            m + 1
+--R        ((m + 1)log(x) - 1)x
+--R   (2)  -------------------------
+--R                2
+--R               m  + 2m + 1
+--R                                                    Type: Expression(Integer)
+--E 4750
+
+--S 4751 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                               m log(x)
+--R        ((m + 1)x log(x) - x)%e
+--R   (3)  -------------------------------
+--R                   2
+--R                  m  + 2m + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 4751
+
+--S 4752 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                               m log(x)                         m + 1
+--R        ((m + 1)x log(x) - x)%e         + ((- m - 1)log(x) + 1)x
+--R   (4)  -------------------------------------------------------------
+--R                                  2
+--R                                 m  + 2m + 1
+--R                                                    Type: Expression(Integer)
+--E 4752
+
+--S 4753 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4753
+
+)clear all
+
+--S 4754 of 5341
+t0:=x^(m+n)*log(x)
+--R 
+--R
+--R               n + m
+--R   (1)  log(x)x
+--R                                                    Type: Expression(Integer)
+--E 4754
+
+--S 4755 of 5341
+r0:=-x^(1+m+n)/(1+m+n)^2+x^(1+m+n)*log(x)/(1+m+n)
+--R 
+--R
+--R                                n + m + 1
+--R        ((n + m + 1)log(x) - 1)x
+--R   (2)  ---------------------------------
+--R            2                2
+--R           n  + (2m + 2)n + m  + 2m + 1
+--R                                                    Type: Expression(Integer)
+--E 4755
+
+--S 4756 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                   (n + m)log(x)
+--R        ((n + m + 1)x log(x) - x)%e
+--R   (3)  ----------------------------------------
+--R               2                2
+--R              n  + (2m + 2)n + m  + 2m + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 4756
+
+--S 4757 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                  (n + m)log(x)
+--R       ((n + m + 1)x log(x) - x)%e
+--R     + 
+--R                                 n + m + 1
+--R       ((- n - m - 1)log(x) + 1)x
+--R  /
+--R      2                2
+--R     n  + (2m + 2)n + m  + 2m + 1
+--R                                                    Type: Expression(Integer)
+--E 4757
+
+--S 4758 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4758
+
+)clear all
+
+--S 4759 of 5341
+t0:=x^m*log(a*x)
+--R 
+--R
+--R                 m
+--R   (1)  log(a x)x
+--R                                                    Type: Expression(Integer)
+--E 4759
+
+--S 4760 of 5341
+r0:=-x^(1+m)/(1+m)^2+x^(1+m)*log(a*x)/(1+m)
+--R 
+--R
+--R                              m + 1
+--R        ((m + 1)log(a x) - 1)x
+--R   (2)  ---------------------------
+--R                 2
+--R                m  + 2m + 1
+--R                                                    Type: Expression(Integer)
+--E 4760
+
+--S 4761 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                 m log(x)
+--R        ((m + 1)x log(x) + (m + 1)x log(a) - x)%e
+--R   (3)  -------------------------------------------------
+--R                            2
+--R                           m  + 2m + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 4761
+
+--S 4762 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                m log(x)
+--R       ((m + 1)x log(x) + (m + 1)x log(a) - x)%e
+--R     + 
+--R                               m + 1
+--R       ((- m - 1)log(a x) + 1)x
+--R  /
+--R      2
+--R     m  + 2m + 1
+--R                                                    Type: Expression(Integer)
+--E 4762
+
+--S 4763 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4763
+
+)clear all
+
+--S 4764 of 5341
+t0:=x^2*log(x)^2
+--R 
+--R
+--R         2      2
+--R   (1)  x log(x)
+--R                                                    Type: Expression(Integer)
+--E 4764
+
+--S 4765 of 5341
+r0:=2/27*x^3-2/9*x^3*log(x)+1/3*x^3*log(x)^2
+--R 
+--R
+--R          3      2     3           3
+--R        9x log(x)  - 6x log(x) + 2x
+--R   (2)  ----------------------------
+--R                     27
+--R                                                    Type: Expression(Integer)
+--E 4765
+
+--S 4766 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          3      2     3           3
+--R        9x log(x)  - 6x log(x) + 2x
+--R   (3)  ----------------------------
+--R                     27
+--R                                         Type: Union(Expression(Integer),...)
+--E 4766
+
+--S 4767 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4767
+
+--S 4768 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4768
+
+)clear all
+
+--S 4769 of 5341
+t0:=x^3*log(x)^3
+--R 
+--R
+--R         3      3
+--R   (1)  x log(x)
+--R                                                    Type: Expression(Integer)
+--E 4769
+
+--S 4770 of 5341
+r0:=-3/128*x^4+3/32*x^4*log(x)-3/16*x^4*log(x)^2+1/4*x^4*log(x)^3
+--R 
+--R
+--R           4      3      4      2      4           4
+--R        32x log(x)  - 24x log(x)  + 12x log(x) - 3x
+--R   (2)  --------------------------------------------
+--R                             128
+--R                                                    Type: Expression(Integer)
+--E 4770
+
+--S 4771 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           4      3      4      2      4           4
+--R        32x log(x)  - 24x log(x)  + 12x log(x) - 3x
+--R   (3)  --------------------------------------------
+--R                             128
+--R                                         Type: Union(Expression(Integer),...)
+--E 4771
+
+--S 4772 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4772
+
+--S 4773 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4773
+
+)clear all
+
+--S 4774 of 5341
+t0:=1/(x*sqrt(1-log(x)^2))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R          +-------------+
+--R          |        2
+--R        x\|- log(x)  + 1
+--R                                                    Type: Expression(Integer)
+--E 4774
+
+--S 4775 of 5341
+r0:=asin(log(x))
+--R 
+--R
+--R   (2)  asin(log(x))
+--R                                                    Type: Expression(Integer)
+--E 4775
+
+--S 4776 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +-------------+
+--R                 |        2
+--R                \|- log(x)  + 1  - 1
+--R   (3)  - 2atan(--------------------)
+--R                       log(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 4776
+
+--S 4777 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                 +-------------+
+--R                 |        2
+--R                \|- log(x)  + 1  - 1
+--R   (4)  - 2atan(--------------------) - asin(log(x))
+--R                       log(x)
+--R                                                    Type: Expression(Integer)
+--E 4777
+
+--S 4778 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4778
+
+)clear all
+
+--S 4779 of 5341
+t0:=16*x^3*log(x)^2
+--R 
+--R
+--R           3      2
+--R   (1)  16x log(x)
+--R                                                    Type: Expression(Integer)
+--E 4779
+
+--S 4780 of 5341
+r0:=1/2*x^4-2*x^4*log(x)+4*x^4*log(x)^2
+--R 
+--R
+--R          4      2     4          4
+--R        8x log(x)  - 4x log(x) + x
+--R   (2)  ---------------------------
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 4780
+
+--S 4781 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          4      2     4          4
+--R        8x log(x)  - 4x log(x) + x
+--R   (3)  ---------------------------
+--R                     2
+--R                                         Type: Union(Expression(Integer),...)
+--E 4781
+
+--S 4782 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4782
+
+--S 4783 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4783
+
+)clear all
+
+--S 4784 of 5341
+t0:=log(sqrt(a+b*x))
+--R 
+--R
+--R             +-------+
+--R   (1)  log(\|b x + a )
+--R                                                    Type: Expression(Integer)
+--E 4784
+
+--S 4785 of 5341
+r0:=-1/2*x+(a+b*x)*log(sqrt(a+b*x))/b
+--R 
+--R
+--R                        +-------+
+--R        (2b x + 2a)log(\|b x + a ) - b x
+--R   (2)  --------------------------------
+--R                       2b
+--R                                                    Type: Expression(Integer)
+--E 4785
+
+--S 4786 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                        +-------+
+--R        (2b x + 2a)log(\|b x + a ) - b x
+--R   (3)  --------------------------------
+--R                       2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 4786
+
+--S 4787 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4787
+
+--S 4788 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4788
+
+)clear all
+
+--S 4789 of 5341
+t0:=x*log(sqrt(2+x))
+--R 
+--R
+--R               +-----+
+--R   (1)  x log(\|x + 2 )
+--R                                                    Type: Expression(Integer)
+--E 4789
+
+--S 4790 of 5341
+r0:=1/2*x-1/8*x^2-log(2+x)+1/2*x^2*log(sqrt(2+x))
+--R 
+--R
+--R          2     +-----+                   2
+--R        4x log(\|x + 2 ) - 8log(x + 2) - x  + 4x
+--R   (2)  ----------------------------------------
+--R                            8
+--R                                                    Type: Expression(Integer)
+--E 4790
+
+--S 4791 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2           +-----+     2
+--R        (4x  - 16)log(\|x + 2 ) - x  + 4x
+--R   (3)  ---------------------------------
+--R                        8
+--R                                         Type: Union(Expression(Integer),...)
+--E 4791
+
+--S 4792 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                +-----+
+--R   (4)  - 2log(\|x + 2 ) + log(x + 2)
+--R                                                    Type: Expression(Integer)
+--E 4792
+
+--S 4793 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4793
+
+)clear all
+
+--S 4794 of 5341
+t0:=x*log((1+3*x)^(1/3))
+--R 
+--R
+--R              3+------+
+--R   (1)  x log(\|3x + 1 )
+--R                                                    Type: Expression(Integer)
+--E 4794
+
+--S 4795 of 5341
+r0:=1/18*x-1/12*x^2+1/2*x^2*log((1+3*x)^(1/3))-1/54*log(1+3*x)
+--R 
+--R
+--R           2    3+------+                     2
+--R        54x log(\|3x + 1 ) - 2log(3x + 1) - 9x  + 6x
+--R   (2)  --------------------------------------------
+--R                             108
+--R                                                    Type: Expression(Integer)
+--E 4795
+
+--S 4796 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R            2         3+------+      2
+--R        (18x  - 2)log(\|3x + 1 ) - 3x  + 2x
+--R   (3)  -----------------------------------
+--R                         36
+--R                                         Type: Union(Expression(Integer),...)
+--E 4796
+
+--S 4797 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               3+------+
+--R        - 3log(\|3x + 1 ) + log(3x + 1)
+--R   (4)  -------------------------------
+--R                       54
+--R                                                    Type: Expression(Integer)
+--E 4797
+
+--S 4798 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4798
+
+)clear all
+
+--S 4799 of 5341
+t0:=x*log(x+x^3)
+--R 
+--R
+--R               3
+--R   (1)  x log(x  + x)
+--R                                                    Type: Expression(Integer)
+--E 4799
+
+--S 4800 of 5341
+r0:=-3/4*x^2+1/2*log(1+x^2)+1/2*x^2*log(x+x^3)
+--R 
+--R
+--R          2     3              2          2
+--R        2x log(x  + x) + 2log(x  + 1) - 3x
+--R   (2)  -----------------------------------
+--R                         4
+--R                                                    Type: Expression(Integer)
+--E 4800
+
+--S 4801 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          2     3              2          2
+--R        2x log(x  + x) + 2log(x  + 1) - 3x
+--R   (3)  -----------------------------------
+--R                         4
+--R                                         Type: Union(Expression(Integer),...)
+--E 4801
+
+--S 4802 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4802
+
+--S 4803 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4803
+
+)clear all
+
+--S 4804 of 5341
+t0:=log(x+sqrt(1+x^2))
+--R 
+--R
+--R             +------+
+--R             | 2
+--R   (1)  log(\|x  + 1  + x)
+--R                                                    Type: Expression(Integer)
+--E 4804
+
+--S 4805 of 5341
+r0:=x*log(x+sqrt(1+x^2))-sqrt(1+x^2)
+--R 
+--R
+--R               +------+         +------+
+--R               | 2              | 2
+--R   (2)  x log(\|x  + 1  + x) - \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 4805
+
+--S 4806 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           +------+           +------+          +------+
+--R           | 2         2      | 2               | 2         2
+--R        (x\|x  + 1  - x )log(\|x  + 1  + x) + x\|x  + 1  - x  - 1
+--R   (3)  ---------------------------------------------------------
+--R                               +------+
+--R                               | 2
+--R                              \|x  + 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4806
+
+--S 4807 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4807
+
+--S 4808 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4808
+
+)clear all
+
+--S 4809 of 5341
+t0:=log(x+sqrt(-1+x^2))
+--R 
+--R
+--R             +------+
+--R             | 2
+--R   (1)  log(\|x  - 1  + x)
+--R                                                    Type: Expression(Integer)
+--E 4809
+
+--S 4810 of 5341
+r0:=x*log(x+sqrt(-1+x^2))-sqrt(-1+x^2)
+--R 
+--R
+--R               +------+         +------+
+--R               | 2              | 2
+--R   (2)  x log(\|x  - 1  + x) - \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 4810
+
+--S 4811 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           +------+           +------+          +------+
+--R           | 2         2      | 2               | 2         2
+--R        (x\|x  - 1  - x )log(\|x  - 1  + x) + x\|x  - 1  - x  + 1
+--R   (3)  ---------------------------------------------------------
+--R                               +------+
+--R                               | 2
+--R                              \|x  - 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4811
+
+--S 4812 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4812
+
+--S 4813 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4813
+
+)clear all
+
+--S 4814 of 5341
+t0:=log(x-sqrt(-1+x^2))
+--R 
+--R
+--R               +------+
+--R               | 2
+--R   (1)  log(- \|x  - 1  + x)
+--R                                                    Type: Expression(Integer)
+--E 4814
+
+--S 4815 of 5341
+r0:=x*log(x-sqrt(-1+x^2))+sqrt(-1+x^2)
+--R 
+--R
+--R                 +------+         +------+
+--R                 | 2              | 2
+--R   (2)  x log(- \|x  - 1  + x) + \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 4815
+
+--S 4816 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           +------+             +------+          +------+
+--R           | 2         2        | 2               | 2         2
+--R        (x\|x  - 1  - x )log(- \|x  - 1  + x) - x\|x  - 1  + x  - 1
+--R   (3)  -----------------------------------------------------------
+--R                                +------+
+--R                                | 2
+--R                               \|x  - 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4816
+
+--S 4817 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4817
+
+--S 4818 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4818
+
+)clear all
+
+--S 4819 of 5341
+t0:=log(sqrt(x)+sqrt(1+x))
+--R 
+--R
+--R             +-----+    +-+
+--R   (1)  log(\|x + 1  + \|x )
+--R                                                    Type: Expression(Integer)
+--E 4819
+
+--S 4820 of 5341
+r0:=1/2*atanh(sqrt(x/(1+x)))+x*log(sqrt(x)+sqrt(1+x))-1/2*sqrt(x/(1+x))/_
+   (1-x/(1+x))
+--R 
+--R
+--R                                         +-----+              +-----+
+--R                +-----+    +-+           |  x                 |  x
+--R        2x log(\|x + 1  + \|x ) + atanh( |----- ) + (- x - 1) |-----
+--R                                        \|x + 1              \|x + 1
+--R   (2)  -------------------------------------------------------------
+--R                                      2
+--R                                                    Type: Expression(Integer)
+--E 4820
+
+-- failed - cannot handle that integrand
+--S 4821 of 5341
+--a0:=integrate(t0,x)
+--E 4821
+
+--S 4822 of 5341
+--m0:=a0-r0
+--E 4822
+
+--S 4823 of 5341
+--d0:=D(m0,x)
+--E 4823
+
+)clear all
+
+--S 4824 of 5341
+t0:=x^(1/3)*log(x)
+--R 
+--R
+--R              3+-+
+--R   (1)  log(x)\|x
+--R                                                    Type: Expression(Integer)
+--E 4824
+
+--S 4825 of 5341
+r0:=-9/16*x^(4/3)+3/4*x^(4/3)*log(x)
+--R 
+--R
+--R                         3+-+
+--R        (12x log(x) - 9x)\|x
+--R   (2)  ---------------------
+--R                  16
+--R                                                    Type: Expression(Integer)
+--E 4825
+
+--S 4826 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                         3+-+
+--R        (12x log(x) - 9x)\|x
+--R   (3)  ---------------------
+--R                  16
+--R                                         Type: Union(Expression(Integer),...)
+--E 4826
+
+--S 4827 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4827
+
+--S 4828 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4828
+
+)clear all
+
+--S 4829 of 5341
+t0:=2^log(x)
+--R 
+--R
+--R         log(x)
+--R   (1)  2
+--R                                                    Type: Expression(Integer)
+--E 4829
+
+--S 4830 of 5341
+r0:=x^(1+log(2))/(1+log(2))
+--R 
+--R
+--R         log(2) + 1
+--R        x
+--R   (2)  -----------
+--R         log(2) + 1
+--R                                                    Type: Expression(Integer)
+--E 4830
+
+--S 4831 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R            log(2)log(x)
+--R        x %e
+--R   (3)  ----------------
+--R           log(2) + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 4831
+
+--S 4832 of 5341
+m0:=a0-r0
+--R 
+--R
+--R            log(2)log(x)    log(2) + 1
+--R        x %e             - x
+--R   (4)  ------------------------------
+--R                  log(2) + 1
+--R                                                    Type: Expression(Integer)
+--E 4832
+
+--S 4833 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4833
+
+)clear all
+
+--S 4834 of 5341
+t0:=(1-log(x))/x^2
+--R 
+--R
+--R        - log(x) + 1
+--R   (1)  ------------
+--R              2
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 4834
+
+--S 4835 of 5341
+r0:=log(x)/x,1/x+(-1+log(x))/x
+--R 
+--R
+--R         log(x) log(x)
+--R   (2)  [------,------]
+--R            x      x
+--R                                             Type: Tuple(Expression(Integer))
+--E 4835
+
+--S 4836 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(x)
+--R   (3)  ------
+--R           x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4836
+
+--S 4837 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4837
+
+--S 4838 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4838
+
+)clear all
+
+--S 4839 of 5341
+--t0:=complexexpand(log(abs(-a^2+x^2)))
+--E 4839
+
+--S 4840 of 5341
+--r0:=-2*x+2*a*atanh(x/a)+1/2*x*log((-a^2+x^2)^2)
+--E 4840
+
+--S 4841 of 5341
+--a0:=integrate(t0,x)
+--E 4841
+
+--S 4842 of 5341
+--m0:=a0-r0
+--E 4842
+
+--S 4843 of 5341
+--d0:=D(m0,x)
+--E 4843
+
+)clear all
+
+--S 4844 of 5341
+t0:=log(1+x+sqrt(1+x))
+--R 
+--R
+--R             +-----+
+--R   (1)  log(\|x + 1  + x + 1)
+--R                                                    Type: Expression(Integer)
+--E 4844
+
+--S 4845 of 5341
+r0:=-x+1/2*log(1+x)+x*log(1+x+sqrt(1+x))+sqrt(1+x)
+--R 
+--R
+--R                +-----+              +-----+
+--R        2x log(\|x + 1  + x + 1) + 2\|x + 1  + log(x + 1) - 2x
+--R   (2)  ------------------------------------------------------
+--R                                   2
+--R                                                    Type: Expression(Integer)
+--E 4845
+
+--S 4846 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-----+                 +-----+     +-----+
+--R   (3)  x log(\|x + 1  + x + 1) + log(\|x + 1 ) + \|x + 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4846
+
+--S 4847 of 5341
+m0:=a0-r0
+--R 
+--R
+--R              +-----+
+--R        2log(\|x + 1 ) - log(x + 1)
+--R   (4)  ---------------------------
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 4847
+
+--S 4848 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4848
+
+)clear all
+
+--S 4849 of 5341
+t0:=log(x+x^3)
+--R 
+--R
+--R             3
+--R   (1)  log(x  + x)
+--R                                                    Type: Expression(Integer)
+--E 4849
+
+--S 4850 of 5341
+r0:=-3*x+2*atan(x)+x*log(x+x^3)
+--R 
+--R
+--R               3
+--R   (2)  x log(x  + x) + 2atan(x) - 3x
+--R                                                    Type: Expression(Integer)
+--E 4850
+
+--S 4851 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R               3
+--R   (3)  x log(x  + x) + 2atan(x) - 3x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4851
+
+--S 4852 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4852
+
+--S 4853 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4853
+
+)clear all
+
+--S 4854 of 5341
+t0:=2^log(-8+7*x)
+--R 
+--R
+--R         log(7x - 8)
+--R   (1)  2
+--R                                                    Type: Expression(Integer)
+--E 4854
+
+--S 4855 of 5341
+r0:=1/7*(-8+7*x)^(1+log(2))/(1+log(2))
+--R 
+--R
+--R                log(2) + 1
+--R        (7x - 8)
+--R   (2)  ------------------
+--R            7log(2) + 7
+--R                                                    Type: Expression(Integer)
+--E 4855
+
+--S 4856 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                  log(2)log(7x - 8)
+--R        (7x - 8)%e
+--R   (3)  ---------------------------
+--R                7log(2) + 7
+--R                                         Type: Union(Expression(Integer),...)
+--E 4856
+
+--S 4857 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                  log(2)log(7x - 8)           log(2) + 1
+--R        (7x - 8)%e                  - (7x - 8)
+--R   (4)  ------------------------------------------------
+--R                           7log(2) + 7
+--R                                                    Type: Expression(Integer)
+--E 4857
+
+--S 4858 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4858
+
+)clear all
+
+--S 4859 of 5341
+t0:=log((-11+5*x)/(5+76*x))
+--R 
+--R
+--R            5x - 11
+--R   (1)  log(-------)
+--R            76x + 5
+--R                                                    Type: Expression(Integer)
+--E 4859
+
+--S 4860 of 5341
+r0:=-1/5*(11-5*x)*log((-11+5*x)/(5+76*x))-861/380*log(5+76*x)
+--R 
+--R
+--R                                            5x - 11
+--R        - 861log(76x + 5) + (380x - 836)log(-------)
+--R                                            76x + 5
+--R   (2)  --------------------------------------------
+--R                             380
+--R                                                    Type: Expression(Integer)
+--E 4860
+
+--S 4861 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                      5x - 11
+--R        - 25log(76x + 5) - 836log(5x - 11) + 380x log(-------)
+--R                                                      76x + 5
+--R   (3)  ------------------------------------------------------
+--R                                  380
+--R                                         Type: Union(Expression(Integer),...)
+--E 4861
+
+--S 4862 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                                                5x - 11
+--R        11log(76x + 5) - 11log(5x - 11) + 11log(-------)
+--R                                                76x + 5
+--R   (4)  ------------------------------------------------
+--R                                5
+--R                                                    Type: Expression(Integer)
+--E 4862
+
+--S 4863 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4863
+
+)clear all
+
+--S 4864 of 5341
+t0:=log((1+x)/(-1+x))/x^2
+--R 
+--R
+--R            x + 1
+--R        log(-----)
+--R            x - 1
+--R   (1)  ----------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 4864
+
+--S 4865 of 5341
+r0:=-2*log(1-x)+2*log(x)-(1+x)*log((-1-x)/(1-x))/x
+--R 
+--R
+--R                                 x + 1
+--R        2x log(x) + (- x - 1)log(-----) - 2x log(- x + 1)
+--R                                 x - 1
+--R   (2)  -------------------------------------------------
+--R                                x
+--R                                                    Type: Expression(Integer)
+--E 4865
+
+--S 4866 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 2                        x + 1
+--R        - x log(x  - 1) + 2x log(x) - log(-----)
+--R                                          x - 1
+--R   (3)  ----------------------------------------
+--R                            x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4866
+
+--S 4867 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               2            x + 1
+--R   (4)  - log(x  - 1) + log(-----) + 2log(- x + 1)
+--R                            x - 1
+--R                                                    Type: Expression(Integer)
+--E 4867
+
+--S 4868 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4868
+
+)clear all
+
+--S 4869 of 5341
+t0:=log(1/(13+x))
+--R 
+--R
+--R               1
+--R   (1)  log(------)
+--R            x + 13
+--R                                                    Type: Expression(Integer)
+--E 4869
+
+--S 4870 of 5341
+r0:=x+(13+x)*log(1/(13+x))
+--R 
+--R
+--R                       1
+--R   (2)  (x + 13)log(------) + x
+--R                    x + 13
+--R                                                    Type: Expression(Integer)
+--E 4870
+
+--S 4871 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                       1
+--R   (3)  (x + 13)log(------) + x
+--R                    x + 13
+--R                                         Type: Union(Expression(Integer),...)
+--E 4871
+
+--S 4872 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4872
+
+--S 4873 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4873
+
+)clear all
+
+--S 4874 of 5341
+t0:=x*log((1+x)/x^2)
+--R 
+--R
+--R              x + 1
+--R   (1)  x log(-----)
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 4874
+
+--S 4875 of 5341
+r0:=1/2*x+1/4*x^2-1/2*log(1+x)+1/2*x^2*log((1+x)/x^2)
+--R 
+--R
+--R                          2    x + 1     2
+--R        - 2log(x + 1) + 2x log(-----) + x  + 2x
+--R                                  2
+--R                                 x
+--R   (2)  ---------------------------------------
+--R                           4
+--R                                                    Type: Expression(Integer)
+--E 4875
+
+--S 4876 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                          2    x + 1     2
+--R        - 2log(x + 1) + 2x log(-----) + x  + 2x
+--R                                  2
+--R                                 x
+--R   (3)  ---------------------------------------
+--R                           4
+--R                                         Type: Union(Expression(Integer),...)
+--E 4876
+
+--S 4877 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4877
+
+--S 4878 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4878
+
+)clear all
+
+--S 4879 of 5341
+t0:=x^3*log((7+5*x)/x^2)
+--R 
+--R
+--R         3    5x + 7
+--R   (1)  x log(------)
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 4879
+
+--S 4880 of 5341
+r0:=343/500*x-49/200*x^2+7/60*x^3+1/16*x^4-2401/2500*log(7+5*x)+_
+   1/4*x^4*log((7+5*x)/x^2)
+--R 
+--R
+--R   (2)
+--R                             4    5x + 7         4        3        2
+--R   - 28812log(5x + 7) + 7500x log(------) + 1875x  + 3500x  - 7350x  + 20580x
+--R                                     2
+--R                                    x
+--R   --------------------------------------------------------------------------
+--R                                      30000
+--R                                                    Type: Expression(Integer)
+--E 4880
+
+--S 4881 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                             4    5x + 7         4        3        2
+--R   - 28812log(5x + 7) + 7500x log(------) + 1875x  + 3500x  - 7350x  + 20580x
+--R                                     2
+--R                                    x
+--R   --------------------------------------------------------------------------
+--R                                      30000
+--R                                         Type: Union(Expression(Integer),...)
+--E 4881
+
+--S 4882 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4882
+
+--S 4883 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4883
+
+)clear all
+
+--S 4884 of 5341
+t0:=(a+b*x)*log(a+b*x)
+--R 
+--R
+--R   (1)  (b x + a)log(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 4884
+
+--S 4885 of 5341
+r0:=-1/2*a*x-1/4*b*x^2+1/2*(a+b*x)^2*log(a+b*x)/b
+--R 
+--R
+--R           2 2              2                 2 2
+--R        (2b x  + 4a b x + 2a )log(b x + a) - b x  - 2a b x
+--R   (2)  --------------------------------------------------
+--R                                4b
+--R                                                    Type: Expression(Integer)
+--E 4885
+
+--S 4886 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2 2              2                 2 2
+--R        (2b x  + 4a b x + 2a )log(b x + a) - b x  - 2a b x
+--R   (3)  --------------------------------------------------
+--R                                4b
+--R                                         Type: Union(Expression(Integer),...)
+--E 4886
+
+--S 4887 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4887
+
+--S 4888 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4888
+
+)clear all
+
+--S 4889 of 5341
+t0:=(a+b*x)^2*log(a+b*x)
+--R 
+--R
+--R          2 2             2
+--R   (1)  (b x  + 2a b x + a )log(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 4889
+
+--S 4890 of 5341
+r0:=-1/9*(a+b*x)^3/b+1/3*(a+b*x)^3*log(a+b*x)/b
+--R 
+--R
+--R   (2)
+--R      3 3       2 2     2        3                 3 3       2 2     2       3
+--R   (3b x  + 9a b x  + 9a b x + 3a )log(b x + a) - b x  - 3a b x  - 3a b x - a
+--R   ---------------------------------------------------------------------------
+--R                                        9b
+--R                                                    Type: Expression(Integer)
+--E 4890
+
+--S 4891 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           3 3       2 2     2        3                 3 3       2 2     2
+--R        (3b x  + 9a b x  + 9a b x + 3a )log(b x + a) - b x  - 3a b x  - 3a b x
+--R   (3)  ----------------------------------------------------------------------
+--R                                          9b
+--R                                         Type: Union(Expression(Integer),...)
+--E 4891
+
+--S 4892 of 5341
+m0:=a0-r0
+--R 
+--R
+--R         3
+--R        a
+--R   (4)  --
+--R        9b
+--R                                                    Type: Expression(Integer)
+--E 4892
+
+--S 4893 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4893
+
+)clear all
+
+--S 4894 of 5341
+t0:=log(a+b*x)/(a+b*x)
+--R 
+--R
+--R        log(b x + a)
+--R   (1)  ------------
+--R           b x + a
+--R                                                    Type: Expression(Integer)
+--E 4894
+
+--S 4895 of 5341
+r0:=1/2*log(a+b*x)^2/b
+--R 
+--R
+--R                    2
+--R        log(b x + a)
+--R   (2)  -------------
+--R              2b
+--R                                                    Type: Expression(Integer)
+--E 4895
+
+--S 4896 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    2
+--R        log(b x + a)
+--R   (3)  -------------
+--R              2b
+--R                                         Type: Union(Expression(Integer),...)
+--E 4896
+
+--S 4897 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4897
+
+--S 4898 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4898
+
+)clear all
+
+--S 4899 of 5341
+t0:=log(a+b*x)/(a+b*x)^2
+--R 
+--R
+--R           log(b x + a)
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 4899
+
+--S 4900 of 5341
+r0:=(-1)/(b*(a+b*x))-log(a+b*x)/(b*(a+b*x))
+--R 
+--R
+--R        - log(b x + a) - 1
+--R   (2)  ------------------
+--R              2
+--R             b x + a b
+--R                                                    Type: Expression(Integer)
+--E 4900
+
+--S 4901 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - log(b x + a) - 1
+--R   (3)  ------------------
+--R              2
+--R             b x + a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 4901
+
+--S 4902 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 4902
+
+--S 4903 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4903
+
+)clear all
+
+--S 4904 of 5341
+t0:=(a+b*x)^n*log(a+b*x)
+--R 
+--R
+--R                             n
+--R   (1)  log(b x + a)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 4904
+
+--S 4905 of 5341
+r0:=-(a+b*x)^(1+n)/(b*(1+n)^2)+(a+b*x)^(1+n)*log(a+b*x)/(b*(1+n))
+--R 
+--R
+--R                                          n + 1
+--R        ((n + 1)log(b x + a) - 1)(b x + a)
+--R   (2)  ---------------------------------------
+--R                       2
+--R                    b n  + 2b n + b
+--R                                                    Type: Expression(Integer)
+--E 4905
+
+--S 4906 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                        n log(b x + a)
+--R        (((b n + b)x + a n + a)log(b x + a) - b x - a)%e
+--R   (3)  --------------------------------------------------------------
+--R                                   2
+--R                                b n  + 2b n + b
+--R                                         Type: Union(Expression(Integer),...)
+--E 4906
+
+--S 4907 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                                                       n log(b x + a)
+--R       (((b n + b)x + a n + a)log(b x + a) - b x - a)%e
+--R     + 
+--R                                           n + 1
+--R       ((- n - 1)log(b x + a) + 1)(b x + a)
+--R  /
+--R        2
+--R     b n  + 2b n + b
+--R                                                    Type: Expression(Integer)
+--E 4907
+
+--S 4908 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4908
+
+)clear all
+
+--S 4909 of 5341
+t0:=log(a*log(b*x)^p)
+--R 
+--R
+--R                      p
+--R   (1)  log(a log(b x) )
+--R                                                    Type: Expression(Integer)
+--E 4909
+
+--S 4910 of 5341
+--r0:=-p*Li(b*x)/b+x*log(a*log(b*x)^p)
+--E 4910
+
+--S 4911 of 5341
+--a0:=integrate(t0,x)
+--E 4911
+
+--S 4912 of 5341
+--m0:=a0-r0
+--E 4912
+
+--S 4913 of 5341
+--d0:=D(m0,x)
+--E 4913
+
+)clear all
+
+--S 4914 of 5341
+t0:=log(a*log(b*x^n)^p)
+--R 
+--R
+--R                     n p
+--R   (1)  log(a log(b x ) )
+--R                                                    Type: Expression(Integer)
+--E 4914
+
+--S 4915 of 5341
+--r0:=-p*x*Ei(log(b*x^n)/n)/(b*x^n)^(1/n)+x*log(a*log(b*x^n)^p)
+--E 4915
+
+--S 4916 of 5341
+--a0:=integrate(t0,x)
+--E 4916
+
+--S 4917 of 5341
+--m0:=a0-r0
+--E 4917
+
+--S 4918 of 5341
+--d0:=D(m0,x)
+--E 4918
+
+)clear all
+
+--S 4919 of 5341
+t0:=log(a*log(b*x)^p)/x
+--R 
+--R
+--R                      p
+--R        log(a log(b x) )
+--R   (1)  ----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 4919
+
+--S 4920 of 5341
+r0:=-log(b*x)*(p-log(a*log(b*x)^p))
+--R 
+--R
+--R                              p
+--R   (2)  log(b x)log(a log(b x) ) - p log(b x)
+--R                                                    Type: Expression(Integer)
+--E 4920
+
+--S 4921 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  p log(b x)log(log(b x)) + (log(a) - p)log(b x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 4921
+
+--S 4922 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                                p
+--R   (4)  - log(b x)log(a log(b x) ) + p log(b x)log(log(b x)) + log(a)log(b x)
+--R                                                    Type: Expression(Integer)
+--E 4922
+
+--S 4923 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4923
+
+)clear all
+
+--S 4924 of 5341
+t0:=log(a*log(b*x^n)^p)/x
+--R 
+--R
+--R                     n p
+--R        log(a log(b x ) )
+--R   (1)  -----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 4924
+
+--S 4925 of 5341
+r0:=-log(b*x^n)*(p-log(a*log(b*x^n)^p))/n
+--R 
+--R
+--R               n              n p             n
+--R        log(b x )log(a log(b x ) ) - p log(b x )
+--R   (2)  ----------------------------------------
+--R                            n
+--R                                                    Type: Expression(Integer)
+--E 4925
+
+--S 4926 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (n p log(x) + p log(b))log(n log(x) + log(b)) + (n log(a) - n p)log(x)
+--R   (3)  ----------------------------------------------------------------------
+--R                                           n
+--R                                         Type: Union(Expression(Integer),...)
+--E 4926
+
+--S 4927 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                n              n p             n
+--R       - log(b x )log(a log(b x ) ) + p log(b x )
+--R     + 
+--R       (n p log(x) + p log(b))log(n log(x) + log(b)) + (n log(a) - n p)log(x)
+--R  /
+--R     n
+--R                                                    Type: Expression(Integer)
+--E 4927
+
+--S 4928 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4928
+
+)clear all
+
+--S 4929 of 5341
+t0:=x^m*log(a*log(b*x)^p)
+--R 
+--R
+--R         m              p
+--R   (1)  x log(a log(b x) )
+--R                                                    Type: Expression(Integer)
+--E 4929
+
+--S 4930 of 5341
+--r0:=-p*x^(1+m)*(b*x)^(-1-m)*Ei((1+m)*log(b*x))/(1+m)+x^(1+m)*_
+--  log(a*log(b*x)^p)/(1+m)
+--E 4930
+
+--S 4931 of 5341
+--a0:=integrate(t0,x)
+--E 4931
+
+--S 4932 of 5341
+--m0:=a0-r0
+--E 4932
+
+--S 4933 of 5341
+--d0:=D(m0,x)
+--E 4933
+
+)clear all
+
+--S 4934 of 5341
+t0:=x^m*log(a*log(b*x^n)^p)
+--R 
+--R
+--R         m             n p
+--R   (1)  x log(a log(b x ) )
+--R                                                    Type: Expression(Integer)
+--E 4934
+
+--S 4935 of 5341
+--r0:=-p*x^(1+m)*Ei((1+m)*log(b*x^n)/n)/((1+m)*(b*x^n)^((1+m)/n))+_
+--  x^(1+m)*log(a*log(b*x^n)^p)/(1+m)
+--E 4935
+
+--S 4936 of 5341
+--a0:=integrate(t0,x)
+--E 4936
+
+--S 4937 of 5341
+--m0:=a0-r0
+--E 4937
+
+--S 4938 of 5341
+--d0:=D(m0,x)
+--E 4938
+
+)clear all
+
+--S 4939 of 5341
+t0:=log(x)/sqrt(a+b*log(x))
+--R 
+--R
+--R             log(x)
+--R   (1)  ---------------
+--R         +------------+
+--R        \|b log(x) + a
+--R                                                    Type: Expression(Integer)
+--E 4939
+
+--S 4940 of 5341
+--r0:=-a*erfi(sqrt(a+b*log(x))/sqrt(b))*sqrt(%pi)/(%e^(a/b)*b^(3/2))-_
+--  1/2*erfi(sqrt(a+b*log(x))/sqrt(b))*sqrt(%pi)/(%e^(a/b)*sqrt(b))+x*_
+--  sqrt(a+b*log(x))/b
+--E 4940
+
+--S 4941 of 5341
+--a0:=integrate(t0,x)
+--E 4941
+
+--S 4942 of 5341
+--m0:=a0-r0
+--E 4942
+
+--S 4943 of 5341
+--d0:=D(m0,x)
+--E 4943
+
+)clear all
+
+--S 4944 of 5341
+t0:=log(x)/sqrt(a-b*log(x))
+--R 
+--R
+--R              log(x)
+--R   (1)  -----------------
+--R         +--------------+
+--R        \|- b log(x) + a
+--R                                                    Type: Expression(Integer)
+--E 4944
+
+--S 4945 of 5341
+r0:=-%e^(a/b)*a*erf(sqrt(a-b*log(x))/sqrt(b))*sqrt(%pi)/b^(3/2)+_
+   1/2*%e^(a/b)*erf(sqrt(a-b*log(x))/sqrt(b))*sqrt(%pi)/sqrt(b)-_
+   x*sqrt(a-b*log(x))/b
+--R 
+--R
+--R                  a
+--R                  -           +--------------+
+--R                  b +---+    \|- b log(x) + a        +-+ +--------------+
+--R        (b - 2a)%e \|%pi erf(-----------------) - 2x\|b \|- b log(x) + a
+--R                                     +-+
+--R                                    \|b
+--R   (2)  -----------------------------------------------------------------
+--R                                         +-+
+--R                                      2b\|b
+--R                                                    Type: Expression(Integer)
+--E 4945
+
+-- integrate: implementation incomplete (constant residues)
+--S 4946 of 5341
+--a0:=integrate(t0,x)
+--E 4946
+
+--S 4947 of 5341
+--m0:=a0-r0
+--E 4947
+
+--S 4948 of 5341
+--d0:=D(m0,x)
+--E 4948
+
+)clear all
+
+--S 4949 of 5341
+t0:=(A+B*log(x))/sqrt(a+b*log(x))
+--R 
+--R
+--R          B log(x) + A
+--R   (1)  ---------------
+--R         +------------+
+--R        \|b log(x) + a
+--R                                                    Type: Expression(Integer)
+--E 4949
+
+--S 4950 of 5341
+--r0:=(A*b-a*B)*erfi(sqrt(a+b*log(x))/sqrt(b))*sqrt(%pi)/(%e^(a/b)*b^(3/2))-_
+--  1/2*B*erfi(sqrt(a+b*log(x))/sqrt(b))*sqrt(%pi)/(%e^(a/b)*sqrt(b))+_
+--  B*x*sqrt(a+b*log(x))/b
+--E 4950
+
+--S 4951 of 5341
+--a0:=integrate(t0,x)
+--E 4951
+
+--S 4952 of 5341
+--m0:=a0-r0
+--E 4952
+
+--S 4953 of 5341
+--d0:=D(m0,x)
+--E 4953
+
+)clear all
+
+--S 4954 of 5341
+t0:=(A+B*log(x))/sqrt(a-b*log(x))
+--R 
+--R
+--R           B log(x) + A
+--R   (1)  -----------------
+--R         +--------------+
+--R        \|- b log(x) + a
+--R                                                    Type: Expression(Integer)
+--E 4954
+
+--S 4955 of 5341
+r0:=-%e^(a/b)*(A*b+a*B)*erf(sqrt(a-b*log(x))/sqrt(b))*sqrt(%pi)/b^(3/2)+_
+   1/2*%e^(a/b)*B*erf(sqrt(a-b*log(x))/sqrt(b))*sqrt(%pi)/sqrt(b)-_
+   B*x*sqrt(a-b*log(x))/b
+--R 
+--R
+--R   (2)
+--R                       a
+--R                       -           +--------------+
+--R                       b +---+    \|- b log(x) + a          +-+ +--------------+
+--R   ((B - 2A)b - 2B a)%e \|%pi erf(-----------------) - 2B x\|b \|- b log(x) + a
+--R                                          +-+
+--R                                         \|b
+--R   -----------------------------------------------------------------------------
+--R                                          +-+
+--R                                       2b\|b
+--R                                                    Type: Expression(Integer)
+--E 4955
+
+-- integrate: implementation incomplete (constant residues)
+--S 4956 of 5341
+--a0:=integrate(t0,x)
+--E 4956
+
+--S 4957 of 5341
+--m0:=a0-r0
+--E 4957
+
+--S 4958 of 5341
+--d0:=D(m0,x)
+--E 4958
+
+)clear all
+
+--S 4959 of 5341
+t0:=x*log(x)/sqrt(-1+x^2)
+--R 
+--R
+--R         x log(x)
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 4959
+
+--S 4960 of 5341
+r0:=atan(sqrt(-1+x^2))-sqrt(-1+x^2)+log(x)*sqrt(-1+x^2)
+--R 
+--R
+--R              +------+                 +------+
+--R              | 2                      | 2
+--R   (2)  atan(\|x  - 1 ) + (log(x) - 1)\|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 4960
+
+--S 4961 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +------+            +------+                         +------+
+--R          | 2                 | 2                              | 2
+--R       (2\|x  - 1  - 2x)atan(\|x  - 1  - x) + (- x log(x) + x)\|x  - 1
+--R     + 
+--R         2               2
+--R       (x  - 1)log(x) - x  + 1
+--R  /
+--R      +------+
+--R      | 2
+--R     \|x  - 1  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4961
+
+--S 4962 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                +------+           +------+
+--R                | 2                | 2
+--R   (4)  - atan(\|x  - 1 ) + 2atan(\|x  - 1  - x)
+--R                                                    Type: Expression(Integer)
+--E 4962
+
+--S 4963 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4963
+
+)clear all
+
+--S 4964 of 5341
+t0:=x*log(x)*sqrt(4+x^2)
+--R 
+--R
+--R                 +------+
+--R                 | 2
+--R   (1)  x log(x)\|x  + 4
+--R                                                    Type: Expression(Integer)
+--E 4964
+
+--S 4965 of 5341
+r0:=-1/9*(4+x^2)^(3/2)+8/3*atanh(1/2*sqrt(4+x^2))+1/3*(4+x^2)^(3/2)*log(x)-_
+   4/3*sqrt(4+x^2)
+--R 
+--R
+--R                 +------+
+--R                 | 2                                      +------+
+--R                \|x  + 4         2                2       | 2
+--R        24atanh(---------) + ((3x  + 12)log(x) - x  - 16)\|x  + 4
+--R                    2
+--R   (2)  ----------------------------------------------------------
+--R                                     9
+--R                                                    Type: Expression(Integer)
+--E 4965
+
+--S 4966 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                    +------+                   +------+
+--R            2       | 2           3            | 2
+--R       ((24x  + 24)\|x  + 4  - 24x  - 72x)log(\|x  + 4  - x + 2)
+--R     + 
+--R                      +------+                   +------+
+--R              2       | 2           3            | 2
+--R       ((- 24x  - 24)\|x  + 4  + 24x  + 72x)log(\|x  + 4  - x - 2)
+--R     + 
+--R                                                      +------+
+--R             5      3                 5      3        | 2
+--R       ((- 3x  - 21x  - 36x)log(x) + x  + 19x  + 48x)\|x  + 4
+--R     + 
+--R          6      4      2                6      4      2
+--R       (3x  + 27x  + 72x  + 48)log(x) - x  - 21x  - 84x  - 64
+--R  /
+--R               +------+
+--R        2      | 2          3
+--R     (9x  + 9)\|x  + 4  - 9x  - 27x
+--R                                         Type: Union(Expression(Integer),...)
+--E 4966
+
+--S 4967 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                                                                    +------+
+--R              +------+                  +------+                    | 2
+--R              | 2                       | 2                        \|x  + 4
+--R        8log(\|x  + 4  - x + 2) - 8log(\|x  + 4  - x - 2) - 8atanh(---------)
+--R                                                                       2
+--R   (4)  ---------------------------------------------------------------------
+--R                                          3
+--R                                                    Type: Expression(Integer)
+--E 4967
+
+--S 4968 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4968
+
+)clear all
+
+--S 4969 of 5341
+t0:=1/(a*x+b*x*log(c*x^n))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R                   n
+--R        b x log(c x ) + a x
+--R                                                    Type: Expression(Integer)
+--E 4969
+
+--S 4970 of 5341
+r0:=log(a+b*log(c*x^n))/(b*n)
+--R 
+--R
+--R                     n
+--R        log(b log(c x ) + a)
+--R   (2)  --------------------
+--R                 b n
+--R                                                    Type: Expression(Integer)
+--E 4970
+
+--S 4971 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        log(b n log(x) + b log(c) + a)
+--R   (3)  ------------------------------
+--R                      b n
+--R                                         Type: Union(Expression(Integer),...)
+--E 4971
+
+--S 4972 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                       n
+--R        - log(b log(c x ) + a) + log(b n log(x) + b log(c) + a)
+--R   (4)  -------------------------------------------------------
+--R                                  b n
+--R                                                    Type: Expression(Integer)
+--E 4972
+
+--S 4973 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4973
+
+)clear all
+
+--S 4974 of 5341
+t0:=1/(a*x+b*x*log(c*x^n)^2)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                   n 2
+--R        b x log(c x )  + a x
+--R                                                    Type: Expression(Integer)
+--E 4974
+
+--S 4975 of 5341
+r0:=atan(log(c*x^n)*sqrt(b)/sqrt(a))/(n*sqrt(a)*sqrt(b))
+--R 
+--R
+--R              +-+       n
+--R             \|b log(c x )
+--R        atan(-------------)
+--R                   +-+
+--R                  \|a
+--R   (2)  -------------------
+--R               +-+ +-+
+--R             n\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 4975
+
+--S 4976 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R       log
+--R                  2      2                               2      +-----+
+--R              (b n log(x)  + 2b n log(c)log(x) + b log(c)  - a)\|- a b
+--R            + 
+--R              2a b n log(x) + 2a b log(c)
+--R         /
+--R               2      2                               2
+--R            b n log(x)  + 2b n log(c)log(x) + b log(c)  + a
+--R    /
+--R          +-----+
+--R       2n\|- a b
+--R     ,
+--R                             +---+
+--R         (n log(x) + log(c))\|a b
+--R    atan(-------------------------)
+--R                     a
+--R    -------------------------------]
+--R                  +---+
+--R                n\|a b
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4976
+
+--S 4977 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                        +-+       n
+--R           +-----+     \|b log(c x )
+--R       - 2\|- a b atan(-------------)
+--R                             +-+
+--R                            \|a
+--R     + 
+--R          +-+ +-+
+--R         \|a \|b
+--R      *
+--R         log
+--R                    2      2                               2      +-----+
+--R                (b n log(x)  + 2b n log(c)log(x) + b log(c)  - a)\|- a b
+--R              + 
+--R                2a b n log(x) + 2a b log(c)
+--R           /
+--R                 2      2                               2
+--R              b n log(x)  + 2b n log(c)log(x) + b log(c)  + a
+--R  /
+--R        +-----+ +-+ +-+
+--R     2n\|- a b \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 4977
+
+--S 4978 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4978
+
+--S 4979 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R                      +-+       n                                      +---+
+--R           +---+     \|b log(c x )     +-+ +-+     (n log(x) + log(c))\|a b
+--R        - \|a b atan(-------------) + \|a \|b atan(-------------------------)
+--R                           +-+                                 a
+--R                          \|a
+--R   (6)  ---------------------------------------------------------------------
+--R                                     +-+ +-+ +---+
+--R                                   n\|a \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 4979
+
+--S 4980 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 4980
+
+)clear all
+
+--S 4981 of 5341
+t0:=1/(a*x+b*x*log(c*x^n)^3)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                   n 3
+--R        b x log(c x )  + a x
+--R                                                    Type: Expression(Integer)
+--E 4981
+
+--S 4982 of 5341
+r0:=1/3*log(a^(1/3)+b^(1/3)*log(c*x^n))/(a^(2/3)*b^(1/3)*n)-_
+   1/6*log(a^(2/3)-a^(1/3)*b^(1/3)*log(c*x^n)+b^(2/3)*log(c*x^n)^2)/_
+   (a^(2/3)*b^(1/3)*n)-atan((a^(1/3)-2*b^(1/3)*log(c*x^n))/(a^(1/3)*_
+   sqrt(3)))/(a^(2/3)*b^(1/3)*n*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          +-+    3+-+2       n 2   3+-+3+-+       n    3+-+2
+--R       - \|3 log(\|b  log(c x )  - \|a \|b log(c x ) + \|a  )
+--R     + 
+--R                                               3+-+       n    3+-+
+--R         +-+    3+-+       n    3+-+          2\|b log(c x ) - \|a
+--R       2\|3 log(\|b log(c x ) + \|a ) + 6atan(---------------------)
+--R                                                      +-+3+-+
+--R                                                     \|3 \|a
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6n\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 4982
+
+--S 4983 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R             +-+
+--R            \|3
+--R         *
+--R            log
+--R                                                         +---+2
+--R                   2      2                           2 3| 2
+--R                 (n log(x)  + 2n log(c)log(x) + log(c) )\|a b
+--R               + 
+--R                                           +---+
+--R                                          3| 2      2
+--R                 (- a n log(x) - a log(c))\|a b  + a
+--R     + 
+--R                                    +---+
+--R         +-+                       3| 2
+--R       2\|3 log((n log(x) + log(c))\|a b  + a)
+--R     + 
+--R                                          +---+
+--R                 +-+           +-+       3| 2       +-+
+--R             (2n\|3 log(x) + 2\|3 log(c))\|a b  - a\|3
+--R       6atan(------------------------------------------)
+--R                                 3a
+--R  /
+--R            +---+
+--R        +-+3| 2
+--R     6n\|3 \|a b
+--R                                         Type: Union(Expression(Integer),...)
+--E 4983
+
+--S 4984 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            +---+
+--R        +-+3| 2      3+-+2       n 2   3+-+3+-+       n    3+-+2
+--R       \|3 \|a b log(\|b  log(c x )  - \|a \|b log(c x ) + \|a  )
+--R     + 
+--R               +---+
+--R           +-+3| 2      3+-+       n    3+-+
+--R       - 2\|3 \|a b log(\|b log(c x ) + \|a )
+--R     + 
+--R           +---+      3+-+       n    3+-+
+--R          3| 2       2\|b log(c x ) - \|a
+--R       - 6\|a b atan(---------------------)
+--R                             +-+3+-+
+--R                            \|3 \|a
+--R     + 
+--R       -
+--R             +-+3+-+2 3+-+
+--R            \|3 \|a   \|b
+--R         *
+--R            log
+--R                                                         +---+2
+--R                   2      2                           2 3| 2
+--R                 (n log(x)  + 2n log(c)log(x) + log(c) )\|a b
+--R               + 
+--R                                           +---+
+--R                                          3| 2      2
+--R                 (- a n log(x) - a log(c))\|a b  + a
+--R     + 
+--R                                              +---+
+--R         +-+3+-+2 3+-+                       3| 2
+--R       2\|3 \|a   \|b log((n log(x) + log(c))\|a b  + a)
+--R     + 
+--R                                                    +---+
+--R                           +-+           +-+       3| 2       +-+
+--R        3+-+2 3+-+     (2n\|3 log(x) + 2\|3 log(c))\|a b  - a\|3
+--R       6\|a   \|b atan(------------------------------------------)
+--R                                           3a
+--R  /
+--R                      +---+
+--R        +-+3+-+2 3+-+3| 2
+--R     6n\|3 \|a   \|b \|a b
+--R                                                    Type: Expression(Integer)
+--E 4984
+
+--S 4985 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4985
+
+)clear all
+
+--S 4986 of 5341
+t0:=1/(a*x+b*x*log(c*x^n)^4)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                   n 4
+--R        b x log(c x )  + a x
+--R                                                    Type: Expression(Integer)
+--E 4986
+
+--S 4987 of 5341
+r0:=-1/2*atan(1-b^(1/4)*log(c*x^n)*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*n*_
+   sqrt(2))+1/2*atan(1+b^(1/4)*log(c*x^n)*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*_
+   n*sqrt(2))-1/4*log(-a^(1/4)*b^(1/4)*log(c*x^n)*sqrt(2)+sqrt(a)+_
+   log(c*x^n)^2*sqrt(b))/(a^(3/4)*b^(1/4)*n*sqrt(2))+1/4*log(a^(1/4)*_
+   b^(1/4)*log(c*x^n)*sqrt(2)+sqrt(a)+log(c*x^n)^2*sqrt(b))/(a^(3/4)*_
+   b^(1/4)*n*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            +-+       n 2    +-+4+-+4+-+       n     +-+
+--R       log(\|b log(c x )  + \|2 \|a \|b log(c x ) + \|a )
+--R     + 
+--R              +-+       n 2    +-+4+-+4+-+       n     +-+
+--R       - log(\|b log(c x )  - \|2 \|a \|b log(c x ) + \|a )
+--R     + 
+--R              +-+4+-+       n    4+-+           +-+4+-+       n    4+-+
+--R             \|2 \|b log(c x ) + \|a           \|2 \|b log(c x ) - \|a
+--R       2atan(------------------------) + 2atan(------------------------)
+--R                       4+-+                              4+-+
+--R                       \|a                               \|a
+--R  /
+--R        +-+4+-+3 4+-+
+--R     4n\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 4987
+
+--S 4988 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R      +-----------+          +-----------+
+--R      |      1               |      1
+--R      |- --------- log(4a n  |- --------- + n log(x) + log(c))
+--R     4|      3   4          4|      3   4
+--R     \|  256a b n           \|  256a b n
+--R   + 
+--R        +-----------+            +-----------+
+--R        |      1                 |      1
+--R     -  |- --------- log(- 4a n  |- --------- + n log(x) + log(c))
+--R       4|      3   4            4|      3   4
+--R       \|  256a b n             \|  256a b n
+--R   + 
+--R                                  +-----------+
+--R                                  |      1
+--R                            4a n  |- ---------
+--R          +-----------+          4|      3   4
+--R          |      1               \|  256a b n
+--R     - 2  |- --------- atan(------------------)
+--R         4|      3   4       n log(x) + log(c)
+--R         \|  256a b n
+--R                                         Type: Union(Expression(Integer),...)
+--E 4988
+
+--S 4989 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R              +-+       n 2    +-+4+-+4+-+       n     +-+
+--R       - log(\|b log(c x )  + \|2 \|a \|b log(c x ) + \|a )
+--R     + 
+--R            +-+       n 2    +-+4+-+4+-+       n     +-+
+--R       log(\|b log(c x )  - \|2 \|a \|b log(c x ) + \|a )
+--R     + 
+--R                +-+4+-+       n    4+-+           +-+4+-+       n    4+-+
+--R               \|2 \|b log(c x ) + \|a           \|2 \|b log(c x ) - \|a
+--R       - 2atan(------------------------) - 2atan(------------------------)
+--R                         4+-+                              4+-+
+--R                         \|a                               \|a
+--R     + 
+--R               +-----------+                    +-----------+
+--R          +-+  |      1     4+-+3 4+-+          |      1
+--R       4n\|2   |- --------- \|a   \|b log(4a n  |- --------- + n log(x) + log(c))
+--R              4|      3   4                    4|      3   4
+--R              \|  256a b n                     \|  256a b n
+--R     + 
+--R       -
+--R                    +-----------+
+--R               +-+  |      1     4+-+3 4+-+
+--R            4n\|2   |- --------- \|a   \|b
+--R                   4|      3   4
+--R                   \|  256a b n
+--R         *
+--R                        +-----------+
+--R                        |      1
+--R            log(- 4a n  |- --------- + n log(x) + log(c))
+--R                       4|      3   4
+--R                       \|  256a b n
+--R     + 
+--R                                                   +-----------+
+--R                                                   |      1
+--R                                             4a n  |- ---------
+--R                 +-----------+                    4|      3   4
+--R            +-+  |      1     4+-+3 4+-+          \|  256a b n
+--R       - 8n\|2   |- --------- \|a   \|b atan(------------------)
+--R                4|      3   4                 n log(x) + log(c)
+--R                \|  256a b n
+--R  /
+--R        +-+4+-+3 4+-+
+--R     4n\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 4989
+
+--S 4990 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4990
+
+)clear all
+
+--S 4991 of 5341
+t0:=1/(a*x+b*x/log(c*x^n))
+--R 
+--R
+--R                    n
+--R             log(c x )
+--R   (1)  -------------------
+--R                   n
+--R        a x log(c x ) + b x
+--R                                                    Type: Expression(Integer)
+--E 4991
+
+--S 4992 of 5341
+r0:=log(x)/a-b*log(b+a*log(c*x^n))/(a^2*n)
+--R 
+--R
+--R                         n
+--R        - b log(a log(c x ) + b) + a n log(x)
+--R   (2)  -------------------------------------
+--R                          2
+--R                         a n
+--R                                                    Type: Expression(Integer)
+--E 4992
+
+--S 4993 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - b log(a n log(x) + a log(c) + b) + a n log(x)
+--R   (3)  -----------------------------------------------
+--R                               2
+--R                              a n
+--R                                         Type: Union(Expression(Integer),...)
+--E 4993
+
+--S 4994 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                       n
+--R        b log(a log(c x ) + b) - b log(a n log(x) + a log(c) + b)
+--R   (4)  ---------------------------------------------------------
+--R                                    2
+--R                                   a n
+--R                                                    Type: Expression(Integer)
+--E 4994
+
+--S 4995 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 4995
+
+)clear all
+
+--S 4996 of 5341
+t0:=1/(a*x+b*x/log(c*x^n)^2)
+--R 
+--R
+--R                    n 2
+--R             log(c x )
+--R   (1)  --------------------
+--R                   n 2
+--R        a x log(c x )  + b x
+--R                                                    Type: Expression(Integer)
+--E 4996
+
+--S 4997 of 5341
+r0:=log(x)/a-atan(log(c*x^n)*sqrt(a)/sqrt(b))*sqrt(b)/(a^(3/2)*n)
+--R 
+--R
+--R                    +-+       n
+--R           +-+     \|a log(c x )             +-+
+--R        - \|b atan(-------------) + n log(x)\|a
+--R                         +-+
+--R                        \|b
+--R   (2)  ----------------------------------------
+--R                             +-+
+--R                         a n\|a
+--R                                                    Type: Expression(Integer)
+--E 4997
+
+--S 4998 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R   [
+--R            +---+
+--R            |  b
+--R            |- -
+--R           \|  a
+--R        *
+--R           log
+--R                                              +---+
+--R                                              |  b       2      2
+--R                  (- 2a n log(x) - 2a log(c)) |- -  + a n log(x)
+--R                                             \|  a
+--R                + 
+--R                                              2
+--R                  2a n log(c)log(x) + a log(c)  - b
+--R             /
+--R                   2      2                               2
+--R                a n log(x)  + 2a n log(c)log(x) + a log(c)  + b
+--R       + 
+--R         2n log(x)
+--R    /
+--R       2a n
+--R     ,
+--R                     +-+
+--R                     |b
+--R     +-+             |-
+--R     |b             \|a
+--R     |- atan(-----------------) + n log(x)
+--R    \|a      n log(x) + log(c)
+--R    --------------------------------------]
+--R                      a n
+--R                                   Type: Union(List(Expression(Integer)),...)
+--E 4998
+
+--S 4999 of 5341
+m0a:=a0.1-r0
+--R 
+--R
+--R   (4)
+--R                  +-+       n
+--R         +-+     \|a log(c x )
+--R       2\|b atan(-------------)
+--R                       +-+
+--R                      \|b
+--R     + 
+--R          +---+
+--R          |  b  +-+
+--R          |- - \|a
+--R         \|  a
+--R      *
+--R         log
+--R                                            +---+
+--R                                            |  b       2      2
+--R                (- 2a n log(x) - 2a log(c)) |- -  + a n log(x)
+--R                                           \|  a
+--R              + 
+--R                                            2
+--R                2a n log(c)log(x) + a log(c)  - b
+--R           /
+--R                 2      2                               2
+--R              a n log(x)  + 2a n log(c)log(x) + a log(c)  + b
+--R  /
+--R          +-+
+--R     2a n\|a
+--R                                                    Type: Expression(Integer)
+--E 4999
+
+--S 5000 of 5341
+d0a:=normalize(D(m0a,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5000
+
+--S 5001 of 5341
+m0b:=a0.2-r0
+--R 
+--R
+--R                                                       +-+
+--R                                                       |b
+--R                  +-+       n          +-+             |-
+--R         +-+     \|a log(c x )     +-+ |b             \|a
+--R        \|b atan(-------------) + \|a  |- atan(-----------------)
+--R                       +-+            \|a      n log(x) + log(c)
+--R                      \|b
+--R   (6)  ---------------------------------------------------------
+--R                                     +-+
+--R                                 a n\|a
+--R                                                    Type: Expression(Integer)
+--E 5001
+
+--S 5002 of 5341
+d0b:=normalize(D(m0b,x))
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Expression(Integer)
+--E 5002
+
+)clear all
+
+--S 5003 of 5341
+t0:=1/(a*x+b*x/log(c*x^n)^3)
+--R 
+--R
+--R                    n 3
+--R             log(c x )
+--R   (1)  --------------------
+--R                   n 3
+--R        a x log(c x )  + b x
+--R                                                    Type: Expression(Integer)
+--E 5003
+
+--S 5004 of 5341
+r0:=log(x)/a-1/3*b^(1/3)*log(b^(1/3)+a^(1/3)*log(c*x^n))/(a^(4/3)*n)+_
+   1/6*b^(1/3)*log(b^(2/3)-a^(1/3)*b^(1/3)*log(c*x^n)+a^(2/3)*_
+   log(c*x^n)^2)/(a^(4/3)*n)+b^(1/3)*atan((b^(1/3)-2*a^(1/3)*log(c*x^n))/_
+   (b^(1/3)*sqrt(3)))/(a^(4/3)*n*sqrt(3))
+--R 
+--R
+--R   (2)
+--R        +-+3+-+    3+-+2       n 2   3+-+3+-+       n    3+-+2
+--R       \|3 \|b log(\|a  log(c x )  - \|a \|b log(c x ) + \|b  )
+--R     + 
+--R                                                         3+-+       n    3+-+
+--R           +-+3+-+    3+-+       n    3+-+     3+-+     2\|a log(c x ) - \|b
+--R       - 2\|3 \|b log(\|a log(c x ) + \|b ) - 6\|b atan(---------------------)
+--R                                                                +-+3+-+
+--R                                                               \|3 \|b
+--R     + 
+--R          +-+      3+-+
+--R       6n\|3 log(x)\|a
+--R  /
+--R          +-+3+-+
+--R     6a n\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 5004
+
+--S 5005 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R       -
+--R                  +---+
+--R             +-+  |  b
+--R            \|3  3|- -
+--R                 \|  a
+--R         *
+--R            log
+--R                  +---+2                        +---+
+--R                  |  b                          |  b    2      2
+--R                 3|- -   + (n log(x) + log(c)) 3|- - + n log(x)
+--R                 \|  a                         \|  a
+--R               + 
+--R                                         2
+--R                 2n log(c)log(x) + log(c)
+--R     + 
+--R              +---+       +---+
+--R         +-+  |  b        |  b
+--R       2\|3  3|- - log(- 3|- -  + n log(x) + log(c))
+--R             \|  a       \|  a
+--R     + 
+--R                            +---+
+--R                       +-+  |  b      +-+           +-+
+--R            +---+     \|3  3|- - + 2n\|3 log(x) + 2\|3 log(c)
+--R            |  b           \|  a                                   +-+
+--R       - 6 3|- - atan(--------------------------------------- + 6n\|3 log(x)
+--R           \|  a                         +---+
+--R                                         |  b
+--R                                      3 3|- -
+--R                                        \|  a
+--R  /
+--R          +-+
+--R     6a n\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 5005
+
+--S 5006 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +-+3+-+    3+-+2       n 2   3+-+3+-+       n    3+-+2
+--R       - \|3 \|b log(\|a  log(c x )  - \|a \|b log(c x ) + \|b  )
+--R     + 
+--R                                                       3+-+       n    3+-+
+--R         +-+3+-+    3+-+       n    3+-+     3+-+     2\|a log(c x ) - \|b
+--R       2\|3 \|b log(\|a log(c x ) + \|b ) + 6\|b atan(---------------------)
+--R                                                              +-+3+-+
+--R                                                             \|3 \|b
+--R     + 
+--R       -
+--R                  +---+
+--R             +-+  |  b 3+-+
+--R            \|3  3|- - \|a
+--R                 \|  a
+--R         *
+--R            log
+--R                  +---+2                        +---+
+--R                  |  b                          |  b    2      2
+--R                 3|- -   + (n log(x) + log(c)) 3|- - + n log(x)
+--R                 \|  a                         \|  a
+--R               + 
+--R                                         2
+--R                 2n log(c)log(x) + log(c)
+--R     + 
+--R              +---+           +---+
+--R         +-+  |  b 3+-+       |  b
+--R       2\|3  3|- - \|a log(- 3|- -  + n log(x) + log(c))
+--R             \|  a           \|  a
+--R     + 
+--R                                +---+
+--R                           +-+  |  b      +-+           +-+
+--R            +---+         \|3  3|- - + 2n\|3 log(x) + 2\|3 log(c)
+--R            |  b 3+-+          \|  a
+--R       - 6 3|- - \|a atan(---------------------------------------)
+--R           \|  a                             +---+
+--R                                             |  b
+--R                                          3 3|- -
+--R                                            \|  a
+--R  /
+--R          +-+3+-+
+--R     6a n\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 5006
+
+--S 5007 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5007
+
+)clear all
+
+--S 5008 of 5341
+t0:=1/(a*x+b*x/log(c*x^n)^4)
+--R 
+--R
+--R                    n 4
+--R             log(c x )
+--R   (1)  --------------------
+--R                   n 4
+--R        a x log(c x )  + b x
+--R                                                    Type: Expression(Integer)
+--E 5008
+
+--S 5009 of 5341
+r0:=log(x)/a+1/2*b^(1/4)*atan(1-a^(1/4)*log(c*x^n)*sqrt(2)/b^(1/4))/_
+   (a^(5/4)*n*sqrt(2))-1/2*b^(1/4)*atan(1+a^(1/4)*log(c*x^n)*sqrt(2)/_
+   b^(1/4))/(a^(5/4)*n*sqrt(2))+1/4*b^(1/4)*log(-a^(1/4)*b^(1/4)*log(c*x^n)*_
+   sqrt(2)+log(c*x^n)^2*sqrt(a)+sqrt(b))/(a^(5/4)*n*sqrt(2))-1/4*b^(1/4)*_
+   log(a^(1/4)*b^(1/4)*log(c*x^n)*sqrt(2)+log(c*x^n)^2*sqrt(a)+sqrt(b))/_
+   (a^(5/4)*n*sqrt(2))
+--R 
+--R
+--R   (2)
+--R         4+-+     +-+       n 2    +-+4+-+4+-+       n     +-+
+--R       - \|b log(\|a log(c x )  + \|2 \|a \|b log(c x ) + \|b )
+--R     + 
+--R       4+-+     +-+       n 2    +-+4+-+4+-+       n     +-+
+--R       \|b log(\|a log(c x )  - \|2 \|a \|b log(c x ) + \|b )
+--R     + 
+--R                    +-+4+-+       n    4+-+
+--R          4+-+     \|2 \|a log(c x ) + \|b
+--R       - 2\|b atan(------------------------)
+--R                             4+-+
+--R                             \|b
+--R     + 
+--R                    +-+4+-+       n    4+-+
+--R          4+-+     \|2 \|a log(c x ) - \|b        +-+      4+-+
+--R       - 2\|b atan(------------------------) + 4n\|2 log(x)\|a
+--R                             4+-+
+--R                             \|b
+--R  /
+--R          +-+4+-+
+--R     4a n\|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 5009
+
+--S 5010 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R            +---------+          +---------+
+--R            |     b              |     b
+--R       - a  |- ------- log(4a n  |- ------- + n log(x) + log(c))
+--R           4|      5 4          4|      5 4
+--R           \|  256a n           \|  256a n
+--R     + 
+--R          +---------+            +---------+
+--R          |     b                |     b
+--R       a  |- ------- log(- 4a n  |- ------- + n log(x) + log(c))
+--R         4|      5 4            4|      5 4
+--R         \|  256a n             \|  256a n
+--R     + 
+--R                                  +---------+
+--R                                  |     b
+--R                            4a n  |- -------
+--R           +---------+           4|      5 4
+--R           |     b               \|  256a n
+--R       2a  |- ------- atan(----------------- + log(x)
+--R          4|      5 4      n log(x) + log(c)
+--R          \|  256a n
+--R  /
+--R     a
+--R                                         Type: Union(Expression(Integer),...)
+--E 5010
+
+--S 5011 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R       4+-+     +-+       n 2    +-+4+-+4+-+       n     +-+
+--R       \|b log(\|a log(c x )  + \|2 \|a \|b log(c x ) + \|b )
+--R     + 
+--R         4+-+     +-+       n 2    +-+4+-+4+-+       n     +-+
+--R       - \|b log(\|a log(c x )  - \|2 \|a \|b log(c x ) + \|b )
+--R     + 
+--R                  +-+4+-+       n    4+-+               +-+4+-+       n    4+-+
+--R        4+-+     \|2 \|a log(c x ) + \|b      4+-+     \|2 \|a log(c x ) - \|b
+--R       2\|b atan(------------------------) + 2\|b atan(------------------------)
+--R                           4+-+                                  4+-+
+--R                           \|b                                   \|b
+--R     + 
+--R                   +---------+              +---------+
+--R              +-+  |     b    4+-+          |     b
+--R       - 4a n\|2   |- ------- \|a log(4a n  |- ------- + n log(x) + log(c))
+--R                  4|      5 4              4|      5 4
+--R                  \|  256a n               \|  256a n
+--R     + 
+--R                 +---------+                +---------+
+--R            +-+  |     b    4+-+            |     b
+--R       4a n\|2   |- ------- \|a log(- 4a n  |- ------- + n log(x) + log(c))
+--R                4|      5 4                4|      5 4
+--R                \|  256a n                 \|  256a n
+--R     + 
+--R                                            +---------+
+--R                                            |     b
+--R                                      4a n  |- -------
+--R                 +---------+               4|      5 4
+--R            +-+  |     b    4+-+           \|  256a n
+--R       8a n\|2   |- ------- \|a atan(-----------------)
+--R                4|      5 4          n log(x) + log(c)
+--R                \|  256a n
+--R  /
+--R          +-+4+-+
+--R     4a n\|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 5011
+
+--S 5012 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5012
+
+)clear all
+
+--S 5013 of 5341
+t0:=log(x)/(x+4*x*log(x)^2)
+--R 
+--R
+--R            log(x)
+--R   (1)  --------------
+--R                 2
+--R        4x log(x)  + x
+--R                                                    Type: Expression(Integer)
+--E 5013
+
+--S 5014 of 5341
+r0:=1/8*log(1+4*log(x)^2)
+--R 
+--R
+--R                   2
+--R        log(4log(x)  + 1)
+--R   (2)  -----------------
+--R                8
+--R                                                    Type: Expression(Integer)
+--E 5014
+
+--S 5015 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                   2
+--R        log(4log(x)  + 1)
+--R   (3)  -----------------
+--R                8
+--R                                         Type: Union(Expression(Integer),...)
+--E 5015
+
+--S 5016 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5016
+
+--S 5017 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5017
+
+)clear all
+
+--S 5018 of 5341
+t0:=1/(x+x*log(7*x)+x*log(7*x)^2)
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                 2
+--R        x log(7x)  + x log(7x) + x
+--R                                                    Type: Expression(Integer)
+--E 5018
+
+--S 5019 of 5341
+r0:=2*atan((1+2*log(7*x))/sqrt(3))/sqrt(3)
+--R 
+--R
+--R              2log(7x) + 1
+--R        2atan(------------)
+--R                   +-+
+--R                  \|3
+--R   (2)  -------------------
+--R                 +-+
+--R                \|3
+--R                                                    Type: Expression(Integer)
+--E 5019
+
+--S 5020 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                +-+           +-+
+--R              2\|3 log(7x) + \|3
+--R        2atan(-------------------)
+--R                       3
+--R   (3)  --------------------------
+--R                    +-+
+--R                   \|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 5020
+
+--S 5021 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                +-+           +-+
+--R              2\|3 log(7x) + \|3           2log(7x) + 1
+--R        2atan(-------------------) - 2atan(------------)
+--R                       3                        +-+
+--R                                               \|3
+--R   (4)  ------------------------------------------------
+--R                               +-+
+--R                              \|3
+--R                                                    Type: Expression(Integer)
+--E 5021
+
+--S 5022 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5022
+
+)clear all
+
+--S 5023 of 5341
+t0:=(-1+log(3*x))/(x*(1-log(3*x)+log(3*x)^2))
+--R 
+--R
+--R                log(3x) - 1
+--R   (1)  --------------------------
+--R                 2
+--R        x log(3x)  - x log(3x) + x
+--R                                                    Type: Expression(Integer)
+--E 5023
+
+--S 5024 of 5341
+r0:=1/2*log(1-log(3*x)+log(3*x)^2)+atan((1-2*log(3*x))/sqrt(3))/sqrt(3)
+--R 
+--R
+--R         +-+           2                        2log(3x) - 1
+--R        \|3 log(log(3x)  - log(3x) + 1) - 2atan(------------)
+--R                                                     +-+
+--R                                                    \|3
+--R   (2)  -----------------------------------------------------
+--R                                  +-+
+--R                                2\|3
+--R                                                    Type: Expression(Integer)
+--E 5024
+
+--S 5025 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                  +-+           +-+
+--R         +-+           2                        2\|3 log(3x) - \|3
+--R        \|3 log(log(3x)  - log(3x) + 1) - 2atan(-------------------)
+--R                                                         3
+--R   (3)  ------------------------------------------------------------
+--R                                      +-+
+--R                                    2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 5025
+
+--S 5026 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                 +-+           +-+
+--R               2\|3 log(3x) - \|3          2log(3x) - 1
+--R        - atan(-------------------) + atan(------------)
+--R                        3                       +-+
+--R                                               \|3
+--R   (4)  ------------------------------------------------
+--R                               +-+
+--R                              \|3
+--R                                                    Type: Expression(Integer)
+--E 5026
+
+--S 5027 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5027
+
+)clear all
+
+--S 5028 of 5341
+t0:=(-1+log(3*x)^2)/(x+x*log(3*x)^3)
+--R 
+--R
+--R                log(3x) - 1
+--R   (1)  --------------------------
+--R                 2
+--R        x log(3x)  - x log(3x) + x
+--R                                                    Type: Expression(Integer)
+--E 5028
+
+--S 5029 of 5341
+r0:=1/2*log(1-log(3*x)+log(3*x)^2)+atan((1-2*log(3*x))/sqrt(3))/sqrt(3)
+--R 
+--R
+--R         +-+           2                        2log(3x) - 1
+--R        \|3 log(log(3x)  - log(3x) + 1) - 2atan(------------)
+--R                                                     +-+
+--R                                                    \|3
+--R   (2)  -----------------------------------------------------
+--R                                  +-+
+--R                                2\|3
+--R                                                    Type: Expression(Integer)
+--E 5029
+
+--S 5030 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                                  +-+           +-+
+--R         +-+           2                        2\|3 log(3x) - \|3
+--R        \|3 log(log(3x)  - log(3x) + 1) - 2atan(-------------------)
+--R                                                         3
+--R   (3)  ------------------------------------------------------------
+--R                                      +-+
+--R                                    2\|3
+--R                                         Type: Union(Expression(Integer),...)
+--E 5030
+
+--S 5031 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                 +-+           +-+
+--R               2\|3 log(3x) - \|3          2log(3x) - 1
+--R        - atan(-------------------) + atan(------------)
+--R                        3                       +-+
+--R                                               \|3
+--R   (4)  ------------------------------------------------
+--R                               +-+
+--R                              \|3
+--R                                                    Type: Expression(Integer)
+--E 5031
+
+--S 5032 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5032
+
+)clear all
+
+--S 5033 of 5341
+t0:=(-1+log(3*x)^2)/(x+x*log(3*x)+x*log(3*x)^2)
+--R 
+--R
+--R                      2
+--R               log(3x)  - 1
+--R   (1)  --------------------------
+--R                 2
+--R        x log(3x)  + x log(3x) + x
+--R                                                    Type: Expression(Integer)
+--E 5033
+
+--S 5034 of 5341
+r0:=log(x)-1/2*log(1+log(3*x)+log(3*x)^2)-atan((1+2*log(3*x))/sqrt(3))*sqrt(3)
+--R 
+--R
+--R                     2                    +-+     2log(3x) + 1
+--R        - log(log(3x)  + log(3x) + 1) - 2\|3 atan(------------) + 2log(x)
+--R                                                       +-+
+--R                                                      \|3
+--R   (2)  -----------------------------------------------------------------
+--R                                        2
+--R                                                    Type: Expression(Integer)
+--E 5034
+
+--S 5035 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                     2                    +-+     2log(x) + 1
+--R        - log(log(3x)  + log(3x) + 1) - 2\|3 atan(-----------) + 2log(x)
+--R                                                       +-+
+--R                                                      \|3
+--R   (3)  ----------------------------------------------------------------
+--R                                        2
+--R                                         Type: Union(Expression(Integer),...)
+--E 5035
+
+--S 5036 of 5341
+m0:=a0-r0
+--R 
+--R
+--R         +-+     2log(3x) + 1     +-+     2log(x) + 1
+--R   (4)  \|3 atan(------------) - \|3 atan(-----------)
+--R                      +-+                      +-+
+--R                     \|3                      \|3
+--R                                                    Type: Expression(Integer)
+--E 5036
+
+--S 5037 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                              2
+--R     - 6log(3)log(x) - 3log(3)  - 3log(3)
+--R  /
+--R                4                         3
+--R       2x log(x)  + (4x log(3) + 4x)log(x)
+--R     + 
+--R                 2                        2
+--R       (2x log(3)  + 6x log(3) + 6x)log(x)
+--R     + 
+--R                 2                                    2
+--R       (2x log(3)  + 6x log(3) + 4x)log(x) + 2x log(3)  + 2x log(3) + 2x
+--R                                                    Type: Expression(Integer)
+--E 5037
+
+)clear all
+
+--S 5038 of 5341
+t0:=1/(x*(3+log(x)))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R        x log(x) + 3x
+--R                                                    Type: Expression(Integer)
+--E 5038
+
+--S 5039 of 5341
+r0:=log(3+log(x))
+--R 
+--R
+--R   (2)  log(log(x) + 3)
+--R                                                    Type: Expression(Integer)
+--E 5039
+
+--S 5040 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  log(log(x) + 3)
+--R                                         Type: Union(Expression(Integer),...)
+--E 5040
+
+--S 5041 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5041
+
+--S 5042 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5042
+
+)clear all
+
+--S 5043 of 5341
+t0:=sqrt(1+log(x))/x
+--R 
+--R
+--R         +----------+
+--R        \|log(x) + 1
+--R   (1)  -------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 5043
+
+--S 5044 of 5341
+r0:=2/3*(1+log(x))^(3/2)
+--R 
+--R
+--R                      +----------+
+--R        (2log(x) + 2)\|log(x) + 1
+--R   (2)  --------------------------
+--R                     3
+--R                                                    Type: Expression(Integer)
+--E 5044
+
+--S 5045 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +----------+
+--R        (2log(x) + 2)\|log(x) + 1
+--R   (3)  --------------------------
+--R                     3
+--R                                         Type: Union(Expression(Integer),...)
+--E 5045
+
+--S 5046 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5046
+
+--S 5047 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5047
+
+)clear all
+
+--S 5048 of 5341
+t0:=(1+log(x))^5/x
+--R 
+--R
+--R              5          4           3           2
+--R        log(x)  + 5log(x)  + 10log(x)  + 10log(x)  + 5log(x) + 1
+--R   (1)  --------------------------------------------------------
+--R                                    x
+--R                                                    Type: Expression(Integer)
+--E 5048
+
+--S 5049 of 5341
+r0:=1/6*(1+log(x))^6
+--R 
+--R
+--R              6          5           4           3           2
+--R        log(x)  + 6log(x)  + 15log(x)  + 20log(x)  + 15log(x)  + 6log(x) + 1
+--R   (2)  --------------------------------------------------------------------
+--R                                          6
+--R                                                    Type: Expression(Integer)
+--E 5049
+
+--S 5050 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R              6          5           4           3           2
+--R        log(x)  + 6log(x)  + 15log(x)  + 20log(x)  + 15log(x)  + 6log(x)
+--R   (3)  ----------------------------------------------------------------
+--R                                        6
+--R                                         Type: Union(Expression(Integer),...)
+--E 5050
+
+--S 5051 of 5341
+m0:=a0-r0
+--R 
+--R
+--R          1
+--R   (4)  - -
+--R          6
+--R                                                    Type: Expression(Integer)
+--E 5051
+
+--S 5052 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5052
+
+)clear all
+
+--S 5053 of 5341
+t0:=1/(x*sqrt(log(x)))
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R          +------+
+--R        x\|log(x)
+--R                                                    Type: Expression(Integer)
+--E 5053
+
+--S 5054 of 5341
+r0:=2*sqrt(log(x))
+--R 
+--R
+--R          +------+
+--R   (2)  2\|log(x)
+--R                                                    Type: Expression(Integer)
+--E 5054
+
+--S 5055 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          +------+
+--R   (3)  2\|log(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 5055
+
+--S 5056 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5056
+
+--S 5057 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5057
+
+)clear all
+
+--S 5058 of 5341
+t0:=1/(x*(1+log(x)^2))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R                2
+--R        x log(x)  + x
+--R                                                    Type: Expression(Integer)
+--E 5058
+
+--S 5059 of 5341
+r0:=atan(log(x))
+--R 
+--R
+--R   (2)  atan(log(x))
+--R                                                    Type: Expression(Integer)
+--E 5059
+
+--S 5060 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  atan(log(x))
+--R                                         Type: Union(Expression(Integer),...)
+--E 5060
+
+--S 5061 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5061
+
+--S 5062 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5062
+
+)clear all
+
+--S 5063 of 5341
+t0:=1/(x*sqrt(-3+log(x)^2))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          +-----------+
+--R          |      2
+--R        x\|log(x)  - 3
+--R                                                    Type: Expression(Integer)
+--E 5063
+
+--S 5064 of 5341
+r0:=atanh(log(x)/sqrt(-3+log(x)^2))
+--R 
+--R
+--R                  log(x)
+--R   (2)  atanh(--------------)
+--R               +-----------+
+--R               |      2
+--R              \|log(x)  - 3
+--R                                                    Type: Expression(Integer)
+--E 5064
+
+--S 5065 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-----------+
+--R               |      2
+--R   (3)  - log(\|log(x)  - 3  - log(x))
+--R                                         Type: Union(Expression(Integer),...)
+--E 5065
+
+--S 5066 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               +-----------+
+--R               |      2                            log(x)
+--R   (4)  - log(\|log(x)  - 3  - log(x)) - atanh(--------------)
+--R                                                +-----------+
+--R                                                |      2
+--R                                               \|log(x)  - 3
+--R                                                    Type: Expression(Integer)
+--E 5066
+
+--S 5067 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5067
+
+)clear all
+
+--S 5068 of 5341
+t0:=1/(x*sqrt(4-9*log(x)^2))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R          +--------------+
+--R          |         2
+--R        x\|- 9log(x)  + 4
+--R                                                    Type: Expression(Integer)
+--E 5068
+
+--S 5069 of 5341
+r0:=1/3*asin(3/2*log(x))
+--R 
+--R
+--R             3log(x)
+--R        asin(-------)
+--R                2
+--R   (2)  -------------
+--R              3
+--R                                                    Type: Expression(Integer)
+--E 5069
+
+--S 5070 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 +--------------+
+--R                 |         2
+--R                \|- 9log(x)  + 4  - 2
+--R          2atan(---------------------)
+--R                       3log(x)
+--R   (3)  - ----------------------------
+--R                        3
+--R                                         Type: Union(Expression(Integer),...)
+--E 5070
+
+--S 5071 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                 +--------------+
+--R                 |         2
+--R                \|- 9log(x)  + 4  - 2         3log(x)
+--R        - 2atan(---------------------) - asin(-------)
+--R                       3log(x)                   2
+--R   (4)  ----------------------------------------------
+--R                               3
+--R                                                    Type: Expression(Integer)
+--E 5071
+
+--S 5072 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5072
+
+)clear all
+
+--S 5073 of 5341
+t0:=1/(x*sqrt(4+log(x)^2))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          +-----------+
+--R          |      2
+--R        x\|log(x)  + 4
+--R                                                    Type: Expression(Integer)
+--E 5073
+
+--S 5074 of 5341
+r0:=asinh(1/2*log(x))
+--R 
+--R
+--R              log(x)
+--R   (2)  asinh(------)
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 5074
+
+--S 5075 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-----------+
+--R               |      2
+--R   (3)  - log(\|log(x)  + 4  - log(x))
+--R                                         Type: Union(Expression(Integer),...)
+--E 5075
+
+--S 5076 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               +-----------+
+--R               |      2                        log(x)
+--R   (4)  - log(\|log(x)  + 4  - log(x)) - asinh(------)
+--R                                                  2
+--R                                                    Type: Expression(Integer)
+--E 5076
+
+--S 5077 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5077
+
+)clear all
+
+--S 5078 of 5341
+t0:=1/(x*(2+3*log(6*x)^3))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R                  3
+--R        3x log(6x)  + 2x
+--R                                                    Type: Expression(Integer)
+--E 5078
+
+--S 5079 of 5341
+r0:=-atan(1/3*(2^(1/3)*3^(2/3)-6*log(6*x))/(2^(1/3)*3^(1/6)))/(2^(2/3)*_
+   3^(5/6))+1/3*log(2^(1/3)+3^(1/3)*log(6*x))/(2^(2/3)*3^(1/3))-_
+   1/6*log(2^(2/3)-6^(1/3)*log(6*x)+3^(2/3)*log(6*x)^2)/(2^(2/3)*3^(1/3))
+--R 
+--R
+--R   (2)
+--R         6+-+5    3+-+2       2   3+-+          3+-+2
+--R       - \|3  log(\|3  log(6x)  - \|6 log(6x) + \|2  )
+--R     + 
+--R                                                            3+-+3+-+2
+--R        6+-+5    3+-+          3+-+     3+-+     6log(6x) - \|2 \|3
+--R       2\|3  log(\|3 log(6x) + \|2 ) + 6\|3 atan(--------------------)
+--R                                                        3+-+6+-+
+--R                                                       3\|2 \|3
+--R  /
+--R      3+-+2 3+-+6+-+5
+--R     6\|2   \|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 5079
+
+--S 5080 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R          +-+    3+--+2       2    3+--+
+--R       - \|3 log(\|12  log(6x)  - 2\|12 log(6x) + 4)
+--R     + 
+--R                                           +-+3+--+           +-+
+--R         +-+    3+--+                     \|3 \|12 log(6x) - \|3
+--R       2\|3 log(\|12 log(6x) + 2) + 6atan(-----------------------)
+--R                                                     3
+--R  /
+--R       +-+3+--+
+--R     6\|3 \|12
+--R                                         Type: Union(Expression(Integer),...)
+--E 5080
+
+--S 5081 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R         3+-+2 +-+3+-+6+-+5    3+--+2       2    3+--+
+--R       - \|2  \|3 \|3 \|3  log(\|12  log(6x)  - 2\|12 log(6x) + 4)
+--R     + 
+--R        +-+6+-+5 3+--+    3+-+2       2   3+-+          3+-+2
+--R       \|3 \|3   \|12 log(\|3  log(6x)  - \|6 log(6x) + \|2  )
+--R     + 
+--R        3+-+2 +-+3+-+6+-+5    3+--+
+--R       2\|2  \|3 \|3 \|3  log(\|12 log(6x) + 2)
+--R     + 
+--R           +-+6+-+5 3+--+    3+-+          3+-+
+--R       - 2\|3 \|3   \|12 log(\|3 log(6x) + \|2 )
+--R     + 
+--R                             +-+3+--+           +-+
+--R        3+-+2 3+-+6+-+5     \|3 \|12 log(6x) - \|3
+--R       6\|2   \|3 \|3  atan(-----------------------)
+--R                                       3
+--R     + 
+--R                                       3+-+3+-+2
+--R           +-+3+-+3+--+     6log(6x) - \|2 \|3
+--R       - 6\|3 \|3 \|12 atan(--------------------)
+--R                                   3+-+6+-+
+--R                                  3\|2 \|3
+--R  /
+--R      3+-+2 +-+3+-+6+-+5 3+--+
+--R     6\|2  \|3 \|3 \|3   \|12
+--R                                                    Type: Expression(Integer)
+--E 5081
+
+--S 5082 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R         3+-+2 6+-+2 3+-+  6+-+4        3     3+-+    3+-+6+-+2        2
+--R       (3\|2   \|3   \| - 6\|3  )log(6x)  + (6\|6  - 6\|2 \|3  )log(6x)
+--R     + 
+--R           3+-+6+-+4 3+-+   3+-+2            3+-+2 6+-+2 3+-+  6+-+4
+--R       (- 2\|2 \|3   \|6 + 6\|2  )log(6x) - 2\|2   \|3   \| + 4\|3
+--R  /
+--R           3+-+6+-+2       5      3+-+6+-+4 3+-+       4      6+-+4       3
+--R       108x\|2 \|3  log(6x)  - 36x\|2 \|3   \|6 log(6x) + 72x \|3  log(6x)
+--R     + 
+--R          3+-+6+-+2       2      3+-+6+-+4 3+-+             6+-+4
+--R       72x\|2 \|3  log(6x)  - 24x\|2 \|3   \|6 log(6x + 48x \|3
+--R                                                    Type: Expression(Integer)
+--E 5082
+
+)clear all
+
+--S 5083 of 5341
+t0:=log(log(6*x))/(x*log(6*x))
+--R 
+--R
+--R        log(log(6x))
+--R   (1)  ------------
+--R          x log(6x)
+--R                                                    Type: Expression(Integer)
+--E 5083
+
+--S 5084 of 5341
+r0:=1/2*log(log(6*x))^2
+--R 
+--R
+--R                    2
+--R        log(log(6x))
+--R   (2)  -------------
+--R              2
+--R                                                    Type: Expression(Integer)
+--E 5084
+
+--S 5085 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                    2
+--R        log(log(6x))
+--R   (3)  -------------
+--R              2
+--R                                         Type: Union(Expression(Integer),...)
+--E 5085
+
+--S 5086 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5086
+
+--S 5087 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5087
+
+)clear all
+
+--S 5088 of 5341
+t0:=2^log(x)/x
+--R 
+--R
+--R         log(x)
+--R        2
+--R   (1)  -------
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 5088
+
+--S 5089 of 5341
+r0:=2^log(x)/log(2)
+--R 
+--R
+--R         log(x)
+--R        2
+--R   (2)  -------
+--R         log(2)
+--R                                                    Type: Expression(Integer)
+--E 5089
+
+--S 5090 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          log(2)log(x)
+--R        %e
+--R   (3)  --------------
+--R            log(2)
+--R                                         Type: Union(Expression(Integer),...)
+--E 5090
+
+--S 5091 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           log(x)     log(2)log(x)
+--R        - 2       + %e
+--R   (4)  --------------------------
+--R                  log(2)
+--R                                                    Type: Expression(Integer)
+--E 5091
+
+--S 5092 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5092
+
+)clear all
+
+--S 5093 of 5341
+t0:=sin(log(x))^2/x
+--R 
+--R
+--R                   2
+--R        sin(log(x))
+--R   (1)  ------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 5093
+
+--S 5094 of 5341
+r0:=1/2*log(x)-1/2*cos(log(x))*sin(log(x))
+--R 
+--R
+--R        - cos(log(x))sin(log(x)) + log(x)
+--R   (2)  ---------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 5094
+
+--S 5095 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        - cos(log(x))sin(log(x)) + log(x)
+--R   (3)  ---------------------------------
+--R                        2
+--R                                         Type: Union(Expression(Integer),...)
+--E 5095
+
+--S 5096 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5096
+
+--S 5097 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5097
+
+)clear all
+
+--S 5098 of 5341
+t0:=(7-log(x))/(x*(3+log(x)))
+--R 
+--R
+--R         - log(x) + 7
+--R   (1)  -------------
+--R        x log(x) + 3x
+--R                                                    Type: Expression(Integer)
+--E 5098
+
+--S 5099 of 5341
+r0:=-log(x)+10*log(3+log(x))
+--R 
+--R
+--R   (2)  10log(log(x) + 3) - log(x)
+--R                                                    Type: Expression(Integer)
+--E 5099
+
+--S 5100 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  10log(log(x) + 3) - log(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 5100
+
+--S 5101 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5101
+
+--S 5102 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5102
+
+)clear all
+
+--S 5103 of 5341
+t0:=(2-log(x))*(3+log(x))^2/x
+--R 
+--R
+--R                3          2
+--R        - log(x)  - 4log(x)  + 3log(x) + 18
+--R   (1)  -----------------------------------
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 5103
+
+--S 5104 of 5341
+r0:=18*log(x)+3/2*log(x)^2-4/3*log(x)^3-1/4*log(x)^4
+--R 
+--R
+--R                 4           3           2
+--R        - 3log(x)  - 16log(x)  + 18log(x)  + 216log(x)
+--R   (2)  ----------------------------------------------
+--R                              12
+--R                                                    Type: Expression(Integer)
+--E 5104
+
+--S 5105 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                 4           3           2
+--R        - 3log(x)  - 16log(x)  + 18log(x)  + 216log(x)
+--R   (3)  ----------------------------------------------
+--R                              12
+--R                                         Type: Union(Expression(Integer),...)
+--E 5105
+
+--S 5106 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5106
+
+--S 5107 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5107
+
+)clear all
+
+--S 5108 of 5341
+t0:=log(x)^2*sqrt(1+log(x)^2)/x
+--R 
+--R
+--R                +-----------+
+--R              2 |      2
+--R        log(x) \|log(x)  + 1
+--R   (1)  ---------------------
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 5108
+
+--S 5109 of 5341
+r0:=-1/8*asinh(log(x))+1/8*log(x)*sqrt(1+log(x)^2)+1/4*log(x)^3*_
+   sqrt(1+log(x)^2)
+--R 
+--R
+--R                            +-----------+
+--R                3           |      2
+--R        (2log(x)  + log(x))\|log(x)  + 1  - asinh(log(x))
+--R   (2)  -------------------------------------------------
+--R                                8
+--R                                                    Type: Expression(Integer)
+--E 5109
+
+--S 5110 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                               +-----------+
+--R                  3            |      2               4          2
+--R         ((8log(x)  + 4log(x))\|log(x)  + 1  - 8log(x)  - 8log(x)  - 1)
+--R      *
+--R              +-----------+
+--R              |      2
+--R         log(\|log(x)  + 1  - log(x))
+--R     + 
+--R                                                      +-----------+
+--R                  7           5           3           |      2                8
+--R       (- 16log(x)  - 24log(x)  - 10log(x)  - log(x))\|log(x)  + 1  + 16log(x)
+--R     + 
+--R               6           4          2
+--R       32log(x)  + 20log(x)  + 4log(x)
+--R  /
+--R                            +-----------+
+--R              3             |      2                4           2
+--R     (64log(x)  + 32log(x))\|log(x)  + 1  - 64log(x)  - 64log(x)  - 8
+--R                                         Type: Union(Expression(Integer),...)
+--E 5110
+
+--S 5111 of 5341
+m0:=a0-r0
+--R 
+--R
+--R             +-----------+
+--R             |      2
+--R        log(\|log(x)  + 1  - log(x)) + asinh(log(x))
+--R   (4)  --------------------------------------------
+--R                              8
+--R                                                    Type: Expression(Integer)
+--E 5111
+
+--S 5112 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5112
+
+)clear all
+
+--S 5113 of 5341
+t0:=(1+log(x))/(x*(3+2*log(x))^2)
+--R 
+--R
+--R                 log(x) + 1
+--R   (1)  ----------------------------
+--R                 2
+--R        4x log(x)  + 12x log(x) + 9x
+--R                                                    Type: Expression(Integer)
+--E 5113
+
+--S 5114 of 5341
+r0:=1/4/(3+2*log(x))+1/4*log(3+2*log(x))
+--R 
+--R
+--R        (2log(x) + 3)log(2log(x) + 3) + 1
+--R   (2)  ---------------------------------
+--R                   8log(x) + 12
+--R                                                    Type: Expression(Integer)
+--E 5114
+
+--S 5115 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R        (2log(x) + 3)log(2log(x) + 3) + 1
+--R   (3)  ---------------------------------
+--R                   8log(x) + 12
+--R                                         Type: Union(Expression(Integer),...)
+--E 5115
+
+--S 5116 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5116
+
+--S 5117 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5117
+
+)clear all
+
+--S 5118 of 5341
+t0:=log(x)/(x*sqrt(1+log(x)))
+--R 
+--R
+--R            log(x)
+--R   (1)  --------------
+--R          +----------+
+--R        x\|log(x) + 1
+--R                                                    Type: Expression(Integer)
+--E 5118
+
+--S 5119 of 5341
+r0:=2/3*(1+log(x))^(3/2)-2*sqrt(1+log(x))
+--R 
+--R
+--R                      +----------+
+--R        (2log(x) - 4)\|log(x) + 1
+--R   (2)  --------------------------
+--R                     3
+--R                                                    Type: Expression(Integer)
+--E 5119
+
+--S 5120 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +----------+
+--R        (2log(x) - 4)\|log(x) + 1
+--R   (3)  --------------------------
+--R                     3
+--R                                         Type: Union(Expression(Integer),...)
+--E 5120
+
+--S 5121 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5121
+
+--S 5122 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5122
+
+)clear all
+
+--S 5123 of 5341
+t0:=log(x)/(x*sqrt(-1+4*log(x)))
+--R 
+--R
+--R             log(x)
+--R   (1)  ---------------
+--R          +-----------+
+--R        x\|4log(x) - 1
+--R                                                    Type: Expression(Integer)
+--E 5123
+
+--S 5124 of 5341
+r0:=1/24*(-1+4*log(x))^(3/2)+1/8*sqrt(-1+4*log(x))
+--R 
+--R
+--R                      +-----------+
+--R        (2log(x) + 1)\|4log(x) - 1
+--R   (2)  ---------------------------
+--R                     12
+--R                                                    Type: Expression(Integer)
+--E 5124
+
+--S 5125 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      +-----------+
+--R        (2log(x) + 1)\|4log(x) - 1
+--R   (3)  ---------------------------
+--R                     12
+--R                                         Type: Union(Expression(Integer),...)
+--E 5125
+
+--S 5126 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5126
+
+--S 5127 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5127
+
+)clear all
+
+--S 5128 of 5341
+t0:=sqrt(1+log(x))/(x*log(x))
+--R 
+--R
+--R         +----------+
+--R        \|log(x) + 1
+--R   (1)  -------------
+--R           x log(x)
+--R                                                    Type: Expression(Integer)
+--E 5128
+
+--S 5129 of 5341
+r0:=-2*atanh(sqrt(1+log(x)))+2*sqrt(1+log(x))
+--R 
+--R
+--R                  +----------+      +----------+
+--R   (2)  - 2atanh(\|log(x) + 1 ) + 2\|log(x) + 1
+--R                                                    Type: Expression(Integer)
+--E 5129
+
+--S 5130 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +----------+             +----------+          +----------+
+--R   (3)  - log(\|log(x) + 1  + 1) + log(\|log(x) + 1  - 1) + 2\|log(x) + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 5130
+
+--S 5131 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R          +----------+             +----------+                +----------+
+--R   - log(\|log(x) + 1  + 1) + log(\|log(x) + 1  - 1) + 2atanh(\|log(x) + 1 )
+--R                                                    Type: Expression(Integer)
+--E 5131
+
+--S 5132 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5132
+
+)clear all
+
+--S 5133 of 5341
+t0:=(1-4*log(x)+log(x)^2)/(x*(-1+log(x))^4)
+--R 
+--R
+--R                             2
+--R                       log(x)  - 4log(x) + 1
+--R   (1)  ---------------------------------------------------
+--R                4            3            2
+--R        x log(x)  - 4x log(x)  + 6x log(x)  - 4x log(x) + x
+--R                                                    Type: Expression(Integer)
+--E 5133
+
+--S 5134 of 5341
+r0:=(-2/3)/(1-log(x))^3+1/(1-log(x))+1/(-1+log(x))^2
+--R 
+--R
+--R                      2
+--R             - 3log(x)  + 9log(x) - 4
+--R   (2)  ---------------------------------
+--R               3          2
+--R        3log(x)  - 9log(x)  + 9log(x) - 3
+--R                                                    Type: Expression(Integer)
+--E 5134
+
+--S 5135 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                      2
+--R             - 3log(x)  + 9log(x) - 4
+--R   (3)  ---------------------------------
+--R               3          2
+--R        3log(x)  - 9log(x)  + 9log(x) - 3
+--R                                         Type: Union(Expression(Integer),...)
+--E 5135
+
+--S 5136 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5136
+
+--S 5137 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5137
+
+)clear all
+
+--S 5138 of 5341
+t0:=log(1/x)^2/x^5
+--R 
+--R
+--R            1 2
+--R        log(-)
+--R            x
+--R   (1)  -------
+--R            5
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 5138
+
+--S 5139 of 5341
+r0:=(-1/32)/x^4+1/8*log(1/x)/x^4-1/4*log(1/x)^2/x^4
+--R 
+--R
+--R               1 2        1
+--R        - 8log(-)  + 4log(-) - 1
+--R               x          x
+--R   (2)  ------------------------
+--R                     4
+--R                  32x
+--R                                                    Type: Expression(Integer)
+--E 5139
+
+--S 5140 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R               1 2        1
+--R        - 8log(-)  + 4log(-) - 1
+--R               x          x
+--R   (3)  ------------------------
+--R                     4
+--R                  32x
+--R                                         Type: Union(Expression(Integer),...)
+--E 5140
+
+--S 5141 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5141
+
+--S 5142 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5142
+
+)clear all
+
+--S 5143 of 5341
+t0:=(log(a*x^n)^2)^p/x
+--R 
+--R
+--R               n 2p
+--R        log(a x )
+--R   (1)  -----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 5143
+
+--S 5144 of 5341
+r0:=log(a*x^n)*(log(a*x^n)^2)^p/(n*(1+2*p))
+--R 
+--R
+--R               n        n 2p
+--R        log(a x )log(a x )
+--R   (2)  --------------------
+--R              2n p + n
+--R                                                    Type: Expression(Integer)
+--E 5144
+
+--S 5145 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             2p log(n log(x) + log(a))
+--R        (n log(x) + log(a))%e
+--R   (3)  ----------------------------------------------
+--R                           2n p + n
+--R                                         Type: Union(Expression(Integer),...)
+--E 5145
+
+--S 5146 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            n        n 2p                        2p log(n log(x) + log(a))
+--R   - log(a x )log(a x )   + (n log(x) + log(a))%e
+--R   -----------------------------------------------------------------------
+--R                                   2n p + n
+--R                                                    Type: Expression(Integer)
+--E 5146
+
+--S 5147 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5147
+
+)clear all
+
+--S 5148 of 5341
+t0:=(log(a*x^n)^m)^p/x
+--R 
+--R
+--R               n m p
+--R        log(a x )
+--R   (1)  ------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 5148
+
+--S 5149 of 5341
+r0:=log(a*x^n)*(log(a*x^n)^m)^p/(n*(1+m*p))
+--R 
+--R
+--R               n        n m p
+--R        log(a x )log(a x )
+--R   (2)  ---------------------
+--R              m n p + n
+--R                                                    Type: Expression(Integer)
+--E 5149
+
+--S 5150 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             m p log(n log(x) + log(a))
+--R        (n log(x) + log(a))%e
+--R   (3)  -----------------------------------------------
+--R                           m n p + n
+--R                                         Type: Union(Expression(Integer),...)
+--E 5150
+
+--S 5151 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R            n        n m p                        m p log(n log(x) + log(a))
+--R   - log(a x )log(a x )    + (n log(x) + log(a))%e
+--R   -------------------------------------------------------------------------
+--R                                   m n p + n
+--R                                                    Type: Expression(Integer)
+--E 5151
+
+--S 5152 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5152
+
+)clear all
+
+--S 5153 of 5341
+t0:=sqrt(log(a*x^n)^2)/x
+--R 
+--R
+--R         +----------+
+--R         |       n 2
+--R        \|log(a x )
+--R   (1)  -------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 5153
+
+--S 5154 of 5341
+r0:=1/2*log(a*x^n)*sqrt(log(a*x^n)^2)/n
+--R 
+--R
+--R                  +----------+
+--R               n  |       n 2
+--R        log(a x )\|log(a x )
+--R   (2)  ----------------------
+--R                  2n
+--R                                                    Type: Expression(Integer)
+--E 5154
+
+--S 5155 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                2
+--R        n log(x)  + 2log(a)log(x)
+--R   (3)  -------------------------
+--R                    2
+--R                                         Type: Union(Expression(Integer),...)
+--E 5155
+
+--S 5156 of 5341
+m0:=a0-r0
+--R 
+--R
+--R                    +----------+
+--R                 n  |       n 2     2      2
+--R        - log(a x )\|log(a x )   + n log(x)  + 2n log(a)log(x)
+--R   (4)  ------------------------------------------------------
+--R                                  2n
+--R                                                    Type: Expression(Integer)
+--E 5156
+
+--S 5157 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)
+--R                           +-------------------------------------+
+--R                           | 2      2                           2     2      2
+--R       (n log(x) + log(a))\|n log(x)  + 2n log(a)log(x) + log(a)   - n log(x)
+--R     + 
+--R                                 2
+--R       - 2n log(a)log(x) - log(a)
+--R  /
+--R       +-------------------------------------+
+--R       | 2      2                           2
+--R     x\|n log(x)  + 2n log(a)log(x) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 5157
+
+)clear all
+
+--S 5158 of 5341
+t0:=(b*log(a*x^n)^m)^p/x
+--R 
+--R
+--R                  n m p
+--R        (b log(a x ) )
+--R   (1)  ---------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 5158
+
+--S 5159 of 5341
+r0:=log(a*x^n)*(b*log(a*x^n)^m)^p/(n*(1+m*p))
+--R 
+--R
+--R               n           n m p
+--R        log(a x )(b log(a x ) )
+--R   (2)  ------------------------
+--R                m n p + n
+--R                                                    Type: Expression(Integer)
+--E 5159
+
+--S 5160 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                             m p log(n log(x) + log(a)) + p log(b)
+--R        (n log(x) + log(a))%e
+--R   (3)  ----------------------------------------------------------
+--R                                 m n p + n
+--R                                         Type: Union(Expression(Integer),...)
+--E 5160
+
+--S 5161 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)
+--R                n           n m p
+--R       - log(a x )(b log(a x ) )
+--R     + 
+--R                            m p log(n log(x) + log(a)) + p log(b)
+--R       (n log(x) + log(a))%e
+--R  /
+--R     m n p + n
+--R                                                    Type: Expression(Integer)
+--E 5161
+
+--S 5162 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5162
+
+)clear all
+
+--S 5163 of 5341
+t0:=1/sqrt(-log(a*x^2))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |         2
+--R        \|- log(a x )
+--R                                                    Type: Expression(Integer)
+--E 5163
+
+--S 5164 of 5341
+r0:=-x*erf(sqrt(-log(a*x^2))/sqrt(2))*sqrt(1/2*%pi)/sqrt(a*x^2)
+--R 
+--R
+--R                      +-----------+
+--R                      |         2
+--R            +---+    \|- log(a x )
+--R          x\|%pi erf(--------------)
+--R                           +-+
+--R                          \|2
+--R   (2)  - --------------------------
+--R                       +----+
+--R                   +-+ |   2
+--R                  \|2 \|a x
+--R                                                    Type: Expression(Integer)
+--E 5164
+
+-- integrate: implementation incomplete (constant residues)
+--S 5165 of 5341
+--a0:=integrate(t0,x)
+--E 5165
+
+--S 5166 of 5341
+--m0:=a0-r0
+--E 5166
+
+--S 5167 of 5341
+--d0:=D(m0,x)
+--E 5167
+
+)clear all
+
+--S 5168 of 5341
+t0:=1/sqrt(-log(a/x^2))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         +---------+
+--R         |       a
+--R         |- log(--)
+--R         |       2
+--R        \|      x
+--R                                                    Type: Expression(Integer)
+--E 5168
+
+--S 5169 of 5341
+--r0:=x*erfi(sqrt(-log(a/x^2))/sqrt(2))*sqrt(1/2*%pi)*sqrt(a/x^2)
+--E 5169
+
+--S 5170 of 5341
+--a0:=integrate(t0,x)
+--E 5170
+
+--S 5171 of 5341
+--m0:=a0-r0
+--E 5171
+
+--S 5172 of 5341
+--d0:=D(m0,x)
+--E 5172
+
+)clear all
+
+--S 5173 of 5341
+t0:=1/sqrt(-log(a*x^n))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |         n
+--R        \|- log(a x )
+--R                                                    Type: Expression(Integer)
+--E 5173
+
+--S 5174 of 5341
+--r0:=-x*erf(sqrt(-log(a*x^n))/sqrt(n))*sqrt(%pi)/((a*x^n)^(1/n)*sqrt(n))
+--E 5174
+
+--S 5175 of 5341
+--a0:=integrate(t0,x)
+--E 5175
+
+--S 5176 of 5341
+--m0:=a0-r0
+--E 5176
+
+--S 5177 of 5341
+--d0:=D(m0,x)
+--E 5177
+
+)clear all
+
+--S 5178 of 5341
+t0:=log(1-x+sqrt(x))/x
+--R 
+--R
+--R             +-+
+--R        log(\|x  - x + 1)
+--R   (1)  -----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 5178
+
+--S 5179 of 5341
+--r0:=-2*log((1-sqrt(5)-2*sqrt(x))/(1-sqrt(5)))*log(sqrt(x))-_
+--  2*log((1+sqrt(5)-2*sqrt(x))/(1+sqrt(5)))*log(sqrt(x))+2*log(sqrt(x))*_
+--  log(1-x+sqrt(x))-2*polylog(2,2*sqrt(x)/(1-sqrt(5)))-2*polylog(2,_
+--  2*sqrt(x)/(1+sqrt(5)))
+--E 5179
+
+--S 5180 of 5341
+--a0:=integrate(t0,x)
+--E 5180
+
+--S 5181 of 5341
+--m0:=a0-r0
+--E 5181
+
+--S 5182 of 5341
+--d0:=D(m0,x)
+--E 5182
+
+)clear all
+
+--S 5183 of 5341
+t0:=x*log(c+d*x)/(a+b*x)
+--R 
+--R
+--R        x log(d x + c)
+--R   (1)  --------------
+--R            b x + a
+--R                                                    Type: Expression(Integer)
+--E 5183
+
+--S 5184 of 5341
+--r0:=-x/b+(c+d*x)*log(c+d*x)/(b*d)-a*log(-d*(a+b*x)/(b*c-a*d))*_
+--  log(c+d*x)/b^2-a*polylog(2,b*(c+d*x)/(b*c-a*d))/b^2
+--E 5184
+
+--S 5185 of 5341
+--a0:=integrate(t0,x)
+--E 5185
+
+--S 5186 of 5341
+--m0:=a0-r0
+--E 5186
+
+--S 5187 of 5341
+--d0:=D(m0,x)
+--E 5187
+
+)clear all
+
+--S 5188 of 5341
+t0:=log(x)/(-1+x)
+--R 
+--R
+--R        log(x)
+--R   (1)  ------
+--R         x - 1
+--R                                                    Type: Expression(Integer)
+--E 5188
+
+--S 5189 of 5341
+--r0:=-polylog(2,1-x)
+--E 5189
+
+--S 5190 of 5341
+--a0:=integrate(t0,x)
+--E 5190
+
+--S 5191 of 5341
+--m0:=a0-r0
+--E 5191
+
+--S 5192 of 5341
+--d0:=D(m0,x)
+--E 5192
+
+)clear all
+
+--S 5193 of 5341
+t0:=x*log(1-a-b*x)/(a+b*x)
+--R 
+--R
+--R        x log(- b x - a + 1)
+--R   (1)  --------------------
+--R               b x + a
+--R                                                    Type: Expression(Integer)
+--E 5193
+
+--S 5194 of 5341
+--r0:=-x/b-(1-a-b*x)*log(1-a-b*x)/b^2+a*polylog(2,a+b*x)/b^2
+--E 5194
+
+--S 5195 of 5341
+--a0:=integrate(t0,x)
+--E 5195
+
+--S 5196 of 5341
+--m0:=a0-r0
+--E 5196
+
+--S 5197 of 5341
+--d0:=D(m0,x)
+--E 5197
+
+)clear all
+
+--S 5198 of 5341
+t0:=(b+2*c*x)*log(x)/(x*(b+c*x))
+--R 
+--R
+--R        (2c x + b)log(x)
+--R   (1)  ----------------
+--R              2
+--R           c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 5198
+
+--S 5199 of 5341
+--r0:=1/2*log(x)^2+log(x)*log((b+c*x)/b)+polylog(2,-c*x/b)
+--E 5199
+
+--S 5200 of 5341
+--a0:=integrate(t0,x)
+--E 5200
+
+--S 5201 of 5341
+--m0:=a0-r0
+--E 5201
+
+--S 5202 of 5341
+--d0:=D(m0,x)
+--E 5202
+
+)clear all
+
+--S 5203 of 5341
+t0:=sin(x*log(x))+log(x)*sin(x*log(x))
+--R 
+--R
+--R   (1)  (log(x) + 1)sin(x log(x))
+--R                                                    Type: Expression(Integer)
+--E 5203
+
+--S 5204 of 5341
+r0:=-cos(x*log(x))
+--R 
+--R
+--R   (2)  - cos(x log(x))
+--R                                                    Type: Expression(Integer)
+--E 5204
+
+--S 5205 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  - cos(x log(x))
+--R                                         Type: Union(Expression(Integer),...)
+--E 5205
+
+--S 5206 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5206
+
+--S 5207 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5207
+
+)clear all
+
+--S 5208 of 5341
+t0:=log((1-(-1+x)^2)/(1+(-1+x)^2))/x^2
+--R 
+--R
+--R                2
+--R             - x  + 2x
+--R        log(-----------)
+--R             2
+--R            x  - 2x + 2
+--R   (1)  ----------------
+--R                2
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 5208
+
+--S 5209 of 5341
+r0:=(-1)/x+atan(1-x)-log((1-(1-x)^2)/(1+(-1+x)^2))/x+1/2*log(2-x)+_
+   1/2*log(x)-1/2*log(2-2*x+x^2)
+--R 
+--R
+--R   (2)
+--R                                                  2
+--R                2                              - x  + 2x
+--R       - x log(x  - 2x + 2) + x log(x) - 2log(-----------) + x log(- x + 2)
+--R                                               2
+--R                                              x  - 2x + 2
+--R     + 
+--R       - 2x atan(x - 1) - 2
+--R  /
+--R     2x
+--R                                                    Type: Expression(Integer)
+--E 5209
+
+--S 5210 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                        2
+--R                2                    2               - x  + 2x
+--R       - x log(x  - 2x + 2) + x log(x  - 2x) - 2log(-----------)
+--R                                                     2
+--R                                                    x  - 2x + 2
+--R     + 
+--R       - 2x atan(x - 1) - 2
+--R  /
+--R     2x
+--R                                         Type: Union(Expression(Integer),...)
+--E 5210
+
+--S 5211 of 5341
+m0:=a0-r0
+--R 
+--R
+--R             2
+--R        log(x  - 2x) - log(x) - log(- x + 2)
+--R   (4)  ------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 5211
+
+--S 5212 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5212
+
+)clear all
+
+--S 5213 of 5341
+t0:=log(x+sqrt(x))
+--R 
+--R
+--R             +-+
+--R   (1)  log(\|x  + x)
+--R                                                    Type: Expression(Integer)
+--E 5213
+
+--S 5214 of 5341
+r0:=-x-log(1+sqrt(x))+x*log(x+sqrt(x))+sqrt(x)
+--R 
+--R
+--R               +-+             +-+         +-+
+--R   (2)  x log(\|x  + x) - log(\|x  + 1) + \|x  - x
+--R                                                    Type: Expression(Integer)
+--E 5214
+
+--S 5215 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R               +-+             +-+         +-+
+--R   (3)  x log(\|x  + x) - log(\|x  + 1) + \|x  - x
+--R                                         Type: Union(Expression(Integer),...)
+--E 5215
+
+--S 5216 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5216
+
+--S 5217 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5217
+
+)clear all
+
+--S 5218 of 5341
+t0:=log(-x/(1+x))
+--R 
+--R
+--R                x
+--R   (1)  log(- -----)
+--R              x + 1
+--R                                                    Type: Expression(Integer)
+--E 5218
+
+--S 5219 of 5341
+r0:=x*log(-x/(1+x))-log(1+x)
+--R 
+--R
+--R                                 x
+--R   (2)  - log(x + 1) + x log(- -----)
+--R                               x + 1
+--R                                                    Type: Expression(Integer)
+--E 5219
+
+--S 5220 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R                                 x
+--R   (3)  - log(x + 1) + x log(- -----)
+--R                               x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 5220
+
+--S 5221 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5221
+
+--S 5222 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5222
+
+)clear all
+
+--S 5223 of 5341
+t0:=log((-1+x)/(1+x))
+--R 
+--R
+--R            x - 1
+--R   (1)  log(-----)
+--R            x + 1
+--R                                                    Type: Expression(Integer)
+--E 5223
+
+--S 5224 of 5341
+r0:=-(1-x)*log((-1+x)/(1+x))-2*log(1+x)
+--R 
+--R
+--R                                   x - 1
+--R   (2)  - 2log(x + 1) + (x - 1)log(-----)
+--R                                   x + 1
+--R                                                    Type: Expression(Integer)
+--E 5224
+
+--S 5225 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R               2              x - 1
+--R   (3)  - log(x  - 1) + x log(-----)
+--R                              x + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 5225
+
+--S 5226 of 5341
+m0:=a0-r0
+--R 
+--R
+--R               2                          x - 1
+--R   (4)  - log(x  - 1) + 2log(x + 1) + log(-----)
+--R                                          x + 1
+--R                                                    Type: Expression(Integer)
+--E 5226
+
+--S 5227 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5227
+
+)clear all
+
+--S 5228 of 5341
+t0:=log((1-x^2)/(1+x^2))/(1+x)^2
+--R 
+--R
+--R               2
+--R            - x  + 1
+--R        log(--------)
+--R              2
+--R             x  + 1
+--R   (1)  -------------
+--R          2
+--R         x  + 2x + 1
+--R                                                    Type: Expression(Integer)
+--E 5228
+
+--S 5229 of 5341
+r0:=(-1)/(1+x)-atan(x)+1/2*log(1-x^2)-log((1-x^2)/(1+x^2))/(1+x)-1/2*log(1+x^2)
+--R 
+--R
+--R   (2)
+--R                                      2
+--R                     2             - x  + 1                  2
+--R       (- x - 1)log(x  + 1) - 2log(--------) + (x + 1)log(- x  + 1)
+--R                                     2
+--R                                    x  + 1
+--R     + 
+--R       (- 2x - 2)atan(x) - 2
+--R  /
+--R     2x + 2
+--R                                                    Type: Expression(Integer)
+--E 5229
+
+--S 5230 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)
+--R                                                           2
+--R                     2                    2             - x  + 1
+--R       (- x - 1)log(x  + 1) + (x + 1)log(x  - 1) - 2log(--------)
+--R                                                          2
+--R                                                         x  + 1
+--R     + 
+--R       (- 2x - 2)atan(x) - 2
+--R  /
+--R     2x + 2
+--R                                         Type: Union(Expression(Integer),...)
+--E 5230
+
+--S 5231 of 5341
+m0:=a0-r0
+--R 
+--R
+--R             2               2
+--R        log(x  - 1) - log(- x  + 1)
+--R   (4)  ---------------------------
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 5231
+
+--S 5232 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5232
+
+)clear all
+
+--S 5233 of 5341
+t0:=log(x)/(1-x^2)
+--R 
+--R
+--R          log(x)
+--R   (1)  - ------
+--R           2
+--R          x  - 1
+--R                                                    Type: Expression(Integer)
+--E 5233
+
+--S 5234 of 5341
+--r0:=atanh(x)*log(x)+1/2*polylog(2,-x)-1/2*polylog(2,x)
+--E 5234
+
+--S 5235 of 5341
+--a0:=integrate(t0,x)
+--E 5235
+
+--S 5236 of 5341
+--m0:=a0-r0
+--E 5236
+
+--S 5237 of 5341
+--d0:=D(m0,x)
+--E 5237
+
+)clear all
+
+--S 5238 of 5341
+t0:=log(x)/(1+x^2)
+--R 
+--R
+--R        log(x)
+--R   (1)  ------
+--R         2
+--R        x  + 1
+--R                                                    Type: Expression(Integer)
+--E 5238
+
+--S 5239 of 5341
+--r0:=atan(x)*log(x)-1/2*%i*polylog(2,-%i*x)+1/2*%i*polylog(2,%i*x)
+--E 5239
+
+--S 5240 of 5341
+--a0:=integrate(t0,x)
+--E 5240
+
+--S 5241 of 5341
+--m0:=a0-r0
+--E 5241
+
+--S 5242 of 5341
+--d0:=D(m0,x)
+--E 5242
+
+)clear all
+
+--S 5243 of 5341
+t0:=log(c*(1+x^2)^n)/(1+x^2)
+--R 
+--R
+--R                2     n
+--R        log(c (x  + 1) )
+--R   (1)  ----------------
+--R              2
+--R             x  + 1
+--R                                                    Type: Expression(Integer)
+--E 5243
+
+--S 5244 of 5341
+--r0:=%i*n*atan(x)^2+2*n*atan(x)*log(2*%i/(%i-x))+atan(x)*log(c*(1+x^2)^n)+_
+--  %i*n*polylog(2,(-%i-x)/(%i-x))
+--E 5244
+
+--S 5245 of 5341
+--a0:=integrate(t0,x)
+--E 5245
+
+--S 5246 of 5341
+--m0:=a0-r0
+--E 5246
+
+--S 5247 of 5341
+--d0:=D(m0,x)
+--E 5247
+
+)clear all
+
+--S 5248 of 5341
+t0:=log(x^2/(1+x^2))/(1+x^2)
+--R 
+--R
+--R               2
+--R              x
+--R        log(------)
+--R             2
+--R            x  + 1
+--R   (1)  -----------
+--R            2
+--R           x  + 1
+--R                                                    Type: Expression(Integer)
+--E 5248
+
+--S 5249 of 5341
+--r0:=%i*atan(x)^2-2*atan(x)*log(2*x/(%i+x))+atan(x)*log(x^2/(1+x^2))+_
+--  %i*polylog(2,(%i-x)/(%i+x))
+--E 5249
+
+--S 5250 of 5341
+--a0:=integrate(t0,x)
+--E 5250
+
+--S 5251 of 5341
+--m0:=a0-r0
+--E 5251
+
+--S 5252 of 5341
+--d0:=D(m0,x)
+--E 5252
+
+)clear all
+
+--S 5253 of 5341
+t0:=log(c*x^n)/(a+b*x^2)
+--R 
+--R
+--R               n
+--R        log(c x )
+--R   (1)  ---------
+--R            2
+--R         b x  + a
+--R                                                    Type: Expression(Integer)
+--E 5253
+
+--S 5254 of 5341
+--r0:=-1/2*n*polylog(2,-x*sqrt(b)/sqrt(-a))/(sqrt(-a)*sqrt(b))+_
+--  1/2*n*polylog(2,x*sqrt(b)/sqrt(-a))/(sqrt(-a)*sqrt(b))+atan(x*_
+--  sqrt(b)/sqrt(a))*log(c*x^n)/(sqrt(a)*sqrt(b)),atan(x*sqrt(b)/_
+--  sqrt(a))*log(c*x^n)/(sqrt(a)*sqrt(b))-1/2*%i*n*polylog(2,-%i*x*_
+--  sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b))+1/2*%i*n*polylog(2,%i*x*sqrt(b)/_
+--  sqrt(a))/(sqrt(a)*sqrt(b))
+--E 5254
+
+--S 5255 of 5341
+--a0:=integrate(t0,x)
+--E 5255
+
+--S 5256 of 5341
+--m0:=a0-r0
+--E 5256
+
+--S 5257 of 5341
+--d0:=D(m0,x)
+--E 5257
+
+)clear all
+
+--S 5258 of 5341
+t0:=log(c*(a+b*x^2)^n)/(a+b*x^2)
+--R 
+--R
+--R                  2     n
+--R        log(c (b x  + a) )
+--R   (1)  ------------------
+--R                2
+--R             b x  + a
+--R                                                    Type: Expression(Integer)
+--E 5258
+
+--S 5259 of 5341
+--r0:=%i*n*atan(x*sqrt(b)/sqrt(a))^2/(sqrt(a)*sqrt(b))+atan(x*sqrt(b)/_
+--  sqrt(a))*log(c*(a+b*x^2)^n)/(sqrt(a)*sqrt(b))+2*n*atan(x*sqrt(b)/_
+--  sqrt(a))*log(2*%i*sqrt(a)/(%i*sqrt(a)-x*sqrt(b)))/(sqrt(a)*sqrt(b))+_
+--  %i*n*polylog(2,(-sqrt(a)+%i*x*sqrt(b))/(sqrt(a)+%i*x*sqrt(b)))/_
+--  (sqrt(a)*sqrt(b))
+--E 5259
+
+--S 5260 of 5341
+--a0:=integrate(t0,x)
+--E 5260
+
+--S 5261 of 5341
+--m0:=a0-r0
+--E 5261
+
+--S 5262 of 5341
+--d0:=D(m0,x)
+--E 5262
+
+)clear all
+
+--S 5263 of 5341
+t0:=log(c*x^2/(a+b*x^2))/(a+b*x^2)
+--R 
+--R
+--R                 2
+--R              c x
+--R        log(--------)
+--R               2
+--R            b x  + a
+--R   (1)  -------------
+--R              2
+--R           b x  + a
+--R                                                    Type: Expression(Integer)
+--E 5263
+
+--S 5264 of 5341
+--r0:=%i*atan(x*sqrt(b)/sqrt(a))^2/(sqrt(a)*sqrt(b))+atan(x*sqrt(b)/_
+--  sqrt(a))*log(c*x^2/(a+b*x^2))/(sqrt(a)*sqrt(b))-2*atan(x*sqrt(b)/_
+--  sqrt(a))*log(2*x*sqrt(b)/(%i*sqrt(a)+x*sqrt(b)))/(sqrt(a)*sqrt(b))+_
+--  %i*polylog(2,(sqrt(a)+%i*x*sqrt(b))/(sqrt(a)-%i*x*sqrt(b)))/_
+--  (sqrt(a)*sqrt(b))
+--E 5264
+
+--S 5265 of 5341
+--a0:=integrate(t0,x)
+--E 5265
+
+--S 5266 of 5341
+--m0:=a0-r0
+--E 5266
+
+--S 5267 of 5341
+--d0:=D(m0,x)
+--E 5267
+
+)clear all
+
+--S 5268 of 5341
+t0:=log(1+%i*sqrt(1-a*x)/sqrt(1+a*x))/(1-a^2*x^2)
+--R 
+--R
+--R               +-------+      +---------+
+--R              \|a x + 1  + %i\|- a x + 1
+--R          log(---------------------------)
+--R                        +-------+
+--R                       \|a x + 1
+--R   (1)  - --------------------------------
+--R                       2 2
+--R                      a x  - 1
+--R                                           Type: Expression(Complex(Integer))
+--E 5268
+
+--S 5269 of 5341
+--r0:=polylog(2,-%i*sqrt(1-a*x)/sqrt(1+a*x))/a
+--E 5269
+
+--S 5270 of 5341
+--a0:=integrate(t0,x)
+--E 5270
+
+--S 5271 of 5341
+--m0:=a0-r0
+--E 5271
+
+--S 5272 of 5341
+--d0:=D(m0,x)
+--E 5272
+
+)clear all
+
+--S 5273 of 5341
+t0:=log(1-%i*sqrt(1-a*x)/sqrt(1+a*x))/(1-a^2*x^2)
+--R 
+--R
+--R               +-------+      +---------+
+--R              \|a x + 1  - %i\|- a x + 1
+--R          log(---------------------------)
+--R                        +-------+
+--R                       \|a x + 1
+--R   (1)  - --------------------------------
+--R                       2 2
+--R                      a x  - 1
+--R                                           Type: Expression(Complex(Integer))
+--E 5273
+
+--S 5274 of 5341
+--r0:=polylog(2,%i*sqrt(1-a*x)/sqrt(1+a*x))/a
+--E 5274
+
+--S 5275 of 5341
+--a0:=integrate(t0,x)
+--E 5275
+
+--S 5276 of 5341
+--m0:=a0-r0
+--E 5276
+
+--S 5277 of 5341
+--d0:=D(m0,x)
+--E 5277
+
+)clear all
+
+--S 5278 of 5341
+t0:=log(%e^(a+b*x))
+--R 
+--R
+--R   (1)  b x + a
+--R                                                    Type: Expression(Integer)
+--E 5278
+
+--S 5279 of 5341
+r0:=1/2*log(%e^(a+b*x))^2/b
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (2)  ------------------
+--R                2b
+--R                                                    Type: Expression(Integer)
+--E 5279
+
+--S 5280 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R           2
+--R        b x  + 2a x
+--R   (3)  -----------
+--R             2
+--R                                         Type: Union(Expression(Integer),...)
+--E 5280
+
+--S 5281 of 5341
+m0:=a0-r0
+--R 
+--R
+--R           2
+--R          a
+--R   (4)  - --
+--R          2b
+--R                                                    Type: Expression(Integer)
+--E 5281
+
+--S 5282 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5282
+
+)clear all
+
+--S 5283 of 5341
+t0:=log(%e^(a+b*x^n))
+--R 
+--R
+--R           n
+--R   (1)  b x  + a
+--R                                                    Type: Expression(Integer)
+--E 5283
+
+--S 5284 of 5341
+r0:=-b*n*x^(1+n)/(1+n)+x*log(%e^(a+b*x^n))
+--R 
+--R
+--R               n + 1               n
+--R        - b n x      + (b n + b)x x  + (a n + a)x
+--R   (2)  -----------------------------------------
+--R                          n + 1
+--R                                                    Type: Expression(Integer)
+--E 5284
+
+--S 5285 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R              n log(x)
+--R        b x %e         + (a n + a)x
+--R   (3)  ---------------------------
+--R                   n + 1
+--R                                         Type: Union(Expression(Integer),...)
+--E 5285
+
+--S 5286 of 5341
+m0:=a0-r0
+--R 
+--R
+--R              n log(x)        n + 1                 n
+--R        b x %e         + b n x      + (- b n - b)x x
+--R   (4)  ---------------------------------------------
+--R                            n + 1
+--R                                                    Type: Expression(Integer)
+--E 5286
+
+--S 5287 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5287
+
+)clear all
+
+--S 5288 of 5341
+t0:=%e^x*log(a+%e^x*b)
+--R 
+--R
+--R          x        x
+--R   (1)  %e log(b %e  + a)
+--R                                                    Type: Expression(Integer)
+--E 5288
+
+--S 5289 of 5341
+r0:=-%e^x+(a+%e^x*b)*log(a+%e^x*b)/b
+--R 
+--R
+--R             x             x            x
+--R        (b %e  + a)log(b %e  + a) - b %e
+--R   (2)  ---------------------------------
+--R                        b
+--R                                                    Type: Expression(Integer)
+--E 5289
+
+--S 5290 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R             x             x            x
+--R        (b %e  + a)log(b %e  + a) - b %e
+--R   (3)  ---------------------------------
+--R                        b
+--R                                         Type: Union(Expression(Integer),...)
+--E 5290
+
+--S 5291 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5291
+
+--S 5292 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5292
+
+)clear all
+
+--S 5293 of 5341
+t0:=1/(x*log(%e^x))
+--R 
+--R
+--R         1
+--R   (1)  --
+--R         2
+--R        x
+--R                                                    Type: Expression(Integer)
+--E 5293
+
+-- catdef: division by zero
+--S 5294 of 5341
+--r0:=-log(x)/(x-log(%e^x))+log(log(%e^x))/(x-log(%e^x))
+--E 5294
+
+--S 5295 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          1
+--R   (2)  - -
+--R          x
+--R                                         Type: Union(Expression(Integer),...)
+--E 5295
+
+--S 5296 of 5341
+--m0:=a0-r0
+--E 5296
+
+--S 5297 of 5341
+--d0:=D(m0,x)
+--E 5297
+
+)clear all
+
+--S 5298 of 5341
+t0:=%e^(a+b*x)*log(x)
+--R 
+--R
+--R          b x + a
+--R   (1)  %e       log(x)
+--R                                                    Type: Expression(Integer)
+--E 5298
+
+--S 5299 of 5341
+--r0:=-%e^a*Ei(b*x)/b+%e^(a+b*x)*log(x)/b
+--E 5299
+
+--S 5300 of 5341
+--a0:=integrate(t0,x)
+--E 5300
+
+--S 5301 of 5341
+--m0:=a0-r0
+--E 5301
+
+--S 5302 of 5341
+--d0:=D(m0,x)
+--e--R
+)clear all
+
+--S 5302 of 5341
+t0:=x^2/(x+log(x))
+--R 
+--R
+--R             2
+--R            x
+--R   (1)  ----------
+--R        log(x) + x
+--R                                                    Type: Expression(Integer)
+--E 5302
+
+--S 5303 of 5341
+--r0:=Int(x^2/(x+log(x)),x)
+--E 5303
+
+--S 5304 of 5341
+--a0:=integrate(t0,x)
+--E 5304
+
+--S 5305 of 5341
+--m0:=a0-r0
+--E 5305
+
+--S 5306 of 5341
+--d0:=D(m0,x)
+--E 5306
+
+)clear all
+
+--S 5307 of 5341
+t0:=x/(x+log(x))
+--R 
+--R
+--R             x
+--R   (1)  ----------
+--R        log(x) + x
+--R                                                    Type: Expression(Integer)
+--E 5307
+
+--S 5308 of 5341
+--r0:=Int(x/(x+log(x)),x)
+--E 5308
+
+--S 5309 of 5341
+--a0:=integrate(t0,x)
+--E 5309
+
+--S 5310 of 5341
+--m0:=a0-r0
+--E 5310
+
+--S 5311 of 5341
+--d0:=D(m0,x)
+--E 5311
+
+)clear all
+
+--S 5312 of 5341
+t0:=1/(x+log(x))
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R        log(x) + x
+--R                                                    Type: Expression(Integer)
+--E 5312
+
+--S 5313 of 5341
+--r0:=Int(1/(x+log(x)),x)
+--E 5313
+
+--S 5314 of 5341
+--a0:=integrate(t0,x)
+--E 5314
+
+--S 5315 of 5341
+--m0:=a0-r0
+--E 5315
+
+--S 5316 of 5341
+--d0:=D(m0,x)
+--E 5316
+
+)clear all
+
+--S 5317 of 5341
+t0:=1/(x*(x+log(x)))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R                    2
+--R        x log(x) + x
+--R                                                    Type: Expression(Integer)
+--E 5317
+
+--S 5318 of 5341
+--r0:=Int(1/(x*(x+log(x))),x)
+--E 5318
+
+--S 5319 of 5341
+--a0:=integrate(t0,x)
+--E 5319
+
+--S 5320 of 5341
+--m0:=a0-r0
+--E 5320
+
+--S 5321 of 5341
+--d0:=D(m0,x)
+--E 5321
+
+)clear all
+
+--S 5322 of 5341
+t0:=1/(x^2*(x+log(x)))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         2          3
+--R        x log(x) + x
+--R                                                    Type: Expression(Integer)
+--E 5322
+
+--S 5323 of 5341
+--r0:=Int(1/(x^2*(x+log(x))),x)
+--E 5323
+
+--S 5324 of 5341
+--a0:=integrate(t0,x)
+--E 5324
+
+--S 5325 of 5341
+--m0:=a0-r0
+--E 5325
+
+--S 5326 of 5341
+--d0:=D(m0,x)
+--E 5326
+
+)clear all
+
+--S 5327 of 5341
+t0:=(1-log(x))/(x*(x+log(x)))
+--R 
+--R
+--R         - log(x) + 1
+--R   (1)  -------------
+--R                    2
+--R        x log(x) + x
+--R                                                    Type: Expression(Integer)
+--E 5327
+
+--S 5328 of 5341
+r0:=-log(x)+log(x+log(x))
+--R 
+--R
+--R   (2)  log(log(x) + x) - log(x)
+--R                                                    Type: Expression(Integer)
+--E 5328
+
+--S 5329 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R   (3)  log(log(x) + x) - log(x)
+--R                                         Type: Union(Expression(Integer),...)
+--E 5329
+
+--S 5330 of 5341
+m0:=a0-r0
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 5330
+
+--S 5331 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5331
+
+)clear all
+
+--S 5332 of 5341
+t0:=(1+x)/(log(x)*(x+log(x)))
+--R 
+--R
+--R               x + 1
+--R   (1)  ------------------
+--R              2
+--R        log(x)  + x log(x)
+--R                                                    Type: Expression(Integer)
+--E 5332
+
+--S 5333 of 5341
+--r0:=Li(x)+log(log(x))-log(x+log(x))
+--E 5333
+
+--S 5334 of 5341
+--a0:=integrate(t0,x)
+--E 5334
+
+--S 5335 of 5341
+--m0:=a0-r0
+--E 5335
+
+--S 5336 of 5341
+--d0:=D(m0,x)
+--E 5336
+
+)clear all
+
+--S 5337 of 5341
+t0:=x^(a*x)+x^(a*x)*log(x)
+--R 
+--R
+--R                     a x
+--R   (1)  (log(x) + 1)x
+--R                                                    Type: Expression(Integer)
+--E 5337
+
+--S 5338 of 5341
+r0:=x^(a*x)/a
+--R 
+--R
+--R         a x
+--R        x
+--R   (2)  ----
+--R          a
+--R                                                    Type: Expression(Integer)
+--E 5338
+
+--S 5339 of 5341
+a0:=integrate(t0,x)
+--R 
+--R
+--R          a x log(x)
+--R        %e
+--R   (3)  ------------
+--R              a
+--R                                         Type: Union(Expression(Integer),...)
+--E 5339
+
+--S 5340 of 5341
+m0:=a0-r0
+--R 
+--R
+--R          a x log(x)    a x
+--R        %e           - x
+--R   (4)  -------------------
+--R                 a
+--R                                                    Type: Expression(Integer)
+--E 5340
+
+--S 5341 of 5341
+d0:=normalize(D(m0,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 5341
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder13.input.pamphlet b/src/input/richder13.input.pamphlet
new file mode 100644
index 0000000..3c06743
--- /dev/null
+++ b/src/input/richder13.input.pamphlet
@@ -0,0 +1,7280 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder13.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|u (a+b x+c x^2)^n (d+e x+f x^2)^p|
+There is 1 derivative that differs from Rubi
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder13.output
+)spool richder13.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 286
+t0:=sqrt(1+2*x+x^2)/sqrt(1+x^2)
+--R 
+--R
+--R         +-----------+
+--R         | 2
+--R        \|x  + 2x + 1
+--R   (1)  --------------
+--R            +------+
+--R            | 2
+--R           \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 286
+r0:=asinh(x)*sqrt(1+2*x+x^2)/(1+x)+sqrt(1+x^2)*sqrt(1+2*x+x^2)/(1+x)
+--R 
+--R
+--R          +------+             +-----------+
+--R          | 2                  | 2
+--R        (\|x  + 1  + asinh(x))\|x  + 2x + 1
+--R   (2)  ------------------------------------
+--R                        x + 1
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 286
+t0:=(a+b*x+c*x^2)^4*(A+C*x^2)
+--R 
+--R
+--R   (1)
+--R        4 10         3 9       4         3       2 2  8
+--R     C c x   + 4C b c x  + (A c  + 4C a c  + 6C b c )x
+--R   + 
+--R            3            2       3   7
+--R     (4A b c  + 12C a b c  + 4C b c)x
+--R   + 
+--R            3        2       2  2          2       4  6
+--R     (4A a c  + (6A b  + 6C a )c  + 12C a b c + C b )x
+--R   + 
+--R               2        3        2            3  5
+--R     (12A a b c  + (4A b  + 12C a b)c + 4C a b )x
+--R   + 
+--R          2 2           2       3        4       2 2  4
+--R     (6A a c  + (12A a b  + 4C a )c + A b  + 6C a b )x
+--R   + 
+--R           2            3       3   3        3        2 2      4  2       3
+--R     (12A a b c + 4A a b  + 4C a b)x  + (4A a c + 6A a b  + C a )x  + 4A a b x
+--R   + 
+--R        4
+--R     A a
+--R                                                    Type: Polynomial(Integer)
+--E 4
+
+--S 5 of 286
+r0:=a^4*A*x+2*a^3*A*b*x^2+1/3*a^2*(6*A*b^2+4*a*A*c+a^2*C)*x^3+a*b*(A*_
+   (b^2+3*a*c)+a^2*C)*x^4+1/5*(A*(b^4+12*a*b^2*c+6*a^2*c^2)+2*a^2*(3*b^2+_
+   2*a*c)*C)*x^5+2/3*b*(b^2+3*a*c)*(A*c+a*C)*x^6+1/7*(2*A*c^2*(3*b^2+2*a*c)+_
+   (b^4+12*a*b^2*c+6*a^2*c^2)*C)*x^7+1/2*b*c*(A*c^2+(b^2+3*a*c)*C)*x^8+_
+   1/9*c^2*(A*c^2+6*b^2*C+4*a*c*C)*x^9+2/5*b*c^3*C*x^10+1/11*c^4*C*x^11
+--R 
+--R
+--R   (2)
+--R      1    4 11   2      3 10    1    4   4      3   2    2 2  9
+--R     -- C c x   + - C b c x   + (- A c  + - C a c  + - C b c )x
+--R     11           5              9        9          3
+--R   + 
+--R      1      3   3        2   1    3   8
+--R     (- A b c  + - C a b c  + - C b c)x
+--R      2          2            2
+--R   + 
+--R      4      3    6    2   6    2  2   12      2    1    4  7
+--R     (- A a c  + (- A b  + - C a )c  + -- C a b c + - C b )x
+--R      7           7        7            7           7
+--R   + 
+--R              2    2    3       2      2      3  6
+--R     (2A a b c  + (- A b  + 2C a b)c + - C a b )x
+--R                   3                   3
+--R   + 
+--R      6    2 2    12      2   4    3     1    4   6    2 2  5
+--R     (- A a c  + (-- A a b  + - C a )c + - A b  + - C a b )x
+--R      5            5          5          5        5
+--R   + 
+--R          2           3      3   4    4    3        2 2   1    4  3       3   2
+--R     (3A a b c + A a b  + C a b)x  + (- A a c + 2A a b  + - C a )x  + 2A a b x
+--R                                      3                   3
+--R   + 
+--R        4
+--R     A a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 5
+
+--S 6 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 6
+
+)clear all
+
+--S 7 of 286
+t0:=(a+b*x+c*x^2)^3*(A+C*x^2)
+--R 
+--R
+--R   (1)
+--R        3 8         2 7       3         2       2   6
+--R     C c x  + 3C b c x  + (A c  + 3C a c  + 3C b c)x
+--R   + 
+--R            2                 3  5          2        2       2           2  4
+--R     (3A b c  + 6C a b c + C b )x  + (3A a c  + (3A b  + 3C a )c + 3C a b )x
+--R   + 
+--R                  3       2   3        2          2      3  2       2         3
+--R   (6A a b c + A b  + 3C a b)x  + (3A a c + 3A a b  + C a )x  + 3A a b x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 7
+
+--S 8 of 286
+r0:=a^3*A*x+3/2*a^2*A*b*x^2+1/3*a*(3*A*(b^2+a*c)+a^2*C)*x^3+1/4*b*(A*(b^2+_
+   6*a*c)+3*a^2*C)*x^4+3/5*(b^2+a*c)*(A*c+a*C)*x^5+1/6*b*(3*A*c^2+(b^2+_
+   6*a*c)*C)*x^6+1/7*c*(A*c^2+3*(b^2+a*c)*C)*x^7+3/8*b*c^2*C*x^8+1/9*c^3*C*x^9
+--R 
+--R
+--R   (2)
+--R     1    3 9   3      2 8    1    3   3      2   3    2   7
+--R     - C c x  + - C b c x  + (- A c  + - C a c  + - C b c)x
+--R     9          8             7        7          7
+--R   + 
+--R      1      2             1    3  6
+--R     (- A b c  + C a b c + - C b )x
+--R      2                    6
+--R   + 
+--R      3      2    3    2   3    2     3      2  5
+--R     (- A a c  + (- A b  + - C a )c + - C a b )x
+--R      5           5        5          5
+--R   + 
+--R      3           1    3   3    2   4       2         2   1    3  3   3    2   2
+--R     (- A a b c + - A b  + - C a b)x  + (A a c + A a b  + - C a )x  + - A a b x
+--R      2           4        4                              3           2
+--R   + 
+--R        3
+--R     A a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 8
+
+--S 9 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 9
+
+)clear all
+
+--S 10 of 286
+t0:=(a+b*x+c*x^2)^2*(A+C*x^2)
+--R 
+--R
+--R   (1)
+--R        2 6           5       2               2  4                     3
+--R     C c x  + 2C b c x  + (A c  + 2C a c + C b )x  + (2A b c + 2C a b)x
+--R   + 
+--R                  2      2  2                 2
+--R     (2A a c + A b  + C a )x  + 2A a b x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 10
+
+--S 11 of 286
+r0:=a^2*A*x+a*A*b*x^2+1/3*(A*(b^2+2*a*c)+a^2*C)*x^3+1/2*b*(A*c+a*C)*x^4+_
+   1/5*(A*c^2+(b^2+2*a*c)*C)*x^5+1/3*b*c*C*x^6+1/7*c^2*C*x^7
+--R 
+--R
+--R   (2)
+--R     1    2 7   1        6    1    2   2         1    2  5
+--R     - C c x  + - C b c x  + (- A c  + - C a c + - C b )x
+--R     7          3             5        5         5
+--R   + 
+--R      1         1        4    2         1    2   1    2  3          2      2
+--R     (- A b c + - C a b)x  + (- A a c + - A b  + - C a )x  + A a b x  + A a x
+--R      2         2             3         3        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 11
+
+--S 12 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 12
+
+)clear all
+
+--S 13 of 286
+t0:=(a+b*x+c*x^2)*(A+C*x^2)
+--R 
+--R
+--R             4        3               2
+--R   (1)  C c x  + C b x  + (A c + C a)x  + A b x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 13
+
+--S 14 of 286
+r0:=a*A*x+1/2*A*b*x^2+1/3*(A*c+a*C)*x^3+1/4*b*C*x^4+1/5*c*C*x^5
+--R 
+--R
+--R        1      5   1      4    1       1      3   1      2
+--R   (2)  - C c x  + - C b x  + (- A c + - C a)x  + - A b x  + A a x
+--R        5          4           3       3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 14
+
+--S 15 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 15
+
+)clear all
+
+--S 16 of 286
+t0:=(A+C*x^2)/(a+b*x+c*x^2)
+--R 
+--R
+--R              2
+--R           C x  + A
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 16
+
+--S 17 of 286
+r0:=C*x/c-1/2*b*C*log(a+b*x+c*x^2)/c^2-(2*A*c^2+(b^2-2*a*c)*C)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R              2                2          2c x + b
+--R       (- 4A c  + 4C a c - 2C b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                                            +-----------+
+--R                     2                      |          2
+--R       (- C b log(c x  + b x + a) + 2C c x)\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 286
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^2
+--R 
+--R
+--R                             2
+--R                          C x  + A
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 19
+
+--S 20 of 286
+r0:=(-b*(A*c+a*C)-(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*(a+b*x+c*x^2))+_
+   4*(A*c+a*C)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                 3         2  2            2                      2       2
+--R         ((- 4A c  - 4C a c )x  + (- 4A b c  - 4C a b c)x - 4A a c  - 4C a c)
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                  +-----------+
+--R             2               2                    |          2
+--R       ((2A c  - 2C a c + C b )x + A b c + C a b)\|- 4a c + b
+--R  /
+--R                                                           +-----------+
+--R           3    2 2  2          2    3        2 2      2   |          2
+--R     ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 286
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + A
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 22
+
+--S 23 of 286
+r0:=1/2*(-b*(A*c+a*C)-(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2)^2)+1/2*(6*A*c^2+(b^2+2*a*c)*C)*(b+2*c*x)/(c*(b^2-4*a*c)^2*_
+   (a+b*x+c*x^2))-2*(6*A*c^2+(b^2+2*a*c)*C)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                   4         3       2 2  4
+--R           (- 24A c  - 8C a c  - 4C b c )x
+--R         + 
+--R                     3            2       3   3
+--R           (- 48A b c  - 16C a b c  - 8C b c)x
+--R         + 
+--R                     3           2        2  2          2        4  2
+--R           (- 48A a c  + (- 24A b  - 16C a )c  - 16C a b c - 4C b )x
+--R         + 
+--R                       2        2            3          2 2       3        2 2
+--R           (- 48A a b c  - 16C a b c - 8C a b )x - 24A a c  - 8C a c - 4C a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 3         2       2   3           2                  3  2
+--R           (12A c  + 4C a c  + 2C b c)x  + (18A b c  + 6C a b c + 3C b )x
+--R         + 
+--R                 2        2       2            2                    3       2
+--R         (20A a c  + (4A b  - 4C a )c + 10C a b )x + 10A a b c - A b  + 6C a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 286
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^4
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + A
+--R  /
+--R        4 8       3 7        3     2 2  6           2     3   5
+--R       c x  + 4b c x  + (4a c  + 6b c )x  + (12a b c  + 4b c)x
+--R     + 
+--R          2 2        2     4  4       2          3  3      3      2 2  2
+--R       (6a c  + 12a b c + b )x  + (12a b c + 4a b )x  + (4a c + 6a b )x
+--R     + 
+--R         3       4
+--R       4a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 25
+
+--S 26 of 286
+r0:=1/3*(-b*(A*c+a*C)-(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2)^3)+1/3*(5*A*c^2+(b^2+a*c)*C)*(b+2*c*x)/(c*(b^2-4*a*c)^2*_
+   (a+b*x+c*x^2)^2)-2*(5*A*c^2+(b^2+a*c)*C)*(b+2*c*x)/((b^2-4*a*c)^3*_
+   (a+b*x+c*x^2))+8*c*(5*A*c^2+(b^2+a*c)*C)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(7/2)
+--R 
+--R
+--R   (2)
+--R                    6          5        2 4  6
+--R           (- 120A c  - 24C a c  - 24C b c )x
+--R         + 
+--R                      5            4        3 3  5
+--R           (- 360A b c  - 72C a b c  - 72C b c )x
+--R         + 
+--R                      5            2        2  4           2 3        4 2  4
+--R           (- 360A a c  + (- 360A b  - 72C a )c  - 144C a b c  - 72C b c )x
+--R         + 
+--R                        4            3         2   3           3 2        5   3
+--R           (- 720A a b c  + (- 120A b  - 144C a b)c  - 168C a b c  - 24C b c)x
+--R         + 
+--R                    2 4              2        3  3         2 2 2          4   2
+--R           (- 360A a c  + (- 360A a b  - 72C a )c  - 144C a b c  - 72C a b c)x
+--R         + 
+--R                    2   3        3   2        2 3            3 3        4 2
+--R           (- 360A a b c  - 72C a b c  - 72C a b c)x - 120A a c  - 24C a c
+--R         + 
+--R                  3 2
+--R           - 24C a b c
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 5          4        2 3  5
+--R           (60A c  + 12C a c  + 12C b c )x
+--R         + 
+--R                    4            3        3 2  4
+--R           (150A b c  + 30C a b c  + 30C b c )x
+--R         + 
+--R                    4          2        2  3          2 2        4   3
+--R           (160A a c  + (110A b  + 32C a )c  + 54C a b c  + 22C b c)x
+--R         + 
+--R                      3         3        2   2          3        5  2
+--R           (240A a b c  + (15A b  + 48C a b)c  + 51C a b c + 3C b )x
+--R         + 
+--R                       2 3           2        3  2          4        2 2
+--R                 132A a c  + (54A a b  - 12C a )c  + (- 3A b  + 66C a b )c
+--R               + 
+--R                       4
+--R                 3C a b
+--R          *
+--R             x
+--R         + 
+--R                2   2             3        3         5      2 3
+--R           66A a b c  + (- 13A a b  + 26C a b)c + A b  + C a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              3 6       2 2 5        4 4     6 3  6
+--R         (192a c  - 144a b c  + 36a b c  - 3b c )x
+--R       + 
+--R              3   5       2 3 4         5 3     7 2  5
+--R         (576a b c  - 432a b c  + 108a b c  - 9b c )x
+--R       + 
+--R              4 5       3 2 4       2 4 3        6 2     8   4
+--R         (576a c  + 144a b c  - 324a b c  + 99a b c  - 9b c)x
+--R       + 
+--R               4   4       3 3 3      2 5 2        7      9  3
+--R         (1152a b c  - 672a b c  + 72a b c  + 18a b c - 3b )x
+--R       + 
+--R              5 4       4 2 3       3 4 2      2 6        8  2
+--R         (576a c  + 144a b c  - 324a b c  + 99a b c - 9a b )x
+--R       + 
+--R              5   3       4 3 2       3 5      2 7         6 3       5 2 2
+--R         (576a b c  - 432a b c  + 108a b c - 9a b )x + 192a c  - 144a b c
+--R       + 
+--R            4 4      3 6
+--R         36a b c - 3a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 286
+t0:=(1-x^2)/(1+x+x^2)^2
+--R 
+--R
+--R                   2
+--R                - x  + 1
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  + 2x  + 3x  + 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 28
+
+--S 29 of 286
+r0:=x/(1+x+x^2)
+--R 
+--R
+--R             x
+--R   (2)  ----------
+--R         2
+--R        x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 29
+
+--S 30 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 30
+
+)clear all
+
+--S 31 of 286
+t0:=(1+x^2)/(1+x+x^2)
+--R 
+--R
+--R           2
+--R          x  + 1
+--R   (1)  ----------
+--R         2
+--R        x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 31
+
+--S 32 of 286
+r0:=x-1/2*log(1+x+x^2)+atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                               +-+
+--R           +-+     2                  (2x + 1)\|3        +-+
+--R        - \|3 log(x  + x + 1) + 2atan(------------) + 2x\|3
+--R                                            3
+--R   (2)  ----------------------------------------------------
+--R                                  +-+
+--R                                2\|3
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 286
+t0:=(-1+x^2)/(25-6*x+x^2)
+--R 
+--R
+--R            2
+--R           x  - 1
+--R   (1)  ------------
+--R         2
+--R        x  - 6x + 25
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 34
+
+--S 35 of 286
+r0:=x+2*atan(3/4-1/4*x)+3*log(25-6*x+x^2)
+--R 
+--R
+--R              2                    x - 3
+--R   (2)  3log(x  - 6x + 25) - 2atan(-----) + x
+--R                                     4
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 286
+t0:=(-10+3*x^2)/(4-4*x+x^2)
+--R 
+--R
+--R            2
+--R          3x  - 10
+--R   (1)  -----------
+--R         2
+--R        x  - 4x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 37
+
+--S 38 of 286
+r0:=2/(2-x)+3*x+12*log(2-x)
+--R 
+--R
+--R                                   2
+--R        (12x - 24)log(- x + 2) + 3x  - 6x - 2
+--R   (2)  -------------------------------------
+--R                        x - 2
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 286
+t0:=(8+x^2)/(6-5*x+x^2)
+--R 
+--R
+--R            2
+--R           x  + 8
+--R   (1)  -----------
+--R         2
+--R        x  - 5x + 6
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 40
+
+--S 41 of 286
+r0:=x-12*log(2-x)+17*log(3-x)
+--R 
+--R
+--R   (2)  17log(- x + 3) - 12log(- x + 2) + x
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 286
+t0:=(a+c*x^2)^3*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R        3 8      3 7       3         2  6         2 5          2       2   4
+--R     C c x  + B c x  + (A c  + 3C a c )x  + 3B a c x  + (3A a c  + 3C a c)x
+--R   + 
+--R         2   3        2       3  2      3       3
+--R     3B a c x  + (3A a c + C a )x  + B a x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 43
+
+--S 44 of 286
+r0:=a^3*A*x+1/2*a^3*B*x^2+1/3*a^2*(3*A*c+a*C)*x^3+3/4*a^2*B*c*x^4+3/5*a*c*_
+   (A*c+a*C)*x^5+1/2*a*B*c^2*x^6+1/7*c^2*(A*c+3*a*C)*x^7+1/8*B*c^3*x^8+_
+   1/9*c^3*C*x^9
+--R 
+--R
+--R   (2)
+--R     1    3 9   1    3 8    1    3   3      2  7   1      2 6
+--R     - C c x  + - B c x  + (- A c  + - C a c )x  + - B a c x
+--R     9          8           7        7             2
+--R   + 
+--R    3      2   3    2   5   3    2   4       2    1    3  3   1    3 2      3
+--R   (- A a c  + - C a c)x  + - B a c x  + (A a c + - C a )x  + - B a x  + A a x
+--R    5          5            4                     3           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 44
+
+--S 45 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 45
+
+)clear all
+
+--S 46 of 286
+t0:=(a+c*x^2)^2*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R        2 6      2 5       2           4           3                2  2      2
+--R     C c x  + B c x  + (A c  + 2C a c)x  + 2B a c x  + (2A a c + C a )x  + B a x
+--R   + 
+--R        2
+--R     A a
+--R                                                    Type: Polynomial(Integer)
+--E 46
+
+--S 47 of 286
+r0:=a^2*A*x+1/2*a^2*B*x^2+1/3*a*(2*A*c+a*C)*x^3+1/2*a*B*c*x^4+_
+   1/5*c*(A*c+2*a*C)*x^5+1/6*B*c^2*x^6+1/7*c^2*C*x^7
+--R 
+--R
+--R   (2)
+--R     1    2 7   1    2 6    1    2   2        5   1        4
+--R     - C c x  + - B c x  + (- A c  + - C a c)x  + - B a c x
+--R     7          6           5        5            2
+--R   + 
+--R      2         1    2  3   1    2 2      2
+--R     (- A a c + - C a )x  + - B a x  + A a x
+--R      3         3           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 47
+
+--S 48 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 48
+
+)clear all
+
+--S 49 of 286
+t0:=(a+c*x^2)*(A+B*x+C*x^2)
+--R 
+--R
+--R             4        3               2
+--R   (1)  C c x  + B c x  + (A c + C a)x  + B a x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 49
+
+--S 50 of 286
+r0:=a*A*x+1/2*a*B*x^2+1/3*(A*c+a*C)*x^3+1/4*B*c*x^4+1/5*c*C*x^5
+--R 
+--R
+--R        1      5   1      4    1       1      3   1      2
+--R   (2)  - C c x  + - B c x  + (- A c + - C a)x  + - B a x  + A a x
+--R        5          4           3       3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 50
+
+--S 51 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 51
+
+)clear all
+
+--S 52 of 286
+t0:=(A+B*x+C*x^2)/(a+c*x^2)
+--R 
+--R
+--R           2
+--R        C x  + B x + A
+--R   (1)  --------------
+--R              2
+--R           c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 52
+
+--S 53 of 286
+r0:=C*x/c+1/2*B*log(a+c*x^2)/c+(A*c-a*C)*atan(x*sqrt(c)/sqrt(a))/_
+   (c^(3/2)*sqrt(a))
+--R 
+--R
+--R                            +-+
+--R                          x\|c               2              +-+ +-+
+--R        (2A c - 2C a)atan(-----) + (B log(c x  + a) + 2C x)\|a \|c
+--R                            +-+
+--R                           \|a
+--R   (2)  -----------------------------------------------------------
+--R                                    +-+ +-+
+--R                                 2c\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 286
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^2
+--R 
+--R
+--R              2
+--R           C x  + B x + A
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 55
+
+--S 56 of 286
+r0:=1/2*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2))+1/2*(A*c+a*C)*_
+   atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                                           +-+
+--R        2          2              2      x\|c                          +-+ +-+
+--R   ((A c  + C a c)x  + A a c + C a )atan(-----) + ((A c - C a)x - B a)\|a \|c
+--R                                           +-+
+--R                                          \|a
+--R   ---------------------------------------------------------------------------
+--R                                  2 2     2   +-+ +-+
+--R                             (2a c x  + 2a c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 286
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^3
+--R 
+--R
+--R                   2
+--R                C x  + B x + A
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3a c x  + 3a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 58
+
+--S 59 of 286
+r0:=1/4*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2)^2)+1/8*(3*A*c+a*C)*x/(a^2*c*_
+   (a+c*x^2))+1/8*(3*A*c+a*C)*atan(x*sqrt(c)/sqrt(a))/(a^(5/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                                                                         +-+
+--R             3        2  4          2       2   2       2       3      x\|c
+--R       ((3A c  + C a c )x  + (6A a c  + 2C a c)x  + 3A a c + C a )atan(-----)
+--R                                                                         +-+
+--R                                                                        \|a
+--R     + 
+--R             2          3                2         2  +-+ +-+
+--R       ((3A c  + C a c)x  + (5A a c - C a )x - 2B a )\|a \|c
+--R  /
+--R        2 3 4      3 2 2     4   +-+ +-+
+--R     (8a c x  + 16a c x  + 8a c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 286
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^4
+--R 
+--R
+--R                        2
+--R                     C x  + B x + A
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        c x  + 4a c x  + 6a c x  + 4a c x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 61
+
+--S 62 of 286
+r0:=1/6*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2)^3)+1/24*(5*A*c+a*C)*x/(a^2*c*_
+   (a+c*x^2)^2)+1/16*(5*A*c+a*C)*x/(a^3*c*(a+c*x^2))+1/16*(5*A*c+a*C)*_
+   atan(x*sqrt(c)/sqrt(a))/(a^(7/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                 4         3  6           3       2 2  4         2 2       3   2
+--R           (15A c  + 3C a c )x  + (45A a c  + 9C a c )x  + (45A a c  + 9C a c)x
+--R         + 
+--R                3        4
+--R           15A a c + 3C a
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                 3         2  5           2       2   3         2        3
+--R           (15A c  + 3C a c )x  + (40A a c  + 8C a c)x  + (33A a c - 3C a )x
+--R         + 
+--R                 3
+--R           - 8B a
+--R      *
+--R          +-+ +-+
+--R         \|a \|c
+--R  /
+--R         3 4 6       4 3 4       5 2 2      6   +-+ +-+
+--R     (48a c x  + 144a c x  + 144a c x  + 48a c)\|a \|c
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 286
+t0:=(1+2*x+x^2)/(1+x^2)^2
+--R 
+--R
+--R          2
+--R         x  + 2x + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 64
+
+--S 65 of 286
+r0a:=(-1)/(1+x^2)+atan(x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atan(x) - 1
+--R   (2)  -------------------
+--R                2
+--R               x  + 1
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 286
+r0b:=-1/2*(1-x)*(1+x)/(1+x^2)+atan(x)
+--R 
+--R
+--R           2                2
+--R        (2x  + 2)atan(x) + x  - 1
+--R   (3)  -------------------------
+--R                   2
+--R                 2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 66
+
+--S 67 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R          2
+--R         x  + 2x + 1
+--R   (4)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 67
+
+)clear all
+
+--S 68 of 286
+t0:=(2+12*x+3*x^2)/(4+x^2)^2
+--R 
+--R
+--R          2
+--R        3x  + 12x + 2
+--R   (1)  -------------
+--R         4     2
+--R        x  + 8x  + 16
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 68
+
+--S 69 of 286
+r0:=1/4*(-24-5*x)/(4+x^2)+7/8*atan(1/2*x)
+--R 
+--R
+--R           2           x
+--R        (7x  + 28)atan(-) - 10x - 48
+--R                       2
+--R   (2)  ----------------------------
+--R                    2
+--R                  8x  + 32
+--R                                                    Type: Expression(Integer)
+--E 69
+
+--S 70 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 70
+
+)clear all
+
+--S 71 of 286
+t0:=(a+b*x+c*x^2)^(5/2)*(A+C*x^2)
+--R 
+--R
+--R   (1)
+--R          2 6           5       2               2  4                     3
+--R       C c x  + 2C b c x  + (A c  + 2C a c + C b )x  + (2A b c + 2C a b)x
+--R     + 
+--R                    2      2  2                 2
+--R       (2A a c + A b  + C a )x  + 2A a b x + A a
+--R  *
+--R      +--------------+
+--R      |   2
+--R     \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 286
+r0:=-5/6144*(b^2-4*a*c)*(32*A*c^2+9*b^2*C-4*a*c*C)*(b+2*c*x)*_
+   (a+b*x+c*x^2)^(3/2)/c^4+1/384*(32*A*c^2+9*b^2*C-4*a*c*C)*(b+2*c*x)*_
+   (a+b*x+c*x^2)^(5/2)/c^3-1/112*C*(9*b-14*c*x)*(a+b*x+c*x^2)^(7/2)/c^2-_
+   5/32768*(b^2-4*a*c)^3*(32*A*c^2+9*b^2*C-4*a*c*C)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/c^(11/2)+5/16384*(b^2-4*a*c)^2*_
+   (32*A*c^2+9*b^2*C-4*a*c*C)*(b+2*c*x)*sqrt(a+b*x+c*x^2)/c^5
+--R 
+--R
+--R   (2)
+--R                    3 5               2 2           4  4
+--R           215040A a c  + (- 161280A a b  - 26880C a )c
+--R         + 
+--R                      4           3 2  3             6           2 4  2
+--R           (40320A a b  + 80640C a b )c  + (- 3360A b  - 50400C a b )c
+--R         + 
+--R                     6          8
+--R           11760C a b c - 945C b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                   7 7              6 6
+--R           86016C c x  + 202752C b c x
+--R         + 
+--R                     7              6            2 5  5
+--R           (114688A c  + 243712C a c  + 124416C b c )x
+--R         + 
+--R                       6                5         3 4  4
+--R           (286720A b c  + 314368C a b c  + 768C b c )x
+--R         + 
+--R                          6             2            2  5            2 4
+--R               372736A a c  + (193536A b  + 211456C a )c  + 6912C a b c
+--R             + 
+--R                       4 3
+--R               - 864C b c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                            5           3           2   4            3 3
+--R               559104A a b c  + (3584A b  + 22272C a b)c  - 9088C a b c
+--R             + 
+--R                      5 2
+--R               1008C b c
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        2 5              2           3  4
+--R               473088A a c  + (43008A a b  + 26880C a )c
+--R             + 
+--R                         4           2 2  3             4 2          6
+--R               (- 4480A b  - 38208C a b )c  + 12656C a b c  - 1260C b c
+--R          *
+--R             x
+--R         + 
+--R                    2   4                3           3   3
+--R           236544A a b c  + (- 71680A a b  - 84864C a b)c
+--R         + 
+--R                   5           2 3  2             5           7
+--R           (6720A b  + 75488C a b )c  - 21000C a b c + 1890C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R            5 +-+
+--R     688128c \|c
+--R                                                    Type: Expression(Integer)
+--E 72
+
+--S 73 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 73
+
+)clear all
+
+--S 74 of 286
+t0:=(a+b*x+c*x^2)^(3/2)*(A+C*x^2)
+--R 
+--R
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R   (1)  (C c x  + C b x  + (A c + C a)x  + A b x + A a)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 286
+r0:=1/192*(24*A*c^2+7*b^2*C-4*a*c*C)*(b+2*c*x)*(a+b*x+c*x^2)^(3/2)/c^3-_
+   1/60*C*(7*b-10*c*x)*(a+b*x+c*x^2)^(5/2)/c^2+1/1024*(b^2-4*a*c)^2*_
+   (24*A*c^2+7*b^2*C-4*a*c*C)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/c^(9/2)-1/512*(b^2-4*a*c)*(24*A*c^2+7*b^2*C-_
+   4*a*c*C)*(b+2*c*x)*sqrt(a+b*x+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R                  2 4               2         3  3          4          2 2  2
+--R           5760A a c  + (- 2880A a b  - 960C a )c  + (360A b  + 2160C a b )c
+--R         + 
+--R                     4          6
+--R           - 900C a b c + 105C b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                  5 5            4 4           5            4        2 3  3
+--R           2560C c x  + 3328C b c x  + (3840A c  + 4480C a c  + 96C b c )x
+--R         + 
+--R                     4             3         3 2  2
+--R           (5760A b c  + 576C a b c  - 112C b c )x
+--R         + 
+--R                     4          2         2  3           2 2         4
+--R           (9600A a c  + (480A b  + 960C a )c  - 864C a b c  + 140C b c)x
+--R         + 
+--R                      3            3          2   2            3          5
+--R           4800A a b c  + (- 720A b  - 2592C a b)c  + 1520C a b c - 210C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R           4 +-+
+--R     15360c \|c
+--R                                                    Type: Expression(Integer)
+--E 75
+
+--S 76 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 76
+
+)clear all
+
+--S 77 of 286
+t0:=(a+b*x+c*x^2)^(1/2)*(A+C*x^2)
+--R 
+--R
+--R                   +--------------+
+--R            2      |   2
+--R   (1)  (C x  + A)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 286
+r0:=-1/24*C*(5*b-6*c*x)*(a+b*x+c*x^2)^(3/2)/c^2-1/128*(b^2-4*a*c)*_
+   (16*A*c^2+5*b^2*C-4*a*c*C)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/c^(7/2)+1/64*(16*A*c^2+5*b^2*C-4*a*c*C)*(b+2*c*x)*_
+   sqrt(a+b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                  3           2        2  2          2         4
+--R         (192A a c  + (- 48A b  - 48C a )c  + 72C a b c - 15C b )
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                3 3          2 2          3          2        2             2
+--R           96C c x  + 16C b c x  + (192A c  + 48C a c  - 20C b c)x + 96A b c
+--R         + 
+--R                               3
+--R           - 104C a b c + 30C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R         3 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 78
+
+--S 79 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 79
+
+)clear all
+
+--S 80 of 286
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^(1/2)
+--R 
+--R
+--R                2
+--R             C x  + A
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 286
+r0:=1/8*(8*A*c^2+3*b^2*C-4*a*c*C)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/c^(5/2)-1/4*C*(3*b-2*c*x)*sqrt(a+b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R            2                2              2c x + b
+--R       (8A c  - 4C a c + 3C b )atanh(----------------------)
+--R                                           +--------------+
+--R                                       +-+ |   2
+--R                                     2\|c \|c x  + b x + a
+--R     + 
+--R                           +--------------+
+--R                       +-+ |   2
+--R       (4C c x - 6C b)\|c \|c x  + b x + a
+--R  /
+--R       2 +-+
+--R     8c \|c
+--R                                                    Type: Expression(Integer)
+--E 81
+
+--S 82 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 82
+
+)clear all
+
+--S 83 of 286
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^(3/2)
+--R 
+--R
+--R                        2
+--R                     C x  + A
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 286
+r0:=C*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/c^(3/2)-_
+   2*(b*(A*c+a*C)+(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                       +--------------+
+--R                    2  |   2                        2c x + b
+--R       (4C a c - C b )\|c x  + b x + a atanh(----------------------)
+--R                                                   +--------------+
+--R                                               +-+ |   2
+--R                                             2\|c \|c x  + b x + a
+--R     + 
+--R             2                2                      +-+
+--R       ((4A c  - 4C a c + 2C b )x + 2A b c + 2C a b)\|c
+--R  /
+--R                       +--------------+
+--R          2    2   +-+ |   2
+--R     (4a c  - b c)\|c \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 84
+
+--S 85 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 85
+
+)clear all
+
+--S 86 of 286
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^(5/2)
+--R 
+--R
+--R                                       2
+--R                                    C x  + A
+--R   (1)  ---------------------------------------------------------------
+--R                                                       +--------------+
+--R          2 4         3            2  2             2  |   2
+--R        (c x  + 2b c x  + (2a c + b )x  + 2a b x + a )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 286
+r0:=-2/3*(b*(A*c+a*C)+(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2)^(3/2))+2/3*(8*A*c^2+(b^2+4*a*c)*C)*(b+2*c*x)/_
+   (c*(b^2-4*a*c)^2*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R             3          2       2   3           2                   3  2
+--R       (32A c  + 16C a c  + 4C b c)x  + (48A b c  + 24C a b c + 6C b )x
+--R     + 
+--R               2        2           2                     3        2
+--R       (48A a c  + 12A b c + 24C a b )x + 24A a b c - 2A b  + 16C a b
+--R  /
+--R             2 3        2 2     4   2       2   2        3      5        3 2
+--R         (48a c  - 24a b c  + 3b c)x  + (48a b c  - 24a b c + 3b )x + 48a c
+--R       + 
+--R              2 2        4
+--R         - 24a b c + 3a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 87
+
+--S 88 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 88
+
+)clear all
+
+--S 89 of 286
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^(7/2)
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + A
+--R  /
+--R          3 6       2 5        2     2   4              3  3      2        2  2
+--R         c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R       + 
+--R           2       3
+--R         3a b x + a
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 286
+r0:=-2/5*(b*(A*c+a*C)+(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2)^(5/2))+2/15*(16*A*c^2+3*b^2*C+4*a*c*C)*(b+2*c*x)/_
+   (c*(b^2-4*a*c)^2*(a+b*x+c*x^2)^(3/2))-16/15*(16*A*c^2+3*b^2*C+4*a*c*C)*_
+   (b+2*c*x)/((b^2-4*a*c)^3*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R              5           4        2 3  5
+--R       (512A c  + 128C a c  + 96C b c )x
+--R     + 
+--R                 4             3         3 2  4
+--R       (1280A b c  + 320C a b c  + 240C b c )x
+--R     + 
+--R                 4          2         2  3           2 2         4   3
+--R       (1280A a c  + (960A b  + 320C a )c  + 480C a b c  + 180C b c)x
+--R     + 
+--R                   3          3         2   2           3         5  2
+--R       (1920A a b c  + (160A b  + 480C a b)c  + 400C a b c + 30C b )x
+--R     + 
+--R              2 3           2 2           4         2 2            4
+--R       (960A a c  + 480A a b c  + (- 20A b  + 480C a b )c + 40C a b )x
+--R     + 
+--R             2   2             3         3          5        2 3
+--R       480A a b c  + (- 80A a b  + 192C a b)c + 6A b  + 16C a b
+--R  /
+--R              3 5       2 2 4         4 3      6 2  4
+--R         (960a c  - 720a b c  + 180a b c  - 15b c )x
+--R       + 
+--R               3   4        2 3 3         5 2      7   3
+--R         (1920a b c  - 1440a b c  + 360a b c  - 30b c)x
+--R       + 
+--R               4 4       3 2 3       2 4 2         6       8  2
+--R         (1920a c  - 480a b c  - 360a b c  + 150a b c - 15b )x
+--R       + 
+--R               4   3        3 3 2       2 5         7         5 3       4 2 2
+--R         (1920a b c  - 1440a b c  + 360a b c - 30a b )x + 960a c  - 720a b c
+--R       + 
+--R             3 4       2 6
+--R         180a b c - 15a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 90
+
+--S 91 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 91
+
+)clear all
+
+--S 92 of 286
+t0:=(A+C*x^2)/(a+b*x+c*x^2)^(9/2)
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + A
+--R  /
+--R          4 8       3 7        3     2 2  6           2     3   5
+--R         c x  + 4b c x  + (4a c  + 6b c )x  + (12a b c  + 4b c)x
+--R       + 
+--R            2 2        2     4  4       2          3  3      3      2 2  2
+--R         (6a c  + 12a b c + b )x  + (12a b c + 4a b )x  + (4a c + 6a b )x
+--R       + 
+--R           3       4
+--R         4a b x + a
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 286
+r0:=-2/7*(b*(A*c+a*C)+(2*A*c^2+(b^2-2*a*c)*C)*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2)^(7/2))+2/35*(24*A*c^2+5*b^2*C+4*a*c*C)*(b+2*c*x)/_
+   (c*(b^2-4*a*c)^2*(a+b*x+c*x^2)^(5/2))-32/105*(24*A*c^2+5*b^2*C+_
+   4*a*c*C)*(b+2*c*x)/((b^2-4*a*c)^3*(a+b*x+c*x^2)^(3/2))+_
+   256/105*c*(24*A*c^2+5*b^2*C+4*a*c*C)*(b+2*c*x)/((b^2-4*a*c)^4*_
+   sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                7            6          2 5  7
+--R       (12288A c  + 2048C a c  + 2560C b c )x
+--R     + 
+--R                  6              5          3 4  6
+--R       (43008A b c  + 7168C a b c  + 8960C b c )x
+--R     + 
+--R                  6            2          2  5             2 4           4 3  5
+--R       (43008A a c  + (53760A b  + 7168C a )c  + 17920C a b c  + 11200C b c )x
+--R     + 
+--R                        5            3           2   4             3 3
+--R           107520A a b c  + (26880A b  + 17920C a b)c  + 26880C a b c
+--R         + 
+--R                  5 2
+--R           5600C b c
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                   2 5              2          3  4           4           2 2  3
+--R           53760A a c  + (80640A a b  + 8960C a )c  + (3360A b  + 24640C a b )c
+--R         + 
+--R                     4 2         6
+--R           17360C a b c  + 700C b c
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                   2   4              3           3   3
+--R           80640A a b c  + (13440A a b  + 13440C a b)c
+--R         + 
+--R                    5           2 3  2            5         7
+--R           (- 336A b  + 19040C a b )c  + 2744C a b c - 70C b
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                   3 4           2 2 3               4           3 2  2
+--R           26880A a c  + 20160A a b c  + (- 1680A a b  + 13440C a b )c
+--R         + 
+--R                 6          2 4            6
+--R           (84A b  + 2240C a b )c - 56C a b
+--R      *
+--R         x
+--R     + 
+--R               3   3             2 3          4   2            5         3 3
+--R       13440A a b c  + (- 3360A a b  + 3840C a b)c  + (504A a b  + 640C a b )c
+--R     + 
+--R              7        2 5
+--R       - 30A b  - 16C a b
+--R  /
+--R                4 7         3 2 6         2 4 5          6 4       8 3  6
+--R         (26880a c  - 26880a b c  + 10080a b c  - 1680a b c  + 105b c )x
+--R       + 
+--R                4   6         3 3 5         2 5 4          7 3       9 2  5
+--R         (80640a b c  - 80640a b c  + 30240a b c  - 5040a b c  + 315b c )x
+--R       + 
+--R                5 6         3 4 4         2 6 3          8 2       10   4
+--R         (80640a c  - 50400a b c  + 25200a b c  - 4725a b c  + 315b  c)x
+--R       + 
+--R                 5   5          4 3 4         3 5 3          9        11  3
+--R         (161280a b c  - 134400a b c  + 33600a b c  - 1050a b c + 105b  )x
+--R       + 
+--R                6 5         4 4 3         3 6 2        2 8          10  2
+--R         (80640a c  - 50400a b c  + 25200a b c  - 4725a b c + 315a b  )x
+--R       + 
+--R                6   4         5 3 3         4 5 2        3 7        2 9
+--R         (80640a b c  - 80640a b c  + 30240a b c  - 5040a b c + 315a b )x
+--R       + 
+--R               7 4         6 2 3         5 4 2        4 6        3 8
+--R         26880a c  - 26880a b c  + 10080a b c  - 1680a b c + 105a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 93
+
+--S 94 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 94
+
+)clear all
+
+--S 95 of 286
+t0:=(a+c*x^2)^(5/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R          2 6      2 5       2           4           3                2  2
+--R       C c x  + B c x  + (A c  + 2C a c)x  + 2B a c x  + (2A a c + C a )x
+--R     + 
+--R          2       2
+--R       B a x + A a
+--R  *
+--R      +--------+
+--R      |   2
+--R     \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 286
+r0:=5/192*a*(8*A*c-a*C)*x*(a+c*x^2)^(3/2)/c+1/48*(8*A*c-a*C)*x*_
+   (a+c*x^2)^(5/2)/c+1/56*(8*B+7*C*x)*(a+c*x^2)^(7/2)/c+5/128*a^3*_
+   (8*A*c-a*C)*atanh(x*sqrt(c)/sqrt(a+c*x^2))/c^(3/2)+5/128*a^2*_
+   (8*A*c-a*C)*x*sqrt(a+c*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                      +-+
+--R              3          4          x\|c
+--R       (840A a c - 105C a )atanh(-----------)
+--R                                  +--------+
+--R                                  |   2
+--R                                 \|c x  + a
+--R     + 
+--R                 3 7         3 6          3           2  5            2 4
+--R           336C c x  + 384B c x  + (448A c  + 952C a c )x  + 1152B a c x
+--R         + 
+--R                     2         2   3          2   2           2          3
+--R           (1456A a c  + 826C a c)x  + 1152B a c x  + (1848A a c + 105C a )x
+--R         + 
+--R                 3
+--R           384B a
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + a
+--R  /
+--R           +-+
+--R     2688c\|c
+--R                                                    Type: Expression(Integer)
+--E 96
+
+--S 97 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 97
+
+)clear all
+
+--S 98 of 286
+t0:=(a+c*x^2)^(3/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R                                                        +--------+
+--R              4        3               2                |   2
+--R   (1)  (C c x  + B c x  + (A c + C a)x  + B a x + A a)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 286
+r0:=1/24*(6*A*c-a*C)*x*(a+c*x^2)^(3/2)/c+1/30*(6*B+5*C*x)*(a+c*x^2)^(5/2)/c+_
+   1/16*a^2*(6*A*c-a*C)*atanh(x*sqrt(c)/sqrt(a+c*x^2))/c^(3/2)+_
+   1/16*a*(6*A*c-a*C)*x*sqrt(a+c*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                    +-+
+--R             2         3          x\|c
+--R       (90A a c - 15C a )atanh(-----------)
+--R                                +--------+
+--R                                |   2
+--R                               \|c x  + a
+--R     + 
+--R                2 5        2 4         2            3            2
+--R           40C c x  + 48B c x  + (60A c  + 70C a c)x  + 96B a c x
+--R         + 
+--R                            2          2
+--R           (150A a c + 15C a )x + 48B a
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|c \|c x  + a
+--R  /
+--R          +-+
+--R     240c\|c
+--R                                                    Type: Expression(Integer)
+--E 99
+
+--S 100 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 100
+
+)clear all
+
+--S 101 of 286
+t0:=(a+c*x^2)^(1/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R                         +--------+
+--R            2            |   2
+--R   (1)  (C x  + B x + A)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 286
+r0:=1/12*(4*B+3*C*x)*(a+c*x^2)^(3/2)/c+1/8*a*(4*A*c-a*C)*atanh(x*_
+   sqrt(c)/sqrt(a+c*x^2))/c^(3/2)+1/8*(4*A*c-a*C)*x*sqrt(a+c*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                   +-+
+--R                      2          x\|c
+--R       (12A a c - 3C a )atanh(-----------)
+--R                               +--------+
+--R                               |   2
+--R                              \|c x  + a
+--R     + 
+--R                                                        +--------+
+--R              3         2                           +-+ |   2
+--R       (6C c x  + 8B c x  + (12A c + 3C a)x + 8B a)\|c \|c x  + a
+--R  /
+--R         +-+
+--R     24c\|c
+--R                                                    Type: Expression(Integer)
+--E 102
+
+--S 103 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 103
+
+)clear all
+
+--S 104 of 286
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^(1/2)
+--R 
+--R
+--R           2
+--R        C x  + B x + A
+--R   (1)  --------------
+--R           +--------+
+--R           |   2
+--R          \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 286
+r0:=1/2*(2*A*c-a*C)*atanh(x*sqrt(c)/sqrt(a+c*x^2))/c^(3/2)+_
+   1/2*(2*B+C*x)*sqrt(a+c*x^2)/c
+--R 
+--R
+--R                               +-+                      +--------+
+--R                             x\|c                   +-+ |   2
+--R        (2A c - C a)atanh(-----------) + (C x + 2B)\|c \|c x  + a
+--R                           +--------+
+--R                           |   2
+--R                          \|c x  + a
+--R   (2)  ----------------------------------------------------------
+--R                                     +-+
+--R                                  2c\|c
+--R                                                    Type: Expression(Integer)
+--E 105
+
+--S 106 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 106
+
+)clear all
+
+--S 107 of 286
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^(3/2)
+--R 
+--R
+--R               2
+--R            C x  + B x + A
+--R   (1)  ---------------------
+--R                   +--------+
+--R            2      |   2
+--R        (c x  + a)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 286
+r0:=C*atanh(x*sqrt(c)/sqrt(a+c*x^2))/c^(3/2)+(-a*B+(A*c-a*C)*x)/_
+   (a*c*sqrt(a+c*x^2))
+--R 
+--R
+--R            +--------+           +-+
+--R            |   2              x\|c                             +-+
+--R        C a\|c x  + a atanh(-----------) + ((A c - C a)x - B a)\|c
+--R                             +--------+
+--R                             |   2
+--R                            \|c x  + a
+--R   (2)  -----------------------------------------------------------
+--R                                     +--------+
+--R                                 +-+ |   2
+--R                             a c\|c \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 108
+
+--S 109 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 109
+
+)clear all
+
+--S 110 of 286
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^(5/2)
+--R 
+--R
+--R                    2
+--R                 C x  + B x + A
+--R   (1)  --------------------------------
+--R                              +--------+
+--R          2 4         2    2  |   2
+--R        (c x  + 2a c x  + a )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 286
+r0:=1/3*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2)^(3/2))+1/3*(2*A*c+a*C)*x/_
+   (a^2*c*sqrt(a+c*x^2))
+--R 
+--R
+--R             2          3                 2
+--R        (2A c  + C a c)x  + 3A a c x - B a
+--R   (2)  -----------------------------------
+--R                             +--------+
+--R               2 2 2     3   |   2
+--R            (3a c x  + 3a c)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 111
+
+--S 112 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 112
+
+)clear all
+
+--S 113 of 286
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^(7/2)
+--R 
+--R
+--R                         2
+--R                      C x  + B x + A
+--R   (1)  ------------------------------------------
+--R                                        +--------+
+--R          3 6       2 4     2   2    3  |   2
+--R        (c x  + 3a c x  + 3a c x  + a )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 286
+r0:=1/5*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2)^(5/2))+1/15*(4*A*c+a*C)*x/_
+   (a^2*c*(a+c*x^2)^(3/2))+2/15*(4*A*c+a*C)*x/(a^3*c*sqrt(a+c*x^2))
+--R 
+--R
+--R             3         2  5           2       2   3        2          3
+--R        (8A c  + 2C a c )x  + (20A a c  + 5C a c)x  + 15A a c x - 3B a
+--R   (2)  ---------------------------------------------------------------
+--R                                                  +--------+
+--R                        3 3 4      4 2 2      5   |   2
+--R                    (15a c x  + 30a c x  + 15a c)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 114
+
+--S 115 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 115
+
+)clear all
+
+--S 116 of 286
+t0:=(A+B*x+C*x^2)/(a+c*x^2)^(9/2)
+--R 
+--R
+--R                              2
+--R                           C x  + B x + A
+--R   (1)  ----------------------------------------------------
+--R                                                  +--------+
+--R          4 8       3 6     2 2 4     3   2    4  |   2
+--R        (c x  + 4a c x  + 6a c x  + 4a c x  + a )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 286
+r0:=1/7*(-a*B+(A*c-a*C)*x)/(a*c*(a+c*x^2)^(7/2))+1/35*(6*A*c+a*C)*x/_
+   (a^2*c*(a+c*x^2)^(5/2))+4/105*(6*A*c+a*C)*x/(a^3*c*(a+c*x^2)^(3/2))+_
+   8/105*(6*A*c+a*C)*x/(a^4*c*sqrt(a+c*x^2))
+--R 
+--R
+--R   (2)
+--R             4         3  7            3        2 2  5          2 2        3   3
+--R       (48A c  + 8C a c )x  + (168A a c  + 28C a c )x  + (210A a c  + 35C a c)x
+--R     + 
+--R             3           4
+--R       105A a c x - 15B a
+--R  /
+--R                                                  +--------+
+--R          4 4 6       5 3 4       6 2 2       7   |   2
+--R     (105a c x  + 315a c x  + 315a c x  + 105a c)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 117
+
+--S 118 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 118
+
+)clear all
+
+--S 119 of 286
+t0:=(a+b*x+c*x^2)^3*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R        3 8       3         2  7       3                 2       2   6
+--R     C c x  + (B c  + 3C b c )x  + (A c  + (3B b + 3C a)c  + 3C b c)x
+--R   + 
+--R                    2        2                 3  5
+--R     ((3A b + 3B a)c  + (3B b  + 6C a b)c + C b )x
+--R   + 
+--R            2        2                2        3         2  4
+--R     (3A a c  + (3A b  + 6B a b + 3C a )c + B b  + 3C a b )x
+--R   + 
+--R                    2        3         2       2   3
+--R     ((6A a b + 3B a )c + A b  + 3B a b  + 3C a b)x
+--R   + 
+--R          2          2       2       3  2        2       3        3
+--R     (3A a c + 3A a b  + 3B a b + C a )x  + (3A a b + B a )x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 119
+
+--S 120 of 286
+r0:=a^3*A*x+1/2*a^2*(3*A*b+a*B)*x^2+1/3*a*(3*A*(b^2+a*c)+a*(3*b*B+a*C))*x^3+_
+   1/4*(A*(b^3+6*a*b*c)+3*a*(b^2*B+a*B*c+a*b*C))*x^4+1/5*(b^3*B+6*a*b*B*c+_
+   3*b^2*(A*c+a*C)+3*a*c*(A*c+a*C))*x^5+1/6*(3*b^2*B*c+3*a*B*c^2+b^3*C+_
+   3*b*c*(A*c+2*a*C))*x^6+1/7*c*(3*b*B*c+3*b^2*C+c*(A*c+3*a*C))*x^7+_
+   1/8*c^2*(B*c+3*b*C)*x^8+1/9*c^3*C*x^9
+--R 
+--R
+--R   (2)
+--R     1    3 9    1    3   3      2  8    1    3    3       3      2   3    2   7
+--R     - C c x  + (- B c  + - C b c )x  + (- A c  + (- B b + - C a)c  + - C b c)x
+--R     9           8        8              7         7       7          7
+--R   + 
+--R       1       1      2    1    2             1    3  6
+--R     ((- A b + - B a)c  + (- B b  + C a b)c + - C b )x
+--R       2       2           2                  6
+--R   + 
+--R      3      2    3    2   6         3    2     1    3   3      2  5
+--R     (- A a c  + (- A b  + - B a b + - C a )c + - B b  + - C a b )x
+--R      5           5        5         5          5        5
+--R   + 
+--R       3         3    2     1    3   3      2   3    2   4
+--R     ((- A a b + - B a )c + - A b  + - B a b  + - C a b)x
+--R       2         4          4        4          4
+--R   + 
+--R         2         2      2    1    3  3    3    2    1    3  2      3
+--R     (A a c + A a b  + B a b + - C a )x  + (- A a b + - B a )x  + A a x
+--R                               3            2         2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 120
+
+--S 121 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 121
+
+)clear all
+
+--S 122 of 286
+t0:=(a+b*x+c*x^2)^2*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R        2 6       2           5       2                       2  4
+--R     C c x  + (B c  + 2C b c)x  + (A c  + (2B b + 2C a)c + C b )x
+--R   + 
+--R                          2           3                2               2  2
+--R     ((2A b + 2B a)c + B b  + 2C a b)x  + (2A a c + A b  + 2B a b + C a )x
+--R   + 
+--R                  2        2
+--R     (2A a b + B a )x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 122
+
+--S 123 of 286
+r0:=a^2*A*x+1/2*a*(2*A*b+a*B)*x^2+1/3*(A*(b^2+2*a*c)+a*(2*b*B+a*C))*x^3+_
+   1/4*(b^2*B+2*a*B*c+2*b*(A*c+a*C))*x^4+1/5*(2*b*B*c+b^2*C+c*_
+   (A*c+2*a*C))*x^5+1/6*c*(B*c+2*b*C)*x^6+1/7*c^2*C*x^7
+--R 
+--R
+--R   (2)
+--R     1    2 7    1    2   1        6    1    2    2       2         1    2  5
+--R     - C c x  + (- B c  + - C b c)x  + (- A c  + (- B b + - C a)c + - C b )x
+--R     7           6        3             5         5       5         5
+--R   + 
+--R       1       1         1    2   1        4
+--R     ((- A b + - B a)c + - B b  + - C a b)x
+--R       2       2         4        2
+--R   + 
+--R      2         1    2   2         1    2  3            1    2  2      2
+--R     (- A a c + - A b  + - B a b + - C a )x  + (A a b + - B a )x  + A a x
+--R      3         3        3         3                    2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 123
+
+--S 124 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 124
+
+)clear all
+
+--S 125 of 286
+t0:=(a+b*x+c*x^2)*(A+B*x+C*x^2)
+--R 
+--R
+--R             4               3                     2
+--R   (1)  C c x  + (B c + C b)x  + (A c + B b + C a)x  + (A b + B a)x + A a
+--R                                                    Type: Polynomial(Integer)
+--E 125
+
+--S 126 of 286
+r0:=a*A*x+1/2*(A*b+a*B)*x^2+1/3*(b*B+A*c+a*C)*x^3+1/4*(B*c+b*C)*x^4+1/5*c*C*x^5
+--R 
+--R
+--R   (2)
+--R     1      5    1       1      4    1       1       1      3
+--R     - C c x  + (- B c + - C b)x  + (- A c + - B b + - C a)x
+--R     5           4       4           3       3       3
+--R   + 
+--R      1       1      2
+--R     (- A b + - B a)x  + A a x
+--R      2       2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 126
+
+--S 127 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 127
+
+)clear all
+
+--S 128 of 286
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)
+--R 
+--R
+--R           2
+--R        C x  + B x + A
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 128
+
+--S 129 of 286
+r0:=C*x/c+1/2*(B*c-b*C)*log(a+b*x+c*x^2)/c^2+(b*B*c-b^2*C-2*c*(A*c-a*C))*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R              2                        2          2c x + b
+--R       (- 4A c  + (2B b + 4C a)c - 2C b )atanh(--------------)
+--R                                                +-----------+
+--R                                                |          2
+--R                                               \|- 4a c + b
+--R     + 
+--R                                                 +-----------+
+--R                          2                      |          2
+--R       ((B c - C b)log(c x  + b x + a) + 2C c x)\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 130
+
+)clear all
+
+--S 131 of 286
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^2
+--R 
+--R
+--R                          2
+--R                       C x  + B x + A
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 131
+
+--S 132 of 286
+r0:=(-A*b*c+2*a*B*c-a*b*C+(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/(c*(b^2-4*a*c)*_
+   (a+b*x+c*x^2))-2*(b*B-2*A*c-2*a*C)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                  3                 2  2            2        2
+--R           (- 4A c  + (2B b - 4C a)c )x  + (- 4A b c  + (2B b  - 4C a b)c)x
+--R         + 
+--R                   2                 2
+--R           - 4A a c  + (2B a b - 4C a )c
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                                 +-----------+
+--R           2                        2                            |          2
+--R     ((2A c  + (- B b - 2C a)c + C b )x + (A b - 2B a)c + C a b)\|- 4a c + b
+--R  /
+--R                                                           +-----------+
+--R           3    2 2  2          2    3        2 2      2   |          2
+--R     ((4a c  - b c )x  + (4a b c  - b c)x + 4a c  - a b c)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 133
+
+)clear all
+
+--S 134 of 286
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + B x + A
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 134
+
+--S 135 of 286
+r0:=1/2*(-A*b*c+2*a*B*c-a*b*C+(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/_
+   (c*(b^2-4*a*c)*(a+b*x+c*x^2)^2)-1/2*(3*b*B*c-b^2*C-2*c*(3*A*c+a*C))*_
+   (b+2*c*x)/(c*(b^2-4*a*c)^2*(a+b*x+c*x^2))+2*(3*b*B*c-b^2*C-_
+   2*c*(3*A*c+a*C))*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                   4                  3       2 2  4
+--R           (- 24A c  + (12B b - 8C a)c  - 4C b c )x
+--R         + 
+--R                     3         2            2       3   3
+--R           (- 48A b c  + (24B b  - 16C a b)c  - 8C b c)x
+--R         + 
+--R                        3           2                  2  2
+--R               - 48A a c  + (- 24A b  + 24B a b - 16C a )c
+--R             + 
+--R                     3          2         4
+--R               (12B b  - 16C a b )c - 4C b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       2           2        2            3          2 2
+--R           (- 48A a b c  + (24B a b  - 16C a b)c - 8C a b )x - 24A a c
+--R         + 
+--R                 2        3         2 2
+--R           (12B a b - 8C a )c - 4C a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 3                   2       2   3
+--R           (12A c  + (- 6B b + 4C a)c  + 2C b c)x
+--R         + 
+--R                   2          2                  3  2
+--R           (18A b c  + (- 9B b  + 6C a b)c + 3C b )x
+--R         + 
+--R                   2        2                 2         3          2
+--R           (20A a c  + (4A b  - 10B a b - 4C a )c - 2B b  + 10C a b )x
+--R         + 
+--R                          2        3        2       2
+--R           (10A a b - 8B a )c - A b  - B a b  + 6C a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 135
+
+--S 136 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 136
+
+)clear all
+
+--S 137 of 286
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^4
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + B x + A
+--R  /
+--R        4 8       3 7        3     2 2  6           2     3   5
+--R       c x  + 4b c x  + (4a c  + 6b c )x  + (12a b c  + 4b c)x
+--R     + 
+--R          2 2        2     4  4       2          3  3      3      2 2  2
+--R       (6a c  + 12a b c + b )x  + (12a b c + 4a b )x  + (4a c + 6a b )x
+--R     + 
+--R         3       4
+--R       4a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 137
+
+--S 138 of 286
+r0:=1/3*(-A*b*c+2*a*B*c-a*b*C+(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/_
+   (c*(b^2-4*a*c)*(a+b*x+c*x^2)^3)-1/6*(5*b*B*c-2*b^2*C-2*c*(5*A*c+a*C))*_
+   (b+2*c*x)/(c*(b^2-4*a*c)^2*(a+b*x+c*x^2)^2)+(5*b*B*c-2*b^2*C-_
+   2*c*(5*A*c+a*C))*(b+2*c*x)/((b^2-4*a*c)^3*(a+b*x+c*x^2))-_
+   4*c*(5*b*B*c-2*b^2*C-2*c*(5*A*c+a*C))*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(7/2)
+--R 
+--R
+--R   (2)
+--R                    6                    5        2 4  6
+--R           (- 240A c  + (120B b - 48C a)c  - 48C b c )x
+--R         + 
+--R                      5          2             4         3 3  5
+--R           (- 720A b c  + (360B b  - 144C a b)c  - 144C b c )x
+--R         + 
+--R                         5            2                    2  4
+--R               - 720A a c  + (- 720A b  + 360B a b - 144C a )c
+--R             + 
+--R                      3           2  3         4 2
+--R               (360B b  - 288C a b )c  - 144C b c
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                            4            3           2         2   3
+--R               - 1440A a b c  + (- 240A b  + 720B a b  - 288C a b)c
+--R             + 
+--R                      4           3  2        5
+--R               (120B b  - 336C a b )c  - 48C b c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                       2 4              2         2          3  3
+--R               - 720A a c  + (- 720A a b  + 360B a b - 144C a )c
+--R             + 
+--R                        3         2 2  2           4
+--R               (360B a b  - 288C a b )c  - 144C a b c
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    2   3          2 2         3   2         2 3            3 3
+--R           (- 720A a b c  + (360B a b  - 144C a b)c  - 144C a b c)x - 240A a c
+--R         + 
+--R                  3         4  2        3 2
+--R           (120B a b - 48C a )c  - 48C a b c
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                  5                     4        2 3  5
+--R           (120A c  + (- 60B b + 24C a)c  + 24C b c )x
+--R         + 
+--R                    4            2            3        3 2  4
+--R           (300A b c  + (- 150B b  + 60C a b)c  + 60C b c )x
+--R         + 
+--R                       4          2                   2  3
+--R               320A a c  + (220A b  - 160B a b + 64C a )c
+--R             + 
+--R                        3           2  2        4
+--R               (- 110B b  + 108C a b )c  + 44C b c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                         3         3           2        2   2
+--R               480A a b c  + (30A b  - 240B a b  + 96C a b)c
+--R             + 
+--R                       4           3         5
+--R               (- 15B b  + 102C a b )c + 6C b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     2 3            2         2         3  2
+--R               264A a c  + (108A a b  - 132B a b - 24C a )c
+--R             + 
+--R                      4          3         2 2         5         4
+--R               (- 6A b  - 54B a b  + 132C a b )c + 3B b  + 6C a b
+--R          *
+--R             x
+--R         + 
+--R                  2         3  2             3        2 2        3          5
+--R           (132A a b - 64B a )c  + (- 26A a b  - 18B a b  + 52C a b)c + 2A b
+--R         + 
+--R                4       2 3
+--R           B a b  + 2C a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              3 6       2 2 5        4 4     6 3  6
+--R         (384a c  - 288a b c  + 72a b c  - 6b c )x
+--R       + 
+--R               3   5       2 3 4         5 3      7 2  5
+--R         (1152a b c  - 864a b c  + 216a b c  - 18b c )x
+--R       + 
+--R               4 5       3 2 4       2 4 3         6 2      8   4
+--R         (1152a c  + 288a b c  - 648a b c  + 198a b c  - 18b c)x
+--R       + 
+--R               4   4        3 3 3       2 5 2        7      9  3
+--R         (2304a b c  - 1344a b c  + 144a b c  + 36a b c - 6b )x
+--R       + 
+--R               5 4       4 2 3       3 4 2       2 6         8  2
+--R         (1152a c  + 288a b c  - 648a b c  + 198a b c - 18a b )x
+--R       + 
+--R               5   3       4 3 2       3 5       2 7         6 3       5 2 2
+--R         (1152a b c  - 864a b c  + 216a b c - 18a b )x + 384a c  - 288a b c
+--R       + 
+--R            4 4      3 6
+--R         72a b c - 6a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 138
+
+--S 139 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 139
+
+)clear all
+
+--S 140 of 286
+t0:=(-4+3*x+x^2)/(-8-2*x+x^2)
+--R 
+--R
+--R         2
+--R        x  + 3x - 4
+--R   (1)  -----------
+--R         2
+--R        x  - 2x - 8
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 140
+
+--S 141 of 286
+r0:=x+4*log(4-x)+log(2+x)
+--R 
+--R
+--R   (2)  log(x + 2) + 4log(- x + 4) + x
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 142
+
+)clear all
+
+--S 143 of 286
+t0:=(7+5*x+4*x^2)/(5+4*x+4*x^2)
+--R 
+--R
+--R          2
+--R        4x  + 5x + 7
+--R   (1)  ------------
+--R          2
+--R        4x  + 4x + 5
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 143
+
+--S 144 of 286
+r0:=x+3/8*atan(1/2+x)+1/8*log(5+4*x+4*x^2)
+--R 
+--R
+--R              2                   2x + 1
+--R        log(4x  + 4x + 5) + 3atan(------) + 8x
+--R                                     2
+--R   (2)  --------------------------------------
+--R                           8
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 145
+
+)clear all
+
+--S 146 of 286
+t0:=(2-x+x^2)/(-5+2*x+x^2)
+--R 
+--R
+--R          2
+--R         x  - x + 2
+--R   (1)  -----------
+--R         2
+--R        x  + 2x - 5
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 146
+
+--S 147 of 286
+r0:=x-1/6*log(1+x-sqrt(6))*(9-5*sqrt(6))-1/6*log(1+x+sqrt(6))*(9+5*sqrt(6))
+--R 
+--R
+--R             +-+          +-+               +-+            +-+
+--R        (- 5\|6  - 9)log(\|6  + x + 1) + (5\|6  - 9)log(- \|6  + x + 1) + 6x
+--R   (2)  --------------------------------------------------------------------
+--R                                          6
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 148
+
+)clear all
+
+--S 149 of 286
+t0:=(1+4*x+3*x^2)/(4+7*x+2*x^2)^2
+--R 
+--R
+--R                  2
+--R                3x  + 4x + 1
+--R   (1)  ----------------------------
+--R          4      3      2
+--R        4x  + 28x  + 65x  + 56x + 16
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 149
+
+--S 150 of 286
+r0:=1/2*(-2-3*x)/(4+7*x+2*x^2)
+--R 
+--R
+--R            3     1
+--R          - - x - -
+--R            4     2
+--R   (2)  ------------
+--R         2   7
+--R        x  + - x + 2
+--R             2
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 150
+
+--S 151 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 151
+
+)clear all
+
+--S 152 of 286
+t0:=(1+x+x^2)/(3+2*x+x^2)^2
+--R 
+--R
+--R                 2
+--R                x  + x + 1
+--R   (1)  -------------------------
+--R         4     3      2
+--R        x  + 4x  + 10x  + 12x + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 152
+
+--S 153 of 286
+r0:=1/4*(1-x)/(3+2*x+x^2)+3/4*atan((1+x)/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                   +-+
+--R           2               (x + 1)\|2               +-+
+--R        (3x  + 6x + 9)atan(-----------) + (- x + 1)\|2
+--R                                2
+--R   (2)  -----------------------------------------------
+--R                         2            +-+
+--R                      (4x  + 8x + 12)\|2
+--R                                                    Type: Expression(Integer)
+--E 153
+
+--S 154 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 154
+
+)clear all
+
+--S 155 of 286
+t0:=(-1+2*x+5*x^2)/(1+x+x^2)^4
+--R 
+--R
+--R                              2
+--R                            5x  + 2x - 1
+--R   (1)  ----------------------------------------------------
+--R         8     7      6      5      4      3      2
+--R        x  + 4x  + 10x  + 16x  + 19x  + 16x  + 10x  + 4x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 155
+
+--S 156 of 286
+r0:=-x/(1+x+x^2)^3
+--R 
+--R
+--R                           x
+--R   (2)  - -----------------------------------
+--R           6     5     4     3     2
+--R          x  + 3x  + 6x  + 7x  + 6x  + 3x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 156
+
+--S 157 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 157
+
+)clear all
+
+--S 158 of 286
+t0:=(a+b*x+c*x^2)^(5/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R          2 6       2           5       2                       2  4
+--R       C c x  + (B c  + 2C b c)x  + (A c  + (2B b + 2C a)c + C b )x
+--R     + 
+--R                            2           3                2               2  2
+--R       ((2A b + 2B a)c + B b  + 2C a b)x  + (2A a c + A b  + 2B a b + C a )x
+--R     + 
+--R                    2        2
+--R       (2A a b + B a )x + A a
+--R  *
+--R      +--------------+
+--R      |   2
+--R     \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 286
+r0:=5/6144*(b^2-4*a*c)*(16*b*B*c-9*b^2*C-4*c*(8*A*c-a*C))*(b+2*c*x)*_
+   (a+b*x+c*x^2)^(3/2)/c^4-1/384*(16*b*B*c-32*A*c^2-9*b^2*C+4*a*c*C)*_
+   (b+2*c*x)*(a+b*x+c*x^2)^(5/2)/c^3+1/112*(16*B*c-9*b*C+14*c*C*x)*_
+   (a+b*x+c*x^2)^(7/2)/c^2+5/32768*(b^2-4*a*c)^3*(16*b*B*c-9*b^2*C-4*c*_
+   (8*A*c-a*C))*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/c^(11/2)-_
+   5/16384*(b^2-4*a*c)^2*(16*b*B*c-9*b^2*C-4*c*(8*A*c-a*C))*_
+   (b+2*c*x)*sqrt(a+b*x+c*x^2)/c^5
+--R 
+--R
+--R   (2)
+--R                    3 5               2 2            3            4  4
+--R           215040A a c  + (- 161280A a b  - 107520B a b - 26880C a )c
+--R         + 
+--R                      4           2 3           3 2  3
+--R           (40320A a b  + 80640B a b  + 80640C a b )c
+--R         + 
+--R                     6             5           2 4  2
+--R           (- 3360A b  - 20160B a b  - 50400C a b )c
+--R         + 
+--R                   7             6           8
+--R           (1680B b  + 11760C a b )c - 945C b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                   7 7            7              6  6
+--R           86016C c x  + (98304B c  + 202752C b c )x
+--R         + 
+--R                     7                           6            2 5  5
+--R           (114688A c  + (237568B b + 243712C a)c  + 124416C b c )x
+--R         + 
+--R                                       6             2                5
+--R               (286720A b + 294912B a)c  + (151552B b  + 314368C a b)c
+--R             + 
+--R                     3 4
+--R               768C b c
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                          6             2                          2  5
+--R               372736A a c  + (193536A b  + 403456B a b + 211456C a )c
+--R             + 
+--R                       3            2  4         4 3
+--R               (1536B b  + 6912C a b )c  - 864C b c
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                                       2  5
+--R               (559104A a b + 294912B a )c
+--R             + 
+--R                       3             2           2   4
+--R               (3584A b  + 15360B a b  + 22272C a b)c
+--R             + 
+--R                         4            3  3          5 2
+--R               (- 1792B b  - 9088C a b )c  + 1008C b c
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                        2 5              2           2            3  4
+--R               473088A a c  + (43008A a b  + 58368B a b + 26880C a )c
+--R             + 
+--R                         4             3           2 2  3
+--R               (- 4480A b  - 21504B a b  - 38208C a b )c
+--R             + 
+--R                       5             4  2          6
+--R               (2240B b  + 12656C a b )c  - 1260C b c
+--R          *
+--R             x
+--R         + 
+--R                     2            3  4
+--R           (236544A a b + 98304B a )c
+--R         + 
+--R                        3            2 2           3   3
+--R           (- 71680A a b  - 118272B a b  - 84864C a b)c
+--R         + 
+--R                   5             4           2 3  2
+--R           (6720A b  + 35840B a b  + 75488C a b )c
+--R         + 
+--R                     6             5            7
+--R           (- 3360B b  - 21000C a b )c + 1890C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R            5 +-+
+--R     688128c \|c
+--R                                                    Type: Expression(Integer)
+--E 159
+
+--S 160 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 160
+
+)clear all
+
+--S 161 of 286
+t0:=(a+b*x+c*x^2)^(3/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R   (1)
+--R           4               3                     2
+--R     (C c x  + (B c + C b)x  + (A c + B b + C a)x  + (A b + B a)x + A a)
+--R  *
+--R      +--------------+
+--R      |   2
+--R     \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 286
+r0:=-1/192*(12*b*B*c-24*A*c^2-7*b^2*C+4*a*c*C)*(b+2*c*x)*_
+   (a+b*x+c*x^2)^(3/2)/c^3+1/60*(12*B*c-7*b*C+10*c*C*x)*_
+   (a+b*x+c*x^2)^(5/2)/c^2-1/1024*(b^2-4*a*c)^2*(12*b*B*c-7*b^2*C-_
+   4*c*(6*A*c-a*C))*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   c^(9/2)+1/512*(b^2-4*a*c)*(12*b*B*c-7*b^2*C-4*c*(6*A*c-a*C))*_
+   (b+2*c*x)*sqrt(a+b*x+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R                  2 4               2          2          3  3
+--R           5760A a c  + (- 2880A a b  - 2880B a b - 960C a )c
+--R         + 
+--R                  4            3          2 2  2            5           4
+--R           (360A b  + 1440B a b  + 2160C a b )c  + (- 180B b  - 900C a b )c
+--R         + 
+--R                 6
+--R           105C b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                  5 5           5            4  4
+--R           2560C c x  + (3072B c  + 3328C b c )x
+--R         + 
+--R                   5                       4        2 3  3
+--R           (3840A c  + (4224B b + 4480C a)c  + 96C b c )x
+--R         + 
+--R                                4          2             3         3 2  2
+--R           ((5760A b + 6144B a)c  + (192B b  + 576C a b)c  - 112C b c )x
+--R         + 
+--R                        4          2                     2  3
+--R               9600A a c  + (480A b  + 1344B a b + 960C a )c
+--R             + 
+--R                        3           2  2         4
+--R               (- 240B b  - 864C a b )c  + 140C b c
+--R          *
+--R             x
+--R         + 
+--R                               2  3            3            2          2   2
+--R           (4800A a b + 3072B a )c  + (- 720A b  - 2400B a b  - 2592C a b)c
+--R         + 
+--R                  4            3           5
+--R           (360B b  + 1520C a b )c - 210C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R           4 +-+
+--R     15360c \|c
+--R                                                    Type: Expression(Integer)
+--E 162
+
+--S 163 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 163
+
+)clear all
+
+--S 164 of 286
+t0:=(a+b*x+c*x^2)^(1/2)*(A+B*x+C*x^2)
+--R 
+--R
+--R                         +--------------+
+--R            2            |   2
+--R   (1)  (C x  + B x + A)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 286
+r0:=1/24*(8*B*c-5*b*C+6*c*C*x)*(a+b*x+c*x^2)^(3/2)/c^2+1/128*(b^2-4*a*c)*_
+   (8*b*B*c-5*b^2*C-4*c*(4*A*c-a*C))*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/c^(7/2)-1/64*(8*b*B*c-16*A*c^2-5*b^2*C+4*a*c*C)*_
+   (b+2*c*x)*sqrt(a+b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R                   3           2                  2  2         3          2
+--R           192A a c  + (- 48A b  - 96B a b - 48C a )c  + (24B b  + 72C a b )c
+--R         + 
+--R                  4
+--R           - 15C b
+--R      *
+--R                      2c x + b
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|c x  + b x + a
+--R     + 
+--R                3 3          3          2  2
+--R           96C c x  + (128B c  + 16C b c )x
+--R         + 
+--R                  3                   2        2                       2
+--R           (192A c  + (32B b + 48C a)c  - 20C b c)x + (96A b + 128B a)c
+--R         + 
+--R                   2                     3
+--R           (- 48B b  - 104C a b)c + 30C b
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|c \|c x  + b x + a
+--R  /
+--R         3 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 165
+
+--S 166 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 166
+
+)clear all
+
+--S 167 of 286
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^(1/2)
+--R 
+--R
+--R             2
+--R          C x  + B x + A
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 286
+r0:=-1/8*(4*b*B*c-8*A*c^2-3*b^2*C+4*a*c*C)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/c^(5/2)+1/4*(4*B*c-3*b*C+2*c*C*x)*_
+   sqrt(a+b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R            2                          2              2c x + b
+--R       (8A c  + (- 4B b - 4C a)c + 3C b )atanh(----------------------)
+--R                                                     +--------------+
+--R                                                 +-+ |   2
+--R                                               2\|c \|c x  + b x + a
+--R     + 
+--R                                  +--------------+
+--R                              +-+ |   2
+--R       (4C c x + 8B c - 6C b)\|c \|c x  + b x + a
+--R  /
+--R       2 +-+
+--R     8c \|c
+--R                                                    Type: Expression(Integer)
+--E 168
+
+--S 169 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 169
+
+)clear all
+
+--S 170 of 286
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^(3/2)
+--R 
+--R
+--R                     2
+--R                  C x  + B x + A
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 286
+r0:=C*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/c^(3/2)-_
+   2*(A*b*c-2*a*B*c+a*b*C-(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/(c*(b^2-4*a*c)*_
+   sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                       +--------------+
+--R                    2  |   2                        2c x + b
+--R       (4C a c - C b )\|c x  + b x + a atanh(----------------------)
+--R                                                   +--------------+
+--R                                               +-+ |   2
+--R                                             2\|c \|c x  + b x + a
+--R     + 
+--R             2                          2                              +-+
+--R       ((4A c  + (- 2B b - 4C a)c + 2C b )x + (2A b - 4B a)c + 2C a b)\|c
+--R  /
+--R                       +--------------+
+--R          2    2   +-+ |   2
+--R     (4a c  - b c)\|c \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 171
+
+--S 172 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 172
+
+)clear all
+
+--S 173 of 286
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^(5/2)
+--R 
+--R
+--R                                    2
+--R                                 C x  + B x + A
+--R   (1)  ---------------------------------------------------------------
+--R                                                       +--------------+
+--R          2 4         3            2  2             2  |   2
+--R        (c x  + 2b c x  + (2a c + b )x  + 2a b x + a )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 286
+r0:=-2/3*(A*b*c-2*a*B*c+a*b*C-(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/_
+   (c*(b^2-4*a*c)*(a+b*x+c*x^2)^(3/2))-2/3*(4*b*B*c-b^2*C-_
+   4*c*(2*A*c+a*C))*(b+2*c*x)/(c*(b^2-4*a*c)^2*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R             3                     2       2   3
+--R       (32A c  + (- 16B b + 16C a)c  + 4C b c)x
+--R     + 
+--R               2           2                   3  2
+--R       (48A b c  + (- 24B b  + 24C a b)c + 6C b )x
+--R     + 
+--R               2         2                   3          2
+--R       (48A a c  + (12A b  - 24B a b)c - 6B b  + 24C a b )x
+--R     + 
+--R                       2         3         2        2
+--R       (24A a b - 16B a )c - 2A b  - 4B a b  + 16C a b
+--R  /
+--R             2 3        2 2     4   2       2   2        3      5        3 2
+--R         (48a c  - 24a b c  + 3b c)x  + (48a b c  - 24a b c + 3b )x + 48a c
+--R       + 
+--R              2 2        4
+--R         - 24a b c + 3a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 174
+
+--S 175 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 175
+
+)clear all
+
+--S 176 of 286
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^(7/2)
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + B x + A
+--R  /
+--R          3 6       2 5        2     2   4              3  3      2        2  2
+--R         c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R       + 
+--R           2       3
+--R         3a b x + a
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 286
+r0:=-2/5*(A*b*c-2*a*B*c+a*b*C-(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/_
+   (c*(b^2-4*a*c)*(a+b*x+c*x^2)^(5/2))-2/15*(8*b*B*c-3*b^2*C-_
+   4*c*(4*A*c+a*C))*(b+2*c*x)/(c*(b^2-4*a*c)^2*(a+b*x+c*x^2)^(3/2))+_
+   16/15*(8*b*B*c-3*b^2*C-4*c*(4*A*c+a*C))*(b+2*c*x)/((b^2-4*a*c)^3*_
+   sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R              5                       4        2 3  5
+--R       (512A c  + (- 256B b + 128C a)c  + 96C b c )x
+--R     + 
+--R                 4            2             3         3 2  4
+--R       (1280A b c  + (- 640B b  + 320C a b)c  + 240C b c )x
+--R     + 
+--R                    4          2                    2  3
+--R           1280A a c  + (960A b  - 640B a b + 320C a )c
+--R         + 
+--R                    3           2  2         4
+--R           (- 480B b  + 480C a b )c  + 180C b c
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                      3          3           2         2   2
+--R           1920A a b c  + (160A b  - 960B a b  + 480C a b)c
+--R         + 
+--R                   4           3          5
+--R           (- 80B b  + 400C a b )c + 30C b
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                 2 3            2         2   2
+--R           960A a c  + (480A a b  - 480B a b)c
+--R         + 
+--R                   4           3         2 2          5          4
+--R           (- 20A b  - 240B a b  + 480C a b )c + 10B b  + 40C a b
+--R      *
+--R         x
+--R     + 
+--R              2          3  2             3        2 2         3          5
+--R       (480A a b - 192B a )c  + (- 80A a b  - 96B a b  + 192C a b)c + 6A b
+--R     + 
+--R             4        2 3
+--R       4B a b  + 16C a b
+--R  /
+--R              3 5       2 2 4         4 3      6 2  4
+--R         (960a c  - 720a b c  + 180a b c  - 15b c )x
+--R       + 
+--R               3   4        2 3 3         5 2      7   3
+--R         (1920a b c  - 1440a b c  + 360a b c  - 30b c)x
+--R       + 
+--R               4 4       3 2 3       2 4 2         6       8  2
+--R         (1920a c  - 480a b c  - 360a b c  + 150a b c - 15b )x
+--R       + 
+--R               4   3        3 3 2       2 5         7         5 3       4 2 2
+--R         (1920a b c  - 1440a b c  + 360a b c - 30a b )x + 960a c  - 720a b c
+--R       + 
+--R             3 4       2 6
+--R         180a b c - 15a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 177
+
+--S 178 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 178
+
+)clear all
+
+--S 179 of 286
+t0:=(A+B*x+C*x^2)/(a+b*x+c*x^2)^(9/2)
+--R 
+--R
+--R   (1)
+--R        2
+--R     C x  + B x + A
+--R  /
+--R          4 8       3 7        3     2 2  6           2     3   5
+--R         c x  + 4b c x  + (4a c  + 6b c )x  + (12a b c  + 4b c)x
+--R       + 
+--R            2 2        2     4  4       2          3  3      3      2 2  2
+--R         (6a c  + 12a b c + b )x  + (12a b c + 4a b )x  + (4a c + 6a b )x
+--R       + 
+--R           3       4
+--R         4a b x + a
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 286
+r0:=-2/7*(A*b*c-2*a*B*c+a*b*C-(b*B*c-b^2*C-2*c*(A*c-a*C))*x)/_
+   (c*(b^2-4*a*c)*(a+b*x+c*x^2)^(7/2))-2/35*(12*b*B*c-5*b^2*C-_
+   4*c*(6*A*c+a*C))*(b+2*c*x)/(c*(b^2-4*a*c)^2*(a+b*x+c*x^2)^(5/2))+_
+   32/105*(12*b*B*c-5*b^2*C-4*c*(6*A*c+a*C))*(b+2*c*x)/((b^2-4*a*c)^3*_
+   (a+b*x+c*x^2)^(3/2))-256/105*c*(12*b*B*c-5*b^2*C-4*c*(6*A*c+a*C))*_
+   (b+2*c*x)/((b^2-4*a*c)^4*sqrt(a+b*x+c*x^2))
+--R 
+--R
+--R   (2)
+--R                7                         6          2 5  7
+--R       (12288A c  + (- 6144B b + 2048C a)c  + 2560C b c )x
+--R     + 
+--R                  6              2              5          3 4  6
+--R       (43008A b c  + (- 21504B b  + 7168C a b)c  + 8960C b c )x
+--R     + 
+--R                     6            2                       2  5
+--R           43008A a c  + (53760A b  - 21504B a b + 7168C a )c
+--R         + 
+--R                      3             2  4           4 3
+--R           (- 26880B b  + 17920C a b )c  + 11200C b c
+--R      *
+--R          5
+--R         x
+--R     + 
+--R                        5            3             2           2   4
+--R           107520A a b c  + (26880A b  - 53760B a b  + 17920C a b)c
+--R         + 
+--R                      4             3  3          5 2
+--R           (- 13440B b  + 26880C a b )c  + 5600C b c
+--R      *
+--R          4
+--R         x
+--R     + 
+--R                   2 5              2           2           3  4
+--R           53760A a c  + (80640A a b  - 26880B a b + 8960C a )c
+--R         + 
+--R                   4             3           2 2  3
+--R           (3360A b  - 40320B a b  + 24640C a b )c
+--R         + 
+--R                     5             4  2         6
+--R           (- 1680B b  + 17360C a b )c  + 700C b c
+--R      *
+--R          3
+--R         x
+--R     + 
+--R                   2   4              3           2 2           3   3
+--R           80640A a b c  + (13440A a b  - 40320B a b  + 13440C a b)c
+--R         + 
+--R                    5            4           2 3  2          6            5
+--R           (- 336A b  - 6720B a b  + 19040C a b )c  + (168B b  + 2744C a b )c
+--R         + 
+--R                  7
+--R           - 70C b
+--R      *
+--R          2
+--R         x
+--R     + 
+--R                   3 4            2 2           3   3
+--R           26880A a c  + (20160A a b  - 13440B a b)c
+--R         + 
+--R                       4           2 3           3 2  2
+--R           (- 1680A a b  - 10080B a b  + 13440C a b )c
+--R         + 
+--R                 6           5          2 4          7          6
+--R           (84A b  + 840B a b  + 2240C a b )c - 42B b  - 56C a b
+--R      *
+--R         x
+--R     + 
+--R                3           4  3             2 3          3 2          4   2
+--R       (13440A a b - 3840B a )c  + (- 3360A a b  - 2880B a b  + 3840C a b)c
+--R     + 
+--R                5         2 4         3 3          7          6        2 5
+--R       (504A a b  + 240B a b  + 640C a b )c - 30A b  - 12B a b  - 16C a b
+--R  /
+--R                4 7         3 2 6         2 4 5          6 4       8 3  6
+--R         (26880a c  - 26880a b c  + 10080a b c  - 1680a b c  + 105b c )x
+--R       + 
+--R                4   6         3 3 5         2 5 4          7 3       9 2  5
+--R         (80640a b c  - 80640a b c  + 30240a b c  - 5040a b c  + 315b c )x
+--R       + 
+--R                5 6         3 4 4         2 6 3          8 2       10   4
+--R         (80640a c  - 50400a b c  + 25200a b c  - 4725a b c  + 315b  c)x
+--R       + 
+--R                 5   5          4 3 4         3 5 3          9        11  3
+--R         (161280a b c  - 134400a b c  + 33600a b c  - 1050a b c + 105b  )x
+--R       + 
+--R                6 5         4 4 3         3 6 2        2 8          10  2
+--R         (80640a c  - 50400a b c  + 25200a b c  - 4725a b c + 315a b  )x
+--R       + 
+--R                6   4         5 3 3         4 5 2        3 7        2 9
+--R         (80640a b c  - 80640a b c  + 30240a b c  - 5040a b c + 315a b )x
+--R       + 
+--R               7 4         6 2 3         5 4 2        4 6        3 8
+--R         26880a c  - 26880a b c  + 10080a b c  - 1680a b c + 105a b
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 180
+
+--S 181 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 181
+
+)clear all
+
+--S 182 of 286
+t0:=(A+B*x)*(a+b*x+c*x^2)/(d+f*x^2)
+--R 
+--R
+--R             3               2
+--R        B c x  + (A c + B b)x  + (A b + B a)x + A a
+--R   (1)  -------------------------------------------
+--R                             2
+--R                          f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 182
+
+--S 183 of 286
+r0:=(b*B+A*c)*x/f+1/2*B*c*x^2/f-1/2*(B*c*d-A*b*f-a*B*f)*log(d+f*x^2)/f^2-_
+   (b*B*d+A*c*d-a*A*f)*atan(x*sqrt(f)/sqrt(d))/(f^(3/2)*sqrt(d))
+--R 
+--R
+--R   (2)
+--R                                            +-+
+--R              2                           x\|f
+--R       (2A a f  + (- 2A c - 2B b)d f)atan(-----)
+--R                                            +-+
+--R                                           \|d
+--R     + 
+--R                                   2               2                     +-+ +-+
+--R     (((A b + B a)f - B c d)log(f x  + d) + B c f x  + (2A c + 2B b)f x)\|d \|f
+--R  /
+--R       2 +-+ +-+
+--R     2f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 183
+
+--S 184 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 184
+
+)clear all
+
+--S 185 of 286
+t0:=(A+B*x)*(a+b*x+c*x^2)^2/(d+f*x^2)
+--R 
+--R
+--R   (1)
+--R          2 5       2           4                        2  3
+--R       B c x  + (A c  + 2B b c)x  + ((2A b + 2B a)c + B b )x
+--R     + 
+--R                    2           2                2        2
+--R       (2A a c + A b  + 2B a b)x  + (2A a b + B a )x + A a
+--R  /
+--R        2
+--R     f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 185
+
+--S 186 of 286
+r0:=(A*b^2*f-A*c*(c*d-2*a*f)-b*B*(2*c*d-2*a*f))*x/f^2+1/2*(2*A*b*c*f-_
+   B*(c^2*d-b^2*f-2*a*c*f))*x^2/f^2+1/3*c*(2*b*B+A*c)*x^3/f+_
+   1/4*B*c^2*x^4/f-1/2*(2*A*b*f*(c*d-a*f)-B*(c^2*d^2-2*a*c*d*f-_
+   f*(b^2*d-a^2*f)))*log(d+f*x^2)/f^3-(A*b^2*d*f-2*b*B*d*(c*d-a*f)-_
+   A*(c*d-a*f)^2)*atan(x*sqrt(f)/sqrt(d))/(f^(5/2)*sqrt(d))
+--R 
+--R
+--R   (2)
+--R               2 3                     2              2         2            2
+--R         (12A a f  + (- 24A a c - 12A b  - 24B a b)d f  + (12A c  + 24B b c)d f)
+--R      *
+--R                +-+
+--R              x\|f
+--R         atan(-----)
+--R                +-+
+--R               \|d
+--R     + 
+--R                             2  2                             2           2 2
+--R             ((12A a b + 6B a )f  + ((- 12A b - 12B a)c - 6B b )d f + 6B c d )
+--R          *
+--R                    2
+--R             log(f x  + d)
+--R         + 
+--R               2 2 4        2           2 3
+--R           3B c f x  + (4A c  + 8B b c)f x
+--R         + 
+--R                                    2  2       2     2
+--R           (((12A b + 12B a)c + 6B b )f  - 6B c d f)x
+--R         + 
+--R                            2            2           2
+--R           ((24A a c + 12A b  + 24B a b)f  + (- 12A c  - 24B b c)d f)x
+--R      *
+--R          +-+ +-+
+--R         \|d \|f
+--R  /
+--R        3 +-+ +-+
+--R     12f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 186
+
+--S 187 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 187
+
+)clear all
+
+--S 188 of 286
+t0:=(A+B*x)*(a+b*x+c*x^2)^3/(d+f*x^2)
+--R 
+--R
+--R   (1)
+--R          3 7       3         2  6                  2       2   5
+--R       B c x  + (A c  + 3B b c )x  + ((3A b + 3B a)c  + 3B b c)x
+--R     + 
+--R              2        2                 3  4
+--R       (3A a c  + (3A b  + 6B a b)c + B b )x
+--R     + 
+--R                      2        3         2  3        2          2       2   2
+--R       ((6A a b + 3B a )c + A b  + 3B a b )x  + (3A a c + 3A a b  + 3B a b)x
+--R     + 
+--R            2       3        3
+--R       (3A a b + B a )x + A a
+--R  /
+--R        2
+--R     f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 188
+
+--S 189 of 286
+r0:=-(b^3*B*d*f+3*A*b^2*f*(c*d-a*f)-3*b*B*(c*d-a*f)^2-_
+   A*c*(c^2*d^2-3*a*c*d*f+3*a^2*f^2))*x/f^3-1/2*(A*b*f*(3*c^2*d-b^2*f-_
+   6*a*c*f)-B*(c^3*d^2-3*a*c^2*d*f+3*a*b^2*f^2-3*c*f*(b^2*d-a^2*f)))*_
+   x^2/f^3+1/3*(b^3*B*f+3*A*b^2*c*f-A*c^2*(c*d-3*a*f)-_
+   3*b*B*c*(c*d-2*a*f))*x^3/f^2+1/4*c*(3*A*b*c*f-B*(c^2*d-3*b^2*f-_
+   3*a*c*f))*x^4/f^2+1/5*c^2*(3*b*B+A*c)*x^5/f+1/6*B*c^3*x^6/f+_
+   1/2*(A*b*f*(3*c^2*d^2-6*a*c*d*f-f*(b^2*d-3*a^2*f))-B*(c*d-a*f)*_
+   (c^2*d^2-2*a*c*d*f-f*(3*b^2*d-a^2*f)))*log(d+f*x^2)/f^4+_
+   (b^3*B*d^2*f+3*A*b^2*d*f*(c*d-a*f)-3*b*B*d*(c*d-a*f)^2-_
+   A*(c*d-a*f)^3)*atan(x*sqrt(f)/sqrt(d))/(f^(7/2)*sqrt(d))
+--R 
+--R
+--R   (2)
+--R                3 4            2            2         2     3
+--R           60A a f  + (- 180A a c - 180A a b  - 180B a b)d f
+--R         + 
+--R                    2          2                     3  2 2
+--R           (180A a c  + (180A b  + 360B a b)c + 60B b )d f
+--R         + 
+--R                   3           2  3
+--R           (- 60A c  - 180B b c )d f
+--R      *
+--R                +-+
+--R              x\|f
+--R         atan(-----)
+--R                +-+
+--R               \|d
+--R     + 
+--R                     2         3  3
+--R               (90A a b + 30B a )f
+--R             + 
+--R                                   2          3          2    2
+--R               ((- 180A a b - 90B a )c - 30A b  - 90B a b )d f
+--R             + 
+--R                                2        2   2         3 3
+--R               ((90A b + 90B a)c  + 90B b c)d f - 30B c d
+--R          *
+--R                    2
+--R             log(f x  + d)
+--R         + 
+--R                3 3 6         3          2  3 5
+--R           10B c f x  + (12A c  + 36B b c )f x
+--R         + 
+--R                             2        2   3        3   2  4
+--R           (((45A b + 45B a)c  + 45B b c)f  - 15B c d f )x
+--R         + 
+--R                       2         2                     3  3
+--R               (60A a c  + (60A b  + 120B a b)c + 20B b )f
+--R             + 
+--R                       3          2    2
+--R               (- 20A c  - 60B b c )d f
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                                 2          3          2  3
+--R               ((180A a b + 90B a )c + 30A b  + 90B a b )f
+--R             + 
+--R                                  2        2     2        3 2
+--R               ((- 90A b - 90B a)c  - 90B b c)d f  + 30B c d f
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                      2            2         2   3
+--R               (180A a c + 180A a b  + 180B a b)f
+--R             + 
+--R                          2            2                     3    2
+--R               (- 180A a c  + (- 180A b  - 360B a b)c - 60B b )d f
+--R             + 
+--R                     3           2  2
+--R               (60A c  + 180B b c )d f
+--R          *
+--R             x
+--R      *
+--R          +-+ +-+
+--R         \|d \|f
+--R  /
+--R        4 +-+ +-+
+--R     60f \|d \|f
+--R                                                    Type: Expression(Integer)
+--E 189
+
+--S 190 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 190
+
+)clear all
+
+--S 191 of 286
+t0:=(A+B*x)/((a+b*x+c*x^2)*(d+f*x^2))
+--R 
+--R
+--R                           B x + A
+--R   (1)  ---------------------------------------------
+--R             4        3               2
+--R        c f x  + b f x  + (a f + c d)x  + b d x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 191
+
+--S 192 of 286
+r0:=1/2*(B*c*d+A*b*f-a*B*f)*log(a+b*x+c*x^2)/(c^2*d^2-2*a*c*d*f+_
+   f*(b^2*d+a^2*f))-1/2*(B*c*d+A*b*f-a*B*f)*log(d+f*x^2)/(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))-(A*b^2*f+2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*_
+   sqrt(b^2-4*a*c))+(b*B*d-A*c*d+a*A*f)*atan(x*sqrt(f)/sqrt(d))*_
+   sqrt(f)/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(d))
+--R 
+--R
+--R   (2)
+--R                        2                     2             +-+
+--R         ((4A a c - 2A b  + 2B a b)f + (- 4A c  + 2B b c)d)\|d
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                   +-----------+           +-+
+--R                                   |          2  +-+     x\|f
+--R       (2A a f + (- 2A c + 2B b)d)\|- 4a c + b  \|f atan(-----)
+--R                                                           +-+
+--R                                                          \|d
+--R     + 
+--R                                          2
+--R           ((- A b + B a)f - B c d)log(f x  + d)
+--R         + 
+--R                                        2
+--R           ((A b - B a)f + B c d)log(c x  + b x + a)
+--R      *
+--R          +-----------+
+--R          |          2  +-+
+--R         \|- 4a c + b  \|d
+--R  /
+--R                                         +-----------+
+--R        2 2               2         2 2  |          2  +-+
+--R     (2a f  + (- 4a c + 2b )d f + 2c d )\|- 4a c + b  \|d
+--R                                                    Type: Expression(Integer)
+--E 192
+
+--S 193 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 193
+
+)clear all
+
+--S 194 of 286
+t0:=(A+B*x)/((a+b*x+c*x^2)^2*(d+f*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R        2   6           5             2      2   4                     3
+--R       c f x  + 2b c f x  + ((2a c + b )f + c d)x  + (2a b f + 2b c d)x
+--R     + 
+--R         2             2    2               2
+--R       (a f + (2a c + b )d)x  + 2a b d x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 194
+
+--S 195 of 286
+r0:=(-A*b*(c^2*d+b^2*f-3*a*c*f)+a*B*(2*c^2*d+b^2*f-2*a*c*f)-_
+   c*(A*b^2*f+2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*x)/((b^2-4*a*c)*_
+   (c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*(a+b*x+c*x^2))+2*c*(A*b^2*f+_
+   2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)^(3/2)*(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f)))-_
+   1/2*f*(2*A*b*f*(c*d-a*f)+B*(c^2*d^2-2*a*c*d*f-f*(b^2*d-a^2*f)))*_
+   log(a+b*x+c*x^2)/(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))^2+_
+   1/2*f*(2*A*b*f*(c*d-a*f)+B*(c^2*d^2-2*a*c*d*f-f*(b^2*d-a^2*f)))*_
+   log(d+f*x^2)/(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))^2-f*(b^3*B*d*f+_
+   2*a*A*b^2*f^2-2*A*c*(c*d-a*f)^2+b*B*(3*c^2*d^2-2*a*c*d*f-a^2*f^2))*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+_
+   a^2*f))^2*sqrt(b^2-4*a*c))-f^(3/2)*(A*b^2*d*f+2*b*B*d*(c*d-a*f)-_
+   A*(c*d-a*f)^2)*atan(x*sqrt(f)/sqrt(d))/((c^2*d^2-2*a*c*d*f+_
+   f*(b^2*d+a^2*f))^2*sqrt(d))
+--R 
+--R
+--R   (2)
+--R                     3 3           2 2        3   2          4       2 3    3
+--R               (24A a c  + (- 24A a b  + 12B a b)c  + (4A a b  - 2B a b )c)f
+--R             + 
+--R                          2 4           2        2   3          4         3  2
+--R                   - 56A a c  + (24A a b  + 12B a b)c  + (- 4A b  - 8B a b )c
+--R                 + 
+--R                       5
+--R                   2B b c
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                       5           2            4        3 3  2
+--R               (40A a c  + (- 16A b  - 28B a b)c  + 10B b c )d f
+--R             + 
+--R                      6         5  3
+--R               (- 8A c  + 4B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     3   2           2 3        3 2           5       2 4  3
+--R               (24A a b c  + (- 24A a b  + 12B a b )c + 4A a b  - 2B a b )f
+--R             + 
+--R                          2   3           3        2 2  2          5         4
+--R                   - 56A a b c  + (24A a b  + 12B a b )c  + (- 4A b  - 8B a b )c
+--R                 + 
+--R                       6
+--R                   2B b
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                         4           3          2  3        4 2  2
+--R               (40A a b c  + (- 16A b  - 28B a b )c  + 10B b c )d f
+--R             + 
+--R                        5       2 4  3
+--R               (- 8A b c  + 4B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 4 2           3 2        4          2 4       3 3  3
+--R           (24A a c  + (- 24A a b  + 12B a b)c + 4A a b  - 2B a b )f
+--R         + 
+--R                      3 3         2 2        3   2            4       2 3
+--R               - 56A a c  + (24A a b  + 12B a b)c  + (- 4A a b  - 8B a b )c
+--R             + 
+--R                     5
+--R               2B a b
+--R          *
+--R                2
+--R             d f
+--R         + 
+--R                 2 4             2        2   3          3 2  2
+--R           (40A a c  + (- 16A a b  - 28B a b)c  + 10B a b c )d f
+--R         + 
+--R                    5           4  3
+--R           (- 8A a c  + 4B a b c )d
+--R      *
+--R          +-+         2c x + b
+--R         \|d atanh(--------------)
+--R                    +-----------+
+--R                    |          2
+--R                   \|- 4a c + b
+--R     + 
+--R                    3 2       2 2   3
+--R               (8A a c  - 2A a b c)f
+--R             + 
+--R                       2 3            2        2   2        4         3      2
+--R               (- 16A a c  + (- 4A a b  + 16B a b)c  + (2A b  - 4B a b )c)d f
+--R             + 
+--R                      4          2            3       3 2  2
+--R               (8A a c  + (- 2A b  - 16B a b)c  + 4B b c )d f
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    3          2 3  3
+--R               (8A a b c - 2A a b )f
+--R             + 
+--R                       2   2            3        2 2         5         4    2
+--R               (- 16A a b c  + (- 4A a b  + 16B a b )c + 2A b  - 4B a b )d f
+--R             + 
+--R                        3          3          2  2       4   2
+--R               (8A a b c  + (- 2A b  - 16B a b )c  + 4B b c)d f
+--R          *
+--R             x
+--R         + 
+--R                4        3 2  3
+--R           (8A a c - 2A a b )f
+--R         + 
+--R                   3 2          2 2        3            4       2 3    2
+--R           (- 16A a c  + (- 4A a b  + 16B a b)c + 2A a b  - 4B a b )d f
+--R         + 
+--R                2 3            2        2   2         3   2
+--R           (8A a c  + (- 2A a b  - 16B a b)c  + 4B a b c)d f
+--R      *
+--R          +-----------+           +-+
+--R          |          2  +-+     x\|f
+--R         \|- 4a c + b  \|f atan(-----)
+--R                                  +-+
+--R                                 \|d
+--R     + 
+--R                           2        3  2          3      2 2    3
+--R                   ((- 8A a b + 4B a )c  + (2A a b  - B a b )c)f
+--R                 + 
+--R                                  2  3          3         2  2      4     2
+--R                   ((8A a b - 8B a )c  + (- 2A b  - 2B a b )c  + B b c)d f
+--R                 + 
+--R                          4      2 3  2
+--R                   (4B a c  - B b c )d f
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           2 2       3            4      2 3  3
+--R                   ((- 8A a b  + 4B a b)c + 2A a b  - B a b )f
+--R                 + 
+--R                           2       2   2          4         3        5    2
+--R                   ((8A a b  - 8B a b)c  + (- 2A b  - 2B a b )c + B b )d f
+--R                 + 
+--R                            3      3 2  2
+--R                   (4B a b c  - B b c )d f
+--R              *
+--R                 x
+--R             + 
+--R                       3        4         2 3      3 2  3
+--R               ((- 8A a b + 4B a )c + 2A a b  - B a b )f
+--R             + 
+--R                     2        3  2            3       2 2          4    2
+--R               ((8A a b - 8B a )c  + (- 2A a b  - 2B a b )c + B a b )d f
+--R             + 
+--R                    2 3        2 2  2
+--R               (4B a c  - B a b c )d f
+--R          *
+--R                    2
+--R             log(f x  + d)
+--R         + 
+--R                         2        3  2            3      2 2    3
+--R                   ((8A a b - 4B a )c  + (- 2A a b  + B a b )c)f
+--R                 + 
+--R                                    2  3        3         2  2      4     2
+--R                   ((- 8A a b + 8B a )c  + (2A b  + 2B a b )c  - B b c)d f
+--R                 + 
+--R                            4      2 3  2
+--R                   (- 4B a c  + B b c )d f
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         2 2       3            4      2 3  3
+--R                   ((8A a b  - 4B a b)c - 2A a b  + B a b )f
+--R                 + 
+--R                             2       2   2        4         3        5    2
+--R                   ((- 8A a b  + 8B a b)c  + (2A b  + 2B a b )c - B b )d f
+--R                 + 
+--R                              3      3 2  2
+--R                   (- 4B a b c  + B b c )d f
+--R              *
+--R                 x
+--R             + 
+--R                     3        4         2 3      3 2  3
+--R               ((8A a b - 4B a )c - 2A a b  + B a b )f
+--R             + 
+--R                       2        3  2          3       2 2          4    2
+--R               ((- 8A a b + 8B a )c  + (2A a b  + 2B a b )c - B a b )d f
+--R             + 
+--R                      2 3        2 2  2
+--R               (- 4B a c  + B a b c )d f
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                      3 2        2 2       3     3
+--R               (- 4A a c  + (2A a b  - 2B a b)c)f
+--R             + 
+--R                     2 3            2       2   2        4         3      2
+--R               (12A a c  + (- 8A a b  + 2B a b)c  + (2A b  - 2B a b )c)d f
+--R             + 
+--R                         4        2           3       3 2  2
+--R               (- 12A a c  + (6A b  + 2B a b)c  - 2B b c )d f
+--R             + 
+--R                    5         4  3
+--R               (4A c  - 2B b c )d
+--R          *
+--R             x
+--R         + 
+--R                   3        4         2 3       3 2  3
+--R           ((- 6A a b + 4B a )c + 2A a b  - 2B a b )f
+--R         + 
+--R                    2         3  2             3       2 2         5         4
+--R             ((14A a b - 12B a )c  + (- 10A a b  + 8B a b )c + 2A b  - 2B a b )d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                            2  3        3         2  2  2                  4 3
+--R         ((- 10A a b + 12B a )c  + (4A b  - 6B a b )c )d f + (2A b - 4B a)c d
+--R      *
+--R          +-----------+
+--R          |          2  +-+
+--R         \|- 4a c + b  \|d
+--R  /
+--R                5 2     4 2   4         4 3      3 2 2     2 4     3
+--R             (8a c  - 2a b c)f  + (- 32a c  + 24a b c  - 4a b c)d f
+--R           + 
+--R                 3 4      2 2 3        4 2     6   2 2
+--R             (48a c  - 44a b c  + 16a b c  - 2b c)d f
+--R           + 
+--R                   2 5        2 4     4 3  3         6     2 5  4
+--R             (- 32a c  + 24a b c  - 4b c )d f + (8a c  - 2b c )d
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                5        4 3  4         4   2      3 3      2 5    3
+--R             (8a b c - 2a b )f  + (- 32a b c  + 24a b c - 4a b )d f
+--R           + 
+--R                 3   3      2 3 2        5      7  2 2
+--R             (48a b c  - 44a b c  + 16a b c - 2b )d f
+--R           + 
+--R                   2   4        3 3     5 2  3           5     3 4  4
+--R             (- 32a b c  + 24a b c  - 4b c )d f + (8a b c  - 2b c )d
+--R        *
+--R           x
+--R       + 
+--R            6      5 2  4         5 2      4 2      3 4    3
+--R         (8a c - 2a b )f  + (- 32a c  + 24a b c - 4a b )d f
+--R       + 
+--R             4 3      3 2 2      2 4        6  2 2
+--R         (48a c  - 44a b c  + 16a b c - 2a b )d f
+--R       + 
+--R               3 4      2 2 3       4 2  3       2 5       2 4  4
+--R         (- 32a c  + 24a b c  - 4a b c )d f + (8a c  - 2a b c )d
+--R    *
+--R        +-----------+
+--R        |          2  +-+
+--R       \|- 4a c + b  \|d
+--R                                                    Type: Expression(Integer)
+--E 195
+
+--S 196 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 196
+
+)clear all
+
+--S 197 of 286
+t0:=(A+B*x)*(a+b*x+c*x^2)^(1/2)/(d+f*x^2)
+--R 
+--R
+--R                  +--------------+
+--R                  |   2
+--R        (B x + A)\|c x  + b x + a
+--R   (1)  --------------------------
+--R                    2
+--R                 f x  + d
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 286
+r0:=1/2*(b*B+2*A*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f*sqrt(c))+B*sqrt(a+b*x+c*x^2)/f-1/2*atan(1/2*(b*sqrt(-d)+2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))))*(B*c*d-A*b*f-a*B*f+(b*B*d+A*c*d-a*A*f)*_
+   sqrt(f)/sqrt(-d))/(f^(3/2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*(B*c*d-A*b*f-_
+   a*B*f+d*(b*B*d+A*c*d-a*A*f)*sqrt(f)/(-d)^(3/2))/(f^(3/2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                                   +-+ +-+                          +---+ +-+
+--R         ((A a f + (- A c - B b)d)\|c \|f  + ((A b + B a)f - B c d)\|- d \|c )
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                                   +-+ +-+                          +---+ +-+
+--R         ((- A a f + (A c + B b)d)\|c \|f  + ((A b + B a)f - B c d)\|- d \|c )
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                        +---+ +-+             2c x + b
+--R           (2A c + B b)\|- d \|f atanh(----------------------)
+--R                                             +--------------+
+--R                                         +-+ |   2
+--R                                       2\|c \|c x  + b x + a
+--R         + 
+--R                            +--------------+
+--R              +---+ +-+ +-+ |   2
+--R           2B\|- d \|c \|f \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                      +-------------------------+ +-----------------------+
+--R        +---+ +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2f\|- d \|c \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 198
+
+--S 199 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 199
+
+)clear all
+
+--S 200 of 286
+t0:=(A+B*x)/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                  B x + A
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 286
+r0:=1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*(B+A*sqrt(f)/_
+   sqrt(-d))/(sqrt(f)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*atan(1/2*_
+   (b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*(B+A*d*sqrt(f)/(-d)^(3/2))/_
+   (sqrt(f)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                           +-----------------------+
+--R            +-+     +---+  |  +---+ +-+
+--R         (A\|f  + B\|- d )\|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                             +-------------------------+
+--R              +-+     +---+  |    +---+ +-+
+--R         (- A\|f  + B\|- d )\|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R  /
+--R                 +-------------------------+ +-----------------------+
+--R       +---+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2\|- d \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 201
+
+--S 202 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 202
+
+)clear all
+
+--S 203 of 286
+t0:=(A+B*x)/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                     B x + A
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 286
+r0:=-2*(A*b*(c^2*d+b^2*f-3*a*c*f)-a*B*(2*c^2*d+b^2*f-2*a*c*f)+_
+   c*(A*b^2*f+2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*x)/((b^2-4*a*c)*(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))-1/2*atan(1/2*(b*_
+   sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(f)*(B*c*d+A*b*f-a*B*f+_
+   d*(b*B*d-A*c*d+a*A*f)*sqrt(f)/(-d)^(3/2))/((c^2*d^2-2*a*c*d*f+_
+   f*(b^2*d+a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+1/2*atan(1/2*(b*_
+   sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*sqrt(f)*(B*c*d+A*b*f-a*B*f+(b*B*d-_
+   A*c*d+a*A*f)*sqrt(f)/sqrt(-d))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                               2        3        2              2      2
+--R             (((- 4A a b + 4B a )c + A b  - B a b )f + (- 4B a c  + B b c)d)
+--R          *
+--R              +---+ +-+
+--R             \|- d \|f
+--R         + 
+--R                2         2  2            2       2                 3
+--R           (4A a c - A a b )f  + (- 4A a c  + (A b  + 4B a b)c - B b )d f
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                               2        3        2              2      2
+--R             (((- 4A a b + 4B a )c + A b  - B a b )f + (- 4B a c  + B b c)d)
+--R          *
+--R              +---+ +-+
+--R             \|- d \|f
+--R         + 
+--R                  2         2  2          2         2                 3
+--R           (- 4A a c + A a b )f  + (4A a c  + (- A b  - 4B a b)c + B b )d f
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                     2        2                     3         2
+--R           ((- 8A a c  + (4A b  - 4B a b)c)f + (8A c  - 4B b c )d)x
+--R         + 
+--R                             2         3         2                   2
+--R           ((- 12A a b + 8B a )c + 4A b  - 4B a b )f + (4A b - 8B a)c d
+--R      *
+--R                +-------------------------+ +-----------------------+
+--R          +---+ |    +---+ +-+              |  +---+ +-+
+--R         \|- d \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R           3      2 2  2         2 2        2      4            3     2 2  2
+--R       ((8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f + (8a c  - 2b c )d )
+--R    *
+--R              +--------------+ +-------------------------+
+--R        +---+ |   2            |    +---+ +-+
+--R       \|- d \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 204
+
+--S 205 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 205
+
+)clear all
+
+--S 206 of 286
+t0:=(A+B*x)/((a+b*x+c*x^2)^(5/2)*(d+f*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R          2   6           5             2      2   4                     3
+--R         c f x  + 2b c f x  + ((2a c + b )f + c d)x  + (2a b f + 2b c d)x
+--R       + 
+--R           2             2    2               2
+--R         (a f + (2a c + b )d)x  + 2a b d x + a d
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 286
+r0:=-2/3*(A*b*(c^2*d+b^2*f-3*a*c*f)-a*B*(2*c^2*d+b^2*f-2*a*c*f)+_
+   c*(A*b^2*f+2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*x)/((b^2-4*a*c)*_
+   (c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*(a+b*x+c*x^2)^(3/2))+8/3*c*_
+   (A*b^2*f+2*A*c*(c*d-a*f)-b*B*(c*d+a*f))*(b+2*c*x)/((b^2-4*a*c)^2*_
+   (c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))-2*f*_
+   (b^4*B*d*f-A*b^3*f*(c*d-2*a*f)+2*a*B*c*(c*d-a*f)^2+b^2*B*(c^2*d^2-_
+   2*a*c*d*f-a^2*f^2)-A*b*c*(c^2*d^2-6*a*c*d*f+5*a^2*f^2)+c*(b^3*B*d*f+_
+   2*a*A*b^2*f^2-2*A*c*(c*d-a*f)^2+b*B*(3*c^2*d^2-2*a*c*d*f-a^2*f^2))*x)/_
+   ((b^2-4*a*c)*(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))^2*sqrt(a+b*x+c*x^2))-_
+   1/2*f^(3/2)*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+_
+   b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*_
+   (b*f*(b*B*d-A*c*d+a*A*f)-(c*d-a*f)*(B*c*d+A*b*f-a*B*f)+(A*b^2*d*f+_
+   2*b*B*d*(c*d-a*f)-A*(c*d-a*f)^2)*sqrt(f)/sqrt(-d))/((c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))^2*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*f^(3/2)*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-_
+   b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*_
+   (b*f*(b*B*d-A*c*d+a*A*f)-(c*d-a*f)*(B*c*d+A*b*f-a*B*f)-(A*b^2*d*f+_
+   2*b*B*d*(c*d-a*f)-A*(c*d-a*f)^2)*sqrt(f)/sqrt(-d))/((c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))^2*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                               3         4  3         2 3        3 2  2
+--R                       (- 96A a b + 48B a )c  + (48A a b  - 24B a b )c
+--R                     + 
+--R                                5       2 4
+--R                       (- 6A a b  + 3B a b )c
+--R                  *
+--R                      3
+--R                     f
+--R                 + 
+--R                             2         3  4          3 3        5          4  2
+--R                       (96A a b - 96B a )c  - 48A a b c  + (6A b  + 18B a b )c
+--R                     + 
+--R                             6
+--R                       - 3B b c
+--R                  *
+--R                        2
+--R                     d f
+--R                 + 
+--R                         2 5          2 4       4 3  2
+--R                   (48B a c  - 24B a b c  + 3B b c )d f
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                               3 2        4   2         2 4        3 3
+--R                       (- 96A a b  + 48B a b)c  + (48A a b  - 24B a b )c
+--R                     + 
+--R                               6       2 5
+--R                       - 6A a b  + 3B a b
+--R                  *
+--R                      3
+--R                     f
+--R                 + 
+--R                             2 2        3   3          4 2        6          5
+--R                       (96A a b  - 96B a b)c  - 48A a b c  + (6A b  + 18B a b )c
+--R                     + 
+--R                             7
+--R                       - 3B b
+--R                  *
+--R                        2
+--R                     d f
+--R                 + 
+--R                         2   4          3 3       5 2  2
+--R                   (48B a b c  - 24B a b c  + 3B b c )d f
+--R              *
+--R                 x
+--R             + 
+--R                           4         5  2         3 3        4 2         2 5
+--R                   (- 96A a b + 48B a )c  + (48A a b  - 24B a b )c - 6A a b
+--R                 + 
+--R                       3 4
+--R                   3B a b
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                         3         4  3        2 3 2          5        2 4
+--R                   (96A a b - 96B a )c  - 48A a b c  + (6A a b  + 18B a b )c
+--R                 + 
+--R                           6
+--R                   - 3B a b
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                     3 4        2 2 3         4 2  2
+--R               (48B a c  - 24B a b c  + 3B a b c )d f
+--R          *
+--R              +---+ +-+
+--R             \|- d \|f
+--R         + 
+--R                     4 3        3 2 2       2 4   4
+--R               (48A a c  - 24A a b c  + 3A a b c)f
+--R             + 
+--R                          3 4        3   3           4        2 3  2
+--R                   - 96A a c  + 96B a b c  + (18A a b  - 48B a b )c
+--R                 + 
+--R                          6         5
+--R                   (- 3A b  + 6B a b )c
+--R              *
+--R                    3
+--R                 d f
+--R             + 
+--R                        2 5             2        2   4        4          3  3
+--R                   48A a c  + (- 24A a b  - 96B a b)c  + (3A b  + 48B a b )c
+--R                 + 
+--R                         5 2
+--R                   - 6B b c
+--R              *
+--R                  2 2
+--R                 d f
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     4   2        3 3        2 5  4
+--R               (48A a b c  - 24A a b c + 3A a b )f
+--R             + 
+--R                          3   3        3 2 2           5        2 4         7
+--R                   - 96A a b c  + 96B a b c  + (18A a b  - 48B a b )c - 3A b
+--R                 + 
+--R                         6
+--R                   6B a b
+--R              *
+--R                    3
+--R                 d f
+--R             + 
+--R                        2   4             3        2 2  3        5          4  2
+--R                   48A a b c  + (- 24A a b  - 96B a b )c  + (3A b  + 48B a b )c
+--R                 + 
+--R                         6
+--R                   - 6B b c
+--R              *
+--R                  2 2
+--R                 d f
+--R          *
+--R             x
+--R         + 
+--R                 5 2        4 2        3 4  4
+--R           (48A a c  - 24A a b c + 3A a b )f
+--R         + 
+--R                      4 3        4   2         2 4        3 3           6
+--R               - 96A a c  + 96B a b c  + (18A a b  - 48B a b )c - 3A a b
+--R             + 
+--R                   2 5
+--R               6B a b
+--R          *
+--R                3
+--R             d f
+--R         + 
+--R                    3 4           2 2        3   3          4        2 3  2
+--R               48A a c  + (- 24A a b  - 96B a b)c  + (3A a b  + 48B a b )c
+--R             + 
+--R                       5
+--R               - 6B a b c
+--R          *
+--R              2 2
+--R             d f
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                               3         4  3         2 3        3 2  2
+--R                       (- 96A a b + 48B a )c  + (48A a b  - 24B a b )c
+--R                     + 
+--R                                5       2 4
+--R                       (- 6A a b  + 3B a b )c
+--R                  *
+--R                      3
+--R                     f
+--R                 + 
+--R                             2         3  4          3 3        5          4  2
+--R                       (96A a b - 96B a )c  - 48A a b c  + (6A b  + 18B a b )c
+--R                     + 
+--R                             6
+--R                       - 3B b c
+--R                  *
+--R                        2
+--R                     d f
+--R                 + 
+--R                         2 5          2 4       4 3  2
+--R                   (48B a c  - 24B a b c  + 3B b c )d f
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                               3 2        4   2         2 4        3 3
+--R                       (- 96A a b  + 48B a b)c  + (48A a b  - 24B a b )c
+--R                     + 
+--R                               6       2 5
+--R                       - 6A a b  + 3B a b
+--R                  *
+--R                      3
+--R                     f
+--R                 + 
+--R                             2 2        3   3          4 2        6          5
+--R                       (96A a b  - 96B a b)c  - 48A a b c  + (6A b  + 18B a b )c
+--R                     + 
+--R                             7
+--R                       - 3B b
+--R                  *
+--R                        2
+--R                     d f
+--R                 + 
+--R                         2   4          3 3       5 2  2
+--R                   (48B a b c  - 24B a b c  + 3B b c )d f
+--R              *
+--R                 x
+--R             + 
+--R                           4         5  2         3 3        4 2         2 5
+--R                   (- 96A a b + 48B a )c  + (48A a b  - 24B a b )c - 6A a b
+--R                 + 
+--R                       3 4
+--R                   3B a b
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                         3         4  3        2 3 2          5        2 4
+--R                   (96A a b - 96B a )c  - 48A a b c  + (6A a b  + 18B a b )c
+--R                 + 
+--R                           6
+--R                   - 3B a b
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                     3 4        2 2 3         4 2  2
+--R               (48B a c  - 24B a b c  + 3B a b c )d f
+--R          *
+--R              +---+ +-+
+--R             \|- d \|f
+--R         + 
+--R                       4 3        3 2 2       2 4   4
+--R               (- 48A a c  + 24A a b c  - 3A a b c)f
+--R             + 
+--R                        3 4        3   3             4        2 3  2
+--R                   96A a c  - 96B a b c  + (- 18A a b  + 48B a b )c
+--R                 + 
+--R                        6         5
+--R                   (3A b  - 6B a b )c
+--R              *
+--R                    3
+--R                 d f
+--R             + 
+--R                          2 5           2        2   4          4          3  3
+--R                   - 48A a c  + (24A a b  + 96B a b)c  + (- 3A b  - 48B a b )c
+--R                 + 
+--R                       5 2
+--R                   6B b c
+--R              *
+--R                  2 2
+--R                 d f
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       4   2        3 3        2 5  4
+--R               (- 48A a b c  + 24A a b c - 3A a b )f
+--R             + 
+--R                        3   3        3 2 2             5        2 4         7
+--R                   96A a b c  - 96B a b c  + (- 18A a b  + 48B a b )c + 3A b
+--R                 + 
+--R                           6
+--R                   - 6B a b
+--R              *
+--R                    3
+--R                 d f
+--R             + 
+--R                          2   4           3        2 2  3
+--R                   - 48A a b c  + (24A a b  + 96B a b )c
+--R                 + 
+--R                          5          4  2       6
+--R                   (- 3A b  - 48B a b )c  + 6B b c
+--R              *
+--R                  2 2
+--R                 d f
+--R          *
+--R             x
+--R         + 
+--R                   5 2        4 2        3 4  4
+--R           (- 48A a c  + 24A a b c - 3A a b )f
+--R         + 
+--R                    4 3        4   2           2 4        3 3           6
+--R               96A a c  - 96B a b c  + (- 18A a b  + 48B a b )c + 3A a b
+--R             + 
+--R                     2 5
+--R               - 6B a b
+--R          *
+--R                3
+--R             d f
+--R         + 
+--R                      3 4         2 2        3   3            4        2 3  2
+--R               - 48A a c  + (24A a b  + 96B a b)c  + (- 3A a b  - 48B a b )c
+--R             + 
+--R                     5
+--R               6B a b c
+--R          *
+--R              2 2
+--R             d f
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                           3 4          2 2        3   3
+--R                   - 160A a c  + (152A a b  - 80B a b)c
+--R                 + 
+--R                             4        2 3  2
+--R                   (- 24A a b  + 12B a b )c
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                         2 5              2        2   4         4          3  3
+--R                   384A a c  + (- 176A a b  - 64B a b)c  + (32A b  + 40B a b )c
+--R                 + 
+--R                          5 2
+--R                   - 12B b c
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                          6          2             5        3 4  2
+--R               (- 288A a c  + (120A b  + 176B a b)c  - 68B b c )d f
+--R             + 
+--R                     7          6  3
+--R               (64A c  - 32B b c )d
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                            3         4  3          2 3         3 2  2
+--R                   (- 432A a b + 96B a )c  + (324A a b  - 168B a b )c
+--R                 + 
+--R                             5        2 4
+--R                   (- 48A a b  + 24B a b )c
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                          2          3  4              3        2 2  3
+--R                   (768A a b - 192B a )c  + (- 360A a b  - 96B a b )c
+--R                 + 
+--R                         5          4  2        6
+--R                   (60A b  + 96B a b )c  - 24B b c
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                                   2  5          3           2  4        4 3  2
+--R               ((- 432A a b + 96B a )c  + (180A b  + 216B a b )c  - 96B b c )d f
+--R             + 
+--R                       6        2 5  3
+--R               (96A b c  - 48B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                           4 3        3 2 2          2 4        3 3            6
+--R                   - 192A a c  - 96A a b c  + (144A a b  - 72B a b )c - 24A a b
+--R                 + 
+--R                        2 5
+--R                   12B a b
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                         3 4          2 2         3   3
+--R                   480A a c  + (120A a b  - 240B a b)c
+--R                 + 
+--R                              4        2 3  2         6          5          7
+--R                   (- 120A a b  - 12B a b )c  + (24A b  + 48B a b )c - 12B b
+--R              *
+--R                    2
+--R                 d f
+--R             + 
+--R                           2 5           2         2   4         4          3  3
+--R                   - 384A a c  + (48A a b  + 288B a b)c  + (48A b  - 48B a b )c
+--R                 + 
+--R                          5 2
+--R                   - 24B b c
+--R              *
+--R                  2
+--R                 d f
+--R             + 
+--R                       6         2            5        3 4  3
+--R               (96A a c  + (24A b  - 48B a b)c  - 12B b c )d
+--R          *
+--R             x
+--R         + 
+--R                        4          5  2          3 3         4 2          2 5
+--R               (- 320A a b + 128B a )c  + (200A a b  - 112B a b )c - 28A a b
+--R             + 
+--R                    3 4
+--R               16B a b
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                      3          4  3            2 3        3 2  2
+--R               (496A a b - 288B a )c  + (- 292A a b  + 56B a b )c
+--R             + 
+--R                       5        2 4         7         6
+--R               (64A a b  + 24B a b )c - 4A b  - 8B a b
+--R          *
+--R                2
+--R             d f
+--R         + 
+--R                        2          3  4            3        2 2  3
+--R               (- 224A a b + 192B a )c  + (112A a b  - 32B a b )c
+--R             + 
+--R                      5          4  2
+--R               (- 8A b  - 16B a b )c
+--R          *
+--R              2
+--R             d f
+--R         + 
+--R                            2  5          3         2  4  3
+--R           ((48A a b - 32B a )c  + (- 4A b  - 8B a b )c )d
+--R      *
+--R                +-------------------------+ +-----------------------+
+--R          +---+ |    +---+ +-+              |  +---+ +-+
+--R         \|- d \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                 6 3      5 2 2     4 4   4
+--R             (96a c  - 48a b c  + 6a b c)f
+--R           + 
+--R                    5 4       4 2 3       3 4 2      2 6     3
+--R             (- 384a c  + 384a b c  - 120a b c  + 12a b c)d f
+--R           + 
+--R                  4 5       3 2 4       2 4 3        6 2     8   2 2
+--R             (576a c  - 672a b c  + 324a b c  - 72a b c  + 6b c)d f
+--R           + 
+--R                    3 6       2 2 5         4 4      6 3  3
+--R             (- 384a c  + 384a b c  - 120a b c  + 12b c )d f
+--R           + 
+--R                 2 7        2 6     4 5  4
+--R             (96a c  - 48a b c  + 6b c )d
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                 6   2      5 3      4 5  4
+--R             (96a b c  - 48a b c + 6a b )f
+--R           + 
+--R                    5   3       4 3 2       3 5       2 7    3
+--R             (- 384a b c  + 384a b c  - 120a b c + 12a b )d f
+--R           + 
+--R                  4   4       3 3 3       2 5 2        7      9  2 2
+--R             (576a b c  - 672a b c  + 324a b c  - 72a b c + 6b )d f
+--R           + 
+--R                    3   5       2 3 4         5 3      7 2  3
+--R             (- 384a b c  + 384a b c  - 120a b c  + 12b c )d f
+--R           + 
+--R                 2   6        3 5     5 4  4
+--R             (96a b c  - 48a b c  + 6b c )d
+--R        *
+--R           x
+--R       + 
+--R             7 2      6 2      5 4  4
+--R         (96a c  - 48a b c + 6a b )f
+--R       + 
+--R                6 3       5 2 2       4 4       3 6    3
+--R         (- 384a c  + 384a b c  - 120a b c + 12a b )d f
+--R       + 
+--R              5 4       4 2 3       3 4 2      2 6        8  2 2
+--R         (576a c  - 672a b c  + 324a b c  - 72a b c + 6a b )d f
+--R       + 
+--R                4 5       3 2 4       2 4 3        6 2  3
+--R         (- 384a c  + 384a b c  - 120a b c  + 12a b c )d f
+--R       + 
+--R             3 6      2 2 5       4 4  4
+--R         (96a c  - 48a b c  + 6a b c )d
+--R    *
+--R              +--------------+ +-------------------------+
+--R        +---+ |   2            |    +---+ +-+
+--R       \|- d \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 207
+
+--S 208 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 208
+
+)clear all
+
+--S 209 of 286
+t0:=(A+B*x)*(a+b*x+c*x^2)/(d+e*x+f*x^2)
+--R 
+--R
+--R             3               2
+--R        B c x  + (A c + B b)x  + (A b + B a)x + A a
+--R   (1)  -------------------------------------------
+--R                          2
+--R                       f x  + e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 209
+
+--S 210 of 286
+r0:=-(B*c*e-b*B*f-A*c*f)*x/f^2+1/2*B*c*x^2/f-1/2*(A*f*(c*e-b*f)-_
+   B*(c*e^2-c*d*f-b*e*f+a*f^2))*log(d+e*x+f*x^2)/f^3-(A*f*(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2)+B*(f*(b*e^2-2*b*d*f-a*e*f)-c*(e^3-3*d*e*f)))*_
+   atanh((e+2*f*x)/sqrt(e^2-4*d*f))/(f^3*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R                   3                                     2
+--R           - 4A a f  + ((2A b + 2B a)e + (4A c + 4B b)d)f
+--R         + 
+--R                            2                      3
+--R           ((- 2A c - 2B b)e  - 6B c d e)f + 2B c e
+--R      *
+--R                  2f x + e
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4d f + e
+--R     + 
+--R                          2                                    2
+--R             ((A b + B a)f  + ((- A c - B b)e - B c d)f + B c e )
+--R          *
+--R                    2
+--R             log(f x  + e x + d)
+--R         + 
+--R                2 2                  2
+--R           B c f x  + ((2A c + 2B b)f  - 2B c e f)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4d f + e
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     2f \|- 4d f + e
+--R                                                    Type: Expression(Integer)
+--E 210
+
+--S 211 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 211
+
+)clear all
+
+--S 212 of 286
+t0:=(A+B*x)*(a+b*x+c*x^2)^2/(d+e*x+f*x^2)
+--R 
+--R
+--R   (1)
+--R          2 5       2           4                        2  3
+--R       B c x  + (A c  + 2B b c)x  + ((2A b + 2B a)c + B b )x
+--R     + 
+--R                    2           2                2        2
+--R       (2A a c + A b  + 2B a b)x  + (2A a b + B a )x + A a
+--R  /
+--R        2
+--R     f x  + e x + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 212
+
+--S 213 of 286
+r0:=(B*(c*e-b*f)*(f*(b*e-2*a*f)-c*(e^2-2*d*f))+A*f*(b^2*f^2-_
+   2*c*f*(b*e-a*f)+c^2*(e^2-d*f)))*x/f^4-1/2*(A*c*f*(c*e-2*b*f)-_
+   B*(b^2*f^2-2*c*f*(b*e-a*f)+c^2*(e^2-d*f)))*x^2/f^3-1/3*c*(B*c*e-_
+   2*b*B*f-A*c*f)*x^3/f^2+1/4*B*c^2*x^4/f+1/2*(A*f*(c*e-b*f)*(f*_
+   (b*e-2*a*f)-c*(e^2-2*d*f))+B*(c^2*(e^4-3*d*e^2*f+d^2*f^2)-_
+   f^2*(2*a*b*e*f-a^2*f^2-b^2*(e^2-d*f))+2*c*f*(a*f*(e^2-d*f)-_
+   b*(e^3-2*d*e*f))))*log(d+e*x+f*x^2)/f^5-(A*f*(c^2*(e^4-4*d*e^2*f+_
+   2*d^2*f^2)-f^2*(2*a*b*e*f-2*a^2*f^2-b^2*(e^2-2*d*f))+2*c*f*(a*f*_
+   (e^2-2*d*f)-b*(e^3-3*d*e*f)))-B*(c^2*(e^5-5*d*e^3*f+5*d^2*e*f^2)+_
+   f^2*(a^2*e*f^2-2*a*b*f*(e^2-2*d*f)+b^2*(e^3-3*d*e*f))+2*c*f*(a*e*f*_
+   (e^2-3*d*f)-b*(e^4-4*d*e^2*f+2*d^2*f^2))))*atanh((e+2*f*x)/_
+   sqrt(e^2-4*d*f))/(f^5*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R                  2 5                    2                     2              4
+--R           - 24A a f  + ((24A a b + 12B a )e + (48A a c + 24A b  + 48B a b)d)f
+--R         + 
+--R                                 2            2
+--R               (- 24A a c - 12A b  - 24B a b)e
+--R             + 
+--R                                          2               2            2
+--R               ((- 72A b - 72B a)c - 36B b )d e + (- 24A c  - 48B b c)d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                                          2  3         2              2
+--R                 ((24A b + 24B a)c + 12B b )e  + (48A c  + 96B b c)d e
+--R               + 
+--R                      2 2
+--R                 60B c d e
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                    2            4        2   3          2 5
+--R           ((- 12A c  - 24B b c)e  - 60B c d e )f + 12B c e
+--R      *
+--R                  2f x + e
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4d f + e
+--R     + 
+--R                              2  4
+--R               (12A a b + 6B a )f
+--R             + 
+--R                                      2
+--R                     (- 12A a c - 6A b  - 12B a b)e
+--R                   + 
+--R                                               2
+--R                     ((- 12A b - 12B a)c - 6B b )d
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                                             2  2         2
+--R                     ((12A b + 12B a)c + 6B b )e  + (12A c  + 24B b c)d e
+--R                   + 
+--R                         2 2
+--R                     6B c d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                       2            3        2   2         2 4
+--R               ((- 6A c  - 12B b c)e  - 18B c d e )f + 6B c e
+--R          *
+--R                    2
+--R             log(f x  + e x + d)
+--R         + 
+--R               2 4 4         2           4       2   3  3
+--R           3B c f x  + ((4A c  + 8B b c)f  - 4B c e f )x
+--R         + 
+--R                                       2  4           2                   2   3
+--R               ((12A b + 12B a)c + 6B b )f  + ((- 6A c  - 12B b c)e - 6B c d)f
+--R             + 
+--R                   2 2 2
+--R               6B c e f
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                               2            4
+--R               (24A a c + 12A b  + 24B a b)f
+--R             + 
+--R                                           2             2              3
+--R               (((- 24A b - 24B a)c - 12B b )e + (- 12A c  - 24B b c)d)f
+--R             + 
+--R                      2            2        2     2        2 3
+--R               ((12A c  + 24B b c)e  + 24B c d e)f  - 12B c e f
+--R          *
+--R             x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4d f + e
+--R  /
+--R          +-----------+
+--R        5 |          2
+--R     12f \|- 4d f + e
+--R                                                    Type: Expression(Integer)
+--E 213
+
+--S 214 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 214
+
+)clear all
+
+--S 215 of 286
+t0:=(A+B*x)/((a+b*x+c*x^2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                     B x + A
+--R   (1)  -----------------------------------------------------------------
+--R             4               3                     2
+--R        c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 215
+
+--S 216 of 286
+r0:=1/2*(B*c*d-A*c*e+A*b*f-a*B*f)*log(a+b*x+c*x^2)/(c^2*d^2+_
+   f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))-1/2*(B*c*d-A*c*e+_
+   A*b*f-a*B*f)*log(d+e*x+f*x^2)/(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))-(A*b^2*f+2*c*(A*c*d+a*B*e-a*A*f)-_
+   b*(B*c*d+A*c*e+a*B*f))*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/((c^2*d^2+_
+   f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(b^2-4*a*c))+_
+   (B*(c*d*e-2*b*d*f+a*e*f)-A*(c*e^2-2*c*d*f-b*e*f+2*a*f^2))*_
+   atanh((e+2*f*x)/sqrt(e^2-4*d*f))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R                  2                                              2
+--R         (- 4A a f  + ((2A b + 2B a)e + (4A c - 4B b)d)f - 2A c e  + 2B c d e)
+--R      *
+--R          +-----------+
+--R          |          2          2f x + e
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4d f + e
+--R     + 
+--R                        2                                        2
+--R         ((4A a c - 2A b  + 2B a b)f + (2A b - 4B a)c e + (- 4A c  + 2B b c)d)
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4d f + e  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                                  2
+--R           ((- A b + B a)f + A c e - B c d)log(f x  + e x + d)
+--R         + 
+--R                                                2
+--R           ((A b - B a)f - A c e + B c d)log(c x  + b x + a)
+--R      *
+--R          +-----------+ +-----------+
+--R          |          2  |          2
+--R         \|- 4d f + e  \|- 4a c + b
+--R  /
+--R          2 2                           2             2                2 2
+--R       (2a f  + (- 2a b e + (- 4a c + 2b )d)f + 2a c e  - 2b c d e + 2c d )
+--R    *
+--R        +-----------+ +-----------+
+--R        |          2  |          2
+--R       \|- 4d f + e  \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 216
+
+--S 217 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 217
+
+)clear all
+
+--S 218 of 286
+t0:=(A+B*x)/((a+b*x+c*x^2)^2*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R        2   6              2   5             2               2   4
+--R       c f x  + (2b c f + c e)x  + ((2a c + b )f + 2b c e + c d)x
+--R     + 
+--R                          2             3     2                      2    2
+--R       (2a b f + (2a c + b )e + 2b c d)x  + (a f + 2a b e + (2a c + b )d)x
+--R     + 
+--R         2                2
+--R       (a e + 2a b d)x + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 218
+
+--S 219 of 286
+r0:=(A*(b^2*c*e-2*a*c^2*e-b^3*f-b*c*(c*d-3*a*f))+a*B*(2*c^2*d+b^2*f-_
+   c*(b*e+2*a*f))-c*(A*b^2*f+2*c*(A*c*d+a*B*e-a*A*f)-b*(B*c*d+A*c*e+_
+   a*B*f))*x)/((b^2-4*a*c)*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))*(a+b*x+c*x^2))+2*c*(A*b^2*f+2*c*(A*c*d+a*B*e-a*A*f)-_
+   b*(B*c*d+A*c*e+a*B*f))*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)^(3/2)*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f))))+1/2*(A*(c*e-b*f)*(f*(b*e-2*a*f)-c*(e^2-2*d*f))-_
+   B*(2*c*d*f*(b*e-a*f)-f^2*(b^2*d-a^2*f)-c^2*d*(e^2-d*f)))*_
+   log(a+b*x+c*x^2)/(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))^2-1/2*(A*(c*e-b*f)*(f*(b*e-2*a*f)-c*(e^2-2*d*f))-_
+   B*(2*c*d*f*(b*e-a*f)-f^2*(b^2*d-a^2*f)-c^2*d*(e^2-d*f)))*_
+   log(d+e*x+f*x^2)/(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))^2+(B*(2*c^3*d^2*e-b*f^2*(b^2*d-a^2*f)-_
+   b*c^2*d*(e^2+3*d*f)+2*c*f*(b^2*d*e+a*b*d*f-a^2*e*f))+_
+   A*(b^2*f^2*(b*e-2*a*f)-2*c^3*d*(e^2-d*f)-2*c*f*(b^2*e^2-a*b*e*f-_
+   a^2*f^2)+c^2*(b*e^3+2*b*d*e*f-4*a*d*f^2)))*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))^2*sqrt(b^2-4*a*c))+(B*(c^2*d*e*(e^2-3*d*f)-_
+   2*c*d*f*(b*e^2-2*b*d*f-a*e*f)+f^2*(b^2*d*e-4*a*b*d*f+a^2*e*f))-_
+   A*(c^2*(e^4-4*d*e^2*f+2*d^2*f^2)-f^2*(2*a*b*e*f-2*a^2*f^2-_
+   b^2*(e^2-2*d*f))+2*c*f*(a*f*(e^2-2*d*f)-b*(e^3-3*d*e*f))))*_
+   atanh((e+2*f*x)/sqrt(e^2-4*d*f))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))^2*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R                       3 2       2 2   4
+--R               (- 16A a c  + 4A a b c)f
+--R             + 
+--R                          2        3  2            3       2 2
+--R                   ((16A a b + 8B a )c  + (- 4A a b  - 2B a b )c)e
+--R                 + 
+--R                         2 3          2        2   2          4         3
+--R                   (32A a c  + (8A a b  - 32B a b)c  + (- 4A b  + 8B a b )c)d
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                           2 3         2 2       4   2
+--R                   (- 16A a c  - 4A a b c  + 2A b c)e
+--R                 + 
+--R                                      2  3         3         2  2       4
+--R                   ((- 48A a b + 16B a )c  + (12A b  + 4B a b )c  - 2B b c)d e
+--R                 + 
+--R                             4        2            3       3 2  2
+--R                   (- 16A a c  + (4A b  + 32B a b)c  - 8B b c )d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                             3       3 2  3
+--R                   (16A a b c  - 4A b c )e
+--R                 + 
+--R                           4          2            3       3 2    2
+--R                   (32A a c  + (- 8A b  - 16B a b)c  + 4B b c )d e
+--R                 + 
+--R                             4       2 3  2
+--R                   (- 24B a c  + 6B b c )d e
+--R              *
+--R                 f
+--R             + 
+--R                        4       2 3  4          4       2 3    3
+--R               (- 8A a c  + 2A b c )e  + (8B a c  - 2B b c )d e
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                       3          2 3  4
+--R               (- 16A a b c + 4A a b )f
+--R             + 
+--R                          2 2       3            4       2 3
+--R                   ((16A a b  + 8B a b)c - 4A a b  - 2B a b )e
+--R                 + 
+--R                         2   2          3        2 2         5         4
+--R                   (32A a b c  + (8A a b  - 32B a b )c - 4A b  + 8B a b )d
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                           2   2         3        5  2
+--R                   (- 16A a b c  - 4A a b c + 2A b )e
+--R                 + 
+--R                              2        2   2         4         3         5
+--R                   ((- 48A a b  + 16B a b)c  + (12A b  + 4B a b )c - 2B b )d e
+--R                 + 
+--R                               3        3          2  2       4   2
+--R                   (- 16A a b c  + (4A b  + 32B a b )c  - 8B b c)d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                           2 2       4   3
+--R                   (16A a b c  - 4A b c)e
+--R                 + 
+--R                             3          3          2  2       4     2
+--R                   (32A a b c  + (- 8A b  - 16B a b )c  + 4B b c)d e
+--R                 + 
+--R                               3       3 2  2
+--R                   (- 24B a b c  + 6B b c )d e
+--R              *
+--R                 f
+--R             + 
+--R                          3       3 2  4            3       3 2    3
+--R               (- 8A a b c  + 2A b c )e  + (8B a b c  - 2B b c )d e
+--R          *
+--R             x
+--R         + 
+--R                   4        3 2  4
+--R           (- 16A a c + 4A a b )f
+--R         + 
+--R                      3        4         2 3       3 2
+--R               ((16A a b + 8B a )c - 4A a b  - 2B a b )e
+--R             + 
+--R                     3 2        2 2        3            4       2 3
+--R               (32A a c  + (8A a b  - 32B a b)c - 4A a b  + 8B a b )d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                       3 2       2 2          4  2
+--R               (- 16A a c  - 4A a b c + 2A a b )e
+--R             + 
+--R                        2         3  2           3       2 2           4
+--R               ((- 48A a b + 16B a )c  + (12A a b  + 4B a b )c - 2B a b )d e
+--R             + 
+--R                       2 3          2        2   2         3   2
+--R               (- 16A a c  + (4A a b  + 32B a b)c  - 8B a b c)d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                     2   2         3   3
+--R               (16A a b c  - 4A a b c)e
+--R             + 
+--R                     2 3            2        2   2         3     2
+--R               (32A a c  + (- 8A a b  - 16B a b)c  + 4B a b c)d e
+--R             + 
+--R                       2 3         2 2  2
+--R               (- 24B a c  + 6B a b c )d e
+--R          *
+--R             f
+--R         + 
+--R                  2 3         2 2  4        2 3         2 2    3
+--R           (- 8A a c  + 2A a b c )e  + (8B a c  - 2B a b c )d e
+--R      *
+--R          +-----------+
+--R          |          2          2f x + e
+--R         \|- 4a c + b  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4d f + e
+--R     + 
+--R                     3 3           2 2        3   2          4       2 3    3
+--R               (24A a c  + (- 24A a b  + 12B a b)c  + (4A a b  - 2B a b )c)f
+--R             + 
+--R                          2         3  3         3 2       5
+--R                   ((12A a b - 24B a )c  + 8A a b c  - 2A b c)e
+--R                 + 
+--R                              2 4           2        2   3
+--R                       - 56A a c  + (24A a b  + 12B a b)c
+--R                     + 
+--R                              4         3  2       5
+--R                       (- 4A b  - 8B a b )c  + 2B b c
+--R                  *
+--R                     d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                        2 4             2        2   3       4 2  2
+--R                   (8A a c  + (- 24A a b  + 12B a b)c  + 4A b c )e
+--R                 + 
+--R                                   2  4       3 3       4 2
+--R                   ((8A a b + 16B a )c  + 4A b c  - 4B b c )d e
+--R                 + 
+--R                           5           2            4        3 3  2
+--R                   (40A a c  + (- 16A b  - 28B a b)c  + 10B b c )d
+--R              *
+--R                 f
+--R             + 
+--R                               2  4       3 3  3
+--R               ((12A a b - 8B a )c  - 2A b c )e
+--R             + 
+--R                         5           4       3 3    2
+--R               (- 24A a c  + 4B a b c  + 2B b c )d e
+--R             + 
+--R                               5       2 4  2           6         5  3
+--R               ((12A b + 8B a)c  - 8B b c )d e + (- 8A c  + 4B b c )d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                     3   2           2 3        3 2           5       2 4  3
+--R               (24A a b c  + (- 24A a b  + 12B a b )c + 4A a b  - 2B a b )f
+--R             + 
+--R                          2 2        3   2         4        6
+--R                   ((12A a b  - 24B a b)c  + 8A a b c - 2A b )e
+--R                 + 
+--R                              2   3           3        2 2  2
+--R                       - 56A a b c  + (24A a b  + 12B a b )c
+--R                     + 
+--R                              5         4         6
+--R                       (- 4A b  - 8B a b )c + 2B b
+--R                  *
+--R                     d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                        2   3             3        2 2  2       5   2
+--R                   (8A a b c  + (- 24A a b  + 12B a b )c  + 4A b c)e
+--R                 + 
+--R                           2        2   3       4 2       5
+--R                   ((8A a b  + 16B a b)c  + 4A b c  - 4B b c)d e
+--R                 + 
+--R                             4           3          2  3        4 2  2
+--R                   (40A a b c  + (- 16A b  - 28B a b )c  + 10B b c )d
+--R              *
+--R                 f
+--R             + 
+--R                        2       2   3       4 2  3
+--R               ((12A a b  - 8B a b)c  - 2A b c )e
+--R             + 
+--R                           4         2 3       4 2    2
+--R               (- 24A a b c  + 4B a b c  + 2B b c )d e
+--R             + 
+--R                      2           4       3 3  2             5       2 4  3
+--R               ((12A b  + 8B a b)c  - 8B b c )d e + (- 8A b c  + 4B b c )d
+--R          *
+--R             x
+--R         + 
+--R                 4 2           3 2        4          2 4       3 3  3
+--R           (24A a c  + (- 24A a b  + 12B a b)c + 4A a b  - 2B a b )f
+--R         + 
+--R                      3         4  2       2 3          5
+--R               ((12A a b - 24B a )c  + 8A a b c - 2A a b )e
+--R             + 
+--R                          3 3         2 2        3   2            4       2 3
+--R                   - 56A a c  + (24A a b  + 12B a b)c  + (- 4A a b  - 8B a b )c
+--R                 + 
+--R                         5
+--R                   2B a b
+--R              *
+--R                 d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                    3 3           2 2        3   2         4   2
+--R               (8A a c  + (- 24A a b  + 12B a b)c  + 4A a b c)e
+--R             + 
+--R                     2         3  3         3 2         4
+--R               ((8A a b + 16B a )c  + 4A a b c  - 4B a b c)d e
+--R             + 
+--R                     2 4             2        2   3          3 2  2
+--R               (40A a c  + (- 16A a b  - 28B a b)c  + 10B a b c )d
+--R          *
+--R             f
+--R         + 
+--R                  2        3  3         3 2  3
+--R           ((12A a b - 8B a )c  - 2A a b c )e
+--R         + 
+--R                   2 4       2   3         3 2    2
+--R           (- 24A a c  + 4B a b c  + 2B a b c )d e
+--R         + 
+--R                           2  4         2 3  2             5           4  3
+--R           ((12A a b + 8B a )c  - 8B a b c )d e + (- 8A a c  + 4B a b c )d
+--R      *
+--R          +-----------+
+--R          |          2          2c x + b
+--R         \|- 4d f + e  atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                           2        3  2          3      2 2    3
+--R                   ((- 8A a b + 4B a )c  + (2A a b  - B a b )c)f
+--R                 + 
+--R                            2 3         2 2      4
+--R                       (8A a c  + 2A a b c  - A b c)e
+--R                     + 
+--R                                      2  3          3         2  2      4
+--R                       ((8A a b - 8B a )c  + (- 2A b  - 2B a b )c  + B b c)d
+--R                  *
+--R                      2
+--R                     f
+--R                 + 
+--R                                  3       3 2  2
+--R                       (- 8A a b c  + 2A b c )e
+--R                     + 
+--R                                4        2           3       3 2
+--R                       (- 8A a c  + (2A b  + 8B a b)c  - 2B b c )d e
+--R                     + 
+--R                              4      2 3  2
+--R                       (4B a c  - B b c )d
+--R                  *
+--R                     f
+--R                 + 
+--R                          4      2 3  3            4      2 3    2
+--R                   (4A a c  - A b c )e  + (- 4B a c  + B b c )d e
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                           2 2       3            4      2 3  3
+--R                   ((- 8A a b  + 4B a b)c + 2A a b  - B a b )f
+--R                 + 
+--R                            2   2         3       5
+--R                       (8A a b c  + 2A a b c - A b )e
+--R                     + 
+--R                               2       2   2          4         3        5
+--R                       ((8A a b  - 8B a b)c  + (- 2A b  - 2B a b )c + B b )d
+--R                  *
+--R                      2
+--R                     f
+--R                 + 
+--R                                2 2       4   2
+--R                       (- 8A a b c  + 2A b c)e
+--R                     + 
+--R                                  3        3         2  2       4
+--R                       (- 8A a b c  + (2A b  + 8B a b )c  - 2B b c)d e
+--R                     + 
+--R                                3      3 2  2
+--R                       (4B a b c  - B b c )d
+--R                  *
+--R                     f
+--R                 + 
+--R                            3      3 2  3              3      3 2    2
+--R                   (4A a b c  - A b c )e  + (- 4B a b c  + B b c )d e
+--R              *
+--R                 x
+--R             + 
+--R                       3        4         2 3      3 2  3
+--R               ((- 8A a b + 4B a )c + 2A a b  - B a b )f
+--R             + 
+--R                        3 2       2 2         4
+--R                   (8A a c  + 2A a b c - A a b )e
+--R                 + 
+--R                         2        3  2            3       2 2          4
+--R                   ((8A a b - 8B a )c  + (- 2A a b  - 2B a b )c + B a b )d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                          2   2         3   2
+--R                   (- 8A a b c  + 2A a b c)e
+--R                 + 
+--R                          2 3          2       2   2         3
+--R                   (- 8A a c  + (2A a b  + 8B a b)c  - 2B a b c)d e
+--R                 + 
+--R                        2 3        2 2  2
+--R                   (4B a c  - B a b c )d
+--R              *
+--R                 f
+--R             + 
+--R                    2 3        2 2  3          2 3        2 2    2
+--R               (4A a c  - A a b c )e  + (- 4B a c  + B a b c )d e
+--R          *
+--R                    2
+--R             log(f x  + e x + d)
+--R         + 
+--R                         2        3  2            3      2 2    3
+--R                   ((8A a b - 4B a )c  + (- 2A a b  + B a b )c)f
+--R                 + 
+--R                              2 3         2 2      4
+--R                       (- 8A a c  - 2A a b c  + A b c)e
+--R                     + 
+--R                                        2  3        3         2  2      4
+--R                       ((- 8A a b + 8B a )c  + (2A b  + 2B a b )c  - B b c)d
+--R                  *
+--R                      2
+--R                     f
+--R                 + 
+--R                                3       3 2  2
+--R                       (8A a b c  - 2A b c )e
+--R                     + 
+--R                              4          2           3       3 2
+--R                       (8A a c  + (- 2A b  - 8B a b)c  + 2B b c )d e
+--R                     + 
+--R                                4      2 3  2
+--R                       (- 4B a c  + B b c )d
+--R                  *
+--R                     f
+--R                 + 
+--R                            4      2 3  3          4      2 3    2
+--R                   (- 4A a c  + A b c )e  + (4B a c  - B b c )d e
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                         2 2       3            4      2 3  3
+--R                   ((8A a b  - 4B a b)c - 2A a b  + B a b )f
+--R                 + 
+--R                              2   2         3       5
+--R                       (- 8A a b c  - 2A a b c + A b )e
+--R                     + 
+--R                                 2       2   2        4         3        5
+--R                       ((- 8A a b  + 8B a b)c  + (2A b  + 2B a b )c - B b )d
+--R                  *
+--R                      2
+--R                     f
+--R                 + 
+--R                              2 2       4   2
+--R                       (8A a b c  - 2A b c)e
+--R                     + 
+--R                                3          3         2  2       4
+--R                       (8A a b c  + (- 2A b  - 8B a b )c  + 2B b c)d e
+--R                     + 
+--R                                  3      3 2  2
+--R                       (- 4B a b c  + B b c )d
+--R                  *
+--R                     f
+--R                 + 
+--R                              3      3 2  3            3      3 2    2
+--R                   (- 4A a b c  + A b c )e  + (4B a b c  - B b c )d e
+--R              *
+--R                 x
+--R             + 
+--R                     3        4         2 3      3 2  3
+--R               ((8A a b - 4B a )c - 2A a b  + B a b )f
+--R             + 
+--R                          3 2       2 2         4
+--R                   (- 8A a c  - 2A a b c + A a b )e
+--R                 + 
+--R                           2        3  2          3       2 2          4
+--R                   ((- 8A a b + 8B a )c  + (2A a b  + 2B a b )c - B a b )d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                        2   2         3   2
+--R                   (8A a b c  - 2A a b c)e
+--R                 + 
+--R                        2 3            2       2   2         3
+--R                   (8A a c  + (- 2A a b  - 8B a b)c  + 2B a b c)d e
+--R                 + 
+--R                          2 3        2 2  2
+--R                   (- 4B a c  + B a b c )d
+--R              *
+--R                 f
+--R             + 
+--R                      2 3        2 2  3        2 3        2 2    2
+--R               (- 4A a c  + A a b c )e  + (4B a c  - B a b c )d e
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                      3 2        2 2       3     3
+--R               (- 4A a c  + (2A a b  - 2B a b)c)f
+--R             + 
+--R                         2        3  2            3       2 2
+--R                   ((2A a b + 4B a )c  + (- 2A a b  + 2B a b )c)e
+--R                 + 
+--R                         2 3            2       2   2        4         3
+--R                   (12A a c  + (- 8A a b  + 2B a b)c  + (2A b  - 2B a b )c)d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                          2 3          2       2   2  2
+--R                   (- 4A a c  + (4A a b  - 6B a b)c )e
+--R                 + 
+--R                                  2  3          3         2  2
+--R                   ((4A a b - 8B a )c  + (- 4A b  + 8B a b )c )d e
+--R                 + 
+--R                             4        2           3       3 2  2
+--R                   (- 12A a c  + (6A b  + 2B a b)c  - 2B b c )d
+--R              *
+--R                 f
+--R             + 
+--R                               2  3 3          4        2           3    2
+--R               (- 2A a b + 4B a )c e  + (4A a c  + (2A b  - 6B a b)c )d e
+--R             + 
+--R                                4       2 3  2         5         4  3
+--R               ((- 6A b + 4B a)c  + 2B b c )d e + (4A c  - 2B b c )d
+--R          *
+--R             x
+--R         + 
+--R                   3        4         2 3       3 2  3
+--R           ((- 6A a b + 4B a )c + 2A a b  - 2B a b )f
+--R         + 
+--R                    3 2        2 2       3            4       2 3
+--R               (4A a c  + (4A a b  - 2B a b)c - 2A a b  + 2B a b )e
+--R             + 
+--R                    2         3  2             3       2 2         5         4
+--R             ((14A a b - 12B a )c  + (- 10A a b  + 8B a b )c + 2A b  - 2B a b )d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                        2        3  2          3       2 2    2
+--R               ((- 10A a b + 4B a )c  + (4A a b  - 4B a b )c)e
+--R             + 
+--R                      2 3           2       2   2          4         3
+--R               (- 8A a c  + (12A a b  - 4B a b)c  + (- 4A b  + 4B a b )c)d e
+--R             + 
+--R                                  2  3        3         2  2  2
+--R               ((- 10A a b + 12B a )c  + (4A b  - 6B a b )c )d
+--R          *
+--R             f
+--R         + 
+--R                2 3            2       2   2  3
+--R           (4A a c  + (- 2A a b  + 2B a b)c )e
+--R         + 
+--R                            2  3        3         2  2    2
+--R           ((- 2A a b - 4B a )c  + (2A b  - 2B a b )c )d e
+--R         + 
+--R                  4          2           3  2                  4 3
+--R           (4A a c  + (- 4A b  + 6B a b)c )d e + (2A b - 4B a)c d
+--R      *
+--R          +-----------+ +-----------+
+--R          |          2  |          2
+--R         \|- 4d f + e  \|- 4a c + b
+--R  /
+--R                5 2     4 2   4
+--R             (8a c  - 2a b c)f
+--R           + 
+--R                    4   2     3 3            4 3      3 2 2     2 4     3
+--R             ((- 16a b c  + 4a b c)e + (- 32a c  + 24a b c  - 4a b c)d)f
+--R           + 
+--R                     4 3     3 2 2     2 4   2
+--R                 (16a c  + 4a b c  - 2a b c)e
+--R               + 
+--R                     3   3      2 3 2       5
+--R                 (16a b c  - 20a b c  + 4a b c)d e
+--R               + 
+--R                     3 4      2 2 3        4 2     6   2
+--R                 (48a c  - 44a b c  + 16a b c  - 2b c)d
+--R            *
+--R                2
+--R               f
+--R           + 
+--R                       3   3     2 3 2  3         3 4      2 2 3       4 2    2
+--R                 (- 16a b c  + 4a b c )e  + (- 32a c  + 40a b c  - 8a b c )d e
+--R               + 
+--R                     2   4        3 3     5 2  2
+--R                 (16a b c  - 20a b c  + 4b c )d e
+--R               + 
+--R                       2 5        2 4     4 3  3
+--R                 (- 32a c  + 24a b c  - 4b c )d
+--R            *
+--R               f
+--R           + 
+--R                3 4     2 2 3  4         2   4       3 3    3
+--R             (8a c  - 2a b c )e  + (- 16a b c  + 4a b c )d e
+--R           + 
+--R                 2 5       2 4     4 3  2 2             5     3 4  3
+--R             (16a c  + 4a b c  - 2b c )d e  + (- 16a b c  + 4b c )d e
+--R           + 
+--R                  6     2 5  4
+--R             (8a c  - 2b c )d
+--R        *
+--R            2
+--R           x
+--R       + 
+--R                5        4 3  4
+--R             (8a b c - 2a b )f
+--R           + 
+--R                    4 2      3 4           4   2      3 3      2 5    3
+--R             ((- 16a b c + 4a b )e + (- 32a b c  + 24a b c - 4a b )d)f
+--R           + 
+--R                     4   2     3 3      2 5  2       3 2 2      2 4        6
+--R                 (16a b c  + 4a b c - 2a b )e  + (16a b c  - 20a b c + 4a b )d e
+--R               + 
+--R                     3   3      2 3 2        5      7  2
+--R                 (48a b c  - 44a b c  + 16a b c - 2b )d
+--R            *
+--R                2
+--R               f
+--R           + 
+--R                       3 2 2     2 4   3         3   3      2 3 2       5     2
+--R                 (- 16a b c  + 4a b c)e  + (- 32a b c  + 40a b c  - 8a b c)d e
+--R               + 
+--R                     2 2 3        4 2     6   2
+--R                 (16a b c  - 20a b c  + 4b c)d e
+--R               + 
+--R                       2   4        3 3     5 2  3
+--R                 (- 32a b c  + 24a b c  - 4b c )d
+--R            *
+--R               f
+--R           + 
+--R                3   3     2 3 2  4         2 2 3       4 2    3
+--R             (8a b c  - 2a b c )e  + (- 16a b c  + 4a b c )d e
+--R           + 
+--R                 2   4       3 3     5 2  2 2           2 4     4 3  3
+--R             (16a b c  + 4a b c  - 2b c )d e  + (- 16a b c  + 4b c )d e
+--R           + 
+--R                    5     3 4  4
+--R             (8a b c  - 2b c )d
+--R        *
+--R           x
+--R       + 
+--R            6      5 2  4
+--R         (8a c - 2a b )f
+--R       + 
+--R                5        4 3           5 2      4 2      3 4    3
+--R         ((- 16a b c + 4a b )e + (- 32a c  + 24a b c - 4a b )d)f
+--R       + 
+--R                 5 2     4 2      3 4  2       4   2      3 3      2 5
+--R             (16a c  + 4a b c - 2a b )e  + (16a b c  - 20a b c + 4a b )d e
+--R           + 
+--R                 4 3      3 2 2      2 4        6  2
+--R             (48a c  - 44a b c  + 16a b c - 2a b )d
+--R        *
+--R            2
+--R           f
+--R       + 
+--R                   4   2     3 3   3         4 3      3 2 2     2 4     2
+--R             (- 16a b c  + 4a b c)e  + (- 32a c  + 40a b c  - 8a b c)d e
+--R           + 
+--R               3   3      2 3 2       5   2          3 4      2 2 3       4 2  3
+--R           (16a b c  - 20a b c  + 4a b c)d e + (- 32a c  + 24a b c  - 4a b c )d
+--R        *
+--R           f
+--R       + 
+--R            4 3     3 2 2  4         3   3     2 3 2    3
+--R         (8a c  - 2a b c )e  + (- 16a b c  + 4a b c )d e
+--R       + 
+--R             3 4     2 2 3       4 2  2 2         2   4       3 3  3
+--R         (16a c  + 4a b c  - 2a b c )d e  + (- 16a b c  + 4a b c )d e
+--R       + 
+--R            2 5       2 4  4
+--R         (8a c  - 2a b c )d
+--R    *
+--R        +-----------+ +-----------+
+--R        |          2  |          2
+--R       \|- 4d f + e  \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 220
+
+)clear all
+
+--S 221 of 286
+t0:=(A+B*x)*(a+b*x+c*x^2)^(1/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R                  +--------------+
+--R                  |   2
+--R        (B x + A)\|c x  + b x + a
+--R   (1)  --------------------------
+--R                 2
+--R              f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 286
+r0:=-1/2*(2*B*c*e-b*B*f-2*A*c*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/(f^2*sqrt(c))+B*sqrt(a+b*x+c*x^2)/f+_
+   atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-_
+   b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*_
+   (2*f*(A*f*(c*d-a*f)-B*d*(c*e-b*f))-(A*f*(c*e-b*f)+B*(f*(b*e-a*f)-_
+   c*(e^2-d*f)))*(e-sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*_
+   (e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*f*(A*f*(c*d-a*f)-_
+   B*d*(c*e-b*f))-(A*f*(c*e-b*f)+B*(f*(b*e-a*f)-c*(e^2-d*f)))*_
+   (e+sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                            2                                        2
+--R             ((2A b + 2B a)f  + ((- 2A c - 2B b)e - 2B c d)f + 2B c e )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                   3                                     2
+--R           - 4A a f  + ((2A b + 2B a)e + (4A c + 4B b)d)f
+--R         + 
+--R                            2                      3
+--R           ((- 2A c - 2B b)e  - 6B c d e)f + 2B c e
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|c \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                              2                                      2
+--R             ((- 2A b - 2B a)f  + ((2A c + 2B b)e + 2B c d)f - 2B c e )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                   3                                     2
+--R           - 4A a f  + ((2A b + 2B a)e + (4A c + 4B b)d)f
+--R         + 
+--R                            2                      3
+--R           ((- 2A c - 2B b)e  - 6B c d e)f + 2B c e
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|c \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                          +-----------+
+--R                                      +-+ |          2
+--R             ((2A c + B b)f - 2B c e)\|2 \|- 4d f + e
+--R          *
+--R                          2c x + b
+--R             atanh(----------------------)
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|c \|c x  + b x + a
+--R         + 
+--R                    +-----------+     +--------------+
+--R                +-+ |          2  +-+ |   2
+--R           2B f\|2 \|- 4d f + e  \|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R               +-----------+
+--R         2 +-+ |          2  +-+
+--R       2f \|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 223
+
+)clear all
+
+--S 224 of 286
+t0:=(A+B*x)*(a+b*x+c*x^2)^(3/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R                                                      +--------------+
+--R              3               2                       |   2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x + A a)\|c x  + b x + a
+--R   (1)  --------------------------------------------------------------
+--R                                   2
+--R                                f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 286
+r0:=1/3*B*(a+b*x+c*x^2)^(3/2)/f+1/16*(b^2-4*a*c)*(2*B*c*e-b*B*f-2*A*c*f)*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f^2)+_
+   1/2*(A*f*(b^2*f^2-c*f*(3*b*e-2*a*f)+2*c^2*(e^2-d*f))-B*(b*f^2*_
+   (b*e-a*f)-c*f*(3*b*e^2-3*b*d*f-2*a*e*f)+2*c^2*(e^3-2*d*e*f)))*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f^4*sqrt(c))-_
+   (A*f*(c*e-b*f)-B*(c*e^2-c*d*f-b*e*f+a*f^2))*sqrt(a+b*x+c*x^2)/f^3-_
+   1/8*(2*B*c*e-b*B*f-2*A*c*f)*(b+2*c*x)*sqrt(a+b*x+c*x^2)/(c*f^2)+_
+   atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-_
+   sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*f*(B*d*(c*e-b*f)*_
+   (f*(b*e-2*a*f)-c*(e^2-2*d*f))-A*f*(2*c*d*f*(b*e-a*f)-f^2*(b^2*d-_
+   a^2*f)-c^2*d*(e^2-d*f)))+(f*(c*e-b*f)*(A*f*(c*d-a*f)-B*d*(c*e-b*f))+_
+   (f*(b*e-a*f)-c*(e^2-d*f))*(A*f*(c*e-b*f)+B*(f*(b*e-a*f)-c*(e^2-d*f))))*_
+   (e-sqrt(e^2-4*d*f)))/(f^4*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-atanh(1/2*(4*a*f-b*_
+   (e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(2*f*(B*d*(c*e-b*f)*(f*(b*e-2*a*f)-c*(e^2-2*d*f))-_
+   A*f*(2*c*d*f*(b*e-a*f)-f^2*(b^2*d-a^2*f)-c^2*d*(e^2-d*f)))+_
+   (f*(c*e-b*f)*(A*f*(c*d-a*f)-B*d*(c*e-b*f))+(f*(b*e-a*f)-c*(e^2-d*f))*_
+   (A*f*(c*e-b*f)+B*(f*(b*e-a*f)-c*(e^2-d*f))))*(e+sqrt(e^2-4*d*f)))/_
+   (f^4*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                               2    4
+--R               (96A a b + 48B a )c f
+--R             + 
+--R                             2           2
+--R                   (- 96A a c  + (- 48A b  - 96B a b)c)e
+--R                 + 
+--R                                      2        2
+--R                   ((- 96A b - 96B a)c  - 48B b c)d
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                                    2        2   2         3           2
+--R                   ((96A b + 96B a)c  + 48B b c)e  + (96A c  + 192B b c )d e
+--R                 + 
+--R                        3 2
+--R                   48B c d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                        3          2  3         3   2          3 4
+--R               ((- 48A c  - 96B b c )e  - 144B c d e )f + 48B c e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2   5
+--R           - 96A a c f
+--R         + 
+--R                            2                2         2                 4
+--R           ((96A a b + 48B a )c e + (192A a c  + (96A b  + 192B a b)c)d)f
+--R         + 
+--R                         2           2              2
+--R               (- 96A a c  + (- 48A b  - 96B a b)c)e
+--R             + 
+--R                                    2         2                3           2  2
+--R               ((- 288A b - 288B a)c  - 144B b c)d e + (- 96A c  - 192B b c )d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                                2        2   3          3           2    2
+--R               ((96A b + 96B a)c  + 48B b c)e  + (192A c  + 384B b c )d e
+--R             + 
+--R                     3 2
+--R               240B c d e
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                    3          2  4         3   3          3 5
+--R           ((- 48A c  - 96B b c )e  - 240B c d e )f + 48B c e
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|c \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                 2    4
+--R               (- 96A a b - 48B a )c f
+--R             + 
+--R                           2         2
+--R                   (96A a c  + (48A b  + 96B a b)c)e
+--R                 + 
+--R                                    2        2
+--R                   ((96A b + 96B a)c  + 48B b c)d
+--R              *
+--R                  3
+--R                 f
+--R             + 
+--R                                      2        2   2           3           2
+--R                   ((- 96A b - 96B a)c  - 48B b c)e  + (- 96A c  - 192B b c )d e
+--R                 + 
+--R                          3 2
+--R                   - 48B c d
+--R              *
+--R                  2
+--R                 f
+--R             + 
+--R                      3          2  3         3   2          3 4
+--R               ((48A c  + 96B b c )e  + 144B c d e )f - 48B c e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2   5
+--R           - 96A a c f
+--R         + 
+--R                            2                2         2                 4
+--R           ((96A a b + 48B a )c e + (192A a c  + (96A b  + 192B a b)c)d)f
+--R         + 
+--R                         2           2              2
+--R               (- 96A a c  + (- 48A b  - 96B a b)c)e
+--R             + 
+--R                                    2         2                3           2  2
+--R               ((- 288A b - 288B a)c  - 144B b c)d e + (- 96A c  - 192B b c )d
+--R          *
+--R              3
+--R             f
+--R         + 
+--R                                2        2   3          3           2    2
+--R               ((96A b + 96B a)c  + 48B b c)e  + (192A c  + 384B b c )d e
+--R             + 
+--R                     3 2
+--R               240B c d e
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                    3          2  4         3   3          3 5
+--R           ((- 48A c  - 96B b c )e  - 240B c d e )f + 48B c e
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|c \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                       2         2                   3  3
+--R               (72A a c  + (18A b  + 36B a b)c - 3B b )f
+--R             + 
+--R                                   2        2              3          2    2
+--R               (((- 72A b - 72B a)c  - 18B b c)e + (- 48A c  - 72B b c )d)f
+--R             + 
+--R                      3          2  2        3             3 3
+--R               ((48A c  + 72B b c )e  + 96B c d e)f - 48B c e
+--R          *
+--R                  +-----------+
+--R              +-+ |          2              2c x + b
+--R             \|2 \|- 4d f + e  atanh(----------------------)
+--R                                           +--------------+
+--R                                       +-+ |   2
+--R                                     2\|c \|c x  + b x + a
+--R         + 
+--R                    2 3 2          2            3        2   2
+--R               16B c f x  + ((24A c  + 28B b c)f  - 24B c e f )x
+--R             + 
+--R                                       2  3
+--R               ((60A b + 64B a)c + 6B b )f
+--R             + 
+--R                        2                    2   2        2 2
+--R               ((- 48A c  - 60B b c)e - 48B c d)f  + 48B c e f
+--R          *
+--R                  +-----------+     +--------------+
+--R              +-+ |          2  +-+ |   2
+--R             \|2 \|- 4d f + e  \|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                  +-----------+
+--R            4 +-+ |          2  +-+
+--R       48c f \|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 225
+
+--S 226 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 226
+
+)clear all
+
+--S 227 of 286
+t0:=(A+B*x)/((a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                     B x + A
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 286
+r0:=-atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-_
+   b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*A*f-B*_
+   (e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))+atanh(1/2*(4*a*f-b*(e+_
+   sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(2*A*f-B*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R            +-----------+
+--R            |          2
+--R         (B\|- 4d f + e   - 2A f + B e)
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R              +-----------+
+--R              |          2
+--R         (- B\|- 4d f + e   - 2A f + B e)
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            +-----------+
+--R        +-+ |          2
+--R       \|2 \|- 4d f + e
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 228
+
+--S 229 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 229
+
+)clear all
+
+--S 230 of 286
+t0:=(A+B*x)/((a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R     B x + A
+--R  /
+--R             4               3                     2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 286
+r0:=2*(A*(b^2*c*e-2*a*c^2*e-b^3*f-b*c*(c*d-3*a*f))+a*B*(2*c^2*d+b^2*f-_
+   c*(b*e+2*a*f))-c*(A*b^2*f+2*c*(A*c*d+a*B*e-a*A*f)-b*(B*c*d+A*c*e+_
+   a*B*f))*x)/((b^2-4*a*c)*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))*sqrt(a+b*x+c*x^2))-f*atanh(1/2*(4*a*f+2*x*(b*f-_
+   c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(-2*(B*(c*d*e-b*d*f)+A*(f*(b*e-a*f)-c*(e^2-d*f)))+_
+   (B*c*d-A*c*e+A*b*f-a*B*f)*(e-sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-_
+   a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))+_
+   f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+_
+   sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(-2*(B*(c*d*e-b*d*f)+_
+   A*(f*(b*e-a*f)-c*(e^2-d*f)))+(B*c*d-A*c*e+A*b*f-a*B*f)*(e+_
+   sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-_
+   a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                2        3        2  2
+--R               ((- 4A a b + 4B a )c + A b  - B a b )f
+--R             + 
+--R                       2      2               2      2
+--R               ((4A a c  - A b c)e + (- 4B a c  + B b c)d)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2          2  3
+--R           (- 8A a c + 2A a b )f
+--R         + 
+--R                              2        3        2
+--R               ((4A a b + 4B a )c - A b  - B a b )e
+--R             + 
+--R                      2          2                  3
+--R               (8A a c  + (- 2A b  - 8B a b)c + 2B b )d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                     2      2   2          2      2
+--R           ((- 4A a c  + A b c)e  + (4B a c  - B b c)d e)f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                              2        3        2  2
+--R               ((4A a b - 4B a )c - A b  + B a b )f
+--R             + 
+--R                         2      2             2      2
+--R               ((- 4A a c  + A b c)e + (4B a c  - B b c)d)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2          2  3
+--R           (- 8A a c + 2A a b )f
+--R         + 
+--R                              2        3        2
+--R               ((4A a b + 4B a )c - A b  - B a b )e
+--R             + 
+--R                      2          2                  3
+--R               (8A a c  + (- 2A b  - 8B a b)c + 2B b )d
+--R          *
+--R              2
+--R             f
+--R         + 
+--R                     2      2   2          2      2
+--R           ((- 4A a c  + A b c)e  + (4B a c  - B b c)d e)f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                        2        2                                2
+--R               (- 4A a c  + (2A b  - 2B a b)c)f + (- 2A b + 4B a)c e
+--R             + 
+--R                    3         2
+--R               (4A c  - 2B b c )d
+--R          *
+--R             x
+--R         + 
+--R                            2         3         2
+--R           ((- 6A a b + 4B a )c + 2A b  - 2B a b )f
+--R         + 
+--R                  2          2                              2
+--R           (4A a c  + (- 2A b  + 2B a b)c)e + (2A b - 4B a)c d
+--R      *
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            3     2 2  2         2         3          2 2       2     4
+--R         (4a c - a b )f  + ((- 4a b c + a b )e + (- 8a c  + 6a b c - b )d)f
+--R       + 
+--R            2 2      2   2            2    3             3    2 2  2
+--R         (4a c  - a b c)e  + (- 4a b c  + b c)d e + (4a c  - b c )d
+--R    *
+--R            +-----------+ +--------------+
+--R        +-+ |          2  |   2
+--R       \|2 \|- 4d f + e  \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 232
+
+)clear all
+
+--S 233 of 286
+t0:=x^2*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)
+--R 
+--R
+--R           +------------------+ +--------+
+--R         2 | 2 2             2  |   2
+--R   (1)  x \|b x  + 2a b x + a  \|d x  + c
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 286
+r0:=-1/30*b*c*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(d^2*(a+b*x))+_
+   1/5*b*x^2*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(d*(a+b*x))-_
+   1/20*(2*b*c-5*a*d*x)*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   (d^2*(a+b*x))-1/8*a*c^2*atanh(x*sqrt(d)/sqrt(c+d*x^2))*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(d^(3/2)*(a+b*x))-1/8*a*c*x*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/(d*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                 +------------------+           +-+
+--R              2  | 2 2             2          x\|d
+--R       - 15a c d\|b x  + 2a b x + a  atanh(-----------)
+--R                                            +--------+
+--R                                            |   2
+--R                                           \|d x  + c
+--R     + 
+--R               2 4        2 3           2                    2  +-+
+--R         (24b d x  + 30a d x  + 8b c d x  + 15a c d x - 16b c )\|d
+--R      *
+--R          +------------------+ +--------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R            2          2  +-+
+--R     (120b d x + 120a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 235
+
+)clear all
+
+--S 236 of 286
+t0:=x*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)
+--R 
+--R
+--R          +------------------+ +--------+
+--R          | 2 2             2  |   2
+--R   (1)  x\|b x  + 2a b x + a  \|d x  + c
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 286
+r0:=1/4*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/d+1/12*a*(c+d*x^2)^(3/2)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(d*(a+b*x))-1/8*b*c^2*atanh(x*sqrt(d)/_
+   sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x+b^2*x^2)/(d^(3/2)*(a+b*x))-_
+   1/8*b*c*x*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/(d*(a+b*x))
+--R 
+--R
+--R   (2)
+--R               +------------------+           +-+
+--R             2 | 2 2             2          x\|d
+--R       - 3b c \|b x  + 2a b x + a  atanh(-----------)
+--R                                          +--------+
+--R                                          |   2
+--R                                         \|d x  + c
+--R     + 
+--R                                               +------------------+ +--------+
+--R              3         2                  +-+ | 2 2             2  |   2
+--R       (6b d x  + 8a d x  + 3b c x + 8a c)\|d \|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R                       +-+
+--R     (24b d x + 24a d)\|d
+--R                                                    Type: Expression(Integer)
+--E 237
+
+--S 238 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 238
+
+)clear all
+
+--S 239 of 286
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)
+--R 
+--R
+--R         +------------------+ +--------+
+--R         | 2 2             2  |   2
+--R   (1)  \|b x  + 2a b x + a  \|d x  + c
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 286
+r0:=1/3*b*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(d*(a+b*x))+_
+   1/2*a*c*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   ((a+b*x)*sqrt(d))+1/2*a*x*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/(a+b*x)
+--R 
+--R
+--R   (2)
+--R              +------------------+           +-+
+--R              | 2 2             2          x\|d
+--R       3a c d\|b x  + 2a b x + a  atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|d x  + c
+--R     + 
+--R                                     +------------------+ +--------+
+--R              2                  +-+ | 2 2             2  |   2
+--R       (2b d x  + 3a d x + 2b c)\|d \|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R                     +-+
+--R     (6b d x + 6a d)\|d
+--R                                                    Type: Expression(Integer)
+--E 240
+
+--S 241 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 241
+
+)clear all
+
+--S 242 of 286
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/x
+--R 
+--R
+--R         +------------------+ +--------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + c
+--R   (1)  --------------------------------
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 286
+r0:=-a*atanh(sqrt(c+d*x^2)/sqrt(c))*sqrt(c)*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   (a+b*x)+1/2*b*c*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x+_
+   b^2*x^2)/((a+b*x)*sqrt(d))+1/2*(2*a+b*x)*sqrt(a^2+2*a*b*x+b^2*x^2)*_
+   sqrt(c+d*x^2)/(a+b*x)
+--R 
+--R
+--R   (2)
+--R                                               +--------+
+--R                    +------------------+       |   2
+--R            +-+ +-+ | 2 2             2       \|d x  + c
+--R       - 2a\|c \|d \|b x  + 2a b x + a  atanh(-----------)
+--R                                                   +-+
+--R                                                  \|c
+--R     + 
+--R           +------------------+           +-+
+--R           | 2 2             2          x\|d
+--R       b c\|b x  + 2a b x + a  atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|d x  + c
+--R     + 
+--R                      +------------------+ +--------+
+--R                  +-+ | 2 2             2  |   2
+--R       (b x + 2a)\|d \|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R                 +-+
+--R     (2b x + 2a)\|d
+--R                                                    Type: Expression(Integer)
+--E 243
+
+--S 244 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 244
+
+)clear all
+
+--S 245 of 286
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/x^2
+--R 
+--R
+--R         +------------------+ +--------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + c
+--R   (1)  --------------------------------
+--R                        2
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 286
+r0:=-b*atanh(sqrt(c+d*x^2)/sqrt(c))*sqrt(c)*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   (a+b*x)+a*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(d)*sqrt(a^2+2*a*b*x+_
+   b^2*x^2)/(a+b*x)-(a-b*x)*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/(x*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                                            +--------+
+--R                 +------------------+       |   2
+--R             +-+ | 2 2             2       \|d x  + c
+--R       - b x\|c \|b x  + 2a b x + a  atanh(-----------)
+--R                                                +-+
+--R                                               \|c
+--R     + 
+--R               +------------------+           +-+
+--R           +-+ | 2 2             2          x\|d
+--R       a x\|d \|b x  + 2a b x + a  atanh(-----------)
+--R                                          +--------+
+--R                                          |   2
+--R                                         \|d x  + c
+--R     + 
+--R                 +------------------+ +--------+
+--R                 | 2 2             2  |   2
+--R       (b x - a)\|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R        2
+--R     b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 246
+
+--S 247 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 247
+
+)clear all
+
+--S 248 of 286
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/x^3
+--R 
+--R
+--R         +------------------+ +--------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + c
+--R   (1)  --------------------------------
+--R                        3
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 286
+r0:=-1/2*a*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(c*x^2*(a+b*x))-_
+   1/2*a*d*atanh(sqrt(c+d*x^2)/sqrt(c))*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   ((a+b*x)*sqrt(c))+b*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(d)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(a+b*x)-1/2*(2*b*c-a*d*x)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+d*x^2)/(c*x*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                                           +--------+
+--R                +------------------+       |   2
+--R              2 | 2 2             2       \|d x  + c
+--R       - a d x \|b x  + 2a b x + a  atanh(-----------)
+--R                                               +-+
+--R                                              \|c
+--R     + 
+--R                     +------------------+           +-+
+--R           2 +-+ +-+ | 2 2             2          x\|d
+--R       2b x \|c \|d \|b x  + 2a b x + a  atanh(-----------)
+--R                                                +--------+
+--R                                                |   2
+--R                                               \|d x  + c
+--R     + 
+--R                        +------------------+ +--------+
+--R                    +-+ | 2 2             2  |   2
+--R       (- 2b x - a)\|c \|b x  + 2a b x + a  \|d x  + c
+--R  /
+--R          3       2  +-+
+--R     (2b x  + 2a x )\|c
+--R                                                    Type: Expression(Integer)
+--E 249
+
+--S 250 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 250
+
+)clear all
+
+--S 251 of 286
+t0:=x^2*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)
+--R 
+--R
+--R           +------------------+ +--------------+
+--R         2 | 2 2             2  |   2
+--R   (1)  x \|b x  + 2a b x + a  \|d x  + e x + c
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 286
+r0:=-1/240*(8*b*c*d+50*a*d*e-35*b*e^2)*(c+e*x+d*x^2)^(3/2)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(d^3*(a+b*x))+1/5*b*x^2*(c+e*x+d*x^2)^(3/2)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(d*(a+b*x))-1/40*(4*b*c-(10*a*d-7*b*e)*x)*_
+   (c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(d^2*(a+b*x))-_
+   1/256*(4*c*d-e^2)*(2*a*d*(4*c*d-5*e^2)-b*(12*c*d*e-7*e^3))*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(d^(9/2)*(a+b*x))-_
+   1/128*(2*a*d*(4*c*d-5*e^2)-b*(12*c*d*e-7*e^3))*(e+2*d*x)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/(d^4*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                 5           4             3           2 2         2 2
+--R           105b e  - 150a d e  - 600b c d e  + 720a c d e  + 720b c d e
+--R         + 
+--R                   2 3
+--R           - 480a c d
+--R      *
+--R          +------------------+
+--R          | 2 2             2              2d x + e
+--R         \|b x  + 2a b x + a  atanh(----------------------)
+--R                                          +--------------+
+--R                                      +-+ |   2
+--R                                    2\|d \|d x  + e x + c
+--R     + 
+--R                 4 4         3          4  3
+--R           768b d x  + (96b d e + 960a d )x
+--R         + 
+--R                    2 2         3            3  2
+--R           (- 112b d e  + 160a d e + 256b c d )x
+--R         + 
+--R                    3         2 2           2            3           4
+--R           (140b d e  - 200a d e  - 464b c d e + 480a c d )x - 210b e
+--R         + 
+--R                   3             2            2          2 2
+--R           300a d e  + 920b c d e  - 1040a c d e - 512b c d
+--R      *
+--R              +------------------+ +--------------+
+--R          +-+ | 2 2             2  |   2
+--R         \|d \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R             4           4  +-+
+--R     (3840b d x + 3840a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 253
+
+)clear all
+
+--S 254 of 286
+t0:=x*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)
+--R 
+--R
+--R          +------------------+ +--------------+
+--R          | 2 2             2  |   2
+--R   (1)  x\|b x  + 2a b x + a  \|d x  + e x + c
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 286
+r0:=1/4*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/d+_
+   1/24*(2*a*d-5*b*e)*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/_
+   (d^2*(a+b*x))-1/128*(4*c*d-e^2)*(4*b*c*d+8*a*d*e-5*b*e^2)*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x+_
+   b^2*x^2)/(d^(7/2)*(a+b*x))-1/64*(4*b*c*d+8*a*d*e-5*b*e^2)*(e+2*d*x)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/(d^3*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                 4          3            2          2         2 2
+--R         (- 15b e  + 24a d e  + 72b c d e  - 96a c d e - 48b c d )
+--R      *
+--R          +------------------+
+--R          | 2 2             2              2d x + e
+--R         \|b x  + 2a b x + a  atanh(----------------------)
+--R                                          +--------------+
+--R                                      +-+ |   2
+--R                                    2\|d \|d x  + e x + c
+--R     + 
+--R                3 3         2          3  2             2        2           2
+--R           96b d x  + (16b d e + 128a d )x  + (- 20b d e  + 32a d e + 48b c d )x
+--R         + 
+--R                3          2                        2
+--R           30b e  - 48a d e  - 104b c d e + 128a c d
+--R      *
+--R              +------------------+ +--------------+
+--R          +-+ | 2 2             2  |   2
+--R         \|d \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R            3          3  +-+
+--R     (384b d x + 384a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 255
+
+--S 256 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 256
+
+)clear all
+
+--S 257 of 286
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)
+--R 
+--R
+--R         +------------------+ +--------------+
+--R         | 2 2             2  |   2
+--R   (1)  \|b x  + 2a b x + a  \|d x  + e x + c
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 286
+r0:=1/3*b*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(d*(a+b*x))+_
+   1/16*(2*a*d-b*e)*(4*c*d-e^2)*atanh(1/2*(e+2*d*x)/(sqrt(d)*_
+   sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x+b^2*x^2)/(d^(5/2)*(a+b*x))+_
+   1/8*(2*a*d-b*e)*(e+2*d*x)*sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/_
+   (d^2*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                                                  +------------------+
+--R              3         2                      2  | 2 2             2
+--R         (3b e  - 6a d e  - 12b c d e + 24a c d )\|b x  + 2a b x + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R               2 2                  2         2                      +-+
+--R         (16b d x  + (4b d e + 24a d )x - 6b e  + 12a d e + 16b c d)\|d
+--R      *
+--R          +------------------+ +--------------+
+--R          | 2 2             2  |   2
+--R         \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R           2         2  +-+
+--R     (48b d x + 48a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 258
+
+--S 259 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 259
+
+)clear all
+
+--S 260 of 286
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/x
+--R 
+--R
+--R         +------------------+ +--------------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + e x + c
+--R   (1)  --------------------------------------
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 286
+r0:=1/8*(4*b*c*d+4*a*d*e-b*e^2)*atanh(1/2*(e+2*d*x)/(sqrt(d)*_
+   sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x+b^2*x^2)/(d^(3/2)*(a+b*x))-_
+   a*atanh(1/2*(2*c+e*x)/(sqrt(c)*sqrt(c+e*x+d*x^2)))*sqrt(c)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(a+b*x)+1/4*(4*a*d+b*e+2*b*d*x)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/(d*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                      +------------------+
+--R              +-+ +-+ | 2 2             2              e x + 2c
+--R       - 8a d\|c \|d \|b x  + 2a b x + a  atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|c \|d x  + e x + c
+--R     + 
+--R                                    +------------------+
+--R               2                    | 2 2             2
+--R         (- b e  + 4a d e + 4b c d)\|b x  + 2a b x + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R                                  +------------------+ +--------------+
+--R                              +-+ | 2 2             2  |   2
+--R       (4b d x + 2b e + 8a d)\|d \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R                     +-+
+--R     (8b d x + 8a d)\|d
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 262
+
+)clear all
+
+--S 263 of 286
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/x^2
+--R 
+--R
+--R         +------------------+ +--------------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + e x + c
+--R   (1)  --------------------------------------
+--R                           2
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 286
+r0:=-1/2*(2*b*c+a*e)*atanh(1/2*(2*c+e*x)/(sqrt(c)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/((a+b*x)*sqrt(c))+1/2*(2*a*d+b*e)*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x+_
+   b^2*x^2)/((a+b*x)*sqrt(d))-(a-b*x)*sqrt(a^2+2*a*b*x+b^2*x^2)*_
+   sqrt(c+e*x+d*x^2)/(x*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                           +------------------+
+--R                       +-+ | 2 2             2              e x + 2c
+--R       (- a e - 2b c)x\|d \|b x  + 2a b x + a  atanh(----------------------)
+--R                                                           +--------------+
+--R                                                       +-+ |   2
+--R                                                     2\|c \|d x  + e x + c
+--R     + 
+--R                         +------------------+
+--R                     +-+ | 2 2             2              2d x + e
+--R       (b e + 2a d)x\|c \|b x  + 2a b x + a  atanh(----------------------)
+--R                                                         +--------------+
+--R                                                     +-+ |   2
+--R                                                   2\|d \|d x  + e x + c
+--R     + 
+--R                           +------------------+ +--------------+
+--R                   +-+ +-+ | 2 2             2  |   2
+--R       (2b x - 2a)\|c \|d \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R          2         +-+ +-+
+--R     (2b x  + 2a x)\|c \|d
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 265
+
+)clear all
+
+--S 266 of 286
+t0:=sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/x^3
+--R 
+--R
+--R         +------------------+ +--------------+
+--R         | 2 2             2  |   2
+--R        \|b x  + 2a b x + a  \|d x  + e x + c
+--R   (1)  --------------------------------------
+--R                           3
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 286
+r0:=-1/2*a*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x+b^2*x^2)/(c*x^2*(a+b*x))-_
+   1/8*(4*a*c*d+4*b*c*e-a*e^2)*atanh(1/2*(2*c+e*x)/(sqrt(c)*_
+   sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x+b^2*x^2)/(c^(3/2)*(a+b*x))+_
+   b*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(d)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)/(a+b*x)-1/4*(4*b*c-a*e-2*a*d*x)*_
+   sqrt(a^2+2*a*b*x+b^2*x^2)*sqrt(c+e*x+d*x^2)/(c*x*(a+b*x))
+--R 
+--R
+--R   (2)
+--R                                    +------------------+
+--R             2                    2 | 2 2             2
+--R         (a e  - 4b c e - 4a c d)x \|b x  + 2a b x + a
+--R      *
+--R                      e x + 2c
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|d x  + e x + c
+--R     + 
+--R                       +------------------+
+--R             2 +-+ +-+ | 2 2             2              2d x + e
+--R       8b c x \|c \|d \|b x  + 2a b x + a  atanh(----------------------)
+--R                                                       +--------------+
+--R                                                   +-+ |   2
+--R                                                 2\|d \|d x  + e x + c
+--R     + 
+--R                                     +------------------+ +--------------+
+--R                                 +-+ | 2 2             2  |   2
+--R       ((- 2a e - 8b c)x - 4a c)\|c \|b x  + 2a b x + a  \|d x  + e x + c
+--R  /
+--R            3         2  +-+
+--R     (8b c x  + 8a c x )\|c
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 268
+
+)clear all
+
+--S 269 of 286
+t0:=x*sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          +--------------+ +-------------------+
+--R          |   2            | 2 4         2    2
+--R   (1)  x\|d x  + e x + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 286
+r0:=1/3*a*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))-_
+   1/240*b*(8*c*d-35*e^2)*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (d^3*(a+b*x^2))+1/5*b*x^2*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d*(a+b*x^2))-1/40*b*(4*c+7*e*x)*(c+e*x+d*x^2)^(3/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^2*(a+b*x^2))-1/16*a*e*(4*c*d-e^2)*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d^(5/2)*(a+b*x^2))+1/256*b*e*(12*c*d-7*e^2)*(4*c*d-e^2)*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d^(9/2)*(a+b*x^2))-1/8*a*e*(e+2*d*x)*sqrt(c+e*x+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^2*(a+b*x^2))+1/128*b*e*(12*c*d-7*e^2)*_
+   (e+2*d*x)*sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^4*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                5          2             3              3         2 2
+--R         (105b e  + (240a d  - 600b c d)e  + (- 960a c d  + 720b c d )e)
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2              2d x + e
+--R         \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                           +--------------+
+--R                                       +-+ |   2
+--R                                     2\|d \|d x  + e x + c
+--R     + 
+--R                 4 4        3   3            2 2          4           3  2
+--R           768b d x  + 96b d e x  + (- 112b d e  + 1280a d  + 256b c d )x
+--R         + 
+--R                    3          3           2             4
+--R           (140b d e  + (320a d  - 464b c d )e)x - 210b e
+--R         + 
+--R                    2             2            3         2 2
+--R           (- 480a d  + 920b c d)e  + 1280a c d  - 512b c d
+--R      *
+--R              +--------------+ +-------------------+
+--R          +-+ |   2            | 2 4         2    2
+--R         \|d \|d x  + e x + c \|b x  + 2a b x  + a
+--R  /
+--R             4 2          4  +-+
+--R     (3840b d x  + 3840a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 270
+
+--S 271 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 271
+
+)clear all
+
+--S 272 of 286
+t0:=sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         +--------------+ +-------------------+
+--R         |   2            | 2 4         2    2
+--R   (1)  \|d x  + e x + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 286
+r0:=-1/24*b*(5*e-6*d*x)*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (d^2*(a+b*x^2))-1/128*(4*c*d-e^2)*(4*b*c*d-16*a*d^2-5*b*e^2)*_
+   atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d^(7/2)*(a+b*x^2))-1/64*(4*b*c*d-16*a*d^2-5*b*e^2)*(e+2*d*x)*_
+   sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^3*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                 4           2            2           3        2 2
+--R         (- 15b e  + (- 48a d  + 72b c d)e  + 192a c d  - 48b c d )
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2              2d x + e
+--R         \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                           +--------------+
+--R                                       +-+ |   2
+--R                                     2\|d \|d x  + e x + c
+--R     + 
+--R                3 3        2   2             2         3          2          3
+--R           96b d x  + 16b d e x  + (- 20b d e  + 192a d  + 48b c d )x + 30b e
+--R         + 
+--R                 2
+--R           (96a d  - 104b c d)e
+--R      *
+--R              +--------------+ +-------------------+
+--R          +-+ |   2            | 2 4         2    2
+--R         \|d \|d x  + e x + c \|b x  + 2a b x  + a
+--R  /
+--R            3 2         3  +-+
+--R     (384b d x  + 384a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 273
+
+--S 274 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 274
+
+)clear all
+
+--S 275 of 286
+t0:=sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x
+--R 
+--R
+--R         +--------------+ +-------------------+
+--R         |   2            | 2 4         2    2
+--R        \|d x  + e x + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 286
+r0:=1/3*b*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))-_
+   1/16*b*e*(4*c*d-e^2)*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^(5/2)*(a+b*x^2))-a*atanh(1/2*(2*c+e*x)/_
+   (sqrt(c)*sqrt(c+e*x+d*x^2)))*sqrt(c)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)+1/2*a*e*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/((a+b*x^2)*sqrt(d))+a*sqrt(c+e*x+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)-1/8*b*e*(e+2*d*x)*_
+   sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                        +-------------------+
+--R              2 +-+ +-+ | 2 4         2    2              e x + 2c
+--R       - 48a d \|c \|d \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                                         +--------------+
+--R                                                     +-+ |   2
+--R                                                   2\|c \|d x  + e x + c
+--R     + 
+--R                                       +-------------------+
+--R              3         2              | 2 4         2    2
+--R         (3b e  + (24a d  - 12b c d)e)\|b x  + 2a b x  + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R                                                              +--------------+
+--R               2 2                  2        2            +-+ |   2
+--R         (16b d x  + 4b d e x - 6b e  + 48a d  + 16b c d)\|d \|d x  + e x + c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R  /
+--R           2 2        2  +-+
+--R     (48b d x  + 48a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 277
+
+)clear all
+
+--S 278 of 286
+t0:=sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^2
+--R 
+--R
+--R         +--------------+ +-------------------+
+--R         |   2            | 2 4         2    2
+--R        \|d x  + e x + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------
+--R                            2
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 286
+r0:=1/8*b*(4*c*d-e^2)*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^(3/2)*(a+b*x^2))-1/2*a*e*atanh(1/2*_
+   (2*c+e*x)/(sqrt(c)*sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   ((a+b*x^2)*sqrt(c))+a*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(d)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)-a*sqrt(c+e*x+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x*(a+b*x^2))+1/4*b*(e+2*d*x)*_
+   sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                      +-------------------+
+--R                  +-+ | 2 4         2    2              e x + 2c
+--R       - 4a d e x\|d \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                                       +--------------+
+--R                                                   +-+ |   2
+--R                                                 2\|c \|d x  + e x + c
+--R     + 
+--R                                        +-------------------+
+--R               2       2            +-+ | 2 4         2    2
+--R         (- b e  + 8a d  + 4b c d)x\|c \|b x  + 2a b x  + a
+--R      *
+--R                      2d x + e
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|d \|d x  + e x + c
+--R     + 
+--R                                         +--------------+ +-------------------+
+--R              2                  +-+ +-+ |   2            | 2 4         2    2
+--R       (4b d x  + 2b e x - 8a d)\|c \|d \|d x  + e x + c \|b x  + 2a b x  + a
+--R  /
+--R            3           +-+ +-+
+--R     (8b d x  + 8a d x)\|c \|d
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 286
+t0:=sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3
+--R 
+--R
+--R         +--------------+ +-------------------+
+--R         |   2            | 2 4         2    2
+--R        \|d x  + e x + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------
+--R                            3
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 286
+r0:=-1/8*a*(4*c*d-e^2)*atanh(1/2*(2*c+e*x)/(sqrt(c)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c^(3/2)*(a+b*x^2))-b*atanh(1/2*(2*c+e*x)/_
+   (sqrt(c)*sqrt(c+e*x+d*x^2)))*sqrt(c)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)+1/2*b*e*atanh(1/2*(e+2*d*x)/(sqrt(d)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/((a+b*x^2)*sqrt(d))+b*sqrt(c+e*x+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)-1/4*a*(2*c+e*x)*sqrt(c+e*x+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*x^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                       +-------------------+
+--R             2                2  2 +-+ | 2 4         2    2
+--R         (a e  - 4a c d - 8b c )x \|d \|b x  + 2a b x  + a
+--R      *
+--R                      e x + 2c
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|d x  + e x + c
+--R     + 
+--R                     +-------------------+
+--R               2 +-+ | 2 4         2    2              2d x + e
+--R       4b c e x \|c \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|d \|d x  + e x + c
+--R     + 
+--R                                         +--------------+ +-------------------+
+--R              2                  +-+ +-+ |   2            | 2 4         2    2
+--R       (8b c x  - 2a e x - 4a c)\|c \|d \|d x  + e x + c \|b x  + 2a b x  + a
+--R  /
+--R            4         2  +-+ +-+
+--R     (8b c x  + 8a c x )\|c \|d
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 283
+
+)clear all
+
+--S 284 of 286
+t0:=sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^4
+--R 
+--R
+--R         +--------------+ +-------------------+
+--R         |   2            | 2 4         2    2
+--R        \|d x  + e x + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------
+--R                            4
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 286
+r0:=-1/3*a*(c+e*x+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*x^3*_
+   (a+b*x^2))+1/16*a*e*(4*c*d-e^2)*atanh(1/2*(2*c+e*x)/(sqrt(c)*_
+   sqrt(c+e*x+d*x^2)))*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c^(5/2)*(a+b*x^2))-_
+   1/2*b*e*atanh(1/2*(2*c+e*x)/(sqrt(c)*sqrt(c+e*x+d*x^2)))*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/((a+b*x^2)*sqrt(c))+b*atanh(1/2*(e+2*d*x)/_
+   (sqrt(d)*sqrt(c+e*x+d*x^2)))*sqrt(d)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)-b*sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x*(a+b*x^2))+_
+   1/8*a*e*(2*c+e*x)*sqrt(c+e*x+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (c^2*x^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                           +-------------------+
+--R                3                   2    3 | 2 4         2    2
+--R         (- 3a e  + (12a c d - 24b c )e)x \|b x  + 2a b x  + a
+--R      *
+--R                      e x + 2c
+--R         atanh(----------------------)
+--R                     +--------------+
+--R                 +-+ |   2
+--R               2\|c \|d x  + e x + c
+--R     + 
+--R                        +-------------------+
+--R            2 3 +-+ +-+ | 2 4         2    2              2d x + e
+--R       48b c x \|c \|d \|b x  + 2a b x  + a  atanh(----------------------)
+--R                                                         +--------------+
+--R                                                     +-+ |   2
+--R                                                   2\|d \|d x  + e x + c
+--R     + 
+--R                                                                +--------------+
+--R               2                  2  2                   2  +-+ |   2
+--R         ((6a e  - 16a c d - 48b c )x  - 4a c e x - 16a c )\|c \|d x  + e x + c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R  /
+--R           2 5        2 3  +-+
+--R     (48b c x  + 48a c x )\|c
+--R                                                    Type: Expression(Integer)
+--E 285
+
+--S 286 of 286
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 286
+
+
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder14a.input.pamphlet b/src/input/richder14a.input.pamphlet
new file mode 100644
index 0000000..fbcabd0
--- /dev/null
+++ b/src/input/richder14a.input.pamphlet
@@ -0,0 +1,10109 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder14a.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a+b x^2+c x^4)^p|
+
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder14a.output
+)spool richder14a.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 767
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          2 4         2    2  m
+--R   (1)  (b x  + 2a b x  + a )x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 767
+r0:=a^2*x^(1+m)/(1+m)+2*a*b*x^(3+m)/(3+m)+b^2*x^(5+m)/(5+m)
+--R 
+--R
+--R   (2)
+--R         2 2     2      2  m + 5          2                    m + 3
+--R       (b m  + 4b m + 3b )x      + (2a b m  + 12a b m + 10a b)x
+--R     + 
+--R         2 2     2       2  m + 1
+--R       (a m  + 8a m + 15a )x
+--R  /
+--R      3     2
+--R     m  + 9m  + 23m + 15
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 767
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         2 8         6    2 4
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 4
+
+--S 5 of 767
+r0:=1/5*a^2*x^5+2/7*a*b*x^7+1/9*b^2*x^9
+--R 
+--R
+--R        1  2 9   2      7   1  2 5
+--R   (2)  - b x  + - a b x  + - a x
+--R        9        7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 5
+
+--S 6 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 767
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         2 7         5    2 3
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 7
+
+--S 8 of 767
+r0:=1/4*a^2*x^4+1/3*a*b*x^6+1/8*b^2*x^8
+--R 
+--R
+--R        1  2 8   1      6   1  2 4
+--R   (2)  - b x  + - a b x  + - a x
+--R        8        3          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 8
+
+--S 9 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 767
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         2 6         4    2 2
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 10
+
+--S 11 of 767
+r0:=1/3*a^2*x^3+2/5*a*b*x^5+1/7*b^2*x^7
+--R 
+--R
+--R        1  2 7   2      5   1  2 3
+--R   (2)  - b x  + - a b x  + - a x
+--R        7        5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 11
+
+--S 12 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 767
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         2 5         3    2
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 13
+
+--S 14 of 767
+r0:=1/6*(a+b*x^2)^3/b
+--R 
+--R
+--R        1  3 6   1    2 4   1  2   2   1  3
+--R        - b x  + - a b x  + - a b x  + - a
+--R        6        2          2          6
+--R   (2)  -----------------------------------
+--R                         b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 14
+
+--S 15 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 767
+t0:=a^2+2*a*b*x^2+b^2*x^4
+--R 
+--R
+--R         2 4         2    2
+--R   (1)  b x  + 2a b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 16
+
+--S 17 of 767
+r0:=a^2*x+2/3*a*b*x^3+1/5*b^2*x^5
+--R 
+--R
+--R        1  2 5   2      3    2
+--R   (2)  - b x  + - a b x  + a x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 17
+
+--S 18 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 19
+
+--S 20 of 767
+r0:=a*b*x^2+1/4*b^2*x^4+a^2*log(x)
+--R 
+--R
+--R          2          2 4         2
+--R        4a log(x) + b x  + 4a b x
+--R   (2)  --------------------------
+--R                     4
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^2
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 22
+
+--S 23 of 767
+r0:=-a^2/x+2*a*b*x+1/3*b^2*x^3
+--R 
+--R
+--R         2 4         2     2
+--R        b x  + 6a b x  - 3a
+--R   (2)  --------------------
+--R                 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 23
+
+--S 24 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^3
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 25
+
+--S 26 of 767
+r0:=-1/2*a^2/x^2+1/2*b^2*x^2+2*a*b*log(x)
+--R 
+--R
+--R              2          2 4    2
+--R        4a b x log(x) + b x  - a
+--R   (2)  -------------------------
+--R                     2
+--R                   2x
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^4
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  4
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 28
+
+--S 29 of 767
+r0:=-1/3*a^2/x^3-2*a*b/x+b^2*x
+--R 
+--R
+--R         2 4         2   1  2
+--R        b x  - 2a b x  - - a
+--R                         3
+--R   (2)  ---------------------
+--R                   3
+--R                  x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 29
+
+--S 30 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^5
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  5
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 31
+
+--S 32 of 767
+r0:=-1/4*a^2/x^4-a*b/x^2+b^2*log(x)
+--R 
+--R
+--R          2 4               2    2
+--R        4b x log(x) - 4a b x  - a
+--R   (2)  --------------------------
+--R                      4
+--R                    4x
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^6
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  6
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 34
+
+--S 35 of 767
+r0:=-1/5*a^2/x^5-2/3*a*b/x^3-b^2/x
+--R 
+--R
+--R           2 4   2      2   1  2
+--R        - b x  - - a b x  - - a
+--R                 3          5
+--R   (2)  ------------------------
+--R                    5
+--R                   x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 35
+
+--S 36 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^7
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  7
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 37
+
+--S 38 of 767
+r0:=-1/6*(a+b*x^2)^3/(a*x^6)
+--R 
+--R
+--R          1  3 6   1    2 4   1  2   2   1  3
+--R        - - b x  - - a b x  - - a b x  - - a
+--R          6        2          2          6
+--R   (2)  -------------------------------------
+--R                            6
+--R                         a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 38
+
+--S 39 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^8
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  8
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 40
+
+--S 41 of 767
+r0:=-1/7*a^2/x^7-2/5*a*b/x^5-1/3*b^2/x^3
+--R 
+--R
+--R          1  2 4   2      2   1  2
+--R        - - b x  - - a b x  - - a
+--R          3        5          7
+--R   (2)  --------------------------
+--R                     7
+--R                    x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 41
+
+--S 42 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^9
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  9
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 43
+
+--S 44 of 767
+r0:=-1/8*a^2/x^8-1/3*a*b/x^6-1/4*b^2/x^4
+--R 
+--R
+--R          1  2 4   1      2   1  2
+--R        - - b x  - - a b x  - - a
+--R          4        3          8
+--R   (2)  --------------------------
+--R                     8
+--R                    x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 44
+
+--S 45 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^10
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                 10
+--R                x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 46
+
+--S 47 of 767
+r0:=-1/9*a^2/x^9-2/7*a*b/x^7-1/5*b^2/x^5
+--R 
+--R
+--R          1  2 4   2      2   1  2
+--R        - - b x  - - a b x  - - a
+--R          5        7          9
+--R   (2)  --------------------------
+--R                     9
+--R                    x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 47
+
+--S 48 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 767
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R          4 8       3 6     2 2 4     3   2    4  m
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a )x
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 767
+r0:=a^4*x^(1+m)/(1+m)+4*a^3*b*x^(3+m)/(3+m)+6*a^2*b^2*x^(5+m)/(5+m)+_
+    4*a*b^3*x^(7+m)/(7+m)+b^4*x^(9+m)/(9+m)
+--R 
+--R
+--R   (2)
+--R         4 4      4 3      4 2       4        4  m + 9
+--R       (b m  + 16b m  + 86b m  + 176b m + 105b )x
+--R     + 
+--R            3 4        3 3         3 2         3          3  m + 7
+--R       (4a b m  + 72a b m  + 416a b m  + 888a b m + 540a b )x
+--R     + 
+--R          2 2 4       2 2 3       2 2 2        2 2         2 2  m + 5
+--R       (6a b m  + 120a b m  + 780a b m  + 1800a b m + 1134a b )x
+--R     + 
+--R          3   4      3   3       3   2        3           3   m + 3
+--R       (4a b m  + 88a b m  + 656a b m  + 1832a b m + 1260a b)x
+--R     + 
+--R         4 4      4 3       4 2       4        4  m + 1
+--R       (a m  + 24a m  + 206a m  + 744a m + 945a )x
+--R  /
+--R      5      4       3       2
+--R     m  + 25m  + 230m  + 950m  + 1689m + 945
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 767
+t0:=x^6*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 14       3 12     2 2 10     3   8    4 6
+--R   (1)  b x   + 4a b x   + 6a b x   + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 52
+
+--S 53 of 767
+r0:=1/7*a^4*x^7+4/9*a^3*b*x^9+6/11*a^2*b^2*x^11+4/13*a*b^3*x^13+1/15*b^4*x^15
+--R 
+--R
+--R         1  4 15    4    3 13    6  2 2 11   4  3   9   1  4 7
+--R   (2)  -- b x   + -- a b x   + -- a b x   + - a b x  + - a x
+--R        15         13           11           9          7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 53
+
+--S 54 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 767
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 13       3 11     2 2 9     3   7    4 5
+--R   (1)  b x   + 4a b x   + 6a b x  + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 55
+
+--S 56 of 767
+r0:=1/6*a^4*x^6+1/2*a^3*b*x^8+3/5*a^2*b^2*x^10+1/3*a*b^3*x^12+1/14*b^4*x^14
+--R 
+--R
+--R         1  4 14   1    3 12   3  2 2 10   1  3   8   1  4 6
+--R   (2)  -- b x   + - a b x   + - a b x   + - a b x  + - a x
+--R        14         3           5           2          6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 56
+
+--S 57 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 767
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 12       3 10     2 2 8     3   6    4 4
+--R   (1)  b x   + 4a b x   + 6a b x  + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 58
+
+--S 59 of 767
+r0:=1/5*a^4*x^5+4/7*a^3*b*x^7+2/3*a^2*b^2*x^9+4/11*a*b^3*x^11+1/13*b^4*x^13
+--R 
+--R
+--R         1  4 13    4    3 11   2  2 2 9   4  3   7   1  4 5
+--R   (2)  -- b x   + -- a b x   + - a b x  + - a b x  + - a x
+--R        13         11           3          7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 59
+
+--S 60 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 767
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 11       3 9     2 2 7     3   5    4 3
+--R   (1)  b x   + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 61
+
+--S 62 of 767
+r0:=-1/10*a*(a+b*x^2)^5/b^2+1/12*(a+b*x^2)^6/b^2
+--R 
+--R
+--R         1  6 12   2    5 10   3  2 4 8   2  3 3 6   1  4 2 4    1  6
+--R        -- b x   + - a b x   + - a b x  + - a b x  + - a b x  - -- a
+--R        12         5           4          3          4          60
+--R   (2)  -------------------------------------------------------------
+--R                                       2
+--R                                      b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 62
+
+--S 63 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 767
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 10       3 8     2 2 6     3   4    4 2
+--R   (1)  b x   + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 64
+
+--S 65 of 767
+r0:=1/3*a^4*x^3+4/5*a^3*b*x^5+6/7*a^2*b^2*x^7+4/9*a*b^3*x^9+1/11*b^4*x^11
+--R 
+--R
+--R         1  4 11   4    3 9   6  2 2 7   4  3   5   1  4 3
+--R   (2)  -- b x   + - a b x  + - a b x  + - a b x  + - a x
+--R        11         9          7          5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 65
+
+--S 66 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 767
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 9       3 7     2 2 5     3   3    4
+--R   (1)  b x  + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 67
+
+--S 68 of 767
+r0:=1/10*(a+b*x^2)^5/b
+--R 
+--R
+--R         1  5 10   1    4 8    2 3 6    3 2 4   1  4   2    1  5
+--R        -- b x   + - a b x  + a b x  + a b x  + - a b x  + -- a
+--R        10         2                            2          10
+--R   (2)  --------------------------------------------------------
+--R                                    b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 68
+
+--S 69 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R   (1)  b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 70
+
+--S 71 of 767
+r0:=a^4*x+4/3*a^3*b*x^3+6/5*a^2*b^2*x^5+4/7*a*b^3*x^7+1/9*b^4*x^9
+--R 
+--R
+--R        1  4 9   4    3 7   6  2 2 5   4  3   3    4
+--R   (2)  - b x  + - a b x  + - a b x  + - a b x  + a x
+--R        9        7          5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 71
+
+--S 72 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 73
+
+--S 74 of 767
+r0:=2*a^3*b*x^2+3/2*a^2*b^2*x^4+2/3*a*b^3*x^6+1/8*b^4*x^8+a^4*log(x)
+--R 
+--R
+--R           4           4 8        3 6      2 2 4      3   2
+--R        24a log(x) + 3b x  + 16a b x  + 36a b x  + 48a b x
+--R   (2)  ---------------------------------------------------
+--R                                 24
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^2
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            2
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 76
+
+--S 77 of 767
+r0:=-a^4/x+4*a^3*b*x+2*a^2*b^2*x^3+4/5*a*b^3*x^5+1/7*b^4*x^7
+--R 
+--R
+--R          4 8        3 6      2 2 4       3   2      4
+--R        5b x  + 28a b x  + 70a b x  + 140a b x  - 35a
+--R   (2)  ----------------------------------------------
+--R                              35x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 77
+
+--S 78 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^3
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            3
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 79
+
+--S 80 of 767
+r0:=-1/2*a^4/x^2+3*a^2*b^2*x^2+a*b^3*x^4+1/6*b^4*x^6+4*a^3*b*log(x)
+--R 
+--R
+--R           3   2          4 8       3 6      2 2 4     4
+--R        24a b x log(x) + b x  + 6a b x  + 18a b x  - 3a
+--R   (2)  ------------------------------------------------
+--R                                 2
+--R                               6x
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^4
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            4
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 82
+
+--S 83 of 767
+r0:=-1/3*a^4/x^3-4*a^3*b/x+6*a^2*b^2*x+4/3*a*b^3*x^3+1/5*b^4*x^5
+--R 
+--R
+--R        1  4 8   4    3 6     2 2 4     3   2   1  4
+--R        - b x  + - a b x  + 6a b x  - 4a b x  - - a
+--R        5        3                              3
+--R   (2)  --------------------------------------------
+--R                              3
+--R                             x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 83
+
+--S 84 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^5
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            5
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 85
+
+--S 86 of 767
+r0:=-1/4*a^4/x^4-2*a^3*b/x^2+2*a*b^3*x^2+1/4*b^4*x^4+6*a^2*b^2*log(x)
+--R 
+--R
+--R           2 2 4          4 8       3 6     3   2    4
+--R        24a b x log(x) + b x  + 8a b x  - 8a b x  - a
+--R   (2)  ----------------------------------------------
+--R                                4
+--R                              4x
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^6
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            6
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 88
+
+--S 89 of 767
+r0:=-1/5*a^4/x^5-4/3*a^3*b/x^3-6*a^2*b^2/x+4*a*b^3*x+1/3*b^4*x^3
+--R 
+--R
+--R        1  4 8       3 6     2 2 4   4  3   2   1  4
+--R        - b x  + 4a b x  - 6a b x  - - a b x  - - a
+--R        3                            3          5
+--R   (2)  --------------------------------------------
+--R                              5
+--R                             x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 89
+
+--S 90 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^7
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            7
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 91
+
+--S 92 of 767
+r0:=-1/6*a^4/x^6-a^3*b/x^4-3*a^2*b^2/x^2+1/2*b^4*x^2+4*a*b^3*log(x)
+--R 
+--R
+--R             3 6           4 8      2 2 4     3   2    4
+--R        24a b x log(x) + 3b x  - 18a b x  - 6a b x  - a
+--R   (2)  ------------------------------------------------
+--R                                 6
+--R                               6x
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^8
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            8
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 94
+
+--S 95 of 767
+r0:=-1/7*a^4/x^7-4/5*a^3*b/x^5-2*a^2*b^2/x^3-4*a*b^3/x+b^4*x
+--R 
+--R
+--R         4 8       3 6     2 2 4   4  3   2   1  4
+--R        b x  - 4a b x  - 2a b x  - - a b x  - - a
+--R                                   5          7
+--R   (2)  ------------------------------------------
+--R                             7
+--R                            x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 95
+
+--S 96 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^9
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            9
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 97
+
+--S 98 of 767
+r0:=-1/8*a^4/x^8-2/3*a^3*b/x^6-3/2*a^2*b^2/x^4-2*a*b^3/x^2+b^4*log(x)
+--R 
+--R
+--R           4 8              3 6      2 2 4      3   2     4
+--R        24b x log(x) - 48a b x  - 36a b x  - 16a b x  - 3a
+--R   (2)  ---------------------------------------------------
+--R                                   8
+--R                                24x
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^10
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           10
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 100
+
+--S 101 of 767
+r0:=-1/9*a^4/x^9-4/7*a^3*b/x^7-6/5*a^2*b^2/x^5-4/3*a*b^3/x^3-b^4/x
+--R 
+--R
+--R           4 8   4    3 6   6  2 2 4   4  3   2   1  4
+--R        - b x  - - a b x  - - a b x  - - a b x  - - a
+--R                 3          5          7          9
+--R   (2)  ----------------------------------------------
+--R                               9
+--R                              x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 101
+
+--S 102 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^11
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           11
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 103
+
+--S 104 of 767
+r0:=-1/10*(a+b*x^2)^5/(a*x^10)
+--R 
+--R
+--R           1  5 10   1    4 8    2 3 6    3 2 4   1  4   2    1  5
+--R        - -- b x   - - a b x  - a b x  - a b x  - - a b x  - -- a
+--R          10         2                            2          10
+--R   (2)  ----------------------------------------------------------
+--R                                      10
+--R                                   a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 104
+
+--S 105 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^12
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           12
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 106
+
+--S 107 of 767
+r0:=-1/11*a^4/x^11-4/9*a^3*b/x^9-6/7*a^2*b^2/x^7-4/5*a*b^3/x^5-1/3*b^4/x^3
+--R 
+--R
+--R          1  4 8   4    3 6   6  2 2 4   4  3   2    1  4
+--R        - - b x  - - a b x  - - a b x  - - a b x  - -- a
+--R          3        5          7          9          11
+--R   (2)  -------------------------------------------------
+--R                                11
+--R                               x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 107
+
+--S 108 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^13
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           13
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 109
+
+--S 110 of 767
+r0a:=-1/12*(a+b*x^2)^5/(a*x^12)+1/60*b*(a+b*x^2)^5/(a^2*x^10)
+--R 
+--R
+--R         1  6 12   1  2 4 8   2  3 3 6   3  4 2 4   2  5   2    1  6
+--R        -- b x   - - a b x  - - a b x  - - a b x  - - a b x  - -- a
+--R        60         4          3          4          5          12
+--R   (2)  ------------------------------------------------------------
+--R                                     2 12
+--R                                    a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 110
+
+--S 111 of 767
+r0b:=-1/12*a^4/x^12-2/5*a^3*b/x^10-3/4*a^2*b^2/x^8-2/3*a*b^3/x^6-1/4*b^4/x^4
+--R 
+--R
+--R          1  4 8   2    3 6   3  2 2 4   2  3   2    1  4
+--R        - - b x  - - a b x  - - a b x  - - a b x  - -- a
+--R          4        3          4          5          12
+--R   (3)  -------------------------------------------------
+--R                                12
+--R                               x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 111
+
+--S 112 of 767
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 767
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 113
+
+)clear all
+
+--S 114 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^14
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           14
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 114
+
+--S 115 of 767
+r0:=-1/13*a^4/x^13-4/11*a^3*b/x^11-2/3*a^2*b^2/x^9-4/7*a*b^3/x^7-1/5*b^4/x^5
+--R 
+--R
+--R          1  4 8   4    3 6   2  2 2 4    4  3   2    1  4
+--R        - - b x  - - a b x  - - a b x  - -- a b x  - -- a
+--R          5        7          3          11          13
+--R   (2)  --------------------------------------------------
+--R                                 13
+--R                                x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 115
+
+--S 116 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 116
+
+)clear all
+
+--S 117 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^15
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           15
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 117
+
+--S 118 of 767
+r0:=-1/14*a^4/x^14-1/3*a^3*b/x^12-3/5*a^2*b^2/x^10-1/2*a*b^3/x^8-1/6*b^4/x^6
+--R 
+--R
+--R          1  4 8   1    3 6   3  2 2 4   1  3   2    1  4
+--R        - - b x  - - a b x  - - a b x  - - a b x  - -- a
+--R          6        2          5          3          14
+--R   (2)  -------------------------------------------------
+--R                                14
+--R                               x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 118
+
+--S 119 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 119
+
+)clear all
+
+--S 120 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^16
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           16
+--R                          x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 120
+
+--S 121 of 767
+r0:=-1/15*a^4/x^15-4/13*a^3*b/x^13-6/11*a^2*b^2/x^11-4/9*a*b^3/x^9-1/7*b^4/x^7
+--R 
+--R
+--R          1  4 8   4    3 6    6  2 2 4    4  3   2    1  4
+--R        - - b x  - - a b x  - -- a b x  - -- a b x  - -- a
+--R          7        9          11          13          15
+--R   (2)  ---------------------------------------------------
+--R                                 15
+--R                                x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 121
+
+--S 122 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 122
+
+)clear all
+
+--S 123 of 767
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6  m
+--R   (1)  (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a )x
+--R                                                    Type: Expression(Integer)
+--E 123
+
+--S 124 of 767
+r0:=a^6*x^(1+m)/(1+m)+6*a^5*b*x^(3+m)/(3+m)+15*a^4*b^2*x^(5+m)/(5+m)+_
+    20*a^3*b^3*x^(7+m)/(7+m)+15*a^2*b^4*x^(9+m)/(9+m)+6*a*b^5*_
+    x^(11+m)/(11+m)+b^6*x^(13+m)/(13+m)
+--R 
+--R
+--R   (2)
+--R           6 6      6 5       6 4        6 3         6 2         6          6
+--R         (b m  + 36b m  + 505b m  + 3480b m  + 12139b m  + 19524b m + 10395b )
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R               5 6         5 5          5 4           5 3           5 2
+--R           6a b m  + 228a b m  + 3330a b m  + 23640a b m  + 84234a b m
+--R         + 
+--R                    5            5
+--R           137412a b m + 73710a b
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R              2 4 6       2 4 5        2 4 4         2 4 3          2 4 2
+--R           15a b m  + 600a b m  + 9195a b m  + 67920a b m  + 249405a b m
+--R         + 
+--R                  2 4           2 4
+--R           415320a b m + 225225a b
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R              3 3 6       3 3 5         3 3 4          3 3 3          3 3 2
+--R           20a b m  + 840a b m  + 13580a b m  + 105840a b m  + 406700a b m
+--R         + 
+--R                  3 3           3 3
+--R           699720a b m + 386100a b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R              4 2 6       4 2 5         4 2 4         4 2 3          4 2 2
+--R           15a b m  + 660a b m  + 11295a b m  + 94200a b m  + 389685a b m
+--R         + 
+--R                  4 2           4 2
+--R           711540a b m + 405405a b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R             5   6       5   5        5   4         5   3          5   2
+--R           6a b m  + 276a b m  + 5010a b m  + 45240a b m  + 208554a b m
+--R         + 
+--R                  5             5
+--R           438324a b m + 270270a b
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R           6 6      6 5       6 4        6 3         6 2          6           6
+--R         (a m  + 48a m  + 925a m  + 9120a m  + 48259a m  + 129072a m + 135135a )
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R      7      6       5         4         3          2
+--R     m  + 49m  + 973m  + 10045m  + 57379m  + 177331m  + 264207m + 135135
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 125
+
+)clear all
+
+--S 126 of 767
+t0:=x^8*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 20       5 18      2 4 16      3 3 14      4 2 12     5   10    6 8
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x   + 6a b x   + a x
+--R                                                    Type: Polynomial(Integer)
+--E 126
+
+--S 127 of 767
+r0:=1/9*a^6*x^9+6/11*a^5*b*x^11+15/13*a^4*b^2*x^13+4/3*a^3*b^3*x^15+_
+    15/17*a^2*b^4*x^17+6/19*a*b^5*x^19+1/21*b^6*x^21
+--R 
+--R
+--R   (2)
+--R      1  6 21    6    5 19   15  2 4 17   4  3 3 15   15  4 2 13    6  5   11
+--R     -- b x   + -- a b x   + -- a b x   + - a b x   + -- a b x   + -- a b x
+--R     21         19           17           3           13           11
+--R   + 
+--R     1  6 9
+--R     - a x
+--R     9
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 127
+
+--S 128 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 128
+
+)clear all
+
+--S 129 of 767
+t0:=x^7*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 19       5 17      2 4 15      3 3 13      4 2 11     5   9    6 7
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x   + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 129
+
+--S 130 of 767
+r0:=1/8*a^6*x^8+3/5*a^5*b*x^10+5/4*a^4*b^2*x^12+10/7*a^3*b^3*x^14+_
+    15/16*a^2*b^4*x^16+1/3*a*b^5*x^18+1/20*b^6*x^20
+--R 
+--R
+--R   (2)
+--R      1  6 20   1    5 18   15  2 4 16   10  3 3 14   5  4 2 12   3  5   10
+--R     -- b x   + - a b x   + -- a b x   + -- a b x   + - a b x   + - a b x
+--R     20         3           16            7           4           5
+--R   + 
+--R     1  6 8
+--R     - a x
+--R     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 130
+
+--S 131 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 131
+
+)clear all
+
+--S 132 of 767
+t0:=x^6*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 18       5 16      2 4 14      3 3 12      4 2 10     5   8    6 6
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x   + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 132
+
+--S 133 of 767
+r0:=1/7*a^6*x^7+2/3*a^5*b*x^9+15/11*a^4*b^2*x^11+20/13*a^3*b^3*x^13+_
+    a^2*b^4*x^15+6/17*a*b^5*x^17+1/19*b^6*x^19
+--R 
+--R
+--R   (2)
+--R    1  6 19    6    5 17    2 4 15   20  3 3 13   15  4 2 11   2  5   9   1  6 7
+--R   -- b x   + -- a b x   + a b x   + -- a b x   + -- a b x   + - a b x  + - a x
+--R   19         17                     13           11           3          7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 133
+
+--S 134 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 134
+
+)clear all
+
+--S 135 of 767
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 17       5 15      2 4 13      3 3 11      4 2 9     5   7    6 5
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x  + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 135
+
+--S 136 of 767
+r0:=1/14*a^2*(a+b*x^2)^7/b^3-1/8*a*(a+b*x^2)^8/b^3+1/18*(a+b*x^2)^9/b^3
+--R 
+--R
+--R   (2)
+--R        1  9 18   3    8 16   15  2 7 14   5  3 6 12   3  4 5 10   3  5 4 8
+--R       -- b x   + - a b x   + -- a b x   + - a b x   + - a b x   + - a b x
+--R       18         8           14           3           2           4
+--R     + 
+--R       1  6 3 6    1   9
+--R       - a b x  + --- a
+--R       6          504
+--R  /
+--R      3
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 136
+
+--S 137 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 137
+
+)clear all
+
+--S 138 of 767
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 16       5 14      2 4 12      3 3 10      4 2 8     5   6    6 4
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x  + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 138
+
+--S 139 of 767
+r0:=1/5*a^6*x^5+6/7*a^5*b*x^7+5/3*a^4*b^2*x^9+20/11*a^3*b^3*x^11+_
+    15/13*a^2*b^4*x^13+2/5*a*b^5*x^15+1/17*b^6*x^17
+--R 
+--R
+--R   (2)
+--R    1  6 17   2    5 15   15  2 4 13   20  3 3 11   5  4 2 9   6  5   7   1  6 5
+--R   -- b x   + - a b x   + -- a b x   + -- a b x   + - a b x  + - a b x  + - a x
+--R   17         5           13           11           3          7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 139
+
+--S 140 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 140
+
+)clear all
+
+--S 141 of 767
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 15       5 13      2 4 11      3 3 9      4 2 7     5   5    6 3
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 141
+
+--S 142 of 767
+r0:=-1/14*a*(a+b*x^2)^7/b^2+1/16*(a+b*x^2)^8/b^2
+--R 
+--R
+--R   (2)
+--R        1  8 16   3    7 14   5  2 6 12     3 5 10   15  4 4 8    5 3 6
+--R       -- b x   + - a b x   + - a b x   + 2a b x   + -- a b x  + a b x
+--R       16         7           4                       8
+--R     + 
+--R       1  6 2 4    1   8
+--R       - a b x  - --- a
+--R       4          112
+--R  /
+--R      2
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 142
+
+--S 143 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 143
+
+)clear all
+
+--S 144 of 767
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 14       5 12      2 4 10      3 3 8      4 2 6     5   4    6 2
+--R   (1)  b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 144
+
+--S 145 of 767
+r0:=1/3*a^6*x^3+6/5*a^5*b*x^5+15/7*a^4*b^2*x^7+20/9*a^3*b^3*x^9+_
+    15/11*a^2*b^4*x^11+6/13*a*b^5*x^13+1/15*b^6*x^15
+--R 
+--R
+--R   (2)
+--R      1  6 15    6    5 13   15  2 4 11   20  3 3 9   15  4 2 7   6  5   5
+--R     -- b x   + -- a b x   + -- a b x   + -- a b x  + -- a b x  + - a b x
+--R     15         13           11            9           7          5
+--R   + 
+--R     1  6 3
+--R     - a x
+--R     3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 145
+
+--S 146 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 146
+
+)clear all
+
+--S 147 of 767
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 13       5 11      2 4 9      3 3 7      4 2 5     5   3    6
+--R   (1)  b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 147
+
+--S 148 of 767
+r0:=1/14*(a+b*x^2)^7/b
+--R 
+--R
+--R   (2)
+--R        1  7 14   1    6 12   3  2 5 10   5  3 4 8   5  4 3 6   3  5 2 4
+--R       -- b x   + - a b x   + - a b x   + - a b x  + - a b x  + - a b x
+--R       14         2           2           2          2          2
+--R     + 
+--R       1  6   2    1  7
+--R       - a b x  + -- a
+--R       2          14
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 148
+
+--S 149 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 149
+
+)clear all
+
+--S 150 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R   (1)  b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 150
+
+--S 151 of 767
+r0:=a^6*x+2*a^5*b*x^3+3*a^4*b^2*x^5+20/7*a^3*b^3*x^7+5/3*a^2*b^4*x^9+_
+    6/11*a*b^5*x^11+1/13*b^6*x^13
+--R 
+--R
+--R         1  6 13    6    5 11   5  2 4 9   20  3 3 7     4 2 5     5   3    6
+--R   (2)  -- b x   + -- a b x   + - a b x  + -- a b x  + 3a b x  + 2a b x  + a x
+--R        13         11           3           7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 151
+
+--S 152 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 152
+
+)clear all
+
+--S 153 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 153
+
+--S 154 of 767
+r0:=3*a^5*b*x^2+15/4*a^4*b^2*x^4+10/3*a^3*b^3*x^6+15/8*a^2*b^4*x^8+_
+    3/5*a*b^5*x^10+1/12*b^6*x^12+a^6*log(x)
+--R 
+--R
+--R   (2)
+--R           6            6 12        5 10       2 4 8       3 3 6       4 2 4
+--R       120a log(x) + 10b x   + 72a b x   + 225a b x  + 400a b x  + 450a b x
+--R     + 
+--R           5   2
+--R       360a b x
+--R  /
+--R     120
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 155
+
+)clear all
+
+--S 156 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^2
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        2
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 156
+
+--S 157 of 767
+r0:=-a^6/x+6*a^5*b*x+5*a^4*b^2*x^3+4*a^3*b^3*x^5+15/7*a^2*b^4*x^7+_
+    2/3*a*b^5*x^9+1/11*b^6*x^11
+--R 
+--R
+--R   (2)
+--R          6 12         5 10       2 4 8       3 3 6        4 2 4        5   2
+--R       21b x   + 154a b x   + 495a b x  + 924a b x  + 1155a b x  + 1386a b x
+--R     + 
+--R             6
+--R       - 231a
+--R  /
+--R     231x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 157
+
+--S 158 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 158
+
+)clear all
+
+--S 159 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^3
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        3
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 159
+
+--S 160 of 767
+r0:=-1/2*a^6/x^2+15/2*a^4*b^2*x^2+5*a^3*b^3*x^4+5/2*a^2*b^4*x^6+_
+    3/4*a*b^5*x^8+1/10*b^6*x^10+6*a^5*b*log(x)
+--R 
+--R
+--R   (2)
+--R           5   2           6 12        5 10      2 4 8       3 3 6       4 2 4
+--R       120a b x log(x) + 2b x   + 15a b x   + 50a b x  + 100a b x  + 150a b x
+--R     + 
+--R            6
+--R       - 10a
+--R  /
+--R        2
+--R     20x
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 161
+
+)clear all
+
+--S 162 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^4
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        4
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 162
+
+--S 163 of 767
+r0:=-1/3*a^6/x^3-6*a^5*b/x+15*a^4*b^2*x+20/3*a^3*b^3*x^3+3*a^2*b^4*x^5+_
+    6/7*a*b^5*x^7+1/9*b^6*x^9
+--R 
+--R
+--R        1  6 12   6    5 10     2 4 8   20  3 3 6      4 2 4     5   2   1  6
+--R        - b x   + - a b x   + 3a b x  + -- a b x  + 15a b x  - 6a b x  - - a
+--R        9         7                      3                               3
+--R   (2)  ---------------------------------------------------------------------
+--R                                           3
+--R                                          x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 163
+
+--S 164 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 164
+
+)clear all
+
+--S 165 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^5
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        5
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 165
+
+--S 166 of 767
+r0:=-1/4*a^6/x^4-3*a^5*b/x^2+10*a^3*b^3*x^2+15/4*a^2*b^4*x^4+a*b^5*x^6+_
+    1/8*b^6*x^8+15*a^4*b^2*log(x)
+--R 
+--R
+--R   (2)
+--R       4 2 4          6 12       5 10      2 4 8      3 3 6      5   2     6
+--R   120a b x log(x) + b x   + 8a b x   + 30a b x  + 80a b x  - 24a b x  - 2a
+--R   -------------------------------------------------------------------------
+--R                                        4
+--R                                      8x
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 167
+
+)clear all
+
+--S 168 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^6
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        6
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 168
+
+--S 169 of 767
+r0:=-1/5*a^6/x^5-2*a^5*b/x^3-15*a^4*b^2/x+20*a^3*b^3*x+5*a^2*b^4*x^3+_
+    6/5*a*b^5*x^5+1/7*b^6*x^7
+--R 
+--R
+--R        1  6 12   6    5 10     2 4 8      3 3 6      4 2 4     5   2   1  6
+--R        - b x   + - a b x   + 5a b x  + 20a b x  - 15a b x  - 2a b x  - - a
+--R        7         5                                                     5
+--R   (2)  --------------------------------------------------------------------
+--R                                          5
+--R                                         x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 169
+
+--S 170 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 170
+
+)clear all
+
+--S 171 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^7
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        7
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 171
+
+--S 172 of 767
+r0:=-1/6*a^6/x^6-3/2*a^5*b/x^4-15/2*a^4*b^2/x^2+15/2*a^2*b^4*x^2+_
+    3/2*a*b^5*x^4+1/6*b^6*x^6+20*a^3*b^3*log(x)
+--R 
+--R
+--R   (2)
+--R       3 3 6          6 12       5 10      2 4 8      4 2 4     5   2    6
+--R   120a b x log(x) + b x   + 9a b x   + 45a b x  - 45a b x  - 9a b x  - a
+--R   -----------------------------------------------------------------------
+--R                                       6
+--R                                     6x
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 173
+
+)clear all
+
+--S 174 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^8
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        8
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 174
+
+--S 175 of 767
+r0:=-1/7*a^6/x^7-6/5*a^5*b/x^5-5*a^4*b^2/x^3-20*a^3*b^3/x+15*a^2*b^4*x+_
+    2*a*b^5*x^3+1/5*b^6*x^5
+--R 
+--R
+--R        1  6 12       5 10      2 4 8      3 3 6     4 2 4   6  5   2   1  6
+--R        - b x   + 2a b x   + 15a b x  - 20a b x  - 5a b x  - - a b x  - - a
+--R        5                                                    5          7
+--R   (2)  --------------------------------------------------------------------
+--R                                          7
+--R                                         x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 175
+
+--S 176 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 176
+
+)clear all
+
+--S 177 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^9
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        9
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 177
+
+--S 178 of 767
+r0:=-1/8*a^6/x^8-a^5*b/x^6-15/4*a^4*b^2/x^4-10*a^3*b^3/x^2+3*a*b^5*x^2+_
+    1/4*b^6*x^4+15*a^2*b^4*log(x)
+--R 
+--R
+--R   (2)
+--R       2 4 8           6 12        5 10      3 3 6      4 2 4     5   2    6
+--R   120a b x log(x) + 2b x   + 24a b x   - 80a b x  - 30a b x  - 8a b x  - a
+--R   -------------------------------------------------------------------------
+--R                                        8
+--R                                      8x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 179
+
+)clear all
+
+--S 180 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^10
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        10
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 180
+
+--S 181 of 767
+r0:=-1/9*a^6/x^9-6/7*a^5*b/x^7-3*a^4*b^2/x^5-20/3*a^3*b^3/x^3-15*a^2*b^4/x+_
+    6*a*b^5*x+1/3*b^6*x^3
+--R 
+--R
+--R        1  6 12       5 10      2 4 8   20  3 3 6     4 2 4   6  5   2   1  6
+--R        - b x   + 6a b x   - 15a b x  - -- a b x  - 3a b x  - - a b x  - - a
+--R        3                                3                    7          9
+--R   (2)  ---------------------------------------------------------------------
+--R                                           9
+--R                                          x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 181
+
+--S 182 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 182
+
+)clear all
+
+--S 183 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^11
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        11
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 183
+
+--S 184 of 767
+r0:=-1/10*a^6/x^10-3/4*a^5*b/x^8-5/2*a^4*b^2/x^6-5*a^3*b^3/x^4-_
+    15/2*a^2*b^4/x^2+1/2*b^6*x^2+6*a*b^5*log(x)
+--R 
+--R
+--R   (2)
+--R             5 10            6 12       2 4 8       3 3 6      4 2 4      5   2
+--R       120a b x  log(x) + 10b x   - 150a b x  - 100a b x  - 50a b x  - 15a b x
+--R     + 
+--R           6
+--R       - 2a
+--R  /
+--R        10
+--R     20x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 185
+
+)clear all
+
+--S 186 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^12
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        12
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 186
+
+--S 187 of 767
+r0:=-1/11*a^6/x^11-2/3*a^5*b/x^9-15/7*a^4*b^2/x^7-4*a^3*b^3/x^5-_
+    5*a^2*b^4/x^3-6*a*b^5/x+b^6*x
+--R 
+--R
+--R         6 12       5 10     2 4 8     3 3 6   15  4 2 4   2  5   2    1  6
+--R        b x   - 6a b x   - 5a b x  - 4a b x  - -- a b x  - - a b x  - -- a
+--R                                                7          3          11
+--R   (2)  -------------------------------------------------------------------
+--R                                         11
+--R                                        x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 187
+
+--S 188 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 188
+
+)clear all
+
+--S 189 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^13
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        13
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 189
+
+--S 190 of 767
+r0:=-1/12*a^6/x^12-3/5*a^5*b/x^10-15/8*a^4*b^2/x^8-10/3*a^3*b^3/x^6-_
+    15/4*a^2*b^4/x^4-3*a*b^5/x^2+b^6*log(x)
+--R 
+--R
+--R   (2)
+--R           6 12               5 10       2 4 8       3 3 6       4 2 4
+--R       120b x  log(x) - 360a b x   - 450a b x  - 400a b x  - 225a b x
+--R     + 
+--R            5   2      6
+--R       - 72a b x  - 10a
+--R  /
+--R         12
+--R     120x
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 191
+
+)clear all
+
+--S 192 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^14
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        14
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 192
+
+--S 193 of 767
+r0:=-1/13*a^6/x^13-6/11*a^5*b/x^11-5/3*a^4*b^2/x^9-20/7*a^3*b^3/x^7-_
+    3*a^2*b^4/x^5-2*a*b^5/x^3-b^6/x
+--R 
+--R
+--R   (2)
+--R      6 12       5 10     2 4 8   20  3 3 6   5  4 2 4    6  5   2    1  6
+--R   - b x   - 2a b x   - 3a b x  - -- a b x  - - a b x  - -- a b x  - -- a
+--R                                   7          3          11          13
+--R   -----------------------------------------------------------------------
+--R                                      13
+--R                                     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 193
+
+--S 194 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 194
+
+)clear all
+
+--S 195 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^15
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        15
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 195
+
+--S 196 of 767
+r0:=-1/14*(a+b*x^2)^7/(a*x^14)
+--R 
+--R
+--R   (2)
+--R          1  7 14   1    6 12   3  2 5 10   5  3 4 8   5  4 3 6   3  5 2 4
+--R       - -- b x   - - a b x   - - a b x   - - a b x  - - a b x  - - a b x
+--R         14         2           2           2          2          2
+--R     + 
+--R         1  6   2    1  7
+--R       - - a b x  - -- a
+--R         2          14
+--R  /
+--R        14
+--R     a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 196
+
+--S 197 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 197
+
+)clear all
+
+--S 198 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^16
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        16
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 198
+
+--S 199 of 767
+r0:=-1/15*a^6/x^15-6/13*a^5*b/x^13-15/11*a^4*b^2/x^11-20/9*a^3*b^3/x^9-_
+    15/7*a^2*b^4/x^7-6/5*a*b^5/x^5-1/3*b^6/x^3
+--R 
+--R
+--R   (2)
+--R     1  6 12   6    5 10   15  2 4 8   20  3 3 6   15  4 2 4    6  5   2    1  6
+--R   - - b x   - - a b x   - -- a b x  - -- a b x  - -- a b x  - -- a b x  - -- a
+--R     3         5            7           9          11          13          15
+--R   -----------------------------------------------------------------------------
+--R                                         15
+--R                                        x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 199
+
+--S 200 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 200
+
+)clear all
+
+--S 201 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^17
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        17
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 201
+
+--S 202 of 767
+r0:=-1/16*(a+b*x^2)^7/(a*x^16)+1/112*b*(a+b*x^2)^7/(a^2*x^14)
+--R 
+--R
+--R   (2)
+--R        1   8 16   1  2 6 12    3 5 10   15  4 4 8     5 3 6   5  6 2 4
+--R       --- b x   - - a b x   - a b x   - -- a b x  - 2a b x  - - a b x
+--R       112         4                      8                    4
+--R     + 
+--R         3  7   2    1  8
+--R       - - a b x  - -- a
+--R         7          16
+--R  /
+--R      2 16
+--R     a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 202
+
+--S 203 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 203
+
+)clear all
+
+--S 204 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^18
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        18
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 204
+
+--S 205 of 767
+r0:=-1/17*a^6/x^17-2/5*a^5*b/x^15-15/13*a^4*b^2/x^13-20/11*a^3*b^3/x^11-_
+    5/3*a^2*b^4/x^9-6/7*a*b^5/x^7-1/5*b^6/x^5
+--R 
+--R
+--R   (2)
+--R     1  6 12   6    5 10   5  2 4 8   20  3 3 6   15  4 2 4   2  5   2    1  6
+--R   - - b x   - - a b x   - - a b x  - -- a b x  - -- a b x  - - a b x  - -- a
+--R     5         7           3          11          13          5          17
+--R   ---------------------------------------------------------------------------
+--R                                        17
+--R                                       x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 205
+
+--S 206 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 206
+
+)clear all
+
+--S 207 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^19
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        19
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 207
+
+--S 208 of 767
+r0:=-1/18*(a+b*x^2)^7/(a*x^18)+1/72*b*(a+b*x^2)^7/(a^2*x^16)-_
+    1/504*b^2*(a+b*x^2)^7/(a^3*x^14)
+--R 
+--R
+--R   (2)
+--R          1   9 18   1  3 6 12   3  4 5 10   3  5 4 8   5  6 3 6   15  7 2 4
+--R       - --- b x   - - a b x   - - a b x   - - a b x  - - a b x  - -- a b x
+--R         504         6           4           2          3          14
+--R     + 
+--R         3  8   2    1  9
+--R       - - a b x  - -- a
+--R         8          18
+--R  /
+--R      3 18
+--R     a x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 208
+
+--S 209 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 209
+
+)clear all
+
+--S 210 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^20
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        20
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 210
+
+--S 211 of 767
+r0:=-1/19*a^6/x^19-6/17*a^5*b/x^17-a^4*b^2/x^15-20/13*a^3*b^3/x^13-_
+    15/11*a^2*b^4/x^11-2/3*a*b^5/x^9-1/7*b^6/x^7
+--R 
+--R
+--R   (2)
+--R     1  6 12   2    5 10   15  2 4 8   20  3 3 6    4 2 4    6  5   2    1  6
+--R   - - b x   - - a b x   - -- a b x  - -- a b x  - a b x  - -- a b x  - -- a
+--R     7         3           11          13                   17          19
+--R   --------------------------------------------------------------------------
+--R                                        19
+--R                                       x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 211
+
+--S 212 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 212
+
+)clear all
+
+--S 213 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^21
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        21
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 213
+
+--S 214 of 767
+r0:=-1/20*a^6/x^20-1/3*a^5*b/x^18-15/16*a^4*b^2/x^16-10/7*a^3*b^3/x^14-_
+    5/4*a^2*b^4/x^12-3/5*a*b^5/x^10-1/8*b^6/x^8
+--R 
+--R
+--R   (2)
+--R     1  6 12   3    5 10   5  2 4 8   10  3 3 6   15  4 2 4   1  5   2    1  6
+--R   - - b x   - - a b x   - - a b x  - -- a b x  - -- a b x  - - a b x  - -- a
+--R     8         5           4           7          16          3          20
+--R   ---------------------------------------------------------------------------
+--R                                        20
+--R                                       x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 214
+
+--S 215 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 215
+
+)clear all
+
+--S 216 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^22
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        22
+--R                                       x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 216
+
+--S 217 of 767
+r0:=-1/21*a^6/x^21-6/19*a^5*b/x^19-15/17*a^4*b^2/x^17-4/3*a^3*b^3/x^15-_
+    15/13*a^2*b^4/x^13-6/11*a*b^5/x^11-1/9*b^6/x^9
+--R 
+--R
+--R   (2)
+--R     1  6 12    6    5 10   15  2 4 8   4  3 3 6   15  4 2 4    6  5   2    1  6
+--R   - - b x   - -- a b x   - -- a b x  - - a b x  - -- a b x  - -- a b x  - -- a
+--R     9         11           13          3          17          19          21
+--R   -----------------------------------------------------------------------------
+--R                                         21
+--R                                        x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 217
+
+--S 218 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 218
+
+)clear all
+
+--S 219 of 767
+t0:=x^m/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  m
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 219
+
+--S 220 of 767
+--r0:=1/2*x^(1+m)/(a*(a+b*x^2))+1/2*(1-m)*x^(1+m)*_
+--  hypergeometric(1,1/2*(1+m),1/2*(3+m),-b*x^2/a)/(a^2*(1+m))
+--E 220
+
+--S 221 of 767
+--d0:=normalize(t0-D(r0,x))
+--E 221
+
+)clear all
+
+--S 222 of 767
+t0:=x^11/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 11
+--R                x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 222
+
+--S 223 of 767
+r0:=-2*a^3*x^2/b^5+3/4*a^2*x^4/b^4-1/3*a*x^6/b^3+1/8*x^8/b^2+_
+    1/2*a^5/(b^6*(a+b*x^2))+5/2*a^4*log(a+b*x^2)/b^6
+--R 
+--R
+--R   (2)
+--R           4   2      5        2          5 10       4 8      2 3 6      3 2 4
+--R       (60a b x  + 60a )log(b x  + a) + 3b x   - 5a b x  + 10a b x  - 30a b x
+--R     + 
+--R            4   2      5
+--R       - 48a b x  + 12a
+--R  /
+--R        7 2        6
+--R     24b x  + 24a b
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 224
+
+)clear all
+
+--S 225 of 767
+t0:=x^9/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  9
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 225
+
+--S 226 of 767
+r0:=3/2*a^2*x^2/b^4-1/2*a*x^4/b^3+1/6*x^6/b^2-1/2*a^4/(b^5*(a+b*x^2))-_
+    2*a^3*log(a+b*x^2)/b^5
+--R 
+--R
+--R   (2)
+--R         3   2      4        2         4 8       3 6     2 2 4     3   2     4
+--R   (- 12a b x  - 12a )log(b x  + a) + b x  - 2a b x  + 6a b x  + 9a b x  - 3a
+--R   ---------------------------------------------------------------------------
+--R                                    6 2       5
+--R                                  6b x  + 6a b
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 227
+
+)clear all
+
+--S 228 of 767
+t0:=x^7/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  7
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 228
+
+--S 229 of 767
+r0:=-a*x^2/b^3+1/4*x^4/b^2+1/2*a^3/(b^4*(a+b*x^2))+3/2*a^2*log(a+b*x^2)/b^4
+--R 
+--R
+--R           2   2     3        2         3 6       2 4     2   2     3
+--R        (6a b x  + 6a )log(b x  + a) + b x  - 3a b x  - 4a b x  + 2a
+--R   (2)  -------------------------------------------------------------
+--R                                  5 2       4
+--R                                4b x  + 4a b
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 230
+
+)clear all
+
+--S 231 of 767
+t0:=x^5/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  5
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 231
+
+--S 232 of 767
+r0:=1/2*x^2/b^2-1/2*a^2/(b^3*(a+b*x^2))-a*log(a+b*x^2)/b^3
+--R 
+--R
+--R                 2     2        2         2 4        2    2
+--R        (- 2a b x  - 2a )log(b x  + a) + b x  + a b x  - a
+--R   (2)  ---------------------------------------------------
+--R                             4 2       3
+--R                           2b x  + 2a b
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 233
+
+)clear all
+
+--S 234 of 767
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 234
+
+--S 235 of 767
+r0:=1/2*a/(b^2*(a+b*x^2))+1/2*log(a+b*x^2)/b^2
+--R 
+--R
+--R            2            2
+--R        (b x  + a)log(b x  + a) + a
+--R   (2)  ---------------------------
+--R                 3 2       2
+--R               2b x  + 2a b
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 236
+
+)clear all
+
+--S 237 of 767
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 237
+
+--S 238 of 767
+r0:=(-1/2)/(b*(a+b*x^2))
+--R 
+--R
+--R               1
+--R               -
+--R               2
+--R   (2)  - ----------
+--R           2 2
+--R          b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 238
+
+--S 239 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 239
+
+)clear all
+
+--S 240 of 767
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         2 5         3    2
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 240
+
+--S 241 of 767
+r0:=1/2/(a*(a+b*x^2))+log(x)/a^2-1/2*log(a+b*x^2)/a^2
+--R 
+--R
+--R              2            2             2
+--R        (- b x  - a)log(b x  + a) + (2b x  + 2a)log(x) + a
+--R   (2)  --------------------------------------------------
+--R                             2   2     3
+--R                           2a b x  + 2a
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 242
+
+)clear all
+
+--S 243 of 767
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 7         5    2 3
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 243
+
+--S 244 of 767
+r0:=(-1)/(a^2*x^2)+1/2/(a*x^2*(a+b*x^2))-2*b*log(x)/a^3+b*log(a+b*x^2)/a^3
+--R 
+--R
+--R   (2)
+--R      2 4         2        2             2 4         2                2    2
+--R   (2b x  + 2a b x )log(b x  + a) + (- 4b x  - 4a b x )log(x) - 2a b x  - a
+--R   -------------------------------------------------------------------------
+--R                                  3   4     4 2
+--R                                2a b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 245
+
+)clear all
+
+--S 246 of 767
+t0:=1/(x^5*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 9         7    2 5
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 246
+
+--S 247 of 767
+r0:=(-3/4)/(a^2*x^4)+3/2*b/(a^3*x^2)+1/2/(a*x^4*(a+b*x^2))+_
+    3*b^2*log(x)/a^4-3/2*b^2*log(a+b*x^2)/a^4
+--R 
+--R
+--R   (2)
+--R            3 6       2 4        2            3 6        2 4              2 4
+--R       (- 6b x  - 6a b x )log(b x  + a) + (12b x  + 12a b x )log(x) + 6a b x
+--R     + 
+--R         2   2    3
+--R       3a b x  - a
+--R  /
+--R       4   6     5 4
+--R     4a b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 248
+
+)clear all
+
+--S 249 of 767
+t0:=x^10/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 10
+--R                x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 249
+
+--S 250 of 767
+r0:=-9/2*a^3*x/b^5+3/2*a^2*x^3/b^4-9/10*a*x^5/b^3+9/14*x^7/b^2-_
+    1/2*x^9/(b*(a+b*x^2))+9/2*a^(7/2)*atan(x*sqrt(b)/sqrt(a))/b^(11/2)
+--R 
+--R
+--R   (2)
+--R                                     +-+
+--R            3   2       4  +-+     x\|b
+--R       (315a b x  + 315a )\|a atan(-----)
+--R                                     +-+
+--R                                    \|a
+--R     + 
+--R           4 9        3 7      2 2 5       3   3       4   +-+
+--R       (10b x  - 18a b x  + 42a b x  - 210a b x  - 315a x)\|b
+--R  /
+--R         6 2        5  +-+
+--R     (70b x  + 70a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 251
+
+)clear all
+
+--S 252 of 767
+t0:=x^8/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  8
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 252
+
+--S 253 of 767
+r0:=7/2*a^2*x/b^4-7/6*a*x^3/b^3+7/10*x^5/b^2-1/2*x^7/(b*(a+b*x^2))-_
+    7/2*a^(5/2)*atan(x*sqrt(b)/sqrt(a))/b^(9/2)
+--R 
+--R
+--R   (2)
+--R                                       +-+
+--R              2   2       3  +-+     x\|b
+--R       (- 105a b x  - 105a )\|a atan(-----)
+--R                                       +-+
+--R                                      \|a
+--R     + 
+--R          3 7        2 5      2   3       3   +-+
+--R       (6b x  - 14a b x  + 70a b x  + 105a x)\|b
+--R  /
+--R         5 2        4  +-+
+--R     (30b x  + 30a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 254
+
+)clear all
+
+--S 255 of 767
+t0:=x^6/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  6
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 255
+
+--S 256 of 767
+r0:=-5/2*a*x/b^3+5/6*x^3/b^2-1/2*x^5/(b*(a+b*x^2))+5/2*a^(3/2)*_
+    atan(x*sqrt(b)/sqrt(a))/b^(7/2)
+--R 
+--R
+--R                                    +-+
+--R                2      2  +-+     x\|b        2 5          3      2   +-+
+--R        (15a b x  + 15a )\|a atan(-----) + (2b x  - 10a b x  - 15a x)\|b
+--R                                    +-+
+--R                                   \|a
+--R   (2)  -----------------------------------------------------------------
+--R                                  4 2       3  +-+
+--R                               (6b x  + 6a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 257
+
+)clear all
+
+--S 258 of 767
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  4
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 258
+
+--S 259 of 767
+r0:=3/2*x/b^2-1/2*x^3/(b*(a+b*x^2))-3/2*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/b^(5/2)
+--R 
+--R
+--R                                 +-+
+--R               2       +-+     x\|b          3         +-+
+--R        (- 3b x  - 3a)\|a atan(-----) + (2b x  + 3a x)\|b
+--R                                 +-+
+--R                                \|a
+--R   (2)  --------------------------------------------------
+--R                           3 2       2  +-+
+--R                        (2b x  + 2a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 260
+
+)clear all
+
+--S 261 of 767
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  2
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 261
+
+--S 262 of 767
+r0:=-1/2*x/(b*(a+b*x^2))+1/2*atan(x*sqrt(b)/sqrt(a))/(b^(3/2)*sqrt(a))
+--R 
+--R
+--R                         +-+
+--R            2          x\|b       +-+ +-+
+--R        (b x  + a)atan(-----) - x\|a \|b
+--R                         +-+
+--R                        \|a
+--R   (2)  ---------------------------------
+--R                 2 2         +-+ +-+
+--R              (2b x  + 2a b)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 263
+
+)clear all
+
+--S 264 of 767
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 264
+
+--S 265 of 767
+r0:=1/2*x/(a*(a+b*x^2))+1/2*atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*sqrt(b))
+--R 
+--R
+--R                         +-+
+--R            2          x\|b       +-+ +-+
+--R        (b x  + a)atan(-----) + x\|a \|b
+--R                         +-+
+--R                        \|a
+--R   (2)  ---------------------------------
+--R                    2     2  +-+ +-+
+--R             (2a b x  + 2a )\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 266
+
+)clear all
+
+--S 267 of 767
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 6         4    2 2
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 267
+
+--S 268 of 767
+r0:=(-3/2)/(a^2*x)+1/2/(a*x*(a+b*x^2))-3/2*atan(x*sqrt(b)/sqrt(a))*_
+    sqrt(b)/a^(5/2)
+--R 
+--R
+--R                                   +-+
+--R               3         +-+     x\|b            2       +-+
+--R        (- 3b x  - 3a x)\|b atan(-----) + (- 3b x  - 2a)\|a
+--R                                   +-+
+--R                                  \|a
+--R   (2)  ----------------------------------------------------
+--R                           2   3     3   +-+
+--R                        (2a b x  + 2a x)\|a
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 269
+
+)clear all
+
+--S 270 of 767
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 8         6    2 4
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 270
+
+--S 271 of 767
+r0:=(-5/6)/(a^2*x^3)+5/2*b/(a^3*x)+1/2/(a*x^3*(a+b*x^2))+_
+    5/2*b^(3/2)*atan(x*sqrt(b)/sqrt(a))/a^(7/2)
+--R 
+--R
+--R                                      +-+
+--R            2 5          3  +-+     x\|b         2 4          2     2  +-+
+--R        (15b x  + 15a b x )\|b atan(-----) + (15b x  + 10a b x  - 2a )\|a
+--R                                      +-+
+--R                                     \|a
+--R   (2)  ------------------------------------------------------------------
+--R                                  3   5     4 3  +-+
+--R                               (6a b x  + 6a x )\|a
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 272
+
+)clear all
+
+--S 273 of 767
+t0:=1/(x^6*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         2 10         8    2 6
+--R        b x   + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 273
+
+--S 274 of 767
+r0:=(-7/10)/(a^2*x^5)+7/6*b/(a^3*x^3)-7/2*b^2/(a^4*x)+1/2/(a*x^5*(a+b*x^2))-_
+    7/2*b^(5/2)*atan(x*sqrt(b)/sqrt(a))/a^(9/2)
+--R 
+--R
+--R   (2)
+--R                                         +-+
+--R              3 7         2 5  +-+     x\|b
+--R       (- 105b x  - 105a b x )\|b atan(-----)
+--R                                         +-+
+--R                                        \|a
+--R     + 
+--R              3 6        2 4      2   2     3  +-+
+--R       (- 105b x  - 70a b x  + 14a b x  - 6a )\|a
+--R  /
+--R         4   7      5 5  +-+
+--R     (30a b x  + 30a x )\|a
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 275
+
+)clear all
+
+--S 276 of 767
+t0:=x^m/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            m
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 767
+--r0:=1/6*x^(1+m)/(a*(a+b*x^2)^3)+1/24*(5-m)*x^(1+m)/(a^2*(a+b*x^2)^2)+_
+--  1/48*(3-m)*(5-m)*x^(1+m)/(a^3*(a+b*x^2))+1/48*(1-m)*(3-m)*_
+--  (5-m)*x^(1+m)*hypergeometric(1,1/2*(1+m),1/2*(3+m),-b*x^2/a)/(a^4*(1+m))
+--E 277
+
+--S 278 of 767
+--d0:=normalize(t0-D(r0,x))
+--E 278
+
+)clear all
+
+--S 279 of 767
+t0:=x^11/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           11
+--R                          x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 279
+
+--S 280 of 767
+r0:=-2*a*x^2/b^5+1/4*x^4/b^4+1/6*a^5/(b^6*(a+b*x^2)^3)-_
+    5/4*a^4/(b^6*(a+b*x^2)^2)+5*a^3/(b^6*(a+b*x^2))+5*a^2*log(a+b*x^2)/b^6
+--R 
+--R
+--R   (2)
+--R           2 3 6       3 2 4       4   2      5        2          5 10
+--R       (60a b x  + 180a b x  + 180a b x  + 60a )log(b x  + a) + 3b x
+--R     + 
+--R              4 8      2 3 6     3 2 4      4   2      5
+--R       - 15a b x  - 63a b x  - 9a b x  + 81a b x  + 47a
+--R  /
+--R        9 6        8 4      2 7 2      3 6
+--R     12b x  + 36a b x  + 36a b x  + 12a b
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 281
+
+)clear all
+
+--S 282 of 767
+t0:=x^9/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            9
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 282
+
+--S 283 of 767
+r0:=1/2*x^2/b^4-1/6*a^4/(b^5*(a+b*x^2)^3)+a^3/(b^5*(a+b*x^2)^2)-_
+    3*a^2/(b^5*(a+b*x^2))-2*a*log(a+b*x^2)/b^5
+--R 
+--R
+--R   (2)
+--R               3 6      2 2 4      3   2      4        2          4 8       3 6
+--R       (- 12a b x  - 36a b x  - 36a b x  - 12a )log(b x  + a) + 3b x  + 9a b x
+--R     + 
+--R           2 2 4      3   2      4
+--R       - 9a b x  - 27a b x  - 13a
+--R  /
+--R       8 6        7 4      2 6 2     3 5
+--R     6b x  + 18a b x  + 18a b x  + 6a b
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 284
+
+)clear all
+
+--S 285 of 767
+t0:=x^7/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            7
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 285
+
+--S 286 of 767
+r0:=1/6*a^3/(b^4*(a+b*x^2)^3)-3/4*a^2/(b^4*(a+b*x^2)^2)+_
+    3/2*a/(b^4*(a+b*x^2))+1/2*log(a+b*x^2)/b^4
+--R 
+--R
+--R   (2)
+--R      3 6        2 4      2   2     3        2             2 4      2   2      3
+--R   (6b x  + 18a b x  + 18a b x  + 6a )log(b x  + a) + 18a b x  + 27a b x  + 11a
+--R   -----------------------------------------------------------------------------
+--R                          7 6        6 4      2 5 2      3 4
+--R                       12b x  + 36a b x  + 36a b x  + 12a b
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 287
+
+)clear all
+
+--S 288 of 767
+t0:=x^5/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            5
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 288
+
+--S 289 of 767
+r0:=1/6*x^6/(a*(a+b*x^2)^3)
+--R 
+--R
+--R                      1  6
+--R                      - x
+--R                      6
+--R   (2)  -------------------------------
+--R           3 6     2 2 4     3   2    4
+--R        a b x  + 3a b x  + 3a b x  + a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 289
+
+--S 290 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 290
+
+)clear all
+
+--S 291 of 767
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            3
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 291
+
+--S 292 of 767
+r0:=1/6*a/(b^2*(a+b*x^2)^3)+(-1/4)/(b^2*(a+b*x^2)^2)
+--R 
+--R
+--R                  1    2    1
+--R                - - b x  - -- a
+--R                  4        12
+--R   (2)  -------------------------------
+--R         5 6       4 4     2 3 2    3 2
+--R        b x  + 3a b x  + 3a b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 292
+
+--S 293 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 293
+
+)clear all
+
+--S 294 of 767
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 294
+
+--S 295 of 767
+r0:=(-1/6)/(b*(a+b*x^2)^3)
+--R 
+--R
+--R                         1
+--R                         -
+--R                         6
+--R   (2)  - ------------------------------
+--R           4 6       3 4     2 2 2    3
+--R          b x  + 3a b x  + 3a b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 295
+
+--S 296 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 296
+
+)clear all
+
+--S 297 of 767
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                            1
+--R   (1)  ----------------------------------------
+--R         4 9       3 7     2 2 5     3   3    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 297
+
+--S 298 of 767
+r0:=1/6/(a*(a+b*x^2)^3)+1/4/(a^2*(a+b*x^2)^2)+1/2/(a^3*(a+b*x^2))+_
+    log(x)/a^4-1/2*log(a+b*x^2)/a^4
+--R 
+--R
+--R   (2)
+--R            3 6        2 4      2   2     3        2
+--R       (- 6b x  - 18a b x  - 18a b x  - 6a )log(b x  + a)
+--R     + 
+--R           3 6        2 4      2   2      3              2 4      2   2      3
+--R       (12b x  + 36a b x  + 36a b x  + 12a )log(x) + 6a b x  + 15a b x  + 11a
+--R  /
+--R        4 3 6      5 2 4      6   2      7
+--R     12a b x  + 36a b x  + 36a b x  + 12a
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 299
+
+)clear all
+
+--S 300 of 767
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                             1
+--R   (1)  ------------------------------------------
+--R         4 11       3 9     2 2 7     3   5    4 3
+--R        b x   + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 300
+
+--S 301 of 767
+r0:=(-2)/(a^4*x^2)+1/6/(a*x^2*(a+b*x^2)^3)+1/3/(a^2*x^2*(a+b*x^2)^2)+_
+    1/(a^3*x^2*(a+b*x^2))-4*b*log(x)/a^5+2*b*log(a+b*x^2)/a^5
+--R 
+--R
+--R   (2)
+--R           4 8        3 6      2 2 4      3   2        2
+--R       (12b x  + 36a b x  + 36a b x  + 12a b x )log(b x  + a)
+--R     + 
+--R             4 8        3 6      2 2 4      3   2               3 6      2 2 4
+--R       (- 24b x  - 72a b x  - 72a b x  - 24a b x )log(x) - 12a b x  - 30a b x
+--R     + 
+--R            3   2     4
+--R       - 22a b x  - 3a
+--R  /
+--R       5 3 8      6 2 6      7   4     8 2
+--R     6a b x  + 18a b x  + 18a b x  + 6a x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 302
+
+)clear all
+
+--S 303 of 767
+t0:=1/(x^5*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R         4 13       3 11     2 2 9     3   7    4 5
+--R        b x   + 4a b x   + 6a b x  + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 303
+
+--S 304 of 767
+r0:=(-5/2)/(a^4*x^4)+5*b/(a^5*x^2)+1/6/(a*x^4*(a+b*x^2)^3)+_
+    5/12/(a^2*x^4*(a+b*x^2)^2)+5/3/(a^3*x^4*(a+b*x^2))+10*b^2*log(x)/a^6-_
+    5*b^2*log(a+b*x^2)/a^6
+--R 
+--R
+--R   (2)
+--R             5 10         4 8       2 3 6      3 2 4        2
+--R       (- 60b x   - 180a b x  - 180a b x  - 60a b x )log(b x  + a)
+--R     + 
+--R            5 10         4 8       2 3 6       3 2 4               4 8
+--R       (120b x   + 360a b x  + 360a b x  + 120a b x )log(x) + 60a b x
+--R     + 
+--R           2 3 6       3 2 4      4   2     5
+--R       150a b x  + 110a b x  + 15a b x  - 3a
+--R  /
+--R        6 3 10      7 2 8      8   6      9 4
+--R     12a b x   + 36a b x  + 36a b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 305
+
+)clear all
+
+--S 306 of 767
+t0:=x^12/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           12
+--R                          x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 306
+
+--S 307 of 767
+r0:=231/16*a^2*x/b^6-77/16*a*x^3/b^5+231/80*x^5/b^4-1/6*x^11/(b*(a+b*x^2)^3)-_
+    11/24*x^9/(b^2*(a+b*x^2)^2)-33/16*x^7/(b^3*(a+b*x^2))-_
+    231/16*a^(5/2)*atan(x*sqrt(b)/sqrt(a))/b^(13/2)
+--R 
+--R
+--R   (2)
+--R                                                                     +-+
+--R               2 3 6         3 2 4         4   2        5  +-+     x\|b
+--R       (- 3465a b x  - 10395a b x  - 10395a b x  - 3465a )\|a atan(-----)
+--R                                                                     +-+
+--R                                                                    \|a
+--R     + 
+--R         5 11         4 9        2 3 7        3 2 5        4   3        5   +-+
+--R     (48b x   - 176a b x  + 1584a b x  + 7623a b x  + 9240a b x  + 3465a x)\|b
+--R  /
+--R          9 6         8 4       2 7 2       3 6  +-+
+--R     (240b x  + 720a b x  + 720a b x  + 240a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 308
+
+)clear all
+
+--S 309 of 767
+t0:=x^10/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           10
+--R                          x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 309
+
+--S 310 of 767
+r0:=-105/16*a*x/b^5+35/16*x^3/b^4-1/6*x^9/(b*(a+b*x^2)^3)-_
+    3/8*x^7/(b^2*(a+b*x^2)^2)-21/16*x^5/(b^3*(a+b*x^2))+_
+    105/16*a^(3/2)*atan(x*sqrt(b)/sqrt(a))/b^(11/2)
+--R 
+--R
+--R   (2)
+--R                                                             +-+
+--R              3 6       2 2 4       3   2       4  +-+     x\|b
+--R       (315a b x  + 945a b x  + 945a b x  + 315a )\|a atan(-----)
+--R                                                             +-+
+--R                                                            \|a
+--R     + 
+--R           4 9         3 7       2 2 5       3   3       4   +-+
+--R       (16b x  - 144a b x  - 693a b x  - 840a b x  - 315a x)\|b
+--R  /
+--R         8 6         7 4       2 6 2      3 5  +-+
+--R     (48b x  + 144a b x  + 144a b x  + 48a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 311
+
+)clear all
+
+--S 312 of 767
+t0:=x^8/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            8
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 312
+
+--S 313 of 767
+r0:=35/16*x/b^4-1/6*x^7/(b*(a+b*x^2)^3)-7/24*x^5/(b^2*(a+b*x^2)^2)-_
+    35/48*x^3/(b^3*(a+b*x^2))-35/16*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/b^(9/2)
+--R 
+--R
+--R   (2)
+--R                                                             +-+
+--R              3 6         2 4       2   2       3  +-+     x\|b
+--R       (- 105b x  - 315a b x  - 315a b x  - 105a )\|a atan(-----)
+--R                                                             +-+
+--R                                                            \|a
+--R     + 
+--R           3 7         2 5       2   3       3   +-+
+--R       (48b x  + 231a b x  + 280a b x  + 105a x)\|b
+--R  /
+--R         7 6         6 4       2 5 2      3 4  +-+
+--R     (48b x  + 144a b x  + 144a b x  + 48a b )\|b
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 314
+
+)clear all
+
+--S 315 of 767
+t0:=x^6/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            6
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 315
+
+--S 316 of 767
+r0:=-1/6*x^5/(b*(a+b*x^2)^3)-5/24*x^3/(b^2*(a+b*x^2)^2)-_
+    5/16*x/(b^3*(a+b*x^2))+5/16*atan(x*sqrt(b)/sqrt(a))/(b^(7/2)*sqrt(a))
+--R 
+--R
+--R   (2)
+--R                                                   +-+
+--R           3 6        2 4      2   2      3      x\|b
+--R       (15b x  + 45a b x  + 45a b x  + 15a )atan(-----)
+--R                                                   +-+
+--R                                                  \|a
+--R     + 
+--R             2 5          3      2   +-+ +-+
+--R       (- 33b x  - 40a b x  - 15a x)\|a \|b
+--R  /
+--R         6 6         5 4       2 4 2      3 3  +-+ +-+
+--R     (48b x  + 144a b x  + 144a b x  + 48a b )\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 317
+
+)clear all
+
+--S 318 of 767
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            4
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 318
+
+--S 319 of 767
+r0:=-1/6*x^3/(b*(a+b*x^2)^3)-1/8*x/(b^2*(a+b*x^2)^2)+_
+    1/16*x/(a*b^2*(a+b*x^2))+1/16*atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*b^(5/2))
+--R 
+--R
+--R   (2)
+--R                                               +-+
+--R          3 6       2 4     2   2     3      x\|b
+--R       (3b x  + 9a b x  + 9a b x  + 3a )atan(-----)
+--R                                               +-+
+--R                                              \|a
+--R     + 
+--R          2 5         3     2   +-+ +-+
+--R       (3b x  - 8a b x  - 3a x)\|a \|b
+--R  /
+--R           5 6       2 4 4       3 3 2      4 2  +-+ +-+
+--R     (48a b x  + 144a b x  + 144a b x  + 48a b )\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 320
+
+)clear all
+
+--S 321 of 767
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                            2
+--R                           x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 321
+
+--S 322 of 767
+r0:=-1/6*x/(b*(a+b*x^2)^3)+1/24*x/(a*b*(a+b*x^2)^2)+_
+    1/16*x/(a^2*b*(a+b*x^2))+1/16*atan(x*sqrt(b)/sqrt(a))/(a^(5/2)*b^(3/2))
+--R 
+--R
+--R   (2)
+--R                                               +-+
+--R          3 6       2 4     2   2     3      x\|b
+--R       (3b x  + 9a b x  + 9a b x  + 3a )atan(-----)
+--R                                               +-+
+--R                                              \|a
+--R     + 
+--R          2 5         3     2   +-+ +-+
+--R       (3b x  + 8a b x  - 3a x)\|a \|b
+--R  /
+--R         2 4 6       3 3 4       4 2 2      5   +-+ +-+
+--R     (48a b x  + 144a b x  + 144a b x  + 48a b)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 323
+
+)clear all
+
+--S 324 of 767
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           1
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 324
+
+--S 325 of 767
+r0:=1/6*x/(a*(a+b*x^2)^3)+5/24*x/(a^2*(a+b*x^2)^2)+_
+    5/16*x/(a^3*(a+b*x^2))+5/16*atan(x*sqrt(b)/sqrt(a))/(a^(7/2)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                                                   +-+
+--R           3 6        2 4      2   2      3      x\|b
+--R       (15b x  + 45a b x  + 45a b x  + 15a )atan(-----)
+--R                                                   +-+
+--R                                                  \|a
+--R     + 
+--R           2 5          3      2   +-+ +-+
+--R       (15b x  + 40a b x  + 33a x)\|a \|b
+--R  /
+--R         3 3 6       4 2 4       5   2      6  +-+ +-+
+--R     (48a b x  + 144a b x  + 144a b x  + 48a )\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 326
+
+)clear all
+
+--S 327 of 767
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                             1
+--R   (1)  ------------------------------------------
+--R         4 10       3 8     2 2 6     3   4    4 2
+--R        b x   + 4a b x  + 6a b x  + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 327
+
+--S 328 of 767
+r0:=(-35/16)/(a^4*x)+1/6/(a*x*(a+b*x^2)^3)+7/24/(a^2*x*(a+b*x^2)^2)+_
+    35/48/(a^3*x*(a+b*x^2))-35/16*atan(x*sqrt(b)/sqrt(a))*sqrt(b)/a^(9/2)
+--R 
+--R
+--R   (2)
+--R                                                              +-+
+--R              3 7         2 5       2   3       3   +-+     x\|b
+--R       (- 105b x  - 315a b x  - 315a b x  - 105a x)\|b atan(-----)
+--R                                                              +-+
+--R                                                             \|a
+--R     + 
+--R              3 6         2 4       2   2      3  +-+
+--R       (- 105b x  - 280a b x  - 231a b x  - 48a )\|a
+--R  /
+--R         4 3 7       5 2 5       6   3      7   +-+
+--R     (48a b x  + 144a b x  + 144a b x  + 48a x)\|a
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 329
+
+)clear all
+
+--S 330 of 767
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R         4 12       3 10     2 2 8     3   6    4 4
+--R        b x   + 4a b x   + 6a b x  + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 330
+
+--S 331 of 767
+r0:=(-35/16)/(a^4*x^3)+105/16*b/(a^5*x)+1/6/(a*x^3*(a+b*x^2)^3)+_
+    3/8/(a^2*x^3*(a+b*x^2)^2)+21/16/(a^3*x^3*(a+b*x^2))+_
+    105/16*b^(3/2)*atan(x*sqrt(b)/sqrt(a))/a^(11/2)
+--R 
+--R
+--R   (2)
+--R                                                               +-+
+--R            4 9         3 7       2 2 5       3   3  +-+     x\|b
+--R       (315b x  + 945a b x  + 945a b x  + 315a b x )\|b atan(-----)
+--R                                                               +-+
+--R                                                              \|a
+--R     + 
+--R            4 8         3 6       2 2 4       3   2      4  +-+
+--R       (315b x  + 840a b x  + 693a b x  + 144a b x  - 16a )\|a
+--R  /
+--R         5 3 9       6 2 7       7   5      8 3  +-+
+--R     (48a b x  + 144a b x  + 144a b x  + 48a x )\|a
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 332
+
+)clear all
+
+--S 333 of 767
+t0:=1/(x^6*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R         4 14       3 12     2 2 10     3   8    4 6
+--R        b x   + 4a b x   + 6a b x   + 4a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 333
+
+--S 334 of 767
+r0:=(-231/80)/(a^4*x^5)+77/16*b/(a^5*x^3)-231/16*b^2/(a^6*x)+_
+    1/6/(a*x^5*(a+b*x^2)^3)+11/24/(a^2*x^5*(a+b*x^2)^2)+_
+    33/16/(a^3*x^5*(a+b*x^2))-231/16*b^(5/2)*atan(x*sqrt(b)/sqrt(a))/a^(13/2)
+--R 
+--R
+--R   (2)
+--R                                                                        +-+
+--R               5 11           4 9         2 3 7        3 2 5  +-+     x\|b
+--R       (- 3465b x   - 10395a b x  - 10395a b x  - 3465a b x )\|b atan(-----)
+--R                                                                        +-+
+--R                                                                       \|a
+--R     + 
+--R             5 10          4 8        2 3 6        3 2 4       4   2      5  +-+
+--R     (- 3465b x   - 9240a b x  - 7623a b x  - 1584a b x  + 176a b x  - 48a )\|a
+--R  /
+--R          6 3 11       7 2 9       8   7       9 5  +-+
+--R     (240a b x   + 720a b x  + 720a b x  + 240a x )\|a
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 335
+
+)clear all
+
+--S 336 of 767
+t0:=x^m/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        m
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 767
+--r0:=1/10*x^(1+m)/(a*(a+b*x^2)^5)+1/80*(9-m)*x^(1+m)/(a^2*(a+b*x^2)^4)+_
+--  1/480*(7-m)*(9-m)*x^(1+m)/(a^3*(a+b*x^2)^3)+1/1920*(5-m)*(7-m)*_
+--  (9-m)*x^(1+m)/(a^4*(a+b*x^2)^2)+1/3840*(3-m)*(5-m)*(7-m)*(9-m)*_
+--  x^(1+m)/(a^5*(a+b*x^2))+1/3840*(1-m)*(3-m)*(5-m)*(7-m)*(9-m)*_
+--  x^(1+m)*hypergeometric(1,1/2*(1+m),1/2*(3+m),-b*x^2/a)/(a^6*(1+m))
+--E 337
+
+--S 338 of 767
+--d0:=normalize(t0-D(r0,x))
+--E 338
+
+)clear all
+
+--S 339 of 767
+t0:=x^15/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        15
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 339
+
+--S 340 of 767
+r0:=-3*a*x^2/b^7+1/4*x^4/b^6+1/10*a^7/(b^8*(a+b*x^2)^5)-_
+    7/8*a^6/(b^8*(a+b*x^2)^4)+7/2*a^5/(b^8*(a+b*x^2)^3)-_
+    35/4*a^4/(b^8*(a+b*x^2)^2)+35/2*a^3/(b^8*(a+b*x^2))+_
+    21/2*a^2*log(a+b*x^2)/b^8
+--R 
+--R
+--R   (2)
+--R                 2 5 10        3 4 8        4 3 6        5 2 4        6   2
+--R             420a b x   + 2100a b x  + 4200a b x  + 4200a b x  + 2100a b x
+--R           + 
+--R                 7
+--R             420a
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R          7 14        6 12       2 5 10       3 4 8        4 3 6        5 2 4
+--R       10b x   - 70a b x   - 500a b x   - 400a b x  + 1300a b x  + 2700a b x
+--R     + 
+--R            6   2       7
+--R       1875a b x  + 459a
+--R  /
+--R        13 10         12 8       2 11 6       3 10 4       4 9 2      5 8
+--R     40b  x   + 200a b  x  + 400a b  x  + 400a b  x  + 200a b x  + 40a b
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 341
+
+)clear all
+
+--S 342 of 767
+t0:=x^13/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        13
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 342
+
+--S 343 of 767
+r0:=1/2*x^2/b^6-1/10*a^6/(b^7*(a+b*x^2)^5)+3/4*a^5/(b^7*(a+b*x^2)^4)-_
+    5/2*a^4/(b^7*(a+b*x^2)^3)+5*a^3/(b^7*(a+b*x^2)^2)-_
+    15/2*a^2/(b^7*(a+b*x^2))-3*a*log(a+b*x^2)/b^7
+--R 
+--R
+--R   (2)
+--R                 5 10       2 4 8       3 3 6       4 2 4       5   2      6
+--R         (- 60a b x   - 300a b x  - 600a b x  - 600a b x  - 300a b x  - 60a )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R        6 12        5 10      2 4 8       3 3 6       4 2 4       5   2      6
+--R     10b x   + 50a b x   - 50a b x  - 400a b x  - 600a b x  - 375a b x  - 87a
+--R  /
+--R        12 10         11 8       2 10 6       3 9 4       4 8 2      5 7
+--R     20b  x   + 100a b  x  + 200a b  x  + 200a b x  + 100a b x  + 20a b
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 344
+
+)clear all
+
+--S 345 of 767
+t0:=x^11/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        11
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 345
+
+--S 346 of 767
+r0:=1/10*a^5/(b^6*(a+b*x^2)^5)-5/8*a^4/(b^6*(a+b*x^2)^4)+_
+    5/3*a^3/(b^6*(a+b*x^2)^3)-5/2*a^2/(b^6*(a+b*x^2)^2)+_
+    5/2*a/(b^6*(a+b*x^2))+1/2*log(a+b*x^2)/b^6
+--R 
+--R
+--R   (2)
+--R             5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (60b x   + 300a b x  + 600a b x  + 600a b x  + 300a b x  + 60a )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R             4 8       2 3 6        3 2 4       4   2       5
+--R       300a b x  + 900a b x  + 1100a b x  + 625a b x  + 137a
+--R  /
+--R         11 10         10 8        2 9 6        3 8 4       4 7 2       5 6
+--R     120b  x   + 600a b  x  + 1200a b x  + 1200a b x  + 600a b x  + 120a b
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 347
+
+)clear all
+
+--S 348 of 767
+t0:=x^9/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        9
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 348
+
+--S 349 of 767
+r0:=1/10*x^10/(a*(a+b*x^2)^5)
+--R 
+--R
+--R                                 1  10
+--R                                -- x
+--R                                10
+--R   (2)  ------------------------------------------------------
+--R           5 10     2 4 8      3 3 6      4 2 4     5   2    6
+--R        a b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 349
+
+--S 350 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 350
+
+)clear all
+
+--S 351 of 767
+t0:=x^7/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        7
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 351
+
+--S 352 of 767
+r0:=1/10*x^8/(a*(a+b*x^2)^5)+1/40*x^8/(a^2*(a+b*x^2)^4)
+--R 
+--R
+--R                            1    10   1    8
+--R                           -- b x   + - a x
+--R                           40         8
+--R   (2)  ------------------------------------------------------
+--R         2 5 10     3 4 8      4 3 6      5 2 4     6   2    7
+--R        a b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 352
+
+--S 353 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 353
+
+)clear all
+
+--S 354 of 767
+t0:=x^5/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        5
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 354
+
+--S 355 of 767
+r0:=-1/10*a^2/(b^3*(a+b*x^2)^5)+1/4*a/(b^3*(a+b*x^2)^4)+_
+    (-1/6)/(b^3*(a+b*x^2)^3)
+--R 
+--R
+--R                       1  2 4    1      2    1  2
+--R                     - - b x  - -- a b x  - -- a
+--R                       6        12          60
+--R   (2)  ------------------------------------------------------
+--R         8 10       7 8      2 6 6      3 5 4     4 4 2    5 3
+--R        b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 355
+
+--S 356 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 356
+
+)clear all
+
+--S 357 of 767
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        3
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 357
+
+--S 358 of 767
+r0:=1/10*a/(b^2*(a+b*x^2)^5)+(-1/8)/(b^2*(a+b*x^2)^4)
+--R 
+--R
+--R                              1    2    1
+--R                            - - b x  - -- a
+--R                              8        40
+--R   (2)  ------------------------------------------------------
+--R         7 10       6 8      2 5 6      3 4 4     4 3 2    5 2
+--R        b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 358
+
+--S 359 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 359
+
+)clear all
+
+--S 360 of 767
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 360
+
+--S 361 of 767
+r0:=(-1/10)/(b*(a+b*x^2)^5)
+--R 
+--R
+--R                                     1
+--R                                    --
+--R                                    10
+--R   (2)  - -----------------------------------------------------
+--R           6 10       5 8      2 4 6      3 3 4     4 2 2    5
+--R          b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 361
+
+--S 362 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 362
+
+)clear all
+
+--S 363 of 767
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                        1
+--R   (1)  -----------------------------------------------------------------
+--R         6 13       5 11      2 4 9      3 3 7      4 2 5     5   3    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 363
+
+--S 364 of 767
+r0:=1/10/(a*(a+b*x^2)^5)+1/8/(a^2*(a+b*x^2)^4)+1/6/(a^3*(a+b*x^2)^3)+_
+    1/4/(a^4*(a+b*x^2)^2)+1/2/(a^5*(a+b*x^2))+log(x)/a^6-1/2*log(a+b*x^2)/a^6
+--R 
+--R
+--R   (2)
+--R               5 10         4 8       2 3 6       3 2 4       4   2      5
+--R         (- 60b x   - 300a b x  - 600a b x  - 600a b x  - 300a b x  - 60a )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R              5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (120b x   + 600a b x  + 1200a b x  + 1200a b x  + 600a b x  + 120a )
+--R      *
+--R         log(x)
+--R     + 
+--R            4 8       2 3 6       3 2 4       4   2       5
+--R       60a b x  + 270a b x  + 470a b x  + 385a b x  + 137a
+--R  /
+--R         6 5 10       7 4 8        8 3 6        9 2 4       10   2       11
+--R     120a b x   + 600a b x  + 1200a b x  + 1200a b x  + 600a  b x  + 120a
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 365
+
+)clear all
+
+--S 366 of 767
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R         6 15       5 13      2 4 11      3 3 9      4 2 7     5   5    6 3
+--R        b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 366
+
+--S 367 of 767
+r0:=(-3)/(a^6*x^2)+1/10/(a*x^2*(a+b*x^2)^5)+3/20/(a^2*x^2*(a+b*x^2)^4)+_
+    1/4/(a^3*x^2*(a+b*x^2)^3)+1/2/(a^4*x^2*(a+b*x^2)^2)+_
+    3/2/(a^5*x^2*(a+b*x^2))-6*b*log(x)/a^7+3*b*log(a+b*x^2)/a^7
+--R 
+--R
+--R   (2)
+--R             6 12         5 10       2 4 8       3 3 6       4 2 4      5   2
+--R         (60b x   + 300a b x   + 600a b x  + 600a b x  + 300a b x  + 60a b x )
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R                 6 12         5 10        2 4 8        3 3 6       4 2 4
+--R           - 120b x   - 600a b x   - 1200a b x  - 1200a b x  - 600a b x
+--R         + 
+--R                 5   2
+--R           - 120a b x
+--R      *
+--R         log(x)
+--R     + 
+--R              5 10       2 4 8       3 3 6       4 2 4       5   2      6
+--R       - 60a b x   - 270a b x  - 470a b x  - 385a b x  - 137a b x  - 10a
+--R  /
+--R        7 5 12       8 4 10       9 3 8       10 2 6       11   4      12 2
+--R     20a b x   + 100a b x   + 200a b x  + 200a  b x  + 100a  b x  + 20a  x
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 368
+
+)clear all
+
+--S 369 of 767
+t0:=1/(x^5*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R         6 17       5 15      2 4 13      3 3 11      4 2 9     5   7    6 5
+--R        b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x  + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 369
+
+--S 370 of 767
+r0:=(-21/4)/(a^6*x^4)+21/2*b/(a^7*x^2)+1/10/(a*x^4*(a+b*x^2)^5)+_
+    7/40/(a^2*x^4*(a+b*x^2)^4)+7/20/(a^3*x^4*(a+b*x^2)^3)+_
+    7/8/(a^4*x^4*(a+b*x^2)^2)+7/2/(a^5*x^4*(a+b*x^2))+_
+    21*b^2*log(x)/a^8-21/2*b^2*log(a+b*x^2)/a^8
+--R 
+--R
+--R   (2)
+--R                 7 14          6 12        2 5 10        3 4 8        4 3 6
+--R           - 420b x   - 2100a b x   - 4200a b x   - 4200a b x  - 2100a b x
+--R         + 
+--R                 5 2 4
+--R           - 420a b x
+--R      *
+--R                2
+--R         log(b x  + a)
+--R     + 
+--R               7 14          6 12        2 5 10        3 4 8        4 3 6
+--R           840b x   + 4200a b x   + 8400a b x   + 8400a b x  + 4200a b x
+--R         + 
+--R               5 2 4
+--R           840a b x
+--R      *
+--R         log(x)
+--R     + 
+--R             6 12        2 5 10        3 4 8        4 3 6       5 2 4      6   2
+--R       420a b x   + 1890a b x   + 3290a b x  + 2695a b x  + 959a b x  + 70a b x
+--R     + 
+--R            7
+--R       - 10a
+--R  /
+--R        8 5 14       9 4 12       10 3 10       11 2 8       12   6      13 4
+--R     40a b x   + 200a b x   + 400a  b x   + 400a  b x  + 200a  b x  + 40a  x
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 371
+
+)clear all
+
+--S 372 of 767
+t0:=x^16/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        16
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 372
+
+--S 373 of 767
+r0:=9009/256*a^2*x/b^8-3003/256*a*x^3/b^7+9009/1280*x^5/b^6-_
+    1/10*x^15/(b*(a+b*x^2)^5)-3/16*x^13/(b^2*(a+b*x^2)^4)-_
+    13/32*x^11/(b^3*(a+b*x^2)^3)-143/128*x^9/(b^4*(a+b*x^2)^2)-_
+    1287/256*x^7/(b^5*(a+b*x^2))-9009/256*a^(5/2)*atan(x*_
+    sqrt(b)/sqrt(a))/b^(17/2)
+--R 
+--R
+--R   (2)
+--R                   2 5 10          3 4 8          4 3 6          5 2 4
+--R           - 45045a b x   - 225225a b x  - 450450a b x  - 450450a b x
+--R         + 
+--R                    6   2         7
+--R           - 225225a b x  - 45045a
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|a atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R               7 15          6 13         2 5 11          3 4 9          4 3 7
+--R           256b x   - 1280a b x   + 16640a b x   + 137995a b x  + 338910a b x
+--R         + 
+--R                  5 2 5          6   3         7
+--R           384384a b x  + 210210a b x  + 45045a x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              13 10          12 8         2 11 6         3 10 4        4 9 2
+--R         1280b  x   + 6400a b  x  + 12800a b  x  + 12800a b  x  + 6400a b x
+--R       + 
+--R              5 8
+--R         1280a b
+--R    *
+--R        +-+
+--R       \|b
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 374
+
+)clear all
+
+--S 375 of 767
+t0:=x^14/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        14
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 375
+
+--S 376 of 767
+r0:=-3003/256*a*x/b^7+1001/256*x^3/b^6-1/10*x^13/(b*(a+b*x^2)^5)-_
+    13/80*x^11/(b^2*(a+b*x^2)^4)-143/480*x^9/(b^3*(a+b*x^2)^3)-_
+    429/640*x^7/(b^4*(a+b*x^2)^2)-3003/1280*x^5/(b^5*(a+b*x^2))+_
+    3003/256*a^(3/2)*atan(x*sqrt(b)/sqrt(a))/b^(15/2)
+--R 
+--R
+--R   (2)
+--R                   5 10          2 4 8          3 3 6          4 2 4
+--R           45045a b x   + 225225a b x  + 450450a b x  + 450450a b x
+--R         + 
+--R                  5   2         6
+--R           225225a b x  + 45045a
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|a atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                6 13           5 11          2 4 9          3 3 7          4 2 5
+--R           1280b x   - 16640a b x   - 137995a b x  - 338910a b x  - 384384a b x
+--R         + 
+--R                    5   3         6
+--R           - 210210a b x  - 45045a x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              12 10           11 8         2 10 6         3 9 4         4 8 2
+--R         3840b  x   + 19200a b  x  + 38400a b  x  + 38400a b x  + 19200a b x
+--R       + 
+--R              5 7
+--R         3840a b
+--R    *
+--R        +-+
+--R       \|b
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 377
+
+)clear all
+
+--S 378 of 767
+t0:=x^12/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        12
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 378
+
+--S 379 of 767
+r0:=693/256*x/b^6-1/10*x^11/(b*(a+b*x^2)^5)-11/80*x^9/(b^2*(a+b*x^2)^4)-_
+    33/160*x^7/(b^3*(a+b*x^2)^3)-231/640*x^5/(b^4*(a+b*x^2)^2)-_
+    231/256*x^3/(b^5*(a+b*x^2))-693/256*atan(x*sqrt(b)/sqrt(a))*_
+    sqrt(a)/b^(13/2)
+--R 
+--R
+--R   (2)
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 3465b x   - 17325a b x  - 34650a b x  - 34650a b x  - 17325a b x
+--R         + 
+--R                  5
+--R           - 3465a
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|a atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                5 11           4 9         2 3 7         3 2 5         4   3
+--R           1280b x   + 10615a b x  + 26070a b x  + 29568a b x  + 16170a b x
+--R         + 
+--R                5
+--R           3465a x
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R              11 10          10 8         2 9 6         3 8 4        4 7 2
+--R         1280b  x   + 6400a b  x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              5 6
+--R         1280a b
+--R    *
+--R        +-+
+--R       \|b
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 380
+
+)clear all
+
+--S 381 of 767
+t0:=x^10/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        10
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 381
+
+--S 382 of 767
+r0:=-1/10*x^9/(b*(a+b*x^2)^5)-9/80*x^7/(b^2*(a+b*x^2)^4)-_
+    21/160*x^5/(b^3*(a+b*x^2)^3)-21/128*x^3/(b^4*(a+b*x^2)^2)-_
+    63/256*x/(b^5*(a+b*x^2))+63/256*atan(x*sqrt(b)/sqrt(a))/(b^(11/2)*sqrt(a))
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x  + 315a )
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R              4 9          3 7        2 2 5        3   3       4   +-+ +-+
+--R       (- 965b x  - 2370a b x  - 2688a b x  - 1470a b x  - 315a x)\|a \|b
+--R  /
+--R              10 10          9 8         2 8 6         3 7 4        4 6 2
+--R         1280b  x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              5 5
+--R         1280a b
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 383
+
+)clear all
+
+--S 384 of 767
+t0:=x^8/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        8
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 384
+
+--S 385 of 767
+r0:=-1/10*x^7/(b*(a+b*x^2)^5)-7/80*x^5/(b^2*(a+b*x^2)^4)-_
+    7/96*x^3/(b^3*(a+b*x^2)^3)-7/128*x/(b^4*(a+b*x^2)^2)+_
+    7/256*x/(a*b^4*(a+b*x^2))+7/256*atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*b^(9/2))
+--R 
+--R
+--R   (2)
+--R              5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (105b x   + 525a b x  + 1050a b x  + 1050a b x  + 525a b x  + 105a )
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R            4 9         3 7       2 2 5       3   3       4   +-+ +-+
+--R       (105b x  - 790a b x  - 896a b x  - 490a b x  - 105a x)\|a \|b
+--R  /
+--R                9 10         2 8 8         3 7 6         4 6 4         5 5 2
+--R         3840a b x   + 19200a b x  + 38400a b x  + 38400a b x  + 19200a b x
+--R       + 
+--R              6 4
+--R         3840a b
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 386
+
+)clear all
+
+--S 387 of 767
+t0:=x^6/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        6
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 387
+
+--S 388 of 767
+r0:=-1/10*x^5/(b*(a+b*x^2)^5)-1/16*x^3/(b^2*(a+b*x^2)^4)-_
+    1/32*x/(b^3*(a+b*x^2)^3)+1/128*x/(a*b^3*(a+b*x^2)^2)+_
+    3/256*x/(a^2*b^3*(a+b*x^2))+3/256*atan(x*sqrt(b)/sqrt(a))/(a^(5/2)*b^(7/2))
+--R 
+--R
+--R   (2)
+--R                                                                            +-+
+--R           5 10        4 8       2 3 6       3 2 4      4   2      5      x\|b
+--R       (15b x   + 75a b x  + 150a b x  + 150a b x  + 75a b x  + 15a )atan(-----)
+--R                                                                            +-+
+--R                                                                           \|a
+--R     + 
+--R           4 9        3 7       2 2 5      3   3      4   +-+ +-+
+--R       (15b x  + 70a b x  - 128a b x  - 70a b x  - 15a x)\|a \|b
+--R  /
+--R              2 8 10        3 7 8         4 6 6         5 5 4        6 4 2
+--R         1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              7 3
+--R         1280a b
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 389
+
+)clear all
+
+--S 390 of 767
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        4
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 390
+
+--S 391 of 767
+r0:=-1/10*x^3/(b*(a+b*x^2)^5)-3/80*x/(b^2*(a+b*x^2)^4)+_
+    1/160*x/(a*b^2*(a+b*x^2)^3)+1/128*x/(a^2*b^2*(a+b*x^2)^2)+_
+    3/256*x/(a^3*b^2*(a+b*x^2))+3/256*atan(x*sqrt(b)/sqrt(a))/(a^(7/2)*b^(5/2))
+--R 
+--R
+--R   (2)
+--R                                                                            +-+
+--R           5 10        4 8       2 3 6       3 2 4      4   2      5      x\|b
+--R       (15b x   + 75a b x  + 150a b x  + 150a b x  + 75a b x  + 15a )atan(-----)
+--R                                                                            +-+
+--R                                                                           \|a
+--R     + 
+--R           4 9        3 7       2 2 5      3   3      4   +-+ +-+
+--R       (15b x  + 70a b x  + 128a b x  - 70a b x  - 15a x)\|a \|b
+--R  /
+--R              3 7 10        4 6 8         5 5 6         6 4 4        7 3 2
+--R         1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              8 2
+--R         1280a b
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 392
+
+)clear all
+
+--S 393 of 767
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        2
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 393
+
+--S 394 of 767
+r0:=-1/10*x/(b*(a+b*x^2)^5)+1/80*x/(a*b*(a+b*x^2)^4)+_
+    7/480*x/(a^2*b*(a+b*x^2)^3)+7/384*x/(a^3*b*(a+b*x^2)^2)+_
+    7/256*x/(a^4*b*(a+b*x^2))+7/256*atan(x*sqrt(b)/sqrt(a))/(a^(9/2)*b^(3/2))
+--R 
+--R
+--R   (2)
+--R              5 10         4 8        2 3 6        3 2 4       4   2       5
+--R         (105b x   + 525a b x  + 1050a b x  + 1050a b x  + 525a b x  + 105a )
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R            4 9         3 7       2 2 5       3   3       4   +-+ +-+
+--R       (105b x  + 490a b x  + 896a b x  + 790a b x  - 105a x)\|a \|b
+--R  /
+--R              4 6 10         5 5 8         6 4 6         7 3 4         8 2 2
+--R         3840a b x   + 19200a b x  + 38400a b x  + 38400a b x  + 19200a b x
+--R       + 
+--R              9
+--R         3840a b
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 395
+
+)clear all
+
+--S 396 of 767
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        1
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 396
+
+--S 397 of 767
+r0:=1/10*x/(a*(a+b*x^2)^5)+9/80*x/(a^2*(a+b*x^2)^4)+_
+    21/160*x/(a^3*(a+b*x^2)^3)+21/128*x/(a^4*(a+b*x^2)^2)+_
+    63/256*x/(a^5*(a+b*x^2))+63/256*atan(x*sqrt(b)/sqrt(a))/(a^(11/2)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x  + 315a )
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R            4 9          3 7        2 2 5        3   3       4   +-+ +-+
+--R       (315b x  + 1470a b x  + 2688a b x  + 2370a b x  + 965a x)\|a \|b
+--R  /
+--R              5 5 10        6 4 8         7 3 6         8 2 4        9   2
+--R         1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a b x
+--R       + 
+--R              10
+--R         1280a
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 398
+
+)clear all
+
+--S 399 of 767
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R         6 14       5 12      2 4 10      3 3 8      4 2 6     5   4    6 2
+--R        b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 399
+
+--S 400 of 767
+r0:=(-693/256)/(a^6*x)+1/10/(a*x*(a+b*x^2)^5)+11/80/(a^2*x*(a+b*x^2)^4)+_
+    33/160/(a^3*x*(a+b*x^2)^3)+231/640/(a^4*x*(a+b*x^2)^2)+_
+    231/256/(a^5*x*(a+b*x^2))-693/256*atan(x*sqrt(b)/sqrt(a))*sqrt(b)/a^(13/2)
+--R 
+--R
+--R   (2)
+--R                  5 11           4 9         2 3 7         3 2 5         4   3
+--R           - 3465b x   - 17325a b x  - 34650a b x  - 34650a b x  - 17325a b x
+--R         + 
+--R                  5
+--R           - 3465a x
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 3465b x   - 16170a b x  - 29568a b x  - 26070a b x  - 10615a b x
+--R         + 
+--R                  5
+--R           - 1280a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R              6 5 11        7 4 9         8 3 7         9 2 5        10   3
+--R         1280a b x   + 6400a b x  + 12800a b x  + 12800a b x  + 6400a  b x
+--R       + 
+--R              11
+--R         1280a  x
+--R    *
+--R        +-+
+--R       \|a
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 401
+
+)clear all
+
+--S 402 of 767
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R         6 16       5 14      2 4 12      3 3 10      4 2 8     5   6    6 4
+--R        b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x  + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 402
+
+--S 403 of 767
+r0:=(-1001/256)/(a^6*x^3)+3003/256*b/(a^7*x)+1/10/(a*x^3*(a+b*x^2)^5)+_
+    13/80/(a^2*x^3*(a+b*x^2)^4)+143/480/(a^3*x^3*(a+b*x^2)^3)+_
+    429/640/(a^4*x^3*(a+b*x^2)^2)+3003/1280/(a^5*x^3*(a+b*x^2))+_
+    3003/256*b^(3/2)*atan(x*sqrt(b)/sqrt(a))/a^(15/2)
+--R 
+--R
+--R   (2)
+--R                 6 13            5 11          2 4 9          3 3 7
+--R           45045b x   + 225225a b x   + 450450a b x  + 450450a b x
+--R         + 
+--R                  4 2 5         5   3
+--R           225225a b x  + 45045a b x
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                 6 12            5 10          2 4 8          3 3 6
+--R           45045b x   + 210210a b x   + 384384a b x  + 338910a b x
+--R         + 
+--R                  4 2 4         5   2        6
+--R           137995a b x  + 16640a b x  - 1280a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R              7 5 13         8 4 11         9 3 9         10 2 7         11   5
+--R         3840a b x   + 19200a b x   + 38400a b x  + 38400a  b x  + 19200a  b x
+--R       + 
+--R              12 3
+--R         3840a  x
+--R    *
+--R        +-+
+--R       \|a
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 404
+
+)clear all
+
+--S 405 of 767
+t0:=1/(x^6*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R                                          1
+--R   (1)  ---------------------------------------------------------------------
+--R         6 18       5 16      2 4 14      3 3 12      4 2 10     5   8    6 6
+--R        b x   + 6a b x   + 15a b x   + 20a b x   + 15a b x   + 6a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 405
+
+--S 406 of 767
+r0:=(-9009/1280)/(a^6*x^5)+3003/256*b/(a^7*x^3)-9009/256*b^2/(a^8*x)+_
+    1/10/(a*x^5*(a+b*x^2)^5)+3/16/(a^2*x^5*(a+b*x^2)^4)+_
+    13/32/(a^3*x^5*(a+b*x^2)^3)+143/128/(a^4*x^5*(a+b*x^2)^2)+_
+    1287/256/(a^5*x^5*(a+b*x^2))-9009/256*b^(5/2)*atan(x*_
+    sqrt(b)/sqrt(a))/a^(17/2)
+--R 
+--R
+--R   (2)
+--R                   7 15            6 13          2 5 11          3 4 9
+--R           - 45045b x   - 225225a b x   - 450450a b x   - 450450a b x
+--R         + 
+--R                    4 3 7         5 2 5
+--R           - 225225a b x  - 45045a b x
+--R      *
+--R                    +-+
+--R          +-+     x\|b
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R                   7 14            6 12          2 5 10          3 4 8
+--R           - 45045b x   - 210210a b x   - 384384a b x   - 338910a b x
+--R         + 
+--R                    4 3 6         5 2 4        6   2       7
+--R           - 137995a b x  - 16640a b x  + 1280a b x  - 256a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R              8 5 15        9 4 13         10 3 11         11 2 9        12   7
+--R         1280a b x   + 6400a b x   + 12800a  b x   + 12800a  b x  + 6400a  b x
+--R       + 
+--R              13 5
+--R         1280a  x
+--R    *
+--R        +-+
+--R       \|a
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 407
+
+)clear all
+
+--S 408 of 767
+t0:=1/(1+2*x^2+x^4)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 408
+
+--S 409 of 767
+r0:=1/2*x/(1+x^2)+1/2*atan(x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atan(x) + x
+--R   (2)  -------------------
+--R                2
+--R              2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 410
+
+)clear all
+
+--S 411 of 767
+t0:=x/(1+2*x^2+x^4)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 411
+
+--S 412 of 767
+r0:=(-1/2)/(1+x^2)
+--R 
+--R
+--R             1
+--R             -
+--R             2
+--R   (2)  - ------
+--R           2
+--R          x  + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 412
+
+--S 413 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 413
+
+)clear all
+
+--S 414 of 767
+t0:=x^2/(1+2*x^2+x^4)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 414
+
+--S 415 of 767
+r0:=-1/2*x/(1+x^2)+1/2*atan(x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atan(x) - x
+--R   (2)  -------------------
+--R                2
+--R              2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 416
+
+)clear all
+
+--S 417 of 767
+t0:=x^3/(1+2*x^2+x^4)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 417
+
+--S 418 of 767
+r0:=1/2/(1+x^2)+1/2*log(1+x^2)
+--R 
+--R
+--R          2          2
+--R        (x  + 1)log(x  + 1) + 1
+--R   (2)  -----------------------
+--R                  2
+--R                2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 419
+
+)clear all
+
+--S 420 of 767
+t0:=x/(81-18*x^2+x^4)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R         4      2
+--R        x  - 18x  + 81
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 420
+
+--S 421 of 767
+r0:=1/2/(9-x^2)
+--R 
+--R
+--R             1
+--R             -
+--R             2
+--R   (2)  - ------
+--R           2
+--R          x  - 9
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 421
+
+--S 422 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 422
+
+)clear all
+
+--S 423 of 767
+t0:=x^3/(16-8*x^2+x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  -------------
+--R         4     2
+--R        x  - 8x  + 16
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 423
+
+--S 424 of 767
+r0:=2/(4-x^2)+1/2*log(4-x^2)
+--R 
+--R
+--R          2            2
+--R        (x  - 4)log(- x  + 4) - 4
+--R   (2)  -------------------------
+--R                   2
+--R                 2x  - 8
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 425
+
+)clear all
+
+--S 426 of 767
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R           +-------------------+
+--R         m | 2 4         2    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 426
+
+--S 427 of 767
+r0:=x^(1+m)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(3+m)+2*a*x^(1+m)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/((3+4*m+m^2)*(a+b*x^2))
+--R 
+--R
+--R                                       +-------------------+
+--R                   2             m + 1 | 2 4         2    2
+--R        ((b m + b)x  + a m + 3a)x     \|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------
+--R                   2              2      2
+--R               (b m  + 4b m + 3b)x  + a m  + 4a m + 3a
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 428
+
+)clear all
+
+--S 429 of 767
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R           +-------------------+
+--R         5 | 2 4         2    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 429
+
+--S 430 of 767
+r0:=1/8*x^6*sqrt(a^2+2*a*b*x^2+b^2*x^4)+1/24*a*x^6*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                        +-------------------+
+--R             8       6  | 2 4         2    2
+--R        (3b x  + 4a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          2
+--R                     24b x  + 24a
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 431
+
+)clear all
+
+--S 432 of 767
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R           +-------------------+
+--R         4 | 2 4         2    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 432
+
+--S 433 of 767
+r0:=1/7*x^5*sqrt(a^2+2*a*b*x^2+b^2*x^4)+2/35*a*x^5*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                        +-------------------+
+--R             7       5  | 2 4         2    2
+--R        (5b x  + 7a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          2
+--R                     35b x  + 35a
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 434
+
+)clear all
+
+--S 435 of 767
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R           +-------------------+
+--R         3 | 2 4         2    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 435
+
+--S 436 of 767
+r0:=1/6*x^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)+1/12*a*x^4*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                        +-------------------+
+--R             6       4  | 2 4         2    2
+--R        (2b x  + 3a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          2
+--R                     12b x  + 12a
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 437
+
+)clear all
+
+--S 438 of 767
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R           +-------------------+
+--R         2 | 2 4         2    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 438
+
+--S 439 of 767
+r0:=1/5*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4)+2/15*a*x^3*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                        +-------------------+
+--R             5       3  | 2 4         2    2
+--R        (3b x  + 5a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          2
+--R                     15b x  + 15a
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 440
+
+)clear all
+
+--S 441 of 767
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 4         2    2
+--R   (1)  x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 441
+
+--S 442 of 767
+r0:=1/4*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/b
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2
+--R        (b x  + a)\|b x  + 2a b x  + a
+--R   (2)  --------------------------------
+--R                       4b
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 443
+
+)clear all
+
+--S 444 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R   (1)  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 767
+r0:=1/3*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+2/3*a*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                      +-------------------+
+--R            3         | 2 4         2    2
+--R        (b x  + 3a x)\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------
+--R                         2
+--R                     3b x  + 3a
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 446
+
+)clear all
+
+--S 447 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 767
+r0:=1/2*sqrt(a^2+2*a*b*x^2+b^2*x^4)+a*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                               +-------------------+
+--R                        2      | 2 4         2    2
+--R        (2a log(x) + b x  + a)\|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------
+--R                             2
+--R                         2b x  + 2a
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 449
+
+)clear all
+
+--S 450 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^2
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   2
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 450
+
+--S 451 of 767
+r0:=sqrt(a^2+2*a*b*x^2+b^2*x^4)/x-2*a*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x*(a+b*x^2))
+--R 
+--R
+--R                   +-------------------+
+--R            2      | 2 4         2    2
+--R        (b x  - a)\|b x  + 2a b x  + a
+--R   (2)  --------------------------------
+--R                      3
+--R                   b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 452
+
+)clear all
+
+--S 453 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^3
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   3
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 453
+
+--S 454 of 767
+r0:=-1/2*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^2*(a+b*x^2))+_
+    b*log(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                          +-------------------+
+--R             2            | 2 4         2    2
+--R        (2b x log(x) - a)\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------
+--R                         4       2
+--R                     2b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 455
+
+)clear all
+
+--S 456 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^4
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   4
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 767
+r0:=-sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3+2/3*a*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^3*(a+b*x^2))
+--R 
+--R
+--R                      +-------------------+
+--R               2      | 2 4         2    2
+--R        (- 3b x  - a)\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------
+--R                       5       3
+--R                   3b x  + 3a x
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 458
+
+)clear all
+
+--S 459 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^5
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   5
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 767
+r0:=-1/4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/(a*x^4)
+--R 
+--R
+--R                     +-------------------+
+--R              2      | 2 4         2    2
+--R        (- b x  - a)\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------
+--R                           4
+--R                       4a x
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 461
+
+)clear all
+
+--S 462 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^6
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   6
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 767
+r0:=-1/3*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^5+_
+    2/15*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^5*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 5b x  - 3a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                        7        5
+--R                   15b x  + 15a x
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 464
+
+)clear all
+
+--S 465 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^7
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   7
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 767
+r0:=-1/4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^6+_
+    1/12*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^6*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 3b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                        8        6
+--R                   12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 467
+
+)clear all
+
+--S 468 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^8
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   8
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 468
+
+--S 469 of 767
+r0:=-1/5*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^7+_
+    2/35*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^7*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 7b x  - 5a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                        9        7
+--R                   35b x  + 35a x
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 470
+
+)clear all
+
+--S 471 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^9
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   9
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 767
+r0:=-1/6*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^8+_
+    1/24*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^8*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 4b x  - 3a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       10        8
+--R                  24b x   + 24a x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 473
+
+)clear all
+
+--S 474 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^10
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   10
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 474
+
+--S 475 of 767
+r0:=-1/7*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^9+_
+    2/63*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^9*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 9b x  - 7a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       11        9
+--R                  63b x   + 63a x
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 476
+
+)clear all
+
+--S 477 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^11
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   11
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 767
+r0:=-1/8*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^10+_
+    1/40*a*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^10*(a+b*x^2))
+--R 
+--R
+--R                       +-------------------+
+--R               2       | 2 4         2    2
+--R        (- 5b x  - 4a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       12        10
+--R                  40b x   + 40a x
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 479
+
+)clear all
+
+--S 480 of 767
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 4         2    2  m | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a )x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 480
+
+--S 481 of 767
+r0:=x^(1+m)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(7+m)+24*a^2*x^(1+m)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/((3+m)*(5+m)*(7+m))+48*a^3*x^(1+m)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/((5+m)*(7+m)*(3+4*m+m^2)*(a+b*x^2))+_
+    6*a*x^(1+m)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/((5+m)*(7+m))
+--R 
+--R
+--R   (2)
+--R           3 3     3 2      3       3  6
+--R         (b m  + 9b m  + 23b m + 15b )x
+--R       + 
+--R              2 3        2 2        2         2  4
+--R         (3a b m  + 33a b m  + 93a b m + 63a b )x
+--R       + 
+--R            2   3      2   2       2          2   2    3 3      3 2      3
+--R         (3a b m  + 39a b m  + 141a b m + 105a b)x  + a m  + 15a m  + 71a m
+--R       + 
+--R             3
+--R         105a
+--R    *
+--R              +-------------------+
+--R        m + 1 | 2 4         2    2
+--R       x     \|b x  + 2a b x  + a
+--R  /
+--R           4        3        2                  2      4        3        2
+--R       (b m  + 16b m  + 86b m  + 176b m + 105b)x  + a m  + 16a m  + 86a m
+--R     + 
+--R       176a m + 105a
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 482
+
+)clear all
+
+--S 483 of 767
+t0:=x^9*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 13         11    2 9  | 2 4         2    2
+--R   (1)  (b x   + 2a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 767
+r0:=1/16*x^10*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/112*a^2*x^10*sqrt(a^2+_
+    2*a*b*x^2+b^2*x^4)+1/560*a^3*x^10*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+    (a+b*x^2)+3/112*a*x^10*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                      +-------------------+
+--R            3 16         2 14       2   12      3 10  | 2 4         2    2
+--R        (35b x   + 120a b x   + 140a b x   + 56a x  )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------------------
+--R                                         2
+--R                                   560b x  + 560a
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 485
+
+)clear all
+
+--S 486 of 767
+t0:=x^8*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 12         10    2 8  | 2 4         2    2
+--R   (1)  (b x   + 2a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 767
+r0:=1/15*x^9*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/715*a^2*x^9*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/6435*a^3*x^9*sqrt(a^2+2*a*b*x^2+_
+    b^2*x^4)/(a+b*x^2)+2/65*a*x^9*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                         +-------------------+
+--R             3 15          2 13        2   11       3 9  | 2 4         2    2
+--R        (429b x   + 1485a b x   + 1755a b x   + 715a x )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------------
+--R                                          2
+--R                                   6435b x  + 6435a
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 488
+
+)clear all
+
+--S 489 of 767
+t0:=x^7*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                 +-------------------+
+--R          2 11         9    2 7  | 2 4         2    2
+--R   (1)  (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 767
+r0:=1/14*x^8*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/70*a^2*x^8*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+1/280*a^3*x^8*sqrt(a^2+2*a*b*x^2+_
+    b^2*x^4)/(a+b*x^2)+1/28*a*x^8*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                   +-------------------+
+--R            3 14        2 12      2   10      3 8  | 2 4         2    2
+--R        (20b x   + 70a b x   + 84a b x   + 35a x )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                       2
+--R                                 280b x  + 280a
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 491
+
+)clear all
+
+--S 492 of 767
+t0:=x^6*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                 +-------------------+
+--R          2 10         8    2 6  | 2 4         2    2
+--R   (1)  (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 492
+
+--S 493 of 767
+r0:=1/13*x^7*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/429*a^2*x^7*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/3003*a^3*x^7*sqrt(a^2+2*a*b*x^2+_
+    b^2*x^4)/(a+b*x^2)+6/143*a*x^7*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                       +-------------------+
+--R             3 13         2 11        2   9       3 7  | 2 4         2    2
+--R        (231b x   + 819a b x   + 1001a b x  + 429a x )\|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------------------------------
+--R                                         2
+--R                                  3003b x  + 3003a
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 494
+
+)clear all
+
+--S 495 of 767
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 9         7    2 5  | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 495
+
+--S 496 of 767
+r0:=1/24*a^2*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/b^3+_
+    1/12*x^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/b-_
+    1/30*a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^3
+--R 
+--R
+--R   (2)
+--R                                                          +-------------------+
+--R       5 10        4 8      2 3 6    3 2 4    4   2    5  | 2 4         2    2
+--R   (10b x   + 26a b x  + 19a b x  + a b x  - a b x  + a )\|b x  + 2a b x  + a
+--R   ----------------------------------------------------------------------------
+--R                                           3
+--R                                       120b
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 497
+
+)clear all
+
+--S 498 of 767
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 8         6    2 4  | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 767
+r0:=1/11*x^5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/231*a^2*x^5*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/1155*a^3*x^5*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+2/33*a*x^5*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                     +-------------------+
+--R             3 11         2 9       2   7       3 5  | 2 4         2    2
+--R        (105b x   + 385a b x  + 495a b x  + 231a x )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------------
+--R                                        2
+--R                                 1155b x  + 1155a
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 500
+
+)clear all
+
+--S 501 of 767
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 7         5    2 3  | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 767
+r0:=-1/8*a*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/b^2+_
+    1/10*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^2
+--R 
+--R
+--R                                                   +-------------------+
+--R           4 8        3 6     2 2 4    3   2    4  | 2 4         2    2
+--R        (4b x  + 11a b x  + 9a b x  + a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                         2
+--R                                      40b
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 503
+
+)clear all
+
+--S 504 of 767
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 6         4    2 2  | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 504
+
+--S 505 of 767
+r0:=1/9*x^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/105*a^2*x^3*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/315*a^3*x^3*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+2/21*a*x^3*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                   +-------------------+
+--R            3 9         2 7       2   5       3 3  | 2 4         2    2
+--R        (35b x  + 135a b x  + 189a b x  + 105a x )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                       2
+--R                                 315b x  + 315a
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 506
+
+)clear all
+
+--S 507 of 767
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                               +-------------------+
+--R          2 5         3    2   | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 767
+r0:=1/8*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/b
+--R 
+--R
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------
+--R                                  8b
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 509
+
+)clear all
+
+--S 510 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 510
+
+--S 511 of 767
+r0:=1/7*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/35*a^2*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/35*a^3*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+6/35*a*x*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                              +-------------------+
+--R           3 7        2 5      2   3      3   | 2 4         2    2
+--R        (5b x  + 21a b x  + 35a b x  + 35a x)\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------
+--R                                     2
+--R                                35b x  + 35a
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 512
+
+)clear all
+
+--S 513 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 513
+
+--S 514 of 767
+r0:=1/6*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/2*a^2*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+    1/4*a*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+a^3*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                                                         +-------------------+
+--R            3           3 6       2 4      2   2      3  | 2 4         2    2
+--R        (12a log(x) + 2b x  + 9a b x  + 18a b x  + 11a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------------
+--R                                          2
+--R                                     12b x  + 12a
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 515
+
+)clear all
+
+--S 516 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^2
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              2
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 767
+r0:=1/5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x+8/5*a*b*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/5*a^2*b*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)-6/5*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x
+--R 
+--R
+--R                                          +-------------------+
+--R          3 6       2 4      2   2     3  | 2 4         2    2
+--R        (b x  + 5a b x  + 15a b x  - 5a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------
+--R                                  3
+--R                              5b x  + 5a x
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 518
+
+)clear all
+
+--S 519 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^3
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              3
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 767
+r0:=1/4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^2-3/2*a^3*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^2*(a+b*x^2))+3/4*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^2+3*a^2*b*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R       2   2          3 6       2 4     2   2     3  | 2 4         2    2
+--R   (12a b x log(x) + b x  + 6a b x  + 9a b x  - 2a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    4       2
+--R                                4b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 521
+
+)clear all
+
+--S 522 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^4
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              4
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 767
+r0:=-7/3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^3+8/3*b^2*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+16/3*a*b^2*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+2*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3
+--R 
+--R
+--R                                        +-------------------+
+--R          3 6       2 4     2   2    3  | 2 4         2    2
+--R        (b x  + 9a b x  - 9a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------
+--R                                5       3
+--R                            3b x  + 3a x
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 524
+
+)clear all
+
+--S 525 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^5
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              5
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 767
+r0:=-(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^4+3/2*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+3/4*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^4+3*a*b^2*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R         2 4           3 6       2 4     2   2    3  | 2 4         2    2
+--R   (12a b x log(x) + 2b x  - 3a b x  - 6a b x  - a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    6       4
+--R                                4b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 527
+
+)clear all
+
+--S 528 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^6
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              6
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 528
+
+--S 529 of 767
+r0:=-3/5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^5+8/5*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x-16/5*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x*(a+b*x^2))+2/5*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^5
+--R 
+--R
+--R                                          +-------------------+
+--R           3 6        2 4     2   2    3  | 2 4         2    2
+--R        (5b x  - 15a b x  - 5a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------
+--R                                 7       5
+--R                             5b x  + 5a x
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 530
+
+)clear all
+
+--S 531 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^7
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              7
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 767
+r0:=-5/12*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^6-1/2*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^2*(a+b*x^2))+1/4*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^6+b^3*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R       3 6           3 6        2 4     2   2     3  | 2 4         2    2
+--R   (12b x log(x) - 5b x  - 18a b x  - 9a b x  - 2a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    8        6
+--R                               12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 533
+
+)clear all
+
+--S 534 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^8
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              8
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 767
+r0:=-11/35*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^7-24/35*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3+16/35*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^3*(a+b*x^2))+6/35*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^7
+--R 
+--R
+--R                                               +-------------------+
+--R              3 6        2 4      2   2     3  | 2 4         2    2
+--R        (- 35b x  - 35a b x  - 21a b x  - 5a )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------
+--R                                    9        7
+--R                               35b x  + 35a x
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 536
+
+)clear all
+
+--S 537 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^9
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              9
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 767
+r0:=-1/8*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(a*x^8)
+--R 
+--R
+--R                                          +-------------------+
+--R            3 6       2 4     2   2    3  | 2 4         2    2
+--R        (- b x  - 3a b x  - 3a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------
+--R                                     8
+--R                                 8a x
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 539
+
+)clear all
+
+--S 540 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^10
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             10
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 540
+
+--S 541 of 767
+r0:=-13/63*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^9-8/63*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^5+16/315*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^5*(a+b*x^2))+2/21*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^9
+--R 
+--R
+--R                                                   +-------------------+
+--R               3 6         2 4       2   2      3  | 2 4         2    2
+--R        (- 105b x  - 189a b x  - 135a b x  - 35a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                     11         9
+--R                               315b x   + 315a x
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 542
+
+)clear all
+
+--S 543 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^11
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             11
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 767
+r0:=-1/8*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(a*x^10)+_
+    1/40*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a^2*x^10)
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 8      3 6     2 2 4      3   2     4  | 2 4         2    2
+--R        (b x  - a b x  - 9a b x  - 11a b x  - 4a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                        2 10
+--R                                     40a x
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 545
+
+)clear all
+
+--S 546 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^12
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             12
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 767
+r0:=-5/33*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^11-8/165*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^7+16/1155*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^7*(a+b*x^2))+2/33*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^11
+--R 
+--R
+--R                                                    +-------------------+
+--R               3 6         2 4       2   2       3  | 2 4         2    2
+--R        (- 231b x  - 495a b x  - 385a b x  - 105a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------------
+--R                                     13          11
+--R                              1155b x   + 1155a x
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 548
+
+)clear all
+
+--S 549 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^13
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             13
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 549
+
+--S 550 of 767
+r0:=-1/12*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(a*x^12)+_
+    1/24*b*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(a^2*x^10)-_
+    1/120*b*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a^3*x^10)
+--R 
+--R
+--R   (2)
+--R           5 10      4 8    2 3 6      3 2 4      4   2      5
+--R       (- b x   + a b x  - a b x  - 19a b x  - 26a b x  - 10a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         3 12
+--R     120a x
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 551
+
+)clear all
+
+--S 552 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^14
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             14
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 767
+r0:=-17/143*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^13-24/1001*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^9+16/3003*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^9*(a+b*x^2))+6/143*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^13
+--R 
+--R
+--R                                                     +-------------------+
+--R               3 6          2 4       2   2       3  | 2 4         2    2
+--R        (- 429b x  - 1001a b x  - 819a b x  - 231a )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------------
+--R                                      15          13
+--R                               3003b x   + 3003a x
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 554
+
+)clear all
+
+--S 555 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^15
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             15
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 555
+
+--S 556 of 767
+r0:=-3/28*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^14-1/56*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^10+1/280*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^10*(a+b*x^2))+1/28*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^14
+--R 
+--R
+--R                                                +-------------------+
+--R              3 6        2 4      2   2      3  | 2 4         2    2
+--R        (- 35b x  - 84a b x  - 70a b x  - 20a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------------
+--R                                   16         14
+--R                             280b x   + 280a x
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 557
+
+)clear all
+
+--S 558 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^16
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             16
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 767
+r0:=-19/195*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^15-8/585*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^11+16/6435*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^11*(a+b*x^2))+2/65*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^15
+--R 
+--R
+--R                                                      +-------------------+
+--R               3 6          2 4        2   2       3  | 2 4         2    2
+--R        (- 715b x  - 1755a b x  - 1485a b x  - 429a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------------------
+--R                                      17          15
+--R                               6435b x   + 6435a x
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 560
+
+)clear all
+
+--S 561 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^17
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             17
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 767
+r0:=-5/56*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^16-3/280*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^12+1/560*a*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^12*(a+b*x^2))+3/112*a*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^16
+--R 
+--R
+--R                                                  +-------------------+
+--R              3 6         2 4       2   2      3  | 2 4         2    2
+--R        (- 56b x  - 140a b x  - 120a b x  - 35a )\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------------------------------
+--R                                    18         16
+--R                              560b x   + 560a x
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 563
+
+)clear all
+
+--S 564 of 767
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                    +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  m | 2 4         2    2
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a )x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 564
+
+--S 565 of 767
+r0:=80*a^2*x^(1+m)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/((7+m)*(9+m)*(11+m))+_
+    10*a*x^(1+m)*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/(99+20*m+m^2)+_
+    x^(1+m)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(11+m)+1920*a^4*x^(1+m)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/((3+m)*(5+m)*(7+m)*(9+m)*(11+m))+_
+    3840*a^5*x^(1+m)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/((5+m)*(7+m)*_
+    (9+m)*(11+m)*(3+4*m+m^2)*(a+b*x^2))+480*a^3*x^(1+m)*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/((5+m)*(7+m)*(9+m)*(11+m))
+--R 
+--R
+--R   (2)
+--R           5 5      5 4       5 3       5 2        5        5  10
+--R         (b m  + 25b m  + 230b m  + 950b m  + 1689b m + 945b )x
+--R       + 
+--R                   4 5         4 4          4 3          4 2           4
+--R               5a b m  + 135a b m  + 1310a b m  + 5610a b m  + 10205a b m
+--R             + 
+--R                      4
+--R               5775a b
+--R        *
+--R            8
+--R           x
+--R       + 
+--R                2 3 5       2 3 4        2 3 3         2 3 2         2 3
+--R             10a b m  + 290a b m  + 3020a b m  + 13660a b m  + 25770a b m
+--R           + 
+--R                   2 3
+--R             14850a b
+--R        *
+--R            6
+--R           x
+--R       + 
+--R                3 2 5       3 2 4        3 2 3         3 2 2         3 2
+--R             10a b m  + 310a b m  + 3500a b m  + 17300a b m  + 34890a b m
+--R           + 
+--R                   3 2
+--R             20790a b
+--R        *
+--R            4
+--R           x
+--R       + 
+--R               4   5       4   4        4   3         4   2         4
+--R             5a b m  + 165a b m  + 2030a b m  + 11310a b m  + 26765a b m
+--R           + 
+--R                   4
+--R             17325a b
+--R        *
+--R            2
+--R           x
+--R       + 
+--R          5 5      5 4       5 3        5 2        5          5
+--R         a m  + 35a m  + 470a m  + 3010a m  + 9129a m + 10395a
+--R    *
+--R              +-------------------+
+--R        m + 1 | 2 4         2    2
+--R       x     \|b x  + 2a b x  + a
+--R  /
+--R           6        5         4          3           2                      2
+--R       (b m  + 36b m  + 505b m  + 3480b m  + 12139b m  + 19524b m + 10395b)x
+--R     + 
+--R          6        5         4          3           2
+--R       a m  + 36a m  + 505a m  + 3480a m  + 12139a m  + 19524a m + 10395a
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 566
+
+)clear all
+
+--S 567 of 767
+t0:=x^13*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 21       3 19     2 2 17     3   15    4 13  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 767
+r0:=1/132*a^2*x^14*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+5/264*a*x^14*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/24*x^14*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)+1/1584*a^4*x^14*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+    1/11088*a^5*x^14*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+    1/396*a^3*x^14*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R             5 24          4 22        2 3 20        3 2 18        4   16
+--R         462b x   + 2520a b x   + 5544a b x   + 6160a b x   + 3465a b x
+--R       + 
+--R             5 14
+--R         792a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             2
+--R     11088b x  + 11088a
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 569
+
+)clear all
+
+--S 570 of 767
+t0:=x^12*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 20       3 18     2 2 16     3   14    4 12  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 767
+r0:=80/9177*a^2*x^13*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/483*a*x^13*_
+    (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/23*x^13*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(5/2)+128/156009*a^4*x^13*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/2028117*a^5*x^13*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+160/52003*a^3*x^13*_
+    (a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R               5 23            4 21           2 3 19           3 2 17
+--R         88179b x   + 482885a b x   + 1067430a b x   + 1193010a b x
+--R       + 
+--R                4   15          5 13
+--R         676039a b x   + 156009a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R               2
+--R     2028117b x  + 2028117a
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 572
+
+)clear all
+
+--S 573 of 767
+t0:=x^11*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 19       3 17     2 2 15     3   13    4 11  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 767
+r0:=1/99*a^2*x^12*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/44*a*x^12*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/22*x^12*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    1/924*a^4*x^12*sqrt(a^2+2*a*b*x^2+b^2*x^4)+1/5544*a^5*x^12*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+1/264*a^3*x^12*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R             5 22          4 20        2 3 18        3 2 16        4   14
+--R         252b x   + 1386a b x   + 3080a b x   + 3465a b x   + 1980a b x
+--R       + 
+--R             5 12
+--R         462a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            2
+--R     5544b x  + 5544a
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 575
+
+)clear all
+
+--S 576 of 767
+t0:=x^10*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 18       3 16     2 2 14     3   12    4 10  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 767
+r0:=80/6783*a^2*x^11*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/399*a*x^11*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/21*x^11*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/88179*a^4*x^11*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/969969*a^5*_
+    x^11*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/6783*a^3*_
+    x^11*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R               5 21            4 19          2 3 17          3 2 15
+--R         46189b x   + 255255a b x   + 570570a b x   + 646646a b x
+--R       + 
+--R                4   13         5 11
+--R         373065a b x   + 88179a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     969969b x  + 969969a
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 578
+
+)clear all
+
+--S 579 of 767
+t0:=x^9*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                        +-------------------+
+--R          4 17       3 15     2 2 13     3   11    4 9  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 767
+r0:=1/360*a^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^5+1/120*a^2*x^4*_
+    (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^3-1/45*a*x^6*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^2+1/20*x^8*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b-1/420*a^3*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(7/2)/b^5
+--R 
+--R
+--R   (2)
+--R             9 18         8 16        2 7 14       3 6 12       4 5 10    5 4 8
+--R         126b x   + 574a b x   + 1001a b x   + 799a b x   + 251a b x   + a b x
+--R       + 
+--R            6 3 6    7 2 4    8   2    9
+--R         - a b x  + a b x  - a b x  + a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          5
+--R     2520b
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 581
+
+)clear all
+
+--S 582 of 767
+t0:=x^8*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                        +-------------------+
+--R          4 16       3 14     2 2 12     3   10    4 8  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 767
+r0:=16/969*a^2*x^9*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/323*a*x^9*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/19*x^9*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/46189*a^4*x^9*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/415701*a^5*x^9*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/4199*a^3*x^9*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R               5 19            4 17          2 3 15          3 2 13
+--R         21879b x   + 122265a b x   + 277134a b x   + 319770a b x
+--R       + 
+--R                4   11         5 9
+--R         188955a b x   + 46189a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     415701b x  + 415701a
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 584
+
+)clear all
+
+--S 585 of 767
+t0:=x^7*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 15       3 13     2 2 11     3   9    4 7  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 585
+
+--S 586 of 767
+r0:=-1/144*a^3*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^4-1/48*a*x^4*_
+    (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^2+1/18*x^6*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b+1/168*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/b^4
+--R 
+--R
+--R   (2)
+--R            8 16         7 14       2 6 12       3 5 10       4 4 8    5 3 6
+--R         56b x   + 259a b x   + 461a b x   + 379a b x   + 125a b x  + a b x
+--R       + 
+--R            6 2 4    7   2    8
+--R         - a b x  + a b x  - a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          4
+--R     1008b
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 587
+
+)clear all
+
+--S 588 of 767
+t0:=x^6*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 14       3 12     2 2 10     3   8    4 6  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 588
+
+--S 589 of 767
+r0:=16/663*a^2*x^7*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/51*a*x^7*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/17*x^7*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/21879*a^4*x^7*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/153153*a^5*x^7*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/2431*a^3*x^7*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R              5 17           4 15          2 3 13          3 2 11         4   9
+--R         9009b x   + 51051a b x   + 117810a b x   + 139230a b x   + 85085a b x
+--R       + 
+--R               5 7
+--R         21879a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     153153b x  + 153153a
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 590
+
+)clear all
+
+--S 591 of 767
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                      +-------------------+
+--R          4 13       3 11     2 2 9     3   7    4 5  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 767
+r0:=1/48*a^2*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^3+1/16*x^4*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b-1/56*a*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/b^3
+--R 
+--R
+--R   (2)
+--R            7 14        6 12       2 5 10       3 4 8      4 3 6    5 2 4
+--R         21b x   + 99a b x   + 181a b x   + 155a b x  + 55a b x  + a b x
+--R       + 
+--R            6   2    7
+--R         - a b x  + a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         3
+--R     336b
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 593
+
+)clear all
+
+--S 594 of 767
+t0:=x^4*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                      +-------------------+
+--R          4 12       3 10     2 2 8     3   6    4 4  | 2 4         2    2
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 767
+r0:=16/429*a^2*x^5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/39*a*x^5*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/15*x^5*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/9009*a^4*x^5*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/45045*a^5*x^5*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/1287*a^3*x^5*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R              5 15           4 13         2 3 11         3 2 9         4   7
+--R         3003b x   + 17325a b x   + 40950a b x   + 50050a b x  + 32175a b x
+--R       + 
+--R              5 5
+--R         9009a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             2
+--R     45045b x  + 45045a
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 596
+
+)clear all
+
+--S 597 of 767
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                     +-------------------+
+--R          4 11       3 9     2 2 7     3   5    4 3  | 2 4         2    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 767
+r0:=-1/12*a*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b^2+_
+    1/14*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/b^2
+--R 
+--R
+--R   (2)
+--R          6 12        5 10      2 4 8      3 3 6      4 2 4    5   2    6
+--R       (6b x   + 29a b x   + 55a b x  + 50a b x  + 20a b x  + a b x  - a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R        2
+--R     84b
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 599
+
+)clear all
+
+--S 600 of 767
+t0:=x^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                     +-------------------+
+--R          4 10       3 8     2 2 6     3   4    4 2  | 2 4         2    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 600
+
+--S 601 of 767
+r0:=80/1287*a^2*x^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/143*a*x^3*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/13*x^3*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/3003*a^4*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/9009*a^5*x^3*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+160/3003*a^3*x^3*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R             5 13          4 11         2 3 9         3 2 7        4   5
+--R         693b x   + 4095a b x   + 10010a b x  + 12870a b x  + 9009a b x
+--R       + 
+--R              5 3
+--R         3003a x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            2
+--R     9009b x  + 9009a
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 602
+
+)clear all
+
+--S 603 of 767
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 9       3 7     2 2 5     3   3    4   | 2 4         2    2
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 767
+r0:=1/12*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/b
+--R 
+--R
+--R   (2)
+--R                                                          +-------------------+
+--R     5 10       4 8      2 3 6      3 2 4     4   2    5  | 2 4         2    2
+--R   (b x   + 5a b x  + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R   ----------------------------------------------------------------------------
+--R                                        12b
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 605
+
+)clear all
+
+--S 606 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 767
+r0:=80/693*a^2*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/99*a*x*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/11*x*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    128/693*a^4*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/693*a^5*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/231*a^3*x*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R           5 11         4 9       2 3 7        3 2 5        4   3       5
+--R       (63b x   + 385a b x  + 990a b x  + 1386a b x  + 1155a b x  + 693a x)
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           2
+--R     693b x  + 693a
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 608
+
+)clear all
+
+--S 609 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 767
+r0:=1/6*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/8*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)+1/10*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)+_
+    1/2*a^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)+1/4*a^3*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+a^5*log(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+    (a+b*x^2)
+--R 
+--R
+--R   (2)
+--R             5            5 10        4 8       2 3 6       3 2 4       4   2
+--R         120a log(x) + 12b x   + 75a b x  + 200a b x  + 300a b x  + 300a b x
+--R       + 
+--R             5
+--R         137a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           2
+--R     120b x  + 120a
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 611
+
+)clear all
+
+--S 612 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^2
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        2
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 612
+
+--S 613 of 767
+r0:=80/63*a*b*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)-10/9*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x+1/9*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x+_
+    128/63*a^3*b*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/63*a^4*b*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/21*a^2*b*x*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R          5 10        4 8       2 3 6       3 2 4       4   2      5
+--R       (7b x   + 45a b x  + 126a b x  + 210a b x  + 315a b x  - 63a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          3
+--R     63b x  + 63a x
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 614
+
+)clear all
+
+--S 615 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^3
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        3
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 767
+r0:=5/12*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^2+5/24*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^2+1/8*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^2-_
+    5/2*a^5*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^2*(a+b*x^2))+5/4*a^3*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^2+5*a^4*b*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R             4   2           5 10        4 8      2 3 6       3 2 4       4   2
+--R         120a b x log(x) + 3b x   + 20a b x  + 60a b x  + 120a b x  + 125a b x
+--R       + 
+--R              5
+--R         - 12a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          4        2
+--R     24b x  + 24a x
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 617
+
+)clear all
+
+--S 618 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^4
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        4
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 767
+r0:=80/21*b^2*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+10/3*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^3-11/3*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^3+_
+    128/21*a^2*b^2*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/21*a^3*b^2*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+32/7*a*b^2*x*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R          5 10        4 8      2 3 6       3 2 4       4   2     5
+--R       (3b x   + 21a b x  + 70a b x  + 210a b x  - 105a b x  - 7a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          5        3
+--R     21b x  + 21a x
+--R                                                    Type: Expression(Integer)
+--E 619
+
+--S 620 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 620
+
+)clear all
+
+--S 621 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^5
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        5
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 767
+r0:=5/3*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+5/4*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^4-3/2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^4+_
+    5*a^2*b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4)+5/2*a*b^2*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)+10*a^3*b^2*log(x)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R             3 2 4           5 10        4 8      2 3 6      3 2 4      4   2
+--R         120a b x log(x) + 2b x   + 15a b x  + 60a b x  + 20a b x  - 30a b x
+--R       + 
+--R             5
+--R         - 3a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          6        4
+--R     12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 623
+
+)clear all
+
+--S 624 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^6
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        6
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 624
+
+--S 625 of 767
+r0:=16/15*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x+2/3*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^5-13/15*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/_
+    x^5+128/15*a*b^3*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/15*a^2*b^3*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)-32/5*a*b^2*(a+b*x^2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4)/x
+--R 
+--R
+--R   (2)
+--R          5 10        4 8       2 3 6       3 2 4      4   2     5
+--R       (3b x   + 25a b x  + 150a b x  - 150a b x  - 25a b x  - 3a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          7        5
+--R     15b x  + 15a x
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 626
+
+)clear all
+
+--S 627 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^7
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        7
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 767
+r0:=5/6*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^2+5/12*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^6-7/12*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^6-5*a^3*b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+    (x^2*(a+b*x^2))+5/2*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^2+_
+    10*a^2*b^3*log(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R             2 3 6           5 10        4 8      2 3 6      3 2 4      4   2
+--R         120a b x log(x) + 3b x   + 30a b x  + 40a b x  - 60a b x  - 15a b x
+--R       + 
+--R             5
+--R         - 2a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          8        6
+--R     12b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 628
+
+--S 629 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 629
+
+)clear all
+
+--S 630 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^8
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        8
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 767
+r0:=-16/3*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^3+2/7*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^7-3/7*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^7+128/21*b^4*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+    256/21*a*b^4*x*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+    32/7*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3
+--R 
+--R
+--R   (2)
+--R          5 10         4 8       2 3 6      3 2 4      4   2     5
+--R       (7b x   + 105a b x  - 210a b x  - 70a b x  - 21a b x  - 3a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          9        7
+--R     21b x  + 21a x
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 632
+
+)clear all
+
+--S 633 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^9
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                        9
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 633
+
+--S 634 of 767
+r0:=-5/3*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^4+5/24*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^8-1/3*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^8+5/2*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+    5/4*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^4+_
+    5*a*b^4*log(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R               4 8            5 10        4 8       2 3 6      3 2 4      4   2
+--R         120a b x log(x) + 12b x   - 65a b x  - 120a b x  - 60a b x  - 20a b x
+--R       + 
+--R             5
+--R         - 3a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          10        8
+--R     24b x   + 24a x
+--R                                                    Type: Expression(Integer)
+--E 634
+
+--S 635 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 635
+
+)clear all
+
+--S 636 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^10
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       10
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 767
+r0:=-16/21*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^5+10/63*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^9-17/63*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^9+128/63*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x-_
+    256/63*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x*(a+b*x^2))+_
+    32/63*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^5
+--R 
+--R
+--R   (2)
+--R           5 10         4 8       2 3 6       3 2 4      4   2     5
+--R       (63b x   - 315a b x  - 210a b x  - 126a b x  - 45a b x  - 7a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          11        9
+--R     63b x   + 63a x
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 638
+
+)clear all
+
+--S 639 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^11
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       11
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 639
+
+--S 640 of 767
+r0:=-5/12*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^6+1/8*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^10-9/40*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^10-1/2*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+    (x^2*(a+b*x^2))+1/4*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^6+_
+    b^5*log(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R             5 10            5 10         4 8       2 3 6       3 2 4      4   2
+--R         120b x  log(x) - 77b x   - 300a b x  - 300a b x  - 200a b x  - 75a b x
+--R       + 
+--R              5
+--R         - 12a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           12         10
+--R     120b x   + 120a x
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 641
+
+)clear all
+
+--S 642 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^12
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       12
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 642
+
+--S 643 of 767
+r0:=-16/63*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^7+10/99*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^11-19/99*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^11-128/231*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3+_
+    256/693*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^3*(a+b*x^2))+_
+    32/231*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^7
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6       3 2 4       4   2      5
+--R       (- 693b x   - 1155a b x  - 1386a b x  - 990a b x  - 385a b x  - 63a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           13         11
+--R     693b x   + 693a x
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 644
+
+)clear all
+
+--S 645 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^13
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       13
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 645
+
+--S 646 of 767
+r0:=-1/12*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a*x^12)
+--R 
+--R
+--R   (2)
+--R           5 10       4 8      2 3 6      3 2 4     4   2    5
+--R       (- b x   - 5a b x  - 10a b x  - 10a b x  - 5a b x  - a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          12
+--R     12a x
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 647
+
+)clear all
+
+--S 648 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^14
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       14
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 767
+r0:=-80/693*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^9+10/143*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^13-21/143*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^13-640/9009*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^5+_
+    256/9009*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^5*(a+b*x^2))+_
+    160/3003*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^9
+--R 
+--R
+--R   (2)
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 3003b x   - 9009a b x  - 12870a b x  - 10010a b x  - 4095a b x
+--R         + 
+--R                 5
+--R           - 693a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            15          13
+--R     9009b x   + 9009a x
+--R                                                    Type: Expression(Integer)
+--E 649
+
+--S 650 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 650
+
+)clear all
+
+--S 651 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^15
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       15
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 767
+r0:=-1/12*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a*x^14)+_
+    1/84*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/(a^2*x^14)
+--R 
+--R
+--R   (2)
+--R         6 12      5 10      2 4 8      3 3 6      4 2 4      5   2     6
+--R       (b x   - a b x   - 20a b x  - 50a b x  - 55a b x  - 29a b x  - 6a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R        2 14
+--R     84a x
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 653
+
+)clear all
+
+--S 654 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^16
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       16
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 654
+
+--S 655 of 767
+r0:=-80/1287*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^11+2/39*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^15-23/195*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^15-128/6435*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^7+_
+    256/45045*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^7*(a+b*x^2))+_
+    32/1287*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^11
+--R 
+--R
+--R   (2)
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R         - 9009b x   - 32175a b x  - 50050a b x  - 40950a b x  - 17325a b x
+--R       + 
+--R                5
+--R         - 3003a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             17           15
+--R     45045b x   + 45045a x
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 656
+
+)clear all
+
+--S 657 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^17
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       17
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 657
+
+--S 658 of 767
+r0:=-1/16*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a*x^16)+_
+    1/48*b*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a^2*x^14)-_
+    1/336*b*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/(a^3*x^14)
+--R 
+--R
+--R   (2)
+--R            7 14      6 12    2 5 10      3 4 8       4 3 6       5 2 4
+--R         - b x   + a b x   - a b x   - 55a b x  - 155a b x  - 181a b x
+--R       + 
+--R              6   2      7
+--R         - 99a b x  - 21a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         3 16
+--R     336a x
+--R                                                    Type: Expression(Integer)
+--E 658
+
+--S 659 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 659
+
+)clear all
+
+--S 660 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^18
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       18
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 767
+r0:=-16/429*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^13+2/51*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^17-5/51*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^17-128/17017*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^9+_
+    256/153153*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^9*(a+b*x^2))+_
+    32/2431*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^13
+--R 
+--R
+--R   (2)
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R         - 21879b x   - 85085a b x  - 139230a b x  - 117810a b x  - 51051a b x
+--R       + 
+--R                5
+--R         - 9009a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              19            17
+--R     153153b x   + 153153a x
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 662
+
+)clear all
+
+--S 663 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^19
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       19
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 663
+
+--S 664 of 767
+r0:=-1/18*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a*x^18)+_
+    1/48*b*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a^2*x^16)-_
+    1/144*b^2*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/(a^3*x^14)+_
+    1/1008*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(7/2)/(a^4*x^14)
+--R 
+--R
+--R   (2)
+--R          8 16      7 14    2 6 12    3 5 10       4 4 8       5 3 6       6 2 4
+--R         b x   - a b x   + a b x   - a b x   - 125a b x  - 379a b x  - 461a b x
+--R       + 
+--R               7   2      8
+--R         - 259a b x  - 56a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          4 18
+--R     1008a x
+--R                                                    Type: Expression(Integer)
+--E 664
+
+--S 665 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 665
+
+)clear all
+
+--S 666 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^20
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       20
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 767
+r0:=-16/663*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^15+10/323*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^19-27/323*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^19-128/37791*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^11+_
+    256/415701*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^11*(a+b*x^2))+_
+    32/4199*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^15
+--R 
+--R
+--R   (2)
+--R                 5 10            4 8          2 3 6          3 2 4
+--R         - 46189b x   - 188955a b x  - 319770a b x  - 277134a b x
+--R       + 
+--R                  4   2         5
+--R         - 122265a b x  - 21879a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              21            19
+--R     415701b x   + 415701a x
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 668
+
+)clear all
+
+--S 669 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^21
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       21
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 669
+
+--S 670 of 767
+r0:=-5/252*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^16+1/36*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^20-7/90*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^20-1/420*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^12+_
+    1/2520*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^12*(a+b*x^2))+_
+    1/168*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^16
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4       4   2       5
+--R       (- 252b x   - 1050a b x  - 1800a b x  - 1575a b x  - 700a b x  - 126a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            22          20
+--R     2520b x   + 2520a x
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 671
+
+)clear all
+
+--S 672 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^22
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       22
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 767
+r0:=-16/969*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^17+10/399*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^21-29/399*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^21-128/74613*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^13+_
+    256/969969*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^13*(a+b*x^2))+_
+    32/6783*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^17
+--R 
+--R
+--R   (2)
+--R                 5 10            4 8          2 3 6          3 2 4
+--R         - 88179b x   - 373065a b x  - 646646a b x  - 570570a b x
+--R       + 
+--R                  4   2         5
+--R         - 255255a b x  - 46189a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              23            21
+--R     969969b x   + 969969a x
+--R                                                    Type: Expression(Integer)
+--E 673
+
+--S 674 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 674
+
+)clear all
+
+--S 675 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^23
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       23
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 767
+r0:=-1/72*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^18+1/44*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^22-3/44*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^22-1/792*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^14+_
+    1/5544*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^14*(a+b*x^2))+_
+    1/264*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^18
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R       (- 462b x   - 1980a b x  - 3465a b x  - 3080a b x  - 1386a b x  - 252a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            24          22
+--R     5544b x   + 5544a x
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 677
+
+)clear all
+
+--S 678 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^24
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       24
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 678
+
+--S 679 of 767
+r0:=-80/6783*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^19+10/483*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^23-31/483*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^23-640/676039*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^15+_
+    256/2028117*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^15*(a+b*x^2))+_
+    160/52003*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^19
+--R 
+--R
+--R   (2)
+--R                  5 10            4 8           2 3 6           3 2 4
+--R         - 156009b x   - 676039a b x  - 1193010a b x  - 1067430a b x
+--R       + 
+--R                  4   2         5
+--R         - 482885a b x  - 88179a
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R               25             23
+--R     2028117b x   + 2028117a x
+--R                                                    Type: Expression(Integer)
+--E 679
+
+--S 680 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 680
+
+)clear all
+
+--S 681 of 767
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^25
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       25
+--R                                      x
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 767
+r0:=-1/99*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^20+5/264*a*(a+b*x^2)*_
+    (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^24-2/33*(a^2+2*a*b*x^2+_
+    b^2*x^4)^(5/2)/x^24-1/1386*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^16+_
+    1/11088*a*b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(x^16*(a+b*x^2))+_
+    1/396*a*b^2*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^20
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R       (- 792b x   - 3465a b x  - 6160a b x  - 5544a b x  - 2520a b x  - 462a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             26           24
+--R     11088b x   + 11088a x
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 683
+
+)clear all
+
+--S 684 of 767
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R                   4
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 684
+
+--S 685 of 767
+r0:=-a*x*(a+b*x^2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/3*x^3*_
+    (a+b*x^2)/(b*sqrt(a^2+2*a*b*x^2+b^2*x^4))+a^(3/2)*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(b^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                  +-+
+--R               2     2  +-+     x\|b       2 5         3     2   +-+
+--R        (3a b x  + 3a )\|a atan(-----) + (b x  - 2a b x  - 3a x)\|b
+--R                                  +-+
+--R                                 \|a
+--R   (2)  ------------------------------------------------------------
+--R                                +-------------------+
+--R                          2 +-+ | 2 4         2    2
+--R                        3b \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 685
+
+--S 686 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 686
+
+)clear all
+
+--S 687 of 767
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R                   3
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 767
+r0:=-1/2*a*(a+b*x^2)*log(a+b*x^2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+    1/2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/b^2
+--R 
+--R
+--R                2    2        2         2 4         2    2
+--R        (- a b x  - a )log(b x  + a) + b x  + 2a b x  + a
+--R   (2)  --------------------------------------------------
+--R                         +-------------------+
+--R                       2 | 2 4         2    2
+--R                     2b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 688
+
+--S 689 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 689
+
+)clear all
+
+--S 690 of 767
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R                   2
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 690
+
+--S 691 of 767
+r0:=x*(a+b*x^2)/(b*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+    (a+b*x^2)*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/(b^(3/2)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                               +-+
+--R              2      +-+     x\|b         3        +-+
+--R        (- b x  - a)\|a atan(-----) + (b x  + a x)\|b
+--R                               +-+
+--R                              \|a
+--R   (2)  ----------------------------------------------
+--R                        +-------------------+
+--R                    +-+ | 2 4         2    2
+--R                  b\|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 691
+
+--S 692 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 692
+
+)clear all
+
+--S 693 of 767
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R                   x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 693
+
+--S 694 of 767
+r0:=1/2*(a+b*x^2)*log(a+b*x^2)/(b*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R             2            2
+--R         (b x  + a)log(b x  + a)
+--R   (2)  ------------------------
+--R           +-------------------+
+--R           | 2 4         2    2
+--R        2b\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 694
+
+--S 695 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 695
+
+)clear all
+
+--S 696 of 767
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 767
+r0:=(a+b*x^2)*atan(x*sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                              +-+
+--R                 2          x\|b
+--R             (b x  + a)atan(-----)
+--R                              +-+
+--R                             \|a
+--R   (2)  ------------------------------
+--R                 +-------------------+
+--R         +-+ +-+ | 2 4         2    2
+--R        \|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 698
+
+)clear all
+
+--S 699 of 767
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4)^(1/2))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R          +-------------------+
+--R          | 2 4         2    2
+--R        x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 699
+
+--S 700 of 767
+r0:=(a+b*x^2)*log(x)/(a*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+    1/2*(a+b*x^2)*log(a+b*x^2)/(a*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R              2            2             2
+--R        (- b x  - a)log(b x  + a) + (2b x  + 2a)log(x)
+--R   (2)  ----------------------------------------------
+--R                      +-------------------+
+--R                      | 2 4         2    2
+--R                   2a\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 700
+
+--S 701 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 701
+
+)clear all
+
+--S 702 of 767
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4)^(1/2))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         2 | 2 4         2    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 767
+r0:=(-a-b*x^2)/(a*x*sqrt(a^2+2*a*b*x^2+b^2*x^4))-(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))*sqrt(b)/(a^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                 +-+
+--R              3        +-+     x\|b           2      +-+
+--R        (- b x  - a x)\|b atan(-----) + (- b x  - a)\|a
+--R                                 +-+
+--R                                \|a
+--R   (2)  ------------------------------------------------
+--R                          +-------------------+
+--R                      +-+ | 2 4         2    2
+--R                  a x\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 703
+
+--S 704 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 704
+
+)clear all
+
+--S 705 of 767
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4)^(1/2))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         3 | 2 4         2    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 705
+
+--S 706 of 767
+r0:=-b*(a+b*x^2)*log(x)/(a^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+    1/2*b*(a+b*x^2)*log(a+b*x^2)/(a^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+    1/2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a^2*x^2)
+--R 
+--R
+--R   (2)
+--R         2 4        2        2             2 4         2           2 4         2
+--R       (b x  + a b x )log(b x  + a) + (- 2b x  - 2a b x )log(x) - b x  - 2a b x
+--R     + 
+--R          2
+--R       - a
+--R  /
+--R           +-------------------+
+--R       2 2 | 2 4         2    2
+--R     2a x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 707
+
+)clear all
+
+--S 708 of 767
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4)^(1/2))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         4 | 2 4         2    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 708
+
+--S 709 of 767
+r0:=1/3*(-a-b*x^2)/(a*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))+b*(a+b*x^2)/_
+    (a^2*x*sqrt(a^2+2*a*b*x^2+b^2*x^4))+b^(3/2)*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(a^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                    +-+
+--R           2 5         3  +-+     x\|b        2 4         2    2  +-+
+--R        (3b x  + 3a b x )\|b atan(-----) + (3b x  + 2a b x  - a )\|a
+--R                                    +-+
+--R                                   \|a
+--R   (2)  -------------------------------------------------------------
+--R                                 +-------------------+
+--R                         2 3 +-+ | 2 4         2    2
+--R                       3a x \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 710
+
+)clear all
+
+--S 711 of 767
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                              4
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 711
+
+--S 712 of 767
+r0:=1/4*a*x*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+    5/8*x/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/8*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(b^(5/2)*sqrt(a)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                      +-+
+--R           2 4         2     2      x\|b            3         +-+ +-+
+--R        (3b x  + 6a b x  + 3a )atan(-----) + (- 5b x  - 3a x)\|a \|b
+--R                                      +-+
+--R                                     \|a
+--R   (2)  -------------------------------------------------------------
+--R                                        +-------------------+
+--R                   3 2       2  +-+ +-+ | 2 4         2    2
+--R                (8b x  + 8a b )\|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 712
+
+--S 713 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 713
+
+)clear all
+
+--S 714 of 767
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                              3
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 714
+
+--S 715 of 767
+r0:=1/4*x^4*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                           4
+--R                          x
+--R   (2)  -------------------------------------
+--R                        +-------------------+
+--R               2     2  | 2 4         2    2
+--R        (4a b x  + 4a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 715
+
+--S 716 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 716
+
+)clear all
+
+--S 717 of 767
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                              2
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 717
+
+--S 718 of 767
+r0:=1/4*x^3*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+    1/8*x/(a*b*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/8*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*b^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                    +-+
+--R          2 4         2    2      x\|b         3        +-+ +-+
+--R        (b x  + 2a b x  + a )atan(-----) + (b x  - a x)\|a \|b
+--R                                    +-+
+--R                                   \|a
+--R   (2)  -------------------------------------------------------
+--R                                      +-------------------+
+--R                  2 2     2   +-+ +-+ | 2 4         2    2
+--R             (8a b x  + 8a b)\|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 719
+
+)clear all
+
+--S 720 of 767
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 720
+
+--S 721 of 767
+r0:=1/4*(-a-b*x^2)/(b*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                            1
+--R   (2)  - ------------------------------------
+--R                         +-------------------+
+--R             2 2         | 2 4         2    2
+--R          (4b x  + 4a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 722
+
+)clear all
+
+--S 723 of 767
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 723
+
+--S 724 of 767
+r0:=1/4*x*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+3/8*x/(a^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/8*(a+b*x^2)*atan(x*sqrt(b)/_
+    sqrt(a))/(a^(5/2)*sqrt(b)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                                      +-+
+--R           2 4         2     2      x\|b          3         +-+ +-+
+--R        (3b x  + 6a b x  + 3a )atan(-----) + (3b x  + 5a x)\|a \|b
+--R                                      +-+
+--R                                     \|a
+--R   (2)  -----------------------------------------------------------
+--R                                       +-------------------+
+--R                  2   2     3  +-+ +-+ | 2 4         2    2
+--R               (8a b x  + 8a )\|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 724
+
+--S 725 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 725
+
+)clear all
+
+--S 726 of 767
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R                               +-------------------+
+--R          2 5         3    2   | 2 4         2    2
+--R        (b x  + 2a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 726
+
+--S 727 of 767
+r0:=1/4*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1/2/(a^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))+(a+b*x^2)*log(x)/(a^3*sqrt(a^2+_
+    2*a*b*x^2+b^2*x^4))-1/2*(a+b*x^2)*log(a+b*x^2)/(a^3*sqrt(a^2+_
+    2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2 4         2     2        2           2 4         2     2
+--R       (- 2b x  - 4a b x  - 2a )log(b x  + a) + (4b x  + 8a b x  + 4a )log(x)
+--R     + 
+--R             2     2
+--R       2a b x  + 3a
+--R  /
+--R                     +-------------------+
+--R        3   2     4  | 2 4         2    2
+--R     (4a b x  + 4a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 727
+
+--S 728 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 728
+
+)clear all
+
+--S 729 of 767
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                +-------------------+
+--R          2 6         4    2 2  | 2 4         2    2
+--R        (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 729
+
+--S 730 of 767
+r0:=1/4*(a+b*x^2)/(a*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/8/(a^2*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))-15/8*(a+b*x^2)/(a^3*x*sqrt(a^2+_
+    2*a*b*x^2+b^2*x^4))-15/8*(a+b*x^2)*atan(x*sqrt(b)/sqrt(a))*_
+    sqrt(b)/(a^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                               +-+
+--R             2 5          3      2   +-+     x\|b
+--R       (- 15b x  - 30a b x  - 15a x)\|b atan(-----)
+--R                                               +-+
+--R                                              \|a
+--R     + 
+--R             2 4          2     2  +-+
+--R       (- 15b x  - 25a b x  - 8a )\|a
+--R  /
+--R                          +-------------------+
+--R        3   3     4   +-+ | 2 4         2    2
+--R     (8a b x  + 8a x)\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 730
+
+--S 731 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 731
+
+)clear all
+
+--S 732 of 767
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                +-------------------+
+--R          2 7         5    2 3  | 2 4         2    2
+--R        (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 767
+r0:=1/4*(a+b*x^2)/(a*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    3/4/(a^2*x^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))-3*b*(a+b*x^2)*_
+    log(x)/(a^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/2*b*(a+b*x^2)*_
+    log(a+b*x^2)/(a^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+    3/2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a^4*x^2)
+--R 
+--R
+--R   (2)
+--R          3 6        2 4     2   2        2
+--R       (6b x  + 12a b x  + 6a b x )log(b x  + a)
+--R     + 
+--R           3 6        2 4      2   2            3 6        2 4      2   2     3
+--R     (- 12b x  - 24a b x  - 12a b x )log(x) - 6b x  - 18a b x  - 15a b x  - 2a
+--R  /
+--R                       +-------------------+
+--R        4   4     5 2  | 2 4         2    2
+--R     (4a b x  + 4a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 733
+
+--S 734 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 734
+
+)clear all
+
+--S 735 of 767
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                +-------------------+
+--R          2 8         6    2 4  | 2 4         2    2
+--R        (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 735
+
+--S 736 of 767
+r0:=1/4*(a+b*x^2)/(a*x^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    7/8/(a^2*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))-35/24*(a+b*x^2)/_
+    (a^3*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))+35/8*b*(a+b*x^2)/_
+    (a^4*x*sqrt(a^2+2*a*b*x^2+b^2*x^4))+35/8*b^(3/2)*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(a^(9/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                                   +-+
+--R            3 7         2 5       2   3  +-+     x\|b
+--R       (105b x  + 210a b x  + 105a b x )\|b atan(-----)
+--R                                                   +-+
+--R                                                  \|a
+--R     + 
+--R            3 6         2 4      2   2     3  +-+
+--R       (105b x  + 175a b x  + 56a b x  - 8a )\|a
+--R  /
+--R                             +-------------------+
+--R         4   5      5 3  +-+ | 2 4         2    2
+--R     (24a b x  + 24a x )\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 736
+
+--S 737 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 737
+
+)clear all
+
+--S 738 of 767
+t0:=x^6/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                        6
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 738
+
+--S 739 of 767
+r0:=1/8*a*x^3*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+    11/48*x^3/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/64*x^3*_
+    (a+b*x^2)/(a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+    5/128*x/(a*b^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))+5/128*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*b^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                                              +-+
+--R           4 8        3 6      2 2 4      3   2      4      x\|b
+--R       (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )atan(-----)
+--R                                                              +-+
+--R                                                             \|a
+--R     + 
+--R           3 7        2 5      2   3      3   +-+ +-+
+--R       (15b x  - 73a b x  - 55a b x  - 15a x)\|a \|b
+--R  /
+--R              6 6        2 5 4        3 4 2       4 3  +-+ +-+
+--R       (384a b x  + 1152a b x  + 1152a b x  + 384a b )\|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 740
+
+)clear all
+
+--S 741 of 767
+t0:=x^5/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                        5
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 741
+
+--S 742 of 767
+r0:=1/8*x^6*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    1/24*x^6/(a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                                    8       6
+--R                                 b x  + 4a x
+--R   (2)  -------------------------------------------------------------
+--R                                                +-------------------+
+--R            2 3 6      3 2 4      4   2      5  | 2 4         2    2
+--R        (24a b x  + 72a b x  + 72a b x  + 24a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 743
+
+)clear all
+
+--S 744 of 767
+t0:=x^4/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                        4
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 767
+r0:=1/8*a*x*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+    3/16*x/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1/64*x*(a+b*x^2)/_
+    (a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+3/128*x/(a^2*b^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/128*(a+b*x^2)*atan(x*_
+    sqrt(b)/sqrt(a))/(a^(5/2)*b^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                                            +-+
+--R          4 8        3 6      2 2 4      3   2     4      x\|b
+--R       (3b x  + 12a b x  + 18a b x  + 12a b x  + 3a )atan(-----)
+--R                                                            +-+
+--R                                                           \|a
+--R     + 
+--R          3 7        2 5      2   3     3   +-+ +-+
+--R       (3b x  + 11a b x  - 11a b x  - 3a x)\|a \|b
+--R  /
+--R                                                           +-------------------+
+--R          2 5 6       3 4 4       4 3 2       5 2  +-+ +-+ | 2 4         2    2
+--R     (128a b x  + 384a b x  + 384a b x  + 128a b )\|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 745
+
+--S 746 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 746
+
+)clear all
+
+--S 747 of 767
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                        3
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 747
+
+--S 748 of 767
+r0:=1/8*a*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    (-1/6)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                                       2
+--R                                 - 4b x  - a
+--R   (2)  -------------------------------------------------------------
+--R                                                +-------------------+
+--R            5 6        4 4      2 3 2      3 2  | 2 4         2    2
+--R        (24b x  + 72a b x  + 72a b x  + 24a b )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 748
+
+--S 749 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 749
+
+)clear all
+
+--S 750 of 767
+t0:=x^2/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                        2
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 750
+
+--S 751 of 767
+r0:=1/8*x^3*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+    5/48*x/(a*b*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    5/192*x*(a+b*x^2)/(a^2*b*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    5/128*x/(a^3*b*sqrt(a^2+2*a*b*x^2+b^2*x^4))+5/128*(a+b*x^2)*_
+    atan(x*sqrt(b)/sqrt(a))/(a^(7/2)*b^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                                              +-+
+--R           4 8        3 6      2 2 4      3   2      4      x\|b
+--R       (15b x  + 60a b x  + 90a b x  + 60a b x  + 15a )atan(-----)
+--R                                                              +-+
+--R                                                             \|a
+--R     + 
+--R           3 7        2 5      2   3      3   +-+ +-+
+--R       (15b x  + 55a b x  + 73a b x  - 15a x)\|a \|b
+--R  /
+--R            3 4 6        4 3 4        5 2 2       6   +-+ +-+
+--R       (384a b x  + 1152a b x  + 1152a b x  + 384a b)\|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 752
+
+)clear all
+
+--S 753 of 767
+t0:=x/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                       x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 753
+
+--S 754 of 767
+r0:=1/8*(-a-b*x^2)/(b*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                       1
+--R   (2)  - ----------------------------------------------------------
+--R                                               +-------------------+
+--R             4 6        3 4      2 2 2     3   | 2 4         2    2
+--R          (8b x  + 24a b x  + 24a b x  + 8a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 755
+
+)clear all
+
+--S 756 of 767
+t0:=1/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                       1
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 767
+r0:=1/8*x*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    7/48*x/(a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    35/192*x*(a+b*x^2)/(a^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+    35/128*x/(a^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+    35/128*(a+b*x^2)*atan(x*sqrt(b)/sqrt(a))/(a^(9/2)*sqrt(b)*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                                                   +-+
+--R            4 8         3 6       2 2 4       3   2       4      x\|b
+--R       (105b x  + 420a b x  + 630a b x  + 420a b x  + 105a )atan(-----)
+--R                                                                   +-+
+--R                                                                  \|a
+--R     + 
+--R            3 7         2 5       2   3       3   +-+ +-+
+--R       (105b x  + 385a b x  + 511a b x  + 279a x)\|a \|b
+--R  /
+--R                                                           +-------------------+
+--R          4 3 6        5 2 4        6   2       7  +-+ +-+ | 2 4         2    2
+--R     (384a b x  + 1152a b x  + 1152a b x  + 384a )\|a \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 758
+
+)clear all
+
+--S 759 of 767
+t0:=1/(x*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                        1
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 9       3 7     2 2 5     3   3    4   | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 767
+r0:=1/8*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    1/6/(a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1/4*(a+b*x^2)/_
+    (a^3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1/2/(a^4*sqrt(a^2+2*a*_
+    b*x^2+b^2*x^4))+(a+b*x^2)*log(x)/(a^5*sqrt(a^2+2*a*b*x^2+_
+    b^2*x^4))-1/2*(a+b*x^2)*log(a+b*x^2)/(a^5*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             4 8        3 6      2 2 4      3   2      4        2
+--R       (- 12b x  - 48a b x  - 72a b x  - 48a b x  - 12a )log(b x  + a)
+--R     + 
+--R           4 8        3 6       2 2 4      3   2      4               3 6
+--R       (24b x  + 96a b x  + 144a b x  + 96a b x  + 24a )log(x) + 12a b x
+--R     + 
+--R          2 2 4      3   2      4
+--R       42a b x  + 52a b x  + 25a
+--R  /
+--R                                             +-------------------+
+--R         5 3 6      6 2 4      7   2      8  | 2 4         2    2
+--R     (24a b x  + 72a b x  + 72a b x  + 24a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 760
+
+--S 761 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 761
+
+)clear all
+
+--S 762 of 767
+t0:=1/(x^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  ------------------------------------------------------------------
+--R                                                     +-------------------+
+--R          4 10       3 8     2 2 6     3   4    4 2  | 2 4         2    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 767
+r0:=1/8*(a+b*x^2)/(a*x*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    3/16/(a^2*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+21/64*(a+b*x^2)/_
+    (a^3*x*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+105/128/(a^4*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))-315/128*(a+b*x^2)/(a^5*x*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))-315/128*(a+b*x^2)*atan(x*_
+    sqrt(b)/sqrt(a))*sqrt(b)/(a^(11/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                4 9          3 7        2 2 5        3   3       4   +-+
+--R         (- 315b x  - 1260a b x  - 1890a b x  - 1260a b x  - 315a x)\|b
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R              4 8          3 6        2 2 4       3   2       4  +-+
+--R       (- 315b x  - 1155a b x  - 1533a b x  - 837a b x  - 128a )\|a
+--R  /
+--R                                                      +-------------------+
+--R          5 3 7       6 2 5       7   3       8   +-+ | 2 4         2    2
+--R     (128a b x  + 384a b x  + 384a b x  + 128a x)\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 763
+
+--S 764 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 764
+
+)clear all
+
+--S 765 of 767
+t0:=1/(x^3*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  ------------------------------------------------------------------
+--R                                                     +-------------------+
+--R          4 11       3 9     2 2 7     3   5    4 3  | 2 4         2    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 765
+
+--S 766 of 767
+r0:=1/8*(a+b*x^2)/(a*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+_
+    5/24/(a^2*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/12*(a+b*x^2)/_
+    (a^3*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/4/(a^4*x^2*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))-5*b*(a+b*x^2)*log(x)/(a^6*_
+    sqrt(a^2+2*a*b*x^2+b^2*x^4))+5/2*b*(a+b*x^2)*log(a+b*x^2)/_
+    (a^6*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+    5/2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a^6*x^2)
+--R 
+--R
+--R   (2)
+--R           5 10         4 8       2 3 6       3 2 4      4   2        2
+--R       (60b x   + 240a b x  + 360a b x  + 240a b x  + 60a b x )log(b x  + a)
+--R     + 
+--R              5 10         4 8       2 3 6       3 2 4       4   2
+--R       (- 120b x   - 480a b x  - 720a b x  - 480a b x  - 120a b x )log(x)
+--R     + 
+--R            5 10         4 8       2 3 6       3 2 4       4   2      5
+--R       - 60b x   - 300a b x  - 570a b x  - 500a b x  - 185a b x  - 12a
+--R  /
+--R                                               +-------------------+
+--R         6 3 8      7 2 6      8   4      9 2  | 2 4         2    2
+--R     (24a b x  + 72a b x  + 72a b x  + 24a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 767
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 767
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder14b.input.pamphlet b/src/input/richder14b.input.pamphlet
new file mode 100644
index 0000000..1cd3900
--- /dev/null
+++ b/src/input/richder14b.input.pamphlet
@@ -0,0 +1,14256 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder14b.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a+b x^2+c x^4)^p|
+There are 2 derivatives that do not match
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder14b.output
+)spool richder14b.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 765
+t0:=1/(x^4*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R                                                      +-------------------+
+--R          4 12       3 10     2 2 8     3   6    4 4  | 2 4         2    2
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 765
+r0:=1/8*(a+b*x^2)/(a*x^3*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+11/48/(a^2*x^3*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))+33/64*(a+b*x^2)/(a^3*x^3*(a^2+2*a*b*_
+   x^2+b^2*x^4)^(3/2))+231/128/(a^4*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   385/128*(a+b*x^2)/(a^5*x^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1155/128*b*_
+   (a+b*x^2)/(a^6*x*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1155/128*b^(3/2)*_
+   (a+b*x^2)*atan(x*sqrt(b)/sqrt(a))/(a^(13/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R               5 11           4 9         2 3 7         3 2 5        4   3  +-+
+--R         (3465b x   + 13860a b x  + 20790a b x  + 13860a b x  + 3465a b x )\|b
+--R      *
+--R                +-+
+--R              x\|b
+--R         atan(-----)
+--R                +-+
+--R               \|a
+--R     + 
+--R                  5 10           4 8         2 3 6        3 2 4        4   2
+--R             3465b x   + 12705a b x  + 16863a b x  + 9207a b x  + 1408a b x
+--R           + 
+--R                   5
+--R             - 128a
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                                                         +-------------------+
+--R          6 3 9        7 2 7        8   5       9 3  +-+ | 2 4         2    2
+--R     (384a b x  + 1152a b x  + 1152a b x  + 384a x )\|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 765
+t0:=x^3/(a^2+2*a*b*x^2+b^2*x^4)^(7/2)
+--R 
+--R
+--R   (1)
+--R      3
+--R     x
+--R  /
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R       (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 765
+r0:=1/12*a*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(7/2))+(-1/10)/_
+   (b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R   (2)
+--R           2
+--R     - 6b x  - a
+--R  /
+--R           7 10         6 8       2 5 6       3 4 4       4 3 2      5 2
+--R       (60b x   + 300a b x  + 600a b x  + 600a b x  + 300a b x  + 60a b )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 765
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          2 7         5    2 3  +-+
+--R   (1)  (b x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 765
+r0:=2/9*a^2*x^(9/2)+4/13*a*b*x^(13/2)+2/17*b^2*x^(17/2)
+--R 
+--R
+--R             2 8           6       2 4  +-+
+--R        (234b x  + 612a b x  + 442a x )\|x
+--R   (2)  -----------------------------------
+--R                        1989
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 765
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          2 6         4    2 2  +-+
+--R   (1)  (b x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 765
+r0:=2/7*a^2*x^(7/2)+4/11*a*b*x^(11/2)+2/15*b^2*x^(15/2)
+--R 
+--R
+--R             2 7           5       2 3  +-+
+--R        (154b x  + 420a b x  + 330a x )\|x
+--R   (2)  -----------------------------------
+--R                        1155
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 765
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          2 5         3    2   +-+
+--R   (1)  (b x  + 2a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 765
+r0:=2/5*a^2*x^(5/2)+4/9*a*b*x^(9/2)+2/13*b^2*x^(13/2)
+--R 
+--R
+--R            2 6           4       2 2  +-+
+--R        (90b x  + 260a b x  + 234a x )\|x
+--R   (2)  ----------------------------------
+--R                        585
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)*sqrt(x)
+--R 
+--R
+--R          2 4         2    2  +-+
+--R   (1)  (b x  + 2a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 765
+r0:=2/3*a^2*x^(3/2)+4/7*a*b*x^(7/2)+2/11*b^2*x^(11/2)
+--R 
+--R
+--R            2 5           3       2   +-+
+--R        (42b x  + 132a b x  + 154a x)\|x
+--R   (2)  ---------------------------------
+--R                       231
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/sqrt(x)
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                 +-+
+--R                \|x
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 765
+r0:=4/5*a*b*x^(5/2)+2/9*b^2*x^(9/2)+2*a^2*sqrt(x)
+--R 
+--R
+--R            2 4          2      2  +-+
+--R        (10b x  + 36a b x  + 90a )\|x
+--R   (2)  ------------------------------
+--R                      45
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^(3/2)
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                 +-+
+--R               x\|x
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 765
+r0:=4/3*a*b*x^(3/2)+2/7*b^2*x^(7/2)-2*a^2/sqrt(x)
+--R 
+--R
+--R          2 4          2      2
+--R        6b x  + 28a b x  - 42a
+--R   (2)  -----------------------
+--R                    +-+
+--R                 21\|x
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^(5/2)
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                2 +-+
+--R               x \|x
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 765
+r0:=-2/3*a^2/x^(3/2)+2/5*b^2*x^(5/2)+4*a*b*sqrt(x)
+--R 
+--R
+--R          2 4          2      2
+--R        6b x  + 60a b x  - 10a
+--R   (2)  -----------------------
+--R                    +-+
+--R                15x\|x
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)/x^(7/2)
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                3 +-+
+--R               x \|x
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 765
+r0:=-2/5*a^2/x^(5/2)+2/3*b^2*x^(3/2)-4*a*b/sqrt(x)
+--R 
+--R
+--R           2 4          2     2
+--R        10b x  - 60a b x  - 6a
+--R   (2)  -----------------------
+--R                   2 +-+
+--R                15x \|x
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 765
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R          4 11       3 9     2 2 7     3   5    4 3  +-+
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 765
+r0:=2/9*a^4*x^(9/2)+8/13*a^3*b*x^(13/2)+12/17*a^2*b^2*x^(17/2)+_
+   8/21*a*b^3*x^(21/2)+2/25*b^4*x^(25/2)
+--R 
+--R
+--R   (2)
+--R          4 12            3 10          2 2 8          3   6         4 4  +-+
+--R   (27846b x   + 132600a b x   + 245700a b x  + 214200a b x  + 77350a x )\|x
+--R   --------------------------------------------------------------------------
+--R                                     348075
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 765
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R          4 10       3 8     2 2 6     3   4    4 2  +-+
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 765
+r0:=2/7*a^4*x^(7/2)+8/11*a^3*b*x^(11/2)+4/5*a^2*b^2*x^(15/2)+_
+   8/19*a*b^3*x^(19/2)+2/23*b^4*x^(23/2)
+--R 
+--R
+--R   (2)
+--R          4 11           3 9          2 2 7          3   5         4 3  +-+
+--R   (14630b x   + 70840a b x  + 134596a b x  + 122360a b x  + 48070a x )\|x
+--R   ------------------------------------------------------------------------
+--R                                    168245
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 765
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R          4 9       3 7     2 2 5     3   3    4   +-+
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 765
+r0:=2/5*a^4*x^(5/2)+8/9*a^3*b*x^(9/2)+12/13*a^2*b^2*x^(13/2)+_
+   8/17*a*b^3*x^(17/2)+2/21*b^4*x^(21/2)
+--R 
+--R
+--R              4 10           3 8         2 2 6         3   4         4 2  +-+
+--R        (6630b x   + 32760a b x  + 64260a b x  + 61880a b x  + 27846a x )\|x
+--R   (2)  ---------------------------------------------------------------------
+--R                                        69615
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2*sqrt(x)
+--R 
+--R
+--R          4 8       3 6     2 2 4     3   2    4  +-+
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 765
+r0:=2/3*a^4*x^(3/2)+8/7*a^3*b*x^(7/2)+12/11*a^2*b^2*x^(11/2)+_
+   8/15*a*b^3*x^(15/2)+2/19*b^4*x^(19/2)
+--R 
+--R
+--R              4 9           3 7         2 2 5         3   3         4   +-+
+--R        (2310b x  + 11704a b x  + 23940a b x  + 25080a b x  + 14630a x)\|x
+--R   (2)  -------------------------------------------------------------------
+--R                                       21945
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/sqrt(x)
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           +-+
+--R                          \|x
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 765
+r0:=8/5*a^3*b*x^(5/2)+4/3*a^2*b^2*x^(9/2)+8/13*a*b^3*x^(13/2)+_
+   2/17*b^4*x^(17/2)+2*a^4*sqrt(x)
+--R 
+--R
+--R             4 8          3 6        2 2 4        3   2        4  +-+
+--R        (390b x  + 2040a b x  + 4420a b x  + 5304a b x  + 6630a )\|x
+--R   (2)  -------------------------------------------------------------
+--R                                     3315
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^(3/2)
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                           +-+
+--R                         x\|x
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 765
+r0:=8/3*a^3*b*x^(3/2)+12/7*a^2*b^2*x^(7/2)+8/11*a*b^3*x^(11/2)+_
+   2/15*b^4*x^(15/2)-2*a^4/sqrt(x)
+--R 
+--R
+--R            4 8         3 6        2 2 4        3   2        4
+--R        154b x  + 840a b x  + 1980a b x  + 3080a b x  - 2310a
+--R   (2)  ------------------------------------------------------
+--R                                    +-+
+--R                               1155\|x
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^(5/2)
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                          2 +-+
+--R                         x \|x
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 765
+r0:=-2/3*a^4/x^(3/2)+12/5*a^2*b^2*x^(5/2)+8/9*a*b^3*x^(9/2)+_
+   2/13*b^4*x^(13/2)+8*a^3*b*sqrt(x)
+--R 
+--R
+--R           4 8         3 6        2 2 4        3   2       4
+--R        90b x  + 520a b x  + 1404a b x  + 4680a b x  - 390a
+--R   (2)  ----------------------------------------------------
+--R                                   +-+
+--R                              585x\|x
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^2/x^(7/2)
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                          3 +-+
+--R                         x \|x
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 765
+r0:=-2/5*a^4/x^(5/2)+4*a^2*b^2*x^(3/2)+8/7*a*b^3*x^(7/2)+_
+   2/11*b^4*x^(11/2)-8*a^3*b/sqrt(x)
+--R 
+--R
+--R           4 8         3 6        2 2 4        3   2       4
+--R        70b x  + 440a b x  + 1540a b x  - 3080a b x  - 154a
+--R   (2)  ----------------------------------------------------
+--R                                  2 +-+
+--R                              385x \|x
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 765
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R   (1)
+--R     6 15       5 13      2 4 11      3 3 9      4 2 7     5   5    6 3  +-+
+--R   (b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 765
+r0:=2/9*a^6*x^(9/2)+12/13*a^5*b*x^(13/2)+30/17*a^4*b^2*x^(17/2)+40/21*a^3*_
+   b^3*x^(21/2)+6/5*a^2*b^4*x^(25/2)+12/29*a*b^5*x^(29/2)+2/33*b^6*x^(33/2)
+--R 
+--R
+--R   (2)
+--R                 6 16             5 14            2 4 12            3 3 10
+--R         1345890b x   + 9189180a b x   + 26648622a b x   + 42299400a b x
+--R       + 
+--R                  4 2 8            5   6           6 4
+--R         39189150a b x  + 20498940a b x  + 4934930a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     22207185
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 765
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R   (1)
+--R     6 14       5 12      2 4 10      3 3 8      4 2 6     5   4    6 2  +-+
+--R   (b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 765
+r0:=2/7*a^6*x^(7/2)+12/11*a^5*b*x^(11/2)+2*a^4*b^2*x^(15/2)+40/19*a^3*b^3*_
+   x^(19/2)+30/23*a^2*b^4*x^(23/2)+4/9*a*b^5*x^(27/2)+2/31*b^6*x^(31/2)
+--R 
+--R
+--R   (2)
+--R                6 15             5 13            2 4 11            3 3 9
+--R         605682b x   + 4172476a b x   + 12245310a b x   + 19764360a b x
+--R       + 
+--R                  4 2 7            5   5           6 3
+--R         18776142a b x  + 10241532a b x  + 2682306a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     9388071
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 765
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R   (1)
+--R     6 13       5 11      2 4 9      3 3 7      4 2 5     5   3    6   +-+
+--R   (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 765
+r0:=2/5*a^6*x^(5/2)+4/3*a^5*b*x^(9/2)+30/13*a^4*b^2*x^(13/2)+40/17*a^3*b^3*_
+   x^(17/2)+10/7*a^2*b^4*x^(21/2)+12/25*a*b^5*x^(25/2)+2/29*b^6*x^(29/2)
+--R 
+--R
+--R   (2)
+--R                6 14             5 12           2 4 10           3 3 8
+--R         232050b x   + 1615068a b x   + 4806750a b x   + 7917000a b x
+--R       + 
+--R                 4 2 6           5   4           6 2
+--R         7764750a b x  + 4486300a b x  + 1345890a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     3364725
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3*sqrt(x)
+--R 
+--R
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6  +-+
+--R   (1)  (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 765
+r0:=2/3*a^6*x^(3/2)+12/7*a^5*b*x^(7/2)+30/11*a^4*b^2*x^(11/2)+8/3*a^3*b^3*_
+   x^(15/2)+30/19*a^2*b^4*x^(19/2)+12/23*a*b^5*x^(23/2)+2/27*b^6*x^(27/2)
+--R 
+--R
+--R   (2)
+--R               6 13            5 11           2 4 9           3 3 7
+--R         67298b x   + 474012a b x   + 1434510a b x  + 2422728a b x
+--R       + 
+--R                 4 2 5           5   3          6
+--R         2477790a b x  + 1557468a b x  + 605682a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     908523
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/sqrt(x)
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                       +-+
+--R                                      \|x
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 765
+r0:=12/5*a^5*b*x^(5/2)+10/3*a^4*b^2*x^(9/2)+40/13*a^3*b^3*x^(13/2)+_
+   30/17*a^2*b^4*x^(17/2)+4/7*a*b^5*x^(21/2)+2/25*b^6*x^(25/2)+2*a^6*sqrt(x)
+--R 
+--R
+--R   (2)
+--R              6 12           5 10          2 4 8          3 3 6          4 2 4
+--R         9282b x   + 66300a b x   + 204750a b x  + 357000a b x  + 386750a b x
+--R       + 
+--R                5   2          6
+--R         278460a b x  + 232050a
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     116025
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^(3/2)
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        +-+
+--R                                      x\|x
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 765
+r0:=4*a^5*b*x^(3/2)+30/7*a^4*b^2*x^(7/2)+40/11*a^3*b^3*x^(11/2)+2*a^2*b^4*_
+   x^(15/2)+12/19*a*b^5*x^(19/2)+2/23*b^6*x^(23/2)-2*a^6/sqrt(x)
+--R 
+--R
+--R   (2)
+--R            6 12           5 10         2 4 8          3 3 6          4 2 4
+--R       2926b x   + 21252a b x   + 67298a b x  + 122360a b x  + 144210a b x
+--R     + 
+--R              5   2         6
+--R       134596a b x  - 67298a
+--R  /
+--R           +-+
+--R     33649\|x
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^(5/2)
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                      2 +-+
+--R                                     x \|x
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 765
+r0:=-2/3*a^6/x^(3/2)+6*a^4*b^2*x^(5/2)+40/9*a^3*b^3*x^(9/2)+30/13*a^2*b^4*_
+   x^(13/2)+12/17*a*b^5*x^(17/2)+2/21*b^6*x^(21/2)+12*a^5*b*sqrt(x)
+--R 
+--R
+--R   (2)
+--R            6 12          5 10         2 4 8         3 3 6         4 2 4
+--R       1326b x   + 9828a b x   + 32130a b x  + 61880a b x  + 83538a b x
+--R     + 
+--R              5   2        6
+--R       167076a b x  - 9282a
+--R  /
+--R            +-+
+--R     13923x\|x
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^3/x^(7/2)
+--R 
+--R
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                      3 +-+
+--R                                     x \|x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 765
+r0:=-2/5*a^6/x^(5/2)+10*a^4*b^2*x^(3/2)+40/7*a^3*b^3*x^(7/2)+30/11*a^2*b^4*_
+   x^(11/2)+4/5*a*b^5*x^(15/2)+2/19*b^6*x^(19/2)-12*a^5*b/sqrt(x)
+--R 
+--R
+--R   (2)
+--R           6 12          5 10         2 4 8         3 3 6         4 2 4
+--R       770b x   + 5852a b x   + 19950a b x  + 41800a b x  + 73150a b x
+--R     + 
+--R               5   2        6
+--R       - 87780a b x  - 2926a
+--R  /
+--R          2 +-+
+--R     7315x \|x
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 765
+t0:=x^(11/2)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                5 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 765
+r0:=9/10*x^(5/2)/b^2-1/2*x^(9/2)/(b*(a+b*x^2))-9/4*a^(5/4)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(13/4)*sqrt(2))+9/4*a^(5/4)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(13/4)*sqrt(2))-9/8*a^(5/4)*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*sqrt(2))+9/8*_
+   a^(5/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*_
+   sqrt(2))-9/2*a*sqrt(x)/b^3
+--R 
+--R
+--R   (2)
+--R               2      2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45a b x  + 45a )\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 2      2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45a b x  - 45a )\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2      2 4+-+     \|2 \|b \|x  + \|a
+--R       (90a b x  + 90a )\|a atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2      2 4+-+     \|2 \|b \|x  - \|a
+--R       (90a b x  + 90a )\|a atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R           2 4           2       2  +-+4+-+ +-+
+--R       (16b x  - 144a b x  - 180a )\|2 \|b \|x
+--R  /
+--R         4 2        3  +-+4+-+
+--R     (40b x  + 40a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 765
+t0:=x^(9/2)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                4 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 765
+r0:=7/6*x^(3/2)/b^2-1/2*x^(7/2)/(b*(a+b*x^2))+7/4*a^(3/4)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(11/4)*sqrt(2))-7/4*a^(3/4)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(11/4)*sqrt(2))-7/8*a^(3/4)*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*sqrt(2))+_
+   7/8*a^(3/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2       4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 21a)\|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               2       4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21b x  - 21a)\|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2       4+-+3     \|2 \|b \|x  + \|a
+--R       (- 42b x  - 42a)\|a  atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2       4+-+3     \|2 \|b \|x  - \|a
+--R       (- 42b x  - 42a)\|a  atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R             3          +-+4+-+3 +-+
+--R       (16b x  + 28a x)\|2 \|b  \|x
+--R  /
+--R         3 2        2  +-+4+-+3
+--R     (24b x  + 24a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 765
+t0:=x^(7/2)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                3 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 765
+r0:=-1/2*x^(5/2)/(b*(a+b*x^2))+5/4*a^(1/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(b^(9/4)*sqrt(2))-5/4*a^(1/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(b^(9/4)*sqrt(2))+5/8*a^(1/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*_
+   b^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*sqrt(2))-5/8*a^(1/4)*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*sqrt(2))+5/2*_
+   sqrt(x)/b^2
+--R 
+--R
+--R   (2)
+--R              2      4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 5a)\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R            2      4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 5a)\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R               2       4+-+     \|2 \|b \|x  + \|a
+--R       (- 10b x  - 10a)\|a atan(-------------------)
+--R                                        4+-+
+--R                                        \|a
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R             2       4+-+     \|2 \|b \|x  - \|a           2        +-+4+-+ +-+
+--R     (- 10b x  - 10a)\|a atan(-------------------) + (16b x  + 20a)\|2 \|b \|x
+--R                                      4+-+
+--R                                      \|a
+--R  /
+--R        3 2       2  +-+4+-+
+--R     (8b x  + 8a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 765
+t0:=x^(5/2)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                2 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 765
+r0:=-1/2*x^(3/2)/(b*(a+b*x^2))-3/4*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(1/4)*b^(7/4)*sqrt(2))+3/4*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(1/4)*b^(7/4)*sqrt(2))+3/8*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*b^(7/4)*sqrt(2))-_
+   3/8*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*_
+   b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              2           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 3a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R            2             +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 3a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (6b x  + 6a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a        +-+4+-+4+-+3 +-+
+--R       (6b x  + 6a)atan(-------------------) - 4x\|2 \|a \|b  \|x
+--R                                4+-+
+--R                                \|a
+--R  /
+--R        2 2         +-+4+-+4+-+3
+--R     (8b x  + 8a b)\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 765
+t0:=x^(3/2)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 +-+
+--R               x\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 765
+r0:=-1/4*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(5/4)*sqrt(2))+_
+   1/4*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(5/4)*sqrt(2))-_
+   1/8*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(3/4)*_
+   b^(5/4)*sqrt(2))+1/8*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(3/4)*b^(5/4)*sqrt(2))-1/2*sqrt(x)/(b*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R           2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a       +-+4+-+3 4+-+ +-+
+--R       (2b x  + 2a)atan(-------------------) - 4\|2 \|a   \|b \|x
+--R                                4+-+
+--R                                \|a
+--R  /
+--R        2 2         +-+4+-+3 4+-+
+--R     (8b x  + 8a b)\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 765
+t0:=sqrt(x)/(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 +-+
+--R                \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 765
+r0:=1/2*x^(3/2)/(a*(a+b*x^2))-1/4*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(5/4)*b^(3/4)*sqrt(2))+1/4*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(5/4)*b^(3/4)*sqrt(2))+1/8*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(5/4)*b^(3/4)*sqrt(2))-1/8*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a        +-+4+-+4+-+3 +-+
+--R       (2b x  + 2a)atan(-------------------) + 4x\|2 \|a \|b  \|x
+--R                                4+-+
+--R                                \|a
+--R  /
+--R            2     2  +-+4+-+4+-+3
+--R     (8a b x  + 8a )\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 765
+t0:=1/((a^2+2*a*b*x^2+b^2*x^4)*sqrt(x))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R          2 4         2    2  +-+
+--R        (b x  + 2a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 765
+r0:=-3/4*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(1/4)*sqrt(2))+_
+   3/4*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(1/4)*sqrt(2))-_
+   3/8*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(7/4)*_
+   b^(1/4)*sqrt(2))+3/8*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(7/4)*b^(1/4)*sqrt(2))+1/2*sqrt(x)/(a*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R            2           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 3a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              2             +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 3a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (6b x  + 6a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a       +-+4+-+3 4+-+ +-+
+--R       (6b x  + 6a)atan(-------------------) + 4\|2 \|a   \|b \|x
+--R                                4+-+
+--R                                \|a
+--R  /
+--R            2     2  +-+4+-+3 4+-+
+--R     (8a b x  + 8a )\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 765
+t0:=1/(x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R          2 5         3    2   +-+
+--R        (b x  + 2a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 765
+r0:=5/4*b^(1/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*sqrt(2))-_
+   5/4*b^(1/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*sqrt(2))-_
+   5/8*b^(1/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(9/4)*sqrt(2))+5/8*b^(1/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(9/4)*sqrt(2))+(-5/2)/(a^2*sqrt(x))+_
+   1/2/(a*(a+b*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R            2      4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 5a)\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              2      4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 5a)\|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R               2       4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (- 10b x  - 10a)\|b \|x atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R               2       4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (- 10b x  - 10a)\|b \|x atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R               2        +-+4+-+
+--R       (- 20b x  - 16a)\|2 \|a
+--R  /
+--R        2   2     3  +-+4+-+ +-+
+--R     (8a b x  + 8a )\|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 765
+t0:=1/(x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R          2 6         4    2 2  +-+
+--R        (b x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 765
+r0:=(-7/6)/(a^2*x^(3/2))+1/2/(a*x^(3/2)*(a+b*x^2))+7/4*b^(3/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*sqrt(2))-7/4*b^(3/4)*_
+   atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*sqrt(2))+7/8*b^(3/4)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(11/4)*_
+   sqrt(2))-7/8*b^(3/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21b x  - 21a x)\|b  \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             3         4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 21a x)\|b  \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R               3         4+-+3 +-+     \|2 \|b \|x  + \|a
+--R       (- 42b x  - 42a x)\|b  \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R               3         4+-+3 +-+     \|2 \|b \|x  - \|a
+--R       (- 42b x  - 42a x)\|b  \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R               2        +-+4+-+3
+--R       (- 28b x  - 16a)\|2 \|a
+--R  /
+--R         2   3      3   +-+4+-+3 +-+
+--R     (24a b x  + 24a x)\|2 \|a  \|x
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 765
+t0:=1/(x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R          2 7         5    2 3  +-+
+--R        (b x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 765
+r0:=(-9/10)/(a^2*x^(5/2))+1/2/(a*x^(5/2)*(a+b*x^2))-9/4*b^(5/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*sqrt(2))+9/4*b^(5/4)*_
+   atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*sqrt(2))+9/8*b^(5/4)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(13/4)*sqrt(2))-_
+   9/8*b^(5/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(13/4)*sqrt(2))+9/2*b/(a^3*sqrt(x))
+--R 
+--R
+--R   (2)
+--R             2 4          2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45b x  - 45a b x )\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2 4          2 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45b x  + 45a b x )\|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R           2 4          2 4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (90b x  + 90a b x )\|b \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R           2 4          2 4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (90b x  + 90a b x )\|b \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R            2 4           2      2  +-+4+-+
+--R       (180b x  + 144a b x  - 16a )\|2 \|a
+--R  /
+--R         3   4      4 2  +-+4+-+ +-+
+--R     (40a b x  + 40a x )\|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 765
+t0:=x^(19/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          9 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 765
+r0:=663/320*x^(5/2)/b^4-1/6*x^(17/2)/(b*(a+b*x^2)^3)-17/48*x^(13/2)/_
+   (b^2*(a+b*x^2)^2)-221/192*x^(9/2)/(b^3*(a+b*x^2))-663/128*a^(5/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(21/4)*sqrt(2))+663/128*_
+   a^(5/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(21/4)*sqrt(2))-_
+   663/256*a^(5/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(21/4)*sqrt(2))+663/256*a^(5/4)*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(21/4)*sqrt(2))-663/64*a*sqrt(x)/b^5
+--R 
+--R
+--R   (2)
+--R                 3 6         2 2 4         3   2        4 4+-+
+--R         (9945a b x  + 29835a b x  + 29835a b x  + 9945a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   3 6         2 2 4         3   2        4 4+-+
+--R         (- 9945a b x  - 29835a b x  - 29835a b x  - 9945a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  3 6         2 2 4         3   2         4 4+-+
+--R         (19890a b x  + 59670a b x  + 59670a b x  + 19890a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  3 6         2 2 4         3   2         4 4+-+
+--R         (19890a b x  + 59670a b x  + 59670a b x  + 19890a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R           4 8           3 6         2 2 4          3   2         4  +-+4+-+ +-+
+--R     (1536b x  - 26112a b x  - 99892a b x  - 111384a b x  - 39780a )\|2 \|b \|x
+--R  /
+--R           8 6           7 4         2 6 2        3 5  +-+4+-+
+--R     (3840b x  + 11520a b x  + 11520a b x  + 3840a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 765
+t0:=x^(17/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          8 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 765
+r0:=385/192*x^(3/2)/b^4-1/6*x^(15/2)/(b*(a+b*x^2)^3)-5/16*x^(11/2)/(b^2*_
+   (a+b*x^2)^2)-55/64*x^(7/2)/(b^3*(a+b*x^2))+385/128*a^(3/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(19/4)*sqrt(2))-_
+   385/128*a^(3/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(19/4)*_
+   sqrt(2))-385/256*a^(3/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(19/4)*sqrt(2))+385/256*a^(3/4)*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(19/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3 6          2 4        2   2        3 4+-+3
+--R         (1155b x  + 3465a b x  + 3465a b x  + 1155a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+3
+--R         (- 1155b x  - 3465a b x  - 3465a b x  - 1155a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+3
+--R         (- 2310b x  - 6930a b x  - 6930a b x  - 2310a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+3
+--R         (- 2310b x  - 6930a b x  - 6930a b x  - 2310a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 7          2 5        2   3        3   +-+4+-+3 +-+
+--R       (512b x  + 3060a b x  + 3960a b x  + 1540a x)\|2 \|b  \|x
+--R  /
+--R          7 6          6 4        2 5 2       3 4  +-+4+-+3
+--R     (768b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 765
+t0:=x^(15/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          7 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 765
+r0:=-1/6*x^(13/2)/(b*(a+b*x^2)^3)-13/48*x^(9/2)/(b^2*(a+b*x^2)^2)-_
+   39/64*x^(5/2)/(b^3*(a+b*x^2))+195/128*a^(1/4)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(17/4)*sqrt(2))-195/128*a^(1/4)*_
+   atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(17/4)*sqrt(2))+_
+   195/256*a^(1/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(17/4)*sqrt(2))-195/256*a^(1/4)*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*sqrt(2))+195/64*sqrt(x)/b^4
+--R 
+--R
+--R   (2)
+--R                3 6          2 4        2   2       3 4+-+
+--R         (- 585b x  - 1755a b x  - 1755a b x  - 585a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              3 6          2 4        2   2       3 4+-+
+--R         (585b x  + 1755a b x  + 1755a b x  + 585a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+
+--R         (- 1170b x  - 3510a b x  - 3510a b x  - 1170a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+
+--R         (- 1170b x  - 3510a b x  - 3510a b x  - 1170a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R             3 6          2 4        2   2        3  +-+4+-+ +-+
+--R       (1536b x  + 5876a b x  + 6552a b x  + 2340a )\|2 \|b \|x
+--R  /
+--R          7 6          6 4        2 5 2       3 4  +-+4+-+
+--R     (768b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 765
+t0:=x^(13/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          6 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 765
+r0:=-1/6*x^(11/2)/(b*(a+b*x^2)^3)-11/48*x^(7/2)/(b^2*(a+b*x^2)^2)-_
+   77/192*x^(3/2)/(b^3*(a+b*x^2))-77/128*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(1/4)*b^(15/4)*sqrt(2))+77/128*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(1/4)*b^(15/4)*sqrt(2))+77/256*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*_
+   b^(15/4)*sqrt(2))-77/256*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(1/4)*b^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                3 6         2 4       2   2       3
+--R         (- 231b x  - 693a b x  - 693a b x  - 231a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              3 6         2 4       2   2       3
+--R         (231b x  + 693a b x  + 693a b x  + 231a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R            3 6          2 4        2   2       3      \|2 \|b \|x  + \|a
+--R       (462b x  + 1386a b x  + 1386a b x  + 462a )atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R            3 6          2 4        2   2       3      \|2 \|b \|x  - \|a
+--R       (462b x  + 1386a b x  + 1386a b x  + 462a )atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R              2 5           3       2   +-+4+-+4+-+3 +-+
+--R       (- 612b x  - 792a b x  - 308a x)\|2 \|a \|b  \|x
+--R  /
+--R          6 6          5 4        2 4 2       3 3  +-+4+-+4+-+3
+--R     (768b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 765
+t0:=x^(11/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          5 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 765
+r0:=-1/6*x^(9/2)/(b*(a+b*x^2)^3)-3/16*x^(5/2)/(b^2*(a+b*x^2)^2)-_
+   15/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(13/4)*_
+   sqrt(2))+15/128*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*_
+   b^(13/4)*sqrt(2))-15/256*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(3/4)*b^(13/4)*sqrt(2))+15/256*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(3/4)*b^(13/4)*sqrt(2))-_
+   15/64*sqrt(x)/(b^3*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R             3 6         2 4       2   2      3
+--R         (45b x  + 135a b x  + 135a b x  + 45a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               3 6         2 4       2   2      3
+--R         (- 45b x  - 135a b x  - 135a b x  - 45a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  + \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  - \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R              2 4           2       2  +-+4+-+3 4+-+ +-+
+--R       (- 452b x  - 504a b x  - 180a )\|2 \|a   \|b \|x
+--R  /
+--R          6 6          5 4        2 4 2       3 3  +-+4+-+3 4+-+
+--R     (768b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 765
+t0:=x^(9/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          4 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 765
+r0:=-1/6*x^(7/2)/(b*(a+b*x^2)^3)-7/48*x^(3/2)/(b^2*(a+b*x^2)^2)+_
+   7/64*x^(3/2)/(a*b^2*(a+b*x^2))-7/128*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(5/4)*b^(11/4)*sqrt(2))+7/128*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*b^(11/4)*sqrt(2))+7/256*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*_
+   b^(11/4)*sqrt(2))-7/256*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(5/4)*b^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3 6        2 4      2   2      3
+--R         (- 21b x  - 63a b x  - 63a b x  - 21a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             3 6        2 4      2   2      3
+--R         (21b x  + 63a b x  + 63a b x  + 21a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  + \|a
+--R       (42b x  + 126a b x  + 126a b x  + 42a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  - \|a
+--R       (42b x  + 126a b x  + 126a b x  + 42a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R           2 5          3      2   +-+4+-+4+-+3 +-+
+--R       (84b x  - 72a b x  - 28a x)\|2 \|a \|b  \|x
+--R  /
+--R            5 6        2 4 4        3 3 2       4 2  +-+4+-+4+-+3
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 765
+t0:=x^(7/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          3 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 765
+r0:=-1/6*x^(5/2)/(b*(a+b*x^2)^3)-5/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(7/4)*b^(9/4)*sqrt(2))+5/128*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(7/4)*b^(9/4)*sqrt(2))-5/256*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(7/4)*b^(9/4)*sqrt(2))+_
+   5/256*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(7/4)*b^(9/4)*sqrt(2))-5/48*sqrt(x)/(b^2*(a+b*x^2)^2)+_
+   5/192*sqrt(x)/(a*b^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R           3 6        2 4      2   2      3      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (15b x  + 45a b x  + 45a b x  + 15a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               3 6        2 4      2   2      3
+--R         (- 15b x  - 45a b x  - 45a b x  - 15a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R           3 6        2 4      2   2      3      \|2 \|b \|x  + \|a
+--R       (30b x  + 90a b x  + 90a b x  + 30a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R           3 6        2 4      2   2      3      \|2 \|b \|x  - \|a
+--R       (30b x  + 90a b x  + 90a b x  + 30a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R           2 4           2      2  +-+4+-+3 4+-+ +-+
+--R       (20b x  - 168a b x  - 60a )\|2 \|a   \|b \|x
+--R  /
+--R            5 6        2 4 4        3 3 2       4 2  +-+4+-+3 4+-+
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a b )\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 765
+t0:=x^(5/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                          2 +-+
+--R                         x \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 765
+r0:=-1/6*x^(3/2)/(b*(a+b*x^2)^3)+1/16*x^(3/2)/(a*b*(a+b*x^2)^2)+_
+   5/64*x^(3/2)/(a^2*b*(a+b*x^2))-5/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(9/4)*b^(7/4)*sqrt(2))+5/128*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(9/4)*b^(7/4)*sqrt(2))+5/256*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(9/4)*b^(7/4)*sqrt(2))-_
+   5/256*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(9/4)*b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3 6        2 4      2   2      3
+--R         (- 15b x  - 45a b x  - 45a b x  - 15a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             3 6        2 4      2   2      3
+--R         (15b x  + 45a b x  + 45a b x  + 15a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R           3 6        2 4      2   2      3      \|2 \|b \|x  + \|a
+--R       (30b x  + 90a b x  + 90a b x  + 30a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R           3 6        2 4      2   2      3      \|2 \|b \|x  - \|a
+--R       (30b x  + 90a b x  + 90a b x  + 30a )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R           2 5           3      2   +-+4+-+4+-+3 +-+
+--R       (60b x  + 168a b x  - 20a x)\|2 \|a \|b  \|x
+--R  /
+--R          2 4 6        3 3 4        4 2 2       5   +-+4+-+4+-+3
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a b)\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 765
+t0:=x^(3/2)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           +-+
+--R                         x\|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 765
+r0:=-7/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(5/4)*_
+   sqrt(2))+7/128*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*_
+   b^(5/4)*sqrt(2))-7/256*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(11/4)*b^(5/4)*sqrt(2))+7/256*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(11/4)*b^(5/4)*sqrt(2))-_
+   1/6*sqrt(x)/(b*(a+b*x^2)^3)+1/48*sqrt(x)/(a*b*(a+b*x^2)^2)+_
+   7/192*sqrt(x)/(a^2*b*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R           3 6        2 4      2   2      3      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 63a b x  + 63a b x  + 21a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               3 6        2 4      2   2      3
+--R         (- 21b x  - 63a b x  - 63a b x  - 21a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  + \|a
+--R       (42b x  + 126a b x  + 126a b x  + 42a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  - \|a
+--R       (42b x  + 126a b x  + 126a b x  + 42a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R           2 4          2      2  +-+4+-+3 4+-+ +-+
+--R       (28b x  + 72a b x  - 84a )\|2 \|a   \|b \|x
+--R  /
+--R          2 4 6        3 3 4        4 2 2       5   +-+4+-+3 4+-+
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a b)\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 765
+t0:=sqrt(x)/(a^2+2*a*b*x^2+b^2*x^4)^2
+--R 
+--R
+--R                           +-+
+--R                          \|x
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 765
+r0:=1/6*x^(3/2)/(a*(a+b*x^2)^3)+3/16*x^(3/2)/(a^2*(a+b*x^2)^2)+_
+   15/64*x^(3/2)/(a^3*(a+b*x^2))-15/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(13/4)*b^(3/4)*sqrt(2))+15/128*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(13/4)*b^(3/4)*sqrt(2))+15/256*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(13/4)*b^(3/4)*sqrt(2))-_
+   15/256*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(13/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3 6         2 4       2   2      3
+--R         (- 45b x  - 135a b x  - 135a b x  - 45a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             3 6         2 4       2   2      3
+--R         (45b x  + 135a b x  + 135a b x  + 45a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  + \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R           3 6         2 4       2   2      3      \|2 \|b \|x  - \|a
+--R       (90b x  + 270a b x  + 270a b x  + 90a )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|a
+--R     + 
+--R            2 5           3       2   +-+4+-+4+-+3 +-+
+--R       (180b x  + 504a b x  + 452a x)\|2 \|a \|b  \|x
+--R  /
+--R          3 3 6        4 2 4        5   2       6  +-+4+-+4+-+3
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a )\|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 765
+t0:=1/((a^2+2*a*b*x^2+b^2*x^4)^2*sqrt(x))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R          4 8       3 6     2 2 4     3   2    4  +-+
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 765
+r0:=-77/128*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(15/4)*b^(1/4)*_
+   sqrt(2))+77/128*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(15/4)*_
+   b^(1/4)*sqrt(2))-77/256*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(15/4)*b^(1/4)*sqrt(2))+77/256*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(15/4)*b^(1/4)*sqrt(2))+_
+   1/6*sqrt(x)/(a*(a+b*x^2)^3)+11/48*sqrt(x)/(a^2*(a+b*x^2)^2)+_
+   77/192*sqrt(x)/(a^3*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R              3 6         2 4       2   2       3
+--R         (231b x  + 693a b x  + 693a b x  + 231a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                3 6         2 4       2   2       3
+--R         (- 231b x  - 693a b x  - 693a b x  - 231a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R            3 6          2 4        2   2       3      \|2 \|b \|x  + \|a
+--R       (462b x  + 1386a b x  + 1386a b x  + 462a )atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R                                                        +-+4+-+ +-+   4+-+
+--R            3 6          2 4        2   2       3      \|2 \|b \|x  - \|a
+--R       (462b x  + 1386a b x  + 1386a b x  + 462a )atan(-------------------)
+--R                                                               4+-+
+--R                                                               \|a
+--R     + 
+--R            2 4           2       2  +-+4+-+3 4+-+ +-+
+--R       (308b x  + 792a b x  + 612a )\|2 \|a   \|b \|x
+--R  /
+--R          3 3 6        4 2 4        5   2       6  +-+4+-+3 4+-+
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a )\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 765
+t0:=1/(x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R          4 9       3 7     2 2 5     3   3    4   +-+
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 765
+r0:=195/128*b^(1/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(17/4)*_
+   sqrt(2))-195/128*b^(1/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(17/4)*sqrt(2))-195/256*b^(1/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*_
+   b^(1/4)*sqrt(2)*sqrt(x))/(a^(17/4)*sqrt(2))+195/256*b^(1/4)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(17/4)*_
+   sqrt(2))+(-195/64)/(a^4*sqrt(x))+1/6/(a*(a+b*x^2)^3*sqrt(x))+_
+   13/48/(a^2*(a+b*x^2)^2*sqrt(x))+39/64/(a^3*(a+b*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R              3 6          2 4        2   2       3 4+-+ +-+
+--R         (585b x  + 1755a b x  + 1755a b x  + 585a )\|b \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                3 6          2 4        2   2       3 4+-+ +-+
+--R         (- 585b x  - 1755a b x  - 1755a b x  - 585a )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+ +-+
+--R         (- 1170b x  - 3510a b x  - 3510a b x  - 1170a )\|b \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 3 6          2 4        2   2        3 4+-+ +-+
+--R         (- 1170b x  - 3510a b x  - 3510a b x  - 1170a )\|b \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               3 6          2 4        2   2        3  +-+4+-+
+--R       (- 2340b x  - 6552a b x  - 5876a b x  - 1536a )\|2 \|a
+--R  /
+--R          4 3 6        5 2 4        6   2       7  +-+4+-+ +-+
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a )\|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 765
+t0:=1/(x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R          4 10       3 8     2 2 6     3   4    4 2  +-+
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 765
+r0:=(-385/192)/(a^4*x^(3/2))+1/6/(a*x^(3/2)*(a+b*x^2)^3)+5/16/(a^2*x^(3/2)*_
+   (a+b*x^2)^2)+55/64/(a^3*x^(3/2)*(a+b*x^2))+385/128*b^(3/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(19/4)*sqrt(2))-_
+   385/128*b^(3/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(19/4)*_
+   sqrt(2))+385/256*b^(3/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(19/4)*sqrt(2))-385/256*b^(3/4)*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(19/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 3 7          2 5        2   3        3  4+-+3 +-+
+--R         (- 1155b x  - 3465a b x  - 3465a b x  - 1155a x)\|b  \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               3 7          2 5        2   3        3  4+-+3 +-+
+--R         (1155b x  + 3465a b x  + 3465a b x  + 1155a x)\|b  \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 3 7          2 5        2   3        3  4+-+3 +-+
+--R         (- 2310b x  - 6930a b x  - 6930a b x  - 2310a x)\|b  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 3 7          2 5        2   3        3  4+-+3 +-+
+--R         (- 2310b x  - 6930a b x  - 6930a b x  - 2310a x)\|b  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               3 6          2 4        2   2       3  +-+4+-+3
+--R       (- 1540b x  - 3960a b x  - 3060a b x  - 512a )\|2 \|a
+--R  /
+--R          4 3 7        5 2 5        6   3       7   +-+4+-+3 +-+
+--R     (768a b x  + 2304a b x  + 2304a b x  + 768a x)\|2 \|a  \|x
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 765
+t0:=1/(x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^2)
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R          4 11       3 9     2 2 7     3   5    4 3  +-+
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 765
+r0:=(-663/320)/(a^4*x^(5/2))+1/6/(a*x^(5/2)*(a+b*x^2)^3)+17/48/(a^2*x^(5/2)*_
+   (a+b*x^2)^2)+221/192/(a^3*x^(5/2)*(a+b*x^2))-663/128*b^(5/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(21/4)*sqrt(2))+_
+   663/128*b^(5/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(21/4)*_
+   sqrt(2))+663/256*b^(5/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(21/4)*sqrt(2))-663/256*b^(5/4)*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(21/4)*sqrt(2))+_
+   663/64*b/(a^5*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                 4 8           3 6         2 2 4        3   2 4+-+ +-+
+--R         (- 9945b x  - 29835a b x  - 29835a b x  - 9945a b x )\|b \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8           3 6         2 2 4        3   2 4+-+ +-+
+--R         (9945b x  + 29835a b x  + 29835a b x  + 9945a b x )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                4 8           3 6         2 2 4         3   2 4+-+ +-+
+--R         (19890b x  + 59670a b x  + 59670a b x  + 19890a b x )\|b \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                4 8           3 6         2 2 4         3   2 4+-+ +-+
+--R         (19890b x  + 59670a b x  + 59670a b x  + 19890a b x )\|b \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8            3 6         2 2 4         3   2        4  +-+4+-+
+--R       (39780b x  + 111384a b x  + 99892a b x  + 26112a b x  - 1536a )\|2 \|a
+--R  /
+--R           5 3 8         6 2 6         7   4        8 2  +-+4+-+ +-+
+--R     (3840a b x  + 11520a b x  + 11520a b x  + 3840a x )\|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 765
+t0:=x^(27/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      13 +-+
+--R                                     x  \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 765
+r0:=13923/4096*x^(5/2)/b^6-1/10*x^(25/2)/(b*(a+b*x^2)^5)-5/32*x^(21/2)/_
+   (b^2*(a+b*x^2)^4)-35/128*x^(17/2)/(b^3*(a+b*x^2)^3)-595/1024*x^(13/2)/_
+   (b^4*(a+b*x^2)^2)-7735/4096*x^(9/2)/(b^5*(a+b*x^2))-69615/8192*a^(5/4)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(29/4)*sqrt(2))+_
+   69615/8192*a^(5/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(29/4)*_
+   sqrt(2))-69615/16384*a^(5/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(29/4)*sqrt(2))+69615/16384*a^(5/4)*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(29/4)*sqrt(2))-_
+   69615/4096*a*sqrt(x)/b^7
+--R 
+--R
+--R   (2)
+--R                    5 10           2 4 8           3 3 6           4 2 4
+--R           348075a b x   + 1740375a b x  + 3480750a b x  + 3480750a b x
+--R         + 
+--R                   5   2          6
+--R           1740375a b x  + 348075a
+--R      *
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                      5 10           2 4 8           3 3 6           4 2 4
+--R           - 348075a b x   - 1740375a b x  - 3480750a b x  - 3480750a b x
+--R         + 
+--R                     5   2          6
+--R           - 1740375a b x  - 348075a
+--R      *
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    5 10           2 4 8           3 3 6           4 2 4
+--R           696150a b x   + 3480750a b x  + 6961500a b x  + 6961500a b x
+--R         + 
+--R                   5   2          6
+--R           3480750a b x  + 696150a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  + \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                    5 10           2 4 8           3 3 6           4 2 4
+--R           696150a b x   + 3480750a b x  + 6961500a b x  + 6961500a b x
+--R         + 
+--R                   5   2          6
+--R           3480750a b x  + 696150a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  - \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                 6 12            5 10           2 4 8            3 3 6
+--R           32768b x   - 819200a b x   - 5270300a b x  - 11804800a b x
+--R         + 
+--R                      4 2 4           5   2           6
+--R           - 12685400a b x  - 6683040a b x  - 1392300a
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|b \|x
+--R  /
+--R               12 10            11 8          2 10 6          3 9 4
+--R         81920b  x   + 409600a b  x  + 819200a b  x  + 819200a b x
+--R       + 
+--R                4 8 2         5 7
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+
+--R       \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 765
+t0:=x^(25/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      12 +-+
+--R                                     x  \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 765
+r0:=33649/12288*x^(3/2)/b^6-1/10*x^(23/2)/(b*(a+b*x^2)^5)-23/160*x^(19/2)/_
+   (b^2*(a+b*x^2)^4)-437/1920*x^(15/2)/(b^3*(a+b*x^2)^3)-437/1024*_
+   x^(11/2)/(b^4*(a+b*x^2)^2)-4807/4096*x^(7/2)/(b^5*(a+b*x^2))+_
+   33649/8192*a^(3/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (b^(27/4)*sqrt(2))-33649/8192*a^(3/4)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(27/4)*sqrt(2))-33649/16384*a^(3/4)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(27/4)*_
+   sqrt(2))+33649/16384*a^(3/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(27/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  5 10             4 8           2 3 6           3 2 4
+--R           504735b x   + 2523675a b x  + 5047350a b x  + 5047350a b x
+--R         + 
+--R                   4   2          5
+--R           2523675a b x  + 504735a
+--R      *
+--R         4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    5 10             4 8           2 3 6           3 2 4
+--R           - 504735b x   - 2523675a b x  - 5047350a b x  - 5047350a b x
+--R         + 
+--R                     4   2          5
+--R           - 2523675a b x  - 504735a
+--R      *
+--R         4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                     5 10             4 8            2 3 6            3 2 4
+--R           - 1009470b x   - 5047350a b x  - 10094700a b x  - 10094700a b x
+--R         + 
+--R                     4   2           5
+--R           - 5047350a b x  - 1009470a
+--R      *
+--R                    +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  + \|a
+--R         \|a  atan(-------------------)
+--R                           4+-+
+--R                           \|a
+--R     + 
+--R                     5 10             4 8            2 3 6            3 2 4
+--R           - 1009470b x   - 5047350a b x  - 10094700a b x  - 10094700a b x
+--R         + 
+--R                     4   2           5
+--R           - 5047350a b x  - 1009470a
+--R      *
+--R                    +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  - \|a
+--R         \|a  atan(-------------------)
+--R                           4+-+
+--R                           \|a
+--R     + 
+--R                  5 11             4 9           2 3 7           3 2 5
+--R           163840b x   + 1749380a b x  + 4628704a b x  + 5471240a b x
+--R         + 
+--R                   4   3          5
+--R           3076480a b x  + 672980a x
+--R      *
+--R          +-+4+-+3 +-+
+--R         \|2 \|b  \|x
+--R  /
+--R                11 10             10 8           2 9 6           3 8 4
+--R         245760b  x   + 1228800a b  x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 4 7 2          5 6
+--R         1228800a b x  + 245760a b
+--R    *
+--R        +-+4+-+3
+--R       \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 765
+t0:=x^(23/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      11 +-+
+--R                                     x  \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 765
+r0:=-1/10*x^(21/2)/(b*(a+b*x^2)^5)-21/160*x^(17/2)/(b^2*(a+b*x^2)^4)-_
+   119/640*x^(13/2)/(b^3*(a+b*x^2)^3)-1547/5120*x^(9/2)/(b^4*(a+b*x^2)^2)-_
+   13923/20480*x^(5/2)/(b^5*(a+b*x^2))+13923/8192*a^(1/4)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(25/4)*sqrt(2))-13923/8192*a^(1/4)*_
+   atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(25/4)*sqrt(2))+_
+   13923/16384*a^(1/4)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(25/4)*sqrt(2))-13923/16384*a^(1/4)*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(25/4)*sqrt(2))+_
+   13923/4096*sqrt(x)/b^6
+--R 
+--R
+--R   (2)
+--R                   5 10            4 8          2 3 6          3 2 4
+--R           - 69615b x   - 348075a b x  - 696150a b x  - 696150a b x
+--R         + 
+--R                    4   2         5
+--R           - 348075a b x  - 69615a
+--R      *
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           69615b x   + 348075a b x  + 696150a b x  + 696150a b x
+--R         + 
+--R                  4   2         5
+--R           348075a b x  + 69615a
+--R      *
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    5 10            4 8           2 3 6           3 2 4
+--R           - 139230b x   - 696150a b x  - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    4   2          5
+--R           - 696150a b x  - 139230a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  + \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                    5 10            4 8           2 3 6           3 2 4
+--R           - 139230b x   - 696150a b x  - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    4   2          5
+--R           - 696150a b x  - 139230a
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  - \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                  5 10             4 8           2 3 6           3 2 4
+--R           163840b x   + 1054060a b x  + 2360960a b x  + 2537080a b x
+--R         + 
+--R                   4   2          5
+--R           1336608a b x  + 278460a
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|b \|x
+--R  /
+--R               11 10            10 8          2 9 6          3 8 4
+--R         81920b  x   + 409600a b  x  + 819200a b x  + 819200a b x
+--R       + 
+--R                4 7 2         5 6
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+
+--R       \|2 \|b
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 765
+t0:=x^(21/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      10 +-+
+--R                                     x  \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 765
+r0:=-1/10*x^(19/2)/(b*(a+b*x^2)^5)-19/160*x^(15/2)/(b^2*(a+b*x^2)^4)-_
+   19/128*x^(11/2)/(b^3*(a+b*x^2)^3)-209/1024*x^(7/2)/(b^4*(a+b*x^2)^2)-_
+   1463/4096*x^(3/2)/(b^5*(a+b*x^2))-4389/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(1/4)*b^(23/4)*sqrt(2))+4389/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(1/4)*b^(23/4)*sqrt(2))+4389/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*_
+   b^(23/4)*sqrt(2))-4389/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(1/4)*b^(23/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   5 10            4 8          2 3 6          3 2 4
+--R           - 21945b x   - 109725a b x  - 219450a b x  - 219450a b x
+--R         + 
+--R                    4   2         5
+--R           - 109725a b x  - 21945a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           21945b x   + 109725a b x  + 219450a b x  + 219450a b x
+--R         + 
+--R                  4   2         5
+--R           109725a b x  + 21945a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   2         5
+--R           219450a b x  + 43890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   2         5
+--R           219450a b x  + 43890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  4 9            3 7          2 2 5          3   3         4
+--R         (- 76060b x  - 201248a b x  - 237880a b x  - 133760a b x  - 29260a x)
+--R      *
+--R          +-+4+-+4+-+3 +-+
+--R         \|2 \|a \|b  \|x
+--R  /
+--R               10 10            9 8          2 8 6          3 7 4          4 6 2
+--R         81920b  x   + 409600a b x  + 819200a b x  + 819200a b x  + 409600a b x
+--R       + 
+--R               5 5
+--R         81920a b
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 765
+t0:=x^(19/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      9 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 765
+r0:=-1/10*x^(17/2)/(b*(a+b*x^2)^5)-17/160*x^(13/2)/(b^2*(a+b*x^2)^4)-_
+   221/1920*x^(9/2)/(b^3*(a+b*x^2)^3)-663/5120*x^(5/2)/(b^4*(a+b*x^2)^2)-_
+   663/8192*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(21/4)*_
+   sqrt(2))+663/8192*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*_
+   b^(21/4)*sqrt(2))-663/16384*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(3/4)*b^(21/4)*sqrt(2))+663/16384*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(3/4)*b^(21/4)*sqrt(2))-_
+   663/4096*sqrt(x)/(b^5*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           9945b x   + 49725a b x  + 99450a b x  + 99450a b x  + 49725a b x
+--R         + 
+--R                5
+--R           9945a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 9945b x   - 49725a b x  - 99450a b x  - 99450a b x  - 49725a b x
+--R         + 
+--R                  5
+--R           - 9945a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                   4 8            3 6          2 2 4          3   2         4
+--R         (- 150580b x  - 337280a b x  - 362440a b x  - 190944a b x  - 39780a )
+--R      *
+--R          +-+4+-+3 4+-+ +-+
+--R         \|2 \|a   \|b \|x
+--R  /
+--R                10 10             9 8           2 8 6           3 7 4
+--R         245760b  x   + 1228800a b x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 4 6 2          5 5
+--R         1228800a b x  + 245760a b
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 765
+t0:=x^(17/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      8 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 765
+r0:=-1/10*x^(15/2)/(b*(a+b*x^2)^5)-3/32*x^(11/2)/(b^2*(a+b*x^2)^4)-_
+   11/128*x^(7/2)/(b^3*(a+b*x^2)^3)-77/1024*x^(3/2)/(b^4*(a+b*x^2)^2)+_
+   231/4096*x^(3/2)/(a*b^4*(a+b*x^2))-231/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(5/4)*b^(19/4)*sqrt(2))+231/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*b^(19/4)*sqrt(2))+231/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*_
+   b^(19/4)*sqrt(2))-231/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(5/4)*b^(19/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1155b x   - 5775a b x  - 11550a b x  - 11550a b x  - 5775a b x
+--R         + 
+--R                  5
+--R           - 1155a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1155b x   + 5775a b x  + 11550a b x  + 11550a b x  + 5775a b x
+--R         + 
+--R                5
+--R           1155a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 9           3 7         2 2 5        3   3        4   +-+4+-+
+--R         (4620b x  - 10592a b x  - 12520a b x  - 7040a b x  - 1540a x)\|2 \|a
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R                 9 10          2 8 8          3 7 6          4 6 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                5 5 2         6 4
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 765
+t0:=x^(15/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      7 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 765
+r0:=-1/10*x^(13/2)/(b*(a+b*x^2)^5)-13/160*x^(9/2)/(b^2*(a+b*x^2)^4)-_
+   39/640*x^(5/2)/(b^3*(a+b*x^2)^3)-117/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(7/4)*b^(17/4)*sqrt(2))+117/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(17/4)*sqrt(2))-117/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(7/4)*_
+   b^(17/4)*sqrt(2))+117/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(7/4)*b^(17/4)*sqrt(2))-39/1024*sqrt(x)/(b^4*_
+   (a+b*x^2)^2)+39/4096*sqrt(x)/(a*b^4*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (585b x   + 2925a b x  + 5850a b x  + 5850a b x  + 2925a b x  + 585a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 585b x   - 2925a b x  - 5850a b x  - 5850a b x  - 2925a b x
+--R           + 
+--R                   5
+--R             - 585a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1170b x   + 5850a b x  + 11700a b x  + 11700a b x  + 5850a b x
+--R         + 
+--R                5
+--R           1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1170b x   + 5850a b x  + 11700a b x  + 11700a b x  + 5850a b x
+--R         + 
+--R                5
+--R           1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8           3 6         2 2 4         3   2        4  +-+4+-+3
+--R         (780b x  - 19840a b x  - 21320a b x  - 11232a b x  - 2340a )\|2 \|a
+--R      *
+--R         4+-+ +-+
+--R         \|b \|x
+--R  /
+--R                 9 10          2 8 8          3 7 6          4 6 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                5 5 2         6 4
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 765
+t0:=x^(13/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      6 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 765
+r0:=-1/10*x^(11/2)/(b*(a+b*x^2)^5)-11/160*x^(7/2)/(b^2*(a+b*x^2)^4)-_
+   77/1920*x^(3/2)/(b^3*(a+b*x^2)^3)+77/5120*x^(3/2)/(a*b^3*(a+b*x^2)^2)+_
+   77/4096*x^(3/2)/(a^2*b^3*(a+b*x^2))-77/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(9/4)*b^(15/4)*sqrt(2))+77/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*b^(15/4)*sqrt(2))+77/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(9/4)*_
+   b^(15/4)*sqrt(2))-77/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(9/4)*b^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1155b x   - 5775a b x  - 11550a b x  - 11550a b x  - 5775a b x
+--R         + 
+--R                  5
+--R           - 1155a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1155b x   + 5775a b x  + 11550a b x  + 11550a b x  + 5775a b x
+--R         + 
+--R                5
+--R           1155a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 9           3 7         2 2 5        3   3        4   +-+4+-+
+--R         (4620b x  + 22176a b x  - 12520a b x  - 7040a b x  - 1540a x)\|2 \|a
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R                2 8 10           3 7 8           4 6 6           5 5 4
+--R         245760a b x   + 1228800a b x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 6 4 2          7 3
+--R         1228800a b x  + 245760a b
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 765
+t0:=x^(11/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      5 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 765
+r0:=-1/10*x^(9/2)/(b*(a+b*x^2)^5)-9/160*x^(5/2)/(b^2*(a+b*x^2)^4)-_
+   63/8192*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(13/4)*_
+   sqrt(2))+63/8192*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*_
+   b^(13/4)*sqrt(2))-63/16384*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(11/4)*b^(13/4)*sqrt(2))+63/16384*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(11/4)*b^(13/4)*sqrt(2))-_
+   3/128*sqrt(x)/(b^3*(a+b*x^2)^3)+3/1024*sqrt(x)/(a*b^3*(a+b*x^2)^2)+_
+   21/4096*sqrt(x)/(a^2*b^3*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x  + 315a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 315b x   - 1575a b x  - 3150a b x  - 3150a b x  - 1575a b x
+--R           + 
+--R                   5
+--R             - 315a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (630b x   + 3150a b x  + 6300a b x  + 6300a b x  + 3150a b x  + 630a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (630b x   + 3150a b x  + 6300a b x  + 6300a b x  + 3150a b x  + 630a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R          4 8          3 6         2 2 4        3   2        4  +-+4+-+3 4+-+ +-+
+--R     (420b x  + 1920a b x  - 11480a b x  - 6048a b x  - 1260a )\|2 \|a   \|b \|x
+--R  /
+--R               2 8 10          3 7 8          4 6 6          5 5 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                6 4 2         7 3
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 765
+t0:=x^(9/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      4 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 765
+r0:=-1/10*x^(7/2)/(b*(a+b*x^2)^5)-7/160*x^(3/2)/(b^2*(a+b*x^2)^4)+_
+   7/640*x^(3/2)/(a*b^2*(a+b*x^2)^3)+63/5120*x^(3/2)/(a^2*b^2*(a+_
+   b*x^2)^2)+63/4096*x^(3/2)/(a^3*b^2*(a+b*x^2))-63/8192*atan(1-_
+   b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*b^(11/4)*sqrt(2))+_
+   63/8192*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*b^(11/4)*_
+   sqrt(2))+63/16384*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(13/4)*b^(11/4)*sqrt(2))-63/16384*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(13/4)*b^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 315b x   - 1575a b x  - 3150a b x  - 3150a b x  - 1575a b x
+--R           + 
+--R                   5
+--R             - 315a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (315b x   + 1575a b x  + 3150a b x  + 3150a b x  + 1575a b x  + 315a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (630b x   + 3150a b x  + 6300a b x  + 6300a b x  + 3150a b x  + 630a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (630b x   + 3150a b x  + 6300a b x  + 6300a b x  + 3150a b x  + 630a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 9          3 7         2 2 5        3   3       4   +-+4+-+
+--R         (1260b x  + 6048a b x  + 11480a b x  - 1920a b x  - 420a x)\|2 \|a
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R               3 7 10          4 6 8          5 5 6          6 4 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                7 3 2         8 2
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 765
+t0:=x^(7/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      3 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 765
+r0:=-1/10*x^(5/2)/(b*(a+b*x^2)^5)-77/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(15/4)*b^(9/4)*sqrt(2))+77/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(15/4)*b^(9/4)*sqrt(2))-77/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(15/4)*_
+   b^(9/4)*sqrt(2))+77/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(15/4)*b^(9/4)*sqrt(2))-1/32*sqrt(x)/(b^2*_
+   (a+b*x^2)^4)+1/384*sqrt(x)/(a*b^2*(a+b*x^2)^3)+11/3072*sqrt(x)/_
+   (a^2*b^2*(a+b*x^2)^2)+77/12288*sqrt(x)/(a^3*b^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1155b x   + 5775a b x  + 11550a b x  + 11550a b x  + 5775a b x
+--R         + 
+--R                5
+--R           1155a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1155b x   - 5775a b x  - 11550a b x  - 11550a b x  - 5775a b x
+--R         + 
+--R                  5
+--R           - 1155a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6         2 2 4         3   2        4  +-+4+-+3
+--R         (1540b x  + 7040a b x  + 12520a b x  - 22176a b x  - 4620a )\|2 \|a
+--R      *
+--R         4+-+ +-+
+--R         \|b \|x
+--R  /
+--R                3 7 10           4 6 8           5 5 6           6 4 4
+--R         245760a b x   + 1228800a b x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 7 3 2          8 2
+--R         1228800a b x  + 245760a b
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 765
+t0:=x^(5/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                      2 +-+
+--R                                     x \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 765
+r0:=-1/10*x^(3/2)/(b*(a+b*x^2)^5)+3/160*x^(3/2)/(a*b*(a+b*x^2)^4)+_
+   13/640*x^(3/2)/(a^2*b*(a+b*x^2)^3)+117/5120*x^(3/2)/(a^3*b*(a+b*x^2)^2)+_
+   117/4096*x^(3/2)/(a^4*b*(a+b*x^2))-117/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(17/4)*b^(7/4)*sqrt(2))+117/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(17/4)*b^(7/4)*sqrt(2))+117/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(17/4)*_
+   b^(7/4)*sqrt(2))-117/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(17/4)*b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   5 10          4 8        2 3 6        3 2 4        4   2
+--R             - 585b x   - 2925a b x  - 5850a b x  - 5850a b x  - 2925a b x
+--R           + 
+--R                   5
+--R             - 585a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              5 10          4 8        2 3 6        3 2 4        4   2       5
+--R         (585b x   + 2925a b x  + 5850a b x  + 5850a b x  + 2925a b x  + 585a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1170b x   + 5850a b x  + 11700a b x  + 11700a b x  + 5850a b x
+--R         + 
+--R                5
+--R           1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1170b x   + 5850a b x  + 11700a b x  + 11700a b x  + 5850a b x
+--R         + 
+--R                5
+--R           1170a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 9           3 7         2 2 5         3   3       4   +-+4+-+
+--R         (2340b x  + 11232a b x  + 21320a b x  + 19840a b x  - 780a x)\|2 \|a
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R               4 6 10          5 5 8          6 4 6          7 3 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                8 2 2         9
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 765
+t0:=x^(3/2)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                        +-+
+--R                                      x\|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 765
+r0:=-231/8192*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(19/4)*b^(5/4)*_
+   sqrt(2))+231/8192*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(19/4)*_
+   b^(5/4)*sqrt(2))-231/16384*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(19/4)*b^(5/4)*sqrt(2))+231/16384*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(19/4)*b^(5/4)*sqrt(2))-_
+   1/10*sqrt(x)/(b*(a+b*x^2)^5)+1/160*sqrt(x)/(a*b*(a+b*x^2)^4)+_
+   1/128*sqrt(x)/(a^2*b*(a+b*x^2)^3)+11/1024*sqrt(x)/(a^3*b*(a+b*x^2)^2)+_
+   77/4096*sqrt(x)/(a^4*b*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                5 10          4 8         2 3 6         3 2 4        4   2
+--R           1155b x   + 5775a b x  + 11550a b x  + 11550a b x  + 5775a b x
+--R         + 
+--R                5
+--R           1155a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 10          4 8         2 3 6         3 2 4        4   2
+--R           - 1155b x   - 5775a b x  - 11550a b x  - 11550a b x  - 5775a b x
+--R         + 
+--R                  5
+--R           - 1155a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           2310b x   + 11550a b x  + 23100a b x  + 23100a b x  + 11550a b x
+--R         + 
+--R                5
+--R           2310a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6         2 2 4         3   2        4  +-+4+-+3
+--R         (1540b x  + 7040a b x  + 12520a b x  + 10592a b x  - 4620a )\|2 \|a
+--R      *
+--R         4+-+ +-+
+--R         \|b \|x
+--R  /
+--R               4 6 10          5 5 8          6 4 6          7 3 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                8 2 2         9
+--R         409600a b x  + 81920a b
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 765
+t0:=sqrt(x)/(a^2+2*a*b*x^2+b^2*x^4)^3
+--R 
+--R
+--R                                       +-+
+--R                                      \|x
+--R   (1)  ----------------------------------------------------------------
+--R         6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6
+--R        b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 765
+r0:=1/10*x^(3/2)/(a*(a+b*x^2)^5)+17/160*x^(3/2)/(a^2*(a+b*x^2)^4)+_
+   221/1920*x^(3/2)/(a^3*(a+b*x^2)^3)+663/5120*x^(3/2)/(a^4*(a+b*x^2)^2)+_
+   663/4096*x^(3/2)/(a^5*(a+b*x^2))-663/8192*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(21/4)*b^(3/4)*sqrt(2))+663/8192*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(21/4)*b^(3/4)*sqrt(2))+663/16384*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(21/4)*_
+   b^(3/4)*sqrt(2))-663/16384*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(21/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  5 10           4 8         2 3 6         3 2 4         4   2
+--R           - 9945b x   - 49725a b x  - 99450a b x  - 99450a b x  - 49725a b x
+--R         + 
+--R                  5
+--R           - 9945a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10           4 8         2 3 6         3 2 4         4   2
+--R           9945b x   + 49725a b x  + 99450a b x  + 99450a b x  + 49725a b x
+--R         + 
+--R                5
+--R           9945a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 5 10           4 8          2 3 6          3 2 4         4   2
+--R           19890b x   + 99450a b x  + 198900a b x  + 198900a b x  + 99450a b x
+--R         + 
+--R                 5
+--R           19890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                4 9            3 7          2 2 5          3   3          4
+--R         (39780b x  + 190944a b x  + 362440a b x  + 337280a b x  + 150580a x)
+--R      *
+--R          +-+4+-+4+-+3 +-+
+--R         \|2 \|a \|b  \|x
+--R  /
+--R                5 5 10           6 4 8           7 3 6           8 2 4
+--R         245760a b x   + 1228800a b x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 9   2          10
+--R         1228800a b x  + 245760a
+--R    *
+--R        +-+4+-+4+-+3
+--R       \|2 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 765
+t0:=1/((a^2+2*a*b*x^2+b^2*x^4)^3*sqrt(x))
+--R 
+--R
+--R                                           1
+--R   (1)  ----------------------------------------------------------------------
+--R          6 12       5 10      2 4 8      3 3 6      4 2 4     5   2    6  +-+
+--R        (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 765
+r0:=-4389/8192*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(23/4)*b^(1/4)*_
+   sqrt(2))+4389/8192*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(23/4)*_
+   b^(1/4)*sqrt(2))-4389/16384*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(23/4)*b^(1/4)*sqrt(2))+4389/16384*log(sqrt(a)+_
+   x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(23/4)*b^(1/4)*sqrt(2))+_
+   1/10*sqrt(x)/(a*(a+b*x^2)^5)+19/160*sqrt(x)/(a^2*(a+b*x^2)^4)+_
+   19/128*sqrt(x)/(a^3*(a+b*x^2)^3)+209/1024*sqrt(x)/(a^4*(a+b*x^2)^2)+_
+   1463/4096*sqrt(x)/(a^5*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           21945b x   + 109725a b x  + 219450a b x  + 219450a b x
+--R         + 
+--R                  4   2         5
+--R           109725a b x  + 21945a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10            4 8          2 3 6          3 2 4
+--R           - 21945b x   - 109725a b x  - 219450a b x  - 219450a b x
+--R         + 
+--R                    4   2         5
+--R           - 109725a b x  - 21945a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   2         5
+--R           219450a b x  + 43890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           43890b x   + 219450a b x  + 438900a b x  + 438900a b x
+--R         + 
+--R                  4   2         5
+--R           219450a b x  + 43890a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                4 8            3 6          2 2 4          3   2         4  +-+
+--R         (29260b x  + 133760a b x  + 237880a b x  + 201248a b x  + 76060a )\|2
+--R      *
+--R         4+-+3 4+-+ +-+
+--R         \|a   \|b \|x
+--R  /
+--R               5 5 10          6 4 8          7 3 6          8 2 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                9   2         10
+--R         409600a b x  + 81920a
+--R    *
+--R        +-+4+-+3 4+-+
+--R       \|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 765
+t0:=1/(x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R   (1)
+--R                                      1
+--R   -----------------------------------------------------------------------
+--R     6 13       5 11      2 4 9      3 3 7      4 2 5     5   3    6   +-+
+--R   (b x   + 6a b x   + 15a b x  + 20a b x  + 15a b x  + 6a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 765
+r0:=13923/8192*b^(1/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(25/4)*_
+   sqrt(2))-13923/8192*b^(1/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(25/4)*sqrt(2))-13923/16384*b^(1/4)*log(sqrt(a)+x*sqrt(b)-_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(25/4)*sqrt(2))+13923/16384*_
+   b^(1/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(25/4)*sqrt(2))+(-13923/4096)/(a^6*sqrt(x))+1/10/(a*(a+b*x^2)^5*_
+   sqrt(x))+21/160/(a^2*(a+b*x^2)^4*sqrt(x))+119/640/(a^3*(a+b*x^2)^3*_
+   sqrt(x))+1547/5120/(a^4*(a+b*x^2)^2*sqrt(x))+13923/20480/(a^5*_
+   (a+b*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                 5 10            4 8          2 3 6          3 2 4
+--R           69615b x   + 348075a b x  + 696150a b x  + 696150a b x
+--R         + 
+--R                  4   2         5
+--R           348075a b x  + 69615a
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   5 10            4 8          2 3 6          3 2 4
+--R           - 69615b x   - 348075a b x  - 696150a b x  - 696150a b x
+--R         + 
+--R                    4   2         5
+--R           - 348075a b x  - 69615a
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    5 10            4 8           2 3 6           3 2 4
+--R           - 139230b x   - 696150a b x  - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    4   2          5
+--R           - 696150a b x  - 139230a
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  + \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                    5 10            4 8           2 3 6           3 2 4
+--R           - 139230b x   - 696150a b x  - 1392300a b x  - 1392300a b x
+--R         + 
+--R                    4   2          5
+--R           - 696150a b x  - 139230a
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  - \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                    5 10             4 8           2 3 6           3 2 4
+--R           - 278460b x   - 1336608a b x  - 2537080a b x  - 2360960a b x
+--R         + 
+--R                     4   2          5
+--R           - 1054060a b x  - 163840a
+--R      *
+--R          +-+4+-+
+--R         \|2 \|a
+--R  /
+--R               6 5 10          7 4 8          8 3 6          9 2 4
+--R         81920a b x   + 409600a b x  + 819200a b x  + 819200a b x
+--R       + 
+--R                10   2         11
+--R         409600a  b x  + 81920a
+--R    *
+--R        +-+4+-+ +-+
+--R       \|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 765
+t0:=1/(x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R   (1)
+--R                                       1
+--R   -------------------------------------------------------------------------
+--R     6 14       5 12      2 4 10      3 3 8      4 2 6     5   4    6 2  +-+
+--R   (b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 765
+r0:=(-33649/12288)/(a^6*x^(3/2))+1/10/(a*x^(3/2)*(a+b*x^2)^5)+_
+   23/160/(a^2*x^(3/2)*(a+b*x^2)^4)+437/1920/(a^3*x^(3/2)*(a+b*x^2)^3)+_
+   437/1024/(a^4*x^(3/2)*(a+b*x^2)^2)+4807/4096/(a^5*x^(3/2)*(a+b*x^2))+_
+   33649/8192*b^(3/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(27/4)*_
+   sqrt(2))-33649/8192*b^(3/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(27/4)*sqrt(2))+33649/16384*b^(3/4)*log(sqrt(a)+x*sqrt(b)-_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(27/4)*sqrt(2))-33649/16384*_
+   b^(3/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(27/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                    5 11             4 9           2 3 7           3 2 5
+--R           - 504735b x   - 2523675a b x  - 5047350a b x  - 5047350a b x
+--R         + 
+--R                     4   3          5
+--R           - 2523675a b x  - 504735a x
+--R      *
+--R         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b  \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  5 11             4 9           2 3 7           3 2 5
+--R           504735b x   + 2523675a b x  + 5047350a b x  + 5047350a b x
+--R         + 
+--R                   4   3          5
+--R           2523675a b x  + 504735a x
+--R      *
+--R         4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b  \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                     5 11             4 9            2 3 7            3 2 5
+--R           - 1009470b x   - 5047350a b x  - 10094700a b x  - 10094700a b x
+--R         + 
+--R                     4   3           5
+--R           - 5047350a b x  - 1009470a x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|b \|x  + \|a
+--R         \|b  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|a
+--R     + 
+--R                     5 11             4 9            2 3 7            3 2 5
+--R           - 1009470b x   - 5047350a b x  - 10094700a b x  - 10094700a b x
+--R         + 
+--R                     4   3           5
+--R           - 5047350a b x  - 1009470a x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|b \|x  - \|a
+--R         \|b  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|a
+--R     + 
+--R                    5 10             4 8           2 3 6           3 2 4
+--R           - 672980b x   - 3076480a b x  - 5471240a b x  - 4628704a b x
+--R         + 
+--R                     4   2          5
+--R           - 1749380a b x  - 163840a
+--R      *
+--R          +-+4+-+3
+--R         \|2 \|a
+--R  /
+--R                6 5 11           7 4 9           8 3 7           9 2 5
+--R         245760a b x   + 1228800a b x  + 2457600a b x  + 2457600a b x
+--R       + 
+--R                 10   3          11
+--R         1228800a  b x  + 245760a  x
+--R    *
+--R        +-+4+-+3 +-+
+--R       \|2 \|a  \|x
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 765
+t0:=1/(x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^3)
+--R 
+--R
+--R   (1)
+--R                                       1
+--R   -------------------------------------------------------------------------
+--R     6 15       5 13      2 4 11      3 3 9      4 2 7     5   5    6 3  +-+
+--R   (b x   + 6a b x   + 15a b x   + 20a b x  + 15a b x  + 6a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 765
+r0:=(-13923/4096)/(a^6*x^(5/2))+1/10/(a*x^(5/2)*(a+b*x^2)^5)+_
+   5/32/(a^2*x^(5/2)*(a+b*x^2)^4)+35/128/(a^3*x^(5/2)*(a+b*x^2)^3)+_
+   595/1024/(a^4*x^(5/2)*(a+b*x^2)^2)+7735/4096/(a^5*x^(5/2)*(a+b*x^2))-_
+   69615/8192*b^(5/4)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(29/4)*_
+   sqrt(2))+69615/8192*b^(5/4)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(29/4)*sqrt(2))+69615/16384*b^(5/4)*log(sqrt(a)+x*sqrt(b)-_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(29/4)*sqrt(2))-69615/16384*_
+   b^(5/4)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(29/4)*sqrt(2))+69615/4096*b/(a^7*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                    6 12             5 10           2 4 8           3 3 6
+--R           - 348075b x   - 1740375a b x   - 3480750a b x  - 3480750a b x
+--R         + 
+--R                     4 2 4          5   2
+--R           - 1740375a b x  - 348075a b x
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  6 12             5 10           2 4 8           3 3 6
+--R           348075b x   + 1740375a b x   + 3480750a b x  + 3480750a b x
+--R         + 
+--R                   4 2 4          5   2
+--R           1740375a b x  + 348075a b x
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  6 12             5 10           2 4 8           3 3 6
+--R           696150b x   + 3480750a b x   + 6961500a b x  + 6961500a b x
+--R         + 
+--R                   4 2 4          5   2
+--R           3480750a b x  + 696150a b x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  + \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                  6 12             5 10           2 4 8           3 3 6
+--R           696150b x   + 3480750a b x   + 6961500a b x  + 6961500a b x
+--R         + 
+--R                   4 2 4          5   2
+--R           3480750a b x  + 696150a b x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  - \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                   6 12             5 10            2 4 8            3 3 6
+--R           1392300b x   + 6683040a b x   + 12685400a b x  + 11804800a b x
+--R         + 
+--R                   4 2 4          5   2         6
+--R           5270300a b x  + 819200a b x  - 32768a
+--R      *
+--R          +-+4+-+
+--R         \|2 \|a
+--R  /
+--R               7 5 12          8 4 10          9 3 8          10 2 6
+--R         81920a b x   + 409600a b x   + 819200a b x  + 819200a  b x
+--R       + 
+--R                11   4         12 2
+--R         409600a  b x  + 81920a  x
+--R    *
+--R        +-+4+-+ +-+
+--R       \|2 \|a \|x
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 765
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R               +-------------------+
+--R         3 +-+ | 2 4         2    2
+--R   (1)  x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 765
+r0:=2/13*x^(9/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+8/117*a*x^(9/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                              +-------------------+
+--R              6        4  +-+ | 2 4         2    2
+--R        (18b x  + 26a x )\|x \|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------
+--R                             2
+--R                       117b x  + 117a
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 765
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R               +-------------------+
+--R         2 +-+ | 2 4         2    2
+--R   (1)  x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 765
+r0:=2/11*x^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+8/77*a*x^(7/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                              +-------------------+
+--R              5        3  +-+ | 2 4         2    2
+--R        (14b x  + 22a x )\|x \|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------
+--R                             2
+--R                        77b x  + 77a
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 765
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R   (1)  x\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 765
+r0:=2/9*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+8/45*a*x^(5/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                              +-------------------+
+--R              4        2  +-+ | 2 4         2    2
+--R        (10b x  + 18a x )\|x \|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------
+--R                             2
+--R                        45b x  + 45a
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 765
+t0:=x^(1/2)*(a^2+2*a*b*x^2+b^2*x^4)^(1/2)
+--R 
+--R
+--R             +-------------------+
+--R         +-+ | 2 4         2    2
+--R   (1)  \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 765
+r0:=2/7*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+8/21*a*x^(3/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                            +-------------------+
+--R             3          +-+ | 2 4         2    2
+--R        (6b x  + 14a x)\|x \|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------
+--R                            2
+--R                       21b x  + 21a
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^(1/2)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                  +-+
+--R                 \|x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 765
+r0:=2/5*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+8/5*a*sqrt(x)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R                          +-------------------+
+--R             2        +-+ | 2 4         2    2
+--R        (2b x  + 10a)\|x \|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------
+--R                           2
+--R                       5b x  + 5a
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^(3/2)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   +-+
+--R                 x\|x
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 765
+r0:=2/3*sqrt(a^2+2*a*b*x^2+b^2*x^4)/sqrt(x)-8/3*a*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/((a+b*x^2)*sqrt(x))
+--R 
+--R
+--R                     +-------------------+
+--R             2       | 2 4         2    2
+--R        (2b x  - 6a)\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------
+--R                      2       +-+
+--R                 (3b x  + 3a)\|x
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^(5/2)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                 2 +-+
+--R                x \|x
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 765
+r0:=2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^(3/2)-8/3*a*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(x^(3/2)*(a+b*x^2))
+--R 
+--R
+--R                     +-------------------+
+--R             2       | 2 4         2    2
+--R        (6b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------
+--R                     3         +-+
+--R                (3b x  + 3a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(1/2)/x^(7/2)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                 3 +-+
+--R                x \|x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 765
+r0:=-2*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^(5/2)+8/5*a*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(x^(5/2)*(a+b*x^2))
+--R 
+--R
+--R                        +-------------------+
+--R                2       | 2 4         2    2
+--R        (- 10b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                      4       2  +-+
+--R                 (5b x  + 5a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 765
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                    +-------------------+
+--R          2 7         5    2 3  +-+ | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 765
+r0:=2/21*x^(9/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+64/1547*a^2*x^(9/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/13923*a^3*x^(9/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+8/119*a*x^(9/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R                                                        +-------------------+
+--R         3 10          2 8        2   6        3 4  +-+ | 2 4         2    2
+--R   (1326b x   + 4914a b x  + 6426a b x  + 3094a x )\|x \|b x  + 2a b x  + a
+--R   --------------------------------------------------------------------------
+--R                                       2
+--R                               13923b x  + 13923a
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 765
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                    +-------------------+
+--R          2 6         4    2 2  +-+ | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 765
+r0:=2/19*x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+64/1045*a^2*x^(7/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/7315*a^3*x^(7/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+8/95*a*x^(7/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R                                                      +-------------------+
+--R        3 9          2 7        2   5        3 3  +-+ | 2 4         2    2
+--R   (770b x  + 2926a b x  + 3990a b x  + 2090a x )\|x \|b x  + 2a b x  + a
+--R   ------------------------------------------------------------------------
+--R                                      2
+--R                               7315b x  + 7315a
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 765
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                   +-------------------+
+--R          2 5         3    2   +-+ | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a x)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 765
+r0:=2/17*x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+64/663*a^2*x^(5/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/3315*a^3*x^(5/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+24/221*a*x^(5/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R                                                      +-------------------+
+--R        3 8          2 6        2   4        3 2  +-+ | 2 4         2    2
+--R   (390b x  + 1530a b x  + 2210a b x  + 1326a x )\|x \|b x  + 2a b x  + a
+--R   ------------------------------------------------------------------------
+--R                                      2
+--R                               3315b x  + 3315a
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 765
+t0:=x^(1/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 4         2    2  +-+ | 2 4         2    2
+--R   (1)  (b x  + 2a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 765
+r0:=2/15*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+64/385*a^2*x^(3/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/1155*a^3*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+8/55*a*x^(3/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                       +-------------------+
+--R             3 7         2 5       2   3       3   +-+ | 2 4         2    2
+--R        (154b x  + 630a b x  + 990a b x  + 770a x)\|x \|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------------------------------
+--R                                         2
+--R                                  1155b x  + 1155a
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(1/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             +-+
+--R                            \|x
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 765
+r0:=2/13*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x)+64/195*a^2*sqrt(x)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/195*a^3*sqrt(x)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+8/39*a*(a+b*x^2)*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                                                     +-------------------+
+--R            3 6         2 4       2   2       3  +-+ | 2 4         2    2
+--R        (30b x  + 130a b x  + 234a b x  + 390a )\|x \|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------------
+--R                                        2
+--R                                  195b x  + 195a
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(3/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             +-+
+--R                           x\|x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 765
+r0:=2/11*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/sqrt(x)+192/77*a*b*x^(3/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/77*a^2*b*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)-24/11*a*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/sqrt(x)
+--R 
+--R
+--R                                                +-------------------+
+--R            3 6        2 4       2   2       3  | 2 4         2    2
+--R        (14b x  + 66a b x  + 154a b x  - 154a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------------
+--R                                    2        +-+
+--R                              (77b x  + 77a)\|x
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(5/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                            2 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 765
+r0:=22/3*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(3/2)-64/9*b^2*x^(5/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)-256/45*a*b^2*x^(5/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)-8*a*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^(3/2)
+--R 
+--R
+--R                                               +-------------------+
+--R            3 6        2 4       2   2      3  | 2 4         2    2
+--R        (10b x  + 54a b x  + 270a b x  - 30a )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------
+--R                                  3          +-+
+--R                            (45b x  + 45a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(7/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                            3 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 765
+r0:=-26/5*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(5/2)+192/35*b^2*x^(3/2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)+256/35*a*b^2*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(a+b*x^2)+24/5*a*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^(5/2)
+--R 
+--R
+--R                                               +-------------------+
+--R            3 6        2 4       2   2      3  | 2 4         2    2
+--R        (10b x  + 70a b x  - 210a b x  - 14a )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------
+--R                                  4        2  +-+
+--R                            (35b x  + 35a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 765
+t0:=x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 11       3 9     2 2 7     3   5    4 3  +-+ | 2 4         2    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 765
+r0:=128/3045*a^2*x^(9/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/145*a*x^(9/2)*_
+   (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/29*x^(9/2)*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)+4096/224315*a^4*x^(9/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+   16384/2018835*a^5*x^(9/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+   512/17255*a^3*x^(9/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R                5 14            4 12           2 3 10           3 2 8
+--R         139230b x   + 807534a b x   + 1922700a b x   + 2375100a b x
+--R       + 
+--R                 4   6          5 4
+--R         1552950a b x  + 448630a x
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R  /
+--R               2
+--R     2018835b x  + 2018835a
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 765
+t0:=x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 10       3 8     2 2 6     3   4    4 2  +-+ | 2 4         2    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 765
+r0:=640/11799*a^2*x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+40/621*a*x^(7/2)*_
+   (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/27*x^(7/2)*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)+4096/129789*a^4*x^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+   16384/908523*a^5*x^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+   512/11799*a^3*x^(7/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R               5 13            4 11          2 3 9           3 2 7
+--R         67298b x   + 395010a b x   + 956340a b x  + 1211364a b x
+--R       + 
+--R                4   5          5 3
+--R         825930a b x  + 259578a x
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     908523b x  + 908523a
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 765
+t0:=x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 9       3 7     2 2 5     3   3    4   +-+ | 2 4         2    2
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 765
+r0:=128/1785*a^2*x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8/105*a*x^(5/2)*_
+   (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/25*x^(5/2)*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)+4096/69615*a^4*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+   16384/348075*a^5*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+   512/7735*a^3*x^(5/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R               5 12            4 10          2 3 8          3 2 6          4   4
+--R         27846b x   + 165750a b x   + 409500a b x  + 535500a b x  + 386750a b x
+--R       + 
+--R                5 2
+--R         139230a x
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     348075b x  + 348075a
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 765
+t0:=x^(1/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                                      +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  +-+ | 2 4         2    2
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 765
+r0:=128/1311*a^2*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+40/437*a*x^(3/2)*_
+   (a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+2/23*x^(3/2)*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)+4096/33649*a^4*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+   16384/100947*a^5*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+   512/4807*a^3*x^(3/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R              5 11           4 9          2 3 7          3 2 5          4   3
+--R         8778b x   + 53130a b x  + 134596a b x  + 183540a b x  + 144210a b x
+--R       + 
+--R               5
+--R         67298a x
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R  /
+--R              2
+--R     100947b x  + 100947a
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^(1/2)
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       +-+
+--R                                      \|x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 765
+r0:=640/4641*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x)+40/357*a*(a+b*x^2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x)+2/21*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)*_
+   sqrt(x)+4096/13923*a^4*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)+_
+   16384/13923*a^5*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)+_
+   2560/13923*a^3*(a+b*x^2)*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R              5 10          4 8         2 3 6         3 2 4         4   2
+--R         1326b x   + 8190a b x  + 21420a b x  + 30940a b x  + 27846a b x
+--R       + 
+--R               5
+--R         27846a
+--R    *
+--R            +-------------------+
+--R        +-+ | 2 4         2    2
+--R       \|x \|b x  + 2a b x  + a
+--R  /
+--R             2
+--R     13923b x  + 13923a
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^(3/2)
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                       +-+
+--R                                     x\|x
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 765
+r0:=128/57*a*b*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)-40/19*a*(a+b*x^2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/sqrt(x)+2/19*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)/sqrt(x)+4096/1463*a^3*b*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)+16384/4389*a^4*b*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)+512/209*a^2*b*x^(3/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R            5 10          4 8        2 3 6         3 2 4         4   2        5
+--R       (462b x   + 2926a b x  + 7980a b x  + 12540a b x  + 14630a b x  - 8778a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             2          +-+
+--R     (4389b x  + 4389a)\|x
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^(5/2)
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                      2 +-+
+--R                                     x \|x
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 765
+r0:=-640/51*b^2*x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)-40/3*a*(a+b*x^2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(3/2)+38/3*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)/x^(3/2)-20480/1989*a^2*b^2*x^(5/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)-16384/1989*a^3*b^2*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)-2560/221*a*b^2*x^(5/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R            5 10          4 8        2 3 6        3 2 4         4   2        5
+--R       (234b x   + 1530a b x  + 4420a b x  + 7956a b x  + 19890a b x  - 1326a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             3            +-+
+--R     (1989b x  + 1989a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^(5/2)/x^(7/2)
+--R 
+--R
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ---------------------------------------------------------------
+--R                                      3 +-+
+--R                                     x \|x
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 765
+r0:=128/15*b^2*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)+8*a*(a+b*x^2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2)/x^(5/2)-42/5*(a^2+2*a*b*x^2+_
+   b^2*x^4)^(5/2)/x^(5/2)+4096/385*a^2*b^2*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)+16384/1155*a^3*b^2*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)+512/55*a*b^2*x^(3/2)*(a+b*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R   (2)
+--R            5 10          4 8        2 3 6        3 2 4         4   2       5
+--R       (154b x   + 1050a b x  + 3300a b x  + 7700a b x  - 11550a b x  - 462a )
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             4          2  +-+
+--R     (1155b x  + 1155a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 765
+t0:=x^(7/2)/sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 3 +-+
+--R                x \|x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 765
+r0:=2/5*x^(5/2)*(a+b*x^2)/(b*sqrt(a^2+2*a*b*x^2+b^2*x^4))-a^(5/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(9/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))+a^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1/2*a^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/2*a^(5/4)*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-2*a*(a+b*x^2)*sqrt(x)/(b^2*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              2     2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5a b x  + 5a )\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                2     2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5a b x  - 5a )\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2      2 4+-+     \|2 \|b \|x  + \|a
+--R       (10a b x  + 10a )\|a atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2      2 4+-+     \|2 \|b \|x  - \|a
+--R       (10a b x  + 10a )\|a atan(-------------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R          2 4          2      2  +-+4+-+ +-+
+--R       (4b x  - 16a b x  - 20a )\|2 \|b \|x
+--R  /
+--R                  +-------------------+
+--R        2 +-+4+-+ | 2 4         2    2
+--R     10b \|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 765
+t0:=x^(5/2)/sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                 2 +-+
+--R                x \|x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 765
+r0:=2/3*x^(3/2)*(a+b*x^2)/(b*sqrt(a^2+2*a*b*x^2+b^2*x^4))+a^(3/4)*_
+   (a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(7/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-a^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   1/2*a^(3/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/2*a^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2      4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 3a)\|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              2      4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 3a)\|a  log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                +-+4+-+ +-+   4+-+
+--R              2      4+-+3     \|2 \|b \|x  + \|a
+--R       (- 6b x  - 6a)\|a  atan(-------------------)
+--R                                       4+-+
+--R                                       \|a
+--R     + 
+--R                              +-+4+-+ +-+   4+-+
+--R            2      4+-+3     \|2 \|b \|x  - \|a          3         +-+4+-+3 +-+
+--R     (- 6b x  - 6a)\|a  atan(-------------------) + (4b x  + 4a x)\|2 \|b  \|x
+--R                                     4+-+
+--R                                     \|a
+--R  /
+--R                 +-------------------+
+--R        +-+4+-+3 | 2 4         2    2
+--R     6b\|2 \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 765
+t0:=x^(3/2)/sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                   +-+
+--R                 x\|x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 765
+r0:=a^(1/4)*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(5/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-a^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   1/2*a^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1/2*a^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+2*(a+b*x^2)*sqrt(x)/_
+   (b*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             2     4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2     4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R              2      4+-+     \|2 \|b \|x  + \|a
+--R       (- 2b x  - 2a)\|a atan(-------------------)
+--R                                      4+-+
+--R                                      \|a
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R              2      4+-+     \|2 \|b \|x  - \|a          2       +-+4+-+ +-+
+--R       (- 2b x  - 2a)\|a atan(-------------------) + (4b x  + 4a)\|2 \|b \|x
+--R                                      4+-+
+--R                                      \|a
+--R  /
+--R                +-------------------+
+--R        +-+4+-+ | 2 4         2    2
+--R     2b\|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 765
+t0:=sqrt(x)/sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R                  +-+
+--R                 \|x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 4         2    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 765
+r0:=-(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(1/4)*b^(3/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(1/4)*b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   1/2*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(1/4)*b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1/2*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R  /
+--R                    +-------------------+
+--R       +-+4+-+4+-+3 | 2 4         2    2
+--R     2\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 765
+t0:=1/(sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R             +-------------------+
+--R         +-+ | 2 4         2    2
+--R        \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 765
+r0:=-(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(1/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(3/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   1/2*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(3/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/2*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(3/4)*_
+   b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R           2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  + \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|b \|x  - \|a
+--R       (2b x  + 2a)atan(-------------------)
+--R                                4+-+
+--R                                \|a
+--R  /
+--R                     +-------------------+
+--R       +-+4+-+3 4+-+ | 2 4         2    2
+--R     2\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 765
+t0:=1/(x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R              +-------------------+
+--R          +-+ | 2 4         2    2
+--R        x\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 765
+r0:=b^(1/4)*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-b^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   1/2*b^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1/2*b^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-2*(a+b*x^2)/(a*sqrt(x)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R           2     4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (b x  + a)\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             2     4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- b x  - a)\|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R              2      4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (- 2b x  - 2a)\|b \|x atan(-------------------)
+--R                                          4+-+
+--R                                          \|a
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R              2      4+-+ +-+     \|2 \|b \|x  - \|a            2       +-+4+-+
+--R       (- 2b x  - 2a)\|b \|x atan(-------------------) + (- 4b x  - 4a)\|2 \|a
+--R                                          4+-+
+--R                                          \|a
+--R  /
+--R                    +-------------------+
+--R        +-+4+-+ +-+ | 2 4         2    2
+--R     2a\|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 765
+t0:=1/(x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R               +-------------------+
+--R         2 +-+ | 2 4         2    2
+--R        x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 765
+r0:=-2/3*(a+b*x^2)/(a*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+b^(3/4)*_
+   (a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-b^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   1/2*b^(3/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1/2*b^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              3        4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 3a x)\|b  \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R            3        4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 3a x)\|b  \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                      +-+4+-+ +-+   4+-+
+--R              3        4+-+3 +-+     \|2 \|b \|x  + \|a
+--R       (- 6b x  - 6a x)\|b  \|x atan(-------------------)
+--R                                             4+-+
+--R                                             \|a
+--R     + 
+--R                                      +-+4+-+ +-+   4+-+
+--R              3        4+-+3 +-+     \|2 \|b \|x  - \|a
+--R       (- 6b x  - 6a x)\|b  \|x atan(-------------------)
+--R                                             4+-+
+--R                                             \|a
+--R     + 
+--R              2       +-+4+-+3
+--R       (- 4b x  - 4a)\|2 \|a
+--R  /
+--R                       +-------------------+
+--R          +-+4+-+3 +-+ | 2 4         2    2
+--R     6a x\|2 \|a  \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 765
+t0:=1/(x^(7/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R               +-------------------+
+--R         3 +-+ | 2 4         2    2
+--R        x \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 765
+r0:=-2/5*(a+b*x^2)/(a*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-b^(5/4)*_
+   (a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+b^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   1/2*b^(5/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1/2*b^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+2*b*(a+b*x^2)/(a^2*_
+   sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2 4         2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 5a b x )\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R          2 4         2 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 5a b x )\|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R           2 4          2 4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (10b x  + 10a b x )\|b \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R           2 4          2 4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (10b x  + 10a b x )\|b \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R           2 4          2     2  +-+4+-+
+--R       (20b x  + 16a b x  - 4a )\|2 \|a
+--R  /
+--R                        +-------------------+
+--R        2 2 +-+4+-+ +-+ | 2 4         2    2
+--R     10a x \|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 765
+t0:=x^(15/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            7 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 765
+r0:=1/4*a*x^(9/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+   17/16*x^(9/2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+117/80*x^(5/2)*_
+   (a+b*x^2)/(b^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))-117/32*a^(5/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(17/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))+117/32*a^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   117/64*a^(5/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+117/64*a^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-117/16*a*(a+b*x^2)*_
+   sqrt(x)/(b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              2 4        2   2       3 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (585a b x  + 1170a b x  + 585a )\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  2 4        2   2       3 4+-+
+--R         (- 585a b x  - 1170a b x  - 585a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                   +-+4+-+ +-+   4+-+
+--R               2 4        2   2        3 4+-+     \|2 \|b \|x  + \|a
+--R       (1170a b x  + 2340a b x  + 1170a )\|a atan(-------------------)
+--R                                                          4+-+
+--R                                                          \|a
+--R     + 
+--R                                                   +-+4+-+ +-+   4+-+
+--R               2 4        2   2        3 4+-+     \|2 \|b \|x  - \|a
+--R       (1170a b x  + 2340a b x  + 1170a )\|a atan(-------------------)
+--R                                                          4+-+
+--R                                                          \|a
+--R     + 
+--R            3 6          2 4        2   2        3  +-+4+-+ +-+
+--R       (128b x  - 1664a b x  - 4212a b x  - 2340a )\|2 \|b \|x
+--R  /
+--R                                 +-------------------+
+--R          5 2         4  +-+4+-+ | 2 4         2    2
+--R     (320b x  + 320a b )\|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 765
+t0:=x^(13/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            6 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 765
+r0:=1/4*a*x^(7/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+   15/16*x^(7/2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/48*x^(3/2)*_
+   (a+b*x^2)/(b^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/32*a^(3/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(15/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-77/32*a^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   77/64*a^(3/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/64*a^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2 4           2       2 4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (231b x  + 462a b x  + 231a )\|a  log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                2 4           2       2 4+-+3
+--R         (- 231b x  - 462a b x  - 231a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                 +-+4+-+ +-+   4+-+
+--R              2 4           2       2 4+-+3     \|2 \|b \|x  + \|a
+--R       (- 462b x  - 924a b x  - 462a )\|a  atan(-------------------)
+--R                                                        4+-+
+--R                                                        \|a
+--R     + 
+--R                                                 +-+4+-+ +-+   4+-+
+--R              2 4           2       2 4+-+3     \|2 \|b \|x  - \|a
+--R       (- 462b x  - 924a b x  - 462a )\|a  atan(-------------------)
+--R                                                        4+-+
+--R                                                        \|a
+--R     + 
+--R            2 5           3       2   +-+4+-+3 +-+
+--R       (128b x  + 484a b x  + 308a x)\|2 \|b  \|x
+--R  /
+--R                                  +-------------------+
+--R          4 2         3  +-+4+-+3 | 2 4         2    2
+--R     (192b x  + 192a b )\|2 \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 765
+t0:=x^(11/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            5 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 765
+r0:=1/4*a*x^(5/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+   13/16*x^(5/2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/32*a^(1/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(b^(13/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-45/32*a^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   45/64*a^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-45/64*a^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/16*(a+b*x^2)*sqrt(x)/_
+   (b^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             2 4          2      2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45b x  - 90a b x  - 45a )\|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2 4          2      2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45b x  + 90a b x  + 45a )\|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                              +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+     \|2 \|b \|x  + \|a
+--R       (- 90b x  - 180a b x  - 90a )\|a atan(-------------------)
+--R                                                     4+-+
+--R                                                     \|a
+--R     + 
+--R                                              +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+     \|2 \|b \|x  - \|a
+--R       (- 90b x  - 180a b x  - 90a )\|a atan(-------------------)
+--R                                                     4+-+
+--R                                                     \|a
+--R     + 
+--R            2 4           2       2  +-+4+-+ +-+
+--R       (128b x  + 324a b x  + 180a )\|2 \|b \|x
+--R  /
+--R                               +-------------------+
+--R         4 2        3  +-+4+-+ | 2 4         2    2
+--R     (64b x  + 64a b )\|2 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 765
+t0:=x^(9/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            4 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 765
+r0:=1/4*a*x^(3/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+   11/16*x^(3/2)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))-21/32*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(1/4)*b^(11/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+21/32*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(1/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   21/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(1/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-21/64*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(1/4)*_
+   b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             2 4          2      2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21b x  - 42a b x  - 21a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R           2 4          2      2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 42a b x  + 21a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  + \|a
+--R       (42b x  + 84a b x  + 42a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  - \|a
+--R       (42b x  + 84a b x  + 42a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R               3          +-+4+-+4+-+3 +-+
+--R       (- 44b x  - 28a x)\|2 \|a \|b  \|x
+--R  /
+--R                                    +-------------------+
+--R         3 2        2  +-+4+-+4+-+3 | 2 4         2    2
+--R     (64b x  + 64a b )\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 765
+t0:=x^(7/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            3 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 765
+r0:=1/4*a*(a+b*x^2)*sqrt(x)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-_
+   5/32*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*_
+   b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+5/32*(a+b*x^2)*atan(1+_
+   b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(9/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-5/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*_
+   b^(1/4)*sqrt(2)*sqrt(x))/(a^(3/4)*b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+5/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(3/4)*b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   9/16*sqrt(x)/(b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R          2 4          2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 10a b x  + 5a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R            2 4          2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 10a b x  - 5a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  + \|a
+--R       (10b x  + 20a b x  + 10a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  - \|a
+--R       (10b x  + 20a b x  + 10a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R               2        +-+4+-+3 4+-+ +-+
+--R       (- 36b x  - 20a)\|2 \|a   \|b \|x
+--R  /
+--R                                     +-------------------+
+--R         3 2        2  +-+4+-+3 4+-+ | 2 4         2    2
+--R     (64b x  + 64a b )\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 765
+t0:=x^(5/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                            2 +-+
+--R                           x \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 765
+r0:=1/4*x^(7/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-1/16*x^(3/2)/_
+   (a*b*sqrt(a^2+2*a*b*x^2+b^2*x^4))-3/32*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(5/4)*b^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   3/32*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*b^(7/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/64*(a+b*x^2)*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*b^(7/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-3/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*b^(7/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2 4         2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 6a b x  - 3a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R          2 4         2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 6a b x  + 3a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|b \|x  + \|a
+--R       (6b x  + 12a b x  + 6a )atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|b \|x  - \|a
+--R       (6b x  + 12a b x  + 6a )atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R             3         +-+4+-+4+-+3 +-+
+--R       (12b x  - 4a x)\|2 \|a \|b  \|x
+--R  /
+--R                                     +-------------------+
+--R           2 2      2   +-+4+-+4+-+3 | 2 4         2    2
+--R     (64a b x  + 64a b)\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 765
+t0:=x^(3/2)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                             +-+
+--R                           x\|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 765
+r0:=1/4*x^(5/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-3/32*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(5/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/32*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(7/4)*b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   3/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(7/4)*b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3/64*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(7/4)*b^(5/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-3/16*sqrt(x)/(a*b*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R          2 4         2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3b x  + 6a b x  + 3a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R            2 4         2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3b x  - 6a b x  - 3a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|b \|x  + \|a
+--R       (6b x  + 12a b x  + 6a )atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|b \|x  - \|a
+--R       (6b x  + 12a b x  + 6a )atan(-------------------)
+--R                                            4+-+
+--R                                            \|a
+--R     + 
+--R            2        +-+4+-+3 4+-+ +-+
+--R       (4b x  - 12a)\|2 \|a   \|b \|x
+--R  /
+--R                                      +-------------------+
+--R           2 2      2   +-+4+-+3 4+-+ | 2 4         2    2
+--R     (64a b x  + 64a b)\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 765
+t0:=sqrt(x)/(a^2+2*a*b*x^2+b^2*x^4)^(3/2)
+--R 
+--R
+--R                             +-+
+--R                            \|x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 4         2    2  | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 765
+r0:=1/4*x^(3/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/16*x^(3/2)/_
+   (a^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))-5/32*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+5/32*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(9/4)*b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+5/64*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(9/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-5/64*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(9/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            2 4          2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5b x  - 10a b x  - 5a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R          2 4          2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5b x  + 10a b x  + 5a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  + \|a
+--R       (10b x  + 20a b x  + 10a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  - \|a
+--R       (10b x  + 20a b x  + 10a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R             3          +-+4+-+4+-+3 +-+
+--R       (20b x  + 36a x)\|2 \|a \|b  \|x
+--R  /
+--R                                    +-------------------+
+--R         2   2      3  +-+4+-+4+-+3 | 2 4         2    2
+--R     (64a b x  + 64a )\|2 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+)clear all
+
+--S 325 of 765
+t0:=1/((a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x))
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R                                  +-------------------+
+--R          2 4         2    2  +-+ | 2 4         2    2
+--R        (b x  + 2a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 765
+r0:=1/4*(a+b*x^2)*sqrt(x)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-21/32*_
+   (a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(1/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+21/32*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))-21/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(11/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   21/64*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(11/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+7/16*sqrt(x)/_
+   (a^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R           2 4          2      2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21b x  + 42a b x  + 21a )log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             2 4          2      2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21b x  - 42a b x  - 21a )log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  + \|a
+--R       (42b x  + 84a b x  + 42a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|b \|x  - \|a
+--R       (42b x  + 84a b x  + 42a )atan(-------------------)
+--R                                              4+-+
+--R                                              \|a
+--R     + 
+--R             2        +-+4+-+3 4+-+ +-+
+--R       (28b x  + 44a)\|2 \|a   \|b \|x
+--R  /
+--R                                     +-------------------+
+--R         2   2      3  +-+4+-+3 4+-+ | 2 4         2    2
+--R     (64a b x  + 64a )\|2 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 765
+t0:=1/(x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R                                   +-------------------+
+--R          2 5         3    2   +-+ | 2 4         2    2
+--R        (b x  + 2a b x  + a x)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 765
+r0:=1/4*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x))+45/32*b^(1/4)*_
+   (a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-45/32*b^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   45/64*b^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/64*b^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+9/16/(a^2*sqrt(x)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-45/16*(a+b*x^2)/(a^3*sqrt(x)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R           2 4          2      2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45b x  + 90a b x  + 45a )\|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               2 4          2      2 4+-+ +-+
+--R         (- 45b x  - 90a b x  - 45a )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (- 90b x  - 180a b x  - 90a )\|b \|x atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (- 90b x  - 180a b x  - 90a )\|b \|x atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|a
+--R     + 
+--R              2 4           2       2  +-+4+-+
+--R       (- 180b x  - 324a b x  - 128a )\|2 \|a
+--R  /
+--R                                   +-------------------+
+--R         3   2      4  +-+4+-+ +-+ | 2 4         2    2
+--R     (64a b x  + 64a )\|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 765
+t0:=1/(x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                                1
+--R   (1)  -------------------------------------------------
+--R                                    +-------------------+
+--R          2 6         4    2 2  +-+ | 2 4         2    2
+--R        (b x  + 2a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 765
+r0:=1/4*(a+b*x^2)/(a*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+   11/16/(a^2*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-77/48*(a+b*x^2)/_
+   (a^3*x^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/32*b^(3/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(15/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-77/32*b^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   77/64*b^(3/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-77/64*b^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                2 5           3       2  4+-+3 +-+
+--R         (- 231b x  - 462a b x  - 231a x)\|b  \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              2 5           3       2  4+-+3 +-+
+--R         (231b x  + 462a b x  + 231a x)\|b  \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R              2 5           3       2  4+-+3 +-+     \|2 \|b \|x  + \|a
+--R       (- 462b x  - 924a b x  - 462a x)\|b  \|x atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|a
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R              2 5           3       2  4+-+3 +-+     \|2 \|b \|x  - \|a
+--R       (- 462b x  - 924a b x  - 462a x)\|b  \|x atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|a
+--R     + 
+--R              2 4           2       2  +-+4+-+3
+--R       (- 308b x  - 484a b x  - 128a )\|2 \|a
+--R  /
+--R                                       +-------------------+
+--R          3   3       4   +-+4+-+3 +-+ | 2 4         2    2
+--R     (192a b x  + 192a x)\|2 \|a  \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 765
+t0:=1/(x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))
+--R 
+--R
+--R                                1
+--R   (1)  -------------------------------------------------
+--R                                    +-------------------+
+--R          2 7         5    2 3  +-+ | 2 4         2    2
+--R        (b x  + 2a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 765
+r0:=1/4*(a+b*x^2)/(a*x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+_
+   13/16/(a^2*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-117/80*(a+b*x^2)/_
+   (a^3*x^(5/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-117/32*b^(5/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(17/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))+117/32*b^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   117/64*b^(5/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-117/64*b^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+117/16*b*(a+b*x^2)/_
+   (a^4*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                3 6          2 4       2   2 4+-+ +-+
+--R         (- 585b x  - 1170a b x  - 585a b x )\|b \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              3 6          2 4       2   2 4+-+ +-+
+--R         (585b x  + 1170a b x  + 585a b x )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                                                         +-+4+-+ +-+   4+-+
+--R             3 6          2 4        2   2 4+-+ +-+     \|2 \|b \|x  + \|a
+--R       (1170b x  + 2340a b x  + 1170a b x )\|b \|x atan(-------------------)
+--R                                                                4+-+
+--R                                                                \|a
+--R     + 
+--R                                                         +-+4+-+ +-+   4+-+
+--R             3 6          2 4        2   2 4+-+ +-+     \|2 \|b \|x  - \|a
+--R       (1170b x  + 2340a b x  + 1170a b x )\|b \|x atan(-------------------)
+--R                                                                4+-+
+--R                                                                \|a
+--R     + 
+--R             3 6          2 4        2   2       3  +-+4+-+
+--R       (2340b x  + 4212a b x  + 1664a b x  - 128a )\|2 \|a
+--R  /
+--R                                       +-------------------+
+--R          4   4       5 2  +-+4+-+ +-+ | 2 4         2    2
+--R     (320a b x  + 320a x )\|2 \|a \|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 765
+t0:=x^(23/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                     11 +-+
+--R                                    x  \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 765
+r0:=1/8*a*x^(17/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   11/32*x^(17/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+119/256*a*x^(9/2)*_
+   (a+b*x^2)/(b^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-2023/1024*x^(9/2)/(b^4*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+13923/5120*x^(5/2)*(a+b*x^2)/(b^5*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-13923/2048*a^(5/4)*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(b^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   13923/2048*a^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (b^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-13923/4096*a^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+13923/4096*a^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-13923/1024*a*(a+b*x^2)*_
+   sqrt(x)/(b^6*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                  4 8          2 3 6          3 2 4          4   2         5
+--R         (69615a b x  + 278460a b x  + 417690a b x  + 278460a b x  + 69615a )
+--R      *
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    4 8          2 3 6          3 2 4          4   2         5
+--R         (- 69615a b x  - 278460a b x  - 417690a b x  - 278460a b x  - 69615a )
+--R      *
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|a log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                   4 8          2 3 6          3 2 4          4   2          5
+--R         (139230a b x  + 556920a b x  + 835380a b x  + 556920a b x  + 139230a )
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  + \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                   4 8          2 3 6          3 2 4          4   2          5
+--R         (139230a b x  + 556920a b x  + 835380a b x  + 556920a b x  + 139230a )
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|b \|x  - \|a
+--R         \|a atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                5 10            4 8          2 3 6           3 2 4
+--R           8192b x   - 172032a b x  - 882028a b x  - 1478932a b x
+--R         + 
+--R                     4   2          5
+--R           - 1058148a b x  - 278460a
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|b \|x
+--R  /
+--R              9 6           8 4         2 7 2         3 6  +-+4+-+
+--R       (20480b x  + 61440a b x  + 61440a b x  + 20480a b )\|2 \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 765
+t0:=x^(21/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                     10 +-+
+--R                                    x  \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 765
+r0:=1/8*a*x^(15/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   31/96*x^(15/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+95/256*a*x^(7/2)*_
+   (a+b*x^2)/(b^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-1425/1024*x^(7/2)/(b^4*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+7315/3072*x^(3/2)*(a+b*x^2)/(b^5*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+7315/2048*a^(3/4)*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(23/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   7315/2048*a^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (b^(23/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-7315/4096*a^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(23/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+7315/4096*a^(3/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(23/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                4 8           3 6          2 2 4         3   2         4 4+-+3
+--R         (21945b x  + 87780a b x  + 131670a b x  + 87780a b x  + 21945a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  4 8           3 6          2 2 4         3   2         4 4+-+3
+--R         (- 21945b x  - 87780a b x  - 131670a b x  - 87780a b x  - 21945a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  4 8            3 6          2 2 4          3   2         4
+--R         (- 43890b x  - 175560a b x  - 263340a b x  - 175560a b x  - 43890a )
+--R      *
+--R                    +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  + \|a
+--R         \|a  atan(-------------------)
+--R                           4+-+
+--R                           \|a
+--R     + 
+--R                  4 8            3 6          2 2 4          3   2         4
+--R         (- 43890b x  - 175560a b x  - 263340a b x  - 175560a b x  - 43890a )
+--R      *
+--R                    +-+4+-+ +-+   4+-+
+--R         4+-+3     \|2 \|b \|x  - \|a
+--R         \|a  atan(-------------------)
+--R                           4+-+
+--R                           \|a
+--R     + 
+--R               4 9           3 7          2 2 5          3   3         4   +-+
+--R         (8192b x  + 67868a b x  + 133380a b x  + 104500a b x  + 29260a x)\|2
+--R      *
+--R         4+-+3 +-+
+--R         \|b  \|x
+--R  /
+--R              8 6           7 4         2 6 2         3 5  +-+4+-+3
+--R       (12288b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 765
+t0:=x^(19/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      9 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 765
+r0:=1/8*a*x^(13/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   29/96*x^(13/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+221/768*a*x^(5/2)*_
+   (a+b*x^2)/(b^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-2873/3072*x^(5/2)/(b^4*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+3315/2048*a^(1/4)*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(b^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   3315/2048*a^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (b^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3315/4096*a^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-3315/4096*a^(1/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+3315/1024*(a+b*x^2)*_
+   sqrt(x)/(b^5*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                 4 8           3 6         2 2 4         3   2        4 4+-+
+--R         (- 9945b x  - 39780a b x  - 59670a b x  - 39780a b x  - 9945a )\|a
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8           3 6         2 2 4         3   2        4 4+-+
+--R         (9945b x  + 39780a b x  + 59670a b x  + 39780a b x  + 9945a )\|a
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  4 8           3 6          2 2 4         3   2         4 4+-+
+--R         (- 19890b x  - 79560a b x  - 119340a b x  - 79560a b x  - 19890a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                  4 8           3 6          2 2 4         3   2         4 4+-+
+--R         (- 19890b x  - 79560a b x  - 119340a b x  - 79560a b x  - 19890a )\|a
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R                4 8            3 6          2 2 4          3   2         4  +-+
+--R         (24576b x  + 126004a b x  + 211276a b x  + 151164a b x  + 39780a )\|2
+--R      *
+--R         4+-+ +-+
+--R         \|b \|x
+--R  /
+--R              8 6           7 4         2 6 2         3 5  +-+4+-+
+--R       (12288b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 765
+t0:=x^(17/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      8 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 765
+r0:=1/8*a*x^(11/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   9/32*x^(11/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+55/256*a*x^(3/2)*_
+   (a+b*x^2)/(b^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-605/1024*x^(3/2)/(b^4*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-1155/2048*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(1/4)*b^(19/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+1155/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(1/4)*b^(19/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1155/4096*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(1/4)*b^(19/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1155/4096*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(1/4)*b^(19/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                 4 8          3 6        2 2 4        3   2        4
+--R         (- 1155b x  - 4620a b x  - 6930a b x  - 4620a b x  - 1155a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1155b x  + 4620a b x  + 6930a b x  + 4620a b x  + 1155a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8          3 6         2 2 4        3   2        4
+--R         (2310b x  + 9240a b x  + 13860a b x  + 9240a b x  + 2310a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6         2 2 4        3   2        4
+--R         (2310b x  + 9240a b x  + 13860a b x  + 9240a b x  + 2310a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               3 7          2 5        2   3        3   +-+4+-+4+-+3 +-+
+--R       (- 3572b x  - 7020a b x  - 5500a b x  - 1540a x)\|2 \|a \|b  \|x
+--R  /
+--R             7 6           6 4         2 5 2        3 4  +-+4+-+4+-+3
+--R       (4096b x  + 12288a b x  + 12288a b x  + 4096a b )\|2 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 765
+t0:=x^(15/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      7 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 765
+r0:=1/8*a*x^(9/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   25/96*x^(9/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+39/256*a*(a+b*x^2)*_
+   sqrt(x)/(b^4*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-195/2048*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(17/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+195/2048*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(3/4)*b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))-195/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(3/4)*b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   195/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(3/4)*b^(17/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   351/1024*sqrt(x)/(b^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (585b x  + 2340a b x  + 3510a b x  + 2340a b x  + 585a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                4 8          3 6        2 2 4        3   2       4
+--R         (- 585b x  - 2340a b x  - 3510a b x  - 2340a b x  - 585a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1170b x  + 4680a b x  + 7020a b x  + 4680a b x  + 1170a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1170b x  + 4680a b x  + 7020a b x  + 4680a b x  + 1170a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               3 6           2 4        2   2        3  +-+4+-+3 4+-+ +-+
+--R       (- 7412b x  - 12428a b x  - 8892a b x  - 2340a )\|2 \|a   \|b \|x
+--R  /
+--R              7 6           6 4         2 5 2         3 4  +-+4+-+3 4+-+
+--R       (12288b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 765
+t0:=x^(13/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      6 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 765
+r0:=1/8*a*x^(7/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   23/96*x^(7/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+77/768*x^(7/2)*_
+   (a+b*x^2)/(a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-77/3072*x^(3/2)/(a*b^3*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-77/2048*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(5/4)*b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   77/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(5/4)*_
+   b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*_
+   b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-77/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(5/4)*_
+   b^(15/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                4 8         3 6        2 2 4       3   2       4
+--R         (- 231b x  - 924a b x  - 1386a b x  - 924a b x  - 231a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (231b x  + 924a b x  + 1386a b x  + 924a b x  + 231a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (462b x  + 1848a b x  + 2772a b x  + 1848a b x  + 462a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (462b x  + 1848a b x  + 2772a b x  + 1848a b x  + 462a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 7          2 5        2   3       3   +-+4+-+4+-+3 +-+
+--R       (924b x  - 1404a b x  - 1100a b x  - 308a x)\|2 \|a \|b  \|x
+--R  /
+--R                6 6         2 5 4         3 4 2         4 3  +-+4+-+4+-+3
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 765
+t0:=x^(11/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      5 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 765
+r0:=1/8*a*x^(5/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   7/32*x^(5/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+15/256*x^(5/2)*_
+   (a+b*x^2)/(a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-45/2048*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(13/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/2048*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(7/4)*b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))-45/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(7/4)*b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   45/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(7/4)*b^(13/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   45/1024*sqrt(x)/(a*b^3*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (45b x  + 180a b x  + 270a b x  + 180a b x  + 45a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8         3 6       2 2 4       3   2      4
+--R         (- 45b x  - 180a b x  - 270a b x  - 180a b x  - 45a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (90b x  + 360a b x  + 540a b x  + 360a b x  + 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (90b x  + 360a b x  + 540a b x  + 360a b x  + 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R           3 6         2 4       2   2       3  +-+4+-+3 4+-+ +-+
+--R       (60b x  - 956a b x  - 684a b x  - 180a )\|2 \|a   \|b \|x
+--R  /
+--R               6 6         2 5 4         3 4 2        4 3  +-+4+-+3 4+-+
+--R       (4096a b x  + 12288a b x  + 12288a b x  + 4096a b )\|2 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 765
+t0:=x^(9/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      4 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 765
+r0:=1/8*a*x^(3/2)*(a+b*x^2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   19/96*x^(3/2)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+7/256*x^(3/2)*_
+   (a+b*x^2)/(a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+35/1024*x^(3/2)/_
+   (a^2*b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))-35/2048*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(9/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+35/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(9/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+35/4096*(a+_
+   b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(9/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-35/4096*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(9/4)*b^(11/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                4 8         3 6       2 2 4       3   2       4
+--R         (- 105b x  - 420a b x  - 630a b x  - 420a b x  - 105a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8         3 6       2 2 4       3   2       4
+--R         (105b x  + 420a b x  + 630a b x  + 420a b x  + 105a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (210b x  + 840a b x  + 1260a b x  + 840a b x  + 210a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (210b x  + 840a b x  + 1260a b x  + 840a b x  + 210a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 7          2 5       2   3       3   +-+4+-+4+-+3 +-+
+--R       (420b x  + 1596a b x  - 500a b x  - 140a x)\|2 \|a \|b  \|x
+--R  /
+--R              2 5 6         3 4 4         4 3 2         5 2  +-+4+-+4+-+3
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 765
+t0:=x^(7/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      3 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 765
+r0:=1/8*a*(a+b*x^2)*sqrt(x)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-_
+   17/96*sqrt(x)/(b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+5/768*(a+b*x^2)*_
+   sqrt(x)/(a*b^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))-35/2048*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(9/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))+35/2048*(a+b*x^2)*atan(1+b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(11/4)*b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))-35/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(11/4)*b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   35/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*_
+   sqrt(x))/(a^(11/4)*b^(9/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   35/3072*sqrt(x)/(a^2*b^2*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              4 8         3 6       2 2 4       3   2       4
+--R         (105b x  + 420a b x  + 630a b x  + 420a b x  + 105a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                4 8         3 6       2 2 4       3   2       4
+--R         (- 105b x  - 420a b x  - 630a b x  - 420a b x  - 105a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (210b x  + 840a b x  + 1260a b x  + 840a b x  + 210a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (210b x  + 840a b x  + 1260a b x  + 840a b x  + 210a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 6         2 4        2   2       3  +-+4+-+3 4+-+ +-+
+--R       (140b x  + 500a b x  - 1596a b x  - 420a )\|2 \|a   \|b \|x
+--R  /
+--R              2 5 6         3 4 4         4 3 2         5 2  +-+4+-+3 4+-+
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a b )\|2 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 765
+t0:=x^(5/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                      2 +-+
+--R                                     x \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 765
+r0:=1/8*x^(7/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-3/32*x^(3/2)/_
+   (a*b*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+9/256*x^(3/2)*(a+b*x^2)/(a^2*b*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))+45/1024*x^(3/2)/(a^3*b*sqrt(a^2+2*a*b*_
+   x^2+b^2*x^4))-45/2048*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(13/4)*b^(7/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/2048*_
+   (a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(13/4)*b^(7/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+45/4096*(a+b*x^2)*log(sqrt(a)+_
+   x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(13/4)*b^(7/4)*sqrt(2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))-45/4096*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+_
+   a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(13/4)*b^(7/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R               4 8         3 6       2 2 4       3   2      4
+--R         (- 45b x  - 180a b x  - 270a b x  - 180a b x  - 45a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (45b x  + 180a b x  + 270a b x  + 180a b x  + 45a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (90b x  + 360a b x  + 540a b x  + 360a b x  + 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R             4 8         3 6       2 2 4       3   2      4
+--R         (90b x  + 360a b x  + 540a b x  + 360a b x  + 90a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 7         2 5       2   3      3   +-+4+-+4+-+3 +-+
+--R       (180b x  + 684a b x  + 956a b x  - 60a x)\|2 \|a \|b  \|x
+--R  /
+--R             3 4 6         4 3 4         5 2 2        6   +-+4+-+4+-+3
+--R       (4096a b x  + 12288a b x  + 12288a b x  + 4096a b)\|2 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 765
+t0:=x^(3/2)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                       +-+
+--R                                     x\|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 765
+r0:=1/8*x^(5/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))-11/96*sqrt(x)/_
+   (a*b*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+11/768*(a+b*x^2)*sqrt(x)/(a^2*b*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))-77/2048*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(15/4)*b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   77/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(15/4)*_
+   b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-77/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(15/4)*_
+   b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(15/4)*_
+   b^(5/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+77/3072*sqrt(x)/(a^3*b*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R              4 8         3 6        2 2 4       3   2       4
+--R         (231b x  + 924a b x  + 1386a b x  + 924a b x  + 231a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                4 8         3 6        2 2 4       3   2       4
+--R         (- 231b x  - 924a b x  - 1386a b x  - 924a b x  - 231a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (462b x  + 1848a b x  + 2772a b x  + 1848a b x  + 462a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (462b x  + 1848a b x  + 2772a b x  + 1848a b x  + 462a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R            3 6          2 4        2   2       3  +-+4+-+3 4+-+ +-+
+--R       (308b x  + 1100a b x  + 1404a b x  - 924a )\|2 \|a   \|b \|x
+--R  /
+--R              3 4 6         4 3 4         5 2 2         6   +-+4+-+3 4+-+
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a b)\|2 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 765
+t0:=sqrt(x)/(a^2+2*a*b*x^2+b^2*x^4)^(5/2)
+--R 
+--R
+--R                                       +-+
+--R                                      \|x
+--R   (1)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 765
+r0:=1/8*x^(3/2)*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+13/96*x^(3/2)/_
+   (a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+39/256*x^(3/2)*(a+b*x^2)/(a^3*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))+195/1024*x^(3/2)/(a^4*sqrt(a^2+2*a*b*_
+   x^2+b^2*x^4))-195/2048*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(17/4)*b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   195/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(17/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+195/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(17/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-195/4096*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(17/4)*_
+   b^(3/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                4 8          3 6        2 2 4        3   2       4
+--R         (- 585b x  - 2340a b x  - 3510a b x  - 2340a b x  - 585a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R              4 8          3 6        2 2 4        3   2       4
+--R         (585b x  + 2340a b x  + 3510a b x  + 2340a b x  + 585a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1170b x  + 4680a b x  + 7020a b x  + 4680a b x  + 1170a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1170b x  + 4680a b x  + 7020a b x  + 4680a b x  + 1170a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R             3 7          2 5         2   3        3   +-+4+-+4+-+3 +-+
+--R       (2340b x  + 8892a b x  + 12428a b x  + 7412a x)\|2 \|a \|b  \|x
+--R  /
+--R              4 3 6         5 2 4         6   2         7  +-+4+-+4+-+3
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a )\|2 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 765
+t0:=1/((a^2+2*a*b*x^2+b^2*x^4)^(5/2)*sqrt(x))
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R                                                      +-------------------+
+--R          4 8       3 6     2 2 4     3   2    4  +-+ | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 765
+r0:=1/8*(a+b*x^2)*sqrt(x)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+5/32*sqrt(x)/_
+   (a^2*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+55/256*(a+b*x^2)*sqrt(x)/(a^3*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))-1155/2048*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(19/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+1155/2048*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(19/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-1155/4096*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(19/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+1155/4096*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(19/4)*b^(1/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+385/1024*_
+   sqrt(x)/(a^4*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R               4 8          3 6        2 2 4        3   2        4
+--R         (1155b x  + 4620a b x  + 6930a b x  + 4620a b x  + 1155a )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 4 8          3 6        2 2 4        3   2        4
+--R         (- 1155b x  - 4620a b x  - 6930a b x  - 4620a b x  - 1155a )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R               4 8          3 6         2 2 4        3   2        4
+--R         (2310b x  + 9240a b x  + 13860a b x  + 9240a b x  + 2310a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  + \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R               4 8          3 6         2 2 4        3   2        4
+--R         (2310b x  + 9240a b x  + 13860a b x  + 9240a b x  + 2310a )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|b \|x  - \|a
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|a
+--R     + 
+--R             3 6          2 4        2   2        3  +-+4+-+3 4+-+ +-+
+--R       (1540b x  + 5500a b x  + 7020a b x  + 3572a )\|2 \|a   \|b \|x
+--R  /
+--R             4 3 6         5 2 4         6   2        7  +-+4+-+3 4+-+
+--R       (4096a b x  + 12288a b x  + 12288a b x  + 4096a )\|2 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 765
+t0:=1/(x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R                                                       +-------------------+
+--R          4 9       3 7     2 2 5     3   3    4   +-+ | 2 4         2    2
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 765
+r0:=1/8*(a+b*x^2)/(a*(a^2+2*a*b*x^2+b^2*x^4)^(5/2)*sqrt(x))+17/96/(a^2*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x))+221/768*(a+b*x^2)/(a^3*(a^2+_
+   2*a*b*x^2+b^2*x^4)^(3/2)*sqrt(x))+3315/2048*b^(1/4)*(a+b*x^2)*_
+   atan(1-b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(21/4)*sqrt(2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-3315/2048*b^(1/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*_
+   sqrt(x)/a^(1/4))/(a^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-_
+   3315/4096*b^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   3315/4096*b^(1/4)*(a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*_
+   sqrt(2)*sqrt(x))/(a^(21/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   663/1024/(a^4*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-3315/1024*(a+b*x^2)/_
+   (a^5*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R               4 8           3 6         2 2 4         3   2        4 4+-+ +-+
+--R         (9945b x  + 39780a b x  + 59670a b x  + 39780a b x  + 9945a )\|b \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                 4 8           3 6         2 2 4         3   2        4 4+-+ +-+
+--R         (- 9945b x  - 39780a b x  - 59670a b x  - 39780a b x  - 9945a )\|b \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  4 8           3 6          2 2 4         3   2         4 4+-+
+--R         (- 19890b x  - 79560a b x  - 119340a b x  - 79560a b x  - 19890a )\|b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|b \|x  + \|a
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                  4 8           3 6          2 2 4         3   2         4 4+-+
+--R         (- 19890b x  - 79560a b x  - 119340a b x  - 79560a b x  - 19890a )\|b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|b \|x  - \|a
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|a
+--R     + 
+--R                  4 8            3 6          2 2 4          3   2         4
+--R         (- 39780b x  - 151164a b x  - 211276a b x  - 126004a b x  - 24576a )
+--R      *
+--R          +-+4+-+
+--R         \|2 \|a
+--R  /
+--R              5 3 6         6 2 4         7   2         8  +-+4+-+ +-+
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a )\|2 \|a \|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 765
+t0:=1/(x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                           1
+--R   (1)  ----------------------------------------------------------------------
+--R                                                         +-------------------+
+--R          4 10       3 8     2 2 6     3   4    4 2  +-+ | 2 4         2    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 765
+r0:=1/8*(a+b*x^2)/(a*x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+19/96/(a^2*_
+   x^(3/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+95/256*(a+b*x^2)/(a^3*x^(3/2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1045/1024/(a^4*x^(3/2)*sqrt(a^2+2*a*_
+   b*x^2+b^2*x^4))-7315/3072*(a+b*x^2)/(a^5*x^(3/2)*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4))+7315/2048*b^(3/4)*(a+b*x^2)*atan(1-b^(1/4)*sqrt(2)*sqrt(x)/_
+   a^(1/4))/(a^(23/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-7315/2048*_
+   b^(3/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/(a^(23/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+7315/4096*b^(3/4)*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(23/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-7315/4096*b^(3/4)*(a+b*x^2)*_
+   log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/(a^(23/4)*_
+   sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                  4 9           3 7          2 2 5         3   3         4
+--R         (- 21945b x  - 87780a b x  - 131670a b x  - 87780a b x  - 21945a x)
+--R      *
+--R         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b  \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                4 9           3 7          2 2 5         3   3         4  4+-+3
+--R         (21945b x  + 87780a b x  + 131670a b x  + 87780a b x  + 21945a x)\|b
+--R      *
+--R          +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                  4 9            3 7          2 2 5          3   3         4
+--R         (- 43890b x  - 175560a b x  - 263340a b x  - 175560a b x  - 43890a x)
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|b \|x  + \|a
+--R         \|b  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|a
+--R     + 
+--R                  4 9            3 7          2 2 5          3   3         4
+--R         (- 43890b x  - 175560a b x  - 263340a b x  - 175560a b x  - 43890a x)
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|b \|x  - \|a
+--R         \|b  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|a
+--R     + 
+--R              4 8            3 6          2 2 4         3   2        4  +-+4+-+3
+--R     (- 29260b x  - 104500a b x  - 133380a b x  - 67868a b x  - 8192a )\|2 \|a
+--R  /
+--R              5 3 7         6 2 5         7   3         8   +-+4+-+3 +-+
+--R       (12288a b x  + 36864a b x  + 36864a b x  + 12288a x)\|2 \|a  \|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 765
+t0:=1/(x^(7/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))
+--R 
+--R
+--R                                           1
+--R   (1)  ----------------------------------------------------------------------
+--R                                                         +-------------------+
+--R          4 11       3 9     2 2 7     3   5    4 3  +-+ | 2 4         2    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 765
+r0:=1/8*(a+b*x^2)/(a*x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(5/2))+7/32/(a^2*_
+   x^(5/2)*(a^2+2*a*b*x^2+b^2*x^4)^(3/2))+119/256*(a+b*x^2)/(a^3*x^(5/2)*_
+   (a^2+2*a*b*x^2+b^2*x^4)^(3/2))+1547/1024/(a^4*x^(5/2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-13923/5120*(a+b*x^2)/(a^5*x^(5/2)*sqrt(a^2+_
+   2*a*b*x^2+b^2*x^4))-13923/2048*b^(5/4)*(a+b*x^2)*atan(1-b^(1/4)*_
+   sqrt(2)*sqrt(x)/a^(1/4))/(a^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+_
+   13923/2048*b^(5/4)*(a+b*x^2)*atan(1+b^(1/4)*sqrt(2)*sqrt(x)/a^(1/4))/_
+   (a^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+13923/4096*b^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)-a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))-13923/4096*b^(5/4)*_
+   (a+b*x^2)*log(sqrt(a)+x*sqrt(b)+a^(1/4)*b^(1/4)*sqrt(2)*sqrt(x))/_
+   (a^(25/4)*sqrt(2)*sqrt(a^2+2*a*b*x^2+b^2*x^4))+13923/1024*b*(a+_
+   b*x^2)/(a^6*sqrt(x)*sqrt(a^2+2*a*b*x^2+b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                     5 10            4 8          2 3 6          3 2 4
+--R             - 69615b x   - 278460a b x  - 417690a b x  - 278460a b x
+--R           + 
+--R                     4   2
+--R             - 69615a b x
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(\|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                5 10            4 8          2 3 6          3 2 4         4   2
+--R         (69615b x   + 278460a b x  + 417690a b x  + 278460a b x  + 69615a b x )
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b \|x log(- \|2 \|a \|b \|x  + x\|b  + \|a )
+--R     + 
+--R                    5 10            4 8          2 3 6          3 2 4
+--R             139230b x   + 556920a b x  + 835380a b x  + 556920a b x
+--R           + 
+--R                    4   2
+--R             139230a b x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  + \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                    5 10            4 8          2 3 6          3 2 4
+--R             139230b x   + 556920a b x  + 835380a b x  + 556920a b x
+--R           + 
+--R                    4   2
+--R             139230a b x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|b \|x  - \|a
+--R         \|b \|x atan(-------------------)
+--R                              4+-+
+--R                              \|a
+--R     + 
+--R                  5 10             4 8           2 3 6          3 2 4
+--R           278460b x   + 1058148a b x  + 1478932a b x  + 882028a b x
+--R         + 
+--R                  4   2        5
+--R           172032a b x  - 8192a
+--R      *
+--R          +-+4+-+
+--R         \|2 \|a
+--R  /
+--R              6 3 8         7 2 6         8   4         9 2  +-+4+-+ +-+
+--R       (20480a b x  + 61440a b x  + 61440a b x  + 20480a x )\|2 \|a \|x
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 765
+t0:=x^m*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R         m  2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 765
+--r0:=x^(1+m)*(a^2+2*a*b*x^2+b^2*x^4)^p*
+-- hypergeometric(1/2*(1+m),-2*p,1/2*(3+m),-b*x^2/a)/((1+m)*
+-- ((a+b*x^2)/a)^(2*p))
+--E 386
+
+--S 387 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 387
+
+)clear all
+
+--S 388 of 765
+t0:=x^9*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R         9  2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 765
+r0:=6*a^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^5*(2+p)*(1+2*p)*(3+2*p)*_
+   (5+2*p))+3*a^2*x^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^3*(2+p)*_
+   (3+2*p)*(5+2*p))-a*x^6*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^2*(2+p)*_
+   (5+2*p))+1/2*x^8*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b*(5+2*p))-_
+   3*a^3*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^5*(1+p)*(2+p)*(3+2*p)*(5+2*p))
+--R 
+--R
+--R   (2)
+--R             3      3   2 4         2    2 p + 1
+--R       (- 12a p - 6a )(b x  + 2a b x  + a )
+--R     + 
+--R              5 4      5 3      5 2      5      5  10
+--R           (4b p  + 20b p  + 35b p  + 25b p + 6b )x
+--R         + 
+--R                4 4        4 3        4 2       4   8
+--R           (4a b p  + 12a b p  + 11a b p  + 3a b p)x
+--R         + 
+--R                2 3 3      2 3 2     2 3   6       3 2 2      3 2      3 2  4
+--R           (- 8a b p  - 12a b p  - 4a b p)x  + (12a b p  + 18a b p + 6a b )x
+--R         + 
+--R               4         4   2      5       5
+--R           (12a b p + 12a b)x  + 12a p + 12a
+--R      *
+--R           2 4         2    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        5 5       5 4       5 3       5 2       5       5
+--R     16b p  + 120b p  + 340b p  + 450b p  + 274b p + 60b
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 765
+t0:=x^7*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R         7  2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 765
+r0:=-3/2*a^3*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^4*(2+p)*(1+2*p)*_
+   (3+2*p))-3/4*a*x^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^2*(2+p)*_
+   (3+2*p))+1/4*x^6*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b*(2+p))+_
+   3/4*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^4*(1+p)*(2+p)*(3+2*p))
+--R 
+--R
+--R   (2)
+--R          2      2   2 4         2    2 p + 1
+--R       (6a p + 3a )(b x  + 2a b x  + a )
+--R     + 
+--R              4 3      4 2      4      4  8        3 3       3 2       3   6
+--R           (4b p  + 12b p  + 11b p + 3b )x  + (4a b p  + 6a b p  + 2a b p)x
+--R         + 
+--R                2 2 2     2 2      2 2  4        3        3   2     4      4
+--R           (- 6a b p  - 9a b p - 3a b )x  + (- 6a b p - 6a b)x  - 6a p - 6a
+--R      *
+--R           2 4         2    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        4 4      4 3       4 2       4       4
+--R     16b p  + 80b p  + 140b p  + 100b p + 24b
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 765
+t0:=x^5*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R         5  2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 765
+r0:=a^2*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^3*(1+2*p)*(3+2*p))+_
+   1/2*x^4*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b*(3+2*p))-_
+   1/2*a*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^3*(1+p)*(3+2*p))
+--R 
+--R
+--R   (2)
+--R                     2 4         2    2 p + 1
+--R       (- 2a p - a)(b x  + 2a b x  + a )
+--R     + 
+--R              3 2     3     3  6        2 2       2       2  4
+--R           (2b p  + 3b p + b )x  + (2a b p  + 3a b p + a b )x
+--R         + 
+--R              2        2   2     3      3
+--R           (2a b p + 2a b)x  + 2a p + 2a
+--R      *
+--R           2 4         2    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R       3 3      3 2      3      3
+--R     8b p  + 24b p  + 22b p + 6b
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 765
+t0:=x^3*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R         3  2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 765
+r0:=-1/2*a*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b^2*(1+2*p))+_
+   1/4*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^2*(1+p))
+--R 
+--R
+--R   (2)
+--R                 2 4         2    2 p + 1
+--R       (2p + 1)(b x  + 2a b x  + a )
+--R     + 
+--R                          2     2      2   2 4         2    2 p
+--R       ((- 2a b p - 2a b)x  - 2a p - 2a )(b x  + 2a b x  + a )
+--R  /
+--R       2 2      2      2
+--R     8b p  + 12b p + 4b
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 765
+t0:=x*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R            2 4         2    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 765
+r0:=1/2*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p/(b*(1+2*p))
+--R 
+--R
+--R            2       2 4         2    2 p
+--R        (b x  + a)(b x  + 2a b x  + a )
+--R   (2)  --------------------------------
+--R                    4b p + 2b
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 765
+t0:=(a^2+2*a*b*x^2+b^2*x^4)^p/x
+--R 
+--R
+--R          2 4         2    2 p
+--R        (b x  + 2a b x  + a )
+--R   (1)  ----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 765
+--r0:=1/4*(a^2+2*a*b*x^2+b^2*x^4)^p*
+-- hypergeometric(-2*p,-2*p,1-2*p,-a/(b*x^2))/(p*((a+b*x^2)/(b*x^2))^(2*p))
+--E 404
+
+--S 405 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 405
+
+)clear all
+
+--S 406 of 765
+t0:=x^m*(a+b*x^2+c*x^4)
+--R 
+--R
+--R            4      2      m
+--R   (1)  (c x  + b x  + a)x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 765
+r0:=a*x^(1+m)/(1+m)+b*x^(3+m)/(3+m)+c*x^(5+m)/(5+m)
+--R 
+--R
+--R   (2)
+--R           2              m + 5       2              m + 3
+--R       (c m  + 4c m + 3c)x      + (b m  + 6b m + 5b)x
+--R     + 
+--R           2               m + 1
+--R       (a m  + 8a m + 15a)x
+--R  /
+--R      3     2
+--R     m  + 9m  + 23m + 15
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 765
+t0:=x^4*(a+b*x^2+c*x^4)
+--R 
+--R
+--R           8      6      4
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 409
+
+--S 410 of 765
+r0:=1/5*a*x^5+1/7*b*x^7+1/9*c*x^9
+--R 
+--R
+--R        1    9   1    7   1    5
+--R   (2)  - c x  + - b x  + - a x
+--R        9        7        5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 410
+
+--S 411 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 765
+t0:=x^3*(a+b*x^2+c*x^4)
+--R 
+--R
+--R           7      5      3
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 412
+
+--S 413 of 765
+r0:=1/4*a*x^4+1/6*b*x^6+1/8*c*x^8
+--R 
+--R
+--R        1    8   1    6   1    4
+--R   (2)  - c x  + - b x  + - a x
+--R        8        6        4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 413
+
+--S 414 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 765
+t0:=x^2*(a+b*x^2+c*x^4)
+--R 
+--R
+--R           6      4      2
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 415
+
+--S 416 of 765
+r0:=1/3*a*x^3+1/5*b*x^5+1/7*c*x^7
+--R 
+--R
+--R        1    7   1    5   1    3
+--R   (2)  - c x  + - b x  + - a x
+--R        7        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 416
+
+--S 417 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 765
+t0:=x*(a+b*x^2+c*x^4)
+--R 
+--R
+--R           5      3
+--R   (1)  c x  + b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 418
+
+--S 419 of 765
+r0:=1/2*a*x^2+1/4*b*x^4+1/6*c*x^6
+--R 
+--R
+--R        1    6   1    4   1    2
+--R   (2)  - c x  + - b x  + - a x
+--R        6        4        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 419
+
+--S 420 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 765
+t0:=a+b*x^2+c*x^4
+--R 
+--R
+--R           4      2
+--R   (1)  c x  + b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 421
+
+--S 422 of 765
+r0:=a*x+1/3*b*x^3+1/5*c*x^5
+--R 
+--R
+--R        1    5   1    3
+--R   (2)  - c x  + - b x  + a x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 422
+
+--S 423 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 765
+t0:=(a+b*x^2+c*x^4)/x
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R               x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 424
+
+--S 425 of 765
+r0:=1/2*b*x^2+1/4*c*x^4+a*log(x)
+--R 
+--R
+--R                       4       2
+--R        4a log(x) + c x  + 2b x
+--R   (2)  ------------------------
+--R                    4
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 765
+t0:=(a+b*x^2+c*x^4)/x^2
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R                2
+--R               x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 427
+
+--S 428 of 765
+r0:=-a/x+b*x+1/3*c*x^3
+--R 
+--R
+--R           4       2
+--R        c x  + 3b x  - 3a
+--R   (2)  -----------------
+--R                3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 428
+
+--S 429 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 765
+t0:=(a+b*x^2+c*x^4)/x^3
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R                3
+--R               x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 430
+
+--S 431 of 765
+r0:=-1/2*a/x^2+1/2*c*x^2+b*log(x)
+--R 
+--R
+--R            2            4
+--R        2b x log(x) + c x  - a
+--R   (2)  ----------------------
+--R                    2
+--R                  2x
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 765
+t0:=(a+b*x^2+c*x^4)/x^4
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R                4
+--R               x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 433
+
+--S 434 of 765
+r0:=-1/3*a/x^3-b/x+c*x
+--R 
+--R
+--R           4      2   1
+--R        c x  - b x  - - a
+--R                      3
+--R   (2)  -----------------
+--R                 3
+--R                x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 434
+
+--S 435 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 765
+t0:=x^m*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 8         6            2  4         2    2  m
+--R   (1)  (c x  + 2b c x  + (2a c + b )x  + 2a b x  + a )x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 765
+r0:=a^2*x^(1+m)/(1+m)+2*a*b*x^(3+m)/(3+m)+(b^2+2*a*c)*x^(5+m)/(5+m)+_
+   2*b*c*x^(7+m)/(7+m)+c^2*x^(9+m)/(9+m)
+--R 
+--R
+--R   (2)
+--R         2 4      2 3      2 2       2        2  m + 9
+--R       (c m  + 16c m  + 86c m  + 176c m + 105c )x
+--R     + 
+--R              4          3           2                      m + 7
+--R       (2b c m  + 36b c m  + 208b c m  + 444b c m + 270b c)x
+--R     + 
+--R                    2  4               2  3                 2  2
+--R           (2a c + b )m  + (40a c + 20b )m  + (260a c + 130b )m
+--R         + 
+--R                         2                  2
+--R           (600a c + 300b )m + 378a c + 189b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R              4          3           2                      m + 3
+--R       (2a b m  + 44a b m  + 328a b m  + 916a b m + 630a b)x
+--R     + 
+--R         2 4      2 3       2 2       2        2  m + 1
+--R       (a m  + 24a m  + 206a m  + 744a m + 945a )x
+--R  /
+--R      5      4       3       2
+--R     m  + 25m  + 230m  + 950m  + 1689m + 945
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 765
+t0:=x^4*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 12         10            2  8         6    2 4
+--R   (1)  c x   + 2b c x   + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 439
+
+--S 440 of 765
+r0:=1/5*a^2*x^5+2/7*a*b*x^7+1/9*(b^2+2*a*c)*x^9+2/11*b*c*x^11+1/13*c^2*x^13
+--R 
+--R
+--R         1  2 13    2      11    2       1  2  9   2      7   1  2 5
+--R   (2)  -- c x   + -- b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        13         11            9       9         7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 440
+
+--S 441 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 765
+t0:=x^3*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 11         9            2  7         5    2 3
+--R   (1)  c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 442
+
+--S 443 of 765
+r0:=1/4*a^2*x^4+1/3*a*b*x^6+1/8*(b^2+2*a*c)*x^8+1/5*b*c*x^10+1/12*c^2*x^12
+--R 
+--R
+--R         1  2 12   1      10    1       1  2  8   1      6   1  2 4
+--R   (2)  -- c x   + - b c x   + (- a c + - b )x  + - a b x  + - a x
+--R        12         5            4       8         3          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 443
+
+--S 444 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 444
+
+)clear all
+
+--S 445 of 765
+t0:=x^2*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 10         8            2  6         4    2 2
+--R   (1)  c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 445
+
+--S 446 of 765
+r0:=1/3*a^2*x^3+2/5*a*b*x^5+1/7*(b^2+2*a*c)*x^7+2/9*b*c*x^9+1/11*c^2*x^11
+--R 
+--R
+--R         1  2 11   2      9    2       1  2  7   2      5   1  2 3
+--R   (2)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        11         9           7       7         5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 446
+
+--S 447 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 765
+t0:=x*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 9         7            2  5         3    2
+--R   (1)  c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 448
+
+--S 449 of 765
+r0:=1/2*a^2*x^2+1/2*a*b*x^4+1/6*(b^2+2*a*c)*x^6+1/4*b*c*x^8+1/10*c^2*x^10
+--R 
+--R
+--R         1  2 10   1      8    1       1  2  6   1      4   1  2 2
+--R   (2)  -- c x   + - b c x  + (- a c + - b )x  + - a b x  + - a x
+--R        10         4           3       6         2          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 449
+
+--S 450 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 765
+t0:=(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R   (1)  c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 451
+
+--S 452 of 765
+r0:=a^2*x+2/3*a*b*x^3+1/5*(b^2+2*a*c)*x^5+2/7*b*c*x^7+1/9*c^2*x^9
+--R 
+--R
+--R        1  2 9   2      7    2       1  2  5   2      3    2
+--R   (2)  - c x  + - b c x  + (- a c + - b )x  + - a b x  + a x
+--R        9        7           5       5         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 452
+
+--S 453 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 765
+t0:=(a+b*x^2+c*x^4)^2/x
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                              x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 454
+
+--S 455 of 765
+r0:=a*b*x^2+1/4*(b^2+2*a*c)*x^4+1/3*b*c*x^6+1/8*c^2*x^8+a^2*log(x)
+--R 
+--R
+--R           2           2 8         6              2  4          2
+--R        24a log(x) + 3c x  + 8b c x  + (12a c + 6b )x  + 24a b x
+--R   (2)  ---------------------------------------------------------
+--R                                    24
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 765
+t0:=(a+b*x^2+c*x^4)^2/x^2
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                               2
+--R                              x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 457
+
+--S 458 of 765
+r0:=-a^2/x+2*a*b*x+1/3*(b^2+2*a*c)*x^3+2/5*b*c*x^5+1/7*c^2*x^7
+--R 
+--R
+--R           2 8          6               2  4           2       2
+--R        15c x  + 42b c x  + (70a c + 35b )x  + 210a b x  - 105a
+--R   (2)  --------------------------------------------------------
+--R                                  105x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 458
+
+--S 459 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 765
+t0:=(a+b*x^2+c*x^4)^2/x^3
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                               3
+--R                              x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 460
+
+--S 461 of 765
+r0:=-1/2*a^2/x^2+1/2*(b^2+2*a*c)*x^2+1/2*b*c*x^4+1/6*c^2*x^6+2*a*b*log(x)
+--R 
+--R
+--R               2          2 8         6             2  4     2
+--R        12a b x log(x) + c x  + 3b c x  + (6a c + 3b )x  - 3a
+--R   (2)  ------------------------------------------------------
+--R                                    2
+--R                                  6x
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 765
+t0:=(a+b*x^2+c*x^4)^2/x^4
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                               4
+--R                              x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 463
+
+--S 464 of 765
+r0:=-1/3*a^2/x^3-2*a*b/x+(b^2+2*a*c)*x+2/3*b*c*x^3+1/5*c^2*x^5
+--R 
+--R
+--R        1  2 8   2      6            2  4         2   1  2
+--R        - c x  + - b c x  + (2a c + b )x  - 2a b x  - - a
+--R        5        3                                    3
+--R   (2)  --------------------------------------------------
+--R                                 3
+--R                                x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 464
+
+--S 465 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 765
+t0:=(a+b*x^2+c*x^4)^2/x^7
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                               7
+--R                              x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 466
+
+--S 467 of 765
+r0:=-1/6*a^2/x^6-1/2*a*b/x^4+1/2*(-b^2-2*a*c)/x^2+1/2*c^2*x^2+2*b*c*log(x)
+--R 
+--R
+--R               6           2 8               2  4         2    2
+--R        12b c x log(x) + 3c x  + (- 6a c - 3b )x  - 3a b x  - a
+--R   (2)  --------------------------------------------------------
+--R                                     6
+--R                                   6x
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 765
+t0:=(a+b*x^2+c*x^4)^2/x^13
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                              13
+--R                             x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 469
+
+--S 470 of 765
+r0:=-1/12*a^2/x^12-1/5*a*b/x^10+1/8*(-b^2-2*a*c)/x^8-1/3*b*c/x^6-1/4*c^2/x^4
+--R 
+--R
+--R          1  2 8   1      6      1       1  2  4   1      2    1  2
+--R        - - c x  - - b c x  + (- - a c - - b )x  - - a b x  - -- a
+--R          4        3             4       8         5          12
+--R   (2)  -----------------------------------------------------------
+--R                                     12
+--R                                    x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 470
+
+--S 471 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 765
+t0:=x^m*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  *
+--R      m
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 765
+r0:=a^3*x^(1+m)/(1+m)+3*a^2*b*x^(3+m)/(3+m)+3*a*(b^2+a*c)*x^(5+m)/(5+m)+_
+   b*(b^2+6*a*c)*x^(7+m)/(7+m)+3*c*(b^2+a*c)*x^(9+m)/(9+m)+_
+   3*b*c^2*x^(11+m)/(11+m)+c^3*x^(13+m)/(13+m)
+--R 
+--R
+--R   (2)
+--R           3 6      3 5       3 4        3 3         3 2         3          3
+--R         (c m  + 36c m  + 505c m  + 3480c m  + 12139c m  + 19524c m + 10395c )
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R               2 6         2 5          2 4           2 3           2 2
+--R           3b c m  + 114b c m  + 1665b c m  + 11820b c m  + 42117b c m
+--R         + 
+--R                   2            2
+--R           68706b c m + 36855b c
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                2     2   6          2       2   5           2        2   4
+--R           (3a c  + 3b c)m  + (120a c  + 120b c)m  + (1839a c  + 1839b c)m
+--R         + 
+--R                    2         2   3            2         2   2
+--R           (13584a c  + 13584b c)m  + (49881a c  + 49881b c)m
+--R         + 
+--R                    2         2              2         2
+--R           (83064a c  + 83064b c)m + 45045a c  + 45045b c
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                      3  6                  3  5                    3  4
+--R           (6a b c + b )m  + (252a b c + 42b )m  + (4074a b c + 679b )m
+--R         + 
+--R                              3  3                        3  2
+--R           (31752a b c + 5292b )m  + (122010a b c + 20335b )m
+--R         + 
+--R                                3                         3
+--R           (209916a b c + 34986b )m + 115830a b c + 19305b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R              2        2  6        2          2  5         2           2  4
+--R           (3a c + 3a b )m  + (132a c + 132a b )m  + (2259a c + 2259a b )m
+--R         + 
+--R                  2            2  3          2            2  2
+--R           (18840a c + 18840a b )m  + (77937a c + 77937a b )m
+--R         + 
+--R                   2             2           2            2
+--R           (142308a c + 142308a b )m + 81081a c + 81081a b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R             2   6       2   5        2   4         2   3          2   2
+--R           3a b m  + 138a b m  + 2505a b m  + 22620a b m  + 104277a b m
+--R         + 
+--R                  2             2
+--R           219162a b m + 135135a b
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R           3 6      3 5       3 4        3 3         3 2          3           3
+--R         (a m  + 48a m  + 925a m  + 9120a m  + 48259a m  + 129072a m + 135135a )
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R      7      6       5         4         3          2
+--R     m  + 49m  + 973m  + 10045m  + 57379m  + 177331m  + 264207m + 135135
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 765
+t0:=x^4*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 16       2 14        2     2   12              3  10      2        2  8
+--R     c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x   + (3a c + 3a b )x
+--R   + 
+--R       2   6    3 4
+--R     3a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 475
+
+--S 476 of 765
+r0:=1/5*a^3*x^5+3/7*a^2*b*x^7+1/3*a*(b^2+a*c)*x^9+1/11*b*(b^2+6*a*c)*x^11+_
+   3/13*c*(b^2+a*c)*x^13+1/5*b*c^2*x^15+1/17*c^3*x^17
+--R 
+--R
+--R   (2)
+--R      1  3 17   1    2 15     3    2    3  2   13     6          1  3  11
+--R     -- c x   + - b c x   + (-- a c  + -- b c)x   + (-- a b c + -- b )x
+--R     17         5            13        13            11         11
+--R   + 
+--R      1  2    1    2  9   3  2   7   1  3 5
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      3       3           7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 476
+
+--S 477 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 765
+t0:=x^3*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 15       2 13        2     2   11              3  9      2        2  7
+--R     c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R   + 
+--R       2   5    3 3
+--R     3a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 478
+
+--S 479 of 765
+r0:=1/4*a^3*x^4+1/2*a^2*b*x^6+3/8*a*(b^2+a*c)*x^8+1/10*b*(b^2+6*a*c)*x^10+_
+   1/4*c*(b^2+a*c)*x^12+3/14*b*c^2*x^14+1/16*c^3*x^16
+--R 
+--R
+--R   (2)
+--R      1  3 16    3    2 14    1    2   1  2   12    3          1  3  10
+--R     -- c x   + -- b c x   + (- a c  + - b c)x   + (- a b c + -- b )x
+--R     16         14            4        4            5         10
+--R   + 
+--R      3  2    3    2  8   1  2   6   1  3 4
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      8       8           2          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 479
+
+--S 480 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 765
+t0:=x^2*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 14       2 12        2     2   10              3  8      2        2  6
+--R     c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R   + 
+--R       2   4    3 2
+--R     3a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 481
+
+--S 482 of 765
+r0:=1/3*a^3*x^3+3/5*a^2*b*x^5+3/7*a*(b^2+a*c)*x^7+1/9*b*(b^2+6*a*c)*x^9+_
+   3/11*c*(b^2+a*c)*x^11+3/13*b*c^2*x^13+1/15*c^3*x^15
+--R 
+--R
+--R   (2)
+--R      1  3 15    3    2 13     3    2    3  2   11    2         1  3  9
+--R     -- c x   + -- b c x   + (-- a c  + -- b c)x   + (- a b c + - b )x
+--R     15         13            11        11            3         9
+--R   + 
+--R      3  2    3    2  7   3  2   5   1  3 3
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      7       7           5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 482
+
+--S 483 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+)clear all
+
+--S 484 of 765
+t0:=x*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 13       2 11        2     2   9              3  7      2        2  5
+--R     c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R   + 
+--R       2   3    3
+--R     3a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 484
+
+--S 485 of 765
+r0:=1/2*a^3*x^2+3/4*a^2*b*x^4+1/2*a*(b^2+a*c)*x^6+1/8*b*(b^2+6*a*c)*x^8+_
+   3/10*c*(b^2+a*c)*x^10+1/4*b*c^2*x^12+1/14*c^3*x^14
+--R 
+--R
+--R   (2)
+--R      1  3 14   1    2 12     3    2    3  2   10    3         1  3  8
+--R     -- c x   + - b c x   + (-- a c  + -- b c)x   + (- a b c + - b )x
+--R     14         4            10        10            4         8
+--R   + 
+--R      1  2    1    2  6   3  2   4   1  3 2
+--R     (- a c + - a b )x  + - a b x  + - a x
+--R      2       2           4          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 485
+
+--S 486 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 765
+t0:=(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 12       2 10        2     2   8              3  6      2        2  4
+--R     c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R   + 
+--R       2   2    3
+--R     3a b x  + a
+--R                                                    Type: Polynomial(Integer)
+--E 487
+
+--S 488 of 765
+r0:=a^3*x+a^2*b*x^3+3/5*a*(b^2+a*c)*x^5+1/7*b*(b^2+6*a*c)*x^7+_
+   1/3*c*(b^2+a*c)*x^9+3/11*b*c^2*x^11+1/13*c^3*x^13
+--R 
+--R
+--R   (2)
+--R      1  3 13    3    2 11    1    2   1  2   9    6         1  3  7
+--R     -- c x   + -- b c x   + (- a c  + - b c)x  + (- a b c + - b )x
+--R     13         11            3        3           7         7
+--R   + 
+--R      3  2    3    2  5    2   3    3
+--R     (- a c + - a b )x  + a b x  + a x
+--R      5       5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 488
+
+--S 489 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 765
+t0:=(a+b*x^2+c*x^4)^3/x
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 490
+
+--S 491 of 765
+r0:=3/2*a^2*b*x^2+3/4*a*(b^2+a*c)*x^4+1/6*b*(b^2+6*a*c)*x^6+_
+   3/8*c*(b^2+a*c)*x^8+3/10*b*c^2*x^10+1/12*c^3*x^12+a^3*log(x)
+--R 
+--R
+--R   (2)
+--R           3            3 12        2 10         2      2   8
+--R       120a log(x) + 10c x   + 36b c x   + (45a c  + 45b c)x
+--R     + 
+--R                      3  6       2         2  4       2   2
+--R       (120a b c + 20b )x  + (90a c + 90a b )x  + 180a b x
+--R  /
+--R     120
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 765
+t0:=(a+b*x^2+c*x^4)^3/x^2
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      2
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 493
+
+--S 494 of 765
+r0:=-a^3/x+3*a^2*b*x+a*(b^2+a*c)*x^3+1/5*b*(b^2+6*a*c)*x^5+_
+   3/7*c*(b^2+a*c)*x^7+1/3*b*c^2*x^9+1/11*c^3*x^11
+--R 
+--R
+--R   (2)
+--R           3 12         2 10          2       2   8                    3  6
+--R       105c x   + 385b c x   + (495a c  + 495b c)x  + (1386a b c + 231b )x
+--R     + 
+--R             2           2  4        2   2        3
+--R       (1155a c + 1155a b )x  + 3465a b x  - 1155a
+--R  /
+--R     1155x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 494
+
+--S 495 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 765
+t0:=(a+b*x^2+c*x^4)^3/x^3
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      3
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 496
+
+--S 497 of 765
+r0:=-1/2*a^3/x^2+3/2*a*(b^2+a*c)*x^2+1/4*b*(b^2+6*a*c)*x^4+_
+   1/2*c*(b^2+a*c)*x^6+3/8*b*c^2*x^8+1/10*c^3*x^10+3*a^2*b*log(x)
+--R 
+--R
+--R   (2)
+--R           2   2           3 12        2 10         2      2   8
+--R       120a b x log(x) + 4c x   + 15b c x   + (20a c  + 20b c)x
+--R     + 
+--R                     3  6       2         2  4      3
+--R       (60a b c + 10b )x  + (60a c + 60a b )x  - 20a
+--R  /
+--R        2
+--R     40x
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 765
+t0:=(a+b*x^2+c*x^4)^3/x^4
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      4
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 499
+
+--S 500 of 765
+r0:=-1/3*a^3/x^3-3*a^2*b/x+3*a*(b^2+a*c)*x+1/3*b*(b^2+6*a*c)*x^3+_
+   3/5*c*(b^2+a*c)*x^5+3/7*b*c^2*x^7+1/9*c^3*x^9
+--R 
+--R
+--R   (2)
+--R       1  3 12   3    2 10    3    2   3  2   8             1  3  6
+--R       - c x   + - b c x   + (- a c  + - b c)x  + (2a b c + - b )x
+--R       9         7            5        5                    3
+--R     + 
+--R          2        2  4     2   2   1  3
+--R       (3a c + 3a b )x  - 3a b x  - - a
+--R                                    3
+--R  /
+--R      3
+--R     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 500
+
+--S 501 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 765
+t0:=x^m/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 765
+--r0:=2*c*x^(1+m)*hypergeometric(1,1/2*(1+m),1/2*(3+m),-2*c*x^2/(b-_
+--  sqrt(b^2-4*a*c)))/((1+m)*(b-sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))-_
+--  2*c*x^(1+m)*hypergeometric(1,1/2*(1+m),1/2*(3+m),-2*c*x^2/(b+_
+--  sqrt(b^2-4*a*c)))/((1+m)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))
+--E 503
+
+--S 504 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 504
+
+)clear all
+
+--S 505 of 765
+t0:=x^5/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                5
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 505
+
+--S 506 of 765
+r0:=1/2*x^2/c-1/4*b*log(a+b*x^2+c*x^4)/c^2-1/2*(b^2-2*a*c)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                2
+--R                 2          2c x  + b
+--R       (4a c - 2b )atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                          +-----------+
+--R                   4      2            2  |          2
+--R       (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 765
+t0:=x^4/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 508
+
+--S 509 of 765
+r0:=x/c-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+_
+   (-b^2+2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R              +-----------+              | +-----------+
+--R              |          2            2  | |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R              +-----------+              |   +-----------+
+--R              |          2            2  |   |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R         +-+ |          2  +-+ |   |          2       | |          2
+--R       x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 765
+t0:=x^3/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 511
+
+--S 512 of 765
+r0:=1/4*log(a+b*x^2+c*x^4)/c+1/2*b*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                        2                               +-----------+
+--R                    2c x  + b             4      2      |          2
+--R        2b atanh(--------------) + log(c x  + b x  + a)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  -------------------------------------------------------------
+--R                                  +-----------+
+--R                                  |          2
+--R                               4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 513
+
+)clear all
+
+--S 514 of 765
+t0:=x^2/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 514
+
+--S 515 of 765
+r0:=-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(b-sqrt(b^2-4*a*c))/_
+   (sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*_
+   sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +--------------------+
+--R          |   +-----------+                   +-+ +-+
+--R          |   |          2                  x\|2 \|c
+--R       - \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                      |   |          2
+--R                                     \|- \|- 4a c + b   + b
+--R     + 
+--R        +------------------+
+--R        | +-----------+                  +-+ +-+
+--R        | |          2                 x\|2 \|c
+--R       \|\|- 4a c + b   + b atan(---------------------)
+--R                                  +------------------+
+--R                                  | +-----------+
+--R                                  | |          2
+--R                                 \|\|- 4a c + b   + b
+--R  /
+--R          +-----------+
+--R      +-+ |          2  +-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 765
+t0:=x/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 517
+
+--S 518 of 765
+r0:=-atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                       2
+--R                   2c x  + b
+--R          atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R   (2)  - ---------------------
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 519
+
+)clear all
+
+--S 520 of 765
+t0:=1/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 520
+
+--S 521 of 765
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/_
+   (sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                +------------------+
+--R                | +-----------+                   +-+ +-+
+--R        +-+ +-+ | |          2                  x\|2 \|c
+--R       \|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                          +--------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + b
+--R     + 
+--R                  +--------------------+
+--R                  |   +-----------+                  +-+ +-+
+--R          +-+ +-+ |   |          2                 x\|2 \|c
+--R       - \|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                              | |          2
+--R                                             \|\|- 4a c + b   + b
+--R  /
+--R                    +--------------------+ +------------------+
+--R      +-----------+ |   +-----------+      | +-----------+
+--R      |          2  |   |          2       | |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 765
+t0:=1/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 523
+
+--S 524 of 765
+r0:=log(x)/a-1/4*log(a+b*x^2+c*x^4)/a+1/2*b*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                   2                                             +-----------+
+--R               2c x  + b                4      2                 |          2
+--R   2b atanh(--------------) + (- log(c x  + b x  + a) + 4log(x))\|- 4a c + b
+--R             +-----------+
+--R             |          2
+--R            \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                    +-----------+
+--R                                    |          2
+--R                                 4a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 765
+t0:=1/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 526
+
+--S 527 of 765
+r0:=(-1)/(a*x)-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (1+b/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (1-b/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                       +------------------+
+--R              +-----------+            | +-----------+
+--R              |          2         +-+ | |          2
+--R         (- x\|- 4a c + b   - b x)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                       +--------------------+
+--R              +-----------+            |   +-----------+
+--R              |          2         +-+ |   |          2
+--R         (- x\|- 4a c + b   + b x)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R       - \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R         +-+ |          2  |   |          2       | |          2
+--R     a x\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 765
+t0:=1/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 529
+
+--S 530 of 765
+r0:=(-1/2)/(a*x^2)-b*log(x)/a^2+1/4*b*log(a+b*x^2+c*x^4)/a^2-1/2*(b^2-2*a*c)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                  2
+--R                 2  2         2c x  + b
+--R       (4a c - 2b )x atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R           2       4      2            2             |          2
+--R       (b x log(c x  + b x  + a) - 4b x log(x) - 2a)\|- 4a c + b
+--R  /
+--R           +-----------+
+--R       2 2 |          2
+--R     4a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 531
+
+)clear all
+
+--S 532 of 765
+t0:=1/(x^4*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           8      6      4
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 532
+
+--S 533 of 765
+r0:=(-1/3)/(a*x^3)+b/(a^2*x)+atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(a^2*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(a^2*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                      +------------------+
+--R                +-----------+                         | +-----------+
+--R              3 |          2                2  3  +-+ | |          2
+--R         (3b x \|- 4a c + b   + (- 6a c + 3b )x )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                    +--------------------+
+--R                +-----------+                       |   +-----------+
+--R              3 |          2              2  3  +-+ |   |          2
+--R         (3b x \|- 4a c + b   + (6a c - 3b )x )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                   +--------------------+ +------------------+
+--R                     +-----------+ |   +-----------+      | +-----------+
+--R          2      +-+ |          2  |   |          2       | |          2
+--R     (3b x  - a)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R       2 3 +-+ |          2  |   |          2       | |          2
+--R     3a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 534
+
+)clear all
+
+--S 535 of 765
+t0:=1/(x^5*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           9      7      5
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 535
+
+--S 536 of 765
+r0:=(-1/4)/(a*x^4)+1/2*b/(a^2*x^2)+(b^2-a*c)*log(x)/a^3-1/4*(b^2-a*c)*_
+   log(a+b*x^2+c*x^4)/a^3+1/2*b*(b^2-3*a*c)*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                      2
+--R                     3  4         2c x  + b
+--R       (- 6a b c + 2b )x atanh(--------------)
+--R                                +-----------+
+--R                                |          2
+--R                               \|- 4a c + b
+--R     + 
+--R                   2  4       4      2                    2  4               2
+--R           (a c - b )x log(c x  + b x  + a) + (- 4a c + 4b )x log(x) + 2a b x
+--R         + 
+--R              2
+--R           - a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       3 4 |          2
+--R     4a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 537
+
+)clear all
+
+--S 538 of 765
+t0:=x^4/(a-b*x^2+c*x^4)
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  - b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 538
+
+--S 539 of 765
+r0:=x/c-atanh(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+(-b^2+2*a*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atanh(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R              +-----------+              | +-----------+
+--R              |          2            2  | |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   + b
+--R      *
+--R                        +-+ +-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R                |   |          2
+--R               \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R              +-----------+              |   +-----------+
+--R              |          2            2  |   |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R                | |          2
+--R               \|\|- 4a c + b   + b
+--R     + 
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R         +-+ |          2  +-+ |   |          2       | |          2
+--R       x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 765
+t0:=x^3/(a-b*x^2+c*x^4)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  - b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 541
+
+--S 542 of 765
+r0:=1/4*log(a-b*x^2+c*x^4)/c+1/2*b*atanh((b-2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                          2                               +-----------+
+--R                      2c x  - b             4      2      |          2
+--R        - 2b atanh(--------------) + log(c x  - b x  + a)\|- 4a c + b
+--R                    +-----------+
+--R                    |          2
+--R                   \|- 4a c + b
+--R   (2)  ---------------------------------------------------------------
+--R                                   +-----------+
+--R                                   |          2
+--R                                4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 543
+
+)clear all
+
+--S 544 of 765
+t0:=x^2/(a-b*x^2+c*x^4)
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  - b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 544
+
+--S 545 of 765
+r0:=atanh(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(b-sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))-_
+   atanh(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(b+_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +--------------------+
+--R        |   +-----------+                    +-+ +-+
+--R        |   |          2                   x\|2 \|c
+--R       \|- \|- 4a c + b   + b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                     |   |          2
+--R                                    \|- \|- 4a c + b   + b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R       - \|\|- 4a c + b   + b atanh(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                     | |          2
+--R                                    \|\|- 4a c + b   + b
+--R  /
+--R          +-----------+
+--R      +-+ |          2  +-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 546
+
+)clear all
+
+--S 547 of 765
+t0:=x/(a-b*x^2+c*x^4)
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  - b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 547
+
+--S 548 of 765
+r0:=atanh((b-2*c*x^2)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                       2
+--R                   2c x  - b
+--R          atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R   (2)  - ---------------------
+--R               +-----------+
+--R               |          2
+--R              \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 549
+
+)clear all
+
+--S 550 of 765
+t0:=1/(a-b*x^2+c*x^4)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  - b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 550
+
+--S 551 of 765
+r0:=atanh(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/_
+   (sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-atanh(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                +------------------+
+--R                | +-----------+                    +-+ +-+
+--R        +-+ +-+ | |          2                   x\|2 \|c
+--R       \|2 \|c \|\|- 4a c + b   + b atanh(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                           |   |          2
+--R                                          \|- \|- 4a c + b   + b
+--R     + 
+--R                  +--------------------+
+--R                  |   +-----------+                   +-+ +-+
+--R          +-+ +-+ |   |          2                  x\|2 \|c
+--R       - \|2 \|c \|- \|- 4a c + b   + b atanh(---------------------)
+--R                                               +------------------+
+--R                                               | +-----------+
+--R                                               | |          2
+--R                                              \|\|- 4a c + b   + b
+--R  /
+--R                    +--------------------+ +------------------+
+--R      +-----------+ |   +-----------+      | +-----------+
+--R      |          2  |   |          2       | |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 765
+t0:=x^3/(a+b+2*a*x^2+a*x^4)
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  --------------------
+--R           4       2
+--R        a x  + 2a x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 553
+
+--S 554 of 765
+r0:=1/4*log(a+b+2*a*x^2+a*x^4)/a-1/2*atan((1+x^2)*sqrt(a)/sqrt(b))/_
+   (sqrt(a)*sqrt(b))
+--R 
+--R
+--R                    2      +-+
+--R                  (x  + 1)\|a            4       2          +-+ +-+
+--R        - 2a atan(------------) + log(a x  + 2a x  + b + a)\|a \|b
+--R                       +-+
+--R                      \|b
+--R   (2)  -----------------------------------------------------------
+--R                                    +-+ +-+
+--R                                 4a\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 765
+t0:=x^2/(a+b+2*a*x^2+a*x^4)
+--R 
+--R
+--R                  2
+--R                 x
+--R   (1)  --------------------
+--R           4       2
+--R        a x  + 2a x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 556
+
+--S 557 of 765
+r0:=1/2*atan((-a)^(1/4)*x/sqrt(sqrt(-a)-sqrt(b)))*sqrt(sqrt(-a)-sqrt(b))/_
+   ((-a)^(3/4)*sqrt(b))-1/2*atan((-a)^(1/4)*x/sqrt(sqrt(-a)+sqrt(b)))*_
+   sqrt(sqrt(-a)+sqrt(b))/((-a)^(3/4)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R        +---------------+            4+---+
+--R        |   +-+    +---+            x\|- a
+--R       \|- \|b  + \|- a  atan(------------------)
+--R                               +---------------+
+--R                               |   +-+    +---+
+--R                              \|- \|b  + \|- a
+--R     + 
+--R          +-------------+           4+---+
+--R          | +-+    +---+           x\|- a
+--R       - \|\|b  + \|- a  atan(----------------)
+--R                               +-------------+
+--R                               | +-+    +---+
+--R                              \|\|b  + \|- a
+--R  /
+--R      4+---+3 +-+
+--R     2\|- a  \|b
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 558
+
+)clear all
+
+--S 559 of 765
+t0:=x/(a+b+2*a*x^2+a*x^4)
+--R 
+--R
+--R                  x
+--R   (1)  --------------------
+--R           4       2
+--R        a x  + 2a x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 559
+
+--S 560 of 765
+r0:=1/2*atan((1+x^2)*sqrt(a)/sqrt(b))/(sqrt(a)*sqrt(b))
+--R 
+--R
+--R               2      +-+
+--R             (x  + 1)\|a
+--R        atan(------------)
+--R                  +-+
+--R                 \|b
+--R   (2)  ------------------
+--R               +-+ +-+
+--R             2\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 765
+t0:=1/(a+b+2*a*x^2+a*x^4)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           4       2
+--R        a x  + 2a x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 562
+
+--S 563 of 765
+r0:=-1/2*atan((-a)^(1/4)*x/sqrt(sqrt(-a)-sqrt(b)))/((-a)^(1/4)*sqrt(b)*_
+   sqrt(sqrt(-a)-sqrt(b)))+1/2*atan((-a)^(1/4)*x/sqrt(sqrt(-a)+sqrt(b)))/_
+   ((-a)^(1/4)*sqrt(b)*sqrt(sqrt(-a)+sqrt(b)))
+--R 
+--R
+--R   (2)
+--R          +-------------+            4+---+
+--R          | +-+    +---+            x\|- a
+--R       - \|\|b  + \|- a  atan(------------------)
+--R                               +---------------+
+--R                               |   +-+    +---+
+--R                              \|- \|b  + \|- a
+--R     + 
+--R        +---------------+           4+---+
+--R        |   +-+    +---+           x\|- a
+--R       \|- \|b  + \|- a  atan(----------------)
+--R                               +-------------+
+--R                               | +-+    +---+
+--R                              \|\|b  + \|- a
+--R  /
+--R                 +---------------+ +-------------+
+--R      4+---+ +-+ |   +-+    +---+  | +-+    +---+
+--R     2\|- a \|b \|- \|b  + \|- a  \|\|b  + \|- a
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 765
+t0:=1/(x*(a+b+2*a*x^2+a*x^4))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R           5       3
+--R        a x  + 2a x  + (b + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 565
+
+--S 566 of 765
+r0:=log(x)/(a+b)-1/4*log(a+b+2*a*x^2+a*x^4)/(a+b)-1/2*atan((1+x^2)*_
+   sqrt(a)/sqrt(b))*sqrt(a)/((a+b)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                 2      +-+
+--R       +-+     (x  + 1)\|a               4       2                     +-+
+--R   - 2\|a atan(------------) + (- log(a x  + 2a x  + b + a) + 4log(x))\|b
+--R                    +-+
+--R                   \|b
+--R   -----------------------------------------------------------------------
+--R                                          +-+
+--R                                (4b + 4a)\|b
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 567
+
+)clear all
+
+--S 568 of 765
+t0:=1/(x^2*(a+b+2*a*x^2+a*x^4))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           6       4           2
+--R        a x  + 2a x  + (b + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 568
+
+--S 569 of 765
+r0:=(-1)/((a+b)*x)-1/2*(-a)^(1/4)*atan((-a)^(1/4)*x/sqrt(sqrt(-a)-_
+   sqrt(b)))*(sqrt(-a)+sqrt(b))/((a+b)*sqrt(b)*sqrt(sqrt(-a)-sqrt(b)))-_
+   1/2*(-a)^(1/4)*atan((-a)^(1/4)*x/sqrt(sqrt(-a)+sqrt(b)))*_
+   (1-sqrt(-a)/sqrt(b))/((a+b)*sqrt(sqrt(-a)+sqrt(b)))
+--R 
+--R
+--R   (2)
+--R                                       +-------------+            4+---+
+--R           4+---+ +-+     +---+4+---+  | +-+    +---+            x\|- a
+--R       (- x\|- a \|b  - x\|- a \|- a )\|\|b  + \|- a  atan(------------------)
+--R                                                            +---------------+
+--R                                                            |   +-+    +---+
+--R                                                           \|- \|b  + \|- a
+--R     + 
+--R                                       +---------------+           4+---+
+--R           4+---+ +-+     +---+4+---+  |   +-+    +---+           x\|- a
+--R       (- x\|- a \|b  + x\|- a \|- a )\|- \|b  + \|- a  atan(----------------)
+--R                                                              +-------------+
+--R                                                              | +-+    +---+
+--R                                                             \|\|b  + \|- a
+--R     + 
+--R               +---------------+ +-------------+
+--R           +-+ |   +-+    +---+  | +-+    +---+
+--R       - 2\|b \|- \|b  + \|- a  \|\|b  + \|- a
+--R  /
+--R                    +---------------+ +-------------+
+--R                +-+ |   +-+    +---+  | +-+    +---+
+--R     (2b + 2a)x\|b \|- \|b  + \|- a  \|\|b  + \|- a
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 765
+t0:=1/(x^3*(a+b+2*a*x^2+a*x^4))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           7       5           3
+--R        a x  + 2a x  + (b + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 571
+
+--S 572 of 765
+r0:=(-1/2)/((a+b)*x^2)-2*a*log(x)/(a+b)^2+1/2*a*log(a+b+2*a*x^2+a*x^4)/_
+   (a+b)^2+1/2*(a-b)*atan((1+x^2)*sqrt(a)/sqrt(b))*sqrt(a)/((a+b)^2*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                             2      +-+
+--R                 2 +-+     (x  + 1)\|a
+--R       (- b + a)x \|a atan(------------)
+--R                                +-+
+--R                               \|b
+--R     + 
+--R           2       4       2                2                +-+
+--R       (a x log(a x  + 2a x  + b + a) - 4a x log(x) - b - a)\|b
+--R  /
+--R        2            2  2 +-+
+--R     (2b  + 4a b + 2a )x \|b
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+)clear all
+
+--S 574 of 765
+t0:=x^m/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               m
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 765
+--r0:=x^(1+m)*AppellF1(1/2*(1+m),2,2,1/2*(3+m),-2*c*x^2/(b+sqrt(b^2-4*a*c)),_
+--  -2*c*x^2/(b-sqrt(b^2-4*a*c)))*(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))^2*_
+--  (1+2*c*x^2/(b+sqrt(b^2-4*a*c)))^2/((1+m)*(a+b*x^2+c*x^4)^2)
+--E 575
+
+--S 576 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 576
+
+)clear all
+
+--S 577 of 765
+t0:=x^7/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               7
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 577
+
+--S 578 of 765
+r0:=-1/2*b*x^2/(c*(b^2-4*a*c))+1/2*x^4*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+_
+   c*x^4))+1/2*b*(b^2-6*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*_
+   (b^2-4*a*c)^(3/2))+1/4*log(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                  2     3   4         2      4  2      2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x  + 12a b c - 2a b )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 2    2   4              3  2     2       2        4      2
+--R           ((4a c  - b c)x  + (4a b c - b )x  + 4a c - a b )log(c x  + b x  + a)
+--R         + 
+--R                  2     2   4           2
+--R           (- 4a c  + 2b c)x  + 2a b c x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              4     2 3  4           3     3 2  2      2 3       2 2
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 579
+
+)clear all
+
+--S 580 of 765
+t0:=x^6/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               6
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 580
+
+--S 581 of 765
+r0:=-1/2*b*x/(c*(b^2-4*a*c))+1/2*x^3*(2*a+b*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b^2-6*a*c-b*(b^2-8*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*(b^2-6*a*c+b*(b^2-8*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*_
+   (b^2-4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                             +-----------+
+--R                 2    2   4              3  2     2       2  |          2
+--R           ((6a c  - b c)x  + (6a b c - b )x  + 6a c - a b )\|- 4a c + b
+--R         + 
+--R                    2    3   4          2     4  2     2         3
+--R           (- 8a b c  + b c)x  + (- 8a b c + b )x  - 8a b c + a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                                             +-----------+
+--R                 2    2   4              3  2     2       2  |          2
+--R           ((6a c  - b c)x  + (6a b c - b )x  + 6a c - a b )\|- 4a c + b
+--R         + 
+--R                  2    3   4        2     4  2     2         3
+--R           (8a b c  - b c)x  + (8a b c - b )x  + 8a b c - a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                         +--------------------+
+--R                                       +-----------+     |   +-----------+
+--R                     2  3          +-+ |          2  +-+ |   |          2
+--R         ((- 2a c + b )x  + a b x)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R             3     2 2  4          2     3   2     2 2       2   +-+
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|2
+--R    *
+--R                          +--------------------+ +------------------+
+--R        +-----------+     |   +-----------+      | +-----------+
+--R        |          2  +-+ |   |          2       | |          2
+--R       \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 765
+t0:=x^5/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               5
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 583
+
+--S 584 of 765
+r0:=1/2*x^2*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   2*a*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                               2
+--R                4         2     2          2c x  + b
+--R       (- 4a c x  - 4a b x  - 4a )atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                        +-----------+
+--R             4       2  |          2
+--R       (- b x  - 2a x )\|- 4a c + b
+--R  /
+--R                                                          +-----------+
+--R           2     2   4               3  2     2        2  |          2
+--R     ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 765
+t0:=x^4/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               4
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 586
+
+--S 587 of 765
+r0:=1/2*x*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+(-b^2-4*a*c)/sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^2+4*a*c+b*sqrt(b^2-_
+   4*a*c))/((b^2-4*a*c)^(3/2)*sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                   +-----------+
+--R                   4    2 2        |          2         2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (4a c  + b c)x
+--R         + 
+--R                      3  2     2       2
+--R           (4a b c + b )x  + 4a c + a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2           2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (- 4a c  - b c)x
+--R         + 
+--R                        3  2     2       2
+--R           (- 4a b c - b )x  - 4a c - a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                               +--------------------+
+--R                             +-----------+     |   +-----------+
+--R               3         +-+ |          2  +-+ |   |          2
+--R         (- b x  - 2a x)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                                                                +-----------+
+--R             2     2   4               3  2     2        2  +-+ |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2 \|- 4a c + b
+--R    *
+--R            +--------------------+ +------------------+
+--R            |   +-----------+      | +-----------+
+--R        +-+ |   |          2       | |          2
+--R       \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 588
+
+)clear all
+
+--S 589 of 765
+t0:=x^3/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               3
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 589
+
+--S 590 of 765
+r0:=1/2*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-b*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                        2                        +-----------+
+--R          4     2 2                 2c x  + b            2       |          2
+--R   (2b c x  + 2b x  + 2a b)atanh(--------------) + (- b x  - 2a)\|- 4a c + b
+--R                                  +-----------+
+--R                                  |          2
+--R                                 \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                                             +-----------+
+--R              2     2   4               3  2     2        2  |          2
+--R        ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 591
+
+)clear all
+
+--S 592 of 765
+t0:=x^2/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                               2
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 592
+
+--S 593 of 765
+r0:=-1/2*x*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(2*b-sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(2*b+sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                               +-----------+
+--R               4       2       |          2          4     2 2         +-+
+--R         ((2c x  + 2b x  + 2a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                               +-----------+
+--R               4       2       |          2          4     2 2         +-+
+--R         ((2c x  + 2b x  + 2a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                     +--------------------+ +------------------+
+--R                       +-----------+ |   +-----------+      | +-----------+
+--R          3        +-+ |          2  |   |          2       | |          2
+--R     (2c x  + b x)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                                +-----------+
+--R             2     2   4               3  2     2        2  +-+ |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2 \|- 4a c + b
+--R    *
+--R        +--------------------+ +------------------+
+--R        |   +-----------+      | +-----------+
+--R        |   |          2       | |          2
+--R       \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 594
+
+)clear all
+
+--S 595 of 765
+t0:=x/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                              x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 595
+
+--S 596 of 765
+r0:=1/2*(-b-2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+2*c*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                          2                      +-----------+
+--R        2 4         2                 2c x  + b           2      |          2
+--R   (- 4c x  - 4b c x  - 4a c)atanh(--------------) + (2c x  + b)\|- 4a c + b
+--R                                    +-----------+
+--R                                    |          2
+--R                                   \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                                             +-----------+
+--R              2     2   4               3  2     2        2  |          2
+--R        ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 597
+
+)clear all
+
+--S 598 of 765
+t0:=1/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 598
+
+--S 599 of 765
+r0:=1/2*x*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b+(b^2-_
+   12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (b+(-b^2+12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                   +-----------+
+--R                   4    2 2        |          2          2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (12a c  - b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c - b )x  + 12a c - a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2            2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (- 12a c  + b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c + b )x  - 12a c + a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                                       +-----------+ |   +-----------+
+--R                 3            2    +-+ |          2  |   |          2
+--R         (- b c x  + (2a c - b )x)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R           2 2       2   4      2          3  2     3      2 2  +-+
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)clear all
+
+--S 601 of 765
+t0:=1/(x*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R         2 9         7            2  5         3    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 601
+
+--S 602 of 765
+r0:=1/2*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*b*(b^2-_
+   6*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^(3/2))+_
+   log(x)/a^2-1/4*log(a+b*x^2+c*x^4)/a^2
+--R 
+--R
+--R   (2)
+--R                  2     3   4         2      4  2      2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x  + 12a b c - 2a b )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    2   4                3  2     2       2
+--R             ((- 4a c  + b c)x  + (- 4a b c + b )x  - 4a c + a b )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                  2     2   4                3  2      2        2
+--R           ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )log(x)
+--R         + 
+--R                     2     2        2
+--R           - 2a b c x  + 4a c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                 +-----------+
+--R          3 2     2 2   4       3        2 3  2      4      3 2  |          2
+--R     ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 603
+
+)clear all
+
+--S 604 of 765
+t0:=1/(x^2*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R         2 10         8            2  6         4    2 2
+--R        c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 604
+
+--S 605 of 765
+r0:=1/2*(-3*b^2+10*a*c)/(a^2*(b^2-4*a*c)*x)+1/2*(b^2-2*a*c+b*c*x^2)/_
+   (a*(b^2-4*a*c)*x*(a+b*x^2+c*x^4))-1/2*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2-10*a*c+b*(3*b^2-16*a*c)/_
+   sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2-_
+   10*a*c+(-3*b^3+16*a*b*c)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2     2   5                  3  3         2        2
+--R             ((- 10a c  + 3b c)x  + (- 10a b c + 3b )x  + (- 10a c + 3a b )x)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   5           2      4  3         2          3
+--R           (- 16a b c  + 3b c)x  + (- 16a b c + 3b )x  + (- 16a b c + 3a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2     2   5                  3  3         2        2
+--R             ((- 10a c  + 3b c)x  + (- 10a b c + 3b )x  + (- 10a c + 3a b )x)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   5         2      4  3       2          3
+--R           (16a b c  - 3b c)x  + (16a b c - 3b )x  + (16a b c - 3a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2     2   4                  3  2     2        2  +-+
+--R         ((- 10a c  + 3b c)x  + (- 11a b c + 3b )x  - 8a c + 2a b )\|2
+--R      *
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2  |   |          2       | |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R           3 2     2 2   5      3        2 3  3      4      3 2    +-+
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x)\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 606
+
+)clear all
+
+--S 607 of 765
+t0:=1/(x^3*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R         2 11         9            2  7         5    2 3
+--R        c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 607
+
+--S 608 of 765
+r0:=(-b^2+3*a*c)/(a^2*(b^2-4*a*c)*x^2)+1/2*(b^2-2*a*c+b*c*x^2)/_
+   (a*(b^2-4*a*c)*x^2*(a+b*x^2+c*x^4))-(b^4-6*a*b^2*c+6*a^2*c^2)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(3/2))-_
+   2*b*log(x)/a^3+1/2*b*log(a+b*x^2+c*x^4)/a^3
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   6       2   2        3      5  4
+--R           (12a c  - 12a b c  + 2b c)x  + (12a b c  - 12a b c + 2b )x
+--R         + 
+--R               3 2      2 2        4  2
+--R           (12a c  - 12a b c + 2a b )x
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    3   6        2     4  4      2         3  2
+--R             ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                           2     3   6           2      4  4
+--R                 (- 16a b c  + 4b c)x  + (- 16a b c + 4b )x
+--R               + 
+--R                       2          3  2
+--R                 (- 16a b c + 4a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R                2 2       2   4        2          3  2     3     2 2
+--R           (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x  - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                  +-----------+
+--R         4 2     3 2   6      4        3 3  4      5      4 2  2  |          2
+--R     ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 609
+
+)clear all
+
+--S 610 of 765
+t0:=1/(x^4*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                1
+--R   (1)  -------------------------------------------------
+--R         2 12         10            2  8         6    2 4
+--R        c x   + 2b c x   + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 610
+
+--S 611 of 765
+r0:=1/6*(-5*b^2+14*a*c)/(a^2*(b^2-4*a*c)*x^3)+1/2*b*(5*b^2-19*a*c)/_
+   (a^3*(b^2-4*a*c)*x)+1/2*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^3*_
+   (a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(5*b^3-19*a*b*c+(5*b^4-29*a*b^2*c+28*a^2*c^2)/sqrt(b^2-4*a*c))/_
+   (a^3*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(5*b^3-19*a*b*c+(-5*b^4+_
+   29*a*b^2*c-28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2      3   7         2       4  5       2           3  3
+--R             ((57a b c  - 15b c)x  + (57a b c - 15b )x  + (57a b c - 15a b )x )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 3        2 2      4   7         2   2        3       5  5
+--R           (- 84a c  + 87a b c  - 15b c)x  + (- 84a b c  + 87a b c - 15b )x
+--R         + 
+--R                 3 2      2 2         4  3
+--R           (- 84a c  + 87a b c - 15a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2      3   7         2       4  5       2           3  3
+--R             ((57a b c  - 15b c)x  + (57a b c - 15b )x  + (57a b c - 15a b )x )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 3        2 2      4   7       2   2        3       5  5
+--R           (84a c  - 87a b c  + 15b c)x  + (84a b c  - 87a b c + 15b )x
+--R         + 
+--R               3 2      2 2         4  3
+--R           (84a c  - 87a b c + 15a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2      3   6         2 2        2       4  4
+--R           (57a b c  - 15b c)x  + (- 14a c  + 62a b c - 15b )x
+--R         + 
+--R               2           3  2     3      2 2
+--R           (40a b c - 10a b )x  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            4 2     3 2   7       4        3 3  5       5      4 2  3  +-+
+--R       ((24a c  - 6a b c)x  + (24a b c - 6a b )x  + (24a c - 6a b )x )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 612
+
+)clear all
+
+--S 613 of 765
+t0:=x^m/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      m
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 765
+--r0:=x^(1+m)*AppellF1(1/2*(1+m),3,3,1/2*(3+m),-2*c*x^2/(b+sqrt(b^2-4*a*c)),_
+--  -2*c*x^2/(b-sqrt(b^2-4*a*c)))*(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))^3*_
+--  (1+2*c*x^2/(b+sqrt(b^2-4*a*c)))^3/((1+m)*(a+b*x^2+c*x^4)^3)
+--E 614
+
+--S 615 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 615
+
+)clear all
+
+--S 616 of 765
+t0:=x^11/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      11
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 616
+
+--S 617 of 765
+r0:=-1/2*b*(b^2-7*a*c)*x^2/(c^2*(b^2-4*a*c)^2)+1/4*(b^2-16*a*c)*x^4/(c*_
+   (b^2-4*a*c)^2)+1/4*x^8*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/4*x^6*(6*a*b-(b^2-16*a*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+_
+   1/2*b*(b^4-10*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c^3*(b^2-4*a*c)^(5/2))+1/4*log(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  8        2 2 3        4 2     6   6
+--R           (60a b c  - 20a b c  + 2b c )x  + (120a b c  - 40a b c  + 4b c)x
+--R         + 
+--R                3   3      2 3 2        5      7  4
+--R           (120a b c  + 20a b c  - 16a b c + 2b )x
+--R         + 
+--R                3 2 2      2 4        6  2      4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )x  + 60a b c  - 20a b c + 2a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2 4       2 3    4 2  8       2   3        3 2     5   6
+--R               (16a c  - 8a b c  + b c )x  + (32a b c  - 16a b c  + 2b c)x
+--R             + 
+--R                   3 3       4     6  4       3   2      2 3        5  2
+--R               (32a c  - 6a b c + b )x  + (32a b c  - 16a b c + 2a b )x
+--R             + 
+--R                  4 2     3 2     2 4
+--R               16a c  - 8a b c + a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                 2 4        2 3     4 2  8      2   3        3 2     5   6
+--R           (- 24a c  + 21a b c  - 3b c )x  + (2a b c  + 12a b c  - 2b c)x
+--R         + 
+--R                 3 3      2 2 2       4   4       3   2     2 3   2
+--R           (- 16a c  + 29a b c  - 4a b c)x  + (14a b c  - 2a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 7        2 6     4 5  8        2   6        3 5     5 4  6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R       + 
+--R              3 6        4 4     6 3  4        3   5      2 3 4       5 3  2
+--R         (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R       + 
+--R            4 5      3 2 4     2 4 3
+--R         64a c  - 32a b c  + 4a b c
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 618
+
+)clear all
+
+--S 619 of 765
+t0:=x^10/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      10
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 619
+
+--S 620 of 765
+r0:=-3/8*b*(b^2-8*a*c)*x/(c^2*(b^2-4*a*c)^2)+1/8*(b^2-28*a*c)*_
+   x^3/(c*(b^2-4*a*c)^2)+1/4*x^7*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+_
+   c*x^4)^2)+1/8*x^5*(12*a*b-(b^2-28*a*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+_
+   c*x^4))+3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b^4-_
+   9*a*b^2*c+28*a^2*c^2-b*(b^4-11*a*b^2*c+44*a^2*c^2)/sqrt(b^2-4*a*c))/_
+   (c^(5/2)*(b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+3/8*atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^4-9*a*b^2*c+28*a^2*c^2+_
+   b*(b^4-11*a*b^2*c+44*a^2*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*(b^2-4*a*c)^2*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (84a c  - 27a b c  + 3b c )x  + (168a b c  - 54a b c  + 6b c)x
+--R             + 
+--R                    3 3      2 2 2        4      6  4
+--R               (168a c  + 30a b c  - 21a b c + 3b )x
+--R             + 
+--R                    3   2      2 3        5  2      4 2      3 2      2 4
+--R               (168a b c  - 54a b c + 6a b )x  + 84a c  - 27a b c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2   4        3 3     5 2  8
+--R           (- 132a b c  + 33a b c  - 3b c )x
+--R         + 
+--R                  2 2 3        4 2     6   6
+--R           (- 264a b c  + 66a b c  - 6b c)x
+--R         + 
+--R                  3   3      2 3 2        5      7  4
+--R           (- 264a b c  - 66a b c  + 27a b c - 3b )x
+--R         + 
+--R                  3 2 2      2 4        6  2       4   2      3 3      2 5
+--R           (- 264a b c  + 66a b c - 6a b )x  - 132a b c  + 33a b c - 3a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (84a c  - 27a b c  + 3b c )x  + (168a b c  - 54a b c  + 6b c)x
+--R             + 
+--R                    3 3      2 2 2        4      6  4
+--R               (168a c  + 30a b c  - 21a b c + 3b )x
+--R             + 
+--R                    3   2      2 3        5  2      4 2      3 2      2 4
+--R               (168a b c  - 54a b c + 6a b )x  + 84a c  - 27a b c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2   4        3 3     5 2  8        2 2 3        4 2     6   6
+--R           (132a b c  - 33a b c  + 3b c )x  + (264a b c  - 66a b c  + 6b c)x
+--R         + 
+--R                3   3      2 3 2        5      7  4
+--R           (264a b c  + 66a b c  - 27a b c + 3b )x
+--R         + 
+--R                3 2 2      2 4        6  2       4   2      3 3      2 5
+--R           (264a b c  - 66a b c + 6a b )x  + 132a b c  - 33a b c + 3a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                 2 3        2 2     4   7      2   2        3      5  5
+--R           (- 44a c  + 37a b c  - 5b c)x  + (4a b c  + 20a b c - 3b )x
+--R         + 
+--R                 3 2      2 2        4  3       3        2 3
+--R           (- 28a c  + 49a b c - 6a b )x  + (24a b c - 3a b )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 6        2 5     4 4  8        2   5         3 4      5 3  6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R       + 
+--R              3 5        4 3     6 2  4        3   4       2 3 3        5 2  2
+--R         (256a c  - 48a b c  + 8b c )x  + (256a b c  - 128a b c  + 16a b c )x
+--R       + 
+--R             4 4      3 2 3     2 4 2
+--R         128a c  - 64a b c  + 8a b c
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 621
+
+)clear all
+
+--S 622 of 765
+t0:=x^9/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      9
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 622
+
+--S 623 of 765
+r0:=1/4*x^6*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-3/2*a*x^2*_
+   (2*a+b*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))-6*a^2*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R               2 2 8      2     6         3       2 2  4      3   2      4
+--R         (- 24a c x  - 48a b c x  + (- 48a c - 24a b )x  - 48a b x  - 24a )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                        3  8         2        2  6      2   4      3 2
+--R         ((- 10a b c + b )x  + (- 20a c - 4a b )x  - 18a b x  - 12a x )
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 624
+
+)clear all
+
+--S 625 of 765
+t0:=x^8/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      8
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 625
+
+--S 626 of 765
+r0:=-1/8*(b^2+20*a*c)*x/(c*(b^2-4*a*c)^2)+1/4*x^5*(2*a+b*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4)^2)+1/8*x^3*(12*a*b+(b^2+20*a*c)*x^2)/((b^2-4*a*c)^2*_
+   (a+b*x^2+c*x^4))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b^3-16*a*b*c+(-b^4+18*a*b^2*c+40*a^2*c^2)/sqrt(b^2-4*a*c))/(c^(3/2)*_
+   (b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/8*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^3-16*a*b*c+(b^4-18*a*b^2*c-_
+   40*a^2*c^2)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)^2*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                         3    3 2  8           2 2     4   6
+--R               (- 16a b c  + b c )x  + (- 32a b c  + 2b c)x
+--R             + 
+--R                     2   2        3     5  4         2 2        4  2      3
+--R               (- 32a b c  - 14a b c + b )x  + (- 32a b c + 2a b )x  - 16a b c
+--R             + 
+--R                2 3
+--R               a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 4        2 3    4 2  8       2   3        3 2     5   6
+--R           (40a c  + 18a b c  - b c )x  + (80a b c  + 36a b c  - 2b c)x
+--R         + 
+--R               3 3      2 2 2        4     6  4       3   2      2 3        5  2
+--R           (80a c  + 76a b c  + 16a b c - b )x  + (80a b c  + 36a b c - 2a b )x
+--R         + 
+--R              4 2      3 2     2 4
+--R           40a c  + 18a b c - a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                         3    3 2  8           2 2     4   6
+--R               (- 16a b c  + b c )x  + (- 32a b c  + 2b c)x
+--R             + 
+--R                     2   2        3     5  4         2 2        4  2      3
+--R               (- 32a b c  - 14a b c + b )x  + (- 32a b c + 2a b )x  - 16a b c
+--R             + 
+--R                2 3
+--R               a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 4        2 3    4 2  8         2   3        3 2     5   6
+--R           (- 40a c  - 18a b c  + b c )x  + (- 80a b c  - 36a b c  + 2b c)x
+--R         + 
+--R                 3 3      2 2 2        4     6  4
+--R           (- 80a c  - 76a b c  - 16a b c + b )x
+--R         + 
+--R                 3   2      2 3        5  2      4 2      3 2     2 4
+--R           (- 80a b c  - 36a b c + 2a b )x  - 40a c  - 18a b c + a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                     2    3   7         2 2       2     4  5
+--R           (- 16a b c  + b c)x  + (- 36a c  - 5a b c - b )x
+--R         + 
+--R                 2          3  3         3     2 2
+--R           (- 28a b c - 2a b )x  + (- 20a c - a b )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 5        2 4     4 3  8        2   4         3 3      5 2  6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R       + 
+--R              3 4        4 2     6   4        3   3       2 3 2        5   2
+--R         (256a c  - 48a b c  + 8b c)x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R             4 3      3 2 2     2 4
+--R         128a c  - 64a b c  + 8a b c
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 627
+
+)clear all
+
+--S 628 of 765
+t0:=x^7/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      7
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 628
+
+--S 629 of 765
+r0:=-1/4*x^6*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+3/4*b*x^2*_
+   (2*a+b*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+3*a*b*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                 2 8        2   6       2           3  4      2 2 2      3
+--R         (12a b c x  + 24a b c x  + (24a b c + 12a b )x  + 24a b x  + 12a b)
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                                 +-----------+
+--R             2    2   8                3  6       2 4     2   2  |          2
+--R       ((8a c  + b c)x  + (10a b c + 2b )x  + 9a b x  + 6a b x )\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 630
+
+)clear all
+
+--S 631 of 765
+t0:=x^6/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      6
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 631
+
+--S 632 of 765
+r0:=1/4*x^3*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+3/8*x*(4*a*b+_
+   (b^2+4*a*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+3/8*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b^2+4*a*c-b*(b^2+12*a*c)/sqrt(b^2-_
+   4*a*c))/((b^2-4*a*c)^2*sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^2+4*a*c+_
+   b*(b^2+12*a*c)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^2*sqrt(2)*sqrt(c)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     3     2 2  8           2     3   6
+--R               (12a c  + 3b c )x  + (24a b c  + 6b c)x
+--R             + 
+--R                   2 2        2      4  4       2          3  2      3      2 2
+--R               (24a c  + 18a b c + 3b )x  + (24a b c + 6a b )x  + 12a c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     3     3 2  8           2 2     4   6
+--R           (- 36a b c  - 3b c )x  + (- 72a b c  - 6b c)x
+--R         + 
+--R                 2   2        3      5  4         2 2        4  2      3
+--R           (- 72a b c  - 42a b c - 3b )x  + (- 72a b c - 6a b )x  - 36a b c
+--R         + 
+--R               2 3
+--R           - 3a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                     3     2 2  8           2     3   6
+--R               (12a c  + 3b c )x  + (24a b c  + 6b c)x
+--R             + 
+--R                   2 2        2      4  4       2          3  2      3      2 2
+--R               (24a c  + 18a b c + 3b )x  + (24a b c + 6a b )x  + 12a c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3     3 2  8         2 2     4   6
+--R           (36a b c  + 3b c )x  + (72a b c  + 6b c)x
+--R         + 
+--R               2   2        3      5  4       2 2        4  2      3        2 3
+--R           (72a b c  + 42a b c + 3b )x  + (72a b c + 6a b )x  + 36a b c + 3a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                2     2   7                3  5        2         2  3      2
+--R         ((12a c  + 3b c)x  + (16a b c + 5b )x  + (- 4a c + 19a b )x  + 12a b x)
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 4        2 3     4 2  8        2   3         3 2      5   6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R       + 
+--R              3 3        4      6  4        3   2       2 3         5  2
+--R         (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             4 2      3 2      2 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 633
+
+)clear all
+
+--S 634 of 765
+t0:=x^5/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      5
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 634
+
+--S 635 of 765
+r0:=1/4*x^6*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-_
+   1/4*(b^2+2*a*c)*x^2*(2*a+b*x^2)/(a*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))-_
+   (b^2+2*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                  3     2 2  8             2     3   6
+--R           (- 8a c  - 4b c )x  + (- 16a b c  - 8b c)x
+--R         + 
+--R                 2 2        2      4  4         2          3  2     3      2 2
+--R           (- 16a c  - 16a b c - 4b )x  + (- 16a b c - 8a b )x  - 8a c - 4a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2 8        2      2   6                 3  4
+--R             - 6b c x  + (4a c  - 10b c)x  + (- 6a b c - 3b )x
+--R           + 
+--R                  2        2  2
+--R             (- 4a c - 2a b )x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 636
+
+)clear all
+
+--S 637 of 765
+t0:=x^4/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      4
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 637
+
+--S 638 of 765
+r0:=1/4*x*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-1/8*x*(7*b^2-4*a*c+_
+   12*b*c*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+3/4*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2+4*a*c-2*b*sqrt(b^2-_
+   4*a*c))/((b^2-4*a*c)^(5/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   3/4*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2+_
+   4*a*c+2*b*sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     2 8      2   6                   3  4        2 2      2
+--R             (- 12b c x  - 24b c x  + (- 24a b c - 12b )x  - 24a b x  - 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8           2      3   6
+--R           (24a c  + 18b c )x  + (48a b c  + 36b c)x
+--R         + 
+--R               2 2        2       4  4       2           3  2      3       2 2
+--R           (48a c  + 60a b c + 18b )x  + (48a b c + 36a b )x  + 24a c + 18a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     2 8      2   6                   3  4        2 2      2
+--R             (- 12b c x  - 24b c x  + (- 24a b c - 12b )x  - 24a b x  - 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8             2      3   6
+--R           (- 24a c  - 18b c )x  + (- 48a b c  - 36b c)x
+--R         + 
+--R               2 2        2       4  4         2           3  2      3       2 2
+--R         (- 48a c  - 60a b c - 18b )x  + (- 48a b c - 36a b )x  - 24a c - 18a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 7        2      2   5                  3  3
+--R           - 12b c x  + (4a c  - 19b c)x  + (- 16a b c - 5b )x
+--R         + 
+--R                 2        2
+--R           (- 12a c - 3a b )x
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 4        2 3     4 2  8        2   3         3 2      5   6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R       + 
+--R              3 3        4      6  4        3   2       2 3         5  2
+--R         (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             4 2      3 2      2 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 639
+
+)clear all
+
+--S 640 of 765
+t0:=x^3/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 640
+
+--S 641 of 765
+r0:=1/4*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-3/4*b*(b+2*c*x^2)/_
+   ((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+3*b*c*atanh((b+2*c*x^2)/sqrt(b^2-_
+   4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R               3 8      2 2 6           2      3   4        2   2      2
+--R         (12b c x  + 24b c x  + (24a b c  + 12b c)x  + 24a b c x  + 12a b c)
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                                 +-----------+
+--R              2 6     2   4                  3  2     2       2  |          2
+--R       (- 6b c x  - 9b c x  + (- 10a b c - 2b )x  - 8a c - a b )\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 642
+
+)clear all
+
+--S 643 of 765
+t0:=x^2/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      2
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 643
+
+--S 644 of 765
+r0:=-1/4*x*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+1/8*x*(b*(b^2+8*a*c)+_
+   c*(b^2+20*a*c)*x^2)/(a*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))+1/8*atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b^2+20*a*c+b*(b^2-_
+   52*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (b^2+20*a*c-b*(b^2-52*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     3    2 2  8           2     3   6
+--R               (20a c  + b c )x  + (40a b c  + 2b c)x
+--R             + 
+--R                   2 2        2     4  4       2          3  2      3     2 2
+--R               (40a c  + 22a b c + b )x  + (40a b c + 2a b )x  + 20a c + a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     3    3 2  8            2 2     4   6
+--R           (- 52a b c  + b c )x  + (- 104a b c  + 2b c)x
+--R         + 
+--R                  2   2        3     5  4          2 2        4  2      3
+--R           (- 104a b c  - 50a b c + b )x  + (- 104a b c + 2a b )x  - 52a b c
+--R         + 
+--R            2 3
+--R           a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     3    2 2  8           2     3   6
+--R               (20a c  + b c )x  + (40a b c  + 2b c)x
+--R             + 
+--R                   2 2        2     4  4       2          3  2      3     2 2
+--R               (40a c  + 22a b c + b )x  + (40a b c + 2a b )x  + 20a c + a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3    3 2  8          2 2     4   6
+--R           (52a b c  - b c )x  + (104a b c  - 2b c)x
+--R         + 
+--R                2   2        3     5  4        2 2        4  2      3       2 3
+--R           (104a b c  + 50a b c - b )x  + (104a b c - 2a b )x  + 52a b c - a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 3    2 2  7           2     3   5       2 2       2     4  3
+--R           (20a c  + b c )x  + (28a b c  + 2b c)x  + (36a c  + 5a b c + b )x
+--R         + 
+--R               2         3
+--R           (16a b c - a b )x
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              3 4      2 2 3       4 2  8        3   3       2 3 2        5   6
+--R         (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R              4 3      2 4        6  4        4   2       3 3       2 5  2
+--R         (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             5 2      4 2      3 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 644
+
+--S 645 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 645
+
+)clear all
+
+--S 646 of 765
+t0:=x/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R     x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 646
+
+--S 647 of 765
+r0:=1/4*(-b-2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+3/2*c*(b+2*c*x^2)/_
+   ((b^2-4*a*c)^2*(a+b*x^2+c*x^4))-6*c^2*atanh((b+2*c*x^2)/sqrt(b^2-_
+   4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R               4 8        3 6           3      2 2  4          2 2      2 2
+--R         (- 24c x  - 48b c x  + (- 48a c  - 24b c )x  - 48a b c x  - 24a c )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                              +-----------+
+--R           3 6        2 4         2     2   2              3  |          2
+--R       (12c x  + 18b c x  + (20a c  + 4b c)x  + 10a b c - b )\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 648
+
+)clear all
+
+--S 649 of 765
+t0:=1/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 649
+
+--S 650 of 765
+r0:=1/4*x*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/8*x*((b^2-7*a*c)*(3*b^2-4*a*c)+3*b*c*(b^2-8*a*c)*x^2)/(a^2*(b^2-_
+   4*a*c)^2*(a+b*x^2+c*x^4))+3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(b^3-8*a*b*c+(b^4-10*a*b^2*c+56*a^2*c^2)/_
+   sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b^3-_
+   8*a*b*c+(-b^4+10*a*b^2*c-56*a^2*c^2)/sqrt(b^2-4*a*c))/(a^2*(b^2-_
+   4*a*c)^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )x  + (- 48a b c  + 6b c)x
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )x  + (- 48a b c + 6a b )x  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (168a c  - 30a b c  + 3b c )x  + (336a b c  - 60a b c  + 6b c)x
+--R         + 
+--R                3 3       2 2 2        4      6  4
+--R           (336a c  + 108a b c  - 24a b c + 3b )x
+--R         + 
+--R                3   2      2 3        5  2       4 2      3 2      2 4
+--R           (336a b c  - 60a b c + 6a b )x  + 168a c  - 30a b c + 3a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )x  + (- 48a b c  + 6b c)x
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )x  + (- 48a b c + 6a b )x  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 168a c  + 30a b c  - 3b c )x  + (- 336a b c  + 60a b c  - 6b c)x
+--R         + 
+--R                  3 3       2 2 2        4      6  4
+--R           (- 336a c  - 108a b c  + 24a b c - 3b )x
+--R         + 
+--R                  3   2      2 3        5  2       4 2      3 2      2 4
+--R           (- 336a b c  + 60a b c - 6a b )x  - 168a c  + 30a b c - 3a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                     3     3 2  7       2 3        2 2     4   5
+--R           (- 24a b c  + 3b c )x  + (28a c  - 49a b c  + 6b c)x
+--R         + 
+--R                2   2        3      5  3       3 2      2 2        4
+--R           (- 4a b c  - 20a b c + 3b )x  + (44a c  - 37a b c + 5a b )x
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              4 4      3 2 3     2 4 2  8        4   3       3 3 2      2 5   6
+--R         (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R              5 3      3 4      2 6  4        5   2       4 3       3 5  2
+--R         (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             6 2      5 2      4 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 651
+
+)clear all
+
+--S 652 of 765
+t0:=1/(x*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 13       2 11        2     2   9              3  7      2        2  5
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   3    3
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 652
+
+--S 653 of 765
+r0:=1/4*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/4*(2*b^4-15*a*b^2*c+16*a^2*c^2+2*b*c*(b^2-7*a*c)*x^2)/(a^2*(b^2-_
+   4*a*c)^2*(a+b*x^2+c*x^4))+1/2*b*(b^4-10*a*b^2*c+30*a^2*c^2)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(5/2))+_
+   log(x)/a^3-1/4*log(a+b*x^2+c*x^4)/a^3
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  8        2 2 3        4 2     6   6
+--R           (60a b c  - 20a b c  + 2b c )x  + (120a b c  - 40a b c  + 4b c)x
+--R         + 
+--R                3   3      2 3 2        5      7  4
+--R           (120a b c  + 20a b c  - 16a b c + 2b )x
+--R         + 
+--R                3 2 2      2 4        6  2      4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )x  + 60a b c  - 20a b c + 2a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2 4       2 3    4 2  8         2   3        3 2     5   6
+--R               (- 16a c  + 8a b c  - b c )x  + (- 32a b c  + 16a b c  - 2b c)x
+--R             + 
+--R                     3 3       4     6  4         3   2      2 3        5  2
+--R               (- 32a c  + 6a b c - b )x  + (- 32a b c  + 16a b c - 2a b )x
+--R             + 
+--R                    4 2     3 2     2 4
+--R               - 16a c  + 8a b c - a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             log(x)
+--R         + 
+--R                 2   3       3 2  6       3 3      2 2 2       4   4
+--R           (- 14a b c  + 2a b c )x  + (16a c  - 29a b c  + 4a b c)x
+--R         + 
+--R                3   2      2 3        5  2      4 2      3 2      2 4
+--R           (- 2a b c  - 12a b c + 2a b )x  + 24a c  - 21a b c + 3a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R         (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R       + 
+--R              6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R         (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R       + 
+--R            7 2      6 2      5 4
+--R         64a c  - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 653
+
+--S 654 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 654
+
+)clear all
+
+--S 655 of 765
+t0:=1/(x^2*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 14       2 12        2     2   10              3  8      2        2  6
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   4    3 2
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 655
+
+--S 656 of 765
+r0:=-3/8*(5*b^2-12*a*c)*(b^2-5*a*c)/(a^3*(b^2-4*a*c)^2*x)+_
+   1/4*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x*(a+b*x^2+c*x^4)^2)+_
+   1/8*(5*b^4-35*a*b^2*c+36*a^2*c^2+b*c*(5*b^2-32*a*c)*x^2)/(a^2*_
+   (b^2-4*a*c)^2*x*(a+b*x^2+c*x^4))-3/8*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*((5*b^2-12*a*c)*(b^2-5*a*c)+_
+   b*(5*b^4-47*a*b^2*c+124*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^2*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-3/8*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*((5*b^2-12*a*c)*(b^2-5*a*c)+_
+   (-5*b^5+47*a*b^3*c-124*a^2*b*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^2*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )x
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)x
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )x
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )x
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2   4         3 3      5 2  9
+--R           (- 372a b c  + 141a b c  - 15b c )x
+--R         + 
+--R                  2 2 3         4 2      6   7
+--R           (- 744a b c  + 282a b c  - 30b c)x
+--R         + 
+--R                  3   3      2 3 2         5       7  5
+--R           (- 744a b c  - 90a b c  + 111a b c - 15b )x
+--R         + 
+--R                  3 2 2       2 4         6  3
+--R           (- 744a b c  + 282a b c - 30a b )x
+--R         + 
+--R                  4   2       3 3       2 5
+--R           (- 372a b c  + 141a b c - 15a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )x
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)x
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )x
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )x
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2   4         3 3      5 2  9
+--R           (372a b c  - 141a b c  + 15b c )x
+--R         + 
+--R                2 2 3         4 2      6   7
+--R           (744a b c  - 282a b c  + 30b c)x
+--R         + 
+--R                3   3      2 3 2         5       7  5
+--R           (744a b c  + 90a b c  - 111a b c + 15b )x
+--R         + 
+--R                3 2 2       2 4         6  3        4   2       3 3       2 5
+--R           (744a b c  - 282a b c + 30a b )x  + (372a b c  - 141a b c + 15a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 4         2 3      4 2  8
+--R           (- 180a c  + 111a b c  - 15b c )x
+--R         + 
+--R                  2   3         3 2      5   6
+--R           (- 392a b c  + 227a b c  - 30b c)x
+--R         + 
+--R                  3 3      2 2 2        4       6  4
+--R           (- 324a c  - 25a b c  + 91a b c - 15b )x
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 364a b c  + 194a b c - 25a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              5 4      4 2 3     3 4 2  9        5   3       4 3 2      3 5   7
+--R         (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R              6 3      4 4      3 6  5        6   2       5 3       4 5  3
+--R         (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R              7 2      6 2      5 4
+--R         (128a c  - 64a b c + 8a b )x
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 657
+
+)clear all
+
+--S 658 of 765
+t0:=1/(x^3*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 15       2 13        2     2   11              3  9      2        2  7
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   5    3 3
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 658
+
+--S 659 of 765
+r0:=-3/2*(b^4-7*a*b^2*c+10*a^2*c^2)/(a^3*(b^2-4*a*c)^2*x^2)+_
+   1/4*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^2*(a+b*x^2+c*x^4)^2)+_
+   1/4*(3*b^4-20*a*b^2*c+20*a^2*c^2+3*b*c*(b^2-6*a*c)*x^2)/(a^2*(b^2-_
+   4*a*c)^2*x^2*(a+b*x^2+c*x^4))-3/2*(b^6-10*a*b^4*c+30*a^2*b^2*c^2-_
+   20*a^3*c^3)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(5/2))-_
+   3*b*log(x)/a^4+3/4*b*log(a+b*x^2+c*x^4)/a^4
+--R 
+--R
+--R   (2)
+--R                3 5       2 2 4        4 3     6 2  10
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )x
+--R         + 
+--R                3   4       2 3 3         5 2      7   8
+--R           (240a b c  - 360a b c  + 120a b c  - 12b c)x
+--R         + 
+--R                4 4       3 2 3      2 4 2        6      8  6
+--R           (240a c  - 240a b c  - 60a b c  + 48a b c - 6b )x
+--R         + 
+--R                4   3       3 3 2       2 5         7  4
+--R           (240a b c  - 360a b c  + 120a b c - 12a b )x
+--R         + 
+--R                5 3       4 2 2      3 4      2 6  2
+--R           (120a c  - 180a b c  + 60a b c - 6a b )x
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2   4        3 3     5 2  10       2 2 3        4 2     6   8
+--R               (48a b c  - 24a b c  + 3b c )x   + (96a b c  - 48a b c  + 6b c)x
+--R             + 
+--R                   3   3        5      7  6       3 2 2      2 4        6  4
+--R               (96a b c  - 18a b c + 3b )x  + (96a b c  - 48a b c + 6a b )x
+--R             + 
+--R                   4   2      3 3      2 5  2
+--R               (48a b c  - 24a b c + 3a b )x
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                      2   4        3 3      5 2  10
+--R               (- 192a b c  + 96a b c  - 12b c )x
+--R             + 
+--R                      2 2 3         4 2      6   8
+--R               (- 384a b c  + 192a b c  - 24b c)x
+--R             + 
+--R                      3   3        5       7  6
+--R               (- 384a b c  + 72a b c - 12b )x
+--R             + 
+--R                      3 2 2       2 4         6  4
+--R               (- 384a b c  + 192a b c - 24a b )x
+--R             + 
+--R                      4   2      3 3       2 5  2
+--R               (- 192a b c  + 96a b c - 12a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R                 3 4      2 2 3       4 2  8
+--R           (- 60a c  + 42a b c  - 6a b c )x
+--R         + 
+--R                  3   3      2 3 2        5   6
+--R           (- 138a b c  + 87a b c  - 12a b c)x
+--R         + 
+--R                  4 3      3 2 2      2 4        6  4
+--R           (- 100a c  - 14a b c  + 36a b c - 6a b )x
+--R         + 
+--R                  4   2      3 3      2 5  2      5 2      4 2      3 4
+--R           (- 122a b c  + 68a b c - 9a b )x  - 32a c  + 16a b c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             6 4      5 2 3     4 4 2  10        6   3      5 3 2     4 5   8
+--R         (64a c  - 32a b c  + 4a b c )x   + (128a b c  - 64a b c  + 8a b c)x
+--R       + 
+--R              7 3      5 4      4 6  6        7   2      6 3      5 5  4
+--R         (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R       + 
+--R             8 2      7 2      6 4  2
+--R         (64a c  - 32a b c + 4a b )x
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 659
+
+--S 660 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 660
+
+)clear all
+
+--S 661 of 765
+t0:=1/(x^4*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 16       2 14        2     2   12              3  10
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x
+--R     + 
+--R          2        2  8     2   6    3 4
+--R       (3a c + 3a b )x  + 3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 661
+
+--S 662 of 765
+r0:=1/24*(-35*b^4+235*a*b^2*c-308*a^2*c^2)/(a^3*(b^2-4*a*c)^2*x^3)+_
+   1/8*b*(35*b^4-270*a*b^2*c+508*a^2*c^2)/(a^4*(b^2-4*a*c)^2*x)+_
+   1/4*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^3*(a+b*x^2+c*x^4)^2)+_
+   1/8*(7*b^4-45*a*b^2*c+44*a^2*c^2+b*c*(7*b^2-40*a*c)*x^2)/(a^2*(b^2-_
+   4*a*c)^2*x^3*(a+b*x^2+c*x^4))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(35*b^5-270*a*b^3*c+508*a^2*b*c^2+(35*b^6-_
+   340*a*b^4*c+978*a^2*b^2*c^2-616*a^3*c^3)/sqrt(b^2-4*a*c))/(a^4*_
+   (b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/8*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(35*b^5-270*a*b^3*c+_
+   508*a^2*b*c^2+(-35*b^6+340*a*b^4*c-978*a^2*b^2*c^2+616*a^3*c^3)/_
+   sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )x
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)x
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )x
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )x
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3 5        2 2 4          4 3       6 2  11
+--R           (- 1848a c  + 2934a b c  - 1020a b c  + 105b c )x
+--R         + 
+--R                   3   4        2 3 3          5 2       7   9
+--R           (- 3696a b c  + 5868a b c  - 2040a b c  + 210b c)x
+--R         + 
+--R                   4 4        3 2 3       2 4 2         6        8  7
+--R           (- 3696a c  + 4020a b c  + 894a b c  - 810a b c + 105b )x
+--R         + 
+--R                   4   3        3 3 2        2 5          7  5
+--R           (- 3696a b c  + 5868a b c  - 2040a b c + 210a b )x
+--R         + 
+--R                   5 3        4 2 2        3 4        2 6  3
+--R           (- 1848a c  + 2934a b c  - 1020a b c + 105a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )x
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)x
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )x
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )x
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3 5        2 2 4          4 3       6 2  11
+--R           (1848a c  - 2934a b c  + 1020a b c  - 105b c )x
+--R         + 
+--R                 3   4        2 3 3          5 2       7   9
+--R           (3696a b c  - 5868a b c  + 2040a b c  - 210b c)x
+--R         + 
+--R                 4 4        3 2 3       2 4 2         6        8  7
+--R           (3696a c  - 4020a b c  - 894a b c  + 810a b c - 105b )x
+--R         + 
+--R                 4   3        3 3 2        2 5          7  5
+--R           (3696a b c  - 5868a b c  + 2040a b c - 210a b )x
+--R         + 
+--R                 5 3        4 2 2        3 4        2 6  3
+--R           (1848a c  - 2934a b c  + 1020a b c - 105a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 2   4         3 3       5 2  10
+--R           (1524a b c  - 810a b c  + 105b c )x
+--R         + 
+--R                  3 4        2 2 3          4 2       6   8
+--R           (- 308a c  + 3283a b c  - 1655a b c  + 210b c)x
+--R         + 
+--R                 3   3       2 3 2         5        7  6
+--R           (2312a b c  + 395a b c  - 670a b c + 105b )x
+--R         + 
+--R                  4 3        3 2 2        2 4          6  4
+--R           (- 484a c  + 2955a b c  - 1413a b c + 175a b )x
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (896a b c  - 448a b c + 56a b )x  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              6 4       5 2 3      4 4 2  11
+--R         (384a c  - 192a b c  + 24a b c )x
+--R       + 
+--R              6   3       5 3 2      4 5   9        7 3       5 4       4 6  7
+--R         (768a b c  - 384a b c  + 48a b c)x  + (768a c  - 144a b c + 24a b )x
+--R       + 
+--R              7   2       6 3       5 5  5        8 2       7 2       6 4  3
+--R         (768a b c  - 384a b c + 48a b )x  + (384a c  - 192a b c + 24a b )x
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 663
+
+)clear all
+
+--S 664 of 765
+t0:=1/(a^2+b+2*a*x^2+x^4)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         4       2        2
+--R        x  + 2a x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 664
+
+--S 665 of 765
+r0:=1/2*atan(x/sqrt(a-sqrt(-b)))/(sqrt(-b)*sqrt(a-sqrt(-b)))-_
+   1/2*atan(x/sqrt(a+sqrt(-b)))/(sqrt(-b)*sqrt(a+sqrt(-b)))
+--R 
+--R
+--R   (2)
+--R    +----------+                         +------------+
+--R    | +---+                 x            |   +---+                x
+--R   \|\|- b  + a atan(---------------) - \|- \|- b  + a atan(-------------)
+--R                      +------------+                         +----------+
+--R                      |   +---+                              | +---+
+--R                     \|- \|- b  + a                         \|\|- b  + a
+--R   -----------------------------------------------------------------------
+--R                             +------------+ +----------+
+--R                       +---+ |   +---+      | +---+
+--R                     2\|- b \|- \|- b  + a \|\|- b  + a
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 666
+
+)clear all
+
+--S 667 of 765
+t0:=1/(-1+a^2+2*a*x^2+x^4)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         4       2    2
+--R        x  + 2a x  + a  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 667
+
+--S 668 of 765
+r0:=-1/2*atanh(x/sqrt(1-a))/sqrt(1-a)-1/2*atan(x/sqrt(1+a))/sqrt(1+a)
+--R 
+--R
+--R           +-----+           x         +-------+         x
+--R        - \|a + 1 atanh(----------) - \|- a + 1 atan(--------)
+--R                         +-------+                    +-----+
+--R                        \|- a + 1                    \|a + 1
+--R   (2)  ------------------------------------------------------
+--R                            +-------+ +-----+
+--R                          2\|- a + 1 \|a + 1
+--R                                                    Type: Expression(Integer)
+--E 668
+
+--S 669 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 669
+
+)clear all
+
+--S 670 of 765
+t0:=1/(1+a^2+2*a*x^2+x^4)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         4       2    2
+--R        x  + 2a x  + a  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 670
+
+--S 671 of 765
+r0:=-1/2*atan((x*sqrt(2)+sqrt(-a-sqrt(1+a^2)))/sqrt(a-sqrt(1+a^2)))/_
+   (sqrt(2)*sqrt(1+a^2)*sqrt(a-sqrt(1+a^2)))+1/2*atan((-2*x+sqrt(2)*_
+   sqrt(-a-sqrt(1+a^2)))/(sqrt(2)*sqrt(a-sqrt(1+a^2))))/(sqrt(2)*_
+   sqrt(1+a^2)*sqrt(a-sqrt(1+a^2)))-1/2*atan((-x*sqrt(2)+sqrt(-a+_
+   sqrt(1+a^2)))/sqrt(a+sqrt(1+a^2)))/(sqrt(2)*sqrt(1+a^2)*sqrt(a+_
+   sqrt(1+a^2)))+1/2*atan((x*sqrt(2)+sqrt(-a+sqrt(1+a^2)))/sqrt(a+_
+   sqrt(1+a^2)))/(sqrt(2)*sqrt(1+a^2)*sqrt(a+sqrt(1+a^2)))
+--R 
+--R
+--R   (2)
+--R                               +---------------+
+--R          +-------------+      |   +------+
+--R          | +------+           |   | 2               +-+
+--R          | | 2               \|- \|a  + 1  - a  + x\|2
+--R       - \|\|a  + 1  + a atan(--------------------------)
+--R                                   +---------------+
+--R                                   |   +------+
+--R                                   |   | 2
+--R                                  \|- \|a  + 1  + a
+--R     + 
+--R                                 +---------------+
+--R        +-------------+          |   +------+
+--R        | +------+           +-+ |   | 2
+--R        | | 2               \|2 \|- \|a  + 1  - a  - 2x
+--R       \|\|a  + 1  + a atan(---------------------------)
+--R                                    +---------------+
+--R                                    |   +------+
+--R                                +-+ |   | 2
+--R                               \|2 \|- \|a  + 1  + a
+--R     + 
+--R                               +-------------+
+--R        +---------------+      | +------+
+--R        |   +------+           | | 2               +-+
+--R        |   | 2               \|\|a  + 1  - a  + x\|2
+--R       \|- \|a  + 1  + a atan(------------------------)
+--R                                   +-------------+
+--R                                   | +------+
+--R                                   | | 2
+--R                                  \|\|a  + 1  + a
+--R     + 
+--R                                 +-------------+
+--R          +---------------+      | +------+
+--R          |   +------+           | | 2               +-+
+--R          |   | 2               \|\|a  + 1  - a  - x\|2
+--R       - \|- \|a  + 1  + a atan(------------------------)
+--R                                     +-------------+
+--R                                     | +------+
+--R                                     | | 2
+--R                                    \|\|a  + 1  + a
+--R  /
+--R                    +---------------+ +-------------+
+--R           +------+ |   +------+      | +------+
+--R       +-+ | 2      |   | 2           | | 2
+--R     2\|2 \|a  + 1 \|- \|a  + 1  + a \|\|a  + 1  + a
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 672
+
+)clear all
+
+--S 673 of 765
+t0:=1/(4-5*x^2+x^4)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 673
+
+--S 674 of 765
+r0:=-1/6*atanh(1/2*x)+1/3*atanh(x)
+--R 
+--R
+--R                          x
+--R        2atanh(x) - atanh(-)
+--R                          2
+--R   (2)  --------------------
+--R                  6
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+)clear all
+
+--S 676 of 765
+t0:=1/(3+4*x^2+x^4)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 676
+
+--S 677 of 765
+r0:=1/2*atan(x)-1/2*atan(x/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                 +-+
+--R               x\|3      +-+
+--R        - atan(-----) + \|3 atan(x)
+--R                 3
+--R   (2)  ---------------------------
+--R                     +-+
+--R                   2\|3
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 678
+
+)clear all
+
+--S 679 of 765
+t0:=1/(9+5*x^2+x^4)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 5x  + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 679
+
+--S 680 of 765
+r0:=-1/12*log(3-x+x^2)+1/12*log(3+x+x^2)-1/6*atan((1-2*x)/sqrt(11))/_
+   sqrt(11)+1/6*atan((1+2*x)/sqrt(11))/sqrt(11)
+--R 
+--R
+--R   (2)
+--R                                                                    +--+
+--R        +--+     2             +--+     2                  (2x + 1)\|11
+--R       \|11 log(x  + x + 3) - \|11 log(x  - x + 3) + 2atan(-------------)
+--R                                                                 11
+--R     + 
+--R                      +--+
+--R             (2x - 1)\|11
+--R       2atan(-------------)
+--R                   11
+--R  /
+--R        +--+
+--R     12\|11
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 681
+
+)clear all
+
+--S 682 of 765
+t0:=1/(1-x^2+x^4)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         4    2
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 682
+
+--S 683 of 765
+r0:=-1/2*atan(-2*x+sqrt(3))+1/2*atan(2*x+sqrt(3))-1/4*log(1+x^2-_
+   x*sqrt(3))/sqrt(3)+1/4*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R             +-+    2                +-+    2          +-+      +-+
+--R       log(x\|3  + x  + 1) - log(- x\|3  + x  + 1) + 2\|3 atan(\|3  + 2x)
+--R     + 
+--R           +-+      +-+
+--R       - 2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 683
+
+--S 684 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 684
+
+)clear all
+
+--S 685 of 765
+t0:=1/(2+2*x^2+x^4)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 685
+
+--S 686 of 765
+r0:=-1/8*log(x^2+sqrt(2)-x*sqrt(2*(-1+sqrt(2))))/sqrt(-1+sqrt(2))+_
+   1/8*log(x^2+sqrt(2)+x*sqrt(2*(-1+sqrt(2))))/sqrt(-1+sqrt(2))-_
+   1/4*atan((-2*x+sqrt(2*(-1+sqrt(2))))/sqrt(2*(1+sqrt(2))))*_
+   sqrt(-1+sqrt(2))+1/4*atan((2*x+sqrt(2*(-1+sqrt(2))))/sqrt(2*(1+_
+   sqrt(2))))*sqrt(-1+sqrt(2))
+--R 
+--R
+--R   (2)
+--R             +---------+                        +---------+
+--R             |  +-+         +-+    2            |  +-+         +-+    2
+--R       log(x\|2\|2  - 2  + \|2  + x ) - log(- x\|2\|2  - 2  + \|2  + x )
+--R     + 
+--R                                   +---------+                +---------+
+--R                          +-+      |  +-+           +-+       |  +-+
+--R          +-+          ((\|2  - 1)\|2\|2  - 2  + 2x\|2  - 2x)\|2\|2  + 2
+--R       (2\|2  - 2)atan(--------------------------------------------------)
+--R                                                2
+--R     + 
+--R                                     +---------+                +---------+
+--R                            +-+      |  +-+           +-+       |  +-+
+--R            +-+          ((\|2  - 1)\|2\|2  - 2  - 2x\|2  + 2x)\|2\|2  + 2
+--R       (- 2\|2  + 2)atan(--------------------------------------------------)
+--R                                                  2
+--R  /
+--R       +--------+
+--R       | +-+
+--R     8\|\|2  - 1
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                    +--------+ +---------+
+--R             2      +-+     2       | +-+      |  +-+
+--R       ((- 5x  + 7)\|2  + 7x  - 10)\|\|2  - 1 \|2\|2  + 2
+--R     + 
+--R                                   +--------+ +---------+
+--R             2      +-+     2      | +-+      |  +-+           +-+
+--R       ((- 2x  - 3)\|2  + 3x  + 4)\|\|2  - 1 \|2\|2  - 2  + 20\|2  - 28
+--R  /
+--R         4      2       +-+      4      2
+--R     (20x  + 40x  + 40)\|2  - 28x  - 56x  - 56
+--R                                                    Type: Expression(Integer)
+--E 687
+
+)clear all
+
+--S 688 of 765
+t0:=x/(1+x^2+x^4)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 688
+
+--S 689 of 765
+r0:=atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                2      +-+
+--R             (2x  + 1)\|3
+--R        atan(-------------)
+--R                   3
+--R   (2)  -------------------
+--R                 +-+
+--R                \|3
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 690
+
+)clear all
+
+--S 691 of 765
+t0:=x/(10+2*x^2+x^4)
+--R 
+--R
+--R              x
+--R   (1)  -------------
+--R         4     2
+--R        x  + 2x  + 10
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 691
+
+--S 692 of 765
+r0:=1/6*atan(1/3+1/3*x^2)
+--R 
+--R
+--R              2
+--R             x  + 1
+--R        atan(------)
+--R                3
+--R   (2)  ------------
+--R              6
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 693
+
+)clear all
+
+--S 694 of 765
+t0:=x^2/(20+9*x^2+x^4)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  -------------
+--R         4     2
+--R        x  + 9x  + 20
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 694
+
+--S 695 of 765
+r0:=-2*atan(1/2*x)+atan(x/sqrt(5))*sqrt(5)
+--R 
+--R
+--R                   +-+
+--R         +-+     x\|5           x
+--R   (2)  \|5 atan(-----) - 2atan(-)
+--R                   5            2
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 696
+
+)clear all
+
+--S 697 of 765
+t0:=x^2/(1-x^2+x^4)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         4    2
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 697
+
+--S 698 of 765
+r0:=-1/2*atan(-2*x+sqrt(3))+1/2*atan(2*x+sqrt(3))+1/4*log(1+x^2-_
+   x*sqrt(3))/sqrt(3)-1/4*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R               +-+    2                +-+    2          +-+      +-+
+--R       - log(x\|3  + x  + 1) + log(- x\|3  + x  + 1) + 2\|3 atan(\|3  + 2x)
+--R     + 
+--R           +-+      +-+
+--R       - 2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 698
+
+--S 699 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 699
+
+)clear all
+
+--S 700 of 765
+t0:=x^2/(2-2*x^2+x^4)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         4     2
+--R        x  - 2x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 700
+
+--S 701 of 765
+r0:=-1/2*atan((-2*x+sqrt(2*(1+sqrt(2))))/sqrt(2*(-1+sqrt(2))))*_
+   sqrt(1/2*(1+sqrt(2)))+1/2*atan((2*x+sqrt(2*(1+sqrt(2))))/sqrt(2*_
+   (-1+sqrt(2))))*sqrt(1/2*(1+sqrt(2)))+1/4*log(x^2+sqrt(2)-x*sqrt(2*_
+   (1+sqrt(2))))/sqrt(2*(1+sqrt(2)))-1/4*log(x^2+sqrt(2)+x*sqrt(2*_
+   (1+sqrt(2))))/sqrt(2*(1+sqrt(2)))
+--R 
+--R
+--R   (2)
+--R                   +---------+
+--R          +-+      |  +-+         +-+    2
+--R       - \|2 log(x\|2\|2  + 2  + \|2  + x )
+--R     + 
+--R                   +---------+
+--R        +-+        |  +-+         +-+    2
+--R       \|2 log(- x\|2\|2  + 2  + \|2  + x )
+--R     + 
+--R           +--------+ +---------+
+--R           | +-+      |  +-+
+--R         2\|\|2  + 1 \|2\|2  + 2
+--R      *
+--R                         +---------+ +---------+                 +---------+
+--R                +-+      |  +-+      |  +-+            +-+       |  +-+
+--R              (\|2  + 1)\|2\|2  - 2 \|2\|2  + 2  + (2x\|2  + 2x)\|2\|2  - 2
+--R         atan(--------------------------------------------------------------)
+--R                                             2
+--R     + 
+--R       -
+--R              +--------+ +---------+
+--R              | +-+      |  +-+
+--R            2\|\|2  + 1 \|2\|2  + 2
+--R         *
+--R                          +---------+ +---------+                   +---------+
+--R                 +-+      |  +-+      |  +-+              +-+       |  +-+
+--R               (\|2  + 1)\|2\|2  - 2 \|2\|2  + 2  + (- 2x\|2  - 2x)\|2\|2  - 2
+--R          atan(----------------------------------------------------------------)
+--R                                               2
+--R  /
+--R           +---------+
+--R       +-+ |  +-+
+--R     4\|2 \|2\|2  + 2
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                      +--------+ +---------+
+--R             2       +-+      2       | +-+      |  +-+            2       +-+
+--R       ((- 7x  - 10)\|2  - 10x  - 14)\|\|2  + 1 \|2\|2  - 2  + (10x  + 14)\|2
+--R     + 
+--R          2
+--R       14x  + 20
+--R  /
+--R         4      2       +-+      4      2
+--R     (20x  - 40x  + 40)\|2  + 28x  - 56x  + 56
+--R                                                    Type: Expression(Integer)
+--E 702
+
+)clear all
+
+--S 703 of 765
+t0:=x^7*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +---------------+
+--R         7 |   4      2
+--R   (1)  x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 703
+
+--S 704 of 765
+r0:=1/480*(35*b^2-8*a*c)*(a+b*x^2+c*x^4)^(3/2)/c^3+1/10*x^4*(a+b*x^2+_
+   c*x^4)^(3/2)/c-1/80*(4*a+7*b*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^2+_
+   1/512*b*(7*b^2-12*a*c)*(b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/c^(9/2)-1/256*b*(7*b^2-12*a*c)*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^4
+--R 
+--R
+--R   (2)
+--R                                                      2
+--R            2   2         3        5              2c x  + b
+--R       (720a b c  - 600a b c + 105b )atanh(-----------------------)
+--R                                                 +---------------+
+--R                                             +-+ |   4      2
+--R                                           2\|c \|c x  + b x  + a
+--R     + 
+--R               4 8        3 6          3       2 2  4              2       3   2
+--R           768c x  + 96b c x  + (256a c  - 112b c )x  + (- 464a b c  + 140b c)x
+--R         + 
+--R                 2 2         2        4
+--R           - 512a c  + 920a b c - 210b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R          4 +-+
+--R     7680c \|c
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 705
+
+)clear all
+
+--S 706 of 765
+t0:=x^5*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +---------------+
+--R         5 |   4      2
+--R   (1)  x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 765
+r0:=-5/48*b*(a+b*x^2+c*x^4)^(3/2)/c^2+1/8*x^2*(a+b*x^2+c*x^4)^(3/2)/c-_
+   1/256*(b^2-4*a*c)*(5*b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/c^(7/2)+1/128*(5*b^2-4*a*c)*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R                                                   2
+--R             2 2        2       4              2c x  + b
+--R       (- 48a c  + 72a b c - 15b )atanh(-----------------------)
+--R                                              +---------------+
+--R                                          +-+ |   4      2
+--R                                        2\|c \|c x  + b x  + a
+--R     + 
+--R             3 6        2 4         2      2   2                 3  +-+
+--R         (96c x  + 16b c x  + (48a c  - 20b c)x  - 104a b c + 30b )\|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R  /
+--R         3 +-+
+--R     768c \|c
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 708
+
+)clear all
+
+--S 709 of 765
+t0:=x^3*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +---------------+
+--R         3 |   4      2
+--R   (1)  x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 765
+r0:=1/6*(a+b*x^2+c*x^4)^(3/2)/c+1/32*b*(b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/_
+   (sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(5/2)-1/16*b*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                                         2
+--R                      3              2c x  + b
+--R       (- 12a b c + 3b )atanh(-----------------------)
+--R                                    +---------------+
+--R                                +-+ |   4      2
+--R                              2\|c \|c x  + b x  + a
+--R     + 
+--R                                            +---------------+
+--R           2 4         2             2  +-+ |   4      2
+--R       (16c x  + 4b c x  + 16a c - 6b )\|c \|c x  + b x  + a
+--R  /
+--R        2 +-+
+--R     96c \|c
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 711
+
+)clear all
+
+--S 712 of 765
+t0:=x*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R          +---------------+
+--R          |   4      2
+--R   (1)  x\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 712
+
+--S 713 of 765
+r0:=-1/16*(b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/c^(3/2)+1/8*(b+2*c*x^2)*sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                   2
+--R                2              2c x  + b
+--R       (4a c - b )atanh(-----------------------)
+--R                              +---------------+
+--R                          +-+ |   4      2
+--R                        2\|c \|c x  + b x  + a
+--R     + 
+--R                        +---------------+
+--R            2       +-+ |   4      2
+--R       (4c x  + 2b)\|c \|c x  + b x  + a
+--R  /
+--R         +-+
+--R     16c\|c
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 714
+
+)clear all
+
+--S 715 of 765
+t0:=sqrt(a+b*x^2+c*x^4)/x
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 715
+
+--S 716 of 765
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))*sqrt(a)+_
+   1/4*b*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/sqrt(c)+_
+   1/2*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (2)
+--R                                  2
+--R           +-+ +-+             b x  + 2a
+--R       - 2\|a \|c atanh(-----------------------)
+--R                              +---------------+
+--R                          +-+ |   4      2
+--R                        2\|a \|c x  + b x  + a
+--R     + 
+--R                          2                     +---------------+
+--R                      2c x  + b             +-+ |   4      2
+--R       b atanh(-----------------------) + 2\|c \|c x  + b x  + a
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R  /
+--R       +-+
+--R     4\|c
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 717
+
+)clear all
+
+--S 718 of 765
+t0:=sqrt(a+b*x^2+c*x^4)/x^3
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 765
+r0:=-1/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)+_
+   1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))*sqrt(c)-_
+   1/2*sqrt(a+b*x^2+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                             2
+--R            2             b x  + 2a
+--R       - b x atanh(-----------------------)
+--R                         +---------------+
+--R                     +-+ |   4      2
+--R                   2\|a \|c x  + b x  + a
+--R     + 
+--R                                   2                     +---------------+
+--R         2 +-+ +-+             2c x  + b             +-+ |   4      2
+--R       2x \|a \|c atanh(-----------------------) - 2\|a \|c x  + b x  + a
+--R                              +---------------+
+--R                          +-+ |   4      2
+--R                        2\|c \|c x  + b x  + a
+--R  /
+--R       2 +-+
+--R     4x \|a
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 720
+
+)clear all
+
+--S 721 of 765
+t0:=sqrt(a+b*x^2+c*x^4)/x^5
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 5
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 765
+r0:=1/16*(b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+_
+   c*x^4)))/a^(3/2)-1/4*sqrt(a+b*x^2+c*x^4)/x^4-1/8*b*sqrt(a+b*x^2+_
+   c*x^4)/(a*x^2)
+--R 
+--R
+--R   (2)
+--R                                      2
+--R                  2  4             b x  + 2a
+--R       (- 4a c + b )x atanh(-----------------------)
+--R                                  +---------------+
+--R                              +-+ |   4      2
+--R                            2\|a \|c x  + b x  + a
+--R     + 
+--R                          +---------------+
+--R              2       +-+ |   4      2
+--R       (- 2b x  - 4a)\|a \|c x  + b x  + a
+--R  /
+--R          4 +-+
+--R     16a x \|a
+--R                                                    Type: Expression(Integer)
+--E 722
+
+--S 723 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 723
+
+)clear all
+
+--S 724 of 765
+t0:=sqrt(a+b*x^2+c*x^4)/x^7
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 7
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 724
+
+--S 725 of 765
+r0:=-1/32*b*(b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+_
+   c*x^4)))/a^(5/2)-1/6*sqrt(a+b*x^2+c*x^4)/x^6-1/24*b*sqrt(a+b*x^2+_
+   c*x^4)/(a*x^4)+1/48*(3*b^2-8*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*x^2)
+--R 
+--R
+--R   (2)
+--R                                        2
+--R                    3  6             b x  + 2a
+--R       (12a b c - 3b )x atanh(-----------------------)
+--R                                    +---------------+
+--R                                +-+ |   4      2
+--R                              2\|a \|c x  + b x  + a
+--R     + 
+--R                                                +---------------+
+--R                     2  4         2      2  +-+ |   4      2
+--R       ((- 16a c + 6b )x  - 4a b x  - 16a )\|a \|c x  + b x  + a
+--R  /
+--R        2 6 +-+
+--R     96a x \|a
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 726
+
+)clear all
+
+--S 727 of 765
+t0:=sqrt(a+b*x^2+c*x^4)/x^9
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 9
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 727
+
+--S 728 of 765
+r0:=1/256*(b^2-4*a*c)*(5*b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*_
+   sqrt(a+b*x^2+c*x^4)))/a^(7/2)-1/8*sqrt(a+b*x^2+c*x^4)/x^8-1/48*b*_
+   sqrt(a+b*x^2+c*x^4)/(a*x^6)+1/192*(5*b^2-12*a*c)*sqrt(a+b*x^2+c*x^4)/_
+   (a^2*x^4)-1/384*b*(15*b^2-52*a*c)*sqrt(a+b*x^2+c*x^4)/(a^3*x^2)
+--R 
+--R
+--R   (2)
+--R                                                  2
+--R           2 2        2       4  8             b x  + 2a
+--R       (48a c  - 72a b c + 15b )x atanh(-----------------------)
+--R                                              +---------------+
+--R                                          +-+ |   4      2
+--R                                        2\|a \|c x  + b x  + a
+--R     + 
+--R                         3  6         2         2  4      2   2      3  +-+
+--R         ((104a b c - 30b )x  + (- 48a c + 20a b )x  - 16a b x  - 96a )\|a
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R  /
+--R         3 8 +-+
+--R     768a x \|a
+--R                                                    Type: Expression(Integer)
+--E 728
+
+--S 729 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 729
+
+)clear all
+
+--S 730 of 765
+t0:=sqrt(a+b*x^2+c*x^4)/x^11
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 11
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 730
+
+--S 731 of 765
+r0:=-1/512*b*(7*b^2-12*a*c)*(b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*_
+   sqrt(a+b*x^2+c*x^4)))/a^(9/2)-1/10*sqrt(a+b*x^2+c*x^4)/x^10-1/80*b*_
+   sqrt(a+b*x^2+c*x^4)/(a*x^8)+1/480*(7*b^2-16*a*c)*sqrt(a+b*x^2+c*x^4)/_
+   (a^2*x^6)-1/1920*b*(35*b^2-116*a*c)*sqrt(a+b*x^2+c*x^4)/(a^3*x^4)+_
+   1/3840*(105*b^4-460*a*b^2*c+256*a^2*c^2)*sqrt(a+b*x^2+c*x^4)/(a^4*x^2)
+--R 
+--R
+--R   (2)
+--R                                                          2
+--R              2   2         3        5  10             b x  + 2a
+--R       (- 720a b c  + 600a b c - 105b )x  atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|a \|c x  + b x  + a
+--R     + 
+--R                2 2         2        4  8        2            3  6
+--R           (512a c  - 920a b c + 210b )x  + (464a b c - 140a b )x
+--R         + 
+--R                  3        2 2  4      3   2       4
+--R           (- 256a c + 112a b )x  - 96a b x  - 768a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R  /
+--R          4 10 +-+
+--R     7680a x  \|a
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 732
+
+)clear all
+
+--S 733 of 765
+t0:=x^4*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +---------------+
+--R         4 |   4      2
+--R   (1)  x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 733
+
+--S 734 of 765
+--r0a:=-2/105*(2*b^2-5*a*c)*x*sqrt(a+b*x^2+c*x^4)/c^2+1/35*x^3*(b+5*c*x^2)*_
+--  sqrt(a+b*x^2+c*x^4)/c+1/210*b*(8*b^2-29*a*c)*elliptic_e(asin(x*_
+--  sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/_
+--  (b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-_
+--  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+--  sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/210*_
+--  elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(8*b^4-37*a*b^2*c+20*_
+--  a^2*c^2+b*(8*b^2-29*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-_
+--  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+--  sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 734
+
+--S 735 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 735
+
+)clear all
+
+--S 736 of 765
+t0:=x^2*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +---------------+
+--R         2 |   4      2
+--R   (1)  x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 736
+
+--S 737 of 765
+--r0:=1/15*x*(b+3*c*x^2)*sqrt(a+b*x^2+c*x^4)/c-1/15*(b^2-3*a*c)*_
+--  elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*_
+--  x^2+c*x^4))+1/15*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+--  sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--  (b^3-4*a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-_
+--  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/_
+--  (b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 737
+
+--S 738 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 738
+
+)clear all
+
+--S 739 of 765
+t0:=sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R   (1)  \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 765
+--r0:=1/3*x*sqrt(a+b*x^2+c*x^4)+1/6*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/_
+--  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--  (b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+--  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*_
+--  sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/6*elliptic_f(asin(x*sqrt(2)*_
+--  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+--  sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/_
+--  (b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/_
+--  (b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 740
+
+--S 741 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 741
+
+)clear all
+
+--S 742 of 765
+t0:=sqrt(a+b*x^2+c*x^4)/x^2
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 765
+--r0:=-sqrt(a+b*x^2+c*x^4)/x-elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+--  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--  sqrt(b^2-4*a*c)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+--  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*_
+--  sqrt(c)*sqrt(a+b*x^2+c*x^4))+elliptic_e(asin(x*sqrt(2)*sqrt(c)/_
+--  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--  (b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+--  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*_
+--  sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 743
+
+--S 744 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 744
+
+)clear all
+
+--S 745 of 765
+t0:=sqrt(a+b*x^2+c*x^4)/x^4
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 4
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 745
+
+--S 746 of 765
+--r0:=-1/3*sqrt(a+b*x^2+c*x^4)/x^3-1/3*b*sqrt(a+b*x^2+c*x^4)/(a*x)+1/6*b*_
+--  elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*_
+--  sqrt(a+b*x^2+c*x^4))-1/6*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+--  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--  (b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+--  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+--  (a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 746
+
+--S 747 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 747
+
+)clear all
+
+--S 748 of 765
+t0:=sqrt(a+b*x^2+c*x^4)/x^6
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                 6
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 748
+
+--S 749 of 765
+--r0:=-1/5*sqrt(a+b*x^2+c*x^4)/x^5-1/15*b*sqrt(a+b*x^2+c*x^4)/(a*x^3)+_
+--  2/15*(b^2-3*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*x)-1/15*(b^2-3*a*c)*_
+--  elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*_
+--  sqrt(a+b*x^2+c*x^4))+1/15*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+--  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--  (b^3-4*a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-_
+--  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+--  sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 749
+
+--S 750 of 765
+--d0:=normalize(t0-D(r0,x))
+--E 750
+
+)clear all
+
+--S 751 of 765
+t0:=x^7*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                              +---------------+
+--R            11      9      7  |   4      2
+--R   (1)  (c x   + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 765
+r0:=-1/256*b*(3*b^2-4*a*c)*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^4+1/1680*_
+   (63*b^2-8*a*c)*(a+b*x^2+c*x^4)^(5/2)/c^3+1/14*x^4*(a+b*x^2+c*x^4)^(5/2)/c-_
+   1/168*(4*a+9*b*x^2)*(a+b*x^2+c*x^4)^(5/2)/c^2-3/4096*b*(b^2-4*a*c)^2*_
+   (3*b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/_
+   c^(11/2)+3/2048*b*(b^2-4*a*c)*(3*b^2-4*a*c)*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^5
+--R 
+--R
+--R   (2)
+--R               3   3        2 3 2          5        7
+--R         (6720a b c  - 8400a b c  + 2940a b c - 315b )
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                 6 12           5 10            5       2 4  8
+--R           10240c x   + 12800b c x   + (16384a c  + 256b c )x
+--R         + 
+--R                     4       3 3  6         2 4          2 3       4 2  4
+--R           (1408a b c  - 288b c )x  + (2048a c  - 1984a b c  + 336b c )x
+--R         + 
+--R                   2   3          3 2       5   2        3 3         2 2 2
+--R           (- 4672a b c  + 2912a b c  - 420b c)x  - 4096a c  + 10976a b c
+--R         + 
+--R                    4        6
+--R           - 5040a b c + 630b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R            5 +-+
+--R     143360c \|c
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 753
+
+)clear all
+
+--S 754 of 765
+t0:=x^5*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                             +---------------+
+--R            9      7      5  |   4      2
+--R   (1)  (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 765
+r0:=1/384*(7*b^2-4*a*c)*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^3-7/120*b*_
+   (a+b*x^2+c*x^4)^(5/2)/c^2+1/12*x^2*(a+b*x^2+c*x^4)^(5/2)/c+1/2048*_
+   (b^2-4*a*c)^2*(7*b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/c^(9/2)-1/1024*(b^2-4*a*c)*(7*b^2-4*a*c)*_
+   (b+2*c*x^2)*sqrt(a+b*x^2+c*x^4)/c^4
+--R 
+--R
+--R   (2)
+--R                                                                   2
+--R              3 3        2 2 2         4        6              2c x  + b
+--R       (- 960a c  + 2160a b c  - 900a b c + 105b )atanh(-----------------------)
+--R                                                              +---------------+
+--R                                                          +-+ |   4      2
+--R                                                        2\|c \|c x  + b x  + a
+--R     + 
+--R                5 10          4 8           4      2 3  6
+--R           2560c x   + 3328b c x  + (4480a c  + 96b c )x
+--R         + 
+--R                    3       3 2  4        2 3         2 2       4   2
+--R           (576a b c  - 112b c )x  + (960a c  - 864a b c  + 140b c)x
+--R         + 
+--R                  2   2          3        5
+--R           - 2592a b c  + 1520a b c - 210b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R           4 +-+
+--R     30720c \|c
+--R                                                    Type: Expression(Integer)
+--E 755
+
+--S 756 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 756
+
+)clear all
+
+--S 757 of 765
+t0:=x^3*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                             +---------------+
+--R            7      5      3  |   4      2
+--R   (1)  (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 765
+r0:=-1/32*b*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^2+1/10*(a+b*x^2+_
+   c*x^4)^(5/2)/c-3/512*b*(b^2-4*a*c)^2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/c^(7/2)+3/256*b*(b^2-4*a*c)*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R                                                       2
+--R              2   2         3       5              2c x  + b
+--R       (- 240a b c  + 120a b c - 15b )atanh(-----------------------)
+--R                                                  +---------------+
+--R                                              +-+ |   4      2
+--R                                            2\|c \|c x  + b x  + a
+--R     + 
+--R               4 8         3 6          3      2 2  4            2      3   2
+--R           256c x  + 352b c x  + (512a c  + 16b c )x  + (112a b c  - 20b c)x
+--R         + 
+--R               2 2         2       4
+--R           256a c  - 200a b c + 30b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R          3 +-+
+--R     2560c \|c
+--R                                                    Type: Expression(Integer)
+--E 758
+
+--S 759 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 759
+
+)clear all
+
+--S 760 of 765
+t0:=x*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                            +---------------+
+--R            5      3        |   4      2
+--R   (1)  (c x  + b x  + a x)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 760
+
+--S 761 of 765
+r0:=1/16*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c+3/256*(b^2-4*a*c)^2*_
+   atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(5/2)-3/128*_
+   (b^2-4*a*c)*(b+2*c*x^2)*sqrt(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                                                2
+--R           2 2        2      4              2c x  + b
+--R       (48a c  - 24a b c + 3b )atanh(-----------------------)
+--R                                           +---------------+
+--R                                       +-+ |   4      2
+--R                                     2\|c \|c x  + b x  + a
+--R     + 
+--R             3 6        2 4         2     2   2               3  +-+
+--R         (32c x  + 48b c x  + (80a c  + 4b c)x  + 40a b c - 6b )\|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R  /
+--R         2 +-+
+--R     256c \|c
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 762
+
+)clear all
+
+--S 763 of 765
+t0:=(a+b*x^2+c*x^4)^(3/2)/x
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 763
+
+--S 764 of 765
+r0:=1/6*(a+b*x^2+c*x^4)^(3/2)-1/2*a^(3/2)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*_
+   sqrt(a+b*x^2+c*x^4)))-1/32*b*(b^2-12*a*c)*atanh(1/2*(b+2*c*x^2)/_
+   (sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(3/2)+1/16*(b^2+8*a*c+2*b*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                      2
+--R               +-+ +-+             b x  + 2a
+--R       - 48a c\|a \|c atanh(-----------------------)
+--R                                  +---------------+
+--R                              +-+ |   4      2
+--R                            2\|a \|c x  + b x  + a
+--R     + 
+--R                                       2
+--R                    3              2c x  + b
+--R       (36a b c - 3b )atanh(-----------------------)
+--R                                  +---------------+
+--R                              +-+ |   4      2
+--R                            2\|c \|c x  + b x  + a
+--R     + 
+--R                                             +---------------+
+--R           2 4          2             2  +-+ |   4      2
+--R       (16c x  + 28b c x  + 64a c + 6b )\|c \|c x  + b x  + a
+--R  /
+--R         +-+
+--R     96c\|c
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 765
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 765
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder14c.input.pamphlet b/src/input/richder14c.input.pamphlet
new file mode 100644
index 0000000..a39bba8
--- /dev/null
+++ b/src/input/richder14c.input.pamphlet
@@ -0,0 +1,21710 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder14c.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a+b x^2+c x^4)^p|
+
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder14c.output
+)spool richder14c.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^3
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          3
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 585
+r0:=-1/2*(a+b*x^2+c*x^4)^(3/2)/x^2-3/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*_
+   sqrt(a+b*x^2+c*x^4)))*sqrt(a)+3/16*(b^2+4*a*c)*atanh(1/2*(b+2*c*x^2)/_
+   (sqrt(c)*sqrt(a+b*x^2+c*x^4)))/sqrt(c)+3/8*(3*b+2*c*x^2)*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (2)
+--R                                       2
+--R              2 +-+ +-+             b x  + 2a
+--R       - 12b x \|a \|c atanh(-----------------------)
+--R                                   +---------------+
+--R                               +-+ |   4      2
+--R                             2\|a \|c x  + b x  + a
+--R     + 
+--R                                       2
+--R                  2  2             2c x  + b
+--R       (12a c + 3b )x atanh(-----------------------)
+--R                                  +---------------+
+--R                              +-+ |   4      2
+--R                            2\|c \|c x  + b x  + a
+--R     + 
+--R                                 +---------------+
+--R            4        2       +-+ |   4      2
+--R       (4c x  + 10b x  - 8a)\|c \|c x  + b x  + a
+--R  /
+--R        2 +-+
+--R     16x \|c
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^5
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          5
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 585
+r0:=-1/4*(a+b*x^2+c*x^4)^(3/2)/x^4-3/16*(b^2+4*a*c)*atanh(1/2*(2*a+b*x^2)/_
+   (sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)+3/4*b*atanh(1/2*(b+2*c*x^2)/_
+   (sqrt(c)*sqrt(a+b*x^2+c*x^4)))*sqrt(c)-3/8*(b-2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                                        2
+--R                    2  4             b x  + 2a
+--R       (- 12a c - 3b )x atanh(-----------------------)
+--R                                    +---------------+
+--R                                +-+ |   4      2
+--R                              2\|a \|c x  + b x  + a
+--R     + 
+--R                                      2
+--R            4 +-+ +-+             2c x  + b
+--R       12b x \|a \|c atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|c \|c x  + b x  + a
+--R     + 
+--R                                 +---------------+
+--R            4        2       +-+ |   4      2
+--R       (8c x  - 10b x  - 4a)\|a \|c x  + b x  + a
+--R  /
+--R        4 +-+
+--R     16x \|a
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^7
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          7
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 585
+r0:=-1/6*(a+b*x^2+c*x^4)^(3/2)/x^6-1/8*b*(a+b*x^2+c*x^4)^(3/2)/(a*x^4)+_
+   1/32*b*(b^2-12*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+_
+   c*x^4)))/a^(3/2)+1/2*c^(3/2)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))+1/16*(b^2-8*a*c+2*b*c*x^2)*sqrt(a+b*x^2+c*x^4)/(a*x^2)
+--R 
+--R
+--R   (2)
+--R                                          2
+--R                      3  6             b x  + 2a
+--R       (- 36a b c + 3b )x atanh(-----------------------)
+--R                                      +---------------+
+--R                                  +-+ |   4      2
+--R                                2\|a \|c x  + b x  + a
+--R     + 
+--R                                        2
+--R              6 +-+ +-+             2c x  + b
+--R       48a c x \|a \|c atanh(-----------------------)
+--R                                   +---------------+
+--R                               +-+ |   4      2
+--R                             2\|c \|c x  + b x  + a
+--R     + 
+--R                                                 +---------------+
+--R                     2  4          2      2  +-+ |   4      2
+--R       ((- 64a c - 6b )x  - 28a b x  - 16a )\|a \|c x  + b x  + a
+--R  /
+--R          6 +-+
+--R     96a x \|a
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^9
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          9
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 585
+r0:=-1/8*(a+b*x^2+c*x^4)^(3/2)/x^8-3/256*(b^2-4*a*c)^2*atanh(1/2*_
+   (2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(5/2)-1/64*(b^2-12*a*c)*_
+   sqrt(a+b*x^2+c*x^4)/(a*x^4)+1/128*b*(3*b^2-20*a*c)*sqrt(a+b*x^2+c*x^4)/_
+   (a^2*x^2)-1/16*(b+6*c*x^2)*sqrt(a+b*x^2+c*x^4)/x^6
+--R 
+--R
+--R   (2)
+--R                                                   2
+--R             2 2        2      4  8             b x  + 2a
+--R       (- 48a c  + 24a b c - 3b )x atanh(-----------------------)
+--R                                               +---------------+
+--R                                           +-+ |   4      2
+--R                                         2\|a \|c x  + b x  + a
+--R     + 
+--R                         3  6         2        2  4      2   2      3  +-+
+--R         ((- 40a b c + 6b )x  + (- 80a c - 4a b )x  - 48a b x  - 32a )\|a
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R  /
+--R         2 8 +-+
+--R     256a x \|a
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^11
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                         11
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 585
+r0:=-1/10*(a+b*x^2+c*x^4)^(3/2)/x^10+3/512*b*(b^2-4*a*c)^2*atanh(1/2*_
+   (2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(7/2)-1/160*(b^2-8*a*c)*_
+   sqrt(a+b*x^2+c*x^4)/(a*x^6)+1/640*b*(5*b^2-28*a*c)*sqrt(a+b*x^2+c*x^4)/_
+   (a^2*x^4)-1/1280*(15*b^4-100*a*b^2*c+128*a^2*c^2)*sqrt(a+b*x^2+c*x^4)/_
+   (a^3*x^2)-3/80*(b+4*c*x^2)*sqrt(a+b*x^2+c*x^4)/x^8
+--R 
+--R
+--R   (2)
+--R                                                       2
+--R            2   2         3       5  10             b x  + 2a
+--R       (240a b c  - 120a b c + 15b )x  atanh(-----------------------)
+--R                                                   +---------------+
+--R                                               +-+ |   4      2
+--R                                             2\|a \|c x  + b x  + a
+--R     + 
+--R                  2 2         2       4  8          2           3  6
+--R           (- 256a c  + 200a b c - 30b )x  + (- 112a b c + 20a b )x
+--R         + 
+--R                  3       2 2  4       3   2       4
+--R           (- 512a c - 16a b )x  - 352a b x  - 256a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R  /
+--R          3 10 +-+
+--R     2560a x  \|a
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^13
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                         13
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 585
+r0:=-1/12*(a+b*x^2+c*x^4)^(3/2)/x^12-1/2048*(b^2-4*a*c)^2*(7*b^2-4*a*c)*_
+   atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(9/2)-_
+   1/960*(3*b^2-20*a*c)*sqrt(a+b*x^2+c*x^4)/(a*x^8)+1/1920*b*(7*b^2-36*a*c)*_
+   sqrt(a+b*x^2+c*x^4)/(a^2*x^6)-1/7680*(35*b^4-216*a*b^2*c+240*a^2*c^2)*_
+   sqrt(a+b*x^2+c*x^4)/(a^3*x^4)+1/15360*b*(105*b^4-760*a*b^2*c+_
+   1296*a^2*c^2)*sqrt(a+b*x^2+c*x^4)/(a^4*x^2)-1/120*(3*b+10*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/x^10
+--R 
+--R
+--R   (2)
+--R              3 3        2 2 2         4        6  12
+--R         (960a c  - 2160a b c  + 900a b c - 105b )x
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                 2   2          3        5  10
+--R           (2592a b c  - 1520a b c + 210b )x
+--R         + 
+--R                  3 2       2 2          4  8          3          2 3  6
+--R           (- 960a c  + 864a b c - 140a b )x  + (- 576a b c + 112a b )x
+--R         + 
+--R                   4       3 2  4        4   2        5
+--R           (- 4480a c - 96a b )x  - 3328a b x  - 2560a
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|a \|c x  + b x  + a
+--R  /
+--R           4 12 +-+
+--R     30720a x  \|a
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 585
+t0:=x^4*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                             +---------------+
+--R            8      6      4  |   4      2
+--R   (1)  (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 585
+--r0:=1/33*x^3*(b+3*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c+1/1155*(8*b^4-51*a*b^2*c+_
+--   60*a^2*c^2)*x*sqrt(a+b*x^2+c*x^4)/c^3-1/385*x^3*(b*(2*b^2+a*c)+_
+--   10*c*(b^2-3*a*c)*x^2)*sqrt(a+b*x^2+c*x^4)/c^2-2/1155*b*(2*b^2-_
+--   9*a*c)*(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+--   sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(2)*_
+--   (b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+--   sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(9/2)*_
+--   sqrt(a+b*x^2+c*x^4))+1/1155*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+--   sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--   (b+sqrt(b^2-4*a*c))*(4*b*(2*b^2-9*a*c)*(b^2-3*a*c)-a*c*(8*b^4-_
+--   51*a*b^2*c+60*a^2*c^2)/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+--   sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+--   sqrt(b^2-4*a*c)))/(c^(9/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 20
+
+--S 21 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 21
+
+)clear all
+
+--S 22 of 585
+t0:=x^2*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                             +---------------+
+--R            6      4      2  |   4      2
+--R   (1)  (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 585
+--r0:=1/63*x*(3*b+7*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c-1/315*x*(b*(4*b^2-9*a*c)+_
+--   6*c*(2*b^2-7*a*c)*x^2)*sqrt(a+b*x^2+c*x^4)/c^2+1/630*(8*b^4-57*a*b^2*c+_
+--   84*a^2*c^2)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a+b*_
+--   x^2+c*x^4))-1/630*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+--   sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+_
+--   sqrt(b^2-4*a*c))*(8*b^4-57*a*b^2*c+84*a^2*c^2-8*a*b*c*(b^2-6*a*c)/_
+--   (b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+--   sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*_
+--   sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 23
+
+--S 24 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 24
+
+)clear all
+
+--S 25 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R   (1)  (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 585
+--r0:=1/7*x*(a+b*x^2+c*x^4)^(3/2)+1/35*x*(b^2+10*a*c+3*b*c*x^2)*_
+--   sqrt(a+b*x^2+c*x^4)/c-1/35*b*(b^2-8*a*c)*elliptic_e(asin(x*sqrt(2)*_
+--   sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+--   sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-_
+--   sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+--   sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))+1/35*_
+--   elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^4-9*a*b^2*c+20*a^2*c^2+_
+--   b*(b^2-8*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+--   sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+--   (c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 26
+
+--S 27 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 27
+
+)clear all
+
+--S 28 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^2
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          2
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 585
+--r0:=-(a+b*x^2+c*x^4)^(3/2)/x+1/5*x*(7*b+6*c*x^2)*sqrt(a+b*x^2+c*x^4)+_
+--   1/10*(b^2+12*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+--   sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+_
+--   sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+--   sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*_
+--   sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/10*elliptic_f(asin(x*sqrt(2)*_
+--   sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+--   sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2+12*a*c)*sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 29
+
+--S 30 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 30
+
+)clear all
+
+--S 31 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^4
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          4
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 585
+--r0:=-1/3*(a+b*x^2+c*x^4)^(3/2)/x^3-1/3*(3*b-2*c*x^2)*sqrt(a+b*x^2+c*x^4)/x+_
+--   2/3*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(2)*(b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(c)*sqrt(a+b*x^2+c*x^4))-_
+--   1/3*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-4*a*c+4*b*sqrt(b^2-_
+--   4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 32
+
+--S 33 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 33
+
+)clear all
+
+--S 34 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^6
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          6
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 585
+--r0:=-1/5*(a+b*x^2+c*x^4)^(3/2)/x^5-1/5*(b^2+12*a*c)*sqrt(a+b*x^2+c*x^4)/_
+--   (a*x)-1/5*(b-6*c*x^2)*sqrt(a+b*x^2+c*x^4)/x^3+1/10*(b^2+12*a*c)*_
+--   elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-_
+--   sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+_
+--   b*x^2+c*x^4))-1/10*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+--   sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-_
+--   4*a*b*c+(b^2+12*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-_
+--   4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-_
+--   4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 35
+
+--S 36 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 36
+
+)clear all
+
+--S 37 of 585
+t0:=(a+b*x^2+c*x^4)^(3/2)/x^8
+--R 
+--R
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R   (1)  -----------------------------------
+--R                          8
+--R                         x
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 585
+--r0:=-1/7*(a+b*x^2+c*x^4)^(3/2)/x^7-1/35*(b^2-20*a*c)*sqrt(a+b*x^2+c*x^4)/_
+--   (a*x^3)+2/35*b*(b^2-8*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*x)-3/35*(b+_
+--   10*c*x^2)*sqrt(a+b*x^2+c*x^4)/x^5-1/35*b*(b^2-8*a*c)*_
+--   elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*_
+--   sqrt(a+b*x^2+c*x^4))+1/35*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+--   sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--   (b^4-9*a*b^2*c+20*a^2*c^2+b*(b^2-8*a*c)*sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*_
+--   sqrt(a+b*x^2+c*x^4))
+--E 38
+
+--S 39 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 39
+
+)clear all
+
+--S 40 of 585
+t0:=sqrt(3-2*x^2-x^4)
+--R 
+--R
+--R         +--------------+
+--R         |   4     2
+--R   (1)  \|- x  - 2x  + 3
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 585
+--r0:=-2*elliptic_e(asin(x),-1/3)/sqrt(3)+4*elliptic_f(asin(x),_
+--   -1/3)/sqrt(3)+1/3*x*sqrt(3-2*x^2-x^4)
+--E 41
+
+--S 42 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 42
+
+)clear all
+
+--S 43 of 585
+t0:=x^7/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 7
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 585
+r0:=-1/32*b*(5*b^2-12*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+_
+   c*x^4)))/c^(7/2)+1/48*(15*b^2-8*a*c)*sqrt(a+b*x^2+c*x^4)/c^3+_
+   1/6*x^4*sqrt(a+b*x^2+c*x^4)/c-1/24*(4*a+5*b*x^2)*sqrt(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                                        2
+--R                     3              2c x  + b
+--R       (36a b c - 15b )atanh(-----------------------)
+--R                                   +---------------+
+--R                               +-+ |   4      2
+--R                             2\|c \|c x  + b x  + a
+--R     + 
+--R                                              +---------------+
+--R           2 4          2              2  +-+ |   4      2
+--R       (16c x  - 20b c x  - 32a c + 30b )\|c \|c x  + b x  + a
+--R  /
+--R        3 +-+
+--R     96c \|c
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 585
+t0:=x^5/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 5
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 585
+r0:=1/16*(3*b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+_
+   c*x^4)))/c^(5/2)-3/8*b*sqrt(a+b*x^2+c*x^4)/c^2+1/4*x^2*sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                      2
+--R                   2              2c x  + b
+--R       (- 4a c + 3b )atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|c \|c x  + b x  + a
+--R     + 
+--R                        +---------------+
+--R            2       +-+ |   4      2
+--R       (4c x  - 6b)\|c \|c x  + b x  + a
+--R  /
+--R        2 +-+
+--R     16c \|c
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 585
+t0:=x^3/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 585
+r0:=-1/4*b*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(3/2)+_
+   1/2*sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R                             2                     +---------------+
+--R                         2c x  + b             +-+ |   4      2
+--R        - b atanh(-----------------------) + 2\|c \|c x  + b x  + a
+--R                        +---------------+
+--R                    +-+ |   4      2
+--R                  2\|c \|c x  + b x  + a
+--R   (2)  ------------------------------------------------------------
+--R                                      +-+
+--R                                   4c\|c
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 585
+t0:=x/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 585
+r0:=1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/sqrt(c)
+--R 
+--R
+--R                         2
+--R                     2c x  + b
+--R        atanh(-----------------------)
+--R                    +---------------+
+--R                +-+ |   4      2
+--R              2\|c \|c x  + b x  + a
+--R   (2)  ------------------------------
+--R                       +-+
+--R                     2\|c
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 585
+t0:=1/(x*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R          +---------------+
+--R          |   4      2
+--R        x\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 585
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)
+--R 
+--R
+--R                          2
+--R                       b x  + 2a
+--R          atanh(-----------------------)
+--R                      +---------------+
+--R                  +-+ |   4      2
+--R                2\|a \|c x  + b x  + a
+--R   (2)  - ------------------------------
+--R                         +-+
+--R                       2\|a
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 585
+t0:=1/(x^3*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         3 |   4      2
+--R        x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 585
+r0:=1/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(3/2)-_
+   1/2*sqrt(a+b*x^2+c*x^4)/(a*x^2)
+--R 
+--R
+--R                            2                      +---------------+
+--R           2             b x  + 2a             +-+ |   4      2
+--R        b x atanh(-----------------------) - 2\|a \|c x  + b x  + a
+--R                        +---------------+
+--R                    +-+ |   4      2
+--R                  2\|a \|c x  + b x  + a
+--R   (2)  ------------------------------------------------------------
+--R                                      2 +-+
+--R                                  4a x \|a
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 585
+t0:=1/(x^5*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         5 |   4      2
+--R        x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 585
+r0:=-1/16*(3*b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+_
+   c*x^4)))/a^(5/2)-1/4*sqrt(a+b*x^2+c*x^4)/(a*x^4)+3/8*b*sqrt(a+b*x^2+_
+   c*x^4)/(a^2*x^2)
+--R 
+--R
+--R   (2)
+--R                                     2
+--R                 2  4             b x  + 2a
+--R       (4a c - 3b )x atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|a \|c x  + b x  + a
+--R     + 
+--R                        +---------------+
+--R            2       +-+ |   4      2
+--R       (6b x  - 4a)\|a \|c x  + b x  + a
+--R  /
+--R        2 4 +-+
+--R     16a x \|a
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 585
+t0:=1/(x^7*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         7 |   4      2
+--R        x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 585
+r0:=1/32*b*(5*b^2-12*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+_
+   c*x^4)))/a^(7/2)-1/6*sqrt(a+b*x^2+c*x^4)/(a*x^6)+5/24*b*sqrt(a+b*x^2+_
+   c*x^4)/(a^2*x^4)-1/48*(15*b^2-16*a*c)*sqrt(a+b*x^2+c*x^4)/(a^3*x^2)
+--R 
+--R
+--R   (2)
+--R                                           2
+--R                       3  6             b x  + 2a
+--R       (- 36a b c + 15b )x atanh(-----------------------)
+--R                                       +---------------+
+--R                                   +-+ |   4      2
+--R                                 2\|a \|c x  + b x  + a
+--R     + 
+--R                                                +---------------+
+--R                    2  4          2      2  +-+ |   4      2
+--R       ((32a c - 30b )x  + 20a b x  - 16a )\|a \|c x  + b x  + a
+--R  /
+--R        3 6 +-+
+--R     96a x \|a
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 585
+t0:=x^4/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 4
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 585
+--r0:=1/3*x*sqrt(a+b*x^2+c*x^4)/c-1/3*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/_
+--   sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--   (b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+--   sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*_
+--   sqrt(2)*sqrt(a+b*x^2+c*x^4))+1/3*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+--   sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--   (b^2-a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+--   sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+--   (c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 68
+
+--S 69 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 69
+
+)clear all
+
+--S 70 of 585
+t0:=x^2/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 585
+--r0:=1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(-b+sqrt(b^2-4*a*c))^(3/2)*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-_
+--   4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/2*_
+--   elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),_
+--   (b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*(b-sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/((-c)^(3/2)*sqrt(2)*_
+--   sqrt(a+b*x^2+c*x^4))
+--E 71
+
+--S 72 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 72
+
+)clear all
+
+--S 73 of 585
+t0:=1/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 585
+--r0:=elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+--   sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+--   sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 74
+
+--S 75 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 75
+
+)clear all
+
+--S 76 of 585
+t0:=1/(x^2*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         2 |   4      2
+--R        x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 585
+--r0:=-sqrt(a+b*x^2+c*x^4)/(a*x)+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+--   sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--   (-b+sqrt(b^2-4*a*c))^(3/2)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+_
+--   b*x^2+c*x^4))+1/2*elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+_
+--   sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*_
+--   (b-sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+--   sqrt(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+--   (a*sqrt(2)*sqrt(-c)*sqrt(a+b*x^2+c*x^4))
+--E 77
+
+--S 78 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 78
+
+)clear all
+
+--S 79 of 585
+t0:=1/(x^4*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         4 |   4      2
+--R        x \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 585
+--r0:=-1/3*sqrt(a+b*x^2+c*x^4)/(a*x^3)+2/3*b*sqrt(a+b*x^2+c*x^4)/(a^2*x)-_
+--   1/3*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(2)*sqrt(c)*_
+--   sqrt(a+b*x^2+c*x^4))+1/3*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+--   sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--   (b^2-a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+--   sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+--   (a^2*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 80
+
+--S 81 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 81
+
+)clear all
+
+--S 82 of 585
+t0:=x^9/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          9
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 585
+r0:=3/16*(5*b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+_
+   c*x^4)))/c^(7/2)+x^6*(2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-_
+   1/8*b*(15*b^2-44*a*c)*sqrt(a+b*x^2+c*x^4)/(c^3*(b^2-4*a*c))-b*x^4*_
+   sqrt(a+b*x^2+c*x^4)/(c*(b^2-4*a*c))+1/4*(4*a*b+(5*b^2-12*a*c)*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/(c^2*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                     +---------------+
+--R               2 2        2       4  |   4      2
+--R         (- 48a c  + 72a b c - 15b )\|c x  + b x  + a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                 3     2 2  6             2      3   4
+--R           (16a c  - 4b c )x  + (- 40a b c  + 10b c)x
+--R         + 
+--R               2 2         2       4  2       2           3
+--R           (48a c  - 124a b c + 30b )x  - 104a b c + 30a b
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                           +---------------+
+--R           4      2 3  +-+ |   4      2
+--R     (64a c  - 16b c )\|c \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 585
+t0:=x^7/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          7
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 585
+r0:=-3/4*b*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(5/2)+_
+   x^4*(2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))+1/2*(3*b^2-4*a*c)*_
+   sqrt(a+b*x^2+c*x^4)/(c^2*(b^2-4*a*c))-(2*a+b*x^2)*sqrt(a+b*x^2+c*x^4)/_
+   (c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                         +---------------+                 2
+--R                      3  |   4      2                  2c x  + b
+--R       (- 12a b c + 3b )\|c x  + b x  + a atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|c \|c x  + b x  + a
+--R     + 
+--R             2     2   4                3  2      2        2  +-+
+--R       ((8a c  - 2b c)x  + (20a b c - 6b )x  + 16a c - 6a b )\|c
+--R  /
+--R                          +---------------+
+--R           3     2 2  +-+ |   4      2
+--R     (16a c  - 4b c )\|c \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 585
+t0:=x^5/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          5
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 585
+r0:=1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(3/2)+x^2*_
+   (2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-b*sqrt(a+b*x^2+c*x^4)/_
+   (c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                   +---------------+                 2
+--R                2  |   4      2                  2c x  + b
+--R       (4a c - b )\|c x  + b x  + a atanh(-----------------------)
+--R                                                +---------------+
+--R                                            +-+ |   4      2
+--R                                          2\|c \|c x  + b x  + a
+--R     + 
+--R                    2  2         +-+
+--R       ((- 4a c + 2b )x  + 2a b)\|c
+--R  /
+--R                        +---------------+
+--R          2     2   +-+ |   4      2
+--R     (8a c  - 2b c)\|c \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 585
+t0:=x^3/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          3
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 585
+r0:=(2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                      2
+--R                 - b x  - 2a
+--R   (2)  -----------------------------
+--R                    +---------------+
+--R                 2  |   4      2
+--R        (4a c - b )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 585
+t0:=x/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 585
+r0:=(-b-2*c*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                      2
+--R                  2c x  + b
+--R   (2)  -----------------------------
+--R                    +---------------+
+--R                 2  |   4      2
+--R        (4a c - b )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 585
+t0:=1/(x*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R                            +---------------+
+--R            5      3        |   4      2
+--R        (c x  + b x  + a x)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 585
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(3/2)+_
+   (b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                     +---------------+                2
+--R                  2  |   4      2                  b x  + 2a
+--R       (- 4a c + b )\|c x  + b x  + a atanh(-----------------------)
+--R                                                  +---------------+
+--R                                              +-+ |   4      2
+--R                                            2\|a \|c x  + b x  + a
+--R     + 
+--R                2            2  +-+
+--R       (- 2b c x  + 4a c - 2b )\|a
+--R  /
+--R                        +---------------+
+--R        2        2  +-+ |   4      2
+--R     (8a c - 2a b )\|a \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 585
+t0:=1/(x^3*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                           1
+--R   (1)  --------------------------------------
+--R                             +---------------+
+--R            7      5      3  |   4      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 585
+r0:=3/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(5/2)+_
+   (b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^2*sqrt(a+b*x^2+c*x^4))-1/2*(3*b^2-_
+   8*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*(b^2-4*a*c)*x^2)
+--R 
+--R
+--R   (2)
+--R                         +---------------+                2
+--R                    3  2 |   4      2                  b x  + 2a
+--R       (12a b c - 3b )x \|c x  + b x  + a atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|a \|c x  + b x  + a
+--R     + 
+--R                2     2   4                  3  2     2        2  +-+
+--R       ((- 16a c  + 6b c)x  + (- 20a b c + 6b )x  - 8a c + 2a b )\|a
+--R  /
+--R                           +---------------+
+--R         3      2 2  2 +-+ |   4      2
+--R     (16a c - 4a b )x \|a \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 585
+t0:=1/(x^5*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                           1
+--R   (1)  --------------------------------------
+--R                             +---------------+
+--R            9      7      5  |   4      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 585
+r0:=-3/16*(5*b^2-4*a*c)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/_
+   a^(7/2)+(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^4*sqrt(a+b*x^2+c*x^4))-_
+   1/4*(5*b^2-12*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*(b^2-4*a*c)*x^4)+_
+   1/8*b*(15*b^2-52*a*c)*sqrt(a+b*x^2+c*x^4)/(a^3*(b^2-4*a*c)*x^2)
+--R 
+--R
+--R   (2)
+--R                                     +---------------+
+--R             2 2        2       4  4 |   4      2
+--R         (48a c  - 72a b c + 15b )x \|c x  + b x  + a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                    2      3   6         2 2         2       4  4
+--R           (104a b c  - 30b c)x  + (- 48a c  + 124a b c - 30b )x
+--R         + 
+--R               2           3  2      3      2 2
+--R           (40a b c - 10a b )x  - 16a c + 4a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                            +---------------+
+--R         4       3 2  4 +-+ |   4      2
+--R     (64a c - 16a b )x \|a \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 585
+t0:=x^6/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          6
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 585
+--r0:=x^3*(2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-b*x*sqrt(a+b*x^2+_
+--   c*x^4)/(c*(b^2-4*a*c))+(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*_
+--   sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+--   sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-_
+--   sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+--   sqrt(b^2-4*a*c)))/(c^(5/2)*(b^2-4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-_
+--   elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-_
+--   sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2-3*a*c)*_
+--   sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+--   sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*_
+--   (b^2-4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 107
+
+--S 108 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 108
+
+)clear all
+
+--S 109 of 585
+t0:=x^4/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          4
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 585
+--r0:=x*(2*a+b*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-1/2*b*_
+--   elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*_
+--   sqrt(a+b*x^2+c*x^4))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+--   sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--   (b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+--   sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+--   (c^(3/2)*(b^2-4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 110
+
+--S 111 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 111
+
+)clear all
+
+--S 112 of 585
+t0:=x^2/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          2
+--R                         x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 585
+--r0:=-x*(b+2*c*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-_
+--   elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+--   sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+--   sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c)*sqrt(a+b*x^2+_
+--   c*x^4))+elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/((b^2-4*a*c)*sqrt(2)*_
+--   sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 113
+
+--S 114 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 114
+
+)clear all
+
+--S 115 of 585
+t0:=1/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                         1
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 585
+--r0:=x*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-_
+--   1/2*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*_
+--   sqrt(a+b*x^2+c*x^4))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+--   sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+--   (b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+--   sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+--   (a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 116
+
+--S 117 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 117
+
+)clear all
+
+--S 118 of 585
+t0:=1/(x^2*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                           1
+--R   (1)  --------------------------------------
+--R                             +---------------+
+--R            6      4      2  |   4      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 585
+--r0:=(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x*sqrt(a+b*x^2+c*x^4))-_
+--   2*(b^2-3*a*c)*sqrt(a+b*x^2+c*x^4)/(a^2*(b^2-4*a*c)*x)+(b^2-3*a*c)*_
+--   elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+--   (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+--   sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(c)*_
+--   sqrt(a+b*x^2+c*x^4))-elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+--   sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*_
+--   a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-_
+--   4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-_
+--   4*a*c)))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 119
+
+--S 120 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 120
+
+)clear all
+
+--S 121 of 585
+t0:=x^4/sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 585
+r0:=-2/3*b*sqrt(b*x^2+c*x^4)/(c^2*x)+1/3*x*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                    +-----------+
+--R            2       |   4      2
+--R        (c x  - 2b)\|c x  + b x
+--R   (2)  -------------------------
+--R                     2
+--R                   3c x
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 585
+t0:=x^3/sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 585
+r0:=-1/2*b*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)+1/2*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                       2 +-+             +-----------+
+--R                      x \|c          +-+ |   4      2
+--R        - b atanh(--------------) + \|c \|c x  + b x
+--R                   +-----------+
+--R                   |   4      2
+--R                  \|c x  + b x
+--R   (2)  ----------------------------------------------
+--R                               +-+
+--R                            2c\|c
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 585
+t0:=x^2/sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 585
+r0:=sqrt(b*x^2+c*x^4)/(c*x)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (2)  --------------
+--R              c x
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 585
+t0:=x/sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 585
+r0:=atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/sqrt(c)
+--R 
+--R
+--R                   2 +-+
+--R                  x \|c
+--R        atanh(--------------)
+--R               +-----------+
+--R               |   4      2
+--R              \|c x  + b x
+--R   (2)  ---------------------
+--R                  +-+
+--R                 \|c
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 585
+t0:=1/sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 585
+r0:=-atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/sqrt(b)
+--R 
+--R
+--R                       +-+
+--R                     x\|b
+--R          atanh(--------------)
+--R                 +-----------+
+--R                 |   4      2
+--R                \|c x  + b x
+--R   (2)  - ---------------------
+--R                    +-+
+--R                   \|b
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 585
+t0:=1/(x*sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          +-----------+
+--R          |   4      2
+--R        x\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 585
+r0:=-sqrt(b*x^2+c*x^4)/(b*x^2)
+--R 
+--R
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R   (2)  - --------------
+--R                  2
+--R               b x
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 585
+t0:=1/(x^2*sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         2 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 585
+r0:=1/2*c*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-_
+   1/2*sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R                         +-+             +-----------+
+--R           3           x\|b          +-+ |   4      2
+--R        c x atanh(--------------) - \|b \|c x  + b x
+--R                   +-----------+
+--R                   |   4      2
+--R                  \|c x  + b x
+--R   (2)  ----------------------------------------------
+--R                               3 +-+
+--R                           2b x \|b
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 585
+t0:=1/(x^3*sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         3 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 585
+r0:=-1/3*sqrt(b*x^2+c*x^4)/(b*x^4)+2/3*c*sqrt(b*x^2+c*x^4)/(b^2*x^2)
+--R 
+--R
+--R                    +-----------+
+--R             2      |   4      2
+--R        (2c x  - b)\|c x  + b x
+--R   (2)  -------------------------
+--R                    2 4
+--R                  3b x
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 585
+t0:=1/(x^4*sqrt(2+2*a-2*(1+a)+b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         4 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 585
+r0:=-3/8*c^2*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)-_
+   1/4*sqrt(b*x^2+c*x^4)/(b*x^5)+3/8*c*sqrt(b*x^2+c*x^4)/(b^2*x^3)
+--R 
+--R
+--R                            +-+                         +-----------+
+--R            2 5           x\|b              2       +-+ |   4      2
+--R        - 3c x atanh(--------------) + (3c x  - 2b)\|b \|c x  + b x
+--R                      +-----------+
+--R                      |   4      2
+--R                     \|c x  + b x
+--R   (2)  -------------------------------------------------------------
+--R                                    2 5 +-+
+--R                                  8b x \|b
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 585
+t0:=x^4/sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 585
+--r0:=1/3*x*sqrt(a+c*x^4)/c+1/3*a^(5/4)*elliptic_f(asin((-c)^(1/4)*x/a^(1/4)),_
+--   -1)*sqrt((a+c*x^4)/a)/((-c)^(5/4)*sqrt(a+c*x^4))
+--E 149
+
+--S 150 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 150
+
+)clear all
+
+--S 151 of 585
+t0:=x^3/sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 585
+r0:=1/2*sqrt(a+c*x^4)/c
+--R 
+--R
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R   (2)  -----------
+--R             2c
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 585
+t0:=x^2/sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 585
+--r0:=a^(3/4)*elliptic_e(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/_
+--   ((-c)^(3/4)*sqrt(a+c*x^4))-a^(3/4)*elliptic_f(asin((-c)^(1/4)*_
+--   x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/((-c)^(3/4)*sqrt(a+c*x^4))
+--E 155
+
+--S 156 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 156
+
+)clear all
+
+--S 157 of 585
+t0:=x/sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 585
+r0:=1/2*atanh(x^2*sqrt(c)/sqrt(a+c*x^4))/sqrt(c)
+--R 
+--R
+--R                  2 +-+
+--R                 x \|c
+--R        atanh(-----------)
+--R               +--------+
+--R               |   4
+--R              \|c x  + a
+--R   (2)  ------------------
+--R                 +-+
+--R               2\|c
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 585
+t0:=1/sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 585
+--r0:=a^(1/4)*elliptic_f(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/_
+--   ((-c)^(1/4)*sqrt(a+c*x^4))
+--E 161
+
+--S 162 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 162
+
+)clear all
+
+--S 163 of 585
+t0:=1/(x*sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R          +--------+
+--R          |   4
+--R        x\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 585
+r0:=-1/2*atanh(sqrt(a+c*x^4)/sqrt(a))/sqrt(a)
+--R 
+--R
+--R                 +--------+
+--R                 |   4
+--R                \|c x  + a
+--R          atanh(-----------)
+--R                     +-+
+--R                    \|a
+--R   (2)  - ------------------
+--R                   +-+
+--R                 2\|a
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 585
+t0:=1/(x^2*sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         2 |   4
+--R        x \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 585
+--r0:=-sqrt(a+c*x^4)/(a*x)-(-c)^(1/4)*elliptic_e(asin((-c)^(1/4)*_
+--   x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/(a^(1/4)*sqrt(a+c*x^4))+(-c)^(1/4)*_
+--   elliptic_f(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/_
+--   (a^(1/4)*sqrt(a+c*x^4))
+--E 167
+
+--S 168 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 168
+
+)clear all
+
+--S 169 of 585
+t0:=1/(x^3*sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         3 |   4
+--R        x \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 585
+r0:=-1/2*sqrt(a+c*x^4)/(a*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   4
+--R          \|c x  + a
+--R   (2)  - -----------
+--R                 2
+--R             2a x
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 585
+t0:=1/(x^4*sqrt(a+(2+2*b-2*(1+b))*x^2+c*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         4 |   4
+--R        x \|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 585
+--r0:=-1/3*sqrt(a+c*x^4)/(a*x^3)+1/3*(-c)^(3/4)*_
+--   elliptic_f(asin((-c)^(1/4)*x/a^(1/4)),-1)*sqrt((a+c*x^4)/a)/(a^(3/4)*_
+--   sqrt(a+c*x^4))
+--E 173
+
+--S 174 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 174
+
+)clear all
+
+--S 175 of 585
+t0:=x^4/sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 585
+r0:=3/8*a^2*atanh(x*sqrt(b)/sqrt(a+b*x^2))/b^(5/2)-_
+   3/8*a*x*sqrt(a+b*x^2)/b^2+1/4*x^3*sqrt(a+b*x^2)/b
+--R 
+--R
+--R                      +-+                          +--------+
+--R          2         x\|b             3         +-+ |   2
+--R        3a atanh(-----------) + (2b x  - 3a x)\|b \|b x  + a
+--R                  +--------+
+--R                  |   2
+--R                 \|b x  + a
+--R   (2)  -----------------------------------------------------
+--R                                 2 +-+
+--R                               8b \|b
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 585
+t0:=x^3/sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 585
+r0:=-2/3*a*sqrt(a+b*x^2)/b^2+1/3*x^2*sqrt(a+b*x^2)/b
+--R 
+--R
+--R                    +--------+
+--R            2       |   2
+--R        (b x  - 2a)\|b x  + a
+--R   (2)  ----------------------
+--R                    2
+--R                  3b
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 585
+t0:=x^2/sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 585
+r0:=-1/2*a*atanh(x*sqrt(b)/sqrt(a+b*x^2))/b^(3/2)+1/2*x*sqrt(a+b*x^2)/b
+--R 
+--R
+--R                       +-+             +--------+
+--R                     x\|b          +-+ |   2
+--R        - a atanh(-----------) + x\|b \|b x  + a
+--R                   +--------+
+--R                   |   2
+--R                  \|b x  + a
+--R   (2)  -----------------------------------------
+--R                             +-+
+--R                          2b\|b
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 585
+t0:=x/sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 585
+r0:=sqrt(a+b*x^2)/b
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R   (2)  -----------
+--R             b
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 585
+t0:=1/sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 585
+r0:=atanh(x*sqrt(b)/sqrt(a+b*x^2))/sqrt(b)
+--R 
+--R
+--R                   +-+
+--R                 x\|b
+--R        atanh(-----------)
+--R               +--------+
+--R               |   2
+--R              \|b x  + a
+--R   (2)  ------------------
+--R                +-+
+--R               \|b
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 585
+t0:=1/(x*sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R          +--------+
+--R          |   2
+--R        x\|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 585
+r0:=-atanh(sqrt(a+b*x^2)/sqrt(a))/sqrt(a)
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R                \|b x  + a
+--R          atanh(-----------)
+--R                     +-+
+--R                    \|a
+--R   (2)  - ------------------
+--R                  +-+
+--R                 \|a
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 585
+t0:=1/(x^2*sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         2 |   2
+--R        x \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 585
+r0:=-sqrt(a+b*x^2)/(a*x)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R          \|b x  + a
+--R   (2)  - -----------
+--R              a x
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 585
+t0:=1/(x^3*sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         3 |   2
+--R        x \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 585
+r0:=1/2*b*atanh(sqrt(a+b*x^2)/sqrt(a))/a^(3/2)-1/2*sqrt(a+b*x^2)/(a*x^2)
+--R 
+--R
+--R                   +--------+
+--R                   |   2              +--------+
+--R           2      \|b x  + a      +-+ |   2
+--R        b x atanh(-----------) - \|a \|b x  + a
+--R                       +-+
+--R                      \|a
+--R   (2)  ----------------------------------------
+--R                            2 +-+
+--R                        2a x \|a
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 585
+t0:=1/(x^4*sqrt(a+b*x^2+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R           +--------+
+--R         4 |   2
+--R        x \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 585
+r0:=-1/3*sqrt(a+b*x^2)/(a*x^3)+2/3*b*sqrt(a+b*x^2)/(a^2*x)
+--R 
+--R
+--R                    +--------+
+--R             2      |   2
+--R        (2b x  - a)\|b x  + a
+--R   (2)  ----------------------
+--R                   2 3
+--R                 3a x
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 585
+t0:=x^4/sqrt(2+2*a-2*(1+a)+c*x^4)
+--R 
+--R
+--R            4
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 585
+r0:=1/3*x^5/sqrt(c*x^4)
+--R 
+--R
+--R            5
+--R           x
+--R   (2)  --------
+--R          +----+
+--R          |   4
+--R        3\|c x
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 585
+t0:=x^3/sqrt(2+2*a-2*(1+a)+c*x^4)
+--R 
+--R
+--R            3
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 585
+r0:=1/2*x^4/sqrt(c*x^4)
+--R 
+--R
+--R            4
+--R           x
+--R   (2)  --------
+--R          +----+
+--R          |   4
+--R        2\|c x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 585
+t0:=x^2/sqrt(2+2*a-2*(1+a)+c*x^4)
+--R 
+--R
+--R            2
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 585
+r0:=x^3/sqrt(c*x^4)
+--R 
+--R
+--R            3
+--R           x
+--R   (2)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 585
+t0:=x/sqrt(2+2*a-2*(1+a)+c*x^4)
+--R 
+--R
+--R           x
+--R   (1)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 585
+r0:=x^2*log(x)/sqrt(c*x^4)
+--R 
+--R
+--R         2
+--R        x log(x)
+--R   (2)  --------
+--R          +----+
+--R          |   4
+--R         \|c x
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 585
+t0:=1/sqrt(2+2*a-2*(1+a)+c*x^4)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R         +----+
+--R         |   4
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 585
+r0:=-x/sqrt(c*x^4)
+--R 
+--R
+--R             x
+--R   (2)  - -------
+--R           +----+
+--R           |   4
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 585
+t0:=1/(x*sqrt(2+2*a-2*(1+a)+c*x^4))
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R          +----+
+--R          |   4
+--R        x\|c x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 585
+r0:=(-1/2)/sqrt(c*x^4)
+--R 
+--R
+--R              1
+--R   (2)  - --------
+--R            +----+
+--R            |   4
+--R          2\|c x
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 585
+t0:=1/(x^2*sqrt(2+2*a-2*(1+a)+c*x^4))
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R           +----+
+--R         2 |   4
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 585
+r0:=(-1/3)/(x*sqrt(c*x^4))
+--R 
+--R
+--R              1
+--R   (2)  - ---------
+--R             +----+
+--R             |   4
+--R          3x\|c x
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 585
+t0:=1/(x^3*sqrt(2+2*a-2*(1+a)+c*x^4))
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R           +----+
+--R         3 |   4
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 585
+r0:=(-1/4)/(x^2*sqrt(c*x^4))
+--R 
+--R
+--R               1
+--R   (2)  - ----------
+--R              +----+
+--R            2 |   4
+--R          4x \|c x
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 585
+t0:=1/(x^4*sqrt(2+2*a-2*(1+a)+c*x^4))
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R           +----+
+--R         4 |   4
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 585
+r0:=(-1/5)/(x^3*sqrt(c*x^4))
+--R 
+--R
+--R               1
+--R   (2)  - ----------
+--R              +----+
+--R            3 |   4
+--R          5x \|c x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 585
+t0:=x^4/sqrt(a+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R          4
+--R         x
+--R   (1)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 585
+r0:=1/5*x^5/sqrt(a)
+--R 
+--R
+--R           5
+--R          x
+--R   (2)  -----
+--R          +-+
+--R        5\|a
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 585
+t0:=x^3/sqrt(a+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R          3
+--R         x
+--R   (1)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 585
+r0:=1/4*x^4/sqrt(a)
+--R 
+--R
+--R           4
+--R          x
+--R   (2)  -----
+--R          +-+
+--R        4\|a
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 585
+t0:=x^2/sqrt(a+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R          2
+--R         x
+--R   (1)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 585
+r0:=1/3*x^3/sqrt(a)
+--R 
+--R
+--R           3
+--R          x
+--R   (2)  -----
+--R          +-+
+--R        3\|a
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 585
+t0:=x/sqrt(a+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R          x
+--R   (1)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 585
+r0:=1/2*x^2/sqrt(a)
+--R 
+--R
+--R           2
+--R          x
+--R   (2)  -----
+--R          +-+
+--R        2\|a
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 585
+t0:=1/sqrt(a+(2+2*c-2*(1+c))*x^4)
+--R 
+--R
+--R          1
+--R   (1)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 585
+r0:=x/sqrt(a)
+--R 
+--R
+--R          x
+--R   (2)  ----
+--R         +-+
+--R        \|a
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 585
+t0:=1/(x*sqrt(a+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R          1
+--R   (1)  -----
+--R          +-+
+--R        x\|a
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 585
+r0:=log(x)/sqrt(a)
+--R 
+--R
+--R        log(x)
+--R   (2)  ------
+--R          +-+
+--R         \|a
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 585
+t0:=1/(x^2*sqrt(a+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         2 +-+
+--R        x \|a
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 585
+r0:=(-1)/(x*sqrt(a))
+--R 
+--R
+--R            1
+--R   (2)  - -----
+--R            +-+
+--R          x\|a
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 585
+t0:=1/(x^3*sqrt(a+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         3 +-+
+--R        x \|a
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 585
+r0:=(-1/2)/(x^2*sqrt(a))
+--R 
+--R
+--R             1
+--R   (2)  - -------
+--R            2 +-+
+--R          2x \|a
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 585
+t0:=1/(x^4*sqrt(a+(2+2*c-2*(1+c))*x^4))
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         4 +-+
+--R        x \|a
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 585
+r0:=(-1/3)/(x^3*sqrt(a))
+--R 
+--R
+--R             1
+--R   (2)  - -------
+--R            3 +-+
+--R          3x \|a
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 585
+t0:=1/sqrt(3-2*x^2-x^4)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   4     2
+--R        \|- x  - 2x  + 3
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 585
+--r0:=elliptic_f(asin(x),-1/3)/sqrt(3)
+--E 257
+
+--S 258 of 585
+--d0:=normalize(t0-D(r0,x))
+--E 258
+
+)clear all
+
+--S 259 of 585
+t0:=x^(7/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R            7      5      3  +-+
+--R   (1)  (c x  + b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 585
+r0:=2/9*a*x^(9/2)+2/13*b*x^(13/2)+2/17*c*x^(17/2)
+--R 
+--R
+--R               8         6         4  +-+
+--R        (234c x  + 306b x  + 442a x )\|x
+--R   (2)  ---------------------------------
+--R                       1989
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 585
+t0:=x^(5/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R            6      4      2  +-+
+--R   (1)  (c x  + b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 585
+r0:=2/7*a*x^(7/2)+2/11*b*x^(11/2)+2/15*c*x^(15/2)
+--R 
+--R
+--R               7         5         3  +-+
+--R        (154c x  + 210b x  + 330a x )\|x
+--R   (2)  ---------------------------------
+--R                       1155
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 585
+t0:=x^(3/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R            5      3        +-+
+--R   (1)  (c x  + b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 585
+r0:=2/5*a*x^(5/2)+2/9*b*x^(9/2)+2/13*c*x^(13/2)
+--R 
+--R
+--R              6         4         2  +-+
+--R        (90c x  + 130b x  + 234a x )\|x
+--R   (2)  --------------------------------
+--R                       585
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 585
+t0:=x^(1/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R            4      2      +-+
+--R   (1)  (c x  + b x  + a)\|x
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 585
+r0:=2/3*a*x^(3/2)+2/7*b*x^(7/2)+2/11*c*x^(11/2)
+--R 
+--R
+--R              5        3           +-+
+--R        (42c x  + 66b x  + 154a x)\|x
+--R   (2)  ------------------------------
+--R                      231
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 585
+t0:=(a+b*x^2+c*x^4)/x^(1/2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R               +-+
+--R              \|x
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 585
+r0:=2/5*b*x^(5/2)+2/9*c*x^(9/2)+2*a*sqrt(x)
+--R 
+--R
+--R              4        2        +-+
+--R        (10c x  + 18b x  + 90a)\|x
+--R   (2)  ---------------------------
+--R                     45
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 585
+t0:=(a+b*x^2+c*x^4)/x^(3/2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R               +-+
+--R             x\|x
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 585
+r0:=2/3*b*x^(3/2)+2/7*c*x^(7/2)-2*a/sqrt(x)
+--R 
+--R
+--R            4        2
+--R        6c x  + 14b x  - 42a
+--R   (2)  --------------------
+--R                  +-+
+--R               21\|x
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 585
+t0:=(a+b*x^2+c*x^4)/x^(5/2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R              2 +-+
+--R             x \|x
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 585
+r0:=-2/3*a/x^(3/2)+2/5*c*x^(5/2)+2*b*sqrt(x)
+--R 
+--R
+--R            4        2
+--R        6c x  + 30b x  - 10a
+--R   (2)  --------------------
+--R                   +-+
+--R               15x\|x
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 585
+t0:=(a+b*x^2+c*x^4)/x^(7/2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R              3 +-+
+--R             x \|x
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 585
+r0:=-2/5*a/x^(5/2)+2/3*c*x^(3/2)-2*b/sqrt(x)
+--R 
+--R
+--R             4        2
+--R        10c x  - 30b x  - 6a
+--R   (2)  --------------------
+--R                 2 +-+
+--R              15x \|x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 585
+t0:=x^(7/2)*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 11         9            2  7         5    2 3  +-+
+--R   (1)  (c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 585
+r0:=2/9*a^2*x^(9/2)+4/13*a*b*x^(13/2)+2/17*(b^2+2*a*c)*x^(17/2)+_
+   4/21*b*c*x^(21/2)+2/25*c^2*x^(25/2)
+--R 
+--R
+--R   (2)
+--R               2 12             10                     2  8              6
+--R         27846c x   + 66300b c x   + (81900a c + 40950b )x  + 107100a b x
+--R       + 
+--R               2 4
+--R         77350a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     348075
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 585
+t0:=x^(5/2)*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 10         8            2  6         4    2 2  +-+
+--R   (1)  (c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 585
+r0:=2/7*a^2*x^(7/2)+4/11*a*b*x^(11/2)+2/15*(b^2+2*a*c)*x^(15/2)+_
+   4/19*b*c*x^(19/2)+2/23*c^2*x^(23/2)
+--R 
+--R
+--R   (2)
+--R               2 11              9                      2  7              5
+--R         43890c x   + 106260b c x  + (134596a c + 67298b )x  + 183540a b x
+--R       + 
+--R                2 3
+--R         144210a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     504735
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 585
+t0:=x^(3/2)*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 9         7            2  5         3    2   +-+
+--R   (1)  (c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 585
+r0:=2/5*a^2*x^(5/2)+4/9*a*b*x^(9/2)+2/13*(b^2+2*a*c)*x^(13/2)+_
+   4/17*b*c*x^(17/2)+2/21*c^2*x^(21/2)
+--R 
+--R
+--R   (2)
+--R              2 10             8                     2  6             4
+--R         6630c x   + 16380b c x  + (21420a c + 10710b )x  + 30940a b x
+--R       + 
+--R               2 2
+--R         27846a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     69615
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 585
+t0:=x^(1/2)*(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 8         6            2  4         2    2  +-+
+--R   (1)  (c x  + 2b c x  + (2a c + b )x  + 2a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 585
+r0:=2/3*a^2*x^(3/2)+4/7*a*b*x^(7/2)+2/11*(b^2+2*a*c)*x^(11/2)+_
+   4/15*b*c*x^(15/2)+2/19*c^2*x^(19/2)
+--R 
+--R
+--R   (2)
+--R         2 9            7                   2  5             3         2   +-+
+--R   (2310c x  + 5852b c x  + (7980a c + 3990b )x  + 12540a b x  + 14630a x)\|x
+--R   ---------------------------------------------------------------------------
+--R                                      21945
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 585
+t0:=(a+b*x^2+c*x^4)^2/x^(1/2)
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                              +-+
+--R                             \|x
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 585
+r0:=4/5*a*b*x^(5/2)+2/9*(b^2+2*a*c)*x^(9/2)+4/13*b*c*x^(13/2)+_
+   2/17*c^2*x^(17/2)+2*a^2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R         2 8            6                   2  4            2         2  +-+
+--R   (1170c x  + 3060b c x  + (4420a c + 2210b )x  + 7956a b x  + 19890a )\|x
+--R   -------------------------------------------------------------------------
+--R                                      9945
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 585
+t0:=(a+b*x^2+c*x^4)^2/x^(3/2)
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                              +-+
+--R                            x\|x
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 585
+r0:=4/3*a*b*x^(3/2)+2/7*(b^2+2*a*c)*x^(7/2)+4/11*b*c*x^(11/2)+_
+   2/15*c^2*x^(15/2)-2*a^2/sqrt(x)
+--R 
+--R
+--R            2 8           6                 2  4            2        2
+--R        154c x  + 420b c x  + (660a c + 330b )x  + 1540a b x  - 2310a
+--R   (2)  --------------------------------------------------------------
+--R                                        +-+
+--R                                   1155\|x
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 585
+t0:=(a+b*x^2+c*x^4)^2/x^(5/2)
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                             2 +-+
+--R                            x \|x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 585
+r0:=-2/3*a^2/x^(3/2)+2/5*(b^2+2*a*c)*x^(5/2)+4/9*b*c*x^(9/2)+_
+   2/13*c^2*x^(13/2)+4*a*b*sqrt(x)
+--R 
+--R
+--R           2 8           6                 2  4            2       2
+--R        90c x  + 260b c x  + (468a c + 234b )x  + 2340a b x  - 390a
+--R   (2)  ------------------------------------------------------------
+--R                                       +-+
+--R                                  585x\|x
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 585
+t0:=(a+b*x^2+c*x^4)^2/x^(7/2)
+--R 
+--R
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R   (1)  ---------------------------------------------
+--R                             3 +-+
+--R                            x \|x
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 585
+r0:=-2/5*a^2/x^(5/2)+2/3*(b^2+2*a*c)*x^(3/2)+4/7*b*c*x^(7/2)+_
+   2/11*c^2*x^(11/2)-4*a*b/sqrt(x)
+--R 
+--R
+--R            2 8           6                  2  4            2       2
+--R        210c x  + 660b c x  + (1540a c + 770b )x  - 4620a b x  - 462a
+--R   (2)  --------------------------------------------------------------
+--R                                       2 +-+
+--R                                  1155x \|x
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 585
+t0:=x^(7/2)*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3 15       2 13        2     2   11              3  9      2        2  7
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   5    3 3
+--R       3a b x  + a x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 585
+r0:=2/9*a^3*x^(9/2)+6/13*a^2*b*x^(13/2)+6/17*a*(b^2+a*c)*x^(17/2)+_
+   2/21*b*(b^2+6*a*c)*x^(21/2)+6/25*c*(b^2+a*c)*x^(25/2)+_
+   6/29*b*c^2*x^(29/2)+2/33*c^3*x^(33/2)
+--R 
+--R
+--R   (2)
+--R                 3 16              2 14               2            2   12
+--R         6729450c x   + 22972950b c x   + (26648622a c  + 26648622b c)x
+--R       + 
+--R                                   3  10             2               2  8
+--R         (63449100a b c + 10574850b )x   + (39189150a c + 39189150a b )x
+--R       + 
+--R                  2   6            3 4
+--R         51247350a b x  + 24674650a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     111035925
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 585
+t0:=x^(5/2)*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3 14       2 12        2     2   10              3  8      2        2  6
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   4    3 2
+--R       3a b x  + a x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 585
+r0:=2/7*a^3*x^(7/2)+6/11*a^2*b*x^(11/2)+2/5*a*(b^2+a*c)*x^(15/2)+_
+   2/19*b*(b^2+6*a*c)*x^(19/2)+6/23*c*(b^2+a*c)*x^(23/2)+_
+   2/9*b*c^2*x^(27/2)+2/31*c^3*x^(31/2)
+--R 
+--R
+--R   (2)
+--R                 3 15              2 13               2            2   11
+--R         3028410c x   + 10431190b c x   + (12245310a c  + 12245310b c)x
+--R       + 
+--R                                  3  9             2               2  7
+--R         (29646540a b c + 4941090b )x  + (18776142a c + 18776142a b )x
+--R       + 
+--R                  2   5            3 3
+--R         25603830a b x  + 13411530a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     46940355
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 585
+t0:=x^(3/2)*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3 13       2 11        2     2   9              3  7      2        2  5
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   3    3
+--R       3a b x  + a x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 585
+r0:=2/5*a^3*x^(5/2)+2/3*a^2*b*x^(9/2)+6/13*a*(b^2+a*c)*x^(13/2)+_
+   2/17*b*(b^2+6*a*c)*x^(17/2)+2/7*c*(b^2+a*c)*x^(21/2)+_
+   6/25*b*c^2*x^(25/2)+2/29*c^3*x^(29/2)
+--R 
+--R
+--R   (2)
+--R                3 14            2 12             2          2   10
+--R         232050c x   + 807534b c x   + (961350a c  + 961350b c)x
+--R       + 
+--R                                3  8            2              2  6
+--R         (2375100a b c + 395850b )x  + (1552950a c + 1552950a b )x
+--R       + 
+--R                 2   4           3 2
+--R         2243150a b x  + 1345890a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     3364725
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 585
+t0:=x^(1/2)*(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 585
+r0:=2/3*a^3*x^(3/2)+6/7*a^2*b*x^(7/2)+6/11*a*(b^2+a*c)*x^(11/2)+_
+   2/15*b*(b^2+6*a*c)*x^(15/2)+6/19*c*(b^2+a*c)*x^(19/2)+_
+   6/23*b*c^2*x^(23/2)+2/27*c^3*x^(27/2)
+--R 
+--R
+--R   (2)
+--R                3 13             2 11              2           2   9
+--R         336490c x   + 1185030b c x   + (1434510a c  + 1434510b c)x
+--R       + 
+--R                                3  7            2              2  5
+--R         (3634092a b c + 605682b )x  + (2477790a c + 2477790a b )x
+--R       + 
+--R                 2   3           3
+--R         3893670a b x  + 3028410a x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     4542615
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 585
+t0:=(a+b*x^2+c*x^4)^3/x^(1/2)
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 585
+r0:=6/5*a^2*b*x^(5/2)+2/3*a*(b^2+a*c)*x^(9/2)+2/13*b*(b^2+6*a*c)*x^(13/2)+_
+   6/17*c*(b^2+a*c)*x^(17/2)+2/7*b*c^2*x^(21/2)+2/25*c^3*x^(25/2)+2*a^3*sqrt(x)
+--R 
+--R
+--R   (2)
+--R              3 12           2 10            2         2   8
+--R         9282c x   + 33150b c x   + (40950a c  + 40950b c)x
+--R       + 
+--R                              3  6          2            2  4          2   2
+--R         (107100a b c + 17850b )x  + (77350a c + 77350a b )x  + 139230a b x
+--R       + 
+--R                3
+--R         232050a
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     116025
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 585
+t0:=(a+b*x^2+c*x^4)^3/x^(3/2)
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R       +-+
+--R     x\|x
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 585
+r0:=2*a^2*b*x^(3/2)+6/7*a*(b^2+a*c)*x^(7/2)+2/11*b*(b^2+6*a*c)*x^(11/2)+_
+   2/5*c*(b^2+a*c)*x^(15/2)+6/19*b*c^2*x^(19/2)+2/23*c^3*x^(23/2)-2*a^3/sqrt(x)
+--R 
+--R
+--R   (2)
+--R             3 12           2 10            2         2   8
+--R       14630c x   + 53130b c x   + (67298a c  + 67298b c)x
+--R     + 
+--R                            3  6           2             2  4          2   2
+--R       (183540a b c + 30590b )x  + (144210a c + 144210a b )x  + 336490a b x
+--R     + 
+--R                3
+--R       - 336490a
+--R  /
+--R            +-+
+--R     168245\|x
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+)clear all
+
+--S 325 of 585
+t0:=(a+b*x^2+c*x^4)^3/x^(5/2)
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      2 +-+
+--R     x \|x
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 585
+r0:=-2/3*a^3/x^(3/2)+6/5*a*(b^2+a*c)*x^(5/2)+2/9*b*(b^2+6*a*c)*x^(9/2)+_
+   6/13*c*(b^2+a*c)*x^(13/2)+6/17*b*c^2*x^(17/2)+2/21*c^3*x^(21/2)+_
+   6*a^2*b*sqrt(x)
+--R 
+--R
+--R   (2)
+--R            3 12           2 10            2         2   8
+--R       6630c x   + 24570b c x   + (32130a c  + 32130b c)x
+--R     + 
+--R                           3  6          2            2  4          2   2
+--R       (92820a b c + 15470b )x  + (83538a c + 83538a b )x  + 417690a b x
+--R     + 
+--R               3
+--R       - 46410a
+--R  /
+--R            +-+
+--R     69615x\|x
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 585
+t0:=(a+b*x^2+c*x^4)^3/x^(7/2)
+--R 
+--R
+--R   (1)
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R  /
+--R      3 +-+
+--R     x \|x
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 585
+r0:=-2/5*a^3/x^(5/2)+2*a*(b^2+a*c)*x^(3/2)+2/7*b*(b^2+6*a*c)*x^(7/2)+_
+   6/11*c*(b^2+a*c)*x^(11/2)+2/5*b*c^2*x^(15/2)+2/19*c^3*x^(19/2)-_
+   6*a^2*b/sqrt(x)
+--R 
+--R
+--R   (2)
+--R           3 12          2 10           2        2   8                      3  6
+--R       770c x   + 2926b c x   + (3990a c  + 3990b c)x  + (12540a b c + 2090b )x
+--R     + 
+--R              2            2  4         2   2        3
+--R       (14630a c + 14630a b )x  - 43890a b x  - 2926a
+--R  /
+--R          2 +-+
+--R     7315x \|x
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 585
+t0:=x^(9/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R              4 +-+
+--R             x \|x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 585
+r0:=2/3*x^(3/2)/c-atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   c^(7/4)*(-b+sqrt(b^2-4*a*c))^(1/4))+atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*c^(7/4)*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R             +-----------+               | +-----------+
+--R             |          2             2 4| |          2
+--R         (3b\|- 4a c + b   - 6a c + 3b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                         +--------------------+
+--R             +-----------+               |   +-----------+
+--R             |          2             2 4|   |          2
+--R         (3b\|- 4a c + b   + 6a c - 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                           +------------------+
+--R               +-----------+               | +-----------+
+--R               |          2             2 4| |          2
+--R         (- 3b\|- 4a c + b   + 6a c - 3b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+
+--R               +-----------+               |   +-----------+
+--R               |          2             2 4|   |          2
+--R         (- 3b\|- 4a c + b   - 6a c + 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                                     +--------------------+ +------------------+
+--R              +-----------+          |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4+-+3 +-+4|   |          2      4| |          2
+--R     2x \|2  \|- 4a c + b  \|c  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                                  +--------------------+ +------------------+
+--R              +-----------+       |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R     3c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 585
+t0:=x^(7/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R              3 +-+
+--R             x \|x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 585
+r0:=atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b-sqrt(b^2-4*a*c))^(3/4))+_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))+atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(5/4)*(-b+sqrt(b^2-4*a*c))^(3/4))+atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(5/4)*(-b+sqrt(b^2-4*a*c))^(3/4))+2*sqrt(x)/c
+--R 
+--R
+--R   (2)
+--R                                       +------------------+3
+--R            +-----------+              | +-----------+
+--R            |          2            2 4| |          2
+--R         (b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                       +--------------------+3
+--R            +-----------+              |   +-----------+
+--R            |          2            2 4|   |          2
+--R         (b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                       +------------------+3
+--R            +-----------+              | +-----------+
+--R            |          2            2 4| |          2
+--R         (b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                       +--------------------+3
+--R            +-----------+              |   +-----------+
+--R            |          2            2 4|   |          2
+--R         (b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                                 +--------------------+3  +------------------+3
+--R           +-----------+         |   +-----------+        | +-----------+
+--R      4+-+ |          2 4+-+ +-+4|   |          2        4| |          2
+--R     2\|2 \|- 4a c + b  \|c \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R                             +--------------------+3  +------------------+3
+--R           +-----------+     |   +-----------+        | +-----------+
+--R      4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 585
+t0:=x^(5/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R              2 +-+
+--R             x \|x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 585
+r0:=-atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (-b-sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))+_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(-b-_
+   sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))+_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(-b+_
+   sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))-_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(-b+_
+   sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +--------------------+3
+--R        |   +-----------+                  4+-+4+-+ +-+
+--R       4|   |          2                   \|2 \|c \|x
+--R       \|- \|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R       - \|\|- 4a c + b   - b  atanh(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R       - \|- \|- 4a c + b   - b  atan(-----------------------)
+--R                                       +--------------------+
+--R                                       |   +-----------+
+--R                                      4|   |          2
+--R                                      \|- \|- 4a c + b   - b
+--R     + 
+--R        +------------------+3
+--R        | +-----------+                4+-+4+-+ +-+
+--R       4| |          2                 \|2 \|c \|x
+--R       \|\|- 4a c + b   - b  atan(---------------------)
+--R                                   +------------------+
+--R                                   | +-----------+
+--R                                  4| |          2
+--R                                  \|\|- 4a c + b   - b
+--R  /
+--R           +-----------+
+--R     4+-+3 |          2 4+-+3
+--R     \|2  \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 585
+t0:=x^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               +-+
+--R             x\|x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 585
+r0:=atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(-b-_
+   sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))+_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(-b-_
+   sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))-_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(-b+_
+   sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))-_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(-b+_
+   sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +--------------------+
+--R        |   +-----------+                 4+-+4+-+ +-+
+--R       4|   |          2                  \|2 \|c \|x
+--R       \|- \|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R       - \|\|- 4a c + b   - b atanh(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                    4| |          2
+--R                                    \|\|- 4a c + b   - b
+--R     + 
+--R        +--------------------+
+--R        |   +-----------+                4+-+4+-+ +-+
+--R       4|   |          2                 \|2 \|c \|x
+--R       \|- \|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+
+--R          | +-----------+               4+-+4+-+ +-+
+--R         4| |          2                \|2 \|c \|x
+--R       - \|\|- 4a c + b   - b atan(---------------------)
+--R                                    +------------------+
+--R                                    | +-----------+
+--R                                   4| |          2
+--R                                   \|\|- 4a c + b   - b
+--R  /
+--R          +-----------+
+--R     4+-+ |          2 4+-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 585
+t0:=x^(1/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               +-+
+--R              \|x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 585
+r0:=-2^(1/4)*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))/((-b-sqrt(b^2-4*a*c))^(1/4)*sqrt(b^2-4*a*c))+2^(1/4)*_
+   c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))/_
+   ((-b-sqrt(b^2-4*a*c))^(1/4)*sqrt(b^2-4*a*c))+2^(1/4)*c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))/(sqrt(b^2-_
+   4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))-2^(1/4)*c^(1/4)*atanh(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))/(sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                +------------------+
+--R                | +-----------+                 4+-+4+-+ +-+
+--R       4+-+4+-+4| |          2                  \|2 \|c \|x
+--R       \|2 \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                  +--------------------+
+--R                  |   +-----------+                4+-+4+-+ +-+
+--R         4+-+4+-+4|   |          2                 \|2 \|c \|x
+--R       - \|2 \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                               +------------------+
+--R                                               | +-----------+
+--R                                              4| |          2
+--R                                              \|\|- 4a c + b   - b
+--R     + 
+--R                  +------------------+
+--R                  | +-----------+                4+-+4+-+ +-+
+--R         4+-+4+-+4| |          2                 \|2 \|c \|x
+--R       - \|2 \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                +--------------------+
+--R                |   +-----------+               4+-+4+-+ +-+
+--R       4+-+4+-+4|   |          2                \|2 \|c \|x
+--R       \|2 \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                            +------------------+
+--R                                            | +-----------+
+--R                                           4| |          2
+--R                                           \|\|- 4a c + b   - b
+--R  /
+--R                    +--------------------+ +------------------+
+--R      +-----------+ |   +-----------+      | +-----------+
+--R      |          2 4|   |          2      4| |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 585
+t0:=1/(x^(1/2)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R            4      2      +-+
+--R        (c x  + b x  + a)\|x
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 585
+r0:=2^(3/4)*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))/((-b-sqrt(b^2-4*a*c))^(3/4)*sqrt(b^2-4*a*c))+2^(3/4)*_
+   c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))/_
+   ((-b-sqrt(b^2-4*a*c))^(3/4)*sqrt(b^2-4*a*c))-2^(3/4)*c^(3/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))/_
+   (sqrt(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))-2^(3/4)*c^(3/4)*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))/_
+   (sqrt(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                    +------------------+3
+--R                    | +-----------+                  4+-+4+-+ +-+
+--R       4+-+3 4+-+3 4| |          2                   \|2 \|c \|x
+--R       \|2   \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                                +--------------------+
+--R                                                |   +-----------+
+--R                                               4|   |          2
+--R                                               \|- \|- 4a c + b   - b
+--R     + 
+--R                      +--------------------+3
+--R                      |   +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4+-+3 4|   |          2                  \|2 \|c \|x
+--R       - \|2   \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                                    +------------------+
+--R                                                    | +-----------+
+--R                                                   4| |          2
+--R                                                   \|\|- 4a c + b   - b
+--R     + 
+--R                    +------------------+3
+--R                    | +-----------+                 4+-+4+-+ +-+
+--R       4+-+3 4+-+3 4| |          2                  \|2 \|c \|x
+--R       \|2   \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                               +--------------------+
+--R                                               |   +-----------+
+--R                                              4|   |          2
+--R                                              \|- \|- 4a c + b   - b
+--R     + 
+--R                      +--------------------+3
+--R                      |   +-----------+                4+-+4+-+ +-+
+--R         4+-+3 4+-+3 4|   |          2                 \|2 \|c \|x
+--R       - \|2   \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                                   +------------------+
+--R                                                   | +-----------+
+--R                                                  4| |          2
+--R                                                  \|\|- 4a c + b   - b
+--R  /
+--R                    +--------------------+3  +------------------+3
+--R      +-----------+ |   +-----------+        | +-----------+
+--R      |          2 4|   |          2        4| |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 585
+t0:=1/(x^(3/2)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R            5      3        +-+
+--R        (c x  + b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 585
+r0:=-c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (1-b/sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b-sqrt(b^2-4*a*c))^(1/4))+c^(1/4)*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (1-b/sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b-sqrt(b^2-4*a*c))^(1/4))-c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/_
+   sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b+sqrt(b^2-4*a*c))^(1/4))+c^(1/4)*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/_
+   sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b+sqrt(b^2-4*a*c))^(1/4))+(-2)/(a*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                                      +------------------+
+--R           +-----------+              | +-----------+
+--R           |          2      4+-+ +-+4| |          2
+--R         (\|- 4a c + b   - b)\|c \|x \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                      +--------------------+
+--R           +-----------+              |   +-----------+
+--R           |          2      4+-+ +-+4|   |          2
+--R         (\|- 4a c + b   + b)\|c \|x \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                        +------------------+
+--R             +-----------+              | +-----------+
+--R             |          2      4+-+ +-+4| |          2
+--R         (- \|- 4a c + b   + b)\|c \|x \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                        +--------------------+
+--R             +-----------+              |   +-----------+
+--R             |          2      4+-+ +-+4|   |          2
+--R         (- \|- 4a c + b   - b)\|c \|x \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R       - 2\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       4+-+3 |          2  +-+4|   |          2      4| |          2
+--R     a \|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 585
+t0:=1/(x^(5/2)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R            6      4      2  +-+
+--R        (c x  + b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 585
+r0:=(-2/3)/(a*x^(3/2))+c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))+c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))+c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))+c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                            +------------------+3
+--R             +-----------+                  | +-----------+
+--R             |          2         4+-+3 +-+4| |          2
+--R         (3x\|- 4a c + b   - 3b x)\|c  \|x \|\|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+ +-+
+--R                     \|2 \|c \|x
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                            +--------------------+3
+--R             +-----------+                  |   +-----------+
+--R             |          2         4+-+3 +-+4|   |          2
+--R         (3x\|- 4a c + b   + 3b x)\|c  \|x \|- \|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                            +------------------+3
+--R             +-----------+                  | +-----------+
+--R             |          2         4+-+3 +-+4| |          2
+--R         (3x\|- 4a c + b   - 3b x)\|c  \|x \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                            +--------------------+3
+--R             +-----------+                  |   +-----------+
+--R             |          2         4+-+3 +-+4|   |          2
+--R         (3x\|- 4a c + b   + 3b x)\|c  \|x \|- \|- 4a c + b   - b
+--R      *
+--R                   4+-+4+-+ +-+
+--R                   \|2 \|c \|x
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R       - 2\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2  +-+4|   |          2        4| |          2
+--R     3a x\|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 585
+t0:=1/(x^(7/2)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R            7      5      3  +-+
+--R        (c x  + b x  + a x )\|x
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 585
+r0:=(-2/5)/(a*x^(5/2))+c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a^2*(-b-sqrt(b^2-4*a*c))^(1/4))-c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a^2*(-b-sqrt(b^2-4*a*c))^(1/4))+c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a^2*(-b+sqrt(b^2-4*a*c))^(1/4))-c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a^2*(-b+sqrt(b^2-4*a*c))^(1/4))+2*b/(a^2*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                  +-----------+
+--R                2 |          2                 2  2 4+-+ +-+
+--R         (- 5b x \|- 4a c + b   + (- 10a c + 5b )x )\|c \|x
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                  +-----------+
+--R                2 |          2               2  2 4+-+ +-+
+--R         (- 5b x \|- 4a c + b   + (10a c - 5b )x )\|c \|x
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                                         +------------------+
+--R                +-----------+                            | +-----------+
+--R              2 |          2               2  2 4+-+ +-+4| |          2
+--R         (5b x \|- 4a c + b   + (10a c - 5b )x )\|c \|x \|\|- 4a c + b   - b
+--R      *
+--R                    4+-+4+-+ +-+
+--R                    \|2 \|c \|x
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                +-----------+
+--R              2 |          2                 2  2 4+-+ +-+
+--R         (5b x \|- 4a c + b   + (- 10a c + 5b )x )\|c \|x
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                                          +--------------------+
+--R                            +-----------+ |   +-----------+
+--R               2      4+-+3 |          2 4|   |          2
+--R         (10b x  - 2a)\|2  \|- 4a c + b  \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R                                   +--------------------+ +------------------+
+--R                 +-----------+     |   +-----------+      | +-----------+
+--R       2 2 4+-+3 |          2  +-+4|   |          2      4| |          2
+--R     5a x  \|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 585
+t0:=x^(13/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             6 +-+
+--R                            x \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 585
+r0:=-1/2*b*x^(3/2)/(c*(b^2-4*a*c))+1/2*x^(7/2)*(2*a+b*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/4*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(3*b^2-14*a*c+b*(3*b^2-20*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*c^(7/4)*(b^2-4*a*c)*(-b-sqrt(b^2-4*a*c))^(1/4))-1/4*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(3*b^2-_
+   14*a*c+b*(3*b^2-20*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*(b^2-4*a*c)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))+1/4*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(3*b^2-14*a*c+(-3*b^3+20*a*b*c)/sqrt(b^2-_
+   4*a*c))/(2^(3/4)*c^(7/4)*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))-_
+   1/4*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(3*b^2-_
+   14*a*c+(-3*b^3+20*a*b*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*(b^2-_
+   4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                      2     2   4                  3  2      2        2
+--R             ((- 14a c  + 3b c)x  + (- 14a b c + 3b )x  - 14a c + 3a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   4           2      4  2      2          3
+--R           (- 20a b c  + 3b c)x  + (- 20a b c + 3b )x  - 20a b c + 3a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                      2     2   4                  3  2      2        2
+--R             ((- 14a c  + 3b c)x  + (- 14a b c + 3b )x  - 14a c + 3a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   4         2      4  2      2          3
+--R           (20a b c  - 3b c)x  + (20a b c - 3b )x  + 20a b c - 3a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                                                   +-----------+
+--R                  2     2   4                3  2      2        2  |          2
+--R           ((14a c  - 3b c)x  + (14a b c - 3b )x  + 14a c - 3a b )\|- 4a c + b
+--R         + 
+--R                   2     3   4         2      4  2      2          3
+--R           (20a b c  - 3b c)x  + (20a b c - 3b )x  + 20a b c - 3a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                                                                   +-----------+
+--R                  2     2   4                3  2      2        2  |          2
+--R           ((14a c  - 3b c)x  + (14a b c - 3b )x  + 14a c - 3a b )\|- 4a c + b
+--R         + 
+--R                     2     3   4           2      4  2      2          3
+--R           (- 20a b c  + 3b c)x  + (- 20a b c + 3b )x  - 20a b c + 3a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                                          +-----------+
+--R                      2  3          4+-+3 |          2 4+-+3 +-+
+--R         ((- 4a c + 2b )x  + 2a b x)\|2  \|- 4a c + b  \|c  \|x
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R              3     2 2  4           2     3   2      2 2       2  4+-+3
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c)x  + 16a c  - 4a b c)\|2
+--R    *
+--R                            +--------------------+ +------------------+
+--R        +-----------+       |   +-----------+      | +-----------+
+--R        |          2 4+-+3 4|   |          2      4| |          2
+--R       \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 585
+t0:=x^(11/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             5 +-+
+--R                            x \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 585
+r0:=1/2*x^(5/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-1/4*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(b^2-10*a*c+_
+   b*(b^2-12*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(b^2-4*a*c)*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))-1/4*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(b^2-10*a*c+b*(b^2-12*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(5/4)*(b^2-4*a*c)*(-b-sqrt(b^2-4*a*c))^(3/4))-1/4*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b^2-10*a*c-_
+   b*(b^2-12*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(b^2-4*a*c)*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))-1/4*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(b^2-10*a*c-b*(b^2-12*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(5/4)*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))-1/2*b*sqrt(x)/_
+   (c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                      2    2   4                 3  2      2       2
+--R             ((- 10a c  + b c)x  + (- 10a b c + b )x  - 10a c + a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2    3   4           2     4  2      2         3
+--R           (- 12a b c  + b c)x  + (- 12a b c + b )x  - 12a b c + a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                      2    2   4                 3  2      2       2
+--R             ((- 10a c  + b c)x  + (- 10a b c + b )x  - 10a c + a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2    3   4         2     4  2      2         3
+--R           (12a b c  - b c)x  + (12a b c - b )x  + 12a b c - a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                      2    2   4                 3  2      2       2
+--R             ((- 10a c  + b c)x  + (- 10a b c + b )x  - 10a c + a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2    3   4           2     4  2      2         3
+--R           (- 12a b c  + b c)x  + (- 12a b c + b )x  - 12a b c + a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                      2    2   4                 3  2      2       2
+--R             ((- 10a c  + b c)x  + (- 10a b c + b )x  - 10a c + a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2    3   4         2     4  2      2         3
+--R           (12a b c  - b c)x  + (12a b c - b )x  + 12a b c - a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                       +-----------+
+--R                      2  2        4+-+ |          2 4+-+ +-+
+--R         ((- 4a c + 2b )x  + 2a b)\|2 \|- 4a c + b  \|c \|x
+--R      *
+--R          +--------------------+3  +------------------+3
+--R          |   +-----------+        | +-----------+
+--R         4|   |          2        4| |          2
+--R         \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              3     2 2  4           2     3   2      2 2       2  4+-+
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c)x  + 16a c  - 4a b c)\|2
+--R    *
+--R                          +--------------------+3  +------------------+3
+--R        +-----------+     |   +-----------+        | +-----------+
+--R        |          2 4+-+4|   |          2        4| |          2
+--R       \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 585
+t0:=x^(9/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             4 +-+
+--R                            x \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 585
+r0:=1/2*x^(3/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/4*atan(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2-12*a*c)/sqrt(b^2-_
+   4*a*c))/(2^(3/4)*c^(3/4)*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))-1/4*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2-_
+   12*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*(b^2-4*a*c)*(-b+sqrt(b^2-_
+   4*a*c))^(1/4))+1/4*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(b^2+12*a*c+b*sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*(b^2-_
+   4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(1/4))-1/4*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(b^2+12*a*c+b*sqrt(b^2-4*a*c))/_
+   (2^(3/4)*c^(3/4)*(b^2-4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                 +-----------+
+--R                 4    2 2        |          2          2    2   4
+--R           (b c x  + b x  + a b)\|- 4a c + b   + (12a c  + b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c + b )x  + 12a c + a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                                 +-----------+
+--R                 4    2 2        |          2            2    2   4
+--R           (b c x  + b x  + a b)\|- 4a c + b   + (- 12a c  - b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c - b )x  - 12a c - a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2            2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (- 12a c  - b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c - b )x  - 12a c - a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2          2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (12a c  + b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c + b )x  + 12a c + a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                                                      +--------------------+
+--R                               +-----------+          |   +-----------+
+--R                3        4+-+3 |          2 4+-+3 +-+4|   |          2
+--R         (- 2b x  - 4a x)\|2  \|- 4a c + b  \|c  \|x \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R              2     2   4                3  2      2        2 4+-+3
+--R       ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )\|2
+--R    *
+--R                            +--------------------+ +------------------+
+--R        +-----------+       |   +-----------+      | +-----------+
+--R        |          2 4+-+3 4|   |          2      4| |          2
+--R       \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 585
+t0:=x^(7/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             3 +-+
+--R                            x \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 585
+r0:=1/4*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(3*b^2+_
+   4*a*c-3*b*sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*(b^2-4*a*c)^(3/2)*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))+1/4*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(3*b^2+4*a*c-3*b*sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(1/4)*(b^2-4*a*c)^(3/2)*(-b+sqrt(b^2-4*a*c))^(3/4))-1/4*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(3*b^2+_
+   4*a*c+3*b*sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*(b^2-4*a*c)^(3/2)*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))-1/4*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(3*b^2+4*a*c+3*b*sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(1/4)*(b^2-4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(3/4))+1/2*(2*a+b*x^2)*_
+   sqrt(x)/((b^2-4*a*c)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                                    +-----------+
+--R                  4     2 2         |          2         2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (4a c  + 3b c)x
+--R         + 
+--R                       3  2     2        2
+--R           (4a b c + 3b )x  + 4a c + 3a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2           2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (- 4a c  - 3b c)x
+--R         + 
+--R                         3  2     2        2
+--R           (- 4a b c - 3b )x  - 4a c - 3a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2         2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (4a c  + 3b c)x
+--R         + 
+--R                       3  2     2        2
+--R           (4a b c + 3b )x  + 4a c + 3a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2           2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (- 4a c  - 3b c)x
+--R         + 
+--R                         3  2     2        2
+--R           (- 4a b c - 3b )x  - 4a c - 3a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                                  +--------------------+3
+--R                            +-----------+         |   +-----------+
+--R                2      4+-+ |          2 4+-+ +-+4|   |          2
+--R         (- 2b x  - 4a)\|2 \|- 4a c + b  \|c \|x \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R                                                                   +-----------+
+--R              2     2   4                3  2      2        2 4+-+ |          2
+--R       ((16a c  - 4b c)x  + (16a b c - 4b )x  + 16a c - 4a b )\|2 \|- 4a c + b
+--R    *
+--R            +--------------------+3  +------------------+3
+--R            |   +-----------+        | +-----------+
+--R       4+-+4|   |          2        4| |          2
+--R       \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 585
+t0:=x^(5/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             2 +-+
+--R                            x \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 585
+r0:=-1/2*x^(3/2)*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(4*b-_
+   sqrt(b^2-4*a*c))/(2^(3/4)*(b^2-4*a*c)^(3/2)*(-b+sqrt(b^2-4*a*c))^(1/4))-_
+   1/2*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (4*b-sqrt(b^2-4*a*c))/(2^(3/4)*(b^2-4*a*c)^(3/2)*(-b+sqrt(b^2-_
+   4*a*c))^(1/4))-1/2*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(4*b+sqrt(b^2-4*a*c))/(2^(3/4)*(b^2-_
+   4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(1/4))+1/2*c^(1/4)*atanh(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(4*b+sqrt(b^2-4*a*c))/_
+   (2^(3/4)*(b^2-4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                              +-----------+
+--R                4      2      |          2          4     2 2        4+-+
+--R         ((- c x  - b x  - a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                              +-----------+
+--R                4      2      |          2          4     2 2        4+-+
+--R         ((- c x  - b x  - a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R              4      2      |          2          4     2 2        4+-+
+--R         ((c x  + b x  + a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R              4      2      |          2          4     2 2        4+-+
+--R         ((c x  + b x  + a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                                              +--------------------+
+--R                            +-----------+     |   +-----------+
+--R              3       4+-+3 |          2  +-+4|   |          2
+--R         (2c x  + b x)\|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R                                                                 +-----------+
+--R             2     2   4               3  2     2        2 4+-+3 |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2  \|- 4a c + b
+--R    *
+--R        +--------------------+ +------------------+
+--R        |   +-----------+      | +-----------+
+--R       4|   |          2      4| |          2
+--R       \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 585
+t0:=x^(3/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                              +-+
+--R                            x\|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 585
+r0:=1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (3+4*b/sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)*(-b-sqrt(b^2-4*a*c))^(3/4))+_
+   1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (3+4*b/sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)*(-b-sqrt(b^2-4*a*c))^(3/4))+_
+   1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (3-4*b/sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))+_
+   1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (3-4*b/sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))-_
+   1/2*(b+2*c*x^2)*sqrt(x)/((b^2-4*a*c)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                                 +-----------+
+--R                 4       2       |          2          4     2 2        4+-+3
+--R         ((- 3c x  - 3b x  - 3a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                                 +-----------+
+--R                 4       2       |          2          4     2 2        4+-+3
+--R         ((- 3c x  - 3b x  - 3a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                                 +-----------+
+--R                 4       2       |          2          4     2 2        4+-+3
+--R         ((- 3c x  - 3b x  - 3a)\|- 4a c + b   - 4b c x  - 4b x  - 4a b)\|c
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                                 +-----------+
+--R                 4       2       |          2          4     2 2        4+-+3
+--R         ((- 3c x  - 3b x  - 3a)\|- 4a c + b   + 4b c x  + 4b x  + 4a b)\|c
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+3
+--R                         +-----------+     |   +-----------+
+--R              2     4+-+ |          2  +-+4|   |          2
+--R         (2c x  + b)\|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R                                                                +-----------+
+--R             2     2   4               3  2     2        2 4+-+ |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2 \|- 4a c + b
+--R    *
+--R        +--------------------+3  +------------------+3
+--R        |   +-----------+        | +-----------+
+--R       4|   |          2        4| |          2
+--R       \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 585
+t0:=x^(1/2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                              +-+
+--R                             \|x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 585
+r0:=1/2*x^(3/2)*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   1/4*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(-b^2+20*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*a*(b^2-4*a*c)*(-b-sqrt(b^2-4*_
+   a*c))^(1/4))-1/4*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(b+(-b^2+20*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*a*(b^2-4*a*c)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))+1/4*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b+(b^2-20*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))-1/4*c^(1/4)*atanh(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b+(b^2-20*a*c)/sqrt(b^2-_
+   4*a*c))/(2^(3/4)*a*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                 +-----------+
+--R                 4    2 2        |          2          2    2   4
+--R           (b c x  + b x  + a b)\|- 4a c + b   + (20a c  - b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (20a b c - b )x  + 20a c - a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                 4+-+4+-+ +-+
+--R         4+-+4| |          2                  \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R                                 +-----------+
+--R                 4    2 2        |          2            2    2   4
+--R           (b c x  + b x  + a b)\|- 4a c + b   + (- 20a c  + b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 20a b c + b )x  - 20a c + a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                4+-+4+-+ +-+
+--R         4+-+4|   |          2                 \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2            2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (- 20a c  + b c)x
+--R         + 
+--R                         3  2      2       2
+--R           (- 20a b c + b )x  - 20a c + a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                4+-+4+-+ +-+
+--R         4+-+4| |          2                 \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R                                   +-----------+
+--R                   4    2 2        |          2          2    2   4
+--R           (- b c x  - b x  - a b)\|- 4a c + b   + (20a c  - b c)x
+--R         + 
+--R                       3  2      2       2
+--R           (20a b c - b )x  + 20a c - a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+               4+-+4+-+ +-+
+--R         4+-+4|   |          2                \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                         4| |          2
+--R                                         \|\|- 4a c + b   - b
+--R     + 
+--R                                          +-----------+
+--R                  3             2   4+-+3 |          2  +-+
+--R         (- 2b c x  + (4a c - 2b )x)\|2  \|- 4a c + b  \|x
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R         4|   |          2      4| |          2
+--R         \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R            2 2       2   4       2          3  2      3      2 2 4+-+3
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2 4|   |          2      4| |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 585
+t0:=1/(x^(1/2)*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                 1
+--R   (1)  ---------------------------------------------------
+--R          2 8         6            2  4         2    2  +-+
+--R        (c x  + 2b c x  + (2a c + b )x  + 2a b x  + a )\|x
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 585
+r0:=-1/4*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (3*b+(3*b^2-28*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*a*(b^2-4*a*c)*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))-1/4*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(3*b+(3*b^2-28*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*a*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))+1/4*c^(3/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(3*b^2-_
+   28*a*c-3*b*sqrt(b^2-4*a*c))/(2^(1/4)*a*(b^2-4*a*c)^(3/2)*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))+1/4*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))*(3*b^2-28*a*c-3*b*sqrt(b^2-4*a*c))/_
+   (2^(1/4)*a*(b^2-4*a*c)^(3/2)*(-b-sqrt(b^2-4*a*c))^(3/4))+1/2*(b^2-_
+   2*a*c+b*c*x^2)*sqrt(x)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                                    +-----------+
+--R                  4     2 2         |          2          2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (28a c  - 3b c)x
+--R         + 
+--R                        3  2      2        2
+--R           (28a b c - 3b )x  + 28a c - 3a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                  4+-+4+-+ +-+
+--R         4+-+3 4| |          2                   \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2            2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (- 28a c  + 3b c)x
+--R         + 
+--R                          3  2      2        2
+--R           (- 28a b c + 3b )x  - 28a c + 3a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                  \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2          2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (28a c  - 3b c)x
+--R         + 
+--R                        3  2      2        2
+--R           (28a b c - 3b )x  + 28a c - 3a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4| |          2                  \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                  4     2 2         |          2            2     2   4
+--R           (3b c x  + 3b x  + 3a b)\|- 4a c + b   + (- 28a c  + 3b c)x
+--R         + 
+--R                          3  2      2        2
+--R           (- 28a b c + 3b )x  - 28a c + 3a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                 \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R     + 
+--R                                                        +--------------------+3
+--R                                      +-----------+     |   +-----------+
+--R                  2            2 4+-+ |          2  +-+4|   |          2
+--R         (- 2b c x  + 4a c - 2b )\|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b
+--R      *
+--R          +------------------+3
+--R          | +-----------+
+--R         4| |          2
+--R         \|\|- 4a c + b   - b
+--R  /
+--R            2 2       2   4       2          3  2      3      2 2 4+-+
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|2
+--R    *
+--R                      +--------------------+3  +------------------+3
+--R        +-----------+ |   +-----------+        | +-----------+
+--R        |          2 4|   |          2        4| |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 585
+t0:=1/(x^(3/2)*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R          2 9         7            2  5         3    2   +-+
+--R        (c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x)\|x
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 585
+r0:=-1/4*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (5*b^2-18*a*c-5*b^3/sqrt(b^2-4*a*c)+28*a*b*c/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a^2*(b^2-4*a*c)*(-b-sqrt(b^2-4*a*c))^(1/4))+1/4*c^(1/4)*atanh(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(5*b^2-18*a*c-5*b^3/_
+   sqrt(b^2-4*a*c)+28*a*b*c/sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-1/4*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(5*b^2-18*a*c+5*b^3/sqrt(b^2-4*a*c)-_
+   28*a*b*c/sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)*(-b+sqrt(b^2-_
+   4*a*c))^(1/4))+1/4*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(5*b^2-18*a*c+5*b^3/sqrt(b^2-4*a*c)-28*a*b*c/sqrt(b^2-_
+   4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(1/4))+_
+   1/2*(-5*b^2+18*a*c)/(a^2*(b^2-4*a*c)*sqrt(x))+1/2*(b^2-2*a*c+b*c*x^2)/_
+   (a*(b^2-4*a*c)*(a+b*x^2+c*x^4)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                                                                   +-----------+
+--R                  2     2   4                3  2      2        2  |          2
+--R           ((18a c  - 5b c)x  + (18a b c - 5b )x  + 18a c - 5a b )\|- 4a c + b
+--R         + 
+--R                     2     3   4           2      4  2      2          3
+--R           (- 28a b c  + 5b c)x  + (- 28a b c + 5b )x  - 28a b c + 5a b
+--R      *
+--R                  +------------------+
+--R                  | +-----------+                 4+-+4+-+ +-+
+--R         4+-+ +-+4| |          2                  \|2 \|c \|x
+--R         \|c \|x \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                             +--------------------+
+--R                                             |   +-----------+
+--R                                            4|   |          2
+--R                                            \|- \|- 4a c + b   - b
+--R     + 
+--R                                                                   +-----------+
+--R                  2     2   4                3  2      2        2  |          2
+--R           ((18a c  - 5b c)x  + (18a b c - 5b )x  + 18a c - 5a b )\|- 4a c + b
+--R         + 
+--R                   2     3   4         2      4  2      2          3
+--R           (28a b c  - 5b c)x  + (28a b c - 5b )x  + 28a b c - 5a b
+--R      *
+--R                  +--------------------+
+--R                  |   +-----------+                4+-+4+-+ +-+
+--R         4+-+ +-+4|   |          2                 \|2 \|c \|x
+--R         \|c \|x \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                               +------------------+
+--R                                               | +-----------+
+--R                                              4| |          2
+--R                                              \|\|- 4a c + b   - b
+--R     + 
+--R                      2     2   4                  3  2      2        2
+--R             ((- 18a c  + 5b c)x  + (- 18a b c + 5b )x  - 18a c + 5a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   4         2      4  2      2          3
+--R           (28a b c  - 5b c)x  + (28a b c - 5b )x  + 28a b c - 5a b
+--R      *
+--R                  +------------------+
+--R                  | +-----------+                4+-+4+-+ +-+
+--R         4+-+ +-+4| |          2                 \|2 \|c \|x
+--R         \|c \|x \|\|- 4a c + b   - b atan(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                      2     2   4                  3  2      2        2
+--R             ((- 18a c  + 5b c)x  + (- 18a b c + 5b )x  - 18a c + 5a b )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   4           2      4  2      2          3
+--R           (- 28a b c  + 5b c)x  + (- 28a b c + 5b )x  - 28a b c + 5a b
+--R      *
+--R                  +--------------------+
+--R                  |   +-----------+               4+-+4+-+ +-+
+--R         4+-+ +-+4|   |          2                \|2 \|c \|x
+--R         \|c \|x \|- \|- 4a c + b   - b atan(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                  2      2   4                   3  2      2        2 4+-+3
+--R         ((- 36a c  + 10b c)x  + (- 38a b c + 10b )x  - 32a c + 8a b )\|2
+--R      *
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2 4|   |          2      4| |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R            3 2     2 2   4       3        2 3  2      4      3 2 4+-+3
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|2
+--R    *
+--R                          +--------------------+ +------------------+
+--R        +-----------+     |   +-----------+      | +-----------+
+--R        |          2  +-+4|   |          2      4| |          2
+--R       \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 585
+t0:=x^(15/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      7 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 585
+r0:=1/4*x^(9/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+3/16*x^(5/2)*_
+   (8*a*b+(b^2+12*a*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))-_
+   3/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b^3-28*a*b*c+(b^4-30*a*b^2*c-24*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(5/4)*(b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(3/4))-3/32*atanh(2^(1/4)*_
+   c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(b^3-28*a*b*c+(b^4-_
+   30*a*b^2*c-24*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(b^2-4*a*c)^2*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))-3/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(b^3-28*a*b*c+(-b^4+30*a*b^2*c+24*a^2*c^2)/_
+   sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(b^2-4*a*c)^2*(-b+sqrt(b^2-_
+   4*a*c))^(3/4))-3/32*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(b^3-28*a*b*c+(-b^4+30*a*b^2*c+24*a^2*c^2)/sqrt(b^2-_
+   4*a*c))/(2^(1/4)*c^(5/4)*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))-_
+   3/16*(b^2+12*a*c)*sqrt(x)/(c*(b^2-4*a*c)^2)
+--R 
+--R
+--R   (2)
+--R                       3     3 2  8          2 2     4   6
+--R               (84a b c  - 3b c )x  + (168a b c  - 6b c)x
+--R             + 
+--R                    2   2        3      5  4        2 2        4  2      3
+--R               (168a b c  + 78a b c - 3b )x  + (168a b c - 6a b )x  + 84a b c
+--R             + 
+--R                   2 3
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 4        2 3     4 2  8        2   3         3 2     5   6
+--R           (72a c  + 90a b c  - 3b c )x  + (144a b c  + 180a b c  - 6b c)x
+--R         + 
+--R                3 3       2 2 2        4      6  4
+--R           (144a c  + 252a b c  + 84a b c - 3b )x
+--R         + 
+--R                3   2       2 3        5  2      4 2      3 2      2 4
+--R           (144a b c  + 180a b c - 6a b )x  + 72a c  + 90a b c - 3a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                       3     3 2  8          2 2     4   6
+--R               (84a b c  - 3b c )x  + (168a b c  - 6b c)x
+--R             + 
+--R                    2   2        3      5  4        2 2        4  2      3
+--R               (168a b c  + 78a b c - 3b )x  + (168a b c - 6a b )x  + 84a b c
+--R             + 
+--R                   2 3
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 4        2 3     4 2  8          2   3         3 2     5   6
+--R           (- 72a c  - 90a b c  + 3b c )x  + (- 144a b c  - 180a b c  + 6b c)x
+--R         + 
+--R                  3 3       2 2 2        4      6  4
+--R           (- 144a c  - 252a b c  - 84a b c + 3b )x
+--R         + 
+--R                  3   2       2 3        5  2      4 2      3 2      2 4
+--R           (- 144a b c  - 180a b c + 6a b )x  - 72a c  - 90a b c + 3a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                       3     3 2  8          2 2     4   6
+--R               (84a b c  - 3b c )x  + (168a b c  - 6b c)x
+--R             + 
+--R                    2   2        3      5  4        2 2        4  2      3
+--R               (168a b c  + 78a b c - 3b )x  + (168a b c - 6a b )x  + 84a b c
+--R             + 
+--R                   2 3
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 4        2 3     4 2  8        2   3         3 2     5   6
+--R           (72a c  + 90a b c  - 3b c )x  + (144a b c  + 180a b c  - 6b c)x
+--R         + 
+--R                3 3       2 2 2        4      6  4
+--R           (144a c  + 252a b c  + 84a b c - 3b )x
+--R         + 
+--R                3   2       2 3        5  2      4 2      3 2      2 4
+--R           (144a b c  + 180a b c - 6a b )x  + 72a c  + 90a b c - 3a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                       3     3 2  8          2 2     4   6
+--R               (84a b c  - 3b c )x  + (168a b c  - 6b c)x
+--R             + 
+--R                    2   2        3      5  4        2 2        4  2      3
+--R               (168a b c  + 78a b c - 3b )x  + (168a b c - 6a b )x  + 84a b c
+--R             + 
+--R                   2 3
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 4        2 3     4 2  8          2   3         3 2     5   6
+--R           (- 72a c  - 90a b c  + 3b c )x  + (- 144a b c  - 180a b c  + 6b c)x
+--R         + 
+--R                  3 3       2 2 2        4      6  4
+--R           (- 144a c  - 252a b c  - 84a b c + 3b )x
+--R         + 
+--R                  3   2       2 3        5  2      4 2      3 2      2 4
+--R           (- 144a b c  - 180a b c + 6a b )x  - 72a c  - 90a b c + 3a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                     2     3   6          2 2        2      4  4
+--R           (- 56a b c  + 2b c)x  + (- 136a c  - 14a b c - 6b )x
+--R         + 
+--R                 2           3  2      3      2 2
+--R           (- 96a b c - 12a b )x  - 72a c - 6a b
+--R      *
+--R                                  +--------------------+3  +------------------+3
+--R            +-----------+         |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+ +-+4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|c \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              2 5         2 4      4 3  8         2   4         3 3      5 2  6
+--R         (512a c  - 256a b c  + 32b c )x  + (1024a b c  - 512a b c  + 64b c )x
+--R       + 
+--R               3 4         4 2      6   4         3   3       2 3 2        5   2
+--R         (1024a c  - 192a b c  + 32b c)x  + (1024a b c  - 512a b c  + 64a b c)x
+--R       + 
+--R             4 3       3 2 2      2 4
+--R         512a c  - 256a b c  + 32a b c
+--R    *
+--R                              +--------------------+3  +------------------+3
+--R            +-----------+     |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 585
+t0:=x^(13/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      6 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 585
+r0:=1/4*x^(7/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+1/16*x^(3/2)*_
+   (24*a*b+(5*b^2+28*a*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+_
+   1/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(5*b^2+_
+   28*a*c+b*(5*b^2+172*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*(b^2-_
+   4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(1/4))-1/32*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(5*b^2+28*a*c+b*(5*b^2+172*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*(b^2-4*a*c)^2*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+1/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(5*b^2+28*a*c-b*(5*b^2+172*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*c^(3/4)*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(1/4))-_
+   1/32*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (5*b^2+28*a*c-b*(5*b^2+172*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*_
+   (b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                       3     2 2  8             2      3   6
+--R               (- 28a c  - 5b c )x  + (- 56a b c  - 10b c)x
+--R             + 
+--R                     2 2        2      4  4         2           3  2      3
+--R               (- 56a c  - 38a b c - 5b )x  + (- 56a b c - 10a b )x  - 28a c
+--R             + 
+--R                   2 2
+--R               - 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2      4   6
+--R           (- 172a b c  - 5b c )x  + (- 344a b c  - 10b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2         4  2       3
+--R           (- 344a b c  - 182a b c - 5b )x  + (- 344a b c - 10a b )x  - 172a b c
+--R         + 
+--R               2 3
+--R           - 5a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                       3     2 2  8             2      3   6
+--R               (- 28a c  - 5b c )x  + (- 56a b c  - 10b c)x
+--R             + 
+--R                     2 2        2      4  4         2           3  2      3
+--R               (- 56a c  - 38a b c - 5b )x  + (- 56a b c - 10a b )x  - 28a c
+--R             + 
+--R                   2 2
+--R               - 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2      4   6
+--R           (172a b c  + 5b c )x  + (344a b c  + 10b c)x
+--R         + 
+--R                2   2         3      5  4        2 2         4  2       3
+--R           (344a b c  + 182a b c + 5b )x  + (344a b c + 10a b )x  + 172a b c
+--R         + 
+--R             2 3
+--R           5a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                     3     2 2  8           2      3   6
+--R               (28a c  + 5b c )x  + (56a b c  + 10b c)x
+--R             + 
+--R                 2 2        2      4  4       2           3  2      3      2 2
+--R             (56a c  + 38a b c + 5b )x  + (56a b c + 10a b )x  + 28a c + 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2      4   6
+--R           (172a b c  + 5b c )x  + (344a b c  + 10b c)x
+--R         + 
+--R                2   2         3      5  4        2 2         4  2       3
+--R           (344a b c  + 182a b c + 5b )x  + (344a b c + 10a b )x  + 172a b c
+--R         + 
+--R             2 3
+--R           5a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                4+-+4+-+ +-+
+--R         4| |          2                 \|2 \|c \|x
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                     3     2 2  8           2      3   6
+--R               (28a c  + 5b c )x  + (56a b c  + 10b c)x
+--R             + 
+--R                 2 2        2      4  4       2           3  2      3      2 2
+--R             (56a c  + 38a b c + 5b )x  + (56a b c + 10a b )x  + 28a c + 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2      4   6
+--R           (- 172a b c  - 5b c )x  + (- 344a b c  - 10b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2         4  2       3
+--R           (- 344a b c  - 182a b c - 5b )x  + (- 344a b c - 10a b )x  - 172a b c
+--R         + 
+--R               2 3
+--R           - 5a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+               4+-+4+-+ +-+
+--R         4|   |          2                \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                   2      2   7                 3  5        2         2  3
+--R             (56a c  + 10b c)x  + (72a b c + 18b )x  + (- 8a c + 74a b )x
+--R           + 
+--R                2
+--R             48a b x
+--R      *
+--R                                    +--------------------+ +------------------+
+--R             +-----------+          |   +-----------+      | +-----------+
+--R       4+-+3 |          2 4+-+3 +-+4|   |          2      4| |          2
+--R       \|2  \|- 4a c + b  \|c  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R              2 4         2 3      4 2  8         2   3         3 2      5   6
+--R         (512a c  - 256a b c  + 32b c )x  + (1024a b c  - 512a b c  + 64b c)x
+--R       + 
+--R               3 3         4       6  4         3   2       2 3         5  2
+--R         (1024a c  - 192a b c + 32b )x  + (1024a b c  - 512a b c + 64a b )x
+--R       + 
+--R             4 2       3 2       2 4
+--R         512a c  - 256a b c + 32a b
+--R    *
+--R                                 +--------------------+ +------------------+
+--R             +-----------+       |   +-----------+      | +-----------+
+--R       4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R       \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 585
+t0:=x^(11/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      5 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 585
+r0:=1/4*x^(5/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-_
+   3/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (7*b^2+20*a*c+b*(7*b^2+36*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*_
+   (b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(3/4))-3/32*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(7*b^2+20*a*c+b*(7*b^2+36*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*(b^2-4*a*c)^2*(-b-sqrt(b^2-_
+   4*a*c))^(3/4))-3/32*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(7*b^2+20*a*c-b*(7*b^2+36*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(1/4)*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))-_
+   3/32*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (7*b^2+20*a*c-b*(7*b^2+36*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*_
+   (b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))+1/16*(24*a*b+(7*b^2+_
+   20*a*c)*x^2)*sqrt(x)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                       3      2 2  8              2      3   6
+--R               (- 60a c  - 21b c )x  + (- 120a b c  - 42b c)x
+--R             + 
+--R                      2 2         2       4  4          2           3  2      3
+--R               (- 120a c  - 102a b c - 21b )x  + (- 120a b c - 42a b )x  - 60a c
+--R             + 
+--R                    2 2
+--R               - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3      3 2  8            2 2      4   6
+--R           (- 108a b c  - 21b c )x  + (- 216a b c  - 42b c)x
+--R         + 
+--R                  2   2         3       5  4          2 2         4  2
+--R           (- 216a b c  - 150a b c - 21b )x  + (- 216a b c - 42a b )x
+--R         + 
+--R                 3         2 3
+--R           - 108a b c - 21a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                  4+-+4+-+ +-+
+--R         4| |          2                   \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R                       3      2 2  8              2      3   6
+--R               (- 60a c  - 21b c )x  + (- 120a b c  - 42b c)x
+--R             + 
+--R                      2 2         2       4  4          2           3  2      3
+--R               (- 120a c  - 102a b c - 21b )x  + (- 120a b c - 42a b )x  - 60a c
+--R             + 
+--R                    2 2
+--R               - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3      3 2  8          2 2      4   6
+--R           (108a b c  + 21b c )x  + (216a b c  + 42b c)x
+--R         + 
+--R                2   2         3       5  4        2 2         4  2       3
+--R           (216a b c  + 150a b c + 21b )x  + (216a b c + 42a b )x  + 108a b c
+--R         + 
+--R              2 3
+--R           21a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                 4+-+4+-+ +-+
+--R         4|   |          2                  \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R     + 
+--R                       3      2 2  8              2      3   6
+--R               (- 60a c  - 21b c )x  + (- 120a b c  - 42b c)x
+--R             + 
+--R                      2 2         2       4  4          2           3  2      3
+--R               (- 120a c  - 102a b c - 21b )x  + (- 120a b c - 42a b )x  - 60a c
+--R             + 
+--R                    2 2
+--R               - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3      3 2  8            2 2      4   6
+--R           (- 108a b c  - 21b c )x  + (- 216a b c  - 42b c)x
+--R         + 
+--R                  2   2         3       5  4          2 2         4  2
+--R           (- 216a b c  - 150a b c - 21b )x  + (- 216a b c - 42a b )x
+--R         + 
+--R                 3         2 3
+--R           - 108a b c - 21a b
+--R      *
+--R          +------------------+3
+--R          | +-----------+                 4+-+4+-+ +-+
+--R         4| |          2                  \|2 \|c \|x
+--R         \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R                       3      2 2  8              2      3   6
+--R               (- 60a c  - 21b c )x  + (- 120a b c  - 42b c)x
+--R             + 
+--R                      2 2         2       4  4          2           3  2      3
+--R               (- 120a c  - 102a b c - 21b )x  + (- 120a b c - 42a b )x  - 60a c
+--R             + 
+--R                    2 2
+--R               - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3      3 2  8          2 2      4   6
+--R           (108a b c  + 21b c )x  + (216a b c  + 42b c)x
+--R         + 
+--R                2   2         3       5  4        2 2         4  2       3
+--R           (216a b c  + 150a b c + 21b )x  + (216a b c + 42a b )x  + 108a b c
+--R         + 
+--R              2 3
+--R           21a b
+--R      *
+--R          +--------------------+3
+--R          |   +-----------+                4+-+4+-+ +-+
+--R         4|   |          2                 \|2 \|c \|x
+--R         \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                   2      2   6                 3  4         2         2  2
+--R             (40a c  + 14b c)x  + (56a b c + 22b )x  + (- 24a c + 78a b )x
+--R           + 
+--R                2
+--R             48a b
+--R      *
+--R                                  +--------------------+3  +------------------+3
+--R            +-----------+         |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+ +-+4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|c \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              2 4         2 3      4 2  8         2   3         3 2      5   6
+--R         (512a c  - 256a b c  + 32b c )x  + (1024a b c  - 512a b c  + 64b c)x
+--R       + 
+--R               3 3         4       6  4         3   2       2 3         5  2
+--R         (1024a c  - 192a b c + 32b )x  + (1024a b c  - 512a b c + 64a b )x
+--R       + 
+--R             4 2       3 2       2 4
+--R         512a c  - 256a b c + 32a b
+--R    *
+--R                              +--------------------+3  +------------------+3
+--R            +-----------+     |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 585
+t0:=x^(9/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      4 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 585
+r0:=1/4*x^(3/2)*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-3/16*x^(3/2)*_
+   (5*b^2-4*a*c+8*b*c*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+3/16*c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(11*b^2+_
+   20*a*c-4*b*sqrt(b^2-4*a*c))/(2^(3/4)*(b^2-4*a*c)^(5/2)*(-b+sqrt(b^2-_
+   4*a*c))^(1/4))-3/16*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(11*b^2+20*a*c-4*b*sqrt(b^2-4*a*c))/(2^(3/4)*_
+   (b^2-4*a*c)^(5/2)*(-b+sqrt(b^2-4*a*c))^(1/4))-3/16*c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(11*b^2+_
+   20*a*c+4*b*sqrt(b^2-4*a*c))/(2^(3/4)*(b^2-4*a*c)^(5/2)*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+3/16*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(11*b^2+20*a*c+4*b*sqrt(b^2-4*a*c))/(2^(3/4)*_
+   (b^2-4*a*c)^(5/2)*(-b-sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (12b c x  + 24b c x  + (24a b c + 12b )x  + 24a b x  + 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8            2      3   6
+--R           (60a c  + 33b c )x  + (120a b c  + 66b c)x
+--R         + 
+--R              2 2         2       4  4        2           3  2      3       2 2
+--R         (120a c  + 126a b c + 33b )x  + (120a b c + 66a b )x  + 60a c + 33a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                 4+-+4+-+ +-+
+--R         4+-+4| |          2                  \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (12b c x  + 24b c x  + (24a b c + 12b )x  + 24a b x  + 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8              2      3   6
+--R           (- 60a c  - 33b c )x  + (- 120a b c  - 66b c)x
+--R         + 
+--R                  2 2         2       4  4          2           3  2      3
+--R           (- 120a c  - 126a b c - 33b )x  + (- 120a b c - 66a b )x  - 60a c
+--R         + 
+--R                2 2
+--R           - 33a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                4+-+4+-+ +-+
+--R         4+-+4|   |          2                 \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R     + 
+--R                     2 8      2   6                   3  4        2 2      2
+--R             (- 12b c x  - 24b c x  + (- 24a b c - 12b )x  - 24a b x  - 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8              2      3   6
+--R           (- 60a c  - 33b c )x  + (- 120a b c  - 66b c)x
+--R         + 
+--R                  2 2         2       4  4          2           3  2      3
+--R           (- 120a c  - 126a b c - 33b )x  + (- 120a b c - 66a b )x  - 60a c
+--R         + 
+--R                2 2
+--R           - 33a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                4+-+4+-+ +-+
+--R         4+-+4| |          2                 \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R                     2 8      2   6                   3  4        2 2      2
+--R             (- 12b c x  - 24b c x  + (- 24a b c - 12b )x  - 24a b x  - 12a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8            2      3   6
+--R           (60a c  + 33b c )x  + (120a b c  + 66b c)x
+--R         + 
+--R              2 2         2       4  4        2           3  2      3       2 2
+--R         (120a c  + 126a b c + 33b )x  + (120a b c + 66a b )x  + 60a c + 33a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+               4+-+4+-+ +-+
+--R         4+-+4|   |          2                \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                         4| |          2
+--R                                         \|\|- 4a c + b   - b
+--R     + 
+--R                  2 7         2      2   5                   3  3
+--R           - 24b c x  + (12a c  - 39b c)x  + (- 28a b c - 11b )x
+--R         + 
+--R                 2        2
+--R           (- 20a c - 7a b )x
+--R      *
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R         4+-+3 |          2  +-+4|   |          2      4| |          2
+--R         \|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R              2 4         2 3      4 2  8        2   3         3 2      5   6
+--R         (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R       + 
+--R              3 3        4       6  4        3   2       2 3         5  2
+--R         (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R       + 
+--R             4 2       3 2       2 4
+--R         256a c  - 128a b c + 16a b
+--R    *
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R       4+-+3 |          2 4|   |          2      4| |          2
+--R       \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 585
+t0:=x^(7/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 585
+r0:=-1/16*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (41*b^2+28*a*c-36*b*sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)^(5/2)*_
+   (-b+sqrt(b^2-4*a*c))^(3/4))-1/16*c^(3/4)*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(41*b^2+28*a*c-36*b*sqrt(b^2-_
+   4*a*c))/(2^(1/4)*(b^2-4*a*c)^(5/2)*(-b+sqrt(b^2-4*a*c))^(3/4))+_
+   1/16*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (41*b^2+28*a*c+36*b*sqrt(b^2-4*a*c))/(2^(1/4)*(b^2-4*a*c)^(5/2)*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))+1/16*c^(3/4)*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(41*b^2+28*a*c+36*b*sqrt(b^2-4*a*c))/_
+   (2^(1/4)*(b^2-4*a*c)^(5/2)*(-b-sqrt(b^2-4*a*c))^(3/4))+1/4*(2*a+b*x^2)*_
+   sqrt(x)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-1/16*(13*b^2-4*a*c+_
+   24*b*c*x^2)*sqrt(x)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (36b c x  + 72b c x  + (72a b c + 36b )x  + 72a b x  + 36a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8           2      3   6
+--R           (28a c  + 41b c )x  + (56a b c  + 82b c)x
+--R         + 
+--R               2 2         2       4  4       2           3  2      3       2 2
+--R           (56a c  + 110a b c + 41b )x  + (56a b c + 82a b )x  + 28a c + 41a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                  4+-+4+-+ +-+
+--R         4+-+3 4| |          2                   \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (36b c x  + 72b c x  + (72a b c + 36b )x  + 72a b x  + 36a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8             2      3   6
+--R           (- 28a c  - 41b c )x  + (- 56a b c  - 82b c)x
+--R         + 
+--R                 2 2         2       4  4         2           3  2      3
+--R           (- 56a c  - 110a b c - 41b )x  + (- 56a b c - 82a b )x  - 28a c
+--R         + 
+--R                2 2
+--R           - 41a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                  \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (36b c x  + 72b c x  + (72a b c + 36b )x  + 72a b x  + 36a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8           2      3   6
+--R           (28a c  + 41b c )x  + (56a b c  + 82b c)x
+--R         + 
+--R               2 2         2       4  4       2           3  2      3       2 2
+--R           (56a c  + 110a b c + 41b )x  + (56a b c + 82a b )x  + 28a c + 41a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4| |          2                  \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                   2 8      2   6                 3  4        2 2      2
+--R             (36b c x  + 72b c x  + (72a b c + 36b )x  + 72a b x  + 36a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8             2      3   6
+--R           (- 28a c  - 41b c )x  + (- 56a b c  - 82b c)x
+--R         + 
+--R                 2 2         2       4  4         2           3  2      3
+--R           (- 56a c  - 110a b c - 41b )x  + (- 56a b c - 82a b )x  - 28a c
+--R         + 
+--R                2 2
+--R           - 41a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                 \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R     + 
+--R                 2 6        2      2   4                  3  2      2        2
+--R         (- 24b c x  + (4a c  - 37b c)x  + (- 36a b c - 9b )x  - 28a c - 5a b )
+--R      *
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2  +-+4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              2 4         2 3      4 2  8        2   3         3 2      5   6
+--R         (256a c  - 128a b c  + 16b c )x  + (512a b c  - 256a b c  + 32b c)x
+--R       + 
+--R              3 3        4       6  4        3   2       2 3         5  2
+--R         (512a c  - 96a b c + 16b )x  + (512a b c  - 256a b c + 32a b )x
+--R       + 
+--R             4 2       3 2       2 4
+--R         256a c  - 128a b c + 16a b
+--R    *
+--R                          +--------------------+3  +------------------+3
+--R            +-----------+ |   +-----------+        | +-----------+
+--R       4+-+ |          2 4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 585
+t0:=x^(5/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      2 +-+
+--R     x \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 585
+r0:=-1/4*x^(3/2)*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+3/16*x^(3/2)*_
+   (b*(b^2+4*a*c)+c*(b^2+12*a*c)*x^2)/(a*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))+_
+   3/32*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b^2+12*a*c-b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*a*(b^2-4*a*c)^2*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-3/32*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))*(b^2+12*a*c-b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*a*(b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(1/4))+3/32*c^(1/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b^2+12*a*c+_
+   b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*a*(b^2-4*a*c)^2*(-b+sqrt(b^2-_
+   4*a*c))^(1/4))-3/32*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(b^2+12*a*c+b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                       3     2 2  8             2     3   6
+--R               (- 36a c  - 3b c )x  + (- 72a b c  - 6b c)x
+--R             + 
+--R                     2 2        2      4  4         2          3  2      3
+--R               (- 72a c  - 42a b c - 3b )x  + (- 72a b c - 6a b )x  - 36a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2     4   6
+--R           (- 204a b c  + 3b c )x  + (- 408a b c  + 6b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2        4  2       3
+--R           (- 408a b c  - 198a b c + 3b )x  + (- 408a b c + 6a b )x  - 204a b c
+--R         + 
+--R             2 3
+--R           3a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                 4+-+4+-+ +-+
+--R         4+-+4| |          2                  \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R                       3     2 2  8             2     3   6
+--R               (- 36a c  - 3b c )x  + (- 72a b c  - 6b c)x
+--R             + 
+--R                     2 2        2      4  4         2          3  2      3
+--R               (- 72a c  - 42a b c - 3b )x  + (- 72a b c - 6a b )x  - 36a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2     4   6
+--R           (204a b c  - 3b c )x  + (408a b c  - 6b c)x
+--R         + 
+--R                2   2         3      5  4        2 2        4  2       3
+--R           (408a b c  + 198a b c - 3b )x  + (408a b c - 6a b )x  + 204a b c
+--R         + 
+--R               2 3
+--R           - 3a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                4+-+4+-+ +-+
+--R         4+-+4|   |          2                 \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R     + 
+--R                     3     2 2  8           2     3   6
+--R               (36a c  + 3b c )x  + (72a b c  + 6b c)x
+--R             + 
+--R                   2 2        2      4  4       2          3  2      3      2 2
+--R               (72a c  + 42a b c + 3b )x  + (72a b c + 6a b )x  + 36a c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2     4   6
+--R           (204a b c  - 3b c )x  + (408a b c  - 6b c)x
+--R         + 
+--R                2   2         3      5  4        2 2        4  2       3
+--R           (408a b c  + 198a b c - 3b )x  + (408a b c - 6a b )x  + 204a b c
+--R         + 
+--R               2 3
+--R           - 3a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                4+-+4+-+ +-+
+--R         4+-+4| |          2                 \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R                     3     2 2  8           2     3   6
+--R               (36a c  + 3b c )x  + (72a b c  + 6b c)x
+--R             + 
+--R                   2 2        2      4  4       2          3  2      3      2 2
+--R               (72a c  + 42a b c + 3b )x  + (72a b c + 6a b )x  + 36a c + 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2     4   6
+--R           (- 204a b c  + 3b c )x  + (- 408a b c  + 6b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2        4  2       3
+--R           (- 408a b c  - 198a b c + 3b )x  + (- 408a b c + 6a b )x  - 204a b c
+--R         + 
+--R             2 3
+--R           3a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+               4+-+4+-+ +-+
+--R         4+-+4|   |          2                \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                         4| |          2
+--R                                         \|\|- 4a c + b   - b
+--R     + 
+--R                 3     2 2  7           2      3   5
+--R           (72a c  + 6b c )x  + (96a b c  + 12b c)x
+--R         + 
+--R                2 2        2      4  3       2          3
+--R           (136a c  + 14a b c + 6b )x  + (56a b c - 2a b )x
+--R      *
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R         4+-+3 |          2  +-+4|   |          2      4| |          2
+--R         \|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R              3 4       2 2 3        4 2  8
+--R         (512a c  - 256a b c  + 32a b c )x
+--R       + 
+--R               3   3       2 3 2        5   6         4 3       2 4         6  4
+--R         (1024a b c  - 512a b c  + 64a b c)x  + (1024a c  - 192a b c + 32a b )x
+--R       + 
+--R               4   2       3 3       2 5  2       5 2       4 2       3 4
+--R         (1024a b c  - 512a b c + 64a b )x  + 512a c  - 256a b c + 32a b
+--R    *
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R       4+-+3 |          2 4|   |          2      4| |          2
+--R       \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 585
+t0:=x^(3/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R       +-+
+--R     x\|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 585
+r0:=-3/32*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b^2+44*a*c-b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*a*(b^2-4*a*c)^2*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))-3/32*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))*(b^2+44*a*c-b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*a*(b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(3/4))-3/32*c^(3/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(b^2+44*a*c+_
+   b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*a*(b^2-4*a*c)^2*(-b+sqrt(b^2-_
+   4*a*c))^(3/4))-3/32*c^(3/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(b^2+44*a*c+b*(b^2-68*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))-1/4*(b+2*c*x^2)*sqrt(x)/_
+   ((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+1/16*(b*(b^2+20*a*c)+c*(b^2+44*a*c)*_
+   x^2)*sqrt(x)/(a*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                        3     2 2  8              2     3   6
+--R               (- 132a c  - 3b c )x  + (- 264a b c  - 6b c)x
+--R             + 
+--R                      2 2         2      4  4          2          3  2       3
+--R               (- 264a c  - 138a b c - 3b )x  + (- 264a b c - 6a b )x  - 132a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2     4   6
+--R           (- 204a b c  + 3b c )x  + (- 408a b c  + 6b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2        4  2       3
+--R           (- 408a b c  - 198a b c + 3b )x  + (- 408a b c + 6a b )x  - 204a b c
+--R         + 
+--R             2 3
+--R           3a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                  4+-+4+-+ +-+
+--R         4+-+3 4| |          2                   \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                        3     2 2  8              2     3   6
+--R               (- 132a c  - 3b c )x  + (- 264a b c  - 6b c)x
+--R             + 
+--R                      2 2         2      4  4          2          3  2       3
+--R               (- 264a c  - 138a b c - 3b )x  + (- 264a b c - 6a b )x  - 132a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2     4   6
+--R           (204a b c  - 3b c )x  + (408a b c  - 6b c)x
+--R         + 
+--R                2   2         3      5  4        2 2        4  2       3
+--R           (408a b c  + 198a b c - 3b )x  + (408a b c - 6a b )x  + 204a b c
+--R         + 
+--R               2 3
+--R           - 3a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                  \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                        3     2 2  8              2     3   6
+--R               (- 132a c  - 3b c )x  + (- 264a b c  - 6b c)x
+--R             + 
+--R                      2 2         2      4  4          2          3  2       3
+--R               (- 264a c  - 138a b c - 3b )x  + (- 264a b c - 6a b )x  - 132a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      3     3 2  8            2 2     4   6
+--R           (- 204a b c  + 3b c )x  + (- 408a b c  + 6b c)x
+--R         + 
+--R                  2   2         3      5  4          2 2        4  2       3
+--R           (- 408a b c  - 198a b c + 3b )x  + (- 408a b c + 6a b )x  - 204a b c
+--R         + 
+--R             2 3
+--R           3a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4| |          2                  \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                        3     2 2  8              2     3   6
+--R               (- 132a c  - 3b c )x  + (- 264a b c  - 6b c)x
+--R             + 
+--R                      2 2         2      4  4          2          3  2       3
+--R               (- 264a c  - 138a b c - 3b )x  + (- 264a b c - 6a b )x  - 132a c
+--R             + 
+--R                   2 2
+--R               - 3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3     3 2  8          2 2     4   6
+--R           (204a b c  - 3b c )x  + (408a b c  - 6b c)x
+--R         + 
+--R                2   2         3      5  4        2 2        4  2       3
+--R           (408a b c  + 198a b c - 3b )x  + (408a b c - 6a b )x  + 204a b c
+--R         + 
+--R               2 3
+--R           - 3a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                 \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R     + 
+--R                 3     2 2  6            2     3   4
+--R           (88a c  + 2b c )x  + (128a b c  + 4b c)x
+--R         + 
+--R                2 2        2      4  2      2          3
+--R           (152a c  + 26a b c + 2b )x  + 72a b c - 6a b
+--R      *
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2  +-+4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              3 4       2 2 3        4 2  8
+--R         (512a c  - 256a b c  + 32a b c )x
+--R       + 
+--R               3   3       2 3 2        5   6         4 3       2 4         6  4
+--R         (1024a b c  - 512a b c  + 64a b c)x  + (1024a c  - 192a b c + 32a b )x
+--R       + 
+--R               4   2       3 3       2 5  2       5 2       4 2       3 4
+--R         (1024a b c  - 512a b c + 64a b )x  + 512a c  - 256a b c + 32a b
+--R    *
+--R                          +--------------------+3  +------------------+3
+--R            +-----------+ |   +-----------+        | +-----------+
+--R       4+-+ |          2 4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 585
+t0:=x^(1/2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R      +-+
+--R     \|x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 585
+r0:=1/4*x^(3/2)*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/16*x^(3/2)*(5*b^4-45*a*b^2*c+52*a^2*c^2+b*c*(5*b^2-44*a*c)*x^2)/_
+   (a^2*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))+1/32*c^(1/4)*atan(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(5*b^3-44*a*b*c+(5*b^4-_
+   54*a*b^2*c+520*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)^2*_
+   (-b+sqrt(b^2-4*a*c))^(1/4))-1/32*c^(1/4)*atanh(2^(1/4)*c^(1/4)*_
+   sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(5*b^3-44*a*b*c+(5*b^4-_
+   54*a*b^2*c+520*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)^2*_
+   (-b+sqrt(b^2-4*a*c))^(1/4))-1/32*c^(1/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))*(5*b^4-54*a*b^2*c+520*a^2*c^2-b*(5*b^2-_
+   44*a*c)*sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)^(5/2)*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+1/32*c^(1/4)*atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(5*b^4-54*a*b^2*c+520*a^2*c^2-b*(5*b^2-_
+   44*a*c)*sqrt(b^2-4*a*c))/(2^(3/4)*a^2*(b^2-4*a*c)^(5/2)*(-b-_
+   sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                       3     3 2  8         2 2      4   6
+--R               (44a b c  - 5b c )x  + (88a b c  - 10b c)x
+--R             + 
+--R                   2   2        3      5  4       2 2         4  2      3
+--R               (88a b c  + 34a b c - 5b )x  + (88a b c - 10a b )x  + 44a b c
+--R             + 
+--R                   2 3
+--R               - 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4        2 3     4 2  8         2   3         3 2      5   6
+--R           (520a c  - 54a b c  + 5b c )x  + (1040a b c  - 108a b c  + 10b c)x
+--R         + 
+--R                 3 3       2 2 2        4      6  4
+--R           (1040a c  + 412a b c  - 44a b c + 5b )x
+--R         + 
+--R                 3   2       2 3         5  2       4 2      3 2      2 4
+--R           (1040a b c  - 108a b c + 10a b )x  + 520a c  - 54a b c + 5a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                 4+-+4+-+ +-+
+--R         4+-+4| |          2                  \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R                       3     3 2  8         2 2      4   6
+--R               (44a b c  - 5b c )x  + (88a b c  - 10b c)x
+--R             + 
+--R                   2   2        3      5  4       2 2         4  2      3
+--R               (88a b c  + 34a b c - 5b )x  + (88a b c - 10a b )x  + 44a b c
+--R             + 
+--R                   2 3
+--R               - 5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4        2 3     4 2  8
+--R           (- 520a c  + 54a b c  - 5b c )x
+--R         + 
+--R                   2   3         3 2      5   6
+--R           (- 1040a b c  + 108a b c  - 10b c)x
+--R         + 
+--R                   3 3       2 2 2        4      6  4
+--R           (- 1040a c  - 412a b c  + 44a b c - 5b )x
+--R         + 
+--R                   3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 1040a b c  + 108a b c - 10a b )x  - 520a c  + 54a b c - 5a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                4+-+4+-+ +-+
+--R         4+-+4|   |          2                 \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R     + 
+--R                         3     3 2  8           2 2      4   6
+--R               (- 44a b c  + 5b c )x  + (- 88a b c  + 10b c)x
+--R             + 
+--R                     2   2        3      5  4         2 2         4  2      3
+--R               (- 88a b c  - 34a b c + 5b )x  + (- 88a b c + 10a b )x  - 44a b c
+--R             + 
+--R                 2 3
+--R               5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4        2 3     4 2  8
+--R           (- 520a c  + 54a b c  - 5b c )x
+--R         + 
+--R                   2   3         3 2      5   6
+--R           (- 1040a b c  + 108a b c  - 10b c)x
+--R         + 
+--R                   3 3       2 2 2        4      6  4
+--R           (- 1040a c  - 412a b c  + 44a b c - 5b )x
+--R         + 
+--R                   3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 1040a b c  + 108a b c - 10a b )x  - 520a c  + 54a b c - 5a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                4+-+4+-+ +-+
+--R         4+-+4| |          2                 \|2 \|c \|x
+--R         \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R                         3     3 2  8           2 2      4   6
+--R               (- 44a b c  + 5b c )x  + (- 88a b c  + 10b c)x
+--R             + 
+--R                     2   2        3      5  4         2 2         4  2      3
+--R               (- 88a b c  - 34a b c + 5b )x  + (- 88a b c + 10a b )x  - 44a b c
+--R             + 
+--R                 2 3
+--R               5a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4        2 3     4 2  8         2   3         3 2      5   6
+--R           (520a c  - 54a b c  + 5b c )x  + (1040a b c  - 108a b c  + 10b c)x
+--R         + 
+--R                 3 3       2 2 2        4      6  4
+--R           (1040a c  + 412a b c  - 44a b c + 5b )x
+--R         + 
+--R                 3   2       2 3         5  2       4 2      3 2      2 4
+--R           (1040a b c  - 108a b c + 10a b )x  + 520a c  - 54a b c + 5a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+               4+-+4+-+ +-+
+--R         4+-+4|   |          2                \|2 \|c \|x
+--R         \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                         4| |          2
+--R                                         \|\|- 4a c + b   - b
+--R     + 
+--R                     3      3 2  7        2 3         2 2      4   5
+--R           (- 88a b c  + 10b c )x  + (104a c  - 178a b c  + 20b c)x
+--R         + 
+--R                 2   2        3       5  3        3 2       2 2         4
+--R           (- 16a b c  - 72a b c + 10b )x  + (168a c  - 138a b c + 18a b )x
+--R      *
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R         4+-+3 |          2  +-+4|   |          2      4| |          2
+--R         \|2  \|- 4a c + b  \|x \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R              4 4       3 2 3      2 4 2  8
+--R         (512a c  - 256a b c  + 32a b c )x
+--R       + 
+--R               4   3       3 3 2      2 5   6         5 3       3 4       2 6  4
+--R         (1024a b c  - 512a b c  + 64a b c)x  + (1024a c  - 192a b c + 32a b )x
+--R       + 
+--R               5   2       4 3       3 5  2       6 2       5 2       4 4
+--R         (1024a b c  - 512a b c + 64a b )x  + 512a c  - 256a b c + 32a b
+--R    *
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R       4+-+3 |          2 4|   |          2      4| |          2
+--R       \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 585
+t0:=1/(x^(1/2)*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          3 12       2 10        2     2   8              3  6
+--R         c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x
+--R       + 
+--R            2        2  4     2   2    3
+--R         (3a c + 3a b )x  + 3a b x  + a
+--R    *
+--R        +-+
+--R       \|x
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 585
+r0:=-3/32*c^(3/4)*atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (7*b^3-52*a*b*c+(-7*b^4+66*a*b^2*c-280*a^2*c^2)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*a^2*(b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(3/4))-3/32*c^(3/4)*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b-sqrt(b^2-4*a*c))^(1/4))*(7*b^3-_
+   52*a*b*c+(-7*b^4+66*a*b^2*c-280*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a^2*(b^2-4*a*c)^2*(-b-sqrt(b^2-4*a*c))^(3/4))-3/32*c^(3/4)*_
+   atan(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(7*b^3-_
+   52*a*b*c+(7*b^4-66*a*b^2*c+280*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a^2*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))-3/32*c^(3/4)*_
+   atanh(2^(1/4)*c^(1/4)*sqrt(x)/(-b+sqrt(b^2-4*a*c))^(1/4))*(7*b^3-_
+   52*a*b*c+(7*b^4-66*a*b^2*c+280*a^2*c^2)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a^2*(b^2-4*a*c)^2*(-b+sqrt(b^2-4*a*c))^(3/4))+1/4*(b^2-2*a*c+b*c*x^2)*_
+   sqrt(x)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+1/16*(7*b^4-55*a*b^2*c+_
+   60*a^2*c^2+b*c*(7*b^2-52*a*c)*x^2)*sqrt(x)/(a^2*(b^2-4*a*c)^2*_
+   (a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                        3      3 2  8          2 2      4   6
+--R               (156a b c  - 21b c )x  + (312a b c  - 42b c)x
+--R             + 
+--R                    2   2         3       5  4        2 2         4  2
+--R               (312a b c  + 114a b c - 21b )x  + (312a b c - 42a b )x
+--R             + 
+--R                   3         2 3
+--R               156a b c - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4         2 3      4 2  8         2   3         3 2      5   6
+--R           (840a c  - 198a b c  + 21b c )x  + (1680a b c  - 396a b c  + 42b c)x
+--R         + 
+--R                 3 3       2 2 2         4       6  4
+--R           (1680a c  + 444a b c  - 156a b c + 21b )x
+--R         + 
+--R                 3   2       2 3         5  2       4 2       3 2       2 4
+--R           (1680a b c  - 396a b c + 42a b )x  + 840a c  - 198a b c + 21a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                  4+-+4+-+ +-+
+--R         4+-+3 4| |          2                   \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                           4|   |          2
+--R                                           \|- \|- 4a c + b   - b
+--R     + 
+--R                        3      3 2  8          2 2      4   6
+--R               (156a b c  - 21b c )x  + (312a b c  - 42b c)x
+--R             + 
+--R                    2   2         3       5  4        2 2         4  2
+--R               (312a b c  + 114a b c - 21b )x  + (312a b c - 42a b )x
+--R             + 
+--R                   3         2 3
+--R               156a b c - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4         2 3      4 2  8
+--R           (- 840a c  + 198a b c  - 21b c )x
+--R         + 
+--R                   2   3         3 2      5   6
+--R           (- 1680a b c  + 396a b c  - 42b c)x
+--R         + 
+--R                   3 3       2 2 2         4       6  4
+--R           (- 1680a c  - 444a b c  + 156a b c - 21b )x
+--R         + 
+--R                   3   2       2 3         5  2       4 2       3 2       2 4
+--R           (- 1680a b c  + 396a b c - 42a b )x  - 840a c  + 198a b c - 21a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                  \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R                        3      3 2  8          2 2      4   6
+--R               (156a b c  - 21b c )x  + (312a b c  - 42b c)x
+--R             + 
+--R                    2   2         3       5  4        2 2         4  2
+--R               (312a b c  + 114a b c - 21b )x  + (312a b c - 42a b )x
+--R             + 
+--R                   3         2 3
+--R               156a b c - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4         2 3      4 2  8         2   3         3 2      5   6
+--R           (840a c  - 198a b c  + 21b c )x  + (1680a b c  - 396a b c  + 42b c)x
+--R         + 
+--R                 3 3       2 2 2         4       6  4
+--R           (1680a c  + 444a b c  - 156a b c + 21b )x
+--R         + 
+--R                 3   2       2 3         5  2       4 2       3 2       2 4
+--R           (1680a b c  - 396a b c + 42a b )x  + 840a c  - 198a b c + 21a b
+--R      *
+--R                +------------------+3
+--R                | +-----------+                 4+-+4+-+ +-+
+--R         4+-+3 4| |          2                  \|2 \|c \|x
+--R         \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                          4|   |          2
+--R                                          \|- \|- 4a c + b   - b
+--R     + 
+--R                        3      3 2  8          2 2      4   6
+--R               (156a b c  - 21b c )x  + (312a b c  - 42b c)x
+--R             + 
+--R                    2   2         3       5  4        2 2         4  2
+--R               (312a b c  + 114a b c - 21b )x  + (312a b c - 42a b )x
+--R             + 
+--R                   3         2 3
+--R               156a b c - 21a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4         2 3      4 2  8
+--R           (- 840a c  + 198a b c  - 21b c )x
+--R         + 
+--R                   2   3         3 2      5   6
+--R           (- 1680a b c  + 396a b c  - 42b c)x
+--R         + 
+--R                   3 3       2 2 2         4       6  4
+--R           (- 1680a c  - 444a b c  + 156a b c - 21b )x
+--R         + 
+--R                   3   2       2 3         5  2       4 2       3 2       2 4
+--R           (- 1680a b c  + 396a b c - 42a b )x  - 840a c  + 198a b c - 21a b
+--R      *
+--R                +--------------------+3
+--R                |   +-----------+                4+-+4+-+ +-+
+--R         4+-+3 4|   |          2                 \|2 \|c \|x
+--R         \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R     + 
+--R                      3      3 2  6        2 3         2 2      4   4
+--R           (- 104a b c  + 14b c )x  + (120a c  - 214a b c  + 28b c)x
+--R         + 
+--R                 2   2        3       5  2       3 2       2 2         4
+--R           (- 16a b c  - 88a b c + 14b )x  + 184a c  - 158a b c + 22a b
+--R      *
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2  +-+4|   |          2        4| |          2
+--R         \|2 \|- 4a c + b  \|x \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R              4 4       3 2 3      2 4 2  8
+--R         (512a c  - 256a b c  + 32a b c )x
+--R       + 
+--R               4   3       3 3 2      2 5   6         5 3       3 4       2 6  4
+--R         (1024a b c  - 512a b c  + 64a b c)x  + (1024a c  - 192a b c + 32a b )x
+--R       + 
+--R               5   2       4 3       3 5  2       6 2       5 2       4 4
+--R         (1024a b c  - 512a b c + 64a b )x  + 512a c  - 256a b c + 32a b
+--R    *
+--R                          +--------------------+3  +------------------+3
+--R            +-----------+ |   +-----------+        | +-----------+
+--R       4+-+ |          2 4|   |          2        4| |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 585
+t0:=(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R        7 7         6 6         2      5 5         3         4 4
+--R     c e x  + 7c d e x  + (21c d  + b)e x  + (35c d  + 5b d)e x
+--R   + 
+--R           4        2      3 3         5        3         2 2
+--R     (35c d  + 10b d  + a)e x  + (21c d  + 10b d  + 3a d)e x
+--R   + 
+--R          6       4       2          7      5      3
+--R     (7c d  + 5b d  + 3a d )e x + c d  + b d  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 412
+
+--S 413 of 585
+r0:=1/4*a*(d+e*x)^4/e+1/6*b*(d+e*x)^6/e+1/8*c*(d+e*x)^8/e
+--R 
+--R
+--R   (2)
+--R       1    8 8        7 7    7    2   1    6 6        3        5 5
+--R       - c e x  + c d e x  + (- c d  + - b)e x  + (7c d  + b d)e x
+--R       8                      2        6
+--R     + 
+--R        35    4   5    2   1    4 4        5   10    3        3 3
+--R       (-- c d  + - b d  + - a)e x  + (7c d  + -- b d  + a d)e x
+--R         4        2        4                    3
+--R     + 
+--R        7    6   5    4   3    2  2 2       7      5      3       1    8
+--R       (- c d  + - b d  + - a d )e x  + (c d  + b d  + a d )e x + - c d
+--R        2        2        2                                       8
+--R     + 
+--R       1    6   1    4
+--R       - b d  + - a d
+--R       6        4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 413
+
+--S 414 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 585
+t0:=(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      2 11 11      2   10 10       2 2         9 9        2 3            8 8
+--R     c e  x   + 11c d e  x   + (55c d  + 2b c)e x  + (165c d  + 18b c d)e x
+--R   + 
+--R          2 4          2           2  7 7
+--R     (330c d  + 72b c d  + 2a c + b )e x
+--R   + 
+--R          2 5           3              2    6 6
+--R     (462c d  + 168b c d  + (14a c + 7b )d)e x
+--R   + 
+--R          2 6           4               2  2         5 5
+--R     (462c d  + 252b c d  + (42a c + 21b )d  + 2a b)e x
+--R   + 
+--R          2 7           5               2  3            4 4
+--R     (330c d  + 252b c d  + (70a c + 35b )d  + 10a b d)e x
+--R   + 
+--R          2 8           6               2  4          2    2  3 3
+--R     (165c d  + 168b c d  + (70a c + 35b )d  + 20a b d  + a )e x
+--R   + 
+--R         2 9          7               2  5          3     2   2 2
+--R     (55c d  + 72b c d  + (42a c + 21b )d  + 20a b d  + 3a d)e x
+--R   + 
+--R         2 10          8              2  6          4     2 2        2 11
+--R     (11c d   + 18b c d  + (14a c + 7b )d  + 10a b d  + 3a d )e x + c d
+--R   + 
+--R           9            2  7         5    2 3
+--R     2b c d  + (2a c + b )d  + 2a b d  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 415
+
+--S 416 of 585
+r0:=1/4*a^2*(d+e*x)^4/e+1/3*a*b*(d+e*x)^6/e+1/8*(b^2+2*a*c)*(d+e*x)^8/e+_
+   1/5*b*c*(d+e*x)^10/e+1/12*c^2*(d+e*x)^12/e
+--R 
+--R
+--R   (2)
+--R        1  2 12 12    2   11 11    11  2 2   1      10 10
+--R       -- c e  x   + c d e  x   + (-- c d  + - b c)e  x
+--R       12                           2        5
+--R     + 
+--R        55  2 3           9 9    165  2 4         2   1       1  2  8 8
+--R       (-- c d  + 2b c d)e x  + (--- c d  + 9b c d  + - a c + - b )e x
+--R         3                        4                   4       8
+--R     + 
+--R           2 5          3            2    7 7
+--R       (66c d  + 24b c d  + (2a c + b )d)e x
+--R     + 
+--R           2 6          4           7  2  2   1      6 6
+--R       (77c d  + 42b c d  + (7a c + - b )d  + - a b)e x
+--R                                    2         3
+--R     + 
+--R           2 7   252      5              2  3           5 5
+--R       (66c d  + --- b c d  + (14a c + 7b )d  + 2a b d)e x
+--R                  5
+--R     + 
+--R        165  2 8          6    35       35  2  4         2   1  2  4 4
+--R       (--- c d  + 42b c d  + (-- a c + -- b )d  + 5a b d  + - a )e x
+--R         4                      2        4                   4
+--R     + 
+--R        55  2 9          7              2  5   20      3    2   3 3
+--R       (-- c d  + 24b c d  + (14a c + 7b )d  + -- a b d  + a d)e x
+--R         3                                      3
+--R     + 
+--R        11  2 10         8           7  2  6         4   3  2 2  2 2
+--R       (-- c d   + 9b c d  + (7a c + - b )d  + 5a b d  + - a d )e x
+--R         2                           2                   2
+--R     + 
+--R         2 11         9            2  7         5    2 3        1  2 12
+--R       (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )e x + -- c d
+--R                                                               12
+--R     + 
+--R       1      10    1       1  2  8   1      6   1  2 4
+--R       - b c d   + (- a c + - b )d  + - a b d  + - a d
+--R       5            4       8         3          4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 416
+
+--S 417 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 585
+t0:=(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      3 15 15      3   14 14        3 2       2  13 13
+--R     c e  x   + 15c d e  x   + (105c d  + 3b c )e  x
+--R   + 
+--R          3 3        2   12 12         3 4         2 2       2     2   11 11
+--R     (455c d  + 39b c d)e  x   + (1365c d  + 234b c d  + 3a c  + 3b c)e  x
+--R   + 
+--R           3 5         2 3         2      2     10 10
+--R     (3003c d  + 858b c d  + (33a c  + 33b c)d)e  x
+--R   + 
+--R           3 6          2 4          2       2   2             3  9 9
+--R     (5005c d  + 2145b c d  + (165a c  + 165b c)d  + 6a b c + b )e x
+--R   + 
+--R           3 7          2 5          2       2   3                3    8 8
+--R     (6435c d  + 3861b c d  + (495a c  + 495b c)d  + (54a b c + 9b )d)e x
+--R   + 
+--R              3 8          2 6          2       2   4                  3  2
+--R         6435c d  + 5148b c d  + (990a c  + 990b c)d  + (216a b c + 36b )d
+--R       + 
+--R           2        2
+--R         3a c + 3a b
+--R    *
+--R        7 7
+--R       e x
+--R   + 
+--R              3 9          2 7           2        2   5                  3  3
+--R         5005c d  + 5148b c d  + (1386a c  + 1386b c)d  + (504a b c + 84b )d
+--R       + 
+--R             2         2
+--R         (21a c + 21a b )d
+--R    *
+--R        6 6
+--R       e x
+--R   + 
+--R              3 10          2 8           2        2   6                   3  4
+--R         3003c d   + 3861b c d  + (1386a c  + 1386b c)d  + (756a b c + 126b )d
+--R       + 
+--R             2         2  2     2
+--R         (63a c + 63a b )d  + 3a b
+--R    *
+--R        5 5
+--R       e x
+--R   + 
+--R              3 11          2 9          2       2   7                   3  5
+--R         1365c d   + 2145b c d  + (990a c  + 990b c)d  + (756a b c + 126b )d
+--R       + 
+--R              2          2  3      2
+--R         (105a c + 105a b )d  + 15a b d
+--R    *
+--R        4 4
+--R       e x
+--R   + 
+--R             3 12         2 10          2       2   8                  3  6
+--R         455c d   + 858b c d   + (495a c  + 495b c)d  + (504a b c + 84b )d
+--R       + 
+--R              2          2  4      2   2    3
+--R         (105a c + 105a b )d  + 30a b d  + a
+--R    *
+--R        3 3
+--R       e x
+--R   + 
+--R             3 13         2 11          2       2   9                  3  7
+--R         105c d   + 234b c d   + (165a c  + 165b c)d  + (216a b c + 36b )d
+--R       + 
+--R             2         2  5      2   3     3
+--R         (63a c + 63a b )d  + 30a b d  + 3a d
+--R    *
+--R        2 2
+--R       e x
+--R   + 
+--R            3 14        2 12         2      2   10                3  8
+--R         15c d   + 39b c d   + (33a c  + 33b c)d   + (54a b c + 9b )d
+--R       + 
+--R             2         2  6      2   4     3 2
+--R         (21a c + 21a b )d  + 15a b d  + 3a d
+--R    *
+--R       e x
+--R   + 
+--R      3 15       2 13        2     2   11              3  9      2        2  7
+--R     c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d  + (3a c + 3a b )d
+--R   + 
+--R       2   5    3 3
+--R     3a b d  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 418
+
+--S 419 of 585
+r0:=1/4*a^3*(d+e*x)^4/e+1/2*a^2*b*(d+e*x)^6/e+3/8*a*(b^2+a*c)*(d+e*x)^8/e+_
+   1/10*b*(b^2+6*a*c)*(d+e*x)^10/e+1/4*c*(b^2+a*c)*(d+e*x)^12/e+_
+   3/14*b*c^2*(d+e*x)^14/e+1/16*c^3*(d+e*x)^16/e
+--R 
+--R
+--R   (2)
+--R        1  3 16 16    3   15 15    15  3 2    3    2  14 14
+--R       -- c e  x   + c d e  x   + (-- c d  + -- b c )e  x
+--R       16                           2        14
+--R     + 
+--R           3 3       2   13 13    455  3 4   39    2 2   1    2   1  2   12 12
+--R       (35c d  + 3b c d)e  x   + (--- c d  + -- b c d  + - a c  + - b c)e  x
+--R                                   4          2          4        4
+--R     + 
+--R            3 5        2 3        2     2     11 11
+--R       (273c d  + 78b c d  + (3a c  + 3b c)d)e  x
+--R     + 
+--R        1001  3 6   429    2 4    33    2   33  2   2   3          1  3  10 10
+--R       (---- c d  + --- b c d  + (-- a c  + -- b c)d  + - a b c + -- b )e  x
+--R          2          2             2         2          5         10
+--R     + 
+--R            3 7         2 5         2      2   3              3    9 9
+--R       (715c d  + 429b c d  + (55a c  + 55b c)d  + (6a b c + b )d)e x
+--R     + 
+--R           6435  3 8   1287    2 6    495    2   495  2   4              9  3  2
+--R           ---- c d  + ---- b c d  + (--- a c  + --- b c)d  + (27a b c + - b )d
+--R             8           2             4          4                      2
+--R         + 
+--R           3  2    3    2
+--R           - a c + - a b
+--R           8       8
+--R      *
+--R          8 8
+--R         e x
+--R     + 
+--R               3 9   5148    2 7          2       2   5                 3  3
+--R           715c d  + ---- b c d  + (198a c  + 198b c)d  + (72a b c + 12b )d
+--R                       7
+--R         + 
+--R              2        2
+--R           (3a c + 3a b )d
+--R      *
+--R          7 7
+--R         e x
+--R     + 
+--R           1001  3 10   1287    2 8          2       2   6                  3  4
+--R           ---- c d   + ---- b c d  + (231a c  + 231b c)d  + (126a b c + 21b )d
+--R             2            2
+--R         + 
+--R            21  2    21    2  2   1  2
+--R           (-- a c + -- a b )d  + - a b
+--R             2        2           2
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R               3 11         2 9          2       2   7    756         126  3  5
+--R           273c d   + 429b c d  + (198a c  + 198b c)d  + (--- a b c + --- b )d
+--R                                                           5           5
+--R         + 
+--R               2         2  3     2
+--R           (21a c + 21a b )d  + 3a b d
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R           455  3 12   429    2 10    495    2   495  2   8
+--R           --- c d   + --- b c d   + (--- a c  + --- b c)d
+--R            4           2              4          4
+--R         + 
+--R                          3  6    105  2    105    2  4   15  2   2   1  3
+--R           (126a b c + 21b )d  + (--- a c + --- a b )d  + -- a b d  + - a
+--R                                   4         4             2          4
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R              3 13        2 11         2      2   9                 3  7
+--R           35c d   + 78b c d   + (55a c  + 55b c)d  + (72a b c + 12b )d
+--R         + 
+--R               2         2  5      2   3    3
+--R           (21a c + 21a b )d  + 10a b d  + a d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R           15  3 14   39    2 12    33    2   33  2   10              9  3  8
+--R           -- c d   + -- b c d   + (-- a c  + -- b c)d   + (27a b c + - b )d
+--R            2          2             2         2                      2
+--R         + 
+--R            21  2    21    2  6   15  2   4   3  3 2
+--R           (-- a c + -- a b )d  + -- a b d  + - a d
+--R             2        2            2          2
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R            3 15       2 13        2     2   11              3  9
+--R           c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R         + 
+--R              2        2  7     2   5    3 3
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R         e x
+--R     + 
+--R        1  3 16    3    2 14    1    2   1  2   12    3          1  3  10
+--R       -- c d   + -- b c d   + (- a c  + - b c)d   + (- a b c + -- b )d
+--R       16         14            4        4            5         10
+--R     + 
+--R        3  2    3    2  8   1  2   6   1  3 4
+--R       (- a c + - a b )d  + - a b d  + - a d
+--R        8       8           2          4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 419
+
+--S 420 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 585
+t0:=(d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R        7 3 7         6 3 6         2      5 3 5         3         4 3 4
+--R     c e f x  + 7c d e f x  + (21c d  + b)e f x  + (35c d  + 5b d)e f x
+--R   + 
+--R           4        2      3 3 3         5        3         2 3 2
+--R     (35c d  + 10b d  + a)e f x  + (21c d  + 10b d  + 3a d)e f x
+--R   + 
+--R          6       4       2    3        7      5      3  3
+--R     (7c d  + 5b d  + 3a d )e f x + (c d  + b d  + a d )f
+--R                                                    Type: Polynomial(Integer)
+--E 421
+
+--S 422 of 585
+r0:=1/4*a*f^3*(d+e*x)^4/e+1/6*b*f^3*(d+e*x)^6/e+1/8*c*f^3*(d+e*x)^8/e
+--R 
+--R
+--R   (2)
+--R       1    8 3 8        7 3 7    7    2   1    6 3 6        3        5 3 5
+--R       - c e f x  + c d e f x  + (- c d  + - b)e f x  + (7c d  + b d)e f x
+--R       8                          2        6
+--R     + 
+--R        35    4   5    2   1    4 3 4        5   10    3        3 3 3
+--R       (-- c d  + - b d  + - a)e f x  + (7c d  + -- b d  + a d)e f x
+--R         4        2        4                      3
+--R     + 
+--R        7    6   5    4   3    2  2 3 2       7      5      3    3
+--R       (- c d  + - b d  + - a d )e f x  + (c d  + b d  + a d )e f x
+--R        2        2        2
+--R     + 
+--R        1    8   1    6   1    4  3
+--R       (- c d  + - b d  + - a d )f
+--R        8        6        4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 422
+
+--S 423 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 585
+t0:=(d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      2 11 3 11      2   10 3 10       2 2         9 3 9
+--R     c e  f x   + 11c d e  f x   + (55c d  + 2b c)e f x
+--R   + 
+--R          2 3            8 3 8        2 4          2           2  7 3 7
+--R     (165c d  + 18b c d)e f x  + (330c d  + 72b c d  + 2a c + b )e f x
+--R   + 
+--R          2 5           3              2    6 3 6
+--R     (462c d  + 168b c d  + (14a c + 7b )d)e f x
+--R   + 
+--R          2 6           4               2  2         5 3 5
+--R     (462c d  + 252b c d  + (42a c + 21b )d  + 2a b)e f x
+--R   + 
+--R          2 7           5               2  3            4 3 4
+--R     (330c d  + 252b c d  + (70a c + 35b )d  + 10a b d)e f x
+--R   + 
+--R          2 8           6               2  4          2    2  3 3 3
+--R     (165c d  + 168b c d  + (70a c + 35b )d  + 20a b d  + a )e f x
+--R   + 
+--R         2 9          7               2  5          3     2   2 3 2
+--R     (55c d  + 72b c d  + (42a c + 21b )d  + 20a b d  + 3a d)e f x
+--R   + 
+--R         2 10          8              2  6          4     2 2    3
+--R     (11c d   + 18b c d  + (14a c + 7b )d  + 10a b d  + 3a d )e f x
+--R   + 
+--R       2 11         9            2  7         5    2 3  3
+--R     (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )f
+--R                                                    Type: Polynomial(Integer)
+--E 424
+
+--S 425 of 585
+r0:=1/4*a^2*f^3*(d+e*x)^4/e+1/3*a*b*f^3*(d+e*x)^6/e+1/8*(b^2+2*a*c)*f^3*_
+   (d+e*x)^8/e+1/5*b*c*f^3*(d+e*x)^10/e+1/12*c^2*f^3*(d+e*x)^12/e
+--R 
+--R
+--R   (2)
+--R        1  2 12 3 12    2   11 3 11    11  2 2   1      10 3 10
+--R       -- c e  f x   + c d e  f x   + (-- c d  + - b c)e  f x
+--R       12                               2        5
+--R     + 
+--R        55  2 3           9 3 9    165  2 4         2   1       1  2  8 3 8
+--R       (-- c d  + 2b c d)e f x  + (--- c d  + 9b c d  + - a c + - b )e f x
+--R         3                          4                   4       8
+--R     + 
+--R           2 5          3            2    7 3 7
+--R       (66c d  + 24b c d  + (2a c + b )d)e f x
+--R     + 
+--R           2 6          4           7  2  2   1      6 3 6
+--R       (77c d  + 42b c d  + (7a c + - b )d  + - a b)e f x
+--R                                    2         3
+--R     + 
+--R           2 7   252      5              2  3           5 3 5
+--R       (66c d  + --- b c d  + (14a c + 7b )d  + 2a b d)e f x
+--R                  5
+--R     + 
+--R        165  2 8          6    35       35  2  4         2   1  2  4 3 4
+--R       (--- c d  + 42b c d  + (-- a c + -- b )d  + 5a b d  + - a )e f x
+--R         4                      2        4                   4
+--R     + 
+--R        55  2 9          7              2  5   20      3    2   3 3 3
+--R       (-- c d  + 24b c d  + (14a c + 7b )d  + -- a b d  + a d)e f x
+--R         3                                      3
+--R     + 
+--R        11  2 10         8           7  2  6         4   3  2 2  2 3 2
+--R       (-- c d   + 9b c d  + (7a c + - b )d  + 5a b d  + - a d )e f x
+--R         2                           2                   2
+--R     + 
+--R         2 11         9            2  7         5    2 3    3
+--R       (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )e f x
+--R     + 
+--R         1  2 12   1      10    1       1  2  8   1      6   1  2 4  3
+--R       (-- c d   + - b c d   + (- a c + - b )d  + - a b d  + - a d )f
+--R        12         5            4       8         3          4
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 425
+
+--S 426 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 585
+t0:=(d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      3 15 3 15      3   14 3 14        3 2       2  13 3 13
+--R     c e  f x   + 15c d e  f x   + (105c d  + 3b c )e  f x
+--R   + 
+--R          3 3        2   12 3 12         3 4         2 2       2     2   11 3 11
+--R     (455c d  + 39b c d)e  f x   + (1365c d  + 234b c d  + 3a c  + 3b c)e  f x
+--R   + 
+--R           3 5         2 3         2      2     10 3 10
+--R     (3003c d  + 858b c d  + (33a c  + 33b c)d)e  f x
+--R   + 
+--R           3 6          2 4          2       2   2             3  9 3 9
+--R     (5005c d  + 2145b c d  + (165a c  + 165b c)d  + 6a b c + b )e f x
+--R   + 
+--R           3 7          2 5          2       2   3                3    8 3 8
+--R     (6435c d  + 3861b c d  + (495a c  + 495b c)d  + (54a b c + 9b )d)e f x
+--R   + 
+--R              3 8          2 6          2       2   4                  3  2
+--R         6435c d  + 5148b c d  + (990a c  + 990b c)d  + (216a b c + 36b )d
+--R       + 
+--R           2        2
+--R         3a c + 3a b
+--R    *
+--R        7 3 7
+--R       e f x
+--R   + 
+--R              3 9          2 7           2        2   5                  3  3
+--R         5005c d  + 5148b c d  + (1386a c  + 1386b c)d  + (504a b c + 84b )d
+--R       + 
+--R             2         2
+--R         (21a c + 21a b )d
+--R    *
+--R        6 3 6
+--R       e f x
+--R   + 
+--R              3 10          2 8           2        2   6                   3  4
+--R         3003c d   + 3861b c d  + (1386a c  + 1386b c)d  + (756a b c + 126b )d
+--R       + 
+--R             2         2  2     2
+--R         (63a c + 63a b )d  + 3a b
+--R    *
+--R        5 3 5
+--R       e f x
+--R   + 
+--R              3 11          2 9          2       2   7                   3  5
+--R         1365c d   + 2145b c d  + (990a c  + 990b c)d  + (756a b c + 126b )d
+--R       + 
+--R              2          2  3      2
+--R         (105a c + 105a b )d  + 15a b d
+--R    *
+--R        4 3 4
+--R       e f x
+--R   + 
+--R             3 12         2 10          2       2   8                  3  6
+--R         455c d   + 858b c d   + (495a c  + 495b c)d  + (504a b c + 84b )d
+--R       + 
+--R              2          2  4      2   2    3
+--R         (105a c + 105a b )d  + 30a b d  + a
+--R    *
+--R        3 3 3
+--R       e f x
+--R   + 
+--R             3 13         2 11          2       2   9                  3  7
+--R         105c d   + 234b c d   + (165a c  + 165b c)d  + (216a b c + 36b )d
+--R       + 
+--R             2         2  5      2   3     3
+--R         (63a c + 63a b )d  + 30a b d  + 3a d
+--R    *
+--R        2 3 2
+--R       e f x
+--R   + 
+--R            3 14        2 12         2      2   10                3  8
+--R         15c d   + 39b c d   + (33a c  + 33b c)d   + (54a b c + 9b )d
+--R       + 
+--R             2         2  6      2   4     3 2
+--R         (21a c + 21a b )d  + 15a b d  + 3a d
+--R    *
+--R          3
+--R       e f x
+--R   + 
+--R          3 15       2 13        2     2   11              3  9
+--R         c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R       + 
+--R            2        2  7     2   5    3 3
+--R         (3a c + 3a b )d  + 3a b d  + a d
+--R    *
+--R        3
+--R       f
+--R                                                    Type: Polynomial(Integer)
+--E 427
+
+--S 428 of 585
+r0:=1/4*a^3*f^3*(d+e*x)^4/e+1/2*a^2*b*f^3*(d+e*x)^6/e+3/8*a*(b^2+a*c)*f^3*_
+   (d+e*x)^8/e+1/10*b*(b^2+6*a*c)*f^3*(d+e*x)^10/e+1/4*c*(b^2+a*c)*f^3*_
+   (d+e*x)^12/e+3/14*b*c^2*f^3*(d+e*x)^14/e+1/16*c^3*f^3*(d+e*x)^16/e
+--R 
+--R
+--R   (2)
+--R        1  3 16 3 16    3   15 3 15    15  3 2    3    2  14 3 14
+--R       -- c e  f x   + c d e  f x   + (-- c d  + -- b c )e  f x
+--R       16                               2        14
+--R     + 
+--R           3 3       2   13 3 13
+--R       (35c d  + 3b c d)e  f x
+--R     + 
+--R        455  3 4   39    2 2   1    2   1  2   12 3 12
+--R       (--- c d  + -- b c d  + - a c  + - b c)e  f x
+--R         4          2          4        4
+--R     + 
+--R            3 5        2 3        2     2     11 3 11
+--R       (273c d  + 78b c d  + (3a c  + 3b c)d)e  f x
+--R     + 
+--R        1001  3 6   429    2 4    33    2   33  2   2   3          1  3  10 3 10
+--R       (---- c d  + --- b c d  + (-- a c  + -- b c)d  + - a b c + -- b )e  f x
+--R          2          2             2         2          5         10
+--R     + 
+--R            3 7         2 5         2      2   3              3    9 3 9
+--R       (715c d  + 429b c d  + (55a c  + 55b c)d  + (6a b c + b )d)e f x
+--R     + 
+--R           6435  3 8   1287    2 6    495    2   495  2   4              9  3  2
+--R           ---- c d  + ---- b c d  + (--- a c  + --- b c)d  + (27a b c + - b )d
+--R             8           2             4          4                      2
+--R         + 
+--R           3  2    3    2
+--R           - a c + - a b
+--R           8       8
+--R      *
+--R          8 3 8
+--R         e f x
+--R     + 
+--R               3 9   5148    2 7          2       2   5                 3  3
+--R           715c d  + ---- b c d  + (198a c  + 198b c)d  + (72a b c + 12b )d
+--R                       7
+--R         + 
+--R              2        2
+--R           (3a c + 3a b )d
+--R      *
+--R          7 3 7
+--R         e f x
+--R     + 
+--R           1001  3 10   1287    2 8          2       2   6                  3  4
+--R           ---- c d   + ---- b c d  + (231a c  + 231b c)d  + (126a b c + 21b )d
+--R             2            2
+--R         + 
+--R            21  2    21    2  2   1  2
+--R           (-- a c + -- a b )d  + - a b
+--R             2        2           2
+--R      *
+--R          6 3 6
+--R         e f x
+--R     + 
+--R               3 11         2 9          2       2   7    756         126  3  5
+--R           273c d   + 429b c d  + (198a c  + 198b c)d  + (--- a b c + --- b )d
+--R                                                           5           5
+--R         + 
+--R               2         2  3     2
+--R           (21a c + 21a b )d  + 3a b d
+--R      *
+--R          5 3 5
+--R         e f x
+--R     + 
+--R           455  3 12   429    2 10    495    2   495  2   8
+--R           --- c d   + --- b c d   + (--- a c  + --- b c)d
+--R            4           2              4          4
+--R         + 
+--R                          3  6    105  2    105    2  4   15  2   2   1  3
+--R           (126a b c + 21b )d  + (--- a c + --- a b )d  + -- a b d  + - a
+--R                                   4         4             2          4
+--R      *
+--R          4 3 4
+--R         e f x
+--R     + 
+--R              3 13        2 11         2      2   9                 3  7
+--R           35c d   + 78b c d   + (55a c  + 55b c)d  + (72a b c + 12b )d
+--R         + 
+--R               2         2  5      2   3    3
+--R           (21a c + 21a b )d  + 10a b d  + a d
+--R      *
+--R          3 3 3
+--R         e f x
+--R     + 
+--R           15  3 14   39    2 12    33    2   33  2   10              9  3  8
+--R           -- c d   + -- b c d   + (-- a c  + -- b c)d   + (27a b c + - b )d
+--R            2          2             2         2                      2
+--R         + 
+--R            21  2    21    2  6   15  2   4   3  3 2
+--R           (-- a c + -- a b )d  + -- a b d  + - a d
+--R             2        2            2          2
+--R      *
+--R          2 3 2
+--R         e f x
+--R     + 
+--R            3 15       2 13        2     2   11              3  9
+--R           c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R         + 
+--R              2        2  7     2   5    3 3
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R            3
+--R         e f x
+--R     + 
+--R            1  3 16    3    2 14    1    2   1  2   12    3          1  3  10
+--R           -- c d   + -- b c d   + (- a c  + - b c)d   + (- a b c + -- b )d
+--R           16         14            4        4            5         10
+--R         + 
+--R            3  2    3    2  8   1  2   6   1  3 4
+--R           (- a c + - a b )d  + - a b d  + - a d
+--R            8       8           2          4
+--R      *
+--R          3
+--R         f
+--R  /
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 428
+
+--S 429 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 585
+t0:=(d+e*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                      4 4       3 3     2 2 2     3       4
+--R                     e x  + 4d e x  + 6d e x  + 4d e x + d
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 430
+
+--S 431 of 585
+r0:=x/c-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+(-b^2+_
+   2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R              +-----------+              | +-----------+
+--R              |          2            2  | |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R              +-----------+              |   +-----------+
+--R              |          2            2  |   |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R       e x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R         +-+ |          2  +-+ |   |          2       | |          2
+--R     c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 585
+t0:=(d+e*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                           3 3       2 2     2       3
+--R                          e x  + 3d e x  + 3d e x + d
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 433
+
+--S 434 of 585
+r0:=1/4*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(c*e)+1/2*b*atanh((b+2*c*(d+e*x)^2)/_
+   sqrt(b^2-4*a*c))/(c*e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    2 2                  2
+--R                2c e x  + 4c d e x + 2c d  + b
+--R       2b atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R     + 
+--R         log
+--R                 4 4         3 3        2      2 2        3                 4
+--R              c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R            + 
+--R                 2
+--R              b d  + a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     4c e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 585
+t0:=(d+e*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                                2 2             2
+--R                               e x  + 2d e x + d
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 436
+
+--S 437 of 585
+r0:=-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(b-sqrt(b^2-_
+   4*a*c))/(e*sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))/(e*sqrt(2)*_
+   sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +--------------------+
+--R          |   +-----------+                       +-+ +-+
+--R          |   |          2              (e x + d)\|2 \|c
+--R       - \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                      |   |          2
+--R                                     \|- \|- 4a c + b   + b
+--R     + 
+--R        +------------------+
+--R        | +-----------+                      +-+ +-+
+--R        | |          2             (e x + d)\|2 \|c
+--R       \|\|- 4a c + b   + b atan(---------------------)
+--R                                  +------------------+
+--R                                  | +-----------+
+--R                                  | |          2
+--R                                 \|\|- 4a c + b   + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     e\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 585
+t0:=(d+e*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                                     e x + d
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 439
+
+--S 440 of 585
+r0:=-atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                    2 2                  2
+--R                2c e x  + 4c d e x + 2c d  + b
+--R          atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R   (2)  - -------------------------------------
+--R                       +-----------+
+--R                       |          2
+--R                     e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 585
+t0:=1/((d+e*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          5 5         4 4         2      3 3         3         2 2
+--R       c e x  + 5c d e x  + (10c d  + b)e x  + (10c d  + 3b d)e x
+--R     + 
+--R            4       2              5      3
+--R       (5c d  + 3b d  + a)e x + c d  + b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 442
+
+--S 443 of 585
+r0:=log(d+e*x)/(a*e)-1/4*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a*e)+_
+   1/2*b*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(a*e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    2 2                  2
+--R                2c e x  + 4c d e x + 2c d  + b
+--R       2b atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R     + 
+--R           -
+--R              log
+--R                      4 4         3 3        2      2 2        3
+--R                   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                 + 
+--R                      4      2
+--R                   c d  + b d  + a
+--R         + 
+--R           4log(e x + d)
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     4a e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 444
+
+)clear all
+
+--S 445 of 585
+t0:=1/((d+e*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          6 6         5 5         2      4 4         3         3 3
+--R       c e x  + 6c d e x  + (15c d  + b)e x  + (20c d  + 4b d)e x
+--R     + 
+--R           4       2      2 2        5       3                 6      4      2
+--R     (15c d  + 6b d  + a)e x  + (6c d  + 4b d  + 2a d)e x + c d  + b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 445
+
+--S 446 of 585
+r0:=(-1)/(a*e*(d+e*x))-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(1+b/sqrt(b^2-4*a*c))/(a*e*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(1-b/sqrt(b^2-4*a*c))/(a*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                       +------------------+
+--R                      +-----------+                    | +-----------+
+--R                      |          2                 +-+ | |          2
+--R         ((- e x - d)\|- 4a c + b   - b e x - b d)\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                       +--------------------+
+--R                      +-----------+                    |   +-----------+
+--R                      |          2                 +-+ |   |          2
+--R         ((- e x - d)\|- 4a c + b   + b e x + b d)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R       - \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                         +--------------------+
+--R                           +-----------+ |   +-----------+
+--R           2           +-+ |          2  |   |          2
+--R       (a e x + a d e)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 585
+t0:=1/((d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          7 7         6 6         2      5 5         3         4 4
+--R       c e x  + 7c d e x  + (21c d  + b)e x  + (35c d  + 5b d)e x
+--R     + 
+--R             4        2      3 3         5        3         2 2
+--R       (35c d  + 10b d  + a)e x  + (21c d  + 10b d  + 3a d)e x
+--R     + 
+--R            6       4       2          7      5      3
+--R       (7c d  + 5b d  + 3a d )e x + c d  + b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 448
+
+--S 449 of 585
+r0:=(-1/2)/(a*e*(d+e*x)^2)-b*log(d+e*x)/(a^2*e)+1/4*b*log(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)/(a^2*e)-1/2*(b^2-2*a*c)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-_
+   4*a*c))/(a^2*e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    2  2 2             2                   2  2
+--R         ((4a c - 2b )e x  + (8a c - 4b )d e x + (4a c - 2b )d )
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                 2 2                 2
+--R             (b e x  + 2b d e x + b d )
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                  2 2                  2
+--R           (- 4b e x  - 8b d e x - 4b d )log(e x + d) - 2a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                   +-----------+
+--R        2 3 2     2   2      2 2   |          2
+--R     (4a e x  + 8a d e x + 4a d e)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 585
+t0:=1/((d+e*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          8 8         7 7         2      6 6         3         5 5
+--R       c e x  + 8c d e x  + (28c d  + b)e x  + (56c d  + 6b d)e x
+--R     + 
+--R             4        2      4 4         5        3         3 3
+--R       (70c d  + 15b d  + a)e x  + (56c d  + 20b d  + 4a d)e x
+--R     + 
+--R             6        4       2  2 2        7       5       3          8      6
+--R       (28c d  + 15b d  + 6a d )e x  + (8c d  + 6b d  + 4a d )e x + c d  + b d
+--R     + 
+--R          4
+--R       a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 451
+
+--S 452 of 585
+r0:=(-1/3)/(a*e*(d+e*x)^3)+b/(a^2*e*(d+e*x))+atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(a^2*_
+   e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(a^2*e*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                    +-----------+
+--R                3 3         2 2       2          3  |          2
+--R           (3b e x  + 9b d e x  + 9b d e x + 3b d )\|- 4a c + b
+--R         + 
+--R                       2  3 3                2    2 2                2  2
+--R           (- 6a c + 3b )e x  + (- 18a c + 9b )d e x  + (- 18a c + 9b )d e x
+--R         + 
+--R                       2  3
+--R           (- 6a c + 3b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                                    +-----------+
+--R                3 3         2 2       2          3  |          2
+--R           (3b e x  + 9b d e x  + 9b d e x + 3b d )\|- 4a c + b
+--R         + 
+--R                     2  3 3              2    2 2              2  2
+--R           (6a c - 3b )e x  + (18a c - 9b )d e x  + (18a c - 9b )d e x
+--R         + 
+--R                     2  3
+--R           (6a c - 3b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                              +-----------+
+--R              2 2                  2      +-+ |          2
+--R         (3b e x  + 6b d e x + 3b d  - a)\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                     +-----------+
+--R          2 4 3     2   3 2     2 2 2      2 3   +-+ |          2
+--R       (3a e x  + 9a d e x  + 9a d e x + 3a d e)\|2 \|- 4a c + b
+--R    *
+--R        +--------------------+ +------------------+
+--R        |   +-----------+      | +-----------+
+--R        |   |          2       | |          2
+--R       \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 585
+t0:=(d+e*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      4 4       3 3     2 2 2     3       4
+--R     e x  + 4d e x  + 6d e x  + 4d e x + d
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 454
+
+--S 455 of 585
+r0:=1/2*(d+e*x)*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+(-b^2-_
+   4*a*c)/sqrt(b^2-4*a*c))/((b^2-4*a*c)*e*sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-_
+   4*a*c)))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^2+_
+   4*a*c+b*sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e*sqrt(2)*sqrt(c)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2    2   4 4         2     2     3 3
+--R           (4a c  + b c)e x  + (16a c  + 4b c)d e x
+--R         + 
+--R                  2     2   2             3  2 2
+--R           ((24a c  + 6b c)d  + 4a b c + b )e x
+--R         + 
+--R                  2     2   3               3              2    2   4
+--R           ((16a c  + 4b c)d  + (8a b c + 2b )d)e x + (4a c  + b c)d
+--R         + 
+--R                      3  2     2       2
+--R           (4a b c + b )d  + 4a c + a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                       +-+ +-+
+--R          | |          2              (e x + d)\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2    2   4 4           2     2     3 3
+--R           (- 4a c  - b c)e x  + (- 16a c  - 4b c)d e x
+--R         + 
+--R                    2     2   2             3  2 2
+--R           ((- 24a c  - 6b c)d  - 4a b c - b )e x
+--R         + 
+--R                    2     2   3                 3                2    2   4
+--R           ((- 16a c  - 4b c)d  + (- 8a b c - 2b )d)e x + (- 4a c  - b c)d
+--R         + 
+--R                        3  2     2       2
+--R           (- 4a b c - b )d  - 4a c - a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R               3 3         2 2          2               3         +-+
+--R         (- b e x  - 3b d e x  + (- 3b d  - 2a)e x - b d  - 2a d)\|2
+--R      *
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R          |          2  +-+ |   |          2       | |          2
+--R         \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 585
+t0:=(d+e*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      3 3       2 2     2       3
+--R     e x  + 3d e x  + 3d e x + d
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 457
+
+--S 458 of 585
+r0:=1/2*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   b*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e)
+--R 
+--R
+--R   (2)
+--R                 4 4           3 3           2     2  2 2          3     2
+--R           2b c e x  + 8b c d e x  + (12b c d  + 2b )e x  + (8b c d  + 4b d)e x
+--R         + 
+--R                 4     2 2
+--R           2b c d  + 2b d  + 2a b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                         +-----------+
+--R             2 2                 2       |          2
+--R       (- b e x  - 2b d e x - b d  - 2a)\|- 4a c + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 585
+t0:=(d+e*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      2 2             2
+--R     e x  + 2d e x + d
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 460
+
+--S 461 of 585
+r0:=-1/2*(d+e*x)*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+_
+   e*x)^4))+atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (2*b-sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(2*b+sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                   4 4         3 3         2       2 2        3
+--R               2c e x  + 8c d e x  + (12c d  + 2b)e x  + (8c d  + 4b d)e x
+--R             + 
+--R                   4       2
+--R               2c d  + 2b d  + 2a
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   4 4            3 3             2     2  2 2
+--R           - 4b c e x  - 16b c d e x  + (- 24b c d  - 4b )e x
+--R         + 
+--R                     3     2              4     2 2
+--R           (- 16b c d  - 8b d)e x - 4b c d  - 4b d  - 4a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                   4 4         3 3         2       2 2        3
+--R               2c e x  + 8c d e x  + (12c d  + 2b)e x  + (8c d  + 4b d)e x
+--R             + 
+--R                   4       2
+--R               2c d  + 2b d  + 2a
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 4 4            3 3           2     2  2 2
+--R           4b c e x  + 16b c d e x  + (24b c d  + 4b )e x
+--R         + 
+--R                   3     2              4     2 2
+--R           (16b c d  + 8b d)e x + 4b c d  + 4b d  + 4a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                                                  +-----------+
+--R              3 3         2 2        2               3        +-+ |          2
+--R         (2c e x  + 6c d e x  + (6c d  + b)e x + 2c d  + b d)\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 585
+t0:=(d+e*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R     e x + d
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 463
+
+--S 464 of 585
+r0:=1/2*(-b-2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   2*c*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e)
+--R 
+--R
+--R   (2)
+--R               2 4 4      2   3 3         2 2         2 2
+--R           - 4c e x  - 16c d e x  + (- 24c d  - 4b c)e x
+--R         + 
+--R                 2 3                  2 4         2
+--R           (- 16c d  - 8b c d)e x - 4c d  - 4b c d  - 4a c
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                        +-----------+
+--R            2 2                  2      |          2
+--R       (2c e x  + 4c d e x + 2c d  + b)\|- 4a c + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 585
+t0:=1/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 466
+
+--S 467 of 585
+r0:=1/2*(d+e*x)*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(b+(b^2-12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*e*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(b+(-b^2+12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-_
+   4*a*c)*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2    2   4 4         2     2     3 3
+--R           (12a c  - b c)e x  + (48a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2              3  2 2
+--R           ((72a c  - 6b c)d  + 12a b c - b )e x
+--R         + 
+--R                  2     2   3                3               2    2   4
+--R           ((48a c  - 4b c)d  + (24a b c - 2b )d)e x + (12a c  - b c)d
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c - b )d  + 12a c - a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2    2   4 4           2     2     3 3
+--R           (- 12a c  + b c)e x  + (- 48a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2              3  2 2
+--R           ((- 72a c  + 6b c)d  - 12a b c + b )e x
+--R         + 
+--R                    2     2   3                  3                 2    2   4
+--R           ((- 48a c  + 4b c)d  + (- 24a b c + 2b )d)e x + (- 12a c  + b c)d
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c + b )d  - 12a c + a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  3 3           2 2            2           2            3
+--R           - b c e x  - 3b c d e x  + (- 3b c d  + 2a c - b )e x - b c d
+--R         + 
+--R                    2
+--R           (2a c - b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            2 2       2   5 4       2 2       2     4 3
+--R         (8a c  - 2a b c)e x  + (32a c  - 8a b c)d e x
+--R       + 
+--R              2 2        2   2     2          3  3 2
+--R         ((48a c  - 12a b c)d  + 8a b c - 2a b )e x
+--R       + 
+--R              2 2       2   3       2          3    2
+--R         ((32a c  - 8a b c)d  + (16a b c - 4a b )d)e x
+--R       + 
+--R             2 2       2   4      2          3  2     3      2 2
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + 8a c - 2a b )e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 585
+t0:=1/((d+e*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 9 9     2   8 8       2 2         7 7       2 3            6 6
+--R       c e x  + 9c d e x  + (36c d  + 2b c)e x  + (84c d  + 14b c d)e x
+--R     + 
+--R            2 4          2           2  5 5
+--R       (126c d  + 42b c d  + 2a c + b )e x
+--R     + 
+--R            2 5          3              2    4 4
+--R       (126c d  + 70b c d  + (10a c + 5b )d)e x
+--R     + 
+--R           2 6          4               2  2         3 3
+--R       (84c d  + 70b c d  + (20a c + 10b )d  + 2a b)e x
+--R     + 
+--R           2 7          5               2  3           2 2
+--R       (36c d  + 42b c d  + (20a c + 10b )d  + 6a b d)e x
+--R     + 
+--R          2 8          6              2  4         2    2        2 9         7
+--R       (9c d  + 14b c d  + (10a c + 5b )d  + 6a b d  + a )e x + c d  + 2b c d
+--R     + 
+--R                2  5         3    2
+--R       (2a c + b )d  + 2a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 469
+
+--S 470 of 585
+r0:=1/2*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+1/2*b*(b^2-6*a*c)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-_
+   4*a*c))/(a^2*(b^2-4*a*c)^(3/2)*e)+log(d+e*x)/(a^2*e)-1/4*log(a+b*_
+   (d+e*x)^2+c*(d+e*x)^4)/(a^2*e)
+--R 
+--R
+--R   (2)
+--R                   2     3   4 4           2     3     3 3
+--R           (12a b c  - 2b c)e x  + (48a b c  - 8b c)d e x
+--R         + 
+--R                    2      3   2        2      4  2 2
+--R           ((72a b c  - 12b c)d  + 12a b c - 2b )e x
+--R         + 
+--R                    2     3   3         2      4                 2     3   4
+--R           ((48a b c  - 8b c)d  + (24a b c - 4b )d)e x + (12a b c  - 2b c)d
+--R         + 
+--R                 2      4  2      2          3
+--R           (12a b c - 2b )d  + 12a b c - 2a b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                      2    2   4 4           2     2     3 3
+--R               (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R             + 
+--R                        2     2   2             3  2 2
+--R               ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R             + 
+--R                        2     2   3                 3                2    2   4
+--R               ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x + (- 4a c  + b c)d
+--R             + 
+--R                            3  2     2       2
+--R               (- 4a b c + b )d  - 4a c + a b
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                     2     2   4 4         2      2     3 3
+--R               (16a c  - 4b c)e x  + (64a c  - 16b c)d e x
+--R             + 
+--R                      2      2   2               3  2 2
+--R               ((96a c  - 24b c)d  + 16a b c - 4b )e x
+--R             + 
+--R                      2      2   3                3               2     2   4
+--R               ((64a c  - 16b c)d  + (32a b c - 8b )d)e x + (16a c  - 4b c)d
+--R             + 
+--R                            3  2      2        2
+--R               (16a b c - 4b )d  + 16a c - 4a b
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                     2 2                          2     2        2
+--R           - 2a b c e x  - 4a b c d e x - 2a b c d  + 4a c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             3 2     2 2   5 4       3 2      2 2     4 3
+--R         (16a c  - 4a b c)e x  + (64a c  - 16a b c)d e x
+--R       + 
+--R              3 2      2 2   2      3        2 3  3 2
+--R         ((96a c  - 24a b c)d  + 16a b c - 4a b )e x
+--R       + 
+--R              3 2      2 2   3       3        2 3    2
+--R         ((64a c  - 16a b c)d  + (32a b c - 8a b )d)e x
+--R       + 
+--R              3 2     2 2   4       3        2 3  2      4      3 2
+--R         ((16a c  - 4a b c)d  + (16a b c - 4a b )d  + 16a c - 4a b )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 585
+t0:=1/((d+e*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 10 10      2   9 9       2 2         8 8        2 3            7 7
+--R       c e  x   + 10c d e x  + (45c d  + 2b c)e x  + (120c d  + 16b c d)e x
+--R     + 
+--R            2 4          2           2  6 6
+--R       (210c d  + 56b c d  + 2a c + b )e x
+--R     + 
+--R            2 5           3              2    5 5
+--R       (252c d  + 112b c d  + (12a c + 6b )d)e x
+--R     + 
+--R            2 6           4               2  2         4 4
+--R       (210c d  + 140b c d  + (30a c + 15b )d  + 2a b)e x
+--R     + 
+--R            2 7           5               2  3           3 3
+--R       (120c d  + 112b c d  + (40a c + 20b )d  + 8a b d)e x
+--R     + 
+--R           2 8          6               2  4          2    2  2 2
+--R       (45c d  + 56b c d  + (30a c + 15b )d  + 12a b d  + a )e x
+--R     + 
+--R           2 9          7              2  5         3     2         2 10
+--R       (10c d  + 16b c d  + (12a c + 6b )d  + 8a b d  + 2a d)e x + c d
+--R     + 
+--R             8            2  6         4    2 2
+--R       2b c d  + (2a c + b )d  + 2a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 472
+
+--S 473 of 585
+r0:=1/2*(-3*b^2+10*a*c)/(a^2*(b^2-4*a*c)*e*(d+e*x))+1/2*(b^2-2*a*c+b*c*_
+   (d+e*x)^2)/(a*(b^2-4*a*c)*e*(d+e*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (3*b^2-10*a*c+b*(3*b^2-16*a*c)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*e*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2-10*a*c+(-3*b^3+16*a*b*c)/_
+   sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       2     2   5 5           2      2     4 4
+--R               (- 10a c  + 3b c)e x  + (- 50a c  + 15b c)d e x
+--R             + 
+--R                         2      2   2               3  3 3
+--R               ((- 100a c  + 30b c)d  - 10a b c + 3b )e x
+--R             + 
+--R                         2      2   3                  3    2 2
+--R               ((- 100a c  + 30b c)d  + (- 30a b c + 9b )d)e x
+--R             + 
+--R                        2      2   4                  3  2      2        2
+--R               ((- 50a c  + 15b c)d  + (- 30a b c + 9b )d  - 10a c + 3a b )e x
+--R             + 
+--R                       2     2   5                  3  3         2        2
+--R               (- 10a c  + 3b c)d  + (- 10a b c + 3b )d  + (- 10a c + 3a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   5 5             2      3     4 4
+--R           (- 16a b c  + 3b c)e x  + (- 80a b c  + 15b c)d e x
+--R         + 
+--R                       2      3   2        2      4  3 3
+--R           ((- 160a b c  + 30b c)d  - 16a b c + 3b )e x
+--R         + 
+--R                       2      3   3           2      4    2 2
+--R           ((- 160a b c  + 30b c)d  + (- 48a b c + 9b )d)e x
+--R         + 
+--R                      2      3   4           2      4  2      2          3
+--R           ((- 80a b c  + 15b c)d  + (- 48a b c + 9b )d  - 16a b c + 3a b )e x
+--R         + 
+--R                     2     3   5           2      4  3         2          3
+--R           (- 16a b c  + 3b c)d  + (- 16a b c + 3b )d  + (- 16a b c + 3a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                       2     2   5 5           2      2     4 4
+--R               (- 10a c  + 3b c)e x  + (- 50a c  + 15b c)d e x
+--R             + 
+--R                         2      2   2               3  3 3
+--R               ((- 100a c  + 30b c)d  - 10a b c + 3b )e x
+--R             + 
+--R                         2      2   3                  3    2 2
+--R               ((- 100a c  + 30b c)d  + (- 30a b c + 9b )d)e x
+--R             + 
+--R                        2      2   4                  3  2      2        2
+--R               ((- 50a c  + 15b c)d  + (- 30a b c + 9b )d  - 10a c + 3a b )e x
+--R             + 
+--R                       2     2   5                  3  3         2        2
+--R               (- 10a c  + 3b c)d  + (- 10a b c + 3b )d  + (- 10a c + 3a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   5 5           2      3     4 4
+--R           (16a b c  - 3b c)e x  + (80a b c  - 15b c)d e x
+--R         + 
+--R                     2      3   2        2      4  3 3
+--R           ((160a b c  - 30b c)d  + 16a b c - 3b )e x
+--R         + 
+--R                     2      3   3         2      4    2 2
+--R           ((160a b c  - 30b c)d  + (48a b c - 9b )d)e x
+--R         + 
+--R                    2      3   4         2      4  2      2          3
+--R           ((80a b c  - 15b c)d  + (48a b c - 9b )d  + 16a b c - 3a b )e x
+--R         + 
+--R                   2     3   5         2      4  3       2          3
+--R           (16a b c  - 3b c)d  + (16a b c - 3b )d  + (16a b c - 3a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2     2   4 4           2      2     3 3
+--R           (- 10a c  + 3b c)e x  + (- 40a c  + 12b c)d e x
+--R         + 
+--R                    2      2   2               3  2 2
+--R           ((- 60a c  + 18b c)d  - 11a b c + 3b )e x
+--R         + 
+--R                    2      2   3                  3                 2     2   4
+--R           ((- 40a c  + 12b c)d  + (- 22a b c + 6b )d)e x + (- 10a c  + 3b c)d
+--R         + 
+--R                          3  2     2        2
+--R           (- 11a b c + 3b )d  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            3 2     2 2   6 5       3 2      2 2     5 4
+--R         (8a c  - 2a b c)e x  + (40a c  - 10a b c)d e x
+--R       + 
+--R              3 2      2 2   2     3        2 3  4 3
+--R         ((80a c  - 20a b c)d  + 8a b c - 2a b )e x
+--R       + 
+--R              3 2      2 2   3       3        2 3    3 2
+--R         ((80a c  - 20a b c)d  + (24a b c - 6a b )d)e x
+--R       + 
+--R              3 2      2 2   4       3        2 3  2     4      3 2  2
+--R         ((40a c  - 10a b c)d  + (24a b c - 6a b )d  + 8a c - 2a b )e x
+--R       + 
+--R             3 2     2 2   5      3        2 3  3      4      3 2
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d)e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 585
+t0:=1/((d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 11 11      2   10 10       2 2         9 9        2 3            8 8
+--R       c e  x   + 11c d e  x   + (55c d  + 2b c)e x  + (165c d  + 18b c d)e x
+--R     + 
+--R            2 4          2           2  7 7
+--R       (330c d  + 72b c d  + 2a c + b )e x
+--R     + 
+--R            2 5           3              2    6 6
+--R       (462c d  + 168b c d  + (14a c + 7b )d)e x
+--R     + 
+--R            2 6           4               2  2         5 5
+--R       (462c d  + 252b c d  + (42a c + 21b )d  + 2a b)e x
+--R     + 
+--R            2 7           5               2  3            4 4
+--R       (330c d  + 252b c d  + (70a c + 35b )d  + 10a b d)e x
+--R     + 
+--R            2 8           6               2  4          2    2  3 3
+--R       (165c d  + 168b c d  + (70a c + 35b )d  + 20a b d  + a )e x
+--R     + 
+--R           2 9          7               2  5          3     2   2 2
+--R       (55c d  + 72b c d  + (42a c + 21b )d  + 20a b d  + 3a d)e x
+--R     + 
+--R           2 10          8              2  6          4     2 2        2 11
+--R       (11c d   + 18b c d  + (14a c + 7b )d  + 10a b d  + 3a d )e x + c d
+--R     + 
+--R             9            2  7         5    2 3
+--R       2b c d  + (2a c + b )d  + 2a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 475
+
+--S 476 of 585
+r0:=(-b^2+3*a*c)/(a^2*(b^2-4*a*c)*e*(d+e*x)^2)+1/2*(b^2-2*a*c+b*c*_
+   (d+e*x)^2)/(a*(b^2-4*a*c)*e*(d+e*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   (b^4-6*a*b^2*c+6*a^2*c^2)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/_
+   (a^3*(b^2-4*a*c)^(3/2)*e)-2*b*log(d+e*x)/(a^3*e)+1/2*b*log(a+b*_
+   (d+e*x)^2+c*(d+e*x)^4)/(a^3*e)
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   6 6       2 3        2 2      4     5 5
+--R           (12a c  - 12a b c  + 2b c)e x  + (72a c  - 72a b c  + 12b c)d e x
+--R         + 
+--R                 2 3         2 2      4   2      2   2        3      5  4 4
+--R           ((180a c  - 180a b c  + 30b c)d  + 12a b c  - 12a b c + 2b )e x
+--R         + 
+--R                 2 3         2 2      4   3       2   2        3      5    3 3
+--R           ((240a c  - 240a b c  + 40b c)d  + (48a b c  - 48a b c + 8b )d)e x
+--R         + 
+--R                    2 3         2 2      4   4       2   2        3       5  2
+--R               (180a c  - 180a b c  + 30b c)d  + (72a b c  - 72a b c + 12b )d
+--R             + 
+--R                  3 2      2 2        4
+--R               12a c  - 12a b c + 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                   2 3        2 2      4   5       2   2        3      5  3
+--R               (72a c  - 72a b c  + 12b c)d  + (48a b c  - 48a b c + 8b )d
+--R             + 
+--R                   3 2      2 2        4
+--R               (24a c  - 24a b c + 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2 3        2 2     4   6       2   2        3      5  4
+--R           (12a c  - 12a b c  + 2b c)d  + (12a b c  - 12a b c + 2b )d
+--R         + 
+--R               3 2      2 2        4  2
+--R           (12a c  - 12a b c + 2a b )d
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                      2    3   6 6           2     3     5 5
+--R               (4a b c  - b c)e x  + (24a b c  - 6b c)d e x
+--R             + 
+--R                        2      3   2       2     4  4 4
+--R               ((60a b c  - 15b c)d  + 4a b c - b )e x
+--R             + 
+--R                        2      3   3         2      4    3 3
+--R               ((80a b c  - 20b c)d  + (16a b c - 4b )d)e x
+--R             + 
+--R                        2      3   4         2      4  2     2         3  2 2
+--R               ((60a b c  - 15b c)d  + (24a b c - 6b )d  + 4a b c - a b )e x
+--R             + 
+--R                        2     3   5         2      4  3      2          3
+--R               ((24a b c  - 6b c)d  + (16a b c - 4b )d  + (8a b c - 2a b )d)e x
+--R             + 
+--R                      2    3   6        2     4  4      2         3  2
+--R               (4a b c  - b c)d  + (4a b c - b )d  + (4a b c - a b )d
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                         2     3   6 6             2      3     5 5
+--R               (- 16a b c  + 4b c)e x  + (- 96a b c  + 24b c)d e x
+--R             + 
+--R                           2      3   2        2      4  4 4
+--R               ((- 240a b c  + 60b c)d  - 16a b c + 4b )e x
+--R             + 
+--R                           2      3   3           2       4    3 3
+--R               ((- 320a b c  + 80b c)d  + (- 64a b c + 16b )d)e x
+--R             + 
+--R                              2      3   4           2       4  2      2
+--R                   (- 240a b c  + 60b c)d  + (- 96a b c + 24b )d  - 16a b c
+--R                 + 
+--R                       3
+--R                   4a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                             2      3   5           2       4  3
+--R                   (- 96a b c  + 24b c)d  + (- 64a b c + 16b )d
+--R                 + 
+--R                         2          3
+--R                   (- 32a b c + 8a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2     3   6           2      4  4         2          3  2
+--R             (- 16a b c  + 4b c)d  + (- 16a b c + 4b )d  + (- 16a b c + 4a b )d
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                2 2       2   4 4         2 2       2     3 3
+--R           (- 6a c  + 2a b c)e x  + (- 24a c  + 8a b c)d e x
+--R         + 
+--R                  2 2        2   2     2          3  2 2
+--R           ((- 36a c  + 12a b c)d  - 7a b c + 2a b )e x
+--R         + 
+--R                  2 2       2   3         2          3
+--R           ((- 24a c  + 8a b c)d  + (- 14a b c + 4a b )d)e x
+--R         + 
+--R                2 2       2   4        2          3  2     3     2 2
+--R           (- 6a c  + 2a b c)d  + (- 7a b c + 2a b )d  - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            4 2     3 2   7 6       4 2      3 2     6 5
+--R         (8a c  - 2a b c)e x  + (48a c  - 12a b c)d e x
+--R       + 
+--R               4 2      3 2   2     4        3 3  5 4
+--R         ((120a c  - 30a b c)d  + 8a b c - 2a b )e x
+--R       + 
+--R               4 2      3 2   3       4        3 3    4 3
+--R         ((160a c  - 40a b c)d  + (32a b c - 8a b )d)e x
+--R       + 
+--R               4 2      3 2   4       4         3 3  2     5      4 2  3 2
+--R         ((120a c  - 30a b c)d  + (48a b c - 12a b )d  + 8a c - 2a b )e x
+--R       + 
+--R              4 2      3 2   5       4        3 3  3       5      4 2    2
+--R         ((48a c  - 12a b c)d  + (32a b c - 8a b )d  + (16a c - 4a b )d)e x
+--R       + 
+--R             4 2     3 2   6      4        3 3  4      5      4 2  2
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 585
+t0:=1/((d+e*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 12 12      2   11 11       2 2         10 10        2 3            9 9
+--R       c e  x   + 12c d e  x   + (66c d  + 2b c)e  x   + (220c d  + 20b c d)e x
+--R     + 
+--R            2 4          2           2  8 8
+--R       (495c d  + 90b c d  + 2a c + b )e x
+--R     + 
+--R            2 5           3              2    7 7
+--R       (792c d  + 240b c d  + (16a c + 8b )d)e x
+--R     + 
+--R            2 6           4               2  2         6 6
+--R       (924c d  + 420b c d  + (56a c + 28b )d  + 2a b)e x
+--R     + 
+--R            2 7           5                2  3            5 5
+--R       (792c d  + 504b c d  + (112a c + 56b )d  + 12a b d)e x
+--R     + 
+--R            2 8           6                2  4          2    2  4 4
+--R       (495c d  + 420b c d  + (140a c + 70b )d  + 30a b d  + a )e x
+--R     + 
+--R            2 9           7                2  5          3     2   3 3
+--R       (220c d  + 240b c d  + (112a c + 56b )d  + 40a b d  + 4a d)e x
+--R     + 
+--R           2 10          8               2  6          4     2 2  2 2
+--R       (66c d   + 90b c d  + (56a c + 28b )d  + 30a b d  + 6a d )e x
+--R     + 
+--R           2 11          9              2  7          5     2 3        2 12
+--R       (12c d   + 20b c d  + (16a c + 8b )d  + 12a b d  + 4a d )e x + c d
+--R     + 
+--R             10            2  8         6    2 4
+--R       2b c d   + (2a c + b )d  + 2a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 478
+
+--S 479 of 585
+r0:=1/6*(-5*b^2+14*a*c)/(a^2*(b^2-4*a*c)*e*(d+e*x)^3)+1/2*b*(5*b^2-19*a*c)/_
+   (a^3*(b^2-4*a*c)*e*(d+e*x))+1/2*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*_
+   e*(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4))+1/2*atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(5*b^3-19*a*b*c+(5*b^4-_
+   29*a*b^2*c+28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*e*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(5*b^3-19*a*b*c+(-5*b^4+29*a*b^2*c-_
+   28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*e*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       2      3   7 7            2       3     6 6
+--R               (57a b c  - 15b c)e x  + (399a b c  - 105b c)d e x
+--R             + 
+--R                          2       3   2        2       4  5 5
+--R               ((1197a b c  - 315b c)d  + 57a b c - 15b )e x
+--R             + 
+--R                          2       3   3          2       4    4 4
+--R               ((1995a b c  - 525b c)d  + (285a b c - 75b )d)e x
+--R             + 
+--R                             2       3   4          2        4  2      2
+--R                   (1995a b c  - 525b c)d  + (570a b c - 150b )d  + 57a b c
+--R                 + 
+--R                          3
+--R                   - 15a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                             2       3   5          2        4  3
+--R                   (1197a b c  - 315b c)d  + (570a b c - 150b )d
+--R                 + 
+--R                        2           3
+--R                   (171a b c - 45a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                            2       3   6          2       4  4
+--R                   (399a b c  - 105b c)d  + (285a b c - 75b )d
+--R                 + 
+--R                        2           3  2
+--R                   (171a b c - 45a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2      3   7         2       4  5       2           3  3
+--R               (57a b c  - 15b c)d  + (57a b c - 15b )d  + (57a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 3        2 2      4   7 7
+--R           (- 84a c  + 87a b c  - 15b c)e x
+--R         + 
+--R                  2 3         2 2       4     6 6
+--R           (- 588a c  + 609a b c  - 105b c)d e x
+--R         + 
+--R                      2 3          2 2       4   2      2   2        3       5
+--R             ((- 1764a c  + 1827a b c  - 315b c)d  - 84a b c  + 87a b c - 15b )
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   3
+--R               (- 2940a c  + 3045a b c  - 525b c)d
+--R             + 
+--R                      2   2         3       5
+--R               (- 420a b c  + 435a b c - 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   4
+--R               (- 2940a c  + 3045a b c  - 525b c)d
+--R             + 
+--R                      2   2         3        5  2      3 2      2 2         4
+--R               (- 840a b c  + 870a b c - 150b )d  - 84a c  + 87a b c - 15a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   5
+--R               (- 1764a c  + 1827a b c  - 315b c)d
+--R             + 
+--R                      2   2         3        5  3
+--R               (- 840a b c  + 870a b c - 150b )d
+--R             + 
+--R                      3 2       2 2         4
+--R               (- 252a c  + 261a b c - 45a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      2 3         2 2       4   6
+--R               (- 588a c  + 609a b c  - 105b c)d
+--R             + 
+--R                      2   2         3       5  4
+--R               (- 420a b c  + 435a b c - 75b )d
+--R             + 
+--R                      3 2       2 2         4  2
+--R               (- 252a c  + 261a b c - 45a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2 3        2 2      4   7         2   2        3       5  5
+--R           (- 84a c  + 87a b c  - 15b c)d  + (- 84a b c  + 87a b c - 15b )d
+--R         + 
+--R                 3 2      2 2         4  3
+--R           (- 84a c  + 87a b c - 15a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                       2      3   7 7            2       3     6 6
+--R               (57a b c  - 15b c)e x  + (399a b c  - 105b c)d e x
+--R             + 
+--R                          2       3   2        2       4  5 5
+--R               ((1197a b c  - 315b c)d  + 57a b c - 15b )e x
+--R             + 
+--R                          2       3   3          2       4    4 4
+--R               ((1995a b c  - 525b c)d  + (285a b c - 75b )d)e x
+--R             + 
+--R                             2       3   4          2        4  2      2
+--R                   (1995a b c  - 525b c)d  + (570a b c - 150b )d  + 57a b c
+--R                 + 
+--R                          3
+--R                   - 15a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                             2       3   5          2        4  3
+--R                   (1197a b c  - 315b c)d  + (570a b c - 150b )d
+--R                 + 
+--R                        2           3
+--R                   (171a b c - 45a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                            2       3   6          2       4  4
+--R                   (399a b c  - 105b c)d  + (285a b c - 75b )d
+--R                 + 
+--R                        2           3  2
+--R                   (171a b c - 45a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2      3   7         2       4  5       2           3  3
+--R               (57a b c  - 15b c)d  + (57a b c - 15b )d  + (57a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 3        2 2      4   7 7
+--R           (84a c  - 87a b c  + 15b c)e x
+--R         + 
+--R                2 3         2 2       4     6 6
+--R           (588a c  - 609a b c  + 105b c)d e x
+--R         + 
+--R                  2 3          2 2       4   2      2   2        3       5  5 5
+--R           ((1764a c  - 1827a b c  + 315b c)d  + 84a b c  - 87a b c + 15b )e x
+--R         + 
+--R                       2 3          2 2       4   3
+--R                 (2940a c  - 3045a b c  + 525b c)d
+--R               + 
+--R                      2   2         3       5
+--R                 (420a b c  - 435a b c + 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2 3          2 2       4   4
+--R               (2940a c  - 3045a b c  + 525b c)d
+--R             + 
+--R                    2   2         3        5  2      3 2      2 2         4
+--R               (840a b c  - 870a b c + 150b )d  + 84a c  - 87a b c + 15a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2 3          2 2       4   5
+--R               (1764a c  - 1827a b c  + 315b c)d
+--R             + 
+--R                  2   2         3        5  3        3 2       2 2         4
+--R             (840a b c  - 870a b c + 150b )d  + (252a c  - 261a b c + 45a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                    2 3         2 2       4   6
+--R               (588a c  - 609a b c  + 105b c)d
+--R             + 
+--R                  2   2         3       5  4        3 2       2 2         4  2
+--R             (420a b c  - 435a b c + 75b )d  + (252a c  - 261a b c + 45a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2 3        2 2      4   7       2   2        3       5  5
+--R           (84a c  - 87a b c  + 15b c)d  + (84a b c  - 87a b c + 15b )d
+--R         + 
+--R               3 2      2 2         4  3
+--R           (84a c  - 87a b c + 15a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2      3   6 6            2      3     5 5
+--R           (57a b c  - 15b c)e x  + (342a b c  - 90b c)d e x
+--R         + 
+--R                     2       3   2      2 2        2       4  4 4
+--R           ((855a b c  - 225b c)d  - 14a c  + 62a b c - 15b )e x
+--R         + 
+--R                      2       3   3         2 2         2       4    3 3
+--R           ((1140a b c  - 300b c)d  + (- 56a c  + 248a b c - 60b )d)e x
+--R         + 
+--R                        2       3   4         2 2         2       4  2      2
+--R               (855a b c  - 225b c)d  + (- 84a c  + 372a b c - 90b )d  + 40a b c
+--R             + 
+--R                      3
+--R               - 10a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        2      3   5         2 2         2       4  3
+--R               (342a b c  - 90b c)d  + (- 56a c  + 248a b c - 60b )d
+--R             + 
+--R                   2           3
+--R               (80a b c - 20a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   2      3   6         2 2        2       4  4
+--R           (57a b c  - 15b c)d  + (- 14a c  + 62a b c - 15b )d
+--R         + 
+--R               2           3  2     3      2 2
+--R           (40a b c - 10a b )d  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R             4 2     3 2   8 7        4 2      3 2     7 6
+--R         (24a c  - 6a b c)e x  + (168a c  - 42a b c)d e x
+--R       + 
+--R               4 2       3 2   2      4        3 3  6 5
+--R         ((504a c  - 126a b c)d  + 24a b c - 6a b )e x
+--R       + 
+--R               4 2       3 2   3        4         3 3    5 4
+--R         ((840a c  - 210a b c)d  + (120a b c - 30a b )d)e x
+--R       + 
+--R               4 2       3 2   4        4         3 3  2      5      4 2  4 3
+--R         ((840a c  - 210a b c)d  + (240a b c - 60a b )d  + 24a c - 6a b )e x
+--R       + 
+--R                 4 2       3 2   5        4         3 3  3       5       4 2
+--R           ((504a c  - 126a b c)d  + (240a b c - 60a b )d  + (72a c - 18a b )d)
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R               4 2      3 2   6        4         3 3  4       5       4 2  2  2
+--R         ((168a c  - 42a b c)d  + (120a b c - 30a b )d  + (72a c - 18a b )d )e x
+--R       + 
+--R              4 2     3 2   7       4        3 3  5       5      4 2  3
+--R         ((24a c  - 6a b c)d  + (24a b c - 6a b )d  + (24a c - 6a b )d )e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 585
+t0:=(d+e*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      4 4       3 3     2 2 2     3       4
+--R     e x  + 4d e x  + 6d e x  + 4d e x + d
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 481
+
+--S 482 of 585
+r0:=1/4*(d+e*x)*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*_
+   (d+e*x)^4)^2)-1/8*(d+e*x)*(7*b^2-4*a*c+12*b*c*(d+e*x)^2)/((b^2-4*a*c)^2*_
+   e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+3/4*atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2+4*a*c-2*b*sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)^(5/2)*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-3/4*atan((d+e*x)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2+4*a*c+2*b*_
+   sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2 8 8        2   7 7            2 2      2   6 6
+--R               - 12b c e x  - 96b c d e x  + (- 336b c d  - 24b c)e x
+--R             + 
+--R                        2 3       2     5 5
+--R               (- 672b c d  - 144b c d)e x
+--R             + 
+--R                        2 4       2   2                3  4 4
+--R               (- 840b c d  - 360b c d  - 24a b c - 12b )e x
+--R             + 
+--R                        2 5       2   3                   3    3 3
+--R               (- 672b c d  - 480b c d  + (- 96a b c - 48b )d)e x
+--R             + 
+--R                        2 6       2   4                    3  2        2  2 2
+--R               (- 336b c d  - 360b c d  + (- 144a b c - 72b )d  - 24a b )e x
+--R             + 
+--R                       2 7       2   5                   3  3        2
+--R               (- 96b c d  - 144b c d  + (- 96a b c - 48b )d  - 48a b d)e x
+--R             + 
+--R                      2 8      2   6                   3  4        2 2      2
+--R               - 12b c d  - 24b c d  + (- 24a b c - 12b )d  - 24a b d  - 12a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8 8          3       2 2    7 7
+--R           (24a c  + 18b c )e x  + (192a c  + 144b c )d e x
+--R         + 
+--R                   3       2 2  2          2      3   6 6
+--R           ((672a c  + 504b c )d  + 48a b c  + 36b c)e x
+--R         + 
+--R                    3        2 2  3            2       3     5 5
+--R           ((1344a c  + 1008b c )d  + (288a b c  + 216b c)d)e x
+--R         + 
+--R                       3        2 2  4            2       3   2      2 2
+--R               (1680a c  + 1260b c )d  + (720a b c  + 540b c)d  + 48a c
+--R             + 
+--R                    2       4
+--R               60a b c + 18b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       3        2 2  5            2       3   3
+--R               (1344a c  + 1008b c )d  + (960a b c  + 720b c)d
+--R             + 
+--R                    2 2         2       4
+--R               (192a c  + 240a b c + 72b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      3       2 2  6            2       3   4
+--R               (672a c  + 504b c )d  + (720a b c  + 540b c)d
+--R             + 
+--R                    2 2         2        4  2      2           3
+--R               (288a c  + 360a b c + 108b )d  + 48a b c + 36a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3       2 2  7            2       3   5
+--R               (192a c  + 144b c )d  + (288a b c  + 216b c)d
+--R             + 
+--R                    2 2         2       4  3       2           3
+--R               (192a c  + 240a b c + 72b )d  + (96a b c + 72a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 3      2 2  8           2      3   6
+--R           (24a c  + 18b c )d  + (48a b c  + 36b c)d
+--R         + 
+--R               2 2        2       4  4       2           3  2      3       2 2
+--R           (48a c  + 60a b c + 18b )d  + (48a b c + 36a b )d  + 24a c + 18a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2 8 8        2   7 7            2 2      2   6 6
+--R               - 12b c e x  - 96b c d e x  + (- 336b c d  - 24b c)e x
+--R             + 
+--R                        2 3       2     5 5
+--R               (- 672b c d  - 144b c d)e x
+--R             + 
+--R                        2 4       2   2                3  4 4
+--R               (- 840b c d  - 360b c d  - 24a b c - 12b )e x
+--R             + 
+--R                        2 5       2   3                   3    3 3
+--R               (- 672b c d  - 480b c d  + (- 96a b c - 48b )d)e x
+--R             + 
+--R                        2 6       2   4                    3  2        2  2 2
+--R               (- 336b c d  - 360b c d  + (- 144a b c - 72b )d  - 24a b )e x
+--R             + 
+--R                       2 7       2   5                   3  3        2
+--R               (- 96b c d  - 144b c d  + (- 96a b c - 48b )d  - 48a b d)e x
+--R             + 
+--R                      2 8      2   6                   3  4        2 2      2
+--R               - 12b c d  - 24b c d  + (- 24a b c - 12b )d  - 24a b d  - 12a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8 8            3       2 2    7 7
+--R           (- 24a c  - 18b c )e x  + (- 192a c  - 144b c )d e x
+--R         + 
+--R                     3       2 2  2          2      3   6 6
+--R           ((- 672a c  - 504b c )d  - 48a b c  - 36b c)e x
+--R         + 
+--R                      3        2 2  3              2       3     5 5
+--R           ((- 1344a c  - 1008b c )d  + (- 288a b c  - 216b c)d)e x
+--R         + 
+--R                         3        2 2  4              2       3   2      2 2
+--R               (- 1680a c  - 1260b c )d  + (- 720a b c  - 540b c)d  - 48a c
+--R             + 
+--R                      2       4
+--R               - 60a b c - 18b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                         3        2 2  5              2       3   3
+--R               (- 1344a c  - 1008b c )d  + (- 960a b c  - 720b c)d
+--R             + 
+--R                      2 2         2       4
+--R               (- 192a c  - 240a b c - 72b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                        3       2 2  6              2       3   4
+--R               (- 672a c  - 504b c )d  + (- 720a b c  - 540b c)d
+--R             + 
+--R                      2 2         2        4  2      2           3
+--R               (- 288a c  - 360a b c - 108b )d  - 48a b c - 36a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        3       2 2  7              2       3   5
+--R               (- 192a c  - 144b c )d  + (- 288a b c  - 216b c)d
+--R             + 
+--R                      2 2         2       4  3         2           3
+--R               (- 192a c  - 240a b c - 72b )d  + (- 96a b c - 72a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   3      2 2  8             2      3   6
+--R           (- 24a c  - 18b c )d  + (- 48a b c  - 36b c)d
+--R         + 
+--R               2 2        2       4  4         2           3  2      3       2 2
+--R         (- 48a c  - 60a b c - 18b )d  + (- 48a b c - 36a b )d  - 24a c - 18a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 7 7        2   6 6            2 2       2      2   5 5
+--R           - 12b c e x  - 84b c d e x  + (- 252b c d  + 4a c  - 19b c)e x
+--R         + 
+--R                    2 3         2      2     4 4
+--R           (- 420b c d  + (20a c  - 95b c)d)e x
+--R         + 
+--R                    2 4         2       2   2               3  3 3
+--R           (- 420b c d  + (40a c  - 190b c)d  - 16a b c - 5b )e x
+--R         + 
+--R                    2 5         2       2   3                   3    2 2
+--R           (- 252b c d  + (40a c  - 190b c)d  + (- 48a b c - 15b )d)e x
+--R         + 
+--R                      2 6         2      2   4                   3  2      2
+--R               - 84b c d  + (20a c  - 95b c)d  + (- 48a b c - 15b )d  - 12a c
+--R             + 
+--R                     2
+--R               - 3a b
+--R          *
+--R             e x
+--R         + 
+--R                  2 7        2      2   5                  3  3
+--R           - 12b c d  + (4a c  - 19b c)d  + (- 16a b c - 5b )d
+--R         + 
+--R                 2        2
+--R           (- 12a c - 3a b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 4        2 3     4 2  9 8
+--R         (128a c  - 64a b c  + 8b c )e x
+--R       + 
+--R               2 4         2 3      4 2    8 7
+--R         (1024a c  - 512a b c  + 64b c )d e x
+--R       + 
+--R                  2 4          2 3       4 2  2       2   3         3 2      5
+--R           ((3584a c  - 1792a b c  + 224b c )d  + 256a b c  - 128a b c  + 16b c)
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (7168a c  - 3584a b c  + 448b c )d
+--R           + 
+--R                   2   3         3 2      5
+--R             (1536a b c  - 768a b c  + 96b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (8960a c  - 4480a b c  + 560b c )d
+--R           + 
+--R                   2   3          3 2       5   2       3 3        4      6
+--R             (3840a b c  - 1920a b c  + 240b c)d  + 256a c  - 48a b c + 8b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (7168a c  - 3584a b c  + 448b c )d
+--R           + 
+--R                 2   3          3 2       5   3         3 3         4       6
+--R           (5120a b c  - 2560a b c  + 320b c)d  + (1024a c  - 192a b c + 32b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  6
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   4
+--R             (3840a b c  - 1920a b c  + 240b c)d
+--R           + 
+--R                   3 3         4       6  2       3   2       2 3         5
+--R             (1536a c  - 288a b c + 48b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   2 4         2 3      4 2  7
+--R             (1024a c  - 512a b c  + 64b c )d
+--R           + 
+--R                   2   3         3 2      5   5         3 3         4       6  3
+--R             (1536a b c  - 768a b c  + 96b c)d  + (1024a c  - 192a b c + 32b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  2 4        2 3     4 2  8        2   3         3 2      5   6
+--R             (128a c  - 64a b c  + 8b c )d  + (256a b c  - 128a b c  + 16b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2       2 3         5  2
+--R             (256a c  - 48a b c + 8b )d  + (256a b c  - 128a b c + 16a b )d
+--R           + 
+--R                 4 2      3 2      2 4
+--R             128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+)clear all
+
+--S 484 of 585
+t0:=(d+e*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      3 3       2 2     2       3
+--R     e x  + 3d e x  + 3d e x + d
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 484
+
+--S 485 of 585
+r0:=1/4*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)-_
+   3/4*b*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   3*b*c*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e)
+--R 
+--R
+--R   (2)
+--R                3 8 8        3   7 7          3 2      2 2  6 6
+--R           12b c e x  + 96b c d e x  + (336b c d  + 24b c )e x
+--R         + 
+--R                  3 3       2 2   5 5
+--R           (672b c d  + 144b c d)e x
+--R         + 
+--R                  3 4       2 2 2          2      3   4 4
+--R           (840b c d  + 360b c d  + 24a b c  + 12b c)e x
+--R         + 
+--R                  3 5       2 2 3           2      3     3 3
+--R           (672b c d  + 480b c d  + (96a b c  + 48b c)d)e x
+--R         + 
+--R                  3 6       2 2 4            2      3   2        2   2 2
+--R           (336b c d  + 360b c d  + (144a b c  + 72b c)d  + 24a b c)e x
+--R         + 
+--R                 3 7       2 2 5           2      3   3        2
+--R           (96b c d  + 144b c d  + (96a b c  + 48b c)d  + 48a b c d)e x
+--R         + 
+--R                3 8      2 2 6           2      3   4        2   2      2
+--R           12b c d  + 24b c d  + (24a b c  + 12b c)d  + 24a b c d  + 12a b c
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                 2 6 6        2   5 5           2 2     2   4 4
+--R           - 6b c e x  - 36b c d e x  + (- 90b c d  - 9b c)e x
+--R         + 
+--R                    2 3      2     3 3
+--R           (- 120b c d  - 36b c d)e x
+--R         + 
+--R                   2 4      2   2               3  2 2
+--R           (- 90b c d  - 54b c d  - 10a b c - 2b )e x
+--R         + 
+--R                   2 5      2   3                  3             2 6     2   4
+--R           (- 36b c d  - 36b c d  + (- 20a b c - 4b )d)e x - 6b c d  - 9b c d
+--R         + 
+--R                          3  2     2       2
+--R           (- 10a b c - 2b )d  - 8a c - a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  9 8        2 4         2 3      4 2    8 7
+--R         (64a c  - 32a b c  + 4b c )e x  + (512a c  - 256a b c  + 32b c )d e x
+--R       + 
+--R                2 4         2 3       4 2  2       2   3        3 2     5   7 6
+--R         ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                  2   3         3 2      5
+--R             (768a b c  - 384a b c  + 48b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (4480a c  - 2240a b c  + 280b c )d
+--R           + 
+--R                   2   3         3 2       5   2       3 3        4      6
+--R             (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4         2 3       4 2  6
+--R             (1792a c  - 896a b c  + 112b c )d
+--R           + 
+--R                   2   3         3 2       5   4        3 3         4       6  2
+--R             (1920a b c  - 960a b c  + 120b c)d  + (768a c  - 144a b c + 24b )d
+--R           + 
+--R                 3   2      2 3        5
+--R             128a b c  - 64a b c + 8a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  2 4         2 3      4 2  7
+--R             (512a c  - 256a b c  + 32b c )d
+--R           + 
+--R                  2   3         3 2      5   5        3 3        4       6  3
+--R             (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 2 4        2 3     4 2  8        2   3        3 2     5   6
+--R             (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2      2 3        5  2
+--R             (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                4 2      3 2      2 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 585
+t0:=(d+e*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      2 2             2
+--R     e x  + 2d e x + d
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 487
+
+--S 488 of 585
+r0:=-1/4*(d+e*x)*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+_
+   e*x)^4)^2)+1/8*(d+e*x)*(b*(b^2+8*a*c)+c*(b^2+20*a*c)*(d+e*x)^2)/(a*_
+   (b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+1/8*atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b^2+20*a*c+b*(b^2-52*a*c)/_
+   sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   1/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (b^2+20*a*c-b*(b^2-52*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*e*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     3    2 2  8 8          3     2 2    7 7
+--R               (20a c  + b c )e x  + (160a c  + 8b c )d e x
+--R             + 
+--R                       3      2 2  2          2     3   6 6
+--R               ((560a c  + 28b c )d  + 40a b c  + 2b c)e x
+--R             + 
+--R                        3      2 2  3            2      3     5 5
+--R               ((1120a c  + 56b c )d  + (240a b c  + 12b c)d)e x
+--R             + 
+--R                           3      2 2  4            2      3   2      2 2
+--R                   (1400a c  + 70b c )d  + (600a b c  + 30b c)d  + 40a c
+--R                 + 
+--R                        2     4
+--R                   22a b c + b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           3      2 2  5            2      3   3
+--R                   (1120a c  + 56b c )d  + (800a b c  + 40b c)d
+--R                 + 
+--R                        2 2        2      4
+--R                   (160a c  + 88a b c + 4b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          3      2 2  6            2      3   4
+--R                   (560a c  + 28b c )d  + (600a b c  + 30b c)d
+--R                 + 
+--R                        2 2         2      4  2      2          3
+--R                   (240a c  + 132a b c + 6b )d  + 40a b c + 2a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          3     2 2  7            2      3   5
+--R                   (160a c  + 8b c )d  + (240a b c  + 12b c)d
+--R                 + 
+--R                        2 2        2      4  3       2          3
+--R                   (160a c  + 88a b c + 4b )d  + (80a b c + 4a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     3    2 2  8           2     3   6
+--R               (20a c  + b c )d  + (40a b c  + 2b c)d
+--R             + 
+--R                   2 2        2     4  4       2          3  2      3     2 2
+--R               (40a c  + 22a b c + b )d  + (40a b c + 2a b )d  + 20a c + a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     3    3 2  8 8              3     3 2    7 7
+--R           (- 52a b c  + b c )e x  + (- 416a b c  + 8b c )d e x
+--R         + 
+--R                        3      3 2  2         2 2     4   6 6
+--R           ((- 1456a b c  + 28b c )d  - 104a b c  + 2b c)e x
+--R         + 
+--R                        3      3 2  3            2 2      4     5 5
+--R           ((- 2912a b c  + 56b c )d  + (- 624a b c  + 12b c)d)e x
+--R         + 
+--R                           3      3 2  4             2 2      4   2       2   2
+--R               (- 3640a b c  + 70b c )d  + (- 1560a b c  + 30b c)d  - 104a b c
+--R             + 
+--R                      3     5
+--R               - 50a b c + b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                           3      3 2  5             2 2      4   3
+--R               (- 2912a b c  + 56b c )d  + (- 2080a b c  + 40b c)d
+--R             + 
+--R                      2   2         3      5
+--R               (- 416a b c  - 200a b c + 4b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                           3      3 2  6             2 2      4   4
+--R               (- 1456a b c  + 28b c )d  + (- 1560a b c  + 30b c)d
+--R             + 
+--R                      2   2         3      5  2       2 2        4
+--R               (- 624a b c  - 300a b c + 6b )d  - 104a b c + 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                          3     3 2  7            2 2      4   5
+--R               (- 416a b c  + 8b c )d  + (- 624a b c  + 12b c)d
+--R             + 
+--R                      2   2         3      5  3          2 2        4
+--R               (- 416a b c  - 200a b c + 4b )d  + (- 208a b c + 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R                     3    3 2  8            2 2     4   6
+--R           (- 52a b c  + b c )d  + (- 104a b c  + 2b c)d
+--R         + 
+--R                  2   2        3     5  4          2 2        4  2      3
+--R           (- 104a b c  - 50a b c + b )d  + (- 104a b c + 2a b )d  - 52a b c
+--R         + 
+--R            2 3
+--R           a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     3    2 2  8 8          3     2 2    7 7
+--R               (20a c  + b c )e x  + (160a c  + 8b c )d e x
+--R             + 
+--R                       3      2 2  2          2     3   6 6
+--R               ((560a c  + 28b c )d  + 40a b c  + 2b c)e x
+--R             + 
+--R                        3      2 2  3            2      3     5 5
+--R               ((1120a c  + 56b c )d  + (240a b c  + 12b c)d)e x
+--R             + 
+--R                           3      2 2  4            2      3   2      2 2
+--R                   (1400a c  + 70b c )d  + (600a b c  + 30b c)d  + 40a c
+--R                 + 
+--R                        2     4
+--R                   22a b c + b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           3      2 2  5            2      3   3
+--R                   (1120a c  + 56b c )d  + (800a b c  + 40b c)d
+--R                 + 
+--R                        2 2        2      4
+--R                   (160a c  + 88a b c + 4b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          3      2 2  6            2      3   4
+--R                   (560a c  + 28b c )d  + (600a b c  + 30b c)d
+--R                 + 
+--R                        2 2         2      4  2      2          3
+--R                   (240a c  + 132a b c + 6b )d  + 40a b c + 2a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          3     2 2  7            2      3   5
+--R                   (160a c  + 8b c )d  + (240a b c  + 12b c)d
+--R                 + 
+--R                        2 2        2      4  3       2          3
+--R                   (160a c  + 88a b c + 4b )d  + (80a b c + 4a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     3    2 2  8           2     3   6
+--R               (20a c  + b c )d  + (40a b c  + 2b c)d
+--R             + 
+--R                   2 2        2     4  4       2          3  2      3     2 2
+--R               (40a c  + 22a b c + b )d  + (40a b c + 2a b )d  + 20a c + a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3    3 2  8 8            3     3 2    7 7
+--R           (52a b c  - b c )e x  + (416a b c  - 8b c )d e x
+--R         + 
+--R                      3      3 2  2         2 2     4   6 6
+--R           ((1456a b c  - 28b c )d  + 104a b c  - 2b c)e x
+--R         + 
+--R                      3      3 2  3          2 2      4     5 5
+--R           ((2912a b c  - 56b c )d  + (624a b c  - 12b c)d)e x
+--R         + 
+--R                         3      3 2  4           2 2      4   2       2   2
+--R               (3640a b c  - 70b c )d  + (1560a b c  - 30b c)d  + 104a b c
+--R             + 
+--R                    3     5
+--R               50a b c - b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                         3      3 2  5           2 2      4   3
+--R               (2912a b c  - 56b c )d  + (2080a b c  - 40b c)d
+--R             + 
+--R                    2   2         3      5
+--R               (416a b c  + 200a b c - 4b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                         3      3 2  6           2 2      4   4
+--R               (1456a b c  - 28b c )d  + (1560a b c  - 30b c)d
+--R             + 
+--R                    2   2         3      5  2       2 2        4
+--R               (624a b c  + 300a b c - 6b )d  + 104a b c - 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        3     3 2  7          2 2      4   5
+--R               (416a b c  - 8b c )d  + (624a b c  - 12b c)d
+--R             + 
+--R                    2   2         3      5  3        2 2        4
+--R               (416a b c  + 200a b c - 4b )d  + (208a b c - 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   3    3 2  8          2 2     4   6
+--R           (52a b c  - b c )d  + (104a b c  - 2b c)d
+--R         + 
+--R                2   2        3     5  4        2 2        4  2      3       2 3
+--R           (104a b c  + 50a b c - b )d  + (104a b c - 2a b )d  + 52a b c - a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 3    2 2  7 7          3     2 2    6 6
+--R           (20a c  + b c )e x  + (140a c  + 7b c )d e x
+--R         + 
+--R                   3      2 2  2          2     3   5 5
+--R           ((420a c  + 21b c )d  + 28a b c  + 2b c)e x
+--R         + 
+--R                   3      2 2  3            2      3     4 4
+--R           ((700a c  + 35b c )d  + (140a b c  + 10b c)d)e x
+--R         + 
+--R                        3      2 2  4            2      3   2      2 2       2
+--R                 (700a c  + 35b c )d  + (280a b c  + 20b c)d  + 36a c  + 5a b c
+--R               + 
+--R                  4
+--R                 b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      3      2 2  5            2      3   3
+--R               (420a c  + 21b c )d  + (280a b c  + 20b c)d
+--R             + 
+--R                    2 2        2      4
+--R               (108a c  + 15a b c + 3b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3     2 2  6            2      3   4
+--R               (140a c  + 7b c )d  + (140a b c  + 10b c)d
+--R             + 
+--R                    2 2        2      4  2      2         3
+--R               (108a c  + 15a b c + 3b )d  + 16a b c - a b
+--R          *
+--R             e x
+--R         + 
+--R                 3    2 2  7           2     3   5       2 2       2     4  3
+--R           (20a c  + b c )d  + (28a b c  + 2b c)d  + (36a c  + 5a b c + b )d
+--R         + 
+--R               2         3
+--R           (16a b c - a b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              3 4      2 2 3       4 2  9 8
+--R         (128a c  - 64a b c  + 8a b c )e x
+--R       + 
+--R               3 4       2 2 3        4 2    8 7
+--R         (1024a c  - 512a b c  + 64a b c )d e x
+--R       + 
+--R                   3 4        2 2 3         4 2  2       3   3       2 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                  5
+--R             16a b c
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  3
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   3   3       2 3 2        5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  4
+--R             (8960a c  - 4480a b c  + 560a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   2       4 3      2 4        6
+--R             (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  5
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   3
+--R             (5120a b c  - 2560a b c  + 320a b c)d
+--R           + 
+--R                   4 3       2 4         6
+--R             (1024a c  - 192a b c + 32a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  6
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   4
+--R             (3840a b c  - 1920a b c  + 240a b c)d
+--R           + 
+--R                   4 3       2 4         6  2       4   2       3 3       2 5
+--R             (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   3 4       2 2 3        4 2  7
+--R             (1024a c  - 512a b c  + 64a b c )d
+--R           + 
+--R                   3   3       2 3 2        5   5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R           + 
+--R                 4 3       2 4         6  3        4   2       3 3       2 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  3 4      2 2 3       4 2  8
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  3   3       2 3 2        5   6        4 3      2 4        6  4
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  4   2       3 3       2 5  2       5 2      4 2      3 4
+--R             (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 585
+t0:=(d+e*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R     e x + d
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 490
+
+--S 491 of 585
+r0:=1/4*(-b-2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)+_
+   3/2*c*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   6*c^2*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e)
+--R 
+--R
+--R   (2)
+--R                4 8 8       4   7 7          4 2        3  6 6
+--R           - 24c e x  - 192c d e x  + (- 672c d  - 48b c )e x
+--R         + 
+--R                   4 3         3   5 5
+--R           (- 1344c d  - 288b c d)e x
+--R         + 
+--R                   4 4         3 2        3      2 2  4 4
+--R           (- 1680c d  - 720b c d  - 48a c  - 24b c )e x
+--R         + 
+--R                   4 5         3 3            3      2 2    3 3
+--R           (- 1344c d  - 960b c d  + (- 192a c  - 96b c )d)e x
+--R         + 
+--R                  4 6         3 4            3       2 2  2          2  2 2
+--R           (- 672c d  - 720b c d  + (- 288a c  - 144b c )d  - 48a b c )e x
+--R         + 
+--R                  4 7         3 5            3      2 2  3          2
+--R           (- 192c d  - 288b c d  + (- 192a c  - 96b c )d  - 96a b c d)e x
+--R         + 
+--R                4 8        3 6           3      2 2  4          2 2      2 2
+--R           - 24c d  - 48b c d  + (- 48a c  - 24b c )d  - 48a b c d  - 24a c
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R              3 6 6      3   5 5        3 2        2  4 4
+--R           12c e x  + 72c d e x  + (180c d  + 18b c )e x
+--R         + 
+--R                3 3        2   3 3        3 4         2 2        2     2   2 2
+--R           (240c d  + 72b c d)e x  + (180c d  + 108b c d  + 20a c  + 4b c)e x
+--R         + 
+--R               3 5        2 3         2     2             3 6        2 4
+--R           (72c d  + 72b c d  + (40a c  + 8b c)d)e x + 12c d  + 18b c d
+--R         + 
+--R                 2     2   2              3
+--R           (20a c  + 4b c)d  + 10a b c - b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  9 8        2 4         2 3      4 2    8 7
+--R         (64a c  - 32a b c  + 4b c )e x  + (512a c  - 256a b c  + 32b c )d e x
+--R       + 
+--R                2 4         2 3       4 2  2       2   3        3 2     5   7 6
+--R         ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                  2   3         3 2      5
+--R             (768a b c  - 384a b c  + 48b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (4480a c  - 2240a b c  + 280b c )d
+--R           + 
+--R                   2   3         3 2       5   2       3 3        4      6
+--R             (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4         2 3       4 2  6
+--R             (1792a c  - 896a b c  + 112b c )d
+--R           + 
+--R                   2   3         3 2       5   4        3 3         4       6  2
+--R             (1920a b c  - 960a b c  + 120b c)d  + (768a c  - 144a b c + 24b )d
+--R           + 
+--R                 3   2      2 3        5
+--R             128a b c  - 64a b c + 8a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  2 4         2 3      4 2  7
+--R             (512a c  - 256a b c  + 32b c )d
+--R           + 
+--R                  2   3         3 2      5   5        3 3        4       6  3
+--R             (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 2 4        2 3     4 2  8        2   3        3 2     5   6
+--R             (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2      2 3        5  2
+--R             (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                4 2      3 2      2 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 585
+t0:=1/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 493
+
+--S 494 of 585
+r0:=1/4*(d+e*x)*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/8*(d+e*x)*((b^2-7*a*c)*(3*b^2-4*a*c)+3*b*c*(b^2-8*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (b^3-8*a*b*c+(b^4-10*a*b^2*c+56*a^2*c^2)/sqrt(b^2-4*a*c))/(a^2*_
+   (b^2-4*a*c)^2*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+3/8*atan((d+e*x)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b^3-8*a*b*c+(-b^4+_
+   10*a*b^2*c-56*a^2*c^2)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^2*e*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                         3     3 2  8 8              3      3 2    7 7
+--R               (- 24a b c  + 3b c )e x  + (- 192a b c  + 24b c )d e x
+--R             + 
+--R                           3      3 2  2        2 2     4   6 6
+--R               ((- 672a b c  + 84b c )d  - 48a b c  + 6b c)e x
+--R             + 
+--R                            3       3 2  3            2 2      4     5 5
+--R               ((- 1344a b c  + 168b c )d  + (- 288a b c  + 36b c)d)e x
+--R             + 
+--R                               3       3 2  4            2 2      4   2
+--R                   (- 1680a b c  + 210b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                        2   2        3      5
+--R                   - 48a b c  - 18a b c + 3b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                               3       3 2  5            2 2       4   3
+--R                   (- 1344a b c  + 168b c )d  + (- 960a b c  + 120b c)d
+--R                 + 
+--R                          2   2        3       5
+--R                   (- 192a b c  - 72a b c + 12b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                              3      3 2  6            2 2      4   4
+--R                   (- 672a b c  + 84b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                          2   2         3       5  2      2 2        4
+--R                   (- 288a b c  - 108a b c + 18b )d  - 48a b c + 6a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                              3      3 2  7            2 2      4   5
+--R                   (- 192a b c  + 24b c )d  + (- 288a b c  + 36b c)d
+--R                 + 
+--R                          2   2        3       5  3         2 2         4
+--R                   (- 192a b c  - 72a b c + 12b )d  + (- 96a b c + 12a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )d  + (- 48a b c  + 6b c)d
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )d  + (- 48a b c + 6a b )d  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4        2 3     4 2  8 8
+--R           (168a c  - 30a b c  + 3b c )e x
+--R         + 
+--R                 2 4         2 3      4 2    7 7
+--R           (1344a c  - 240a b c  + 24b c )d e x
+--R         + 
+--R                  2 4         2 3      4 2  2       2   3        3 2     5   6 6
+--R           ((4704a c  - 840a b c  + 84b c )d  + 336a b c  - 60a b c  + 6b c)e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (9408a c  - 1680a b c  + 168b c )d
+--R             + 
+--R                     2   3         3 2      5
+--R               (2016a b c  - 360a b c  + 36b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      2 4          2 3       4 2  4
+--R               (11760a c  - 2100a b c  + 210b c )d
+--R             + 
+--R                     2   3         3 2      5   2       3 3       2 2 2
+--R               (5040a b c  - 900a b c  + 90b c)d  + 336a c  + 108a b c
+--R             + 
+--R                      4      6
+--R               - 24a b c + 3b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (9408a c  - 1680a b c  + 168b c )d
+--R             + 
+--R                     2   3          3 2       5   3
+--R               (6720a b c  - 1200a b c  + 120b c)d
+--R             + 
+--R                     3 3       2 2 2        4       6
+--R               (1344a c  + 432a b c  - 96a b c + 12b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2 4         2 3      4 2  6
+--R               (4704a c  - 840a b c  + 84b c )d
+--R             + 
+--R                     2   3         3 2      5   4
+--R               (5040a b c  - 900a b c  + 90b c)d
+--R             + 
+--R                     3 3       2 2 2         4       6  2       3   2      2 3
+--R               (2016a c  + 648a b c  - 144a b c + 18b )d  + 336a b c  - 60a b c
+--R             + 
+--R                   5
+--R               6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2 4         2 3      4 2  7
+--R               (1344a c  - 240a b c  + 24b c )d
+--R             + 
+--R                     2   3         3 2      5   5
+--R               (2016a b c  - 360a b c  + 36b c)d
+--R             + 
+--R                     3 3       2 2 2        4       6  3
+--R               (1344a c  + 432a b c  - 96a b c + 12b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (672a b c  - 120a b c + 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (168a c  - 30a b c  + 3b c )d  + (336a b c  - 60a b c  + 6b c)d
+--R         + 
+--R                3 3       2 2 2        4      6  4
+--R           (336a c  + 108a b c  - 24a b c + 3b )d
+--R         + 
+--R                3   2      2 3        5  2       4 2      3 2      2 4
+--R           (336a b c  - 60a b c + 6a b )d  + 168a c  - 30a b c + 3a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                         3     3 2  8 8              3      3 2    7 7
+--R               (- 24a b c  + 3b c )e x  + (- 192a b c  + 24b c )d e x
+--R             + 
+--R                           3      3 2  2        2 2     4   6 6
+--R               ((- 672a b c  + 84b c )d  - 48a b c  + 6b c)e x
+--R             + 
+--R                            3       3 2  3            2 2      4     5 5
+--R               ((- 1344a b c  + 168b c )d  + (- 288a b c  + 36b c)d)e x
+--R             + 
+--R                               3       3 2  4            2 2      4   2
+--R                   (- 1680a b c  + 210b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                        2   2        3      5
+--R                   - 48a b c  - 18a b c + 3b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                               3       3 2  5            2 2       4   3
+--R                   (- 1344a b c  + 168b c )d  + (- 960a b c  + 120b c)d
+--R                 + 
+--R                          2   2        3       5
+--R                   (- 192a b c  - 72a b c + 12b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                              3      3 2  6            2 2      4   4
+--R                   (- 672a b c  + 84b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                          2   2         3       5  2      2 2        4
+--R                   (- 288a b c  - 108a b c + 18b )d  - 48a b c + 6a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                              3      3 2  7            2 2      4   5
+--R                   (- 192a b c  + 24b c )d  + (- 288a b c  + 36b c)d
+--R                 + 
+--R                          2   2        3       5  3         2 2         4
+--R                   (- 192a b c  - 72a b c + 12b )d  + (- 96a b c + 12a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )d  + (- 48a b c  + 6b c)d
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )d  + (- 48a b c + 6a b )d  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4        2 3     4 2  8 8
+--R           (- 168a c  + 30a b c  - 3b c )e x
+--R         + 
+--R                   2 4         2 3      4 2    7 7
+--R           (- 1344a c  + 240a b c  - 24b c )d e x
+--R         + 
+--R                      2 4         2 3      4 2  2       2   3        3 2     5
+--R             ((- 4704a c  + 840a b c  - 84b c )d  - 336a b c  + 60a b c  - 6b c)
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  3
+--R               (- 9408a c  + 1680a b c  - 168b c )d
+--R             + 
+--R                       2   3         3 2      5
+--R               (- 2016a b c  + 360a b c  - 36b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  4
+--R               (- 11760a c  + 2100a b c  - 210b c )d
+--R             + 
+--R                       2   3         3 2      5   2       3 3       2 2 2
+--R               (- 5040a b c  + 900a b c  - 90b c)d  - 336a c  - 108a b c
+--R             + 
+--R                    4      6
+--R               24a b c - 3b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  5
+--R               (- 9408a c  + 1680a b c  - 168b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 6720a b c  + 1200a b c  - 120b c)d
+--R             + 
+--R                       3 3       2 2 2        4       6
+--R               (- 1344a c  - 432a b c  + 96a b c - 12b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 4         2 3      4 2  6
+--R               (- 4704a c  + 840a b c  - 84b c )d
+--R             + 
+--R                       2   3         3 2      5   4
+--R               (- 5040a b c  + 900a b c  - 90b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  2       3   2
+--R               (- 2016a c  - 648a b c  + 144a b c - 18b )d  - 336a b c
+--R             + 
+--R                  2 3        5
+--R               60a b c - 6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2 4         2 3      4 2  7
+--R               (- 1344a c  + 240a b c  - 24b c )d
+--R             + 
+--R                       2   3         3 2      5   5
+--R               (- 2016a b c  + 360a b c  - 36b c)d
+--R             + 
+--R                       3 3       2 2 2        4       6  3
+--R               (- 1344a c  - 432a b c  + 96a b c - 12b )d
+--R             + 
+--R                      3   2       2 3         5
+--R               (- 672a b c  + 120a b c - 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                  2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 168a c  + 30a b c  - 3b c )d  + (- 336a b c  + 60a b c  - 6b c)d
+--R         + 
+--R                  3 3       2 2 2        4      6  4
+--R           (- 336a c  - 108a b c  + 24a b c - 3b )d
+--R         + 
+--R                  3   2      2 3        5  2       4 2      3 2      2 4
+--R           (- 336a b c  + 60a b c - 6a b )d  - 168a c  + 30a b c - 3a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                     3     3 2  7 7              3      3 2    6 6
+--R           (- 24a b c  + 3b c )e x  + (- 168a b c  + 21b c )d e x
+--R         + 
+--R                       3      3 2  2      2 3        2 2     4   5 5
+--R           ((- 504a b c  + 63b c )d  + 28a c  - 49a b c  + 6b c)e x
+--R         + 
+--R                       3       3 2  3        2 3         2 2      4     4 4
+--R           ((- 840a b c  + 105b c )d  + (140a c  - 245a b c  + 30b c)d)e x
+--R         + 
+--R                          3       3 2  4        2 3         2 2      4   2
+--R               (- 840a b c  + 105b c )d  + (280a c  - 490a b c  + 60b c)d
+--R             + 
+--R                   2   2        3      5
+--R               - 4a b c  - 20a b c + 3b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                          3      3 2  5        2 3         2 2      4   3
+--R               (- 504a b c  + 63b c )d  + (280a c  - 490a b c  + 60b c)d
+--R             + 
+--R                     2   2        3      5
+--R               (- 12a b c  - 60a b c + 9b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                          3      3 2  6        2 3         2 2      4   4
+--R               (- 168a b c  + 21b c )d  + (140a c  - 245a b c  + 30b c)d
+--R             + 
+--R                     2   2        3      5  2      3 2      2 2        4
+--R               (- 12a b c  - 60a b c + 9b )d  + 44a c  - 37a b c + 5a b
+--R          *
+--R             e x
+--R         + 
+--R                     3     3 2  7       2 3        2 2     4   5
+--R           (- 24a b c  + 3b c )d  + (28a c  - 49a b c  + 6b c)d
+--R         + 
+--R                2   2        3      5  3       3 2      2 2        4
+--R           (- 4a b c  - 20a b c + 3b )d  + (44a c  - 37a b c + 5a b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              4 4      3 2 3     2 4 2  9 8
+--R         (128a c  - 64a b c  + 8a b c )e x
+--R       + 
+--R               4 4       3 2 3      2 4 2    8 7
+--R         (1024a c  - 512a b c  + 64a b c )d e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  2       4   3       3 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                2 5
+--R             16a b c
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  3
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   4   3       3 3 2      2 5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  4
+--R             (8960a c  - 4480a b c  + 560a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   2       5 3      3 4      2 6
+--R             (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  5
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   3
+--R             (5120a b c  - 2560a b c  + 320a b c)d
+--R           + 
+--R                   5 3       3 4       2 6
+--R             (1024a c  - 192a b c + 32a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  6
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   4
+--R             (3840a b c  - 1920a b c  + 240a b c)d
+--R           + 
+--R                   5 3       3 4       2 6  2       5   2       4 3       3 5
+--R             (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   4 4       3 2 3      2 4 2  7
+--R             (1024a c  - 512a b c  + 64a b c )d
+--R           + 
+--R                   4   3       3 3 2      2 5   5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R           + 
+--R                 5 3       3 4       2 6  3        5   2       4 3       3 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  4 4      3 2 3     2 4 2  8
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  4   3       3 3 2      2 5   6        5 3      3 4      2 6  4
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  5   2       4 3       3 5  2       6 2      5 2      4 4
+--R             (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 585
+t0:=1/((d+e*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 13 13      3   12 12       3 2       2  11 11
+--R       c e  x   + 13c d e  x   + (78c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   10 10        3 4         2 2       2     2   9 9
+--R       (286c d  + 33b c d)e  x   + (715c d  + 165b c d  + 3a c  + 3b c)e x
+--R     + 
+--R             3 5         2 3         2      2     8 8
+--R       (1287c d  + 495b c d  + (27a c  + 27b c)d)e x
+--R     + 
+--R             3 6         2 4          2       2   2             3  7 7
+--R       (1716c d  + 990b c d  + (108a c  + 108b c)d  + 6a b c + b )e x
+--R     + 
+--R             3 7          2 5          2       2   3                3    6 6
+--R       (1716c d  + 1386b c d  + (252a c  + 252b c)d  + (42a b c + 7b )d)e x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           1287c d  + 1386b c d  + (378a c  + 378b c)d  + (126a b c + 21b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           715c d  + 990b c d  + (378a c  + 378b c)d  + (210a b c + 35b )d
+--R         + 
+--R               2         2
+--R           (15a c + 15a b )d
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 10         2 8          2       2   6                  3  4
+--R           286c d   + 495b c d  + (252a c  + 252b c)d  + (210a b c + 35b )d
+--R         + 
+--R               2         2  2     2
+--R           (30a c + 30a b )d  + 3a b
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 11         2 9          2       2   7                  3  5
+--R           78c d   + 165b c d  + (108a c  + 108b c)d  + (126a b c + 21b )d
+--R         + 
+--R               2         2  3     2
+--R           (30a c + 30a b )d  + 9a b d
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 12        2 10         2      2   8                3  6
+--R           13c d   + 33b c d   + (27a c  + 27b c)d  + (42a b c + 7b )d
+--R         + 
+--R               2         2  4     2   2    3
+--R           (15a c + 15a b )d  + 9a b d  + a
+--R      *
+--R         e x
+--R     + 
+--R        3 13       2 11        2     2   9              3  7      2        2  5
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   3    3
+--R       3a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 496
+
+--S 497 of 585
+r0:=1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/4*(2*b^4-15*a*b^2*c+16*a^2*c^2+2*b*c*(b^2-7*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+1/2*b*_
+   (b^4-10*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/_
+   (a^3*(b^2-4*a*c)^(5/2)*e)+log(d+e*x)/(a^3*e)-1/4*log(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)/(a^3*e)
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  8 8
+--R           (60a b c  - 20a b c  + 2b c )e x
+--R         + 
+--R                2   4         3 3      5 2    7 7
+--R           (480a b c  - 160a b c  + 16b c )d e x
+--R         + 
+--R                    2   4         3 3      5 2  2       2 2 3        4 2     6
+--R             ((1680a b c  - 560a b c  + 56b c )d  + 120a b c  - 40a b c  + 4b c)
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  3
+--R               (3360a b c  - 1120a b c  + 112b c )d
+--R             + 
+--R                    2 2 3         4 2      6
+--R               (720a b c  - 240a b c  + 24b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  4
+--R               (4200a b c  - 1400a b c  + 140b c )d
+--R             + 
+--R                     2 2 3         4 2      6   2       3   3      2 3 2
+--R               (1800a b c  - 600a b c  + 60b c)d  + 120a b c  + 20a b c
+--R             + 
+--R                      5      7
+--R               - 16a b c + 2b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  5
+--R               (3360a b c  - 1120a b c  + 112b c )d
+--R             + 
+--R                     2 2 3         4 2      6   3
+--R               (2400a b c  - 800a b c  + 80b c)d
+--R             + 
+--R                    3   3      2 3 2        5      7
+--R               (480a b c  + 80a b c  - 64a b c + 8b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2   4         3 3      5 2  6
+--R               (1680a b c  - 560a b c  + 56b c )d
+--R             + 
+--R                     2 2 3         4 2      6   4
+--R               (1800a b c  - 600a b c  + 60b c)d
+--R             + 
+--R                    3   3       2 3 2        5       7  2       3 2 2      2 4
+--R               (720a b c  + 120a b c  - 96a b c + 12b )d  + 120a b c  - 40a b c
+--R             + 
+--R                   6
+--R               4a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                    2   4         3 3      5 2  7
+--R               (480a b c  - 160a b c  + 16b c )d
+--R             + 
+--R                    2 2 3         4 2      6   5
+--R               (720a b c  - 240a b c  + 24b c)d
+--R             + 
+--R                    3   3      2 3 2        5      7  3
+--R               (480a b c  + 80a b c  - 64a b c + 8b )d
+--R             + 
+--R                    3 2 2      2 4        6
+--R               (240a b c  - 80a b c + 8a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2   4        3 3     5 2  8        2 2 3        4 2     6   6
+--R           (60a b c  - 20a b c  + 2b c )d  + (120a b c  - 40a b c  + 4b c)d
+--R         + 
+--R                3   3      2 3 2        5      7  4
+--R           (120a b c  + 20a b c  - 16a b c + 2b )d
+--R         + 
+--R                3 2 2      2 4        6  2      4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )d  + 60a b c  - 20a b c + 2a b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                     2 4       2 3    4 2  8 8
+--R               (- 16a c  + 8a b c  - b c )e x
+--R             + 
+--R                      2 4        2 3     4 2    7 7
+--R               (- 128a c  + 64a b c  - 8b c )d e x
+--R             + 
+--R                            2 4         2 3      4 2  2      2   3        3 2
+--R                     (- 448a c  + 224a b c  - 28b c )d  - 32a b c  + 16a b c
+--R                   + 
+--R                         5
+--R                     - 2b c
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  3
+--R                   (- 896a c  + 448a b c  - 56b c )d
+--R                 + 
+--R                          2   3        3 2      5
+--R                   (- 192a b c  + 96a b c  - 12b c)d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2 4         2 3      4 2  4
+--R                   (- 1120a c  + 560a b c  - 70b c )d
+--R                 + 
+--R                          2   3         3 2      5   2      3 3       4     6
+--R                   (- 480a b c  + 240a b c  - 30b c)d  - 32a c  + 6a b c - b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  5
+--R                   (- 896a c  + 448a b c  - 56b c )d
+--R                 + 
+--R                          2   3         3 2      5   3
+--R                   (- 640a b c  + 320a b c  - 40b c)d
+--R                 + 
+--R                          3 3        4      6
+--R                   (- 128a c  + 24a b c - 4b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  6
+--R                   (- 448a c  + 224a b c  - 28b c )d
+--R                 + 
+--R                          2   3         3 2      5   4
+--R                   (- 480a b c  + 240a b c  - 30b c)d
+--R                 + 
+--R                          3 3        4      6  2      3   2      2 3        5
+--R                   (- 192a c  + 36a b c - 6b )d  - 32a b c  + 16a b c - 2a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2 4        2 3     4 2  7
+--R                   (- 128a c  + 64a b c  - 8b c )d
+--R                 + 
+--R                          2   3        3 2      5   5
+--R                   (- 192a b c  + 96a b c  - 12b c)d
+--R                 + 
+--R                        3 3        4      6  3         3   2      2 3        5
+--R                 (- 128a c  + 24a b c - 4b )d  + (- 64a b c  + 32a b c - 4a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2 4       2 3    4 2  8         2   3        3 2     5   6
+--R               (- 16a c  + 8a b c  - b c )d  + (- 32a b c  + 16a b c  - 2b c)d
+--R             + 
+--R                     3 3       4     6  4         3   2      2 3        5  2
+--R               (- 32a c  + 6a b c - b )d  + (- 32a b c  + 16a b c - 2a b )d
+--R             + 
+--R                    4 2     3 2     2 4
+--R               - 16a c  + 8a b c - a b
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                   2 4        2 3     4 2  8 8
+--R               (64a c  - 32a b c  + 4b c )e x
+--R             + 
+--R                    2 4         2 3      4 2    7 7
+--R               (512a c  - 256a b c  + 32b c )d e x
+--R             + 
+--R                         2 4         2 3       4 2  2       2   3        3 2
+--R                   (1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c
+--R                 + 
+--R                     5
+--R                   8b c
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  3
+--R                   (3584a c  - 1792a b c  + 224b c )d
+--R                 + 
+--R                        2   3         3 2      5
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  4
+--R                   (4480a c  - 2240a b c  + 280b c )d
+--R                 + 
+--R                       2   3         3 2       5   2       3 3        4      6
+--R                 (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  5
+--R                   (3584a c  - 1792a b c  + 224b c )d
+--R                 + 
+--R                         2   3          3 2       5   3
+--R                   (2560a b c  - 1280a b c  + 160b c)d
+--R                 + 
+--R                        3 3        4       6
+--R                   (512a c  - 96a b c + 16b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                         2 4         2 3       4 2  6
+--R                   (1792a c  - 896a b c  + 112b c )d
+--R                 + 
+--R                         2   3         3 2       5   4
+--R                   (1920a b c  - 960a b c  + 120b c)d
+--R                 + 
+--R                        3 3         4       6  2       3   2      2 3        5
+--R                   (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                        2 4         2 3      4 2  7
+--R                   (512a c  - 256a b c  + 32b c )d
+--R                 + 
+--R                        2   3         3 2      5   5
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R                 + 
+--R                      3 3        4       6  3        3   2       2 3         5
+--R                 (512a c  - 96a b c + 16b )d  + (256a b c  - 128a b c + 16a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                 2   3       3 2  6 6         2   3        3 2    5 5
+--R           (- 14a b c  + 2a b c )e x  + (- 84a b c  + 12a b c )d e x
+--R         + 
+--R                   2   3        3 2  2      3 3      2 2 2       4   4 4
+--R           ((- 210a b c  + 30a b c )d  + 16a c  - 29a b c  + 4a b c)e x
+--R         + 
+--R                   2   3        3 2  3       3 3       2 2 2        4     3 3
+--R           ((- 280a b c  + 40a b c )d  + (64a c  - 116a b c  + 16a b c)d)e x
+--R         + 
+--R                      2   3        3 2  4       3 3       2 2 2        4   2
+--R               (- 210a b c  + 30a b c )d  + (96a c  - 174a b c  + 24a b c)d
+--R             + 
+--R                   3   2      2 3        5
+--R               - 2a b c  - 12a b c + 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2   3        3 2  5       3 3       2 2 2        4   3
+--R               (- 84a b c  + 12a b c )d  + (64a c  - 116a b c  + 16a b c)d
+--R             + 
+--R                    3   2      2 3        5
+--R               (- 4a b c  - 24a b c + 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2   3       3 2  6       3 3      2 2 2       4   4
+--R           (- 14a b c  + 2a b c )d  + (16a c  - 29a b c  + 4a b c)d
+--R         + 
+--R                3   2      2 3        5  2      4 2      3 2      2 4
+--R           (- 2a b c  - 12a b c + 2a b )d  + 24a c  - 21a b c + 3a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             5 4      4 2 3     3 4 2  9 8
+--R         (64a c  - 32a b c  + 4a b c )e x
+--R       + 
+--R              5 4       4 2 3      3 4 2    8 7
+--R         (512a c  - 256a b c  + 32a b c )d e x
+--R       + 
+--R                     5 4       4 2 3       3 4 2  2       5   3      4 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  3
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  4
+--R             (4480a c  - 2240a b c  + 280a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   2       6 3      4 4      3 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  5
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   3
+--R             (2560a b c  - 1280a b c  + 160a b c)d
+--R           + 
+--R                  6 3      4 4       3 6
+--R             (512a c  - 96a b c + 16a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   5 4       4 2 3       3 4 2  6
+--R             (1792a c  - 896a b c  + 112a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   4
+--R             (1920a b c  - 960a b c  + 120a b c)d
+--R           + 
+--R                  6 3       4 4       3 6  2       6   2      5 3      4 5
+--R             (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  5 4       4 2 3      3 4 2  7
+--R             (512a c  - 256a b c  + 32a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5   5
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R           + 
+--R                  6 3      4 4       3 6  3        6   2       5 3       4 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R             (64a c  - 32a b c  + 4a b c )d  + (128a b c  - 64a b c  + 8a b c)d
+--R           + 
+--R                  6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R             (128a c  - 24a b c + 4a b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                7 2      6 2      5 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 585
+t0:=1/((d+e*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 14 14      3   13 13       3 2       2  12 12
+--R       c e  x   + 14c d e  x   + (91c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   11 11         3 4         2 2       2     2   10 10
+--R       (364c d  + 36b c d)e  x   + (1001c d  + 198b c d  + 3a c  + 3b c)e  x
+--R     + 
+--R             3 5         2 3         2      2     9 9
+--R       (2002c d  + 660b c d  + (30a c  + 30b c)d)e x
+--R     + 
+--R             3 6          2 4          2       2   2             3  8 8
+--R       (3003c d  + 1485b c d  + (135a c  + 135b c)d  + 6a b c + b )e x
+--R     + 
+--R             3 7          2 5          2       2   3                3    7 7
+--R       (3432c d  + 2376b c d  + (360a c  + 360b c)d  + (48a b c + 8b )d)e x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           3003c d  + 2772b c d  + (630a c  + 630b c)d  + (168a b c + 28b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R                3 9          2 7          2       2   5                  3  3
+--R           2002c d  + 2376b c d  + (756a c  + 756b c)d  + (336a b c + 56b )d
+--R         + 
+--R               2         2
+--R           (18a c + 18a b )d
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R                3 10          2 8          2       2   6                  3  4
+--R           1001c d   + 1485b c d  + (630a c  + 630b c)d  + (420a b c + 70b )d
+--R         + 
+--R               2         2  2     2
+--R           (45a c + 45a b )d  + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 11         2 9          2       2   7                  3  5
+--R           364c d   + 660b c d  + (360a c  + 360b c)d  + (336a b c + 56b )d
+--R         + 
+--R               2         2  3      2
+--R           (60a c + 60a b )d  + 12a b d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 12         2 10          2       2   8                  3  6
+--R           91c d   + 198b c d   + (135a c  + 135b c)d  + (168a b c + 28b )d
+--R         + 
+--R               2         2  4      2   2    3
+--R           (45a c + 45a b )d  + 18a b d  + a
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 13        2 11         2      2   9                3  7
+--R           14c d   + 36b c d   + (30a c  + 30b c)d  + (48a b c + 8b )d
+--R         + 
+--R               2         2  5      2   3     3
+--R           (18a c + 18a b )d  + 12a b d  + 2a d
+--R      *
+--R         e x
+--R     + 
+--R        3 14       2 12        2     2   10              3  8      2        2  6
+--R       c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   4    3 2
+--R       3a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 499
+
+--S 500 of 585
+r0:=-3/8*(5*b^2-12*a*c)*(b^2-5*a*c)/(a^3*(b^2-4*a*c)^2*e*(d+e*x))+_
+   1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(d+e*x)*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/8*(5*b^4-35*a*b^2*c+36*a^2*c^2+b*c*(5*b^2-32*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(d+e*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   ((5*b^2-12*a*c)*(b^2-5*a*c)+b*(5*b^4-47*a*b^2*c+124*a^2*c^2)/sqrt(b^2-_
+   4*a*c))/(a^3*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   ((5*b^2-12*a*c)*(b^2-5*a*c)+(-5*b^5+47*a*b^3*c-124*a^2*b*c^2)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2 4         2 3      4 2  9 9
+--R               (- 180a c  + 111a b c  - 15b c )e x
+--R             + 
+--R                       2 4         2 3       4 2    8 8
+--R               (- 1620a c  + 999a b c  - 135b c )d e x
+--R             + 
+--R                           2 4          2 3       4 2  2       2   3         3 2
+--R                   (- 6480a c  + 3996a b c  - 540b c )d  - 360a b c  + 222a b c
+--R                 + 
+--R                        5
+--R                   - 30b c
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  3
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                           2   3          3 2       5
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  4
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                           2   3          3 2       5   2       3 3      2 2 2
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d  - 360a c  + 42a b c
+--R                 + 
+--R                        4       6
+--R                   81a b c - 15b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  5
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                            2   3          3 2        5   3
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  6
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                            2   3          3 2        5   4
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  2       3   2
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d  - 360a b c
+--R                 + 
+--R                       2 3         5
+--R                   222a b c - 30a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2 4          2 3       4 2  7
+--R                   (- 6480a c  + 3996a b c  - 540b c )d
+--R                 + 
+--R                           2   3          3 2       5   5
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  3
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d
+--R                 + 
+--R                           3   2       2 3         5
+--R                   (- 1080a b c  + 666a b c - 90a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2 4         2 3       4 2  8
+--R                   (- 1620a c  + 999a b c  - 135b c )d
+--R                 + 
+--R                           2   3          3 2       5   6
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6  4
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R                 + 
+--R                           3   2       2 3         5  2       4 2       3 2
+--R                   (- 1080a b c  + 666a b c - 90a b )d  - 180a c  + 111a b c
+--R                 + 
+--R                        2 4
+--R                   - 15a b
+--R              *
+--R                 e x
+--R             + 
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )d
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)d
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )d
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )d
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2   4         3 3      5 2  9 9
+--R           (- 372a b c  + 141a b c  - 15b c )e x
+--R         + 
+--R                   2   4          3 3       5 2    8 8
+--R           (- 3348a b c  + 1269a b c  - 135b c )d e x
+--R         + 
+--R                        2   4          3 3       5 2  2       2 2 3         4 2
+--R               (- 13392a b c  + 5076a b c  - 540b c )d  - 744a b c  + 282a b c
+--R             + 
+--R                    6
+--R               - 30b c
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  3
+--R               (- 31248a b c  + 11844a b c  - 1260b c )d
+--R             + 
+--R                       2 2 3          4 2       6
+--R               (- 5208a b c  + 1974a b c  - 210b c)d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  4
+--R               (- 46872a b c  + 17766a b c  - 1890b c )d
+--R             + 
+--R                        2 2 3          4 2       6   2       3   3      2 3 2
+--R               (- 15624a b c  + 5922a b c  - 630b c)d  - 744a b c  - 90a b c
+--R             + 
+--R                     5       7
+--R               111a b c - 15b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  5
+--R               (- 46872a b c  + 17766a b c  - 1890b c )d
+--R             + 
+--R                        2 2 3          4 2        6   3
+--R               (- 26040a b c  + 9870a b c  - 1050b c)d
+--R             + 
+--R                       3   3       2 3 2         5       7
+--R               (- 3720a b c  - 450a b c  + 555a b c - 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  6
+--R               (- 31248a b c  + 11844a b c  - 1260b c )d
+--R             + 
+--R                        2 2 3          4 2        6   4
+--R               (- 26040a b c  + 9870a b c  - 1050b c)d
+--R             + 
+--R                       3   3       2 3 2          5        7  2       3 2 2
+--R               (- 7440a b c  - 900a b c  + 1110a b c - 150b )d  - 744a b c
+--R             + 
+--R                   2 4         6
+--R               282a b c - 30a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                        2   4          3 3       5 2  7
+--R               (- 13392a b c  + 5076a b c  - 540b c )d
+--R             + 
+--R                        2 2 3          4 2       6   5
+--R               (- 15624a b c  + 5922a b c  - 630b c)d
+--R             + 
+--R                       3   3       2 3 2          5        7  3
+--R               (- 7440a b c  - 900a b c  + 1110a b c - 150b )d
+--R             + 
+--R                       3 2 2       2 4         6
+--R               (- 2232a b c  + 846a b c - 90a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2   4          3 3       5 2  8
+--R               (- 3348a b c  + 1269a b c  - 135b c )d
+--R             + 
+--R                       2 2 3          4 2       6   6
+--R               (- 5208a b c  + 1974a b c  - 210b c)d
+--R             + 
+--R                       3   3       2 3 2         5       7  4
+--R               (- 3720a b c  - 450a b c  + 555a b c - 75b )d
+--R             + 
+--R                       3 2 2       2 4         6  2       4   2       3 3
+--R               (- 2232a b c  + 846a b c - 90a b )d  - 372a b c  + 141a b c
+--R             + 
+--R                    2 5
+--R               - 15a b
+--R          *
+--R             e x
+--R         + 
+--R                  2   4         3 3      5 2  9
+--R           (- 372a b c  + 141a b c  - 15b c )d
+--R         + 
+--R                  2 2 3         4 2      6   7
+--R           (- 744a b c  + 282a b c  - 30b c)d
+--R         + 
+--R                  3   3      2 3 2         5       7  5
+--R           (- 744a b c  - 90a b c  + 111a b c - 15b )d
+--R         + 
+--R                  3 2 2       2 4         6  3
+--R           (- 744a b c  + 282a b c - 30a b )d
+--R         + 
+--R                  4   2       3 3       2 5
+--R           (- 372a b c  + 141a b c - 15a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2 4         2 3      4 2  9 9
+--R               (- 180a c  + 111a b c  - 15b c )e x
+--R             + 
+--R                       2 4         2 3       4 2    8 8
+--R               (- 1620a c  + 999a b c  - 135b c )d e x
+--R             + 
+--R                           2 4          2 3       4 2  2       2   3         3 2
+--R                   (- 6480a c  + 3996a b c  - 540b c )d  - 360a b c  + 222a b c
+--R                 + 
+--R                        5
+--R                   - 30b c
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  3
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                           2   3          3 2       5
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  4
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                           2   3          3 2       5   2       3 3      2 2 2
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d  - 360a c  + 42a b c
+--R                 + 
+--R                        4       6
+--R                   81a b c - 15b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  5
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                            2   3          3 2        5   3
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  6
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                            2   3          3 2        5   4
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  2       3   2
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d  - 360a b c
+--R                 + 
+--R                       2 3         5
+--R                   222a b c - 30a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2 4          2 3       4 2  7
+--R                   (- 6480a c  + 3996a b c  - 540b c )d
+--R                 + 
+--R                           2   3          3 2       5   5
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  3
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d
+--R                 + 
+--R                           3   2       2 3         5
+--R                   (- 1080a b c  + 666a b c - 90a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2 4         2 3       4 2  8
+--R                   (- 1620a c  + 999a b c  - 135b c )d
+--R                 + 
+--R                           2   3          3 2       5   6
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6  4
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R                 + 
+--R                           3   2       2 3         5  2       4 2       3 2
+--R                   (- 1080a b c  + 666a b c - 90a b )d  - 180a c  + 111a b c
+--R                 + 
+--R                        2 4
+--R                   - 15a b
+--R              *
+--R                 e x
+--R             + 
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )d
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)d
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )d
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )d
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2   4         3 3      5 2  9 9
+--R           (372a b c  - 141a b c  + 15b c )e x
+--R         + 
+--R                 2   4          3 3       5 2    8 8
+--R           (3348a b c  - 1269a b c  + 135b c )d e x
+--R         + 
+--R                      2   4          3 3       5 2  2       2 2 3         4 2
+--R               (13392a b c  - 5076a b c  + 540b c )d  + 744a b c  - 282a b c
+--R             + 
+--R                  6
+--R               30b c
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  3
+--R               (31248a b c  - 11844a b c  + 1260b c )d
+--R             + 
+--R                     2 2 3          4 2       6
+--R               (5208a b c  - 1974a b c  + 210b c)d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  4
+--R               (46872a b c  - 17766a b c  + 1890b c )d
+--R             + 
+--R                      2 2 3          4 2       6   2       3   3      2 3 2
+--R               (15624a b c  - 5922a b c  + 630b c)d  + 744a b c  + 90a b c
+--R             + 
+--R                       5       7
+--R               - 111a b c + 15b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  5
+--R               (46872a b c  - 17766a b c  + 1890b c )d
+--R             + 
+--R                      2 2 3          4 2        6   3
+--R               (26040a b c  - 9870a b c  + 1050b c)d
+--R             + 
+--R                     3   3       2 3 2         5       7
+--R               (3720a b c  + 450a b c  - 555a b c + 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  6
+--R               (31248a b c  - 11844a b c  + 1260b c )d
+--R             + 
+--R                      2 2 3          4 2        6   4
+--R               (26040a b c  - 9870a b c  + 1050b c)d
+--R             + 
+--R                     3   3       2 3 2          5        7  2       3 2 2
+--R               (7440a b c  + 900a b c  - 1110a b c + 150b )d  + 744a b c
+--R             + 
+--R                     2 4         6
+--R               - 282a b c + 30a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      2   4          3 3       5 2  7
+--R               (13392a b c  - 5076a b c  + 540b c )d
+--R             + 
+--R                      2 2 3          4 2       6   5
+--R               (15624a b c  - 5922a b c  + 630b c)d
+--R             + 
+--R                     3   3       2 3 2          5        7  3
+--R               (7440a b c  + 900a b c  - 1110a b c + 150b )d
+--R             + 
+--R                     3 2 2       2 4         6
+--R               (2232a b c  - 846a b c + 90a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  8
+--R               (3348a b c  - 1269a b c  + 135b c )d
+--R             + 
+--R                     2 2 3          4 2       6   6
+--R               (5208a b c  - 1974a b c  + 210b c)d
+--R             + 
+--R                     3   3       2 3 2         5       7  4
+--R               (3720a b c  + 450a b c  - 555a b c + 75b )d
+--R             + 
+--R                   3 2 2       2 4         6  2       4   2       3 3       2 5
+--R             (2232a b c  - 846a b c + 90a b )d  + 372a b c  - 141a b c + 15a b
+--R          *
+--R             e x
+--R         + 
+--R                2   4         3 3      5 2  9
+--R           (372a b c  - 141a b c  + 15b c )d
+--R         + 
+--R                2 2 3         4 2      6   7
+--R           (744a b c  - 282a b c  + 30b c)d
+--R         + 
+--R                3   3      2 3 2         5       7  5
+--R           (744a b c  + 90a b c  - 111a b c + 15b )d
+--R         + 
+--R                3 2 2       2 4         6  3        4   2       3 3       2 5
+--R           (744a b c  - 282a b c + 30a b )d  + (372a b c  - 141a b c + 15a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 4         2 3      4 2  8 8
+--R           (- 180a c  + 111a b c  - 15b c )e x
+--R         + 
+--R                   2 4         2 3       4 2    7 7
+--R           (- 1440a c  + 888a b c  - 120b c )d e x
+--R         + 
+--R                       2 4          2 3       4 2  2       2   3         3 2
+--R               (- 5040a c  + 3108a b c  - 420b c )d  - 392a b c  + 227a b c
+--R             + 
+--R                    5
+--R               - 30b c
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  3
+--R               (- 10080a c  + 6216a b c  - 840b c )d
+--R             + 
+--R                       2   3          3 2       5
+--R               (- 2352a b c  + 1362a b c  - 180b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2 4          2 3        4 2  4
+--R               (- 12600a c  + 7770a b c  - 1050b c )d
+--R             + 
+--R                       2   3          3 2       5   2       3 3      2 2 2
+--R               (- 5880a b c  + 3405a b c  - 450b c)d  - 324a c  - 25a b c
+--R             + 
+--R                    4       6
+--R               91a b c - 15b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  5
+--R               (- 10080a c  + 6216a b c  - 840b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 7840a b c  + 4540a b c  - 600b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6
+--R               (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  6
+--R               (- 5040a c  + 3108a b c  - 420b c )d
+--R             + 
+--R                       2   3          3 2       5   4
+--R               (- 5880a b c  + 3405a b c  - 450b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  2       3   2
+--R               (- 1944a c  - 150a b c  + 546a b c - 90b )d  - 364a b c
+--R             + 
+--R                   2 3         5
+--R               194a b c - 25a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2 4         2 3       4 2  7
+--R               (- 1440a c  + 888a b c  - 120b c )d
+--R             + 
+--R                       2   3          3 2       5   5
+--R               (- 2352a b c  + 1362a b c  - 180b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  3
+--R               (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R             + 
+--R                      3   2       2 3         5
+--R               (- 728a b c  + 388a b c - 50a b )d
+--R          *
+--R             e x
+--R         + 
+--R                  2 4         2 3      4 2  8
+--R           (- 180a c  + 111a b c  - 15b c )d
+--R         + 
+--R                  2   3         3 2      5   6
+--R           (- 392a b c  + 227a b c  - 30b c)d
+--R         + 
+--R                  3 3      2 2 2        4       6  4
+--R           (- 324a c  - 25a b c  + 91a b c - 15b )d
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 364a b c  + 194a b c - 25a b )d  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              5 4      4 2 3     3 4 2  10 9
+--R         (128a c  - 64a b c  + 8a b c )e  x
+--R       + 
+--R               5 4       4 2 3      3 4 2    9 8
+--R         (1152a c  - 576a b c  + 72a b c )d e x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  2       5   3       4 3 2
+--R             (4608a c  - 2304a b c  + 288a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                3 5
+--R             16a b c
+--R        *
+--R            8 7
+--R           e x
+--R       + 
+--R                    5 4        4 2 3       3 4 2  3
+--R             (10752a c  - 5376a b c  + 672a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5
+--R             (1792a b c  - 896a b c  + 112a b c)d
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                    5 4        4 2 3        3 4 2  4
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   2       6 3      4 4      3 6
+--R             (5376a b c  - 2688a b c  + 336a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                    5 4        4 2 3        3 4 2  5
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   3
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   6 3       4 4       3 6
+--R             (1280a c  - 240a b c + 40a b )d
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                    5 4        4 2 3       3 4 2  6
+--R             (10752a c  - 5376a b c  + 672a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   4
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   6 3       4 4       3 6  2       6   2       5 3       4 5
+--R             (2560a c  - 480a b c + 80a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  7
+--R             (4608a c  - 2304a b c  + 288a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   5
+--R             (5376a b c  - 2688a b c  + 336a b c)d
+--R           + 
+--R                 6 3       4 4       3 6  3        6   2       5 3       4 5
+--R           (2560a c  - 480a b c + 80a b )d  + (768a b c  - 384a b c + 48a b )d
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   5 4       4 2 3      3 4 2  8
+--R             (1152a c  - 576a b c  + 72a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   6
+--R             (1792a b c  - 896a b c  + 112a b c)d
+--R           + 
+--R                   6 3       4 4       3 6  4
+--R             (1280a c  - 240a b c + 40a b )d
+--R           + 
+--R                  6   2       5 3       4 5  2       7 2      6 2      5 4
+--R             (768a b c  - 384a b c + 48a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  5 4      4 2 3     3 4 2  9
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5   7        6 3      4 4      3 6  5
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  6   2       5 3       4 5  3        7 2      6 2      5 4
+--R             (256a b c  - 128a b c + 16a b )d  + (128a c  - 64a b c + 8a b )d
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 585
+t0:=1/((d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 15 15      3   14 14        3 2       2  13 13
+--R       c e  x   + 15c d e  x   + (105c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   12 12         3 4         2 2       2     2   11 11
+--R       (455c d  + 39b c d)e  x   + (1365c d  + 234b c d  + 3a c  + 3b c)e  x
+--R     + 
+--R             3 5         2 3         2      2     10 10
+--R       (3003c d  + 858b c d  + (33a c  + 33b c)d)e  x
+--R     + 
+--R             3 6          2 4          2       2   2             3  9 9
+--R       (5005c d  + 2145b c d  + (165a c  + 165b c)d  + 6a b c + b )e x
+--R     + 
+--R             3 7          2 5          2       2   3                3    8 8
+--R       (6435c d  + 3861b c d  + (495a c  + 495b c)d  + (54a b c + 9b )d)e x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           6435c d  + 5148b c d  + (990a c  + 990b c)d  + (216a b c + 36b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          7 7
+--R         e x
+--R     + 
+--R                3 9          2 7           2        2   5                  3  3
+--R           5005c d  + 5148b c d  + (1386a c  + 1386b c)d  + (504a b c + 84b )d
+--R         + 
+--R               2         2
+--R           (21a c + 21a b )d
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R                3 10          2 8           2        2   6
+--R           3003c d   + 3861b c d  + (1386a c  + 1386b c)d
+--R         + 
+--R                           3  4       2         2  2     2
+--R           (756a b c + 126b )d  + (63a c + 63a b )d  + 3a b
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R                3 11          2 9          2       2   7                   3  5
+--R           1365c d   + 2145b c d  + (990a c  + 990b c)d  + (756a b c + 126b )d
+--R         + 
+--R                2          2  3      2
+--R           (105a c + 105a b )d  + 15a b d
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 12         2 10          2       2   8                  3  6
+--R           455c d   + 858b c d   + (495a c  + 495b c)d  + (504a b c + 84b )d
+--R         + 
+--R                2          2  4      2   2    3
+--R           (105a c + 105a b )d  + 30a b d  + a
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R               3 13         2 11          2       2   9                  3  7
+--R           105c d   + 234b c d   + (165a c  + 165b c)d  + (216a b c + 36b )d
+--R         + 
+--R               2         2  5      2   3     3
+--R           (63a c + 63a b )d  + 30a b d  + 3a d
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 14        2 12         2      2   10                3  8
+--R           15c d   + 39b c d   + (33a c  + 33b c)d   + (54a b c + 9b )d
+--R         + 
+--R               2         2  6      2   4     3 2
+--R           (21a c + 21a b )d  + 15a b d  + 3a d
+--R      *
+--R         e x
+--R     + 
+--R        3 15       2 13        2     2   11              3  9      2        2  7
+--R       c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   5    3 3
+--R       3a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 502
+
+--S 503 of 585
+r0:=-3/2*(b^4-7*a*b^2*c+10*a^2*c^2)/(a^3*(b^2-4*a*c)^2*e*(d+e*x)^2)+_
+   1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(d+e*x)^2*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/4*(3*b^4-20*a*b^2*c+20*a^2*c^2+3*b*c*(b^2-6*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(d+e*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   3/2*(b^6-10*a*b^4*c+30*a^2*b^2*c^2-20*a^3*c^3)*atanh((b+2*c*(d+e*x)^2)/_
+   sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(5/2)*e)-3*b*log(d+e*x)/(a^4*e)+_
+   3/4*b*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a^4*e)
+--R 
+--R
+--R   (2)
+--R                3 5       2 2 4        4 3     6 2  10 10
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )e  x
+--R         + 
+--R                 3 5        2 2 4         4 3      6 2    9 9
+--R           (1200a c  - 1800a b c  + 600a b c  - 60b c )d e x
+--R         + 
+--R                     3 5        2 2 4          4 3       6 2  2       3   4
+--R               (5400a c  - 8100a b c  + 2700a b c  - 270b c )d  + 240a b c
+--R             + 
+--R                     2 3 3         5 2      7
+--R               - 360a b c  + 120a b c  - 12b c
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                      3 5         2 2 4          4 3       6 2  3
+--R               (14400a c  - 21600a b c  + 7200a b c  - 720b c )d
+--R             + 
+--R                     3   4        2 3 3         5 2      7
+--R               (1920a b c  - 2880a b c  + 960a b c  - 96b c)d
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  4
+--R               (25200a c  - 37800a b c  + 12600a b c  - 1260b c )d
+--R             + 
+--R                     3   4         2 3 3          5 2       7   2       4 4
+--R               (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d  + 240a c
+--R             + 
+--R                     3 2 3      2 4 2        6      8
+--R               - 240a b c  - 60a b c  + 48a b c - 6b
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  5
+--R               (30240a c  - 45360a b c  + 15120a b c  - 1512b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   3
+--R               (13440a b c  - 20160a b c  + 6720a b c  - 672b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8
+--R               (1440a c  - 1440a b c  - 360a b c  + 288a b c - 36b )d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  6
+--R               (25200a c  - 37800a b c  + 12600a b c  - 1260b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   4
+--R               (16800a b c  - 25200a b c  + 8400a b c  - 840b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  2
+--R               (3600a c  - 3600a b c  - 900a b c  + 720a b c - 90b )d
+--R             + 
+--R                   4   3       3 3 2       2 5         7
+--R               240a b c  - 360a b c  + 120a b c - 12a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                      3 5         2 2 4          4 3       6 2  7
+--R               (14400a c  - 21600a b c  + 7200a b c  - 720b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   5
+--R               (13440a b c  - 20160a b c  + 6720a b c  - 672b c)d
+--R             + 
+--R                     4 4        3 2 3        2 4 2         6        8  3
+--R               (4800a c  - 4800a b c  - 1200a b c  + 960a b c - 120b )d
+--R             + 
+--R                    4   3        3 3 2       2 5         7
+--R               (960a b c  - 1440a b c  + 480a b c - 48a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     3 5        2 2 4          4 3       6 2  8
+--R               (5400a c  - 8100a b c  + 2700a b c  - 270b c )d
+--R             + 
+--R                     3   4         2 3 3          5 2       7   6
+--R               (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  4
+--R               (3600a c  - 3600a b c  - 900a b c  + 720a b c - 90b )d
+--R             + 
+--R                     4   3        3 3 2       2 5         7  2       5 3
+--R               (1440a b c  - 2160a b c  + 720a b c - 72a b )d  + 120a c
+--R             + 
+--R                     4 2 2      3 4      2 6
+--R               - 180a b c  + 60a b c - 6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     3 5        2 2 4         4 3      6 2  9
+--R               (1200a c  - 1800a b c  + 600a b c  - 60b c )d
+--R             + 
+--R                     3   4        2 3 3         5 2      7   7
+--R               (1920a b c  - 2880a b c  + 960a b c  - 96b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  5
+--R               (1440a c  - 1440a b c  - 360a b c  + 288a b c - 36b )d
+--R             + 
+--R                    4   3        3 3 2       2 5         7  3
+--R               (960a b c  - 1440a b c  + 480a b c - 48a b )d
+--R             + 
+--R                    5 3       4 2 2       3 4       2 6
+--R               (240a c  - 360a b c  + 120a b c - 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                3 5       2 2 4        4 3     6 2  10
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )d
+--R         + 
+--R                3   4       2 3 3         5 2      7   8
+--R           (240a b c  - 360a b c  + 120a b c  - 12b c)d
+--R         + 
+--R                4 4       3 2 3      2 4 2        6      8  6
+--R           (240a c  - 240a b c  - 60a b c  + 48a b c - 6b )d
+--R         + 
+--R                4   3       3 3 2       2 5         7  4
+--R           (240a b c  - 360a b c  + 120a b c - 12a b )d
+--R         + 
+--R                5 3       4 2 2      3 4      2 6  2
+--R           (120a c  - 180a b c  + 60a b c - 6a b )d
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                   2   4        3 3     5 2  10 10
+--R               (48a b c  - 24a b c  + 3b c )e  x
+--R             + 
+--R                    2   4         3 3      5 2    9 9
+--R               (480a b c  - 240a b c  + 30b c )d e x
+--R             + 
+--R                         2   4          3 3       5 2  2      2 2 3        4 2
+--R                   (2160a b c  - 1080a b c  + 135b c )d  + 96a b c  - 48a b c
+--R                 + 
+--R                     6
+--R                   6b c
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  3
+--R                   (5760a b c  - 2880a b c  + 360b c )d
+--R                 + 
+--R                        2 2 3         4 2      6
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  4
+--R                   (10080a b c  - 5040a b c  + 630b c )d
+--R                 + 
+--R                       2 2 3          4 2       6   2      3   3        5      7
+--R                 (2688a b c  - 1344a b c  + 168b c)d  + 96a b c  - 18a b c + 3b
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  5
+--R                   (12096a b c  - 6048a b c  + 756b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   3
+--R                   (5376a b c  - 2688a b c  + 336b c)d
+--R                 + 
+--R                        3   3         5       7
+--R                   (576a b c  - 108a b c + 18b )d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  6
+--R                   (10080a b c  - 5040a b c  + 630b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   4
+--R                   (6720a b c  - 3360a b c  + 420b c)d
+--R                 + 
+--R                       3   3         5       7  2      3 2 2      2 4        6
+--R                 (1440a b c  - 270a b c + 45b )d  + 96a b c  - 48a b c + 6a b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  7
+--R                   (5760a b c  - 2880a b c  + 360b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   5
+--R                   (5376a b c  - 2688a b c  + 336b c)d
+--R                 + 
+--R                         3   3         5       7  3
+--R                   (1920a b c  - 360a b c + 60b )d
+--R                 + 
+--R                        3 2 2       2 4         6
+--R                   (384a b c  - 192a b c + 24a b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  8
+--R                   (2160a b c  - 1080a b c  + 135b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   6
+--R                   (2688a b c  - 1344a b c  + 168b c)d
+--R                 + 
+--R                         3   3         5       7  4
+--R                   (1440a b c  - 270a b c + 45b )d
+--R                 + 
+--R                      3 2 2       2 4         6  2      4   2      3 3      2 5
+--R                 (576a b c  - 288a b c + 36a b )d  + 48a b c  - 24a b c + 3a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                        2   4         3 3      5 2  9
+--R                   (480a b c  - 240a b c  + 30b c )d
+--R                 + 
+--R                        2 2 3         4 2      6   7
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R                 + 
+--R                        3   3         5       7  5
+--R                   (576a b c  - 108a b c + 18b )d
+--R                 + 
+--R                        3 2 2       2 4         6  3
+--R                   (384a b c  - 192a b c + 24a b )d
+--R                 + 
+--R                       4   2      3 3      2 5
+--R                   (96a b c  - 48a b c + 6a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                   2   4        3 3     5 2  10       2 2 3        4 2     6   8
+--R               (48a b c  - 24a b c  + 3b c )d   + (96a b c  - 48a b c  + 6b c)d
+--R             + 
+--R                   3   3        5      7  6       3 2 2      2 4        6  4
+--R               (96a b c  - 18a b c + 3b )d  + (96a b c  - 48a b c + 6a b )d
+--R             + 
+--R                   4   2      3 3      2 5  2
+--R               (48a b c  - 24a b c + 3a b )d
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                      2   4        3 3      5 2  10 10
+--R               (- 192a b c  + 96a b c  - 12b c )e  x
+--R             + 
+--R                       2   4         3 3       5 2    9 9
+--R               (- 1920a b c  + 960a b c  - 120b c )d e x
+--R             + 
+--R                           2   4          3 3       5 2  2       2 2 3
+--R                   (- 8640a b c  + 4320a b c  - 540b c )d  - 384a b c
+--R                 + 
+--R                         4 2      6
+--R                   192a b c  - 24b c
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  3
+--R                   (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                 + 
+--R                           2 2 3          4 2       6
+--R                   (- 3072a b c  + 1536a b c  - 192b c)d
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  4
+--R                   (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                 + 
+--R                            2 2 3          4 2       6   2       3   3        5
+--R                   (- 10752a b c  + 5376a b c  - 672b c)d  - 384a b c  + 72a b c
+--R                 + 
+--R                        7
+--R                   - 12b
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  5
+--R                   (- 48384a b c  + 24192a b c  - 3024b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   3
+--R                   (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                 + 
+--R                           3   3         5       7
+--R                   (- 2304a b c  + 432a b c - 72b )d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  6
+--R                   (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   4
+--R                   (- 26880a b c  + 13440a b c  - 1680b c)d
+--R                 + 
+--R                           3   3          5        7  2       3 2 2       2 4
+--R                   (- 5760a b c  + 1080a b c - 180b )d  - 384a b c  + 192a b c
+--R                 + 
+--R                          6
+--R                   - 24a b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  7
+--R                   (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   5
+--R                   (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                 + 
+--R                           3   3          5        7  3
+--R                   (- 7680a b c  + 1440a b c - 240b )d
+--R                 + 
+--R                           3 2 2       2 4         6
+--R                   (- 1536a b c  + 768a b c - 96a b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2   4          3 3       5 2  8
+--R                   (- 8640a b c  + 4320a b c  - 540b c )d
+--R                 + 
+--R                            2 2 3          4 2       6   6
+--R                   (- 10752a b c  + 5376a b c  - 672b c)d
+--R                 + 
+--R                           3   3          5        7  4
+--R                   (- 5760a b c  + 1080a b c - 180b )d
+--R                 + 
+--R                           3 2 2        2 4          6  2       4   2      3 3
+--R                   (- 2304a b c  + 1152a b c - 144a b )d  - 192a b c  + 96a b c
+--R                 + 
+--R                        2 5
+--R                   - 12a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2   4         3 3       5 2  9
+--R                   (- 1920a b c  + 960a b c  - 120b c )d
+--R                 + 
+--R                           2 2 3          4 2       6   7
+--R                   (- 3072a b c  + 1536a b c  - 192b c)d
+--R                 + 
+--R                           3   3         5       7  5
+--R                   (- 2304a b c  + 432a b c - 72b )d
+--R                 + 
+--R                           3 2 2       2 4         6  3
+--R                   (- 1536a b c  + 768a b c - 96a b )d
+--R                 + 
+--R                          4   2       3 3       2 5
+--R                   (- 384a b c  + 192a b c - 24a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                      2   4        3 3      5 2  10
+--R               (- 192a b c  + 96a b c  - 12b c )d
+--R             + 
+--R                      2 2 3         4 2      6   8
+--R               (- 384a b c  + 192a b c  - 24b c)d
+--R             + 
+--R                      3   3        5       7  6
+--R               (- 384a b c  + 72a b c - 12b )d
+--R             + 
+--R                      3 2 2       2 4         6  4
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R             + 
+--R                      4   2      3 3       2 5  2
+--R               (- 192a b c  + 96a b c - 12a b )d
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                 3 4      2 2 3       4 2  8 8
+--R           (- 60a c  + 42a b c  - 6a b c )e x
+--R         + 
+--R                  3 4       2 2 3        4 2    7 7
+--R           (- 480a c  + 336a b c  - 48a b c )d e x
+--R         + 
+--R                       3 4        2 2 3         4 2  2       3   3      2 3 2
+--R               (- 1680a c  + 1176a b c  - 168a b c )d  - 138a b c  + 87a b c
+--R             + 
+--R                      5
+--R               - 12a b c
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  3
+--R               (- 3360a c  + 2352a b c  - 336a b c )d
+--R             + 
+--R                      3   3       2 3 2        5
+--R               (- 828a b c  + 522a b c  - 72a b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  4
+--R               (- 4200a c  + 2940a b c  - 420a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   2       4 3      3 2 2
+--R               (- 2070a b c  + 1305a b c  - 180a b c)d  - 100a c  - 14a b c
+--R             + 
+--R                  2 4        6
+--R               36a b c - 6a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  5
+--R               (- 3360a c  + 2352a b c  - 336a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   3
+--R               (- 2760a b c  + 1740a b c  - 240a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6
+--R               (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  6
+--R               (- 1680a c  + 1176a b c  - 168a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   4
+--R               (- 2070a b c  + 1305a b c  - 180a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6  2       4   2
+--R               (- 600a c  - 84a b c  + 216a b c - 36a b )d  - 122a b c
+--R             + 
+--R                  3 3      2 5
+--R               68a b c - 9a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3 4       2 2 3        4 2  7
+--R               (- 480a c  + 336a b c  - 48a b c )d
+--R             + 
+--R                      3   3       2 3 2        5   5
+--R               (- 828a b c  + 522a b c  - 72a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6  3
+--R               (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R             + 
+--R                      4   2       3 3       2 5
+--R               (- 244a b c  + 136a b c - 18a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 3 4      2 2 3       4 2  8
+--R           (- 60a c  + 42a b c  - 6a b c )d
+--R         + 
+--R                  3   3      2 3 2        5   6
+--R           (- 138a b c  + 87a b c  - 12a b c)d
+--R         + 
+--R                  4 3      3 2 2      2 4        6  4
+--R           (- 100a c  - 14a b c  + 36a b c - 6a b )d
+--R         + 
+--R                  4   2      3 3      2 5  2      5 2      4 2      3 4
+--R           (- 122a b c  + 68a b c - 9a b )d  - 32a c  + 16a b c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             6 4      5 2 3     4 4 2  11 10
+--R         (64a c  - 32a b c  + 4a b c )e  x
+--R       + 
+--R              6 4       5 2 3      4 4 2    10 9
+--R         (640a c  - 320a b c  + 40a b c )d e  x
+--R       + 
+--R                     6 4        5 2 3       4 4 2  2       6   3      5 3 2
+--R               (2880a c  - 1440a b c  + 180a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 4 5
+--R               8a b c
+--R        *
+--R            9 8
+--R           e x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  3
+--R             (7680a c  - 3840a b c  + 480a b c )d
+--R           + 
+--R                   6   3       5 3 2      4 5
+--R             (1024a b c  - 512a b c  + 64a b c)d
+--R        *
+--R            8 7
+--R           e x
+--R       + 
+--R                    6 4        5 2 3       4 4 2  4
+--R             (13440a c  - 6720a b c  + 840a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   2       7 3      5 4      4 6
+--R             (3584a b c  - 1792a b c  + 224a b c)d  + 128a c  - 24a b c + 4a b
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                    6 4        5 2 3        4 4 2  5
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   3
+--R             (7168a b c  - 3584a b c  + 448a b c)d
+--R           + 
+--R                  7 3       5 4       4 6
+--R             (768a c  - 144a b c + 24a b )d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                    6 4        5 2 3       4 4 2  6
+--R             (13440a c  - 6720a b c  + 840a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   4
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   7 3       5 4       4 6  2       7   2      6 3      5 5
+--R             (1920a c  - 360a b c + 60a b )d  + 128a b c  - 64a b c + 8a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  7
+--R             (7680a c  - 3840a b c  + 480a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   5
+--R             (7168a b c  - 3584a b c  + 448a b c)d
+--R           + 
+--R                 7 3       5 4       4 6  3        7   2       6 3       5 5
+--R           (2560a c  - 480a b c + 80a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  8
+--R             (2880a c  - 1440a b c  + 180a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   6
+--R             (3584a b c  - 1792a b c  + 224a b c)d
+--R           + 
+--R                   7 3       5 4       4 6  4
+--R             (1920a c  - 360a b c + 60a b )d
+--R           + 
+--R                  7   2       6 3       5 5  2      8 2      7 2      6 4
+--R             (768a b c  - 384a b c + 48a b )d  + 64a c  - 32a b c + 4a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  6 4       5 2 3      4 4 2  9
+--R             (640a c  - 320a b c  + 40a b c )d
+--R           + 
+--R                   6   3       5 3 2      4 5   7
+--R             (1024a b c  - 512a b c  + 64a b c)d
+--R           + 
+--R                  7 3       5 4       4 6  5        7   2       6 3       5 5  3
+--R             (768a c  - 144a b c + 24a b )d  + (512a b c  - 256a b c + 32a b )d
+--R           + 
+--R                  8 2      7 2      6 4
+--R             (128a c  - 64a b c + 8a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 6 4      5 2 3     4 4 2  10
+--R             (64a c  - 32a b c  + 4a b c )d
+--R           + 
+--R                  6   3      5 3 2     4 5   8        7 3      5 4      4 6  6
+--R             (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R           + 
+--R                  7   2      6 3      5 5  4       8 2      7 2      6 4  2
+--R             (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 585
+t0:=1/((d+e*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 16 16      3   15 15        3 2       2  14 14
+--R       c e  x   + 16c d e  x   + (120c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   13 13         3 4         2 2       2     2   12 12
+--R       (560c d  + 42b c d)e  x   + (1820c d  + 273b c d  + 3a c  + 3b c)e  x
+--R     + 
+--R             3 5          2 3         2      2     11 11
+--R       (4368c d  + 1092b c d  + (36a c  + 36b c)d)e  x
+--R     + 
+--R             3 6          2 4          2       2   2             3  10 10
+--R       (8008c d  + 3003b c d  + (198a c  + 198b c)d  + 6a b c + b )e  x
+--R     + 
+--R              3 7          2 5          2       2   3                 3    9 9
+--R       (11440c d  + 6006b c d  + (660a c  + 660b c)d  + (60a b c + 10b )d)e x
+--R     + 
+--R                 3 8          2 6           2        2   4                  3  2
+--R           12870c d  + 9009b c d  + (1485a c  + 1485b c)d  + (270a b c + 45b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          8 8
+--R         e x
+--R     + 
+--R                 3 9           2 7           2        2   5
+--R           11440c d  + 10296b c d  + (2376a c  + 2376b c)d
+--R         + 
+--R                           3  3       2         2
+--R           (720a b c + 120b )d  + (24a c + 24a b )d
+--R      *
+--R          7 7
+--R         e x
+--R     + 
+--R                3 10          2 8           2        2   6
+--R           8008c d   + 9009b c d  + (2772a c  + 2772b c)d
+--R         + 
+--R                            3  4       2         2  2     2
+--R           (1260a b c + 210b )d  + (84a c + 84a b )d  + 3a b
+--R      *
+--R          6 6
+--R         e x
+--R     + 
+--R                3 11          2 9           2        2   7
+--R           4368c d   + 6006b c d  + (2376a c  + 2376b c)d
+--R         + 
+--R                            3  5        2          2  3      2
+--R           (1512a b c + 252b )d  + (168a c + 168a b )d  + 18a b d
+--R      *
+--R          5 5
+--R         e x
+--R     + 
+--R                3 12          2 10           2        2   8
+--R           1820c d   + 3003b c d   + (1485a c  + 1485b c)d
+--R         + 
+--R                            3  6        2          2  4      2   2    3
+--R           (1260a b c + 210b )d  + (210a c + 210a b )d  + 45a b d  + a
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 13          2 11          2       2   9                   3  7
+--R           560c d   + 1092b c d   + (660a c  + 660b c)d  + (720a b c + 120b )d
+--R         + 
+--R                2          2  5      2   3     3
+--R           (168a c + 168a b )d  + 60a b d  + 4a d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R               3 14         2 12          2       2   10                  3  8
+--R           120c d   + 273b c d   + (198a c  + 198b c)d   + (270a b c + 45b )d
+--R         + 
+--R               2         2  6      2   4     3 2
+--R           (84a c + 84a b )d  + 45a b d  + 6a d
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 15        2 13         2      2   11                 3  9
+--R           16c d   + 42b c d   + (36a c  + 36b c)d   + (60a b c + 10b )d
+--R         + 
+--R               2         2  7      2   5     3 3
+--R           (24a c + 24a b )d  + 18a b d  + 4a d
+--R      *
+--R         e x
+--R     + 
+--R        3 16       2 14        2     2   12              3  10
+--R       c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R     + 
+--R          2        2  8     2   6    3 4
+--R       (3a c + 3a b )d  + 3a b d  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 505
+
+--S 506 of 585
+r0:=1/24*(-35*b^4+235*a*b^2*c-308*a^2*c^2)/(a^3*(b^2-4*a*c)^2*e*(d+e*x)^3)+_
+   1/8*b*(35*b^4-270*a*b^2*c+508*a^2*c^2)/(a^4*(b^2-4*a*c)^2*e*(d+e*x))+_
+   1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(d+e*x)^3*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/8*(7*b^4-45*a*b^2*c+44*a^2*c^2+b*c*(7*b^2-40*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   1/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (35*b^5-270*a*b^3*c+508*a^2*b*c^2+(35*b^6-340*a*b^4*c+978*a^2*b^2*c^2-_
+   616*a^3*c^3)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))+1/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(35*b^5-270*a*b^3*c+508*a^2*b*c^2+(-35*b^6+340*a*b^4*c-_
+   978*a^2*b^2*c^2+616*a^3*c^3)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^2*e*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     2   4         3 3       5 2  11 11
+--R               (1524a b c  - 810a b c  + 105b c )e  x
+--R             + 
+--R                      2   4          3 3        5 2    10 10
+--R               (16764a b c  - 8910a b c  + 1155b c )d e  x
+--R             + 
+--R                          2   4           3 3        5 2  2        2 2 3
+--R                   (83820a b c  - 44550a b c  + 5775b c )d  + 3048a b c
+--R                 + 
+--R                            4 2       6
+--R                   - 1620a b c  + 210b c
+--R              *
+--R                  9 9
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  3
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                          2 2 3           4 2        6
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  4
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   2        3   3
+--R                   (109728a b c  - 58320a b c  + 7560b c)d  + 3048a b c
+--R                 + 
+--R                        2 3 2         5        7
+--R                   - 96a b c  - 600a b c + 105b
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  5
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   3
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  6
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   4
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  2
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                        3 2 2        2 4          6
+--R                   3048a b c  - 1620a b c + 210a b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  7
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   5
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  3
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2        2 4           6
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  8
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   6
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  4
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2         2 4           6  2        4   2
+--R                   (30480a b c  - 16200a b c + 2100a b )d  + 1524a b c
+--R                 + 
+--R                         3 3        2 5
+--R                   - 810a b c + 105a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2   4           3 3        5 2  9
+--R                   (83820a b c  - 44550a b c  + 5775b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   7
+--R                   (109728a b c  - 58320a b c  + 7560b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  5
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                          3 2 2         2 4           6  3
+--R                   (30480a b c  - 16200a b c + 2100a b )d
+--R                 + 
+--R                         4   2        3 3        2 5
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2   4          3 3        5 2  10
+--R                   (16764a b c  - 8910a b c  + 1155b c )d
+--R                 + 
+--R                          2 2 3           4 2        6   8
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7  6
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R                 + 
+--R                          3 2 2        2 4           6  4
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R                 + 
+--R                         4   2        3 3        2 5  2
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )d
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)d
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )d
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )d
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3 5        2 2 4          4 3       6 2  11 11
+--R           (- 1848a c  + 2934a b c  - 1020a b c  + 105b c )e  x
+--R         + 
+--R                    3 5         2 2 4           4 3        6 2    10 10
+--R           (- 20328a c  + 32274a b c  - 11220a b c  + 1155b c )d e  x
+--R         + 
+--R                         3 5          2 2 4           4 3        6 2  2
+--R               (- 101640a c  + 161370a b c  - 56100a b c  + 5775b c )d
+--R             + 
+--R                      3   4        2 3 3          5 2       7
+--R               - 3696a b c  + 5868a b c  - 2040a b c  + 210b c
+--R          *
+--R              9 9
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  3
+--R               (- 304920a c  + 484110a b c  - 168300a b c  + 17325b c )d
+--R             + 
+--R                        3   4         2 3 3           5 2        7
+--R               (- 33264a b c  + 52812a b c  - 18360a b c  + 1890b c)d
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  4
+--R               (- 609840a c  + 968220a b c  - 336600a b c  + 34650b c )d
+--R             + 
+--R                         3   4          2 3 3           5 2        7   2
+--R               (- 133056a b c  + 211248a b c  - 73440a b c  + 7560b c)d
+--R             + 
+--R                      4 4        3 2 3       2 4 2         6        8
+--R               - 3696a c  + 4020a b c  + 894a b c  - 810a b c + 105b
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                         3 5           2 2 4            4 3         6 2  5
+--R               (- 853776a c  + 1355508a b c  - 471240a b c  + 48510b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   3
+--R               (- 310464a b c  + 492912a b c  - 171360a b c  + 17640b c)d
+--R             + 
+--R                        4 4         3 2 3        2 4 2          6        8
+--R               (- 25872a c  + 28140a b c  + 6258a b c  - 5670a b c + 735b )d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                         3 5           2 2 4            4 3         6 2  6
+--R               (- 853776a c  + 1355508a b c  - 471240a b c  + 48510b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   4
+--R               (- 465696a b c  + 739368a b c  - 257040a b c  + 26460b c)d
+--R             + 
+--R                        4 4         3 2 3         2 4 2           6         8  2
+--R               (- 77616a c  + 84420a b c  + 18774a b c  - 17010a b c + 2205b )d
+--R             + 
+--R                      4   3        3 3 2        2 5          7
+--R               - 3696a b c  + 5868a b c  - 2040a b c + 210a b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  7
+--R               (- 609840a c  + 968220a b c  - 336600a b c  + 34650b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   5
+--R               (- 465696a b c  + 739368a b c  - 257040a b c  + 26460b c)d
+--R             + 
+--R                              4 4          3 2 3         2 4 2           6
+--R                     - 129360a c  + 140700a b c  + 31290a b c  - 28350a b c
+--R                   + 
+--R                          8
+--R                     3675b
+--R              *
+--R                  3
+--R                 d
+--R             + 
+--R                        4   3         3 3 2         2 5           7
+--R               (- 18480a b c  + 29340a b c  - 10200a b c + 1050a b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  8
+--R               (- 304920a c  + 484110a b c  - 168300a b c  + 17325b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   6
+--R               (- 310464a b c  + 492912a b c  - 171360a b c  + 17640b c)d
+--R             + 
+--R                              4 4          3 2 3         2 4 2           6
+--R                     - 129360a c  + 140700a b c  + 31290a b c  - 28350a b c
+--R                   + 
+--R                          8
+--R                     3675b
+--R              *
+--R                  4
+--R                 d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  2
+--R               (- 36960a b c  + 58680a b c  - 20400a b c + 2100a b )d
+--R             + 
+--R                      5 3        4 2 2        3 4        2 6
+--R               - 1848a c  + 2934a b c  - 1020a b c + 105a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                         3 5          2 2 4           4 3        6 2  9
+--R               (- 101640a c  + 161370a b c  - 56100a b c  + 5775b c )d
+--R             + 
+--R                         3   4          2 3 3           5 2        7   7
+--R               (- 133056a b c  + 211248a b c  - 73440a b c  + 7560b c)d
+--R             + 
+--R                        4 4         3 2 3         2 4 2           6         8  5
+--R               (- 77616a c  + 84420a b c  + 18774a b c  - 17010a b c + 2205b )d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  3
+--R               (- 36960a b c  + 58680a b c  - 20400a b c + 2100a b )d
+--R             + 
+--R                       5 3        4 2 2        3 4        2 6
+--R               (- 5544a c  + 8802a b c  - 3060a b c + 315a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        3 5         2 2 4           4 3        6 2  10
+--R               (- 20328a c  + 32274a b c  - 11220a b c  + 1155b c )d
+--R             + 
+--R                        3   4         2 3 3           5 2        7   8
+--R               (- 33264a b c  + 52812a b c  - 18360a b c  + 1890b c)d
+--R             + 
+--R                        4 4         3 2 3        2 4 2          6        8  6
+--R               (- 25872a c  + 28140a b c  + 6258a b c  - 5670a b c + 735b )d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  4
+--R               (- 18480a b c  + 29340a b c  - 10200a b c + 1050a b )d
+--R             + 
+--R                       5 3        4 2 2        3 4        2 6  2
+--R               (- 5544a c  + 8802a b c  - 3060a b c + 315a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   3 5        2 2 4          4 3       6 2  11
+--R           (- 1848a c  + 2934a b c  - 1020a b c  + 105b c )d
+--R         + 
+--R                   3   4        2 3 3          5 2       7   9
+--R           (- 3696a b c  + 5868a b c  - 2040a b c  + 210b c)d
+--R         + 
+--R                   4 4        3 2 3       2 4 2         6        8  7
+--R           (- 3696a c  + 4020a b c  + 894a b c  - 810a b c + 105b )d
+--R         + 
+--R                   4   3        3 3 2        2 5          7  5
+--R           (- 3696a b c  + 5868a b c  - 2040a b c + 210a b )d
+--R         + 
+--R                   5 3        4 2 2        3 4        2 6  3
+--R           (- 1848a c  + 2934a b c  - 1020a b c + 105a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     2   4         3 3       5 2  11 11
+--R               (1524a b c  - 810a b c  + 105b c )e  x
+--R             + 
+--R                      2   4          3 3        5 2    10 10
+--R               (16764a b c  - 8910a b c  + 1155b c )d e  x
+--R             + 
+--R                          2   4           3 3        5 2  2        2 2 3
+--R                   (83820a b c  - 44550a b c  + 5775b c )d  + 3048a b c
+--R                 + 
+--R                            4 2       6
+--R                   - 1620a b c  + 210b c
+--R              *
+--R                  9 9
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  3
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                          2 2 3           4 2        6
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  4
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   2        3   3
+--R                   (109728a b c  - 58320a b c  + 7560b c)d  + 3048a b c
+--R                 + 
+--R                        2 3 2         5        7
+--R                   - 96a b c  - 600a b c + 105b
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  5
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   3
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  6
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   4
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  2
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                        3 2 2        2 4          6
+--R                   3048a b c  - 1620a b c + 210a b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  7
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   5
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  3
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2        2 4           6
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  8
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   6
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  4
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2         2 4           6  2        4   2
+--R                   (30480a b c  - 16200a b c + 2100a b )d  + 1524a b c
+--R                 + 
+--R                         3 3        2 5
+--R                   - 810a b c + 105a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2   4           3 3        5 2  9
+--R                   (83820a b c  - 44550a b c  + 5775b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   7
+--R                   (109728a b c  - 58320a b c  + 7560b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  5
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                          3 2 2         2 4           6  3
+--R                   (30480a b c  - 16200a b c + 2100a b )d
+--R                 + 
+--R                         4   2        3 3        2 5
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2   4          3 3        5 2  10
+--R                   (16764a b c  - 8910a b c  + 1155b c )d
+--R                 + 
+--R                          2 2 3           4 2        6   8
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7  6
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R                 + 
+--R                          3 2 2        2 4           6  4
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R                 + 
+--R                         4   2        3 3        2 5  2
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )d
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)d
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )d
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )d
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3 5        2 2 4          4 3       6 2  11 11
+--R           (1848a c  - 2934a b c  + 1020a b c  - 105b c )e  x
+--R         + 
+--R                  3 5         2 2 4           4 3        6 2    10 10
+--R           (20328a c  - 32274a b c  + 11220a b c  - 1155b c )d e  x
+--R         + 
+--R                       3 5          2 2 4           4 3        6 2  2
+--R               (101640a c  - 161370a b c  + 56100a b c  - 5775b c )d
+--R             + 
+--R                    3   4        2 3 3          5 2       7
+--R               3696a b c  - 5868a b c  + 2040a b c  - 210b c
+--R          *
+--R              9 9
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  3
+--R               (304920a c  - 484110a b c  + 168300a b c  - 17325b c )d
+--R             + 
+--R                      3   4         2 3 3           5 2        7
+--R               (33264a b c  - 52812a b c  + 18360a b c  - 1890b c)d
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  4
+--R               (609840a c  - 968220a b c  + 336600a b c  - 34650b c )d
+--R             + 
+--R                       3   4          2 3 3           5 2        7   2
+--R               (133056a b c  - 211248a b c  + 73440a b c  - 7560b c)d
+--R             + 
+--R                    4 4        3 2 3       2 4 2         6        8
+--R               3696a c  - 4020a b c  - 894a b c  + 810a b c - 105b
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                       3 5           2 2 4            4 3         6 2  5
+--R               (853776a c  - 1355508a b c  + 471240a b c  - 48510b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   3
+--R               (310464a b c  - 492912a b c  + 171360a b c  - 17640b c)d
+--R             + 
+--R                      4 4         3 2 3        2 4 2          6        8
+--R               (25872a c  - 28140a b c  - 6258a b c  + 5670a b c - 735b )d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       3 5           2 2 4            4 3         6 2  6
+--R               (853776a c  - 1355508a b c  + 471240a b c  - 48510b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   4
+--R               (465696a b c  - 739368a b c  + 257040a b c  - 26460b c)d
+--R             + 
+--R                      4 4         3 2 3         2 4 2           6         8  2
+--R               (77616a c  - 84420a b c  - 18774a b c  + 17010a b c - 2205b )d
+--R             + 
+--R                    4   3        3 3 2        2 5          7
+--R               3696a b c  - 5868a b c  + 2040a b c - 210a b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  7
+--R               (609840a c  - 968220a b c  + 336600a b c  - 34650b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   5
+--R               (465696a b c  - 739368a b c  + 257040a b c  - 26460b c)d
+--R             + 
+--R                       4 4          3 2 3         2 4 2           6         8  3
+--R               (129360a c  - 140700a b c  - 31290a b c  + 28350a b c - 3675b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7
+--R               (18480a b c  - 29340a b c  + 10200a b c - 1050a b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  8
+--R               (304920a c  - 484110a b c  + 168300a b c  - 17325b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   6
+--R               (310464a b c  - 492912a b c  + 171360a b c  - 17640b c)d
+--R             + 
+--R                       4 4          3 2 3         2 4 2           6         8  4
+--R               (129360a c  - 140700a b c  - 31290a b c  + 28350a b c - 3675b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  2        5 3
+--R               (36960a b c  - 58680a b c  + 20400a b c - 2100a b )d  + 1848a c
+--R             + 
+--R                      4 2 2        3 4        2 6
+--R               - 2934a b c  + 1020a b c - 105a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       3 5          2 2 4           4 3        6 2  9
+--R               (101640a c  - 161370a b c  + 56100a b c  - 5775b c )d
+--R             + 
+--R                       3   4          2 3 3           5 2        7   7
+--R               (133056a b c  - 211248a b c  + 73440a b c  - 7560b c)d
+--R             + 
+--R                      4 4         3 2 3         2 4 2           6         8  5
+--R               (77616a c  - 84420a b c  - 18774a b c  + 17010a b c - 2205b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  3
+--R               (36960a b c  - 58680a b c  + 20400a b c - 2100a b )d
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6
+--R               (5544a c  - 8802a b c  + 3060a b c - 315a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  10
+--R               (20328a c  - 32274a b c  + 11220a b c  - 1155b c )d
+--R             + 
+--R                      3   4         2 3 3           5 2        7   8
+--R               (33264a b c  - 52812a b c  + 18360a b c  - 1890b c)d
+--R             + 
+--R                      4 4         3 2 3        2 4 2          6        8  6
+--R               (25872a c  - 28140a b c  - 6258a b c  + 5670a b c - 735b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  4
+--R               (18480a b c  - 29340a b c  + 10200a b c - 1050a b )d
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6  2
+--R               (5544a c  - 8802a b c  + 3060a b c - 315a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 3 5        2 2 4          4 3       6 2  11
+--R           (1848a c  - 2934a b c  + 1020a b c  - 105b c )d
+--R         + 
+--R                 3   4        2 3 3          5 2       7   9
+--R           (3696a b c  - 5868a b c  + 2040a b c  - 210b c)d
+--R         + 
+--R                 4 4        3 2 3       2 4 2         6        8  7
+--R           (3696a c  - 4020a b c  - 894a b c  + 810a b c - 105b )d
+--R         + 
+--R                 4   3        3 3 2        2 5          7  5
+--R           (3696a b c  - 5868a b c  + 2040a b c - 210a b )d
+--R         + 
+--R                 5 3        4 2 2        3 4        2 6  3
+--R           (1848a c  - 2934a b c  + 1020a b c - 105a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 2   4         3 3       5 2  10 10
+--R           (1524a b c  - 810a b c  + 105b c )e  x
+--R         + 
+--R                  2   4          3 3        5 2    9 9
+--R           (15240a b c  - 8100a b c  + 1050b c )d e x
+--R         + 
+--R                      2   4           3 3        5 2  2       3 4        2 2 3
+--R               (68580a b c  - 36450a b c  + 4725b c )d  - 308a c  + 3283a b c
+--R             + 
+--R                        4 2       6
+--R               - 1655a b c  + 210b c
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                       2   4           3 3         5 2  3
+--R               (182880a b c  - 97200a b c  + 12600b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6
+--R               (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  4
+--R               (320040a b c  - 170100a b c  + 22050b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   2        3   3
+--R               (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d  + 2312a b c
+--R             + 
+--R                   2 3 2         5        7
+--R               395a b c  - 670a b c + 105b
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  5
+--R               (384048a b c  - 204120a b c  + 26460b c )d
+--R             + 
+--R                        3 4          2 2 3           4 2         6   3
+--R               (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R             + 
+--R                      3   3        2 3 2          5        7
+--R               (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  6
+--R               (320040a b c  - 170100a b c  + 22050b c )d
+--R             + 
+--R                        3 4          2 2 3            4 2         6   4
+--R               (- 21560a c  + 229810a b c  - 115850a b c  + 14700b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  2       4 3
+--R               (34680a b c  + 5925a b c  - 10050a b c + 1575b )d  - 484a c
+--R             + 
+--R                    3 2 2        2 4          6
+--R               2955a b c  - 1413a b c + 175a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2   4           3 3         5 2  7
+--R               (182880a b c  - 97200a b c  + 12600b c )d
+--R             + 
+--R                        3 4          2 2 3           4 2         6   5
+--R               (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  3
+--R               (46240a b c  + 7900a b c  - 13400a b c + 2100b )d
+--R             + 
+--R                       4 3         3 2 2        2 4          6
+--R               (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  8
+--R               (68580a b c  - 36450a b c  + 4725b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   6
+--R               (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  4
+--R               (34680a b c  + 5925a b c  - 10050a b c + 1575b )d
+--R             + 
+--R                       4 3         3 2 2        2 4           6  2       4   2
+--R               (- 2904a c  + 17730a b c  - 8478a b c + 1050a b )d  + 896a b c
+--R             + 
+--R                     3 3       2 5
+--R               - 448a b c + 56a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      2   4          3 3        5 2  9
+--R               (15240a b c  - 8100a b c  + 1050b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   7
+--R               (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R             + 
+--R                      3   3        2 3 2          5        7  5
+--R               (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R             + 
+--R                       4 3         3 2 2        2 4          6  3
+--R               (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R             + 
+--R                     4   2       3 3        2 5
+--R               (1792a b c  - 896a b c + 112a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2   4         3 3       5 2  10
+--R           (1524a b c  - 810a b c  + 105b c )d
+--R         + 
+--R                  3 4        2 2 3          4 2       6   8
+--R           (- 308a c  + 3283a b c  - 1655a b c  + 210b c)d
+--R         + 
+--R                 3   3       2 3 2         5        7  6
+--R           (2312a b c  + 395a b c  - 670a b c + 105b )d
+--R         + 
+--R                  4 3        3 2 2        2 4          6  4
+--R           (- 484a c  + 2955a b c  - 1413a b c + 175a b )d
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (896a b c  - 448a b c + 56a b )d  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              6 4       5 2 3      4 4 2  12 11
+--R         (384a c  - 192a b c  + 24a b c )e  x
+--R       + 
+--R               6 4        5 2 3       4 4 2    11 10
+--R         (4224a c  - 2112a b c  + 264a b c )d e  x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  2       6   3       5 3 2
+--R             (21120a c  - 10560a b c  + 1320a b c )d  + 768a b c  - 384a b c
+--R           + 
+--R                4 5
+--R             48a b c
+--R        *
+--R            10 9
+--R           e  x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  3
+--R             (63360a c  - 31680a b c  + 3960a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5
+--R             (6912a b c  - 3456a b c  + 432a b c)d
+--R        *
+--R            9 8
+--R           e x
+--R       + 
+--R                     6 4         5 2 3        4 4 2  4
+--R             (126720a c  - 63360a b c  + 7920a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   2       7 3       5 4
+--R             (27648a b c  - 13824a b c  + 1728a b c)d  + 768a c  - 144a b c
+--R           + 
+--R                4 6
+--R             24a b
+--R        *
+--R            8 7
+--R           e x
+--R       + 
+--R                     6 4         5 2 3         4 4 2  5
+--R             (177408a c  - 88704a b c  + 11088a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   3
+--R             (64512a b c  - 32256a b c  + 4032a b c)d
+--R           + 
+--R                   7 3        5 4        4 6
+--R             (5376a c  - 1008a b c + 168a b )d
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                     6 4         5 2 3         4 4 2  6
+--R             (177408a c  - 88704a b c  + 11088a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   4
+--R             (96768a b c  - 48384a b c  + 6048a b c)d
+--R           + 
+--R                  7 3        5 4        4 6  2       7   2       6 3       5 5
+--R           (16128a c  - 3024a b c + 504a b )d  + 768a b c  - 384a b c + 48a b
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                     6 4         5 2 3        4 4 2  7
+--R             (126720a c  - 63360a b c  + 7920a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   5
+--R             (96768a b c  - 48384a b c  + 6048a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  3
+--R             (26880a c  - 5040a b c + 840a b )d
+--R           + 
+--R                   7   2        6 3        5 5
+--R             (3840a b c  - 1920a b c + 240a b )d
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  8
+--R             (63360a c  - 31680a b c  + 3960a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   6
+--R             (64512a b c  - 32256a b c  + 4032a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  4
+--R             (26880a c  - 5040a b c + 840a b )d
+--R           + 
+--R                   7   2        6 3        5 5  2       8 2       7 2       6 4
+--R             (7680a b c  - 3840a b c + 480a b )d  + 384a c  - 192a b c + 24a b
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  9
+--R             (21120a c  - 10560a b c  + 1320a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   7
+--R             (27648a b c  - 13824a b c  + 1728a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  5
+--R             (16128a c  - 3024a b c + 504a b )d
+--R           + 
+--R                   7   2        6 3        5 5  3
+--R             (7680a b c  - 3840a b c + 480a b )d
+--R           + 
+--R                   8 2       7 2       6 4
+--R             (1152a c  - 576a b c + 72a b )d
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  10
+--R             (4224a c  - 2112a b c  + 264a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   8
+--R             (6912a b c  - 3456a b c  + 432a b c)d
+--R           + 
+--R                   7 3        5 4        4 6  6
+--R             (5376a c  - 1008a b c + 168a b )d
+--R           + 
+--R                   7   2        6 3        5 5  4
+--R             (3840a b c  - 1920a b c + 240a b )d
+--R           + 
+--R                   8 2       7 2       6 4  2
+--R             (1152a c  - 576a b c + 72a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  6 4       5 2 3      4 4 2  11
+--R             (384a c  - 192a b c  + 24a b c )d
+--R           + 
+--R                  6   3       5 3 2      4 5   9
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R           + 
+--R                  7 3       5 4       4 6  7        7   2       6 3       5 5  5
+--R             (768a c  - 144a b c + 24a b )d  + (768a b c  - 384a b c + 48a b )d
+--R           + 
+--R                  8 2       7 2       6 4  3
+--R             (384a c  - 192a b c + 24a b )d
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 585
+t0:=(d*f+e*f*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                 4 4 4       3 4 3     2 2 4 2     3   4     4 4
+--R                e f x  + 4d e f x  + 6d e f x  + 4d e f x + d f
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 508
+
+--S 509 of 585
+r0:=f^4*x/c-f^4*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*e*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))-f^4*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                  +------------------+
+--R                 +-----------+                    | +-----------+
+--R               4 |          2               2  4  | |          2
+--R         (- b f \|- 4a c + b   + (- 2a c + b )f )\|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                +--------------------+
+--R                 +-----------+                  |   +-----------+
+--R               4 |          2             2  4  |   |          2
+--R         (- b f \|- 4a c + b   + (2a c - b )f )\|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                   +--------------------+ +------------------+
+--R                 +-----------+     |   +-----------+      | +-----------+
+--R          4  +-+ |          2  +-+ |   |          2       | |          2
+--R       e f x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R         +-+ |          2  +-+ |   |          2       | |          2
+--R     c e\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 585
+t0:=(d*f+e*f*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                       3 3 3       2 3 2     2   3     3 3
+--R                      e f x  + 3d e f x  + 3d e f x + d f
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 511
+
+--S 512 of 585
+r0:=1/4*f^3*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(c*e)+_
+   1/2*b*f^3*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(c*e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                      2 2                  2
+--R           3      2c e x  + 4c d e x + 2c d  + b
+--R       2b f atanh(------------------------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R     + 
+--R          3
+--R         f
+--R      *
+--R         log
+--R                 4 4         3 3        2      2 2        3                 4
+--R              c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d
+--R            + 
+--R                 2
+--R              b d  + a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     4c e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 513
+
+)clear all
+
+--S 514 of 585
+t0:=(d*f+e*f*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                             2 2 2         2     2 2
+--R                            e f x  + 2d e f x + d f
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 514
+
+--S 515 of 585
+r0:=-f^2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(b-_
+   sqrt(b^2-4*a*c))/(e*sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+f^2*atan((d+e*x)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))/_
+   (e*sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R            +--------------------+
+--R            |   +-----------+                       +-+ +-+
+--R          2 |   |          2              (e x + d)\|2 \|c
+--R       - f \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                      +-+ +-+
+--R        2 | |          2             (e x + d)\|2 \|c
+--R       f \|\|- 4a c + b   + b atan(---------------------)
+--R                                    +------------------+
+--R                                    | +-----------+
+--R                                    | |          2
+--R                                   \|\|- 4a c + b   + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     e\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 585
+t0:=(d*f+e*f*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)
+--R 
+--R
+--R   (1)
+--R                                   e f x + d f
+--R   --------------------------------------------------------------------------
+--R      4 4         3 3        2      2 2        3                 4      2
+--R   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x + c d  + b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 517
+
+--S 518 of 585
+r0:=-f*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(e*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                      2 2                  2
+--R                  2c e x  + 4c d e x + 2c d  + b
+--R          f atanh(------------------------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R   (2)  - ---------------------------------------
+--R                        +-----------+
+--R                        |          2
+--R                      e\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 519
+
+)clear all
+
+--S 520 of 585
+t0:=1/((d*f+e*f*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          5   5         4   4         2      3   3         3         2   2
+--R       c e f x  + 5c d e f x  + (10c d  + b)e f x  + (10c d  + 3b d)e f x
+--R     + 
+--R            4       2                 5      3
+--R       (5c d  + 3b d  + a)e f x + (c d  + b d  + a d)f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 520
+
+--S 521 of 585
+r0:=log(d+e*x)/(a*e*f)-1/4*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a*e*f)+_
+   1/2*b*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(a*e*f*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    2 2                  2
+--R                2c e x  + 4c d e x + 2c d  + b
+--R       2b atanh(------------------------------)
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R     + 
+--R           -
+--R              log
+--R                      4 4         3 3        2      2 2        3
+--R                   c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                 + 
+--R                      4      2
+--R                   c d  + b d  + a
+--R         + 
+--R           4log(e x + d)
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            +-----------+
+--R            |          2
+--R     4a e f\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 585
+t0:=1/((d*f+e*f*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          6 2 6         5 2 5         2      4 2 4         3         3 2 3
+--R       c e f x  + 6c d e f x  + (15c d  + b)e f x  + (20c d  + 4b d)e f x
+--R     + 
+--R             4       2      2 2 2        5       3           2
+--R       (15c d  + 6b d  + a)e f x  + (6c d  + 4b d  + 2a d)e f x
+--R     + 
+--R           6      4      2  2
+--R       (c d  + b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 523
+
+--S 524 of 585
+r0:=(-1)/(a*e*f^2*(d+e*x))-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(1+b/sqrt(b^2-4*a*c))/(a*e*f^2*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))-atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(1-b/sqrt(b^2-4*a*c))/(a*e*f^2*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                       +------------------+
+--R                      +-----------+                    | +-----------+
+--R                      |          2                 +-+ | |          2
+--R         ((- e x - d)\|- 4a c + b   - b e x - b d)\|c \|\|- 4a c + b   + b
+--R      *
+--R                           +-+ +-+
+--R                 (e x + d)\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                       +--------------------+
+--R                      +-----------+                    |   +-----------+
+--R                      |          2                 +-+ |   |          2
+--R         ((- e x - d)\|- 4a c + b   + b e x + b d)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                          +-+ +-+
+--R                (e x + d)\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R       - \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                              +--------------------+
+--R                                +-----------+ |   +-----------+
+--R           2 2           2  +-+ |          2  |   |          2
+--R       (a e f x + a d e f )\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 585
+t0:=1/((d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          7 3 7         6 3 6         2      5 3 5         3         4 3 4
+--R       c e f x  + 7c d e f x  + (21c d  + b)e f x  + (35c d  + 5b d)e f x
+--R     + 
+--R             4        2      3 3 3         5        3         2 3 2
+--R       (35c d  + 10b d  + a)e f x  + (21c d  + 10b d  + 3a d)e f x
+--R     + 
+--R            6       4       2    3        7      5      3  3
+--R       (7c d  + 5b d  + 3a d )e f x + (c d  + b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 526
+
+--S 527 of 585
+r0:=(-1/2)/(a*e*f^3*(d+e*x)^2)-b*log(d+e*x)/(a^2*e*f^3)+_
+   1/4*b*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a^2*e*f^3)-1/2*(b^2-2*a*c)*_
+   atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(a^2*e*f^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    2  2 2             2                   2  2
+--R         ((4a c - 2b )e x  + (8a c - 4b )d e x + (4a c - 2b )d )
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                 2 2                 2
+--R             (b e x  + 2b d e x + b d )
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                  2 2                  2
+--R           (- 4b e x  - 8b d e x - 4b d )log(e x + d) - 2a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                          +-----------+
+--R        2 3 3 2     2   2 3      2 2   3  |          2
+--R     (4a e f x  + 8a d e f x + 4a d e f )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 585
+t0:=1/((d*f+e*f*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          8 4 8         7 4 7         2      6 4 6         3         5 4 5
+--R       c e f x  + 8c d e f x  + (28c d  + b)e f x  + (56c d  + 6b d)e f x
+--R     + 
+--R             4        2      4 4 4         5        3         3 4 3
+--R       (70c d  + 15b d  + a)e f x  + (56c d  + 20b d  + 4a d)e f x
+--R     + 
+--R             6        4       2  2 4 2        7       5       3    4
+--R       (28c d  + 15b d  + 6a d )e f x  + (8c d  + 6b d  + 4a d )e f x
+--R     + 
+--R           8      6      4  4
+--R       (c d  + b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 529
+
+--S 530 of 585
+r0:=(-1/3)/(a*e*f^4*(d+e*x)^3)+b/(a^2*e*f^4*(d+e*x))+atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/_
+   (a^2*e*f^4*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/_
+   (a^2*e*f^4*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                    +-----------+
+--R                3 3         2 2       2          3  |          2
+--R           (3b e x  + 9b d e x  + 9b d e x + 3b d )\|- 4a c + b
+--R         + 
+--R                       2  3 3                2    2 2                2  2
+--R           (- 6a c + 3b )e x  + (- 18a c + 9b )d e x  + (- 18a c + 9b )d e x
+--R         + 
+--R                       2  3
+--R           (- 6a c + 3b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                                    +-----------+
+--R                3 3         2 2       2          3  |          2
+--R           (3b e x  + 9b d e x  + 9b d e x + 3b d )\|- 4a c + b
+--R         + 
+--R                     2  3 3              2    2 2              2  2
+--R           (6a c - 3b )e x  + (18a c - 9b )d e x  + (18a c - 9b )d e x
+--R         + 
+--R                     2  3
+--R           (6a c - 3b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                              +-----------+
+--R              2 2                  2      +-+ |          2
+--R         (3b e x  + 6b d e x + 3b d  - a)\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                              +-----------+
+--R          2 4 4 3     2   3 4 2     2 2 2 4      2 3   4  +-+ |          2
+--R       (3a e f x  + 9a d e f x  + 9a d e f x + 3a d e f )\|2 \|- 4a c + b
+--R    *
+--R        +--------------------+ +------------------+
+--R        |   +-----------+      | +-----------+
+--R        |   |          2       | |          2
+--R       \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 531
+
+)clear all
+
+--S 532 of 585
+t0:=(d*f+e*f*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      4 4 4       3 4 3     2 2 4 2     3   4     4 4
+--R     e f x  + 4d e f x  + 6d e f x  + 4d e f x + d f
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 532
+
+--S 533 of 585
+r0:=1/2*f^4*(d+e*x)*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+1/2*f^4*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*(b+(-b^2-4*a*c)/sqrt(b^2-4*a*c))/((b^2-4*a*c)*e*sqrt(2)*_
+   sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*f^4*atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*(b^2+4*a*c+b*sqrt(b^2-4*a*c))/((b^2-_
+   4*a*c)^(3/2)*e*sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      4 4 4           3 4 3            2    2  2 4 2
+--R               - b c e f x  - 4b c d e f x  + (- 6b c d  - b )e f x
+--R             + 
+--R                        3     2     4            4    2 2        4
+--R               (- 4b c d  - 2b d)e f x + (- b c d  - b d  - a b)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2    2   4 4 4         2     2     3 4 3
+--R           (4a c  + b c)e f x  + (16a c  + 4b c)d e f x
+--R         + 
+--R                  2     2   2             3  2 4 2
+--R           ((24a c  + 6b c)d  + 4a b c + b )e f x
+--R         + 
+--R                  2     2   3               3      4
+--R           ((16a c  + 4b c)d  + (8a b c + 2b )d)e f x
+--R         + 
+--R                 2    2   4              3  2     2       2  4
+--R           ((4a c  + b c)d  + (4a b c + b )d  + 4a c + a b )f
+--R      *
+--R          +------------------+
+--R          | +-----------+                       +-+ +-+
+--R          | |          2              (e x + d)\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                      4 4 4           3 4 3            2    2  2 4 2
+--R               - b c e f x  - 4b c d e f x  + (- 6b c d  - b )e f x
+--R             + 
+--R                        3     2     4            4    2 2        4
+--R               (- 4b c d  - 2b d)e f x + (- b c d  - b d  - a b)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2    2   4 4 4           2     2     3 4 3
+--R           (- 4a c  - b c)e f x  + (- 16a c  - 4b c)d e f x
+--R         + 
+--R                    2     2   2             3  2 4 2
+--R           ((- 24a c  - 6b c)d  - 4a b c - b )e f x
+--R         + 
+--R                    2     2   3                 3      4
+--R           ((- 16a c  - 4b c)d  + (- 8a b c - 2b )d)e f x
+--R         + 
+--R                   2    2   4                3  2     2       2  4
+--R           ((- 4a c  - b c)d  + (- 4a b c - b )d  - 4a c - a b )f
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                      +-+ +-+
+--R          |   |          2             (e x + d)\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R               3 4 3         2 4 2          2         4          3         4
+--R         (- b e f x  - 3b d e f x  + (- 3b d  - 2a)e f x + (- b d  - 2a d)f )
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 534
+
+)clear all
+
+--S 535 of 585
+t0:=(d*f+e*f*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      3 3 3       2 3 2     2   3     3 3
+--R     e f x  + 3d e f x  + 3d e f x + d f
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 535
+
+--S 536 of 585
+r0:=1/2*f^3*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   b*f^3*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e)
+--R 
+--R
+--R   (2)
+--R                 4 3 4           3 3 3           2     2  2 3 2
+--R           2b c e f x  + 8b c d e f x  + (12b c d  + 2b )e f x
+--R         + 
+--R                  3     2     3           4     2 2         3
+--R           (8b c d  + 4b d)e f x + (2b c d  + 2b d  + 2a b)f
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                                   +-----------+
+--R             2 3 2           3          2       3  |          2
+--R       (- b e f x  - 2b d e f x + (- b d  - 2a)f )\|- 4a c + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 537
+
+)clear all
+
+--S 538 of 585
+t0:=(d*f+e*f*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R      2 2 2         2     2 2
+--R     e f x  + 2d e f x + d f
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 538
+
+--S 539 of 585
+r0:=-1/2*f^2*(d+e*x)*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+f^2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(2*b-sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-f^2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(2*b+sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                   4 2 4         3 2 3         2       2 2 2
+--R               2c e f x  + 8c d e f x  + (12c d  + 2b)e f x
+--R             + 
+--R                    3           2         4       2       2
+--R               (8c d  + 4b d)e f x + (2c d  + 2b d  + 2a)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   4 2 4            3 2 3             2     2  2 2 2
+--R           - 4b c e f x  - 16b c d e f x  + (- 24b c d  - 4b )e f x
+--R         + 
+--R                     3     2     2             4     2 2         2
+--R           (- 16b c d  - 8b d)e f x + (- 4b c d  - 4b d  - 4a b)f
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                   4 2 4         3 2 3         2       2 2 2
+--R               2c e f x  + 8c d e f x  + (12c d  + 2b)e f x
+--R             + 
+--R                    3           2         4       2       2
+--R               (8c d  + 4b d)e f x + (2c d  + 2b d  + 2a)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 4 2 4            3 2 3           2     2  2 2 2
+--R           4b c e f x  + 16b c d e f x  + (24b c d  + 4b )e f x
+--R         + 
+--R                   3     2     2           4     2 2         2
+--R           (16b c d  + 8b d)e f x + (4b c d  + 4b d  + 4a b)f
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R              3 2 3         2 2 2        2        2         3        2  +-+
+--R         (2c e f x  + 6c d e f x  + (6c d  + b)e f x + (2c d  + b d)f )\|2
+--R      *
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R          |          2  |   |          2       | |          2
+--R         \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 585
+t0:=(d*f+e*f*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R     e f x + d f
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 541
+
+--S 542 of 585
+r0:=-1/2*f*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   2*c*f*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*e)
+--R 
+--R
+--R   (2)
+--R               2 4   4      2   3   3         2 2         2   2
+--R           - 4c e f x  - 16c d e f x  + (- 24c d  - 4b c)e f x
+--R         + 
+--R                 2 3                       2 4         2
+--R           (- 16c d  - 8b c d)e f x + (- 4c d  - 4b c d  - 4a c)f
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                                               +-----------+
+--R            2   2                     2        |          2
+--R       (2c e f x  + 4c d e f x + (2c d  + b)f)\|- 4a c + b
+--R  /
+--R              2     2   5 4         2     2     4 3
+--R         (8a c  - 2b c)e x  + (32a c  - 8b c)d e x
+--R       + 
+--R                2      2   2              3  3 2
+--R         ((48a c  - 12b c)d  + 8a b c - 2b )e x
+--R       + 
+--R                2     2   3                3    2
+--R         ((32a c  - 8b c)d  + (16a b c - 4b )d)e x
+--R       + 
+--R               2     2   4               3  2     2        2
+--R         ((8a c  - 2b c)d  + (8a b c - 2b )d  + 8a c - 2a b )e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 543
+
+)clear all
+
+--S 544 of 585
+t0:=1/(a+b*(d+e*x)^2+c*(d+e*x)^4)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 8 8     2   7 7       2 2         6 6       2 3            5 5
+--R       c e x  + 8c d e x  + (28c d  + 2b c)e x  + (56c d  + 12b c d)e x
+--R     + 
+--R           2 4          2           2  4 4
+--R       (70c d  + 30b c d  + 2a c + b )e x
+--R     + 
+--R           2 5          3             2    3 3
+--R       (56c d  + 40b c d  + (8a c + 4b )d)e x
+--R     + 
+--R           2 6          4              2  2         2 2
+--R       (28c d  + 30b c d  + (12a c + 6b )d  + 2a b)e x
+--R     + 
+--R          2 7          5             2  3                 2 8         6
+--R       (8c d  + 12b c d  + (8a c + 4b )d  + 4a b d)e x + c d  + 2b c d
+--R     + 
+--R                2  4         2    2
+--R       (2a c + b )d  + 2a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 544
+
+--S 545 of 585
+r0:=1/2*(d+e*x)*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(b+(b^2-12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*e*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(b+(-b^2+12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*e*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2    2   4 4         2     2     3 3
+--R           (12a c  - b c)e x  + (48a c  - 4b c)d e x
+--R         + 
+--R                  2     2   2              3  2 2
+--R           ((72a c  - 6b c)d  + 12a b c - b )e x
+--R         + 
+--R                  2     2   3                3               2    2   4
+--R           ((48a c  - 4b c)d  + (24a b c - 2b )d)e x + (12a c  - b c)d
+--R         + 
+--R                       3  2      2       2
+--R           (12a b c - b )d  + 12a c - a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      4 4           3 3            2    2  2 2
+--R               - b c e x  - 4b c d e x  + (- 6b c d  - b )e x
+--R             + 
+--R                        3     2             4    2 2
+--R               (- 4b c d  - 2b d)e x - b c d  - b d  - a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2    2   4 4           2     2     3 3
+--R           (- 12a c  + b c)e x  + (- 48a c  + 4b c)d e x
+--R         + 
+--R                    2     2   2              3  2 2
+--R           ((- 72a c  + 6b c)d  - 12a b c + b )e x
+--R         + 
+--R                    2     2   3                  3                 2    2   4
+--R           ((- 48a c  + 4b c)d  + (- 24a b c + 2b )d)e x + (- 12a c  + b c)d
+--R         + 
+--R                         3  2      2       2
+--R           (- 12a b c + b )d  - 12a c + a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  3 3           2 2            2           2            3
+--R           - b c e x  - 3b c d e x  + (- 3b c d  + 2a c - b )e x - b c d
+--R         + 
+--R                    2
+--R           (2a c - b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            2 2       2   5 4       2 2       2     4 3
+--R         (8a c  - 2a b c)e x  + (32a c  - 8a b c)d e x
+--R       + 
+--R              2 2        2   2     2          3  3 2
+--R         ((48a c  - 12a b c)d  + 8a b c - 2a b )e x
+--R       + 
+--R              2 2       2   3       2          3    2
+--R         ((32a c  - 8a b c)d  + (16a b c - 4a b )d)e x
+--R       + 
+--R             2 2       2   4      2          3  2     3      2 2
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + 8a c - 2a b )e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 546
+
+)clear all
+
+--S 547 of 585
+t0:=1/((d*f+e*f*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 9   9     2   8   8       2 2         7   7       2 3            6   6
+--R       c e f x  + 9c d e f x  + (36c d  + 2b c)e f x  + (84c d  + 14b c d)e f x
+--R     + 
+--R            2 4          2           2  5   5
+--R       (126c d  + 42b c d  + 2a c + b )e f x
+--R     + 
+--R            2 5          3              2    4   4
+--R       (126c d  + 70b c d  + (10a c + 5b )d)e f x
+--R     + 
+--R           2 6          4               2  2         3   3
+--R       (84c d  + 70b c d  + (20a c + 10b )d  + 2a b)e f x
+--R     + 
+--R           2 7          5               2  3           2   2
+--R       (36c d  + 42b c d  + (20a c + 10b )d  + 6a b d)e f x
+--R     + 
+--R          2 8          6              2  4         2    2
+--R       (9c d  + 14b c d  + (10a c + 5b )d  + 6a b d  + a )e f x
+--R     + 
+--R         2 9         7            2  5         3    2
+--R       (c d  + 2b c d  + (2a c + b )d  + 2a b d  + a d)f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 547
+
+--S 548 of 585
+r0:=1/2*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))+1/2*b*(b^2-6*a*c)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-_
+   4*a*c))/(a^2*(b^2-4*a*c)^(3/2)*e*f)+log(d+e*x)/(a^2*e*f)-_
+   1/4*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a^2*e*f)
+--R 
+--R
+--R   (2)
+--R                   2     3   4 4           2     3     3 3
+--R           (12a b c  - 2b c)e x  + (48a b c  - 8b c)d e x
+--R         + 
+--R                    2      3   2        2      4  2 2
+--R           ((72a b c  - 12b c)d  + 12a b c - 2b )e x
+--R         + 
+--R                    2     3   3         2      4                 2     3   4
+--R           ((48a b c  - 8b c)d  + (24a b c - 4b )d)e x + (12a b c  - 2b c)d
+--R         + 
+--R                 2      4  2      2          3
+--R           (12a b c - 2b )d  + 12a b c - 2a b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                      2    2   4 4           2     2     3 3
+--R               (- 4a c  + b c)e x  + (- 16a c  + 4b c)d e x
+--R             + 
+--R                        2     2   2             3  2 2
+--R               ((- 24a c  + 6b c)d  - 4a b c + b )e x
+--R             + 
+--R                        2     2   3                 3                2    2   4
+--R               ((- 16a c  + 4b c)d  + (- 8a b c + 2b )d)e x + (- 4a c  + b c)d
+--R             + 
+--R                            3  2     2       2
+--R               (- 4a b c + b )d  - 4a c + a b
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                     2     2   4 4         2      2     3 3
+--R               (16a c  - 4b c)e x  + (64a c  - 16b c)d e x
+--R             + 
+--R                      2      2   2               3  2 2
+--R               ((96a c  - 24b c)d  + 16a b c - 4b )e x
+--R             + 
+--R                      2      2   3                3               2     2   4
+--R               ((64a c  - 16b c)d  + (32a b c - 8b )d)e x + (16a c  - 4b c)d
+--R             + 
+--R                            3  2      2        2
+--R               (16a b c - 4b )d  + 16a c - 4a b
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                     2 2                          2     2        2
+--R           - 2a b c e x  - 4a b c d e x - 2a b c d  + 4a c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             3 2     2 2   5   4       3 2      2 2     4   3
+--R         (16a c  - 4a b c)e f x  + (64a c  - 16a b c)d e f x
+--R       + 
+--R              3 2      2 2   2      3        2 3  3   2
+--R         ((96a c  - 24a b c)d  + 16a b c - 4a b )e f x
+--R       + 
+--R              3 2      2 2   3       3        2 3    2
+--R         ((64a c  - 16a b c)d  + (32a b c - 8a b )d)e f x
+--R       + 
+--R              3 2     2 2   4       3        2 3  2      4      3 2
+--R         ((16a c  - 4a b c)d  + (16a b c - 4a b )d  + 16a c - 4a b )e f
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 549
+
+)clear all
+
+--S 550 of 585
+t0:=1/((d*f+e*f*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 10 2 10      2   9 2 9       2 2         8 2 8
+--R       c e  f x   + 10c d e f x  + (45c d  + 2b c)e f x
+--R     + 
+--R            2 3            7 2 7        2 4          2           2  6 2 6
+--R       (120c d  + 16b c d)e f x  + (210c d  + 56b c d  + 2a c + b )e f x
+--R     + 
+--R            2 5           3              2    5 2 5
+--R       (252c d  + 112b c d  + (12a c + 6b )d)e f x
+--R     + 
+--R            2 6           4               2  2         4 2 4
+--R       (210c d  + 140b c d  + (30a c + 15b )d  + 2a b)e f x
+--R     + 
+--R            2 7           5               2  3           3 2 3
+--R       (120c d  + 112b c d  + (40a c + 20b )d  + 8a b d)e f x
+--R     + 
+--R           2 8          6               2  4          2    2  2 2 2
+--R       (45c d  + 56b c d  + (30a c + 15b )d  + 12a b d  + a )e f x
+--R     + 
+--R           2 9          7              2  5         3     2     2
+--R       (10c d  + 16b c d  + (12a c + 6b )d  + 8a b d  + 2a d)e f x
+--R     + 
+--R         2 10         8            2  6         4    2 2  2
+--R       (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 550
+
+--S 551 of 585
+r0:=1/2*(-3*b^2+10*a*c)/(a^2*(b^2-4*a*c)*e*f^2*(d+e*x))+1/2*(b^2-_
+   2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f^2*(d+e*x)*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))-1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(3*b^2-10*a*c+b*(3*b^2-16*a*c)/sqrt(b^2-4*a*c))/_
+   (a^2*(b^2-4*a*c)*e*f^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (3*b^2-10*a*c+(-3*b^3+16*a*b*c)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*_
+   e*f^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       2     2   5 5           2      2     4 4
+--R               (- 10a c  + 3b c)e x  + (- 50a c  + 15b c)d e x
+--R             + 
+--R                         2      2   2               3  3 3
+--R               ((- 100a c  + 30b c)d  - 10a b c + 3b )e x
+--R             + 
+--R                         2      2   3                  3    2 2
+--R               ((- 100a c  + 30b c)d  + (- 30a b c + 9b )d)e x
+--R             + 
+--R                        2      2   4                  3  2      2        2
+--R               ((- 50a c  + 15b c)d  + (- 30a b c + 9b )d  - 10a c + 3a b )e x
+--R             + 
+--R                       2     2   5                  3  3         2        2
+--R               (- 10a c  + 3b c)d  + (- 10a b c + 3b )d  + (- 10a c + 3a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2     3   5 5             2      3     4 4
+--R           (- 16a b c  + 3b c)e x  + (- 80a b c  + 15b c)d e x
+--R         + 
+--R                       2      3   2        2      4  3 3
+--R           ((- 160a b c  + 30b c)d  - 16a b c + 3b )e x
+--R         + 
+--R                       2      3   3           2      4    2 2
+--R           ((- 160a b c  + 30b c)d  + (- 48a b c + 9b )d)e x
+--R         + 
+--R                      2      3   4           2      4  2      2          3
+--R           ((- 80a b c  + 15b c)d  + (- 48a b c + 9b )d  - 16a b c + 3a b )e x
+--R         + 
+--R                     2     3   5           2      4  3         2          3
+--R           (- 16a b c  + 3b c)d  + (- 16a b c + 3b )d  + (- 16a b c + 3a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                       2     2   5 5           2      2     4 4
+--R               (- 10a c  + 3b c)e x  + (- 50a c  + 15b c)d e x
+--R             + 
+--R                         2      2   2               3  3 3
+--R               ((- 100a c  + 30b c)d  - 10a b c + 3b )e x
+--R             + 
+--R                         2      2   3                  3    2 2
+--R               ((- 100a c  + 30b c)d  + (- 30a b c + 9b )d)e x
+--R             + 
+--R                        2      2   4                  3  2      2        2
+--R               ((- 50a c  + 15b c)d  + (- 30a b c + 9b )d  - 10a c + 3a b )e x
+--R             + 
+--R                       2     2   5                  3  3         2        2
+--R               (- 10a c  + 3b c)d  + (- 10a b c + 3b )d  + (- 10a c + 3a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2     3   5 5           2      3     4 4
+--R           (16a b c  - 3b c)e x  + (80a b c  - 15b c)d e x
+--R         + 
+--R                     2      3   2        2      4  3 3
+--R           ((160a b c  - 30b c)d  + 16a b c - 3b )e x
+--R         + 
+--R                     2      3   3         2      4    2 2
+--R           ((160a b c  - 30b c)d  + (48a b c - 9b )d)e x
+--R         + 
+--R                    2      3   4         2      4  2      2          3
+--R           ((80a b c  - 15b c)d  + (48a b c - 9b )d  + 16a b c - 3a b )e x
+--R         + 
+--R                   2     3   5         2      4  3       2          3
+--R           (16a b c  - 3b c)d  + (16a b c - 3b )d  + (16a b c - 3a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2     2   4 4           2      2     3 3
+--R           (- 10a c  + 3b c)e x  + (- 40a c  + 12b c)d e x
+--R         + 
+--R                    2      2   2               3  2 2
+--R           ((- 60a c  + 18b c)d  - 11a b c + 3b )e x
+--R         + 
+--R                    2      2   3                  3                 2     2   4
+--R           ((- 40a c  + 12b c)d  + (- 22a b c + 6b )d)e x + (- 10a c  + 3b c)d
+--R         + 
+--R                          3  2     2        2
+--R           (- 11a b c + 3b )d  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            3 2     2 2   6 2 5       3 2      2 2     5 2 4
+--R         (8a c  - 2a b c)e f x  + (40a c  - 10a b c)d e f x
+--R       + 
+--R              3 2      2 2   2     3        2 3  4 2 3
+--R         ((80a c  - 20a b c)d  + 8a b c - 2a b )e f x
+--R       + 
+--R              3 2      2 2   3       3        2 3    3 2 2
+--R         ((80a c  - 20a b c)d  + (24a b c - 6a b )d)e f x
+--R       + 
+--R              3 2      2 2   4       3        2 3  2     4      3 2  2 2
+--R         ((40a c  - 10a b c)d  + (24a b c - 6a b )d  + 8a c - 2a b )e f x
+--R       + 
+--R             3 2     2 2   5      3        2 3  3      4      3 2      2
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d)e f
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 585
+t0:=1/((d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 11 3 11      2   10 3 10       2 2         9 3 9
+--R       c e  f x   + 11c d e  f x   + (55c d  + 2b c)e f x
+--R     + 
+--R            2 3            8 3 8        2 4          2           2  7 3 7
+--R       (165c d  + 18b c d)e f x  + (330c d  + 72b c d  + 2a c + b )e f x
+--R     + 
+--R            2 5           3              2    6 3 6
+--R       (462c d  + 168b c d  + (14a c + 7b )d)e f x
+--R     + 
+--R            2 6           4               2  2         5 3 5
+--R       (462c d  + 252b c d  + (42a c + 21b )d  + 2a b)e f x
+--R     + 
+--R            2 7           5               2  3            4 3 4
+--R       (330c d  + 252b c d  + (70a c + 35b )d  + 10a b d)e f x
+--R     + 
+--R            2 8           6               2  4          2    2  3 3 3
+--R       (165c d  + 168b c d  + (70a c + 35b )d  + 20a b d  + a )e f x
+--R     + 
+--R           2 9          7               2  5          3     2   2 3 2
+--R       (55c d  + 72b c d  + (42a c + 21b )d  + 20a b d  + 3a d)e f x
+--R     + 
+--R           2 10          8              2  6          4     2 2    3
+--R       (11c d   + 18b c d  + (14a c + 7b )d  + 10a b d  + 3a d )e f x
+--R     + 
+--R         2 11         9            2  7         5    2 3  3
+--R       (c d   + 2b c d  + (2a c + b )d  + 2a b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 553
+
+--S 554 of 585
+r0:=(-b^2+3*a*c)/(a^2*(b^2-4*a*c)*e*f^3*(d+e*x)^2)+1/2*(b^2-2*a*c+_
+   b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f^3*(d+e*x)^2*(a+b*(d+e*x)^2+c*(d+_
+   e*x)^4))-(b^4-6*a*b^2*c+6*a^2*c^2)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-_
+   4*a*c))/(a^3*(b^2-4*a*c)^(3/2)*e*f^3)-2*b*log(d+e*x)/(a^3*e*f^3)+_
+   1/2*b*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a^3*e*f^3)
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   6 6       2 3        2 2      4     5 5
+--R           (12a c  - 12a b c  + 2b c)e x  + (72a c  - 72a b c  + 12b c)d e x
+--R         + 
+--R                 2 3         2 2      4   2      2   2        3      5  4 4
+--R           ((180a c  - 180a b c  + 30b c)d  + 12a b c  - 12a b c + 2b )e x
+--R         + 
+--R                 2 3         2 2      4   3       2   2        3      5    3 3
+--R           ((240a c  - 240a b c  + 40b c)d  + (48a b c  - 48a b c + 8b )d)e x
+--R         + 
+--R                    2 3         2 2      4   4       2   2        3       5  2
+--R               (180a c  - 180a b c  + 30b c)d  + (72a b c  - 72a b c + 12b )d
+--R             + 
+--R                  3 2      2 2        4
+--R               12a c  - 12a b c + 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                   2 3        2 2      4   5       2   2        3      5  3
+--R               (72a c  - 72a b c  + 12b c)d  + (48a b c  - 48a b c + 8b )d
+--R             + 
+--R                   3 2      2 2        4
+--R               (24a c  - 24a b c + 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2 3        2 2     4   6       2   2        3      5  4
+--R           (12a c  - 12a b c  + 2b c)d  + (12a b c  - 12a b c + 2b )d
+--R         + 
+--R               3 2      2 2        4  2
+--R           (12a c  - 12a b c + 2a b )d
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                      2    3   6 6           2     3     5 5
+--R               (4a b c  - b c)e x  + (24a b c  - 6b c)d e x
+--R             + 
+--R                        2      3   2       2     4  4 4
+--R               ((60a b c  - 15b c)d  + 4a b c - b )e x
+--R             + 
+--R                        2      3   3         2      4    3 3
+--R               ((80a b c  - 20b c)d  + (16a b c - 4b )d)e x
+--R             + 
+--R                        2      3   4         2      4  2     2         3  2 2
+--R               ((60a b c  - 15b c)d  + (24a b c - 6b )d  + 4a b c - a b )e x
+--R             + 
+--R                        2     3   5         2      4  3      2          3
+--R               ((24a b c  - 6b c)d  + (16a b c - 4b )d  + (8a b c - 2a b )d)e x
+--R             + 
+--R                      2    3   6        2     4  4      2         3  2
+--R               (4a b c  - b c)d  + (4a b c - b )d  + (4a b c - a b )d
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                         2     3   6 6             2      3     5 5
+--R               (- 16a b c  + 4b c)e x  + (- 96a b c  + 24b c)d e x
+--R             + 
+--R                           2      3   2        2      4  4 4
+--R               ((- 240a b c  + 60b c)d  - 16a b c + 4b )e x
+--R             + 
+--R                           2      3   3           2       4    3 3
+--R               ((- 320a b c  + 80b c)d  + (- 64a b c + 16b )d)e x
+--R             + 
+--R                              2      3   4           2       4  2      2
+--R                   (- 240a b c  + 60b c)d  + (- 96a b c + 24b )d  - 16a b c
+--R                 + 
+--R                       3
+--R                   4a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                             2      3   5           2       4  3
+--R                   (- 96a b c  + 24b c)d  + (- 64a b c + 16b )d
+--R                 + 
+--R                         2          3
+--R                   (- 32a b c + 8a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2     3   6           2      4  4         2          3  2
+--R             (- 16a b c  + 4b c)d  + (- 16a b c + 4b )d  + (- 16a b c + 4a b )d
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                2 2       2   4 4         2 2       2     3 3
+--R           (- 6a c  + 2a b c)e x  + (- 24a c  + 8a b c)d e x
+--R         + 
+--R                  2 2        2   2     2          3  2 2
+--R           ((- 36a c  + 12a b c)d  - 7a b c + 2a b )e x
+--R         + 
+--R                  2 2       2   3         2          3
+--R           ((- 24a c  + 8a b c)d  + (- 14a b c + 4a b )d)e x
+--R         + 
+--R                2 2       2   4        2          3  2     3     2 2
+--R           (- 6a c  + 2a b c)d  + (- 7a b c + 2a b )d  - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            4 2     3 2   7 3 6       4 2      3 2     6 3 5
+--R         (8a c  - 2a b c)e f x  + (48a c  - 12a b c)d e f x
+--R       + 
+--R               4 2      3 2   2     4        3 3  5 3 4
+--R         ((120a c  - 30a b c)d  + 8a b c - 2a b )e f x
+--R       + 
+--R               4 2      3 2   3       4        3 3    4 3 3
+--R         ((160a c  - 40a b c)d  + (32a b c - 8a b )d)e f x
+--R       + 
+--R               4 2      3 2   4       4         3 3  2     5      4 2  3 3 2
+--R         ((120a c  - 30a b c)d  + (48a b c - 12a b )d  + 8a c - 2a b )e f x
+--R       + 
+--R              4 2      3 2   5       4        3 3  3       5      4 2    2 3
+--R         ((48a c  - 12a b c)d  + (32a b c - 8a b )d  + (16a c - 4a b )d)e f x
+--R       + 
+--R             4 2     3 2   6      4        3 3  4      5      4 2  2    3
+--R         ((8a c  - 2a b c)d  + (8a b c - 2a b )d  + (8a c - 2a b )d )e f
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 585
+t0:=1/((d*f+e*f*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 12 4 12      2   11 4 11       2 2         10 4 10
+--R       c e  f x   + 12c d e  f x   + (66c d  + 2b c)e  f x
+--R     + 
+--R            2 3            9 4 9        2 4          2           2  8 4 8
+--R       (220c d  + 20b c d)e f x  + (495c d  + 90b c d  + 2a c + b )e f x
+--R     + 
+--R            2 5           3              2    7 4 7
+--R       (792c d  + 240b c d  + (16a c + 8b )d)e f x
+--R     + 
+--R            2 6           4               2  2         6 4 6
+--R       (924c d  + 420b c d  + (56a c + 28b )d  + 2a b)e f x
+--R     + 
+--R            2 7           5                2  3            5 4 5
+--R       (792c d  + 504b c d  + (112a c + 56b )d  + 12a b d)e f x
+--R     + 
+--R            2 8           6                2  4          2    2  4 4 4
+--R       (495c d  + 420b c d  + (140a c + 70b )d  + 30a b d  + a )e f x
+--R     + 
+--R            2 9           7                2  5          3     2   3 4 3
+--R       (220c d  + 240b c d  + (112a c + 56b )d  + 40a b d  + 4a d)e f x
+--R     + 
+--R           2 10          8               2  6          4     2 2  2 4 2
+--R       (66c d   + 90b c d  + (56a c + 28b )d  + 30a b d  + 6a d )e f x
+--R     + 
+--R           2 11          9              2  7          5     2 3    4
+--R       (12c d   + 20b c d  + (16a c + 8b )d  + 12a b d  + 4a d )e f x
+--R     + 
+--R         2 12         10            2  8         6    2 4  4
+--R       (c d   + 2b c d   + (2a c + b )d  + 2a b d  + a d )f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 556
+
+--S 557 of 585
+r0:=1/6*(-5*b^2+14*a*c)/(a^2*(b^2-4*a*c)*e*f^4*(d+e*x)^3)+1/2*b*(5*b^2-_
+   19*a*c)/(a^3*(b^2-4*a*c)*e*f^4*(d+e*x))+1/2*(b^2-2*a*c+b*c*(d+e*x)^2)/_
+   (a*(b^2-4*a*c)*e*f^4*(d+e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   1/2*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (5*b^3-19*a*b*c+(5*b^4-29*a*b^2*c+28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*_
+   (b^2-4*a*c)*e*f^4*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan((d+e*x)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(5*b^3-19*a*b*c+_
+   (-5*b^4+29*a*b^2*c-28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*_
+   e*f^4*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       2      3   7 7            2       3     6 6
+--R               (57a b c  - 15b c)e x  + (399a b c  - 105b c)d e x
+--R             + 
+--R                          2       3   2        2       4  5 5
+--R               ((1197a b c  - 315b c)d  + 57a b c - 15b )e x
+--R             + 
+--R                          2       3   3          2       4    4 4
+--R               ((1995a b c  - 525b c)d  + (285a b c - 75b )d)e x
+--R             + 
+--R                             2       3   4          2        4  2      2
+--R                   (1995a b c  - 525b c)d  + (570a b c - 150b )d  + 57a b c
+--R                 + 
+--R                          3
+--R                   - 15a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                             2       3   5          2        4  3
+--R                   (1197a b c  - 315b c)d  + (570a b c - 150b )d
+--R                 + 
+--R                        2           3
+--R                   (171a b c - 45a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                            2       3   6          2       4  4
+--R                   (399a b c  - 105b c)d  + (285a b c - 75b )d
+--R                 + 
+--R                        2           3  2
+--R                   (171a b c - 45a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2      3   7         2       4  5       2           3  3
+--R               (57a b c  - 15b c)d  + (57a b c - 15b )d  + (57a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 3        2 2      4   7 7
+--R           (- 84a c  + 87a b c  - 15b c)e x
+--R         + 
+--R                  2 3         2 2       4     6 6
+--R           (- 588a c  + 609a b c  - 105b c)d e x
+--R         + 
+--R                      2 3          2 2       4   2      2   2        3       5
+--R             ((- 1764a c  + 1827a b c  - 315b c)d  - 84a b c  + 87a b c - 15b )
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   3
+--R               (- 2940a c  + 3045a b c  - 525b c)d
+--R             + 
+--R                      2   2         3       5
+--R               (- 420a b c  + 435a b c - 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   4
+--R               (- 2940a c  + 3045a b c  - 525b c)d
+--R             + 
+--R                      2   2         3        5  2      3 2      2 2         4
+--R               (- 840a b c  + 870a b c - 150b )d  - 84a c  + 87a b c - 15a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 3          2 2       4   5
+--R               (- 1764a c  + 1827a b c  - 315b c)d
+--R             + 
+--R                      2   2         3        5  3
+--R               (- 840a b c  + 870a b c - 150b )d
+--R             + 
+--R                      3 2       2 2         4
+--R               (- 252a c  + 261a b c - 45a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      2 3         2 2       4   6
+--R               (- 588a c  + 609a b c  - 105b c)d
+--R             + 
+--R                      2   2         3       5  4
+--R               (- 420a b c  + 435a b c - 75b )d
+--R             + 
+--R                      3 2       2 2         4  2
+--R               (- 252a c  + 261a b c - 45a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2 3        2 2      4   7         2   2        3       5  5
+--R           (- 84a c  + 87a b c  - 15b c)d  + (- 84a b c  + 87a b c - 15b )d
+--R         + 
+--R                 3 2      2 2         4  3
+--R           (- 84a c  + 87a b c - 15a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                       2      3   7 7            2       3     6 6
+--R               (57a b c  - 15b c)e x  + (399a b c  - 105b c)d e x
+--R             + 
+--R                          2       3   2        2       4  5 5
+--R               ((1197a b c  - 315b c)d  + 57a b c - 15b )e x
+--R             + 
+--R                          2       3   3          2       4    4 4
+--R               ((1995a b c  - 525b c)d  + (285a b c - 75b )d)e x
+--R             + 
+--R                             2       3   4          2        4  2      2
+--R                   (1995a b c  - 525b c)d  + (570a b c - 150b )d  + 57a b c
+--R                 + 
+--R                          3
+--R                   - 15a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                             2       3   5          2        4  3
+--R                   (1197a b c  - 315b c)d  + (570a b c - 150b )d
+--R                 + 
+--R                        2           3
+--R                   (171a b c - 45a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                            2       3   6          2       4  4
+--R                   (399a b c  - 105b c)d  + (285a b c - 75b )d
+--R                 + 
+--R                        2           3  2
+--R                   (171a b c - 45a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                       2      3   7         2       4  5       2           3  3
+--R               (57a b c  - 15b c)d  + (57a b c - 15b )d  + (57a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 3        2 2      4   7 7
+--R           (84a c  - 87a b c  + 15b c)e x
+--R         + 
+--R                2 3         2 2       4     6 6
+--R           (588a c  - 609a b c  + 105b c)d e x
+--R         + 
+--R                  2 3          2 2       4   2      2   2        3       5  5 5
+--R           ((1764a c  - 1827a b c  + 315b c)d  + 84a b c  - 87a b c + 15b )e x
+--R         + 
+--R                       2 3          2 2       4   3
+--R                 (2940a c  - 3045a b c  + 525b c)d
+--R               + 
+--R                      2   2         3       5
+--R                 (420a b c  - 435a b c + 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2 3          2 2       4   4
+--R               (2940a c  - 3045a b c  + 525b c)d
+--R             + 
+--R                    2   2         3        5  2      3 2      2 2         4
+--R               (840a b c  - 870a b c + 150b )d  + 84a c  - 87a b c + 15a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2 3          2 2       4   5
+--R               (1764a c  - 1827a b c  + 315b c)d
+--R             + 
+--R                  2   2         3        5  3        3 2       2 2         4
+--R             (840a b c  - 870a b c + 150b )d  + (252a c  - 261a b c + 45a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                    2 3         2 2       4   6
+--R               (588a c  - 609a b c  + 105b c)d
+--R             + 
+--R                  2   2         3       5  4        3 2       2 2         4  2
+--R             (420a b c  - 435a b c + 75b )d  + (252a c  - 261a b c + 45a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2 3        2 2      4   7       2   2        3       5  5
+--R           (84a c  - 87a b c  + 15b c)d  + (84a b c  - 87a b c + 15b )d
+--R         + 
+--R               3 2      2 2         4  3
+--R           (84a c  - 87a b c + 15a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   2      3   6 6            2      3     5 5
+--R           (57a b c  - 15b c)e x  + (342a b c  - 90b c)d e x
+--R         + 
+--R                     2       3   2      2 2        2       4  4 4
+--R           ((855a b c  - 225b c)d  - 14a c  + 62a b c - 15b )e x
+--R         + 
+--R                      2       3   3         2 2         2       4    3 3
+--R           ((1140a b c  - 300b c)d  + (- 56a c  + 248a b c - 60b )d)e x
+--R         + 
+--R                        2       3   4         2 2         2       4  2      2
+--R               (855a b c  - 225b c)d  + (- 84a c  + 372a b c - 90b )d  + 40a b c
+--R             + 
+--R                      3
+--R               - 10a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        2      3   5         2 2         2       4  3
+--R               (342a b c  - 90b c)d  + (- 56a c  + 248a b c - 60b )d
+--R             + 
+--R                   2           3
+--R               (80a b c - 20a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   2      3   6         2 2        2       4  4
+--R           (57a b c  - 15b c)d  + (- 14a c  + 62a b c - 15b )d
+--R         + 
+--R               2           3  2     3      2 2
+--R           (40a b c - 10a b )d  - 8a c + 2a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R             4 2     3 2   8 4 7        4 2      3 2     7 4 6
+--R         (24a c  - 6a b c)e f x  + (168a c  - 42a b c)d e f x
+--R       + 
+--R               4 2       3 2   2      4        3 3  6 4 5
+--R         ((504a c  - 126a b c)d  + 24a b c - 6a b )e f x
+--R       + 
+--R               4 2       3 2   3        4         3 3    5 4 4
+--R         ((840a c  - 210a b c)d  + (120a b c - 30a b )d)e f x
+--R       + 
+--R               4 2       3 2   4        4         3 3  2      5      4 2  4 4 3
+--R         ((840a c  - 210a b c)d  + (240a b c - 60a b )d  + 24a c - 6a b )e f x
+--R       + 
+--R                 4 2       3 2   5        4         3 3  3       5       4 2
+--R           ((504a c  - 126a b c)d  + (240a b c - 60a b )d  + (72a c - 18a b )d)
+--R        *
+--R            3 4 2
+--R           e f x
+--R       + 
+--R                 4 2      3 2   6        4         3 3  4       5       4 2  2
+--R           ((168a c  - 42a b c)d  + (120a b c - 30a b )d  + (72a c - 18a b )d )
+--R        *
+--R            2 4
+--R           e f x
+--R       + 
+--R              4 2     3 2   7       4        3 3  5       5      4 2  3    4
+--R         ((24a c  - 6a b c)d  + (24a b c - 6a b )d  + (24a c - 6a b )d )e f
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 558
+
+)clear all
+
+--S 559 of 585
+t0:=(d*f+e*f*x)^4/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      4 4 4       3 4 3     2 2 4 2     3   4     4 4
+--R     e f x  + 4d e f x  + 6d e f x  + 4d e f x + d f
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 559
+
+--S 560 of 585
+r0:=1/4*f^4*(d+e*x)*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)-1/8*f^4*(d+e*x)*(7*b^2-4*a*c+12*b*c*(d+e*x)^2)/((b^2-_
+   4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+3/4*f^4*atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2+4*a*c-2*b*sqrt(b^2-_
+   4*a*c))/((b^2-4*a*c)^(5/2)*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   3/4*f^4*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (3*b^2+4*a*c+2*b*sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2 8 4 8        2   7 4 7            2 2      2   6 4 6
+--R               - 12b c e f x  - 96b c d e f x  + (- 336b c d  - 24b c)e f x
+--R             + 
+--R                        2 3       2     5 4 5
+--R               (- 672b c d  - 144b c d)e f x
+--R             + 
+--R                        2 4       2   2                3  4 4 4
+--R               (- 840b c d  - 360b c d  - 24a b c - 12b )e f x
+--R             + 
+--R                        2 5       2   3                   3    3 4 3
+--R               (- 672b c d  - 480b c d  + (- 96a b c - 48b )d)e f x
+--R             + 
+--R                        2 6       2   4                    3  2        2  2 4 2
+--R               (- 336b c d  - 360b c d  + (- 144a b c - 72b )d  - 24a b )e f x
+--R             + 
+--R                       2 7       2   5                   3  3        2     4
+--R               (- 96b c d  - 144b c d  + (- 96a b c - 48b )d  - 48a b d)e f x
+--R             + 
+--R                     2 8      2   6                   3  4        2 2      2   4
+--R             (- 12b c d  - 24b c d  + (- 24a b c - 12b )d  - 24a b d  - 12a b)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3      2 2  8 4 8          3       2 2    7 4 7
+--R           (24a c  + 18b c )e f x  + (192a c  + 144b c )d e f x
+--R         + 
+--R                   3       2 2  2          2      3   6 4 6
+--R           ((672a c  + 504b c )d  + 48a b c  + 36b c)e f x
+--R         + 
+--R                    3        2 2  3            2       3     5 4 5
+--R           ((1344a c  + 1008b c )d  + (288a b c  + 216b c)d)e f x
+--R         + 
+--R                       3        2 2  4            2       3   2      2 2
+--R               (1680a c  + 1260b c )d  + (720a b c  + 540b c)d  + 48a c
+--R             + 
+--R                    2       4
+--R               60a b c + 18b
+--R          *
+--R              4 4 4
+--R             e f x
+--R         + 
+--R                       3        2 2  5            2       3   3
+--R               (1344a c  + 1008b c )d  + (960a b c  + 720b c)d
+--R             + 
+--R                    2 2         2       4
+--R               (192a c  + 240a b c + 72b )d
+--R          *
+--R              3 4 3
+--R             e f x
+--R         + 
+--R                      3       2 2  6            2       3   4
+--R               (672a c  + 504b c )d  + (720a b c  + 540b c)d
+--R             + 
+--R                    2 2         2        4  2      2           3
+--R               (288a c  + 360a b c + 108b )d  + 48a b c + 36a b
+--R          *
+--R              2 4 2
+--R             e f x
+--R         + 
+--R                      3       2 2  7            2       3   5
+--R               (192a c  + 144b c )d  + (288a b c  + 216b c)d
+--R             + 
+--R                    2 2         2       4  3       2           3
+--R               (192a c  + 240a b c + 72b )d  + (96a b c + 72a b )d
+--R          *
+--R                4
+--R             e f x
+--R         + 
+--R                     3      2 2  8           2      3   6
+--R               (24a c  + 18b c )d  + (48a b c  + 36b c)d
+--R             + 
+--R                 2 2        2       4  4       2           3  2      3       2 2
+--R             (48a c  + 60a b c + 18b )d  + (48a b c + 36a b )d  + 24a c + 18a b
+--R          *
+--R              4
+--R             f
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2 8 4 8        2   7 4 7            2 2      2   6 4 6
+--R               - 12b c e f x  - 96b c d e f x  + (- 336b c d  - 24b c)e f x
+--R             + 
+--R                        2 3       2     5 4 5
+--R               (- 672b c d  - 144b c d)e f x
+--R             + 
+--R                        2 4       2   2                3  4 4 4
+--R               (- 840b c d  - 360b c d  - 24a b c - 12b )e f x
+--R             + 
+--R                        2 5       2   3                   3    3 4 3
+--R               (- 672b c d  - 480b c d  + (- 96a b c - 48b )d)e f x
+--R             + 
+--R                        2 6       2   4                    3  2        2  2 4 2
+--R               (- 336b c d  - 360b c d  + (- 144a b c - 72b )d  - 24a b )e f x
+--R             + 
+--R                       2 7       2   5                   3  3        2     4
+--R               (- 96b c d  - 144b c d  + (- 96a b c - 48b )d  - 48a b d)e f x
+--R             + 
+--R                     2 8      2   6                   3  4        2 2      2   4
+--R             (- 12b c d  - 24b c d  + (- 24a b c - 12b )d  - 24a b d  - 12a b)f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3      2 2  8 4 8            3       2 2    7 4 7
+--R           (- 24a c  - 18b c )e f x  + (- 192a c  - 144b c )d e f x
+--R         + 
+--R                     3       2 2  2          2      3   6 4 6
+--R           ((- 672a c  - 504b c )d  - 48a b c  - 36b c)e f x
+--R         + 
+--R                      3        2 2  3              2       3     5 4 5
+--R           ((- 1344a c  - 1008b c )d  + (- 288a b c  - 216b c)d)e f x
+--R         + 
+--R                         3        2 2  4              2       3   2      2 2
+--R               (- 1680a c  - 1260b c )d  + (- 720a b c  - 540b c)d  - 48a c
+--R             + 
+--R                      2       4
+--R               - 60a b c - 18b
+--R          *
+--R              4 4 4
+--R             e f x
+--R         + 
+--R                         3        2 2  5              2       3   3
+--R               (- 1344a c  - 1008b c )d  + (- 960a b c  - 720b c)d
+--R             + 
+--R                      2 2         2       4
+--R               (- 192a c  - 240a b c - 72b )d
+--R          *
+--R              3 4 3
+--R             e f x
+--R         + 
+--R                        3       2 2  6              2       3   4
+--R               (- 672a c  - 504b c )d  + (- 720a b c  - 540b c)d
+--R             + 
+--R                      2 2         2        4  2      2           3
+--R               (- 288a c  - 360a b c - 108b )d  - 48a b c - 36a b
+--R          *
+--R              2 4 2
+--R             e f x
+--R         + 
+--R                        3       2 2  7              2       3   5
+--R               (- 192a c  - 144b c )d  + (- 288a b c  - 216b c)d
+--R             + 
+--R                      2 2         2       4  3         2           3
+--R               (- 192a c  - 240a b c - 72b )d  + (- 96a b c - 72a b )d
+--R          *
+--R                4
+--R             e f x
+--R         + 
+--R                       3      2 2  8             2      3   6
+--R               (- 24a c  - 18b c )d  + (- 48a b c  - 36b c)d
+--R             + 
+--R                     2 2        2       4  4         2           3  2      3
+--R               (- 48a c  - 60a b c - 18b )d  + (- 48a b c - 36a b )d  - 24a c
+--R             + 
+--R                    2 2
+--R               - 18a b
+--R          *
+--R              4
+--R             f
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 7 4 7        2   6 4 6            2 2       2      2   5 4 5
+--R           - 12b c e f x  - 84b c d e f x  + (- 252b c d  + 4a c  - 19b c)e f x
+--R         + 
+--R                    2 3         2      2     4 4 4
+--R           (- 420b c d  + (20a c  - 95b c)d)e f x
+--R         + 
+--R                    2 4         2       2   2               3  3 4 3
+--R           (- 420b c d  + (40a c  - 190b c)d  - 16a b c - 5b )e f x
+--R         + 
+--R                    2 5         2       2   3                   3    2 4 2
+--R           (- 252b c d  + (40a c  - 190b c)d  + (- 48a b c - 15b )d)e f x
+--R         + 
+--R                      2 6         2      2   4                   3  2      2
+--R               - 84b c d  + (20a c  - 95b c)d  + (- 48a b c - 15b )d  - 12a c
+--R             + 
+--R                     2
+--R               - 3a b
+--R          *
+--R                4
+--R             e f x
+--R         + 
+--R                      2 7        2      2   5                  3  3
+--R               - 12b c d  + (4a c  - 19b c)d  + (- 16a b c - 5b )d
+--R             + 
+--R                     2        2
+--R               (- 12a c - 3a b )d
+--R          *
+--R              4
+--R             f
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 4        2 3     4 2  9 8
+--R         (128a c  - 64a b c  + 8b c )e x
+--R       + 
+--R               2 4         2 3      4 2    8 7
+--R         (1024a c  - 512a b c  + 64b c )d e x
+--R       + 
+--R                  2 4          2 3       4 2  2       2   3         3 2      5
+--R           ((3584a c  - 1792a b c  + 224b c )d  + 256a b c  - 128a b c  + 16b c)
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (7168a c  - 3584a b c  + 448b c )d
+--R           + 
+--R                   2   3         3 2      5
+--R             (1536a b c  - 768a b c  + 96b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (8960a c  - 4480a b c  + 560b c )d
+--R           + 
+--R                   2   3          3 2       5   2       3 3        4      6
+--R             (3840a b c  - 1920a b c  + 240b c)d  + 256a c  - 48a b c + 8b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (7168a c  - 3584a b c  + 448b c )d
+--R           + 
+--R                 2   3          3 2       5   3         3 3         4       6
+--R           (5120a b c  - 2560a b c  + 320b c)d  + (1024a c  - 192a b c + 32b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  6
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   4
+--R             (3840a b c  - 1920a b c  + 240b c)d
+--R           + 
+--R                   3 3         4       6  2       3   2       2 3         5
+--R             (1536a c  - 288a b c + 48b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   2 4         2 3      4 2  7
+--R             (1024a c  - 512a b c  + 64b c )d
+--R           + 
+--R                   2   3         3 2      5   5         3 3         4       6  3
+--R             (1536a b c  - 768a b c  + 96b c)d  + (1024a c  - 192a b c + 32b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  2 4        2 3     4 2  8        2   3         3 2      5   6
+--R             (128a c  - 64a b c  + 8b c )d  + (256a b c  - 128a b c  + 16b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2       2 3         5  2
+--R             (256a c  - 48a b c + 8b )d  + (256a b c  - 128a b c + 16a b )d
+--R           + 
+--R                 4 2      3 2      2 4
+--R             128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 585
+t0:=(d*f+e*f*x)^3/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      3 3 3       2 3 2     2   3     3 3
+--R     e f x  + 3d e f x  + 3d e f x + d f
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 562
+
+--S 563 of 585
+r0:=1/4*f^3*(2*a+b*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)-_
+   3/4*b*f^3*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   3*b*c*f^3*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e)
+--R 
+--R
+--R   (2)
+--R                3 8 3 8        3   7 3 7          3 2      2 2  6 3 6
+--R           12b c e f x  + 96b c d e f x  + (336b c d  + 24b c )e f x
+--R         + 
+--R                  3 3       2 2   5 3 5
+--R           (672b c d  + 144b c d)e f x
+--R         + 
+--R                  3 4       2 2 2          2      3   4 3 4
+--R           (840b c d  + 360b c d  + 24a b c  + 12b c)e f x
+--R         + 
+--R                  3 5       2 2 3           2      3     3 3 3
+--R           (672b c d  + 480b c d  + (96a b c  + 48b c)d)e f x
+--R         + 
+--R                  3 6       2 2 4            2      3   2        2   2 3 2
+--R           (336b c d  + 360b c d  + (144a b c  + 72b c)d  + 24a b c)e f x
+--R         + 
+--R                 3 7       2 2 5           2      3   3        2       3
+--R           (96b c d  + 144b c d  + (96a b c  + 48b c)d  + 48a b c d)e f x
+--R         + 
+--R               3 8      2 2 6           2      3   4        2   2      2     3
+--R         (12b c d  + 24b c d  + (24a b c  + 12b c)d  + 24a b c d  + 12a b c)f
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                 2 6 3 6        2   5 3 5           2 2     2   4 3 4
+--R           - 6b c e f x  - 36b c d e f x  + (- 90b c d  - 9b c)e f x
+--R         + 
+--R                    2 3      2     3 3 3
+--R           (- 120b c d  - 36b c d)e f x
+--R         + 
+--R                   2 4      2   2               3  2 3 2
+--R           (- 90b c d  - 54b c d  - 10a b c - 2b )e f x
+--R         + 
+--R                   2 5      2   3                  3      3
+--R           (- 36b c d  - 36b c d  + (- 20a b c - 4b )d)e f x
+--R         + 
+--R                  2 6     2   4                  3  2     2       2  3
+--R           (- 6b c d  - 9b c d  + (- 10a b c - 2b )d  - 8a c - a b )f
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  9 8        2 4         2 3      4 2    8 7
+--R         (64a c  - 32a b c  + 4b c )e x  + (512a c  - 256a b c  + 32b c )d e x
+--R       + 
+--R                2 4         2 3       4 2  2       2   3        3 2     5   7 6
+--R         ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                  2   3         3 2      5
+--R             (768a b c  - 384a b c  + 48b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (4480a c  - 2240a b c  + 280b c )d
+--R           + 
+--R                   2   3         3 2       5   2       3 3        4      6
+--R             (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4         2 3       4 2  6
+--R             (1792a c  - 896a b c  + 112b c )d
+--R           + 
+--R                   2   3         3 2       5   4        3 3         4       6  2
+--R             (1920a b c  - 960a b c  + 120b c)d  + (768a c  - 144a b c + 24b )d
+--R           + 
+--R                 3   2      2 3        5
+--R             128a b c  - 64a b c + 8a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  2 4         2 3      4 2  7
+--R             (512a c  - 256a b c  + 32b c )d
+--R           + 
+--R                  2   3         3 2      5   5        3 3        4       6  3
+--R             (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 2 4        2 3     4 2  8        2   3        3 2     5   6
+--R             (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2      2 3        5  2
+--R             (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                4 2      3 2      2 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 585
+t0:=(d*f+e*f*x)^2/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R      2 2 2         2     2 2
+--R     e f x  + 2d e f x + d f
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 565
+
+--S 566 of 585
+r0:=-1/4*f^2*(d+e*x)*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/8*f^2*(d+e*x)*(b*(b^2+8*a*c)+c*(b^2+20*a*c)*(d+_
+   e*x)^2)/(a*(b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+1/8*f^2*_
+   atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b^2+_
+   20*a*c+b*(b^2-52*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*e*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/8*f^2*atan((d+e*x)*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b^2+20*a*c-b*(b^2-52*a*c)/_
+   sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     3    2 2  8 2 8          3     2 2    7 2 7
+--R               (20a c  + b c )e f x  + (160a c  + 8b c )d e f x
+--R             + 
+--R                       3      2 2  2          2     3   6 2 6
+--R               ((560a c  + 28b c )d  + 40a b c  + 2b c)e f x
+--R             + 
+--R                        3      2 2  3            2      3     5 2 5
+--R               ((1120a c  + 56b c )d  + (240a b c  + 12b c)d)e f x
+--R             + 
+--R                           3      2 2  4            2      3   2      2 2
+--R                   (1400a c  + 70b c )d  + (600a b c  + 30b c)d  + 40a c
+--R                 + 
+--R                        2     4
+--R                   22a b c + b
+--R              *
+--R                  4 2 4
+--R                 e f x
+--R             + 
+--R                           3      2 2  5            2      3   3
+--R                   (1120a c  + 56b c )d  + (800a b c  + 40b c)d
+--R                 + 
+--R                        2 2        2      4
+--R                   (160a c  + 88a b c + 4b )d
+--R              *
+--R                  3 2 3
+--R                 e f x
+--R             + 
+--R                          3      2 2  6            2      3   4
+--R                   (560a c  + 28b c )d  + (600a b c  + 30b c)d
+--R                 + 
+--R                        2 2         2      4  2      2          3
+--R                   (240a c  + 132a b c + 6b )d  + 40a b c + 2a b
+--R              *
+--R                  2 2 2
+--R                 e f x
+--R             + 
+--R                          3     2 2  7            2      3   5
+--R                   (160a c  + 8b c )d  + (240a b c  + 12b c)d
+--R                 + 
+--R                        2 2        2      4  3       2          3
+--R                   (160a c  + 88a b c + 4b )d  + (80a b c + 4a b )d
+--R              *
+--R                    2
+--R                 e f x
+--R             + 
+--R                         3    2 2  8           2     3   6
+--R                   (20a c  + b c )d  + (40a b c  + 2b c)d
+--R                 + 
+--R                     2 2        2     4  4       2          3  2      3     2 2
+--R                 (40a c  + 22a b c + b )d  + (40a b c + 2a b )d  + 20a c + a b
+--R              *
+--R                  2
+--R                 f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     3    3 2  8 2 8              3     3 2    7 2 7
+--R           (- 52a b c  + b c )e f x  + (- 416a b c  + 8b c )d e f x
+--R         + 
+--R                        3      3 2  2         2 2     4   6 2 6
+--R           ((- 1456a b c  + 28b c )d  - 104a b c  + 2b c)e f x
+--R         + 
+--R                        3      3 2  3            2 2      4     5 2 5
+--R           ((- 2912a b c  + 56b c )d  + (- 624a b c  + 12b c)d)e f x
+--R         + 
+--R                           3      3 2  4             2 2      4   2       2   2
+--R               (- 3640a b c  + 70b c )d  + (- 1560a b c  + 30b c)d  - 104a b c
+--R             + 
+--R                      3     5
+--R               - 50a b c + b
+--R          *
+--R              4 2 4
+--R             e f x
+--R         + 
+--R                           3      3 2  5             2 2      4   3
+--R               (- 2912a b c  + 56b c )d  + (- 2080a b c  + 40b c)d
+--R             + 
+--R                      2   2         3      5
+--R               (- 416a b c  - 200a b c + 4b )d
+--R          *
+--R              3 2 3
+--R             e f x
+--R         + 
+--R                           3      3 2  6             2 2      4   4
+--R               (- 1456a b c  + 28b c )d  + (- 1560a b c  + 30b c)d
+--R             + 
+--R                      2   2         3      5  2       2 2        4
+--R               (- 624a b c  - 300a b c + 6b )d  - 104a b c + 2a b
+--R          *
+--R              2 2 2
+--R             e f x
+--R         + 
+--R                          3     3 2  7            2 2      4   5
+--R               (- 416a b c  + 8b c )d  + (- 624a b c  + 12b c)d
+--R             + 
+--R                      2   2         3      5  3          2 2        4
+--R               (- 416a b c  - 200a b c + 4b )d  + (- 208a b c + 4a b )d
+--R          *
+--R                2
+--R             e f x
+--R         + 
+--R                         3    3 2  8            2 2     4   6
+--R               (- 52a b c  + b c )d  + (- 104a b c  + 2b c)d
+--R             + 
+--R                      2   2        3     5  4          2 2        4  2      3
+--R               (- 104a b c  - 50a b c + b )d  + (- 104a b c + 2a b )d  - 52a b c
+--R             + 
+--R                2 3
+--R               a b
+--R          *
+--R              2
+--R             f
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     3    2 2  8 2 8          3     2 2    7 2 7
+--R               (20a c  + b c )e f x  + (160a c  + 8b c )d e f x
+--R             + 
+--R                       3      2 2  2          2     3   6 2 6
+--R               ((560a c  + 28b c )d  + 40a b c  + 2b c)e f x
+--R             + 
+--R                        3      2 2  3            2      3     5 2 5
+--R               ((1120a c  + 56b c )d  + (240a b c  + 12b c)d)e f x
+--R             + 
+--R                           3      2 2  4            2      3   2      2 2
+--R                   (1400a c  + 70b c )d  + (600a b c  + 30b c)d  + 40a c
+--R                 + 
+--R                        2     4
+--R                   22a b c + b
+--R              *
+--R                  4 2 4
+--R                 e f x
+--R             + 
+--R                           3      2 2  5            2      3   3
+--R                   (1120a c  + 56b c )d  + (800a b c  + 40b c)d
+--R                 + 
+--R                        2 2        2      4
+--R                   (160a c  + 88a b c + 4b )d
+--R              *
+--R                  3 2 3
+--R                 e f x
+--R             + 
+--R                          3      2 2  6            2      3   4
+--R                   (560a c  + 28b c )d  + (600a b c  + 30b c)d
+--R                 + 
+--R                        2 2         2      4  2      2          3
+--R                   (240a c  + 132a b c + 6b )d  + 40a b c + 2a b
+--R              *
+--R                  2 2 2
+--R                 e f x
+--R             + 
+--R                          3     2 2  7            2      3   5
+--R                   (160a c  + 8b c )d  + (240a b c  + 12b c)d
+--R                 + 
+--R                        2 2        2      4  3       2          3
+--R                   (160a c  + 88a b c + 4b )d  + (80a b c + 4a b )d
+--R              *
+--R                    2
+--R                 e f x
+--R             + 
+--R                         3    2 2  8           2     3   6
+--R                   (20a c  + b c )d  + (40a b c  + 2b c)d
+--R                 + 
+--R                     2 2        2     4  4       2          3  2      3     2 2
+--R                 (40a c  + 22a b c + b )d  + (40a b c + 2a b )d  + 20a c + a b
+--R              *
+--R                  2
+--R                 f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3    3 2  8 2 8            3     3 2    7 2 7
+--R           (52a b c  - b c )e f x  + (416a b c  - 8b c )d e f x
+--R         + 
+--R                      3      3 2  2         2 2     4   6 2 6
+--R           ((1456a b c  - 28b c )d  + 104a b c  - 2b c)e f x
+--R         + 
+--R                      3      3 2  3          2 2      4     5 2 5
+--R           ((2912a b c  - 56b c )d  + (624a b c  - 12b c)d)e f x
+--R         + 
+--R                         3      3 2  4           2 2      4   2       2   2
+--R               (3640a b c  - 70b c )d  + (1560a b c  - 30b c)d  + 104a b c
+--R             + 
+--R                    3     5
+--R               50a b c - b
+--R          *
+--R              4 2 4
+--R             e f x
+--R         + 
+--R                         3      3 2  5           2 2      4   3
+--R               (2912a b c  - 56b c )d  + (2080a b c  - 40b c)d
+--R             + 
+--R                    2   2         3      5
+--R               (416a b c  + 200a b c - 4b )d
+--R          *
+--R              3 2 3
+--R             e f x
+--R         + 
+--R                         3      3 2  6           2 2      4   4
+--R               (1456a b c  - 28b c )d  + (1560a b c  - 30b c)d
+--R             + 
+--R                    2   2         3      5  2       2 2        4
+--R               (624a b c  + 300a b c - 6b )d  + 104a b c - 2a b
+--R          *
+--R              2 2 2
+--R             e f x
+--R         + 
+--R                        3     3 2  7          2 2      4   5
+--R               (416a b c  - 8b c )d  + (624a b c  - 12b c)d
+--R             + 
+--R                    2   2         3      5  3        2 2        4
+--R               (416a b c  + 200a b c - 4b )d  + (208a b c - 4a b )d
+--R          *
+--R                2
+--R             e f x
+--R         + 
+--R                       3    3 2  8          2 2     4   6
+--R               (52a b c  - b c )d  + (104a b c  - 2b c)d
+--R             + 
+--R                    2   2        3     5  4        2 2        4  2      3
+--R               (104a b c  + 50a b c - b )d  + (104a b c - 2a b )d  + 52a b c
+--R             + 
+--R                  2 3
+--R               - a b
+--R          *
+--R              2
+--R             f
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 3    2 2  7 2 7          3     2 2    6 2 6
+--R           (20a c  + b c )e f x  + (140a c  + 7b c )d e f x
+--R         + 
+--R                   3      2 2  2          2     3   5 2 5
+--R           ((420a c  + 21b c )d  + 28a b c  + 2b c)e f x
+--R         + 
+--R                   3      2 2  3            2      3     4 2 4
+--R           ((700a c  + 35b c )d  + (140a b c  + 10b c)d)e f x
+--R         + 
+--R                        3      2 2  4            2      3   2      2 2       2
+--R                 (700a c  + 35b c )d  + (280a b c  + 20b c)d  + 36a c  + 5a b c
+--R               + 
+--R                  4
+--R                 b
+--R          *
+--R              3 2 3
+--R             e f x
+--R         + 
+--R                      3      2 2  5            2      3   3
+--R               (420a c  + 21b c )d  + (280a b c  + 20b c)d
+--R             + 
+--R                    2 2        2      4
+--R               (108a c  + 15a b c + 3b )d
+--R          *
+--R              2 2 2
+--R             e f x
+--R         + 
+--R                      3     2 2  6            2      3   4
+--R               (140a c  + 7b c )d  + (140a b c  + 10b c)d
+--R             + 
+--R                    2 2        2      4  2      2         3
+--R               (108a c  + 15a b c + 3b )d  + 16a b c - a b
+--R          *
+--R                2
+--R             e f x
+--R         + 
+--R                     3    2 2  7           2     3   5
+--R               (20a c  + b c )d  + (28a b c  + 2b c)d
+--R             + 
+--R                   2 2       2     4  3       2         3
+--R               (36a c  + 5a b c + b )d  + (16a b c - a b )d
+--R          *
+--R              2
+--R             f
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              3 4      2 2 3       4 2  9 8
+--R         (128a c  - 64a b c  + 8a b c )e x
+--R       + 
+--R               3 4       2 2 3        4 2    8 7
+--R         (1024a c  - 512a b c  + 64a b c )d e x
+--R       + 
+--R                   3 4        2 2 3         4 2  2       3   3       2 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                  5
+--R             16a b c
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  3
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   3   3       2 3 2        5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  4
+--R             (8960a c  - 4480a b c  + 560a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   2       4 3      2 4        6
+--R             (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  5
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   3
+--R             (5120a b c  - 2560a b c  + 320a b c)d
+--R           + 
+--R                   4 3       2 4         6
+--R             (1024a c  - 192a b c + 32a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   3 4        2 2 3         4 2  6
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   3   3        2 3 2         5   4
+--R             (3840a b c  - 1920a b c  + 240a b c)d
+--R           + 
+--R                   4 3       2 4         6  2       4   2       3 3       2 5
+--R             (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   3 4       2 2 3        4 2  7
+--R             (1024a c  - 512a b c  + 64a b c )d
+--R           + 
+--R                   3   3       2 3 2        5   5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R           + 
+--R                 4 3       2 4         6  3        4   2       3 3       2 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  3 4      2 2 3       4 2  8
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  3   3       2 3 2        5   6        4 3      2 4        6  4
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  4   2       3 3       2 5  2       5 2      4 2      3 4
+--R             (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 567
+
+)clear all
+
+--S 568 of 585
+t0:=(d*f+e*f*x)/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R     e f x + d f
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 568
+
+--S 569 of 585
+r0:=-1/4*f*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)*e*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)+_
+   3/2*c*f*(b+2*c*(d+e*x)^2)/((b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))-_
+   6*c^2*f*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^(5/2)*e)
+--R 
+--R
+--R   (2)
+--R                4 8   8       4   7   7          4 2        3  6   6
+--R           - 24c e f x  - 192c d e f x  + (- 672c d  - 48b c )e f x
+--R         + 
+--R                   4 3         3   5   5
+--R           (- 1344c d  - 288b c d)e f x
+--R         + 
+--R                   4 4         3 2        3      2 2  4   4
+--R           (- 1680c d  - 720b c d  - 48a c  - 24b c )e f x
+--R         + 
+--R                   4 5         3 3            3      2 2    3   3
+--R           (- 1344c d  - 960b c d  + (- 192a c  - 96b c )d)e f x
+--R         + 
+--R                  4 6         3 4            3       2 2  2          2  2   2
+--R           (- 672c d  - 720b c d  + (- 288a c  - 144b c )d  - 48a b c )e f x
+--R         + 
+--R                  4 7         3 5            3      2 2  3          2
+--R           (- 192c d  - 288b c d  + (- 192a c  - 96b c )d  - 96a b c d)e f x
+--R         + 
+--R                 4 8        3 6           3      2 2  4          2 2      2 2
+--R           (- 24c d  - 48b c d  + (- 48a c  - 24b c )d  - 48a b c d  - 24a c )f
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R              3 6   6      3   5   5        3 2        2  4   4
+--R           12c e f x  + 72c d e f x  + (180c d  + 18b c )e f x
+--R         + 
+--R                3 3        2   3   3
+--R           (240c d  + 72b c d)e f x
+--R         + 
+--R                3 4         2 2        2     2   2   2
+--R           (180c d  + 108b c d  + 20a c  + 4b c)e f x
+--R         + 
+--R               3 5        2 3         2     2
+--R           (72c d  + 72b c d  + (40a c  + 8b c)d)e f x
+--R         + 
+--R               3 6        2 4         2     2   2              3
+--R           (12c d  + 18b c d  + (20a c  + 4b c)d  + 10a b c - b )f
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  9 8        2 4         2 3      4 2    8 7
+--R         (64a c  - 32a b c  + 4b c )e x  + (512a c  - 256a b c  + 32b c )d e x
+--R       + 
+--R                2 4         2 3       4 2  2       2   3        3 2     5   7 6
+--R         ((1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c  + 8b c)e x
+--R       + 
+--R                   2 4          2 3       4 2  3
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                  2   3         3 2      5
+--R             (768a b c  - 384a b c  + 48b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  4
+--R             (4480a c  - 2240a b c  + 280b c )d
+--R           + 
+--R                   2   3         3 2       5   2       3 3        4      6
+--R             (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   2 4          2 3       4 2  5
+--R             (3584a c  - 1792a b c  + 224b c )d
+--R           + 
+--R                   2   3          3 2       5   3        3 3        4       6
+--R             (2560a b c  - 1280a b c  + 160b c)d  + (512a c  - 96a b c + 16b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   2 4         2 3       4 2  6
+--R             (1792a c  - 896a b c  + 112b c )d
+--R           + 
+--R                   2   3         3 2       5   4        3 3         4       6  2
+--R             (1920a b c  - 960a b c  + 120b c)d  + (768a c  - 144a b c + 24b )d
+--R           + 
+--R                 3   2      2 3        5
+--R             128a b c  - 64a b c + 8a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                  2 4         2 3      4 2  7
+--R             (512a c  - 256a b c  + 32b c )d
+--R           + 
+--R                  2   3         3 2      5   5        3 3        4       6  3
+--R             (768a b c  - 384a b c  + 48b c)d  + (512a c  - 96a b c + 16b )d
+--R           + 
+--R                  3   2       2 3         5
+--R             (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                 2 4        2 3     4 2  8        2   3        3 2     5   6
+--R             (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R           + 
+--R                  3 3        4      6  4        3   2      2 3        5  2
+--R             (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                4 2      3 2      2 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 585
+t0:=1/(a+b*(d+e*x)^2+c*(d+e*x)^4)^3
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 12 12      3   11 11       3 2       2  10 10
+--R       c e  x   + 12c d e  x   + (66c d  + 3b c )e  x
+--R     + 
+--R            3 3        2   9 9        3 4         2 2       2     2   8 8
+--R       (220c d  + 30b c d)e x  + (495c d  + 135b c d  + 3a c  + 3b c)e x
+--R     + 
+--R            3 5         2 3         2      2     7 7
+--R       (792c d  + 360b c d  + (24a c  + 24b c)d)e x
+--R     + 
+--R            3 6         2 4         2      2   2             3  6 6
+--R       (924c d  + 630b c d  + (84a c  + 84b c)d  + 6a b c + b )e x
+--R     + 
+--R            3 7         2 5          2       2   3                3    5 5
+--R       (792c d  + 756b c d  + (168a c  + 168b c)d  + (36a b c + 6b )d)e x
+--R     + 
+--R               3 8         2 6          2       2   4                 3  2
+--R           495c d  + 630b c d  + (210a c  + 210b c)d  + (90a b c + 15b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          4 4
+--R         e x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           220c d  + 360b c d  + (168a c  + 168b c)d  + (120a b c + 20b )d
+--R         + 
+--R               2         2
+--R           (12a c + 12a b )d
+--R      *
+--R          3 3
+--R         e x
+--R     + 
+--R              3 10         2 8         2      2   6                 3  4
+--R           66c d   + 135b c d  + (84a c  + 84b c)d  + (90a b c + 15b )d
+--R         + 
+--R               2         2  2     2
+--R           (18a c + 18a b )d  + 3a b
+--R      *
+--R          2 2
+--R         e x
+--R     + 
+--R              3 11        2 9         2      2   7                3  5
+--R           12c d   + 30b c d  + (24a c  + 24b c)d  + (36a b c + 6b )d
+--R         + 
+--R               2         2  3     2
+--R           (12a c + 12a b )d  + 6a b d
+--R      *
+--R         e x
+--R     + 
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d  + (3a c + 3a b )d
+--R     + 
+--R         2   2    3
+--R       3a b d  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 571
+
+--S 572 of 585
+r0:=1/4*(d+e*x)*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/8*(d+e*x)*((b^2-7*a*c)*(3*b^2-4*a*c)+3*b*c*(b^2-8*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (b^3-8*a*b*c+(b^4-10*a*b^2*c+56*a^2*c^2)/sqrt(b^2-4*a*c))/(a^2*(b^2-_
+   4*a*c)^2*e*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+3/8*atan((d+e*x)*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b^3-8*a*b*c+(-b^4+10*a*b^2*c-_
+   56*a^2*c^2)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^2*e*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                         3     3 2  8 8              3      3 2    7 7
+--R               (- 24a b c  + 3b c )e x  + (- 192a b c  + 24b c )d e x
+--R             + 
+--R                           3      3 2  2        2 2     4   6 6
+--R               ((- 672a b c  + 84b c )d  - 48a b c  + 6b c)e x
+--R             + 
+--R                            3       3 2  3            2 2      4     5 5
+--R               ((- 1344a b c  + 168b c )d  + (- 288a b c  + 36b c)d)e x
+--R             + 
+--R                               3       3 2  4            2 2      4   2
+--R                   (- 1680a b c  + 210b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                        2   2        3      5
+--R                   - 48a b c  - 18a b c + 3b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                               3       3 2  5            2 2       4   3
+--R                   (- 1344a b c  + 168b c )d  + (- 960a b c  + 120b c)d
+--R                 + 
+--R                          2   2        3       5
+--R                   (- 192a b c  - 72a b c + 12b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                              3      3 2  6            2 2      4   4
+--R                   (- 672a b c  + 84b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                          2   2         3       5  2      2 2        4
+--R                   (- 288a b c  - 108a b c + 18b )d  - 48a b c + 6a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                              3      3 2  7            2 2      4   5
+--R                   (- 192a b c  + 24b c )d  + (- 288a b c  + 36b c)d
+--R                 + 
+--R                          2   2        3       5  3         2 2         4
+--R                   (- 192a b c  - 72a b c + 12b )d  + (- 96a b c + 12a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )d  + (- 48a b c  + 6b c)d
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )d  + (- 48a b c + 6a b )d  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2 4        2 3     4 2  8 8
+--R           (168a c  - 30a b c  + 3b c )e x
+--R         + 
+--R                 2 4         2 3      4 2    7 7
+--R           (1344a c  - 240a b c  + 24b c )d e x
+--R         + 
+--R                  2 4         2 3      4 2  2       2   3        3 2     5   6 6
+--R           ((4704a c  - 840a b c  + 84b c )d  + 336a b c  - 60a b c  + 6b c)e x
+--R         + 
+--R                     2 4          2 3       4 2  3
+--R               (9408a c  - 1680a b c  + 168b c )d
+--R             + 
+--R                     2   3         3 2      5
+--R               (2016a b c  - 360a b c  + 36b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      2 4          2 3       4 2  4
+--R               (11760a c  - 2100a b c  + 210b c )d
+--R             + 
+--R                     2   3         3 2      5   2       3 3       2 2 2
+--R               (5040a b c  - 900a b c  + 90b c)d  + 336a c  + 108a b c
+--R             + 
+--R                      4      6
+--R               - 24a b c + 3b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2 4          2 3       4 2  5
+--R               (9408a c  - 1680a b c  + 168b c )d
+--R             + 
+--R                     2   3          3 2       5   3
+--R               (6720a b c  - 1200a b c  + 120b c)d
+--R             + 
+--R                     3 3       2 2 2        4       6
+--R               (1344a c  + 432a b c  - 96a b c + 12b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2 4         2 3      4 2  6
+--R               (4704a c  - 840a b c  + 84b c )d
+--R             + 
+--R                     2   3         3 2      5   4
+--R               (5040a b c  - 900a b c  + 90b c)d
+--R             + 
+--R                     3 3       2 2 2         4       6  2       3   2      2 3
+--R               (2016a c  + 648a b c  - 144a b c + 18b )d  + 336a b c  - 60a b c
+--R             + 
+--R                   5
+--R               6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2 4         2 3      4 2  7
+--R               (1344a c  - 240a b c  + 24b c )d
+--R             + 
+--R                     2   3         3 2      5   5
+--R               (2016a b c  - 360a b c  + 36b c)d
+--R             + 
+--R                     3 3       2 2 2        4       6  3
+--R               (1344a c  + 432a b c  - 96a b c + 12b )d
+--R             + 
+--R                    3   2       2 3         5
+--R               (672a b c  - 120a b c + 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                2 4        2 3     4 2  8        2   3        3 2     5   6
+--R           (168a c  - 30a b c  + 3b c )d  + (336a b c  - 60a b c  + 6b c)d
+--R         + 
+--R                3 3       2 2 2        4      6  4
+--R           (336a c  + 108a b c  - 24a b c + 3b )d
+--R         + 
+--R                3   2      2 3        5  2       4 2      3 2      2 4
+--R           (336a b c  - 60a b c + 6a b )d  + 168a c  - 30a b c + 3a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                         3     3 2  8 8              3      3 2    7 7
+--R               (- 24a b c  + 3b c )e x  + (- 192a b c  + 24b c )d e x
+--R             + 
+--R                           3      3 2  2        2 2     4   6 6
+--R               ((- 672a b c  + 84b c )d  - 48a b c  + 6b c)e x
+--R             + 
+--R                            3       3 2  3            2 2      4     5 5
+--R               ((- 1344a b c  + 168b c )d  + (- 288a b c  + 36b c)d)e x
+--R             + 
+--R                               3       3 2  4            2 2      4   2
+--R                   (- 1680a b c  + 210b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                        2   2        3      5
+--R                   - 48a b c  - 18a b c + 3b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                               3       3 2  5            2 2       4   3
+--R                   (- 1344a b c  + 168b c )d  + (- 960a b c  + 120b c)d
+--R                 + 
+--R                          2   2        3       5
+--R                   (- 192a b c  - 72a b c + 12b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                              3      3 2  6            2 2      4   4
+--R                   (- 672a b c  + 84b c )d  + (- 720a b c  + 90b c)d
+--R                 + 
+--R                          2   2         3       5  2      2 2        4
+--R                   (- 288a b c  - 108a b c + 18b )d  - 48a b c + 6a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                              3      3 2  7            2 2      4   5
+--R                   (- 192a b c  + 24b c )d  + (- 288a b c  + 36b c)d
+--R                 + 
+--R                          2   2        3       5  3         2 2         4
+--R                   (- 192a b c  - 72a b c + 12b )d  + (- 96a b c + 12a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                         3     3 2  8           2 2     4   6
+--R               (- 24a b c  + 3b c )d  + (- 48a b c  + 6b c)d
+--R             + 
+--R                     2   2        3      5  4         2 2        4  2      3
+--R               (- 48a b c  - 18a b c + 3b )d  + (- 48a b c + 6a b )d  - 24a b c
+--R             + 
+--R                 2 3
+--R               3a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4        2 3     4 2  8 8
+--R           (- 168a c  + 30a b c  - 3b c )e x
+--R         + 
+--R                   2 4         2 3      4 2    7 7
+--R           (- 1344a c  + 240a b c  - 24b c )d e x
+--R         + 
+--R                      2 4         2 3      4 2  2       2   3        3 2     5
+--R             ((- 4704a c  + 840a b c  - 84b c )d  - 336a b c  + 60a b c  - 6b c)
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  3
+--R               (- 9408a c  + 1680a b c  - 168b c )d
+--R             + 
+--R                       2   3         3 2      5
+--R               (- 2016a b c  + 360a b c  - 36b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  4
+--R               (- 11760a c  + 2100a b c  - 210b c )d
+--R             + 
+--R                       2   3         3 2      5   2       3 3       2 2 2
+--R               (- 5040a b c  + 900a b c  - 90b c)d  - 336a c  - 108a b c
+--R             + 
+--R                    4      6
+--R               24a b c - 3b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  5
+--R               (- 9408a c  + 1680a b c  - 168b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 6720a b c  + 1200a b c  - 120b c)d
+--R             + 
+--R                       3 3       2 2 2        4       6
+--R               (- 1344a c  - 432a b c  + 96a b c - 12b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 4         2 3      4 2  6
+--R               (- 4704a c  + 840a b c  - 84b c )d
+--R             + 
+--R                       2   3         3 2      5   4
+--R               (- 5040a b c  + 900a b c  - 90b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  2       3   2
+--R               (- 2016a c  - 648a b c  + 144a b c - 18b )d  - 336a b c
+--R             + 
+--R                  2 3        5
+--R               60a b c - 6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2 4         2 3      4 2  7
+--R               (- 1344a c  + 240a b c  - 24b c )d
+--R             + 
+--R                       2   3         3 2      5   5
+--R               (- 2016a b c  + 360a b c  - 36b c)d
+--R             + 
+--R                       3 3       2 2 2        4       6  3
+--R               (- 1344a c  - 432a b c  + 96a b c - 12b )d
+--R             + 
+--R                      3   2       2 3         5
+--R               (- 672a b c  + 120a b c - 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                  2 4        2 3     4 2  8          2   3        3 2     5   6
+--R           (- 168a c  + 30a b c  - 3b c )d  + (- 336a b c  + 60a b c  - 6b c)d
+--R         + 
+--R                  3 3       2 2 2        4      6  4
+--R           (- 336a c  - 108a b c  + 24a b c - 3b )d
+--R         + 
+--R                  3   2      2 3        5  2       4 2      3 2      2 4
+--R           (- 336a b c  + 60a b c - 6a b )d  - 168a c  + 30a b c - 3a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                     3     3 2  7 7              3      3 2    6 6
+--R           (- 24a b c  + 3b c )e x  + (- 168a b c  + 21b c )d e x
+--R         + 
+--R                       3      3 2  2      2 3        2 2     4   5 5
+--R           ((- 504a b c  + 63b c )d  + 28a c  - 49a b c  + 6b c)e x
+--R         + 
+--R                       3       3 2  3        2 3         2 2      4     4 4
+--R           ((- 840a b c  + 105b c )d  + (140a c  - 245a b c  + 30b c)d)e x
+--R         + 
+--R                          3       3 2  4        2 3         2 2      4   2
+--R               (- 840a b c  + 105b c )d  + (280a c  - 490a b c  + 60b c)d
+--R             + 
+--R                   2   2        3      5
+--R               - 4a b c  - 20a b c + 3b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                          3      3 2  5        2 3         2 2      4   3
+--R               (- 504a b c  + 63b c )d  + (280a c  - 490a b c  + 60b c)d
+--R             + 
+--R                     2   2        3      5
+--R               (- 12a b c  - 60a b c + 9b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                          3      3 2  6        2 3         2 2      4   4
+--R               (- 168a b c  + 21b c )d  + (140a c  - 245a b c  + 30b c)d
+--R             + 
+--R                     2   2        3      5  2      3 2      2 2        4
+--R               (- 12a b c  - 60a b c + 9b )d  + 44a c  - 37a b c + 5a b
+--R          *
+--R             e x
+--R         + 
+--R                     3     3 2  7       2 3        2 2     4   5
+--R           (- 24a b c  + 3b c )d  + (28a c  - 49a b c  + 6b c)d
+--R         + 
+--R                2   2        3      5  3       3 2      2 2        4
+--R           (- 4a b c  - 20a b c + 3b )d  + (44a c  - 37a b c + 5a b )d
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              4 4      3 2 3     2 4 2  9 8
+--R         (128a c  - 64a b c  + 8a b c )e x
+--R       + 
+--R               4 4       3 2 3      2 4 2    8 7
+--R         (1024a c  - 512a b c  + 64a b c )d e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  2       4   3       3 3 2
+--R             (3584a c  - 1792a b c  + 224a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                2 5
+--R             16a b c
+--R        *
+--R            7 6
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  3
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   4   3       3 3 2      2 5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R        *
+--R            6 5
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  4
+--R             (8960a c  - 4480a b c  + 560a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   2       5 3      3 4      2 6
+--R             (3840a b c  - 1920a b c  + 240a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            5 4
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  5
+--R             (7168a c  - 3584a b c  + 448a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   3
+--R             (5120a b c  - 2560a b c  + 320a b c)d
+--R           + 
+--R                   5 3       3 4       2 6
+--R             (1024a c  - 192a b c + 32a b )d
+--R        *
+--R            4 3
+--R           e x
+--R       + 
+--R                   4 4        3 2 3       2 4 2  6
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   4   3        3 3 2       2 5   4
+--R             (3840a b c  - 1920a b c  + 240a b c)d
+--R           + 
+--R                   5 3       3 4       2 6  2       5   2       4 3       3 5
+--R             (1536a c  - 288a b c + 48a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            3 2
+--R           e x
+--R       + 
+--R                   4 4       3 2 3      2 4 2  7
+--R             (1024a c  - 512a b c  + 64a b c )d
+--R           + 
+--R                   4   3       3 3 2      2 5   5
+--R             (1536a b c  - 768a b c  + 96a b c)d
+--R           + 
+--R                 5 3       3 4       2 6  3        5   2       4 3       3 5
+--R           (1024a c  - 192a b c + 32a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            2
+--R           e x
+--R       + 
+--R                  4 4      3 2 3     2 4 2  8
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  4   3       3 3 2      2 5   6        5 3      3 4      2 6  4
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  5   2       4 3       3 5  2       6 2      5 2      4 4
+--R             (256a b c  - 128a b c + 16a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R           e
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+)clear all
+
+--S 574 of 585
+t0:=1/((d*f+e*f*x)*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 13   13      3   12   12       3 2       2  11   11
+--R       c e  f x   + 13c d e  f x   + (78c d  + 3b c )e  f x
+--R     + 
+--R            3 3        2   10   10        3 4         2 2       2     2   9   9
+--R       (286c d  + 33b c d)e  f x   + (715c d  + 165b c d  + 3a c  + 3b c)e f x
+--R     + 
+--R             3 5         2 3         2      2     8   8
+--R       (1287c d  + 495b c d  + (27a c  + 27b c)d)e f x
+--R     + 
+--R             3 6         2 4          2       2   2             3  7   7
+--R       (1716c d  + 990b c d  + (108a c  + 108b c)d  + 6a b c + b )e f x
+--R     + 
+--R             3 7          2 5          2       2   3                3    6   6
+--R       (1716c d  + 1386b c d  + (252a c  + 252b c)d  + (42a b c + 7b )d)e f x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           1287c d  + 1386b c d  + (378a c  + 378b c)d  + (126a b c + 21b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          5   5
+--R         e f x
+--R     + 
+--R               3 9         2 7          2       2   5                  3  3
+--R           715c d  + 990b c d  + (378a c  + 378b c)d  + (210a b c + 35b )d
+--R         + 
+--R               2         2
+--R           (15a c + 15a b )d
+--R      *
+--R          4   4
+--R         e f x
+--R     + 
+--R               3 10         2 8          2       2   6                  3  4
+--R           286c d   + 495b c d  + (252a c  + 252b c)d  + (210a b c + 35b )d
+--R         + 
+--R               2         2  2     2
+--R           (30a c + 30a b )d  + 3a b
+--R      *
+--R          3   3
+--R         e f x
+--R     + 
+--R              3 11         2 9          2       2   7                  3  5
+--R           78c d   + 165b c d  + (108a c  + 108b c)d  + (126a b c + 21b )d
+--R         + 
+--R               2         2  3     2
+--R           (30a c + 30a b )d  + 9a b d
+--R      *
+--R          2   2
+--R         e f x
+--R     + 
+--R              3 12        2 10         2      2   8                3  6
+--R           13c d   + 33b c d   + (27a c  + 27b c)d  + (42a b c + 7b )d
+--R         + 
+--R               2         2  4     2   2    3
+--R           (15a c + 15a b )d  + 9a b d  + a
+--R      *
+--R         e f x
+--R     + 
+--R            3 13       2 11        2     2   9              3  7
+--R           c d   + 3b c d   + (3a c  + 3b c)d  + (6a b c + b )d
+--R         + 
+--R              2        2  5     2   3    3
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R         f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 574
+
+--S 575 of 585
+r0:=1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4)^2)+1/4*(2*b^4-15*a*b^2*c+16*a^2*c^2+2*b*c*(b^2-7*a*c)*_
+   (d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*f*(a+b*(d+e*x)^2+c*(d+e*x)^4))+_
+   1/2*b*(b^4-10*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-_
+   4*a*c))/(a^3*(b^2-4*a*c)^(5/2)*e*f)+log(d+e*x)/(a^3*e*f)-1/4*log(a+_
+   b*(d+e*x)^2+c*(d+e*x)^4)/(a^3*e*f)
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  8 8
+--R           (60a b c  - 20a b c  + 2b c )e x
+--R         + 
+--R                2   4         3 3      5 2    7 7
+--R           (480a b c  - 160a b c  + 16b c )d e x
+--R         + 
+--R                    2   4         3 3      5 2  2       2 2 3        4 2     6
+--R             ((1680a b c  - 560a b c  + 56b c )d  + 120a b c  - 40a b c  + 4b c)
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  3
+--R               (3360a b c  - 1120a b c  + 112b c )d
+--R             + 
+--R                    2 2 3         4 2      6
+--R               (720a b c  - 240a b c  + 24b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  4
+--R               (4200a b c  - 1400a b c  + 140b c )d
+--R             + 
+--R                     2 2 3         4 2      6   2       3   3      2 3 2
+--R               (1800a b c  - 600a b c  + 60b c)d  + 120a b c  + 20a b c
+--R             + 
+--R                      5      7
+--R               - 16a b c + 2b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  5
+--R               (3360a b c  - 1120a b c  + 112b c )d
+--R             + 
+--R                     2 2 3         4 2      6   3
+--R               (2400a b c  - 800a b c  + 80b c)d
+--R             + 
+--R                    3   3      2 3 2        5      7
+--R               (480a b c  + 80a b c  - 64a b c + 8b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     2   4         3 3      5 2  6
+--R               (1680a b c  - 560a b c  + 56b c )d
+--R             + 
+--R                     2 2 3         4 2      6   4
+--R               (1800a b c  - 600a b c  + 60b c)d
+--R             + 
+--R                    3   3       2 3 2        5       7  2       3 2 2      2 4
+--R               (720a b c  + 120a b c  - 96a b c + 12b )d  + 120a b c  - 40a b c
+--R             + 
+--R                   6
+--R               4a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                    2   4         3 3      5 2  7
+--R               (480a b c  - 160a b c  + 16b c )d
+--R             + 
+--R                    2 2 3         4 2      6   5
+--R               (720a b c  - 240a b c  + 24b c)d
+--R             + 
+--R                    3   3      2 3 2        5      7  3
+--R               (480a b c  + 80a b c  - 64a b c + 8b )d
+--R             + 
+--R                    3 2 2      2 4        6
+--R               (240a b c  - 80a b c + 8a b )d
+--R          *
+--R             e x
+--R         + 
+--R               2   4        3 3     5 2  8        2 2 3        4 2     6   6
+--R           (60a b c  - 20a b c  + 2b c )d  + (120a b c  - 40a b c  + 4b c)d
+--R         + 
+--R                3   3      2 3 2        5      7  4
+--R           (120a b c  + 20a b c  - 16a b c + 2b )d
+--R         + 
+--R                3 2 2      2 4        6  2      4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )d  + 60a b c  - 20a b c + 2a b
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                     2 4       2 3    4 2  8 8
+--R               (- 16a c  + 8a b c  - b c )e x
+--R             + 
+--R                      2 4        2 3     4 2    7 7
+--R               (- 128a c  + 64a b c  - 8b c )d e x
+--R             + 
+--R                            2 4         2 3      4 2  2      2   3        3 2
+--R                     (- 448a c  + 224a b c  - 28b c )d  - 32a b c  + 16a b c
+--R                   + 
+--R                         5
+--R                     - 2b c
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  3
+--R                   (- 896a c  + 448a b c  - 56b c )d
+--R                 + 
+--R                          2   3        3 2      5
+--R                   (- 192a b c  + 96a b c  - 12b c)d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2 4         2 3      4 2  4
+--R                   (- 1120a c  + 560a b c  - 70b c )d
+--R                 + 
+--R                          2   3         3 2      5   2      3 3       4     6
+--R                   (- 480a b c  + 240a b c  - 30b c)d  - 32a c  + 6a b c - b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  5
+--R                   (- 896a c  + 448a b c  - 56b c )d
+--R                 + 
+--R                          2   3         3 2      5   3
+--R                   (- 640a b c  + 320a b c  - 40b c)d
+--R                 + 
+--R                          3 3        4      6
+--R                   (- 128a c  + 24a b c - 4b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2 4         2 3      4 2  6
+--R                   (- 448a c  + 224a b c  - 28b c )d
+--R                 + 
+--R                          2   3         3 2      5   4
+--R                   (- 480a b c  + 240a b c  - 30b c)d
+--R                 + 
+--R                          3 3        4      6  2      3   2      2 3        5
+--R                   (- 192a c  + 36a b c - 6b )d  - 32a b c  + 16a b c - 2a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2 4        2 3     4 2  7
+--R                   (- 128a c  + 64a b c  - 8b c )d
+--R                 + 
+--R                          2   3        3 2      5   5
+--R                   (- 192a b c  + 96a b c  - 12b c)d
+--R                 + 
+--R                        3 3        4      6  3         3   2      2 3        5
+--R                 (- 128a c  + 24a b c - 4b )d  + (- 64a b c  + 32a b c - 4a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2 4       2 3    4 2  8         2   3        3 2     5   6
+--R               (- 16a c  + 8a b c  - b c )d  + (- 32a b c  + 16a b c  - 2b c)d
+--R             + 
+--R                     3 3       4     6  4         3   2      2 3        5  2
+--R               (- 32a c  + 6a b c - b )d  + (- 32a b c  + 16a b c - 2a b )d
+--R             + 
+--R                    4 2     3 2     2 4
+--R               - 16a c  + 8a b c - a b
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                   2 4        2 3     4 2  8 8
+--R               (64a c  - 32a b c  + 4b c )e x
+--R             + 
+--R                    2 4         2 3      4 2    7 7
+--R               (512a c  - 256a b c  + 32b c )d e x
+--R             + 
+--R                         2 4         2 3       4 2  2       2   3        3 2
+--R                   (1792a c  - 896a b c  + 112b c )d  + 128a b c  - 64a b c
+--R                 + 
+--R                     5
+--R                   8b c
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  3
+--R                   (3584a c  - 1792a b c  + 224b c )d
+--R                 + 
+--R                        2   3         3 2      5
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  4
+--R                   (4480a c  - 2240a b c  + 280b c )d
+--R                 + 
+--R                       2   3         3 2       5   2       3 3        4      6
+--R                 (1920a b c  - 960a b c  + 120b c)d  + 128a c  - 24a b c + 4b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                         2 4          2 3       4 2  5
+--R                   (3584a c  - 1792a b c  + 224b c )d
+--R                 + 
+--R                         2   3          3 2       5   3
+--R                   (2560a b c  - 1280a b c  + 160b c)d
+--R                 + 
+--R                        3 3        4       6
+--R                   (512a c  - 96a b c + 16b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                         2 4         2 3       4 2  6
+--R                   (1792a c  - 896a b c  + 112b c )d
+--R                 + 
+--R                         2   3         3 2       5   4
+--R                   (1920a b c  - 960a b c  + 120b c)d
+--R                 + 
+--R                        3 3         4       6  2       3   2      2 3        5
+--R                   (768a c  - 144a b c + 24b )d  + 128a b c  - 64a b c + 8a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                        2 4         2 3      4 2  7
+--R                   (512a c  - 256a b c  + 32b c )d
+--R                 + 
+--R                        2   3         3 2      5   5
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R                 + 
+--R                      3 3        4       6  3        3   2       2 3         5
+--R                 (512a c  - 96a b c + 16b )d  + (256a b c  - 128a b c + 16a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                   2 4        2 3     4 2  8        2   3        3 2     5   6
+--R               (64a c  - 32a b c  + 4b c )d  + (128a b c  - 64a b c  + 8b c)d
+--R             + 
+--R                    3 3        4      6  4        3   2      2 3        5  2
+--R               (128a c  - 24a b c + 4b )d  + (128a b c  - 64a b c + 8a b )d
+--R             + 
+--R                  4 2      3 2      2 4
+--R               64a c  - 32a b c + 4a b
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                 2   3       3 2  6 6         2   3        3 2    5 5
+--R           (- 14a b c  + 2a b c )e x  + (- 84a b c  + 12a b c )d e x
+--R         + 
+--R                   2   3        3 2  2      3 3      2 2 2       4   4 4
+--R           ((- 210a b c  + 30a b c )d  + 16a c  - 29a b c  + 4a b c)e x
+--R         + 
+--R                   2   3        3 2  3       3 3       2 2 2        4     3 3
+--R           ((- 280a b c  + 40a b c )d  + (64a c  - 116a b c  + 16a b c)d)e x
+--R         + 
+--R                      2   3        3 2  4       3 3       2 2 2        4   2
+--R               (- 210a b c  + 30a b c )d  + (96a c  - 174a b c  + 24a b c)d
+--R             + 
+--R                   3   2      2 3        5
+--R               - 2a b c  - 12a b c + 2a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2   3        3 2  5       3 3       2 2 2        4   3
+--R               (- 84a b c  + 12a b c )d  + (64a c  - 116a b c  + 16a b c)d
+--R             + 
+--R                    3   2      2 3        5
+--R               (- 4a b c  - 24a b c + 4a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2   3       3 2  6       3 3      2 2 2       4   4
+--R           (- 14a b c  + 2a b c )d  + (16a c  - 29a b c  + 4a b c)d
+--R         + 
+--R                3   2      2 3        5  2      4 2      3 2      2 4
+--R           (- 2a b c  - 12a b c + 2a b )d  + 24a c  - 21a b c + 3a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             5 4      4 2 3     3 4 2  9   8
+--R         (64a c  - 32a b c  + 4a b c )e f x
+--R       + 
+--R              5 4       4 2 3      3 4 2    8   7
+--R         (512a c  - 256a b c  + 32a b c )d e f x
+--R       + 
+--R                     5 4       4 2 3       3 4 2  2       5   3      4 3 2
+--R               (1792a c  - 896a b c  + 112a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 3 5
+--R               8a b c
+--R        *
+--R            7   6
+--R           e f x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  3
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R        *
+--R            6   5
+--R           e f x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  4
+--R             (4480a c  - 2240a b c  + 280a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   2       6 3      4 4      3 6
+--R             (1920a b c  - 960a b c  + 120a b c)d  + 128a c  - 24a b c + 4a b
+--R        *
+--R            5   4
+--R           e f x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  5
+--R             (3584a c  - 1792a b c  + 224a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   3
+--R             (2560a b c  - 1280a b c  + 160a b c)d
+--R           + 
+--R                  6 3      4 4       3 6
+--R             (512a c  - 96a b c + 16a b )d
+--R        *
+--R            4   3
+--R           e f x
+--R       + 
+--R                   5 4       4 2 3       3 4 2  6
+--R             (1792a c  - 896a b c  + 112a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   4
+--R             (1920a b c  - 960a b c  + 120a b c)d
+--R           + 
+--R                  6 3       4 4       3 6  2       6   2      5 3      4 5
+--R             (768a c  - 144a b c + 24a b )d  + 128a b c  - 64a b c + 8a b
+--R        *
+--R            3   2
+--R           e f x
+--R       + 
+--R                  5 4       4 2 3      3 4 2  7
+--R             (512a c  - 256a b c  + 32a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5   5
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R           + 
+--R                  6 3      4 4       3 6  3        6   2       5 3       4 5
+--R             (512a c  - 96a b c + 16a b )d  + (256a b c  - 128a b c + 16a b )d
+--R        *
+--R            2
+--R           e f x
+--R       + 
+--R                 5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R             (64a c  - 32a b c  + 4a b c )d  + (128a b c  - 64a b c  + 8a b c)d
+--R           + 
+--R                  6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R             (128a c  - 24a b c + 4a b )d  + (128a b c  - 64a b c + 8a b )d
+--R           + 
+--R                7 2      6 2      5 4
+--R             64a c  - 32a b c + 4a b
+--R        *
+--R           e f
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 585
+t0:=1/((d*f+e*f*x)^2*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 14 2 14      3   13 2 13       3 2       2  12 2 12
+--R       c e  f x   + 14c d e  f x   + (91c d  + 3b c )e  f x
+--R     + 
+--R            3 3        2   11 2 11
+--R       (364c d  + 36b c d)e  f x
+--R     + 
+--R             3 4         2 2       2     2   10 2 10
+--R       (1001c d  + 198b c d  + 3a c  + 3b c)e  f x
+--R     + 
+--R             3 5         2 3         2      2     9 2 9
+--R       (2002c d  + 660b c d  + (30a c  + 30b c)d)e f x
+--R     + 
+--R             3 6          2 4          2       2   2             3  8 2 8
+--R       (3003c d  + 1485b c d  + (135a c  + 135b c)d  + 6a b c + b )e f x
+--R     + 
+--R             3 7          2 5          2       2   3                3    7 2 7
+--R       (3432c d  + 2376b c d  + (360a c  + 360b c)d  + (48a b c + 8b )d)e f x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           3003c d  + 2772b c d  + (630a c  + 630b c)d  + (168a b c + 28b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          6 2 6
+--R         e f x
+--R     + 
+--R                3 9          2 7          2       2   5                  3  3
+--R           2002c d  + 2376b c d  + (756a c  + 756b c)d  + (336a b c + 56b )d
+--R         + 
+--R               2         2
+--R           (18a c + 18a b )d
+--R      *
+--R          5 2 5
+--R         e f x
+--R     + 
+--R                3 10          2 8          2       2   6                  3  4
+--R           1001c d   + 1485b c d  + (630a c  + 630b c)d  + (420a b c + 70b )d
+--R         + 
+--R               2         2  2     2
+--R           (45a c + 45a b )d  + 3a b
+--R      *
+--R          4 2 4
+--R         e f x
+--R     + 
+--R               3 11         2 9          2       2   7                  3  5
+--R           364c d   + 660b c d  + (360a c  + 360b c)d  + (336a b c + 56b )d
+--R         + 
+--R               2         2  3      2
+--R           (60a c + 60a b )d  + 12a b d
+--R      *
+--R          3 2 3
+--R         e f x
+--R     + 
+--R              3 12         2 10          2       2   8                  3  6
+--R           91c d   + 198b c d   + (135a c  + 135b c)d  + (168a b c + 28b )d
+--R         + 
+--R               2         2  4      2   2    3
+--R           (45a c + 45a b )d  + 18a b d  + a
+--R      *
+--R          2 2 2
+--R         e f x
+--R     + 
+--R              3 13        2 11         2      2   9                3  7
+--R           14c d   + 36b c d   + (30a c  + 30b c)d  + (48a b c + 8b )d
+--R         + 
+--R               2         2  5      2   3     3
+--R           (18a c + 18a b )d  + 12a b d  + 2a d
+--R      *
+--R            2
+--R         e f x
+--R     + 
+--R            3 14       2 12        2     2   10              3  8
+--R           c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R         + 
+--R              2        2  6     2   4    3 2
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R          2
+--R         f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 577
+
+--S 578 of 585
+r0:=-3/8*(5*b^2-12*a*c)*(b^2-5*a*c)/(a^3*(b^2-4*a*c)^2*e*f^2*(d+e*x))+_
+   1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f^2*(d+e*x)*(a+b*_
+   (d+e*x)^2+c*(d+e*x)^4)^2)+1/8*(5*b^4-35*a*b^2*c+36*a^2*c^2+b*c*(5*b^2-_
+   32*a*c)*(d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*f^2*(d+e*x)*(a+b*(d+e*x)^2+_
+   c*(d+e*x)^4))-3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*((5*b^2-12*a*c)*(b^2-5*a*c)+b*(5*b^4-47*a*b^2*c+124*a^2*c^2)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^2*e*f^2*sqrt(2)*sqrt(b-sqrt(b^2-_
+   4*a*c)))-3/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   sqrt(c)*((5*b^2-12*a*c)*(b^2-5*a*c)+(-5*b^5+47*a*b^3*c-124*a^2*b*c^2)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^2*e*f^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      2 4         2 3      4 2  9 9
+--R               (- 180a c  + 111a b c  - 15b c )e x
+--R             + 
+--R                       2 4         2 3       4 2    8 8
+--R               (- 1620a c  + 999a b c  - 135b c )d e x
+--R             + 
+--R                           2 4          2 3       4 2  2       2   3         3 2
+--R                   (- 6480a c  + 3996a b c  - 540b c )d  - 360a b c  + 222a b c
+--R                 + 
+--R                        5
+--R                   - 30b c
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  3
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                           2   3          3 2       5
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  4
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                           2   3          3 2       5   2       3 3      2 2 2
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d  - 360a c  + 42a b c
+--R                 + 
+--R                        4       6
+--R                   81a b c - 15b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  5
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                            2   3          3 2        5   3
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  6
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                            2   3          3 2        5   4
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  2       3   2
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d  - 360a b c
+--R                 + 
+--R                       2 3         5
+--R                   222a b c - 30a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2 4          2 3       4 2  7
+--R                   (- 6480a c  + 3996a b c  - 540b c )d
+--R                 + 
+--R                           2   3          3 2       5   5
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  3
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d
+--R                 + 
+--R                           3   2       2 3         5
+--R                   (- 1080a b c  + 666a b c - 90a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2 4         2 3       4 2  8
+--R                   (- 1620a c  + 999a b c  - 135b c )d
+--R                 + 
+--R                           2   3          3 2       5   6
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6  4
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R                 + 
+--R                           3   2       2 3         5  2       4 2       3 2
+--R                   (- 1080a b c  + 666a b c - 90a b )d  - 180a c  + 111a b c
+--R                 + 
+--R                        2 4
+--R                   - 15a b
+--R              *
+--R                 e x
+--R             + 
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )d
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)d
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )d
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )d
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2   4         3 3      5 2  9 9
+--R           (- 372a b c  + 141a b c  - 15b c )e x
+--R         + 
+--R                   2   4          3 3       5 2    8 8
+--R           (- 3348a b c  + 1269a b c  - 135b c )d e x
+--R         + 
+--R                        2   4          3 3       5 2  2       2 2 3         4 2
+--R               (- 13392a b c  + 5076a b c  - 540b c )d  - 744a b c  + 282a b c
+--R             + 
+--R                    6
+--R               - 30b c
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  3
+--R               (- 31248a b c  + 11844a b c  - 1260b c )d
+--R             + 
+--R                       2 2 3          4 2       6
+--R               (- 5208a b c  + 1974a b c  - 210b c)d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  4
+--R               (- 46872a b c  + 17766a b c  - 1890b c )d
+--R             + 
+--R                        2 2 3          4 2       6   2       3   3      2 3 2
+--R               (- 15624a b c  + 5922a b c  - 630b c)d  - 744a b c  - 90a b c
+--R             + 
+--R                     5       7
+--R               111a b c - 15b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  5
+--R               (- 46872a b c  + 17766a b c  - 1890b c )d
+--R             + 
+--R                        2 2 3          4 2        6   3
+--R               (- 26040a b c  + 9870a b c  - 1050b c)d
+--R             + 
+--R                       3   3       2 3 2         5       7
+--R               (- 3720a b c  - 450a b c  + 555a b c - 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                        2   4           3 3        5 2  6
+--R               (- 31248a b c  + 11844a b c  - 1260b c )d
+--R             + 
+--R                        2 2 3          4 2        6   4
+--R               (- 26040a b c  + 9870a b c  - 1050b c)d
+--R             + 
+--R                       3   3       2 3 2          5        7  2       3 2 2
+--R               (- 7440a b c  - 900a b c  + 1110a b c - 150b )d  - 744a b c
+--R             + 
+--R                   2 4         6
+--R               282a b c - 30a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                        2   4          3 3       5 2  7
+--R               (- 13392a b c  + 5076a b c  - 540b c )d
+--R             + 
+--R                        2 2 3          4 2       6   5
+--R               (- 15624a b c  + 5922a b c  - 630b c)d
+--R             + 
+--R                       3   3       2 3 2          5        7  3
+--R               (- 7440a b c  - 900a b c  + 1110a b c - 150b )d
+--R             + 
+--R                       3 2 2       2 4         6
+--R               (- 2232a b c  + 846a b c - 90a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2   4          3 3       5 2  8
+--R               (- 3348a b c  + 1269a b c  - 135b c )d
+--R             + 
+--R                       2 2 3          4 2       6   6
+--R               (- 5208a b c  + 1974a b c  - 210b c)d
+--R             + 
+--R                       3   3       2 3 2         5       7  4
+--R               (- 3720a b c  - 450a b c  + 555a b c - 75b )d
+--R             + 
+--R                       3 2 2       2 4         6  2       4   2       3 3
+--R               (- 2232a b c  + 846a b c - 90a b )d  - 372a b c  + 141a b c
+--R             + 
+--R                    2 5
+--R               - 15a b
+--R          *
+--R             e x
+--R         + 
+--R                  2   4         3 3      5 2  9
+--R           (- 372a b c  + 141a b c  - 15b c )d
+--R         + 
+--R                  2 2 3         4 2      6   7
+--R           (- 744a b c  + 282a b c  - 30b c)d
+--R         + 
+--R                  3   3      2 3 2         5       7  5
+--R           (- 744a b c  - 90a b c  + 111a b c - 15b )d
+--R         + 
+--R                  3 2 2       2 4         6  3
+--R           (- 744a b c  + 282a b c - 30a b )d
+--R         + 
+--R                  4   2       3 3       2 5
+--R           (- 372a b c  + 141a b c - 15a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                      2 4         2 3      4 2  9 9
+--R               (- 180a c  + 111a b c  - 15b c )e x
+--R             + 
+--R                       2 4         2 3       4 2    8 8
+--R               (- 1620a c  + 999a b c  - 135b c )d e x
+--R             + 
+--R                           2 4          2 3       4 2  2       2   3         3 2
+--R                   (- 6480a c  + 3996a b c  - 540b c )d  - 360a b c  + 222a b c
+--R                 + 
+--R                        5
+--R                   - 30b c
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  3
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                           2   3          3 2       5
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  4
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                           2   3          3 2       5   2       3 3      2 2 2
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d  - 360a c  + 42a b c
+--R                 + 
+--R                        4       6
+--R                   81a b c - 15b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2 4           2 3        4 2  5
+--R                   (- 22680a c  + 13986a b c  - 1890b c )d
+--R                 + 
+--R                            2   3          3 2        5   3
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2 4          2 3        4 2  6
+--R                   (- 15120a c  + 9324a b c  - 1260b c )d
+--R                 + 
+--R                            2   3          3 2        5   4
+--R                   (- 12600a b c  + 7770a b c  - 1050b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  2       3   2
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d  - 360a b c
+--R                 + 
+--R                       2 3         5
+--R                   222a b c - 30a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2 4          2 3       4 2  7
+--R                   (- 6480a c  + 3996a b c  - 540b c )d
+--R                 + 
+--R                           2   3          3 2       5   5
+--R                   (- 7560a b c  + 4662a b c  - 630b c)d
+--R                 + 
+--R                           3 3       2 2 2         4        6  3
+--R                   (- 3600a c  + 420a b c  + 810a b c - 150b )d
+--R                 + 
+--R                           3   2       2 3         5
+--R                   (- 1080a b c  + 666a b c - 90a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2 4         2 3       4 2  8
+--R                   (- 1620a c  + 999a b c  - 135b c )d
+--R                 + 
+--R                           2   3          3 2       5   6
+--R                   (- 2520a b c  + 1554a b c  - 210b c)d
+--R                 + 
+--R                           3 3       2 2 2         4       6  4
+--R                   (- 1800a c  + 210a b c  + 405a b c - 75b )d
+--R                 + 
+--R                           3   2       2 3         5  2       4 2       3 2
+--R                   (- 1080a b c  + 666a b c - 90a b )d  - 180a c  + 111a b c
+--R                 + 
+--R                        2 4
+--R                   - 15a b
+--R              *
+--R                 e x
+--R             + 
+--R                      2 4         2 3      4 2  9
+--R               (- 180a c  + 111a b c  - 15b c )d
+--R             + 
+--R                      2   3         3 2      5   7
+--R               (- 360a b c  + 222a b c  - 30b c)d
+--R             + 
+--R                      3 3      2 2 2        4       6  5
+--R               (- 360a c  + 42a b c  + 81a b c - 15b )d
+--R             + 
+--R                      3   2       2 3         5  3
+--R               (- 360a b c  + 222a b c - 30a b )d
+--R             + 
+--R                      4 2       3 2       2 4
+--R               (- 180a c  + 111a b c - 15a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                2   4         3 3      5 2  9 9
+--R           (372a b c  - 141a b c  + 15b c )e x
+--R         + 
+--R                 2   4          3 3       5 2    8 8
+--R           (3348a b c  - 1269a b c  + 135b c )d e x
+--R         + 
+--R                      2   4          3 3       5 2  2       2 2 3         4 2
+--R               (13392a b c  - 5076a b c  + 540b c )d  + 744a b c  - 282a b c
+--R             + 
+--R                  6
+--R               30b c
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  3
+--R               (31248a b c  - 11844a b c  + 1260b c )d
+--R             + 
+--R                     2 2 3          4 2       6
+--R               (5208a b c  - 1974a b c  + 210b c)d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  4
+--R               (46872a b c  - 17766a b c  + 1890b c )d
+--R             + 
+--R                      2 2 3          4 2       6   2       3   3      2 3 2
+--R               (15624a b c  - 5922a b c  + 630b c)d  + 744a b c  + 90a b c
+--R             + 
+--R                       5       7
+--R               - 111a b c + 15b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  5
+--R               (46872a b c  - 17766a b c  + 1890b c )d
+--R             + 
+--R                      2 2 3          4 2        6   3
+--R               (26040a b c  - 9870a b c  + 1050b c)d
+--R             + 
+--R                     3   3       2 3 2         5       7
+--R               (3720a b c  + 450a b c  - 555a b c + 75b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  6
+--R               (31248a b c  - 11844a b c  + 1260b c )d
+--R             + 
+--R                      2 2 3          4 2        6   4
+--R               (26040a b c  - 9870a b c  + 1050b c)d
+--R             + 
+--R                     3   3       2 3 2          5        7  2       3 2 2
+--R               (7440a b c  + 900a b c  - 1110a b c + 150b )d  + 744a b c
+--R             + 
+--R                     2 4         6
+--R               - 282a b c + 30a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      2   4          3 3       5 2  7
+--R               (13392a b c  - 5076a b c  + 540b c )d
+--R             + 
+--R                      2 2 3          4 2       6   5
+--R               (15624a b c  - 5922a b c  + 630b c)d
+--R             + 
+--R                     3   3       2 3 2          5        7  3
+--R               (7440a b c  + 900a b c  - 1110a b c + 150b )d
+--R             + 
+--R                     3 2 2       2 4         6
+--R               (2232a b c  - 846a b c + 90a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     2   4          3 3       5 2  8
+--R               (3348a b c  - 1269a b c  + 135b c )d
+--R             + 
+--R                     2 2 3          4 2       6   6
+--R               (5208a b c  - 1974a b c  + 210b c)d
+--R             + 
+--R                     3   3       2 3 2         5       7  4
+--R               (3720a b c  + 450a b c  - 555a b c + 75b )d
+--R             + 
+--R                   3 2 2       2 4         6  2       4   2       3 3       2 5
+--R             (2232a b c  - 846a b c + 90a b )d  + 372a b c  - 141a b c + 15a b
+--R          *
+--R             e x
+--R         + 
+--R                2   4         3 3      5 2  9
+--R           (372a b c  - 141a b c  + 15b c )d
+--R         + 
+--R                2 2 3         4 2      6   7
+--R           (744a b c  - 282a b c  + 30b c)d
+--R         + 
+--R                3   3      2 3 2         5       7  5
+--R           (744a b c  + 90a b c  - 111a b c + 15b )d
+--R         + 
+--R                3 2 2       2 4         6  3        4   2       3 3       2 5
+--R           (744a b c  - 282a b c + 30a b )d  + (372a b c  - 141a b c + 15a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                  2 4         2 3      4 2  8 8
+--R           (- 180a c  + 111a b c  - 15b c )e x
+--R         + 
+--R                   2 4         2 3       4 2    7 7
+--R           (- 1440a c  + 888a b c  - 120b c )d e x
+--R         + 
+--R                       2 4          2 3       4 2  2       2   3         3 2
+--R               (- 5040a c  + 3108a b c  - 420b c )d  - 392a b c  + 227a b c
+--R             + 
+--R                    5
+--R               - 30b c
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  3
+--R               (- 10080a c  + 6216a b c  - 840b c )d
+--R             + 
+--R                       2   3          3 2       5
+--R               (- 2352a b c  + 1362a b c  - 180b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                        2 4          2 3        4 2  4
+--R               (- 12600a c  + 7770a b c  - 1050b c )d
+--R             + 
+--R                       2   3          3 2       5   2       3 3      2 2 2
+--R               (- 5880a b c  + 3405a b c  - 450b c)d  - 324a c  - 25a b c
+--R             + 
+--R                    4       6
+--R               91a b c - 15b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                        2 4          2 3       4 2  5
+--R               (- 10080a c  + 6216a b c  - 840b c )d
+--R             + 
+--R                       2   3          3 2       5   3
+--R               (- 7840a b c  + 4540a b c  - 600b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6
+--R               (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       2 4          2 3       4 2  6
+--R               (- 5040a c  + 3108a b c  - 420b c )d
+--R             + 
+--R                       2   3          3 2       5   4
+--R               (- 5880a b c  + 3405a b c  - 450b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  2       3   2
+--R               (- 1944a c  - 150a b c  + 546a b c - 90b )d  - 364a b c
+--R             + 
+--R                   2 3         5
+--R               194a b c - 25a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                       2 4         2 3       4 2  7
+--R               (- 1440a c  + 888a b c  - 120b c )d
+--R             + 
+--R                       2   3          3 2       5   5
+--R               (- 2352a b c  + 1362a b c  - 180b c)d
+--R             + 
+--R                       3 3       2 2 2         4       6  3
+--R               (- 1296a c  - 100a b c  + 364a b c - 60b )d
+--R             + 
+--R                      3   2       2 3         5
+--R               (- 728a b c  + 388a b c - 50a b )d
+--R          *
+--R             e x
+--R         + 
+--R                  2 4         2 3      4 2  8
+--R           (- 180a c  + 111a b c  - 15b c )d
+--R         + 
+--R                  2   3         3 2      5   6
+--R           (- 392a b c  + 227a b c  - 30b c)d
+--R         + 
+--R                  3 3      2 2 2        4       6  4
+--R           (- 324a c  - 25a b c  + 91a b c - 15b )d
+--R         + 
+--R                  3   2       2 3         5  2       4 2      3 2      2 4
+--R           (- 364a b c  + 194a b c - 25a b )d  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              5 4      4 2 3     3 4 2  10 2 9
+--R         (128a c  - 64a b c  + 8a b c )e  f x
+--R       + 
+--R               5 4       4 2 3      3 4 2    9 2 8
+--R         (1152a c  - 576a b c  + 72a b c )d e f x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  2       5   3       4 3 2
+--R             (4608a c  - 2304a b c  + 288a b c )d  + 256a b c  - 128a b c
+--R           + 
+--R                3 5
+--R             16a b c
+--R        *
+--R            8 2 7
+--R           e f x
+--R       + 
+--R                    5 4        4 2 3       3 4 2  3
+--R             (10752a c  - 5376a b c  + 672a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5
+--R             (1792a b c  - 896a b c  + 112a b c)d
+--R        *
+--R            7 2 6
+--R           e f x
+--R       + 
+--R                    5 4        4 2 3        3 4 2  4
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   2       6 3      4 4      3 6
+--R             (5376a b c  - 2688a b c  + 336a b c)d  + 256a c  - 48a b c + 8a b
+--R        *
+--R            6 2 5
+--R           e f x
+--R       + 
+--R                    5 4        4 2 3        3 4 2  5
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   3
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   6 3       4 4       3 6
+--R             (1280a c  - 240a b c + 40a b )d
+--R        *
+--R            5 2 4
+--R           e f x
+--R       + 
+--R                    5 4        4 2 3       3 4 2  6
+--R             (10752a c  - 5376a b c  + 672a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   4
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   6 3       4 4       3 6  2       6   2       5 3       4 5
+--R             (2560a c  - 480a b c + 80a b )d  + 256a b c  - 128a b c + 16a b
+--R        *
+--R            4 2 3
+--R           e f x
+--R       + 
+--R                   5 4        4 2 3       3 4 2  7
+--R             (4608a c  - 2304a b c  + 288a b c )d
+--R           + 
+--R                   5   3        4 3 2       3 5   5
+--R             (5376a b c  - 2688a b c  + 336a b c)d
+--R           + 
+--R                 6 3       4 4       3 6  3        6   2       5 3       4 5
+--R           (2560a c  - 480a b c + 80a b )d  + (768a b c  - 384a b c + 48a b )d
+--R        *
+--R            3 2 2
+--R           e f x
+--R       + 
+--R                   5 4       4 2 3      3 4 2  8
+--R             (1152a c  - 576a b c  + 72a b c )d
+--R           + 
+--R                   5   3       4 3 2       3 5   6
+--R             (1792a b c  - 896a b c  + 112a b c)d
+--R           + 
+--R                   6 3       4 4       3 6  4
+--R             (1280a c  - 240a b c + 40a b )d
+--R           + 
+--R                  6   2       5 3       4 5  2       7 2      6 2      5 4
+--R             (768a b c  - 384a b c + 48a b )d  + 128a c  - 64a b c + 8a b
+--R        *
+--R            2 2
+--R           e f x
+--R       + 
+--R                  5 4      4 2 3     3 4 2  9
+--R             (128a c  - 64a b c  + 8a b c )d
+--R           + 
+--R                  5   3       4 3 2      3 5   7        6 3      4 4      3 6  5
+--R             (256a b c  - 128a b c  + 16a b c)d  + (256a c  - 48a b c + 8a b )d
+--R           + 
+--R                  6   2       5 3       4 5  3        7 2      6 2      5 4
+--R             (256a b c  - 128a b c + 16a b )d  + (128a c  - 64a b c + 8a b )d
+--R        *
+--R              2
+--R           e f
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 579
+
+)clear all
+
+--S 580 of 585
+t0:=1/((d*f+e*f*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 15 3 15      3   14 3 14        3 2       2  13 3 13
+--R       c e  f x   + 15c d e  f x   + (105c d  + 3b c )e  f x
+--R     + 
+--R            3 3        2   12 3 12
+--R       (455c d  + 39b c d)e  f x
+--R     + 
+--R             3 4         2 2       2     2   11 3 11
+--R       (1365c d  + 234b c d  + 3a c  + 3b c)e  f x
+--R     + 
+--R             3 5         2 3         2      2     10 3 10
+--R       (3003c d  + 858b c d  + (33a c  + 33b c)d)e  f x
+--R     + 
+--R             3 6          2 4          2       2   2             3  9 3 9
+--R       (5005c d  + 2145b c d  + (165a c  + 165b c)d  + 6a b c + b )e f x
+--R     + 
+--R             3 7          2 5          2       2   3                3    8 3 8
+--R       (6435c d  + 3861b c d  + (495a c  + 495b c)d  + (54a b c + 9b )d)e f x
+--R     + 
+--R                3 8          2 6          2       2   4                  3  2
+--R           6435c d  + 5148b c d  + (990a c  + 990b c)d  + (216a b c + 36b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          7 3 7
+--R         e f x
+--R     + 
+--R                3 9          2 7           2        2   5                  3  3
+--R           5005c d  + 5148b c d  + (1386a c  + 1386b c)d  + (504a b c + 84b )d
+--R         + 
+--R               2         2
+--R           (21a c + 21a b )d
+--R      *
+--R          6 3 6
+--R         e f x
+--R     + 
+--R                3 10          2 8           2        2   6
+--R           3003c d   + 3861b c d  + (1386a c  + 1386b c)d
+--R         + 
+--R                           3  4       2         2  2     2
+--R           (756a b c + 126b )d  + (63a c + 63a b )d  + 3a b
+--R      *
+--R          5 3 5
+--R         e f x
+--R     + 
+--R                3 11          2 9          2       2   7                   3  5
+--R           1365c d   + 2145b c d  + (990a c  + 990b c)d  + (756a b c + 126b )d
+--R         + 
+--R                2          2  3      2
+--R           (105a c + 105a b )d  + 15a b d
+--R      *
+--R          4 3 4
+--R         e f x
+--R     + 
+--R               3 12         2 10          2       2   8                  3  6
+--R           455c d   + 858b c d   + (495a c  + 495b c)d  + (504a b c + 84b )d
+--R         + 
+--R                2          2  4      2   2    3
+--R           (105a c + 105a b )d  + 30a b d  + a
+--R      *
+--R          3 3 3
+--R         e f x
+--R     + 
+--R               3 13         2 11          2       2   9                  3  7
+--R           105c d   + 234b c d   + (165a c  + 165b c)d  + (216a b c + 36b )d
+--R         + 
+--R               2         2  5      2   3     3
+--R           (63a c + 63a b )d  + 30a b d  + 3a d
+--R      *
+--R          2 3 2
+--R         e f x
+--R     + 
+--R              3 14        2 12         2      2   10                3  8
+--R           15c d   + 39b c d   + (33a c  + 33b c)d   + (54a b c + 9b )d
+--R         + 
+--R               2         2  6      2   4     3 2
+--R           (21a c + 21a b )d  + 15a b d  + 3a d
+--R      *
+--R            3
+--R         e f x
+--R     + 
+--R            3 15       2 13        2     2   11              3  9
+--R           c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R         + 
+--R              2        2  7     2   5    3 3
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R          3
+--R         f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 580
+
+--S 581 of 585
+r0:=-3/2*(b^4-7*a*b^2*c+10*a^2*c^2)/(a^3*(b^2-4*a*c)^2*e*f^3*(d+e*x)^2)+_
+   1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f^3*(d+e*x)^2*(a+b*_
+   (d+e*x)^2+c*(d+e*x)^4)^2)+1/4*(3*b^4-20*a*b^2*c+20*a^2*c^2+3*b*c*_
+   (b^2-6*a*c)*(d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*f^3*(d+e*x)^2*(a+b*_
+   (d+e*x)^2+c*(d+e*x)^4))-3/2*(b^6-10*a*b^4*c+30*a^2*b^2*c^2-20*a^3*c^3)*_
+   atanh((b+2*c*(d+e*x)^2)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(5/2)*e*f^3)-_
+   3*b*log(d+e*x)/(a^4*e*f^3)+3/4*b*log(a+b*(d+e*x)^2+c*(d+e*x)^4)/(a^4*e*f^3)
+--R 
+--R
+--R   (2)
+--R                3 5       2 2 4        4 3     6 2  10 10
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )e  x
+--R         + 
+--R                 3 5        2 2 4         4 3      6 2    9 9
+--R           (1200a c  - 1800a b c  + 600a b c  - 60b c )d e x
+--R         + 
+--R                     3 5        2 2 4          4 3       6 2  2       3   4
+--R               (5400a c  - 8100a b c  + 2700a b c  - 270b c )d  + 240a b c
+--R             + 
+--R                     2 3 3         5 2      7
+--R               - 360a b c  + 120a b c  - 12b c
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                      3 5         2 2 4          4 3       6 2  3
+--R               (14400a c  - 21600a b c  + 7200a b c  - 720b c )d
+--R             + 
+--R                     3   4        2 3 3         5 2      7
+--R               (1920a b c  - 2880a b c  + 960a b c  - 96b c)d
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  4
+--R               (25200a c  - 37800a b c  + 12600a b c  - 1260b c )d
+--R             + 
+--R                     3   4         2 3 3          5 2       7   2       4 4
+--R               (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d  + 240a c
+--R             + 
+--R                     3 2 3      2 4 2        6      8
+--R               - 240a b c  - 60a b c  + 48a b c - 6b
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  5
+--R               (30240a c  - 45360a b c  + 15120a b c  - 1512b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   3
+--R               (13440a b c  - 20160a b c  + 6720a b c  - 672b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8
+--R               (1440a c  - 1440a b c  - 360a b c  + 288a b c - 36b )d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  6
+--R               (25200a c  - 37800a b c  + 12600a b c  - 1260b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   4
+--R               (16800a b c  - 25200a b c  + 8400a b c  - 840b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  2
+--R               (3600a c  - 3600a b c  - 900a b c  + 720a b c - 90b )d
+--R             + 
+--R                   4   3       3 3 2       2 5         7
+--R               240a b c  - 360a b c  + 120a b c - 12a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                      3 5         2 2 4          4 3       6 2  7
+--R               (14400a c  - 21600a b c  + 7200a b c  - 720b c )d
+--R             + 
+--R                      3   4         2 3 3          5 2       7   5
+--R               (13440a b c  - 20160a b c  + 6720a b c  - 672b c)d
+--R             + 
+--R                     4 4        3 2 3        2 4 2         6        8  3
+--R               (4800a c  - 4800a b c  - 1200a b c  + 960a b c - 120b )d
+--R             + 
+--R                    4   3        3 3 2       2 5         7
+--R               (960a b c  - 1440a b c  + 480a b c - 48a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                     3 5        2 2 4          4 3       6 2  8
+--R               (5400a c  - 8100a b c  + 2700a b c  - 270b c )d
+--R             + 
+--R                     3   4         2 3 3          5 2       7   6
+--R               (6720a b c  - 10080a b c  + 3360a b c  - 336b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  4
+--R               (3600a c  - 3600a b c  - 900a b c  + 720a b c - 90b )d
+--R             + 
+--R                     4   3        3 3 2       2 5         7  2       5 3
+--R               (1440a b c  - 2160a b c  + 720a b c - 72a b )d  + 120a c
+--R             + 
+--R                     4 2 2      3 4      2 6
+--R               - 180a b c  + 60a b c - 6a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                     3 5        2 2 4         4 3      6 2  9
+--R               (1200a c  - 1800a b c  + 600a b c  - 60b c )d
+--R             + 
+--R                     3   4        2 3 3         5 2      7   7
+--R               (1920a b c  - 2880a b c  + 960a b c  - 96b c)d
+--R             + 
+--R                     4 4        3 2 3       2 4 2         6       8  5
+--R               (1440a c  - 1440a b c  - 360a b c  + 288a b c - 36b )d
+--R             + 
+--R                    4   3        3 3 2       2 5         7  3
+--R               (960a b c  - 1440a b c  + 480a b c - 48a b )d
+--R             + 
+--R                    5 3       4 2 2       3 4       2 6
+--R               (240a c  - 360a b c  + 120a b c - 12a b )d
+--R          *
+--R             e x
+--R         + 
+--R                3 5       2 2 4        4 3     6 2  10
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )d
+--R         + 
+--R                3   4       2 3 3         5 2      7   8
+--R           (240a b c  - 360a b c  + 120a b c  - 12b c)d
+--R         + 
+--R                4 4       3 2 3      2 4 2        6      8  6
+--R           (240a c  - 240a b c  - 60a b c  + 48a b c - 6b )d
+--R         + 
+--R                4   3       3 3 2       2 5         7  4
+--R           (240a b c  - 360a b c  + 120a b c - 12a b )d
+--R         + 
+--R                5 3       4 2 2      3 4      2 6  2
+--R           (120a c  - 180a b c  + 60a b c - 6a b )d
+--R      *
+--R                   2 2                  2
+--R               2c e x  + 4c d e x + 2c d  + b
+--R         atanh(------------------------------)
+--R                        +-----------+
+--R                        |          2
+--R                       \|- 4a c + b
+--R     + 
+--R                   2   4        3 3     5 2  10 10
+--R               (48a b c  - 24a b c  + 3b c )e  x
+--R             + 
+--R                    2   4         3 3      5 2    9 9
+--R               (480a b c  - 240a b c  + 30b c )d e x
+--R             + 
+--R                         2   4          3 3       5 2  2      2 2 3        4 2
+--R                   (2160a b c  - 1080a b c  + 135b c )d  + 96a b c  - 48a b c
+--R                 + 
+--R                     6
+--R                   6b c
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  3
+--R                   (5760a b c  - 2880a b c  + 360b c )d
+--R                 + 
+--R                        2 2 3         4 2      6
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  4
+--R                   (10080a b c  - 5040a b c  + 630b c )d
+--R                 + 
+--R                       2 2 3          4 2       6   2      3   3        5      7
+--R                 (2688a b c  - 1344a b c  + 168b c)d  + 96a b c  - 18a b c + 3b
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  5
+--R                   (12096a b c  - 6048a b c  + 756b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   3
+--R                   (5376a b c  - 2688a b c  + 336b c)d
+--R                 + 
+--R                        3   3         5       7
+--R                   (576a b c  - 108a b c + 18b )d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                          2   4          3 3       5 2  6
+--R                   (10080a b c  - 5040a b c  + 630b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   4
+--R                   (6720a b c  - 3360a b c  + 420b c)d
+--R                 + 
+--R                       3   3         5       7  2      3 2 2      2 4        6
+--R                 (1440a b c  - 270a b c + 45b )d  + 96a b c  - 48a b c + 6a b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  7
+--R                   (5760a b c  - 2880a b c  + 360b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   5
+--R                   (5376a b c  - 2688a b c  + 336b c)d
+--R                 + 
+--R                         3   3         5       7  3
+--R                   (1920a b c  - 360a b c + 60b )d
+--R                 + 
+--R                        3 2 2       2 4         6
+--R                   (384a b c  - 192a b c + 24a b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                         2   4          3 3       5 2  8
+--R                   (2160a b c  - 1080a b c  + 135b c )d
+--R                 + 
+--R                         2 2 3          4 2       6   6
+--R                   (2688a b c  - 1344a b c  + 168b c)d
+--R                 + 
+--R                         3   3         5       7  4
+--R                   (1440a b c  - 270a b c + 45b )d
+--R                 + 
+--R                      3 2 2       2 4         6  2      4   2      3 3      2 5
+--R                 (576a b c  - 288a b c + 36a b )d  + 48a b c  - 24a b c + 3a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                        2   4         3 3      5 2  9
+--R                   (480a b c  - 240a b c  + 30b c )d
+--R                 + 
+--R                        2 2 3         4 2      6   7
+--R                   (768a b c  - 384a b c  + 48b c)d
+--R                 + 
+--R                        3   3         5       7  5
+--R                   (576a b c  - 108a b c + 18b )d
+--R                 + 
+--R                        3 2 2       2 4         6  3
+--R                   (384a b c  - 192a b c + 24a b )d
+--R                 + 
+--R                       4   2      3 3      2 5
+--R                   (96a b c  - 48a b c + 6a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                   2   4        3 3     5 2  10       2 2 3        4 2     6   8
+--R               (48a b c  - 24a b c  + 3b c )d   + (96a b c  - 48a b c  + 6b c)d
+--R             + 
+--R                   3   3        5      7  6       3 2 2      2 4        6  4
+--R               (96a b c  - 18a b c + 3b )d  + (96a b c  - 48a b c + 6a b )d
+--R             + 
+--R                   4   2      3 3      2 5  2
+--R               (48a b c  - 24a b c + 3a b )d
+--R          *
+--R             log
+--R                     4 4         3 3        2      2 2        3
+--R                  c e x  + 4c d e x  + (6c d  + b)e x  + (4c d  + 2b d)e x
+--R                + 
+--R                     4      2
+--R                  c d  + b d  + a
+--R         + 
+--R                      2   4        3 3      5 2  10 10
+--R               (- 192a b c  + 96a b c  - 12b c )e  x
+--R             + 
+--R                       2   4         3 3       5 2    9 9
+--R               (- 1920a b c  + 960a b c  - 120b c )d e x
+--R             + 
+--R                           2   4          3 3       5 2  2       2 2 3
+--R                   (- 8640a b c  + 4320a b c  - 540b c )d  - 384a b c
+--R                 + 
+--R                         4 2      6
+--R                   192a b c  - 24b c
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  3
+--R                   (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                 + 
+--R                           2 2 3          4 2       6
+--R                   (- 3072a b c  + 1536a b c  - 192b c)d
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  4
+--R                   (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                 + 
+--R                            2 2 3          4 2       6   2       3   3        5
+--R                   (- 10752a b c  + 5376a b c  - 672b c)d  - 384a b c  + 72a b c
+--R                 + 
+--R                        7
+--R                   - 12b
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  5
+--R                   (- 48384a b c  + 24192a b c  - 3024b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   3
+--R                   (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                 + 
+--R                           3   3         5       7
+--R                   (- 2304a b c  + 432a b c - 72b )d
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  6
+--R                   (- 40320a b c  + 20160a b c  - 2520b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   4
+--R                   (- 26880a b c  + 13440a b c  - 1680b c)d
+--R                 + 
+--R                           3   3          5        7  2       3 2 2       2 4
+--R                   (- 5760a b c  + 1080a b c - 180b )d  - 384a b c  + 192a b c
+--R                 + 
+--R                          6
+--R                   - 24a b
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                            2   4           3 3        5 2  7
+--R                   (- 23040a b c  + 11520a b c  - 1440b c )d
+--R                 + 
+--R                            2 2 3           4 2        6   5
+--R                   (- 21504a b c  + 10752a b c  - 1344b c)d
+--R                 + 
+--R                           3   3          5        7  3
+--R                   (- 7680a b c  + 1440a b c - 240b )d
+--R                 + 
+--R                           3 2 2       2 4         6
+--R                   (- 1536a b c  + 768a b c - 96a b )d
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                           2   4          3 3       5 2  8
+--R                   (- 8640a b c  + 4320a b c  - 540b c )d
+--R                 + 
+--R                            2 2 3          4 2       6   6
+--R                   (- 10752a b c  + 5376a b c  - 672b c)d
+--R                 + 
+--R                           3   3          5        7  4
+--R                   (- 5760a b c  + 1080a b c - 180b )d
+--R                 + 
+--R                           3 2 2        2 4          6  2       4   2      3 3
+--R                   (- 2304a b c  + 1152a b c - 144a b )d  - 192a b c  + 96a b c
+--R                 + 
+--R                        2 5
+--R                   - 12a b
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                           2   4         3 3       5 2  9
+--R                   (- 1920a b c  + 960a b c  - 120b c )d
+--R                 + 
+--R                           2 2 3          4 2       6   7
+--R                   (- 3072a b c  + 1536a b c  - 192b c)d
+--R                 + 
+--R                           3   3         5       7  5
+--R                   (- 2304a b c  + 432a b c - 72b )d
+--R                 + 
+--R                           3 2 2       2 4         6  3
+--R                   (- 1536a b c  + 768a b c - 96a b )d
+--R                 + 
+--R                          4   2       3 3       2 5
+--R                   (- 384a b c  + 192a b c - 24a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                      2   4        3 3      5 2  10
+--R               (- 192a b c  + 96a b c  - 12b c )d
+--R             + 
+--R                      2 2 3         4 2      6   8
+--R               (- 384a b c  + 192a b c  - 24b c)d
+--R             + 
+--R                      3   3        5       7  6
+--R               (- 384a b c  + 72a b c - 12b )d
+--R             + 
+--R                      3 2 2       2 4         6  4
+--R               (- 384a b c  + 192a b c - 24a b )d
+--R             + 
+--R                      4   2      3 3       2 5  2
+--R               (- 192a b c  + 96a b c - 12a b )d
+--R          *
+--R             log(e x + d)
+--R         + 
+--R                 3 4      2 2 3       4 2  8 8
+--R           (- 60a c  + 42a b c  - 6a b c )e x
+--R         + 
+--R                  3 4       2 2 3        4 2    7 7
+--R           (- 480a c  + 336a b c  - 48a b c )d e x
+--R         + 
+--R                       3 4        2 2 3         4 2  2       3   3      2 3 2
+--R               (- 1680a c  + 1176a b c  - 168a b c )d  - 138a b c  + 87a b c
+--R             + 
+--R                      5
+--R               - 12a b c
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  3
+--R               (- 3360a c  + 2352a b c  - 336a b c )d
+--R             + 
+--R                      3   3       2 3 2        5
+--R               (- 828a b c  + 522a b c  - 72a b c)d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  4
+--R               (- 4200a c  + 2940a b c  - 420a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   2       4 3      3 2 2
+--R               (- 2070a b c  + 1305a b c  - 180a b c)d  - 100a c  - 14a b c
+--R             + 
+--R                  2 4        6
+--R               36a b c - 6a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  5
+--R               (- 3360a c  + 2352a b c  - 336a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   3
+--R               (- 2760a b c  + 1740a b c  - 240a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6
+--R               (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       3 4        2 2 3         4 2  6
+--R               (- 1680a c  + 1176a b c  - 168a b c )d
+--R             + 
+--R                       3   3        2 3 2         5   4
+--R               (- 2070a b c  + 1305a b c  - 180a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6  2       4   2
+--R               (- 600a c  - 84a b c  + 216a b c - 36a b )d  - 122a b c
+--R             + 
+--R                  3 3      2 5
+--R               68a b c - 9a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3 4       2 2 3        4 2  7
+--R               (- 480a c  + 336a b c  - 48a b c )d
+--R             + 
+--R                      3   3       2 3 2        5   5
+--R               (- 828a b c  + 522a b c  - 72a b c)d
+--R             + 
+--R                      4 3      3 2 2       2 4         6  3
+--R               (- 400a c  - 56a b c  + 144a b c - 24a b )d
+--R             + 
+--R                      4   2       3 3       2 5
+--R               (- 244a b c  + 136a b c - 18a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 3 4      2 2 3       4 2  8
+--R           (- 60a c  + 42a b c  - 6a b c )d
+--R         + 
+--R                  3   3      2 3 2        5   6
+--R           (- 138a b c  + 87a b c  - 12a b c)d
+--R         + 
+--R                  4 3      3 2 2      2 4        6  4
+--R           (- 100a c  - 14a b c  + 36a b c - 6a b )d
+--R         + 
+--R                  4   2      3 3      2 5  2      5 2      4 2      3 4
+--R           (- 122a b c  + 68a b c - 9a b )d  - 32a c  + 16a b c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             6 4      5 2 3     4 4 2  11 3 10
+--R         (64a c  - 32a b c  + 4a b c )e  f x
+--R       + 
+--R              6 4       5 2 3      4 4 2    10 3 9
+--R         (640a c  - 320a b c  + 40a b c )d e  f x
+--R       + 
+--R                     6 4        5 2 3       4 4 2  2       6   3      5 3 2
+--R               (2880a c  - 1440a b c  + 180a b c )d  + 128a b c  - 64a b c
+--R             + 
+--R                 4 5
+--R               8a b c
+--R        *
+--R            9 3 8
+--R           e f x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  3
+--R             (7680a c  - 3840a b c  + 480a b c )d
+--R           + 
+--R                   6   3       5 3 2      4 5
+--R             (1024a b c  - 512a b c  + 64a b c)d
+--R        *
+--R            8 3 7
+--R           e f x
+--R       + 
+--R                    6 4        5 2 3       4 4 2  4
+--R             (13440a c  - 6720a b c  + 840a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   2       7 3      5 4      4 6
+--R             (3584a b c  - 1792a b c  + 224a b c)d  + 128a c  - 24a b c + 4a b
+--R        *
+--R            7 3 6
+--R           e f x
+--R       + 
+--R                    6 4        5 2 3        4 4 2  5
+--R             (16128a c  - 8064a b c  + 1008a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   3
+--R             (7168a b c  - 3584a b c  + 448a b c)d
+--R           + 
+--R                  7 3       5 4       4 6
+--R             (768a c  - 144a b c + 24a b )d
+--R        *
+--R            6 3 5
+--R           e f x
+--R       + 
+--R                    6 4        5 2 3       4 4 2  6
+--R             (13440a c  - 6720a b c  + 840a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   4
+--R             (8960a b c  - 4480a b c  + 560a b c)d
+--R           + 
+--R                   7 3       5 4       4 6  2       7   2      6 3      5 5
+--R             (1920a c  - 360a b c + 60a b )d  + 128a b c  - 64a b c + 8a b
+--R        *
+--R            5 3 4
+--R           e f x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  7
+--R             (7680a c  - 3840a b c  + 480a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   5
+--R             (7168a b c  - 3584a b c  + 448a b c)d
+--R           + 
+--R                 7 3       5 4       4 6  3        7   2       6 3       5 5
+--R           (2560a c  - 480a b c + 80a b )d  + (512a b c  - 256a b c + 32a b )d
+--R        *
+--R            4 3 3
+--R           e f x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  8
+--R             (2880a c  - 1440a b c  + 180a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   6
+--R             (3584a b c  - 1792a b c  + 224a b c)d
+--R           + 
+--R                   7 3       5 4       4 6  4
+--R             (1920a c  - 360a b c + 60a b )d
+--R           + 
+--R                  7   2       6 3       5 5  2      8 2      7 2      6 4
+--R             (768a b c  - 384a b c + 48a b )d  + 64a c  - 32a b c + 4a b
+--R        *
+--R            3 3 2
+--R           e f x
+--R       + 
+--R                  6 4       5 2 3      4 4 2  9
+--R             (640a c  - 320a b c  + 40a b c )d
+--R           + 
+--R                   6   3       5 3 2      4 5   7
+--R             (1024a b c  - 512a b c  + 64a b c)d
+--R           + 
+--R                  7 3       5 4       4 6  5        7   2       6 3       5 5  3
+--R             (768a c  - 144a b c + 24a b )d  + (512a b c  - 256a b c + 32a b )d
+--R           + 
+--R                  8 2      7 2      6 4
+--R             (128a c  - 64a b c + 8a b )d
+--R        *
+--R            2 3
+--R           e f x
+--R       + 
+--R                 6 4      5 2 3     4 4 2  10
+--R             (64a c  - 32a b c  + 4a b c )d
+--R           + 
+--R                  6   3      5 3 2     4 5   8        7 3      5 4      4 6  6
+--R             (128a b c  - 64a b c  + 8a b c)d  + (128a c  - 24a b c + 4a b )d
+--R           + 
+--R                  7   2      6 3      5 5  4       8 2      7 2      6 4  2
+--R             (128a b c  - 64a b c + 8a b )d  + (64a c  - 32a b c + 4a b )d
+--R        *
+--R              3
+--R           e f
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 585
+t0:=1/((d*f+e*f*x)^4*(a+b*(d+e*x)^2+c*(d+e*x)^4)^3)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 16 4 16      3   15 4 15        3 2       2  14 4 14
+--R       c e  f x   + 16c d e  f x   + (120c d  + 3b c )e  f x
+--R     + 
+--R            3 3        2   13 4 13
+--R       (560c d  + 42b c d)e  f x
+--R     + 
+--R             3 4         2 2       2     2   12 4 12
+--R       (1820c d  + 273b c d  + 3a c  + 3b c)e  f x
+--R     + 
+--R             3 5          2 3         2      2     11 4 11
+--R       (4368c d  + 1092b c d  + (36a c  + 36b c)d)e  f x
+--R     + 
+--R             3 6          2 4          2       2   2             3  10 4 10
+--R       (8008c d  + 3003b c d  + (198a c  + 198b c)d  + 6a b c + b )e  f x
+--R     + 
+--R              3 7          2 5          2       2   3                 3    9 4 9
+--R       (11440c d  + 6006b c d  + (660a c  + 660b c)d  + (60a b c + 10b )d)e f x
+--R     + 
+--R                 3 8          2 6           2        2   4                  3  2
+--R           12870c d  + 9009b c d  + (1485a c  + 1485b c)d  + (270a b c + 45b )d
+--R         + 
+--R             2        2
+--R           3a c + 3a b
+--R      *
+--R          8 4 8
+--R         e f x
+--R     + 
+--R                 3 9           2 7           2        2   5
+--R           11440c d  + 10296b c d  + (2376a c  + 2376b c)d
+--R         + 
+--R                           3  3       2         2
+--R           (720a b c + 120b )d  + (24a c + 24a b )d
+--R      *
+--R          7 4 7
+--R         e f x
+--R     + 
+--R                3 10          2 8           2        2   6
+--R           8008c d   + 9009b c d  + (2772a c  + 2772b c)d
+--R         + 
+--R                            3  4       2         2  2     2
+--R           (1260a b c + 210b )d  + (84a c + 84a b )d  + 3a b
+--R      *
+--R          6 4 6
+--R         e f x
+--R     + 
+--R                3 11          2 9           2        2   7
+--R           4368c d   + 6006b c d  + (2376a c  + 2376b c)d
+--R         + 
+--R                            3  5        2          2  3      2
+--R           (1512a b c + 252b )d  + (168a c + 168a b )d  + 18a b d
+--R      *
+--R          5 4 5
+--R         e f x
+--R     + 
+--R                3 12          2 10           2        2   8
+--R           1820c d   + 3003b c d   + (1485a c  + 1485b c)d
+--R         + 
+--R                            3  6        2          2  4      2   2    3
+--R           (1260a b c + 210b )d  + (210a c + 210a b )d  + 45a b d  + a
+--R      *
+--R          4 4 4
+--R         e f x
+--R     + 
+--R               3 13          2 11          2       2   9                   3  7
+--R           560c d   + 1092b c d   + (660a c  + 660b c)d  + (720a b c + 120b )d
+--R         + 
+--R                2          2  5      2   3     3
+--R           (168a c + 168a b )d  + 60a b d  + 4a d
+--R      *
+--R          3 4 3
+--R         e f x
+--R     + 
+--R               3 14         2 12          2       2   10                  3  8
+--R           120c d   + 273b c d   + (198a c  + 198b c)d   + (270a b c + 45b )d
+--R         + 
+--R               2         2  6      2   4     3 2
+--R           (84a c + 84a b )d  + 45a b d  + 6a d
+--R      *
+--R          2 4 2
+--R         e f x
+--R     + 
+--R              3 15        2 13         2      2   11                 3  9
+--R           16c d   + 42b c d   + (36a c  + 36b c)d   + (60a b c + 10b )d
+--R         + 
+--R               2         2  7      2   5     3 3
+--R           (24a c + 24a b )d  + 18a b d  + 4a d
+--R      *
+--R            4
+--R         e f x
+--R     + 
+--R            3 16       2 14        2     2   12              3  10
+--R           c d   + 3b c d   + (3a c  + 3b c)d   + (6a b c + b )d
+--R         + 
+--R              2        2  8     2   6    3 4
+--R           (3a c + 3a b )d  + 3a b d  + a d
+--R      *
+--R          4
+--R         f
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 583
+
+--S 584 of 585
+r0:=1/24*(-35*b^4+235*a*b^2*c-308*a^2*c^2)/(a^3*(b^2-4*a*c)^2*e*f^4*_
+   (d+e*x)^3)+1/8*b*(35*b^4-270*a*b^2*c+508*a^2*c^2)/(a^4*(b^2-4*a*c)^2*_
+   e*f^4*(d+e*x))+1/4*(b^2-2*a*c+b*c*(d+e*x)^2)/(a*(b^2-4*a*c)*e*f^4*(d+_
+   e*x)^3*(a+b*(d+e*x)^2+c*(d+e*x)^4)^2)+1/8*(7*b^4-45*a*b^2*c+44*a^2*c^2+_
+   b*c*(7*b^2-40*a*c)*(d+e*x)^2)/(a^2*(b^2-4*a*c)^2*e*f^4*(d+e*x)^3*(a+_
+   b*(d+e*x)^2+c*(d+e*x)^4))+1/8*atan((d+e*x)*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(35*b^5-270*a*b^3*c+508*a^2*b*c^2+(35*b^6-_
+   340*a*b^4*c+978*a^2*b^2*c^2-616*a^3*c^3)/sqrt(b^2-4*a*c))/(a^4*(b^2-_
+   4*a*c)^2*e*f^4*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/8*atan((d+e*x)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(35*b^5-270*a*b^3*c+_
+   508*a^2*b*c^2+(-35*b^6+340*a*b^4*c-978*a^2*b^2*c^2+616*a^3*c^3)/_
+   sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^2*e*f^4*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                     2   4         3 3       5 2  11 11
+--R               (1524a b c  - 810a b c  + 105b c )e  x
+--R             + 
+--R                      2   4          3 3        5 2    10 10
+--R               (16764a b c  - 8910a b c  + 1155b c )d e  x
+--R             + 
+--R                          2   4           3 3        5 2  2        2 2 3
+--R                   (83820a b c  - 44550a b c  + 5775b c )d  + 3048a b c
+--R                 + 
+--R                            4 2       6
+--R                   - 1620a b c  + 210b c
+--R              *
+--R                  9 9
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  3
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                          2 2 3           4 2        6
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  4
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   2        3   3
+--R                   (109728a b c  - 58320a b c  + 7560b c)d  + 3048a b c
+--R                 + 
+--R                        2 3 2         5        7
+--R                   - 96a b c  - 600a b c + 105b
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  5
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   3
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  6
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   4
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  2
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                        3 2 2        2 4          6
+--R                   3048a b c  - 1620a b c + 210a b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  7
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   5
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  3
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2        2 4           6
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  8
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   6
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  4
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2         2 4           6  2        4   2
+--R                   (30480a b c  - 16200a b c + 2100a b )d  + 1524a b c
+--R                 + 
+--R                         3 3        2 5
+--R                   - 810a b c + 105a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2   4           3 3        5 2  9
+--R                   (83820a b c  - 44550a b c  + 5775b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   7
+--R                   (109728a b c  - 58320a b c  + 7560b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  5
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                          3 2 2         2 4           6  3
+--R                   (30480a b c  - 16200a b c + 2100a b )d
+--R                 + 
+--R                         4   2        3 3        2 5
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2   4          3 3        5 2  10
+--R                   (16764a b c  - 8910a b c  + 1155b c )d
+--R                 + 
+--R                          2 2 3           4 2        6   8
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7  6
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R                 + 
+--R                          3 2 2        2 4           6  4
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R                 + 
+--R                         4   2        3 3        2 5  2
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )d
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)d
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )d
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )d
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   3 5        2 2 4          4 3       6 2  11 11
+--R           (- 1848a c  + 2934a b c  - 1020a b c  + 105b c )e  x
+--R         + 
+--R                    3 5         2 2 4           4 3        6 2    10 10
+--R           (- 20328a c  + 32274a b c  - 11220a b c  + 1155b c )d e  x
+--R         + 
+--R                         3 5          2 2 4           4 3        6 2  2
+--R               (- 101640a c  + 161370a b c  - 56100a b c  + 5775b c )d
+--R             + 
+--R                      3   4        2 3 3          5 2       7
+--R               - 3696a b c  + 5868a b c  - 2040a b c  + 210b c
+--R          *
+--R              9 9
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  3
+--R               (- 304920a c  + 484110a b c  - 168300a b c  + 17325b c )d
+--R             + 
+--R                        3   4         2 3 3           5 2        7
+--R               (- 33264a b c  + 52812a b c  - 18360a b c  + 1890b c)d
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  4
+--R               (- 609840a c  + 968220a b c  - 336600a b c  + 34650b c )d
+--R             + 
+--R                         3   4          2 3 3           5 2        7   2
+--R               (- 133056a b c  + 211248a b c  - 73440a b c  + 7560b c)d
+--R             + 
+--R                      4 4        3 2 3       2 4 2         6        8
+--R               - 3696a c  + 4020a b c  + 894a b c  - 810a b c + 105b
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                         3 5           2 2 4            4 3         6 2  5
+--R               (- 853776a c  + 1355508a b c  - 471240a b c  + 48510b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   3
+--R               (- 310464a b c  + 492912a b c  - 171360a b c  + 17640b c)d
+--R             + 
+--R                        4 4         3 2 3        2 4 2          6        8
+--R               (- 25872a c  + 28140a b c  + 6258a b c  - 5670a b c + 735b )d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                         3 5           2 2 4            4 3         6 2  6
+--R               (- 853776a c  + 1355508a b c  - 471240a b c  + 48510b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   4
+--R               (- 465696a b c  + 739368a b c  - 257040a b c  + 26460b c)d
+--R             + 
+--R                        4 4         3 2 3         2 4 2           6         8  2
+--R               (- 77616a c  + 84420a b c  + 18774a b c  - 17010a b c + 2205b )d
+--R             + 
+--R                      4   3        3 3 2        2 5          7
+--R               - 3696a b c  + 5868a b c  - 2040a b c + 210a b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  7
+--R               (- 609840a c  + 968220a b c  - 336600a b c  + 34650b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   5
+--R               (- 465696a b c  + 739368a b c  - 257040a b c  + 26460b c)d
+--R             + 
+--R                              4 4          3 2 3         2 4 2           6
+--R                     - 129360a c  + 140700a b c  + 31290a b c  - 28350a b c
+--R                   + 
+--R                          8
+--R                     3675b
+--R              *
+--R                  3
+--R                 d
+--R             + 
+--R                        4   3         3 3 2         2 5           7
+--R               (- 18480a b c  + 29340a b c  - 10200a b c + 1050a b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                         3 5          2 2 4            4 3         6 2  8
+--R               (- 304920a c  + 484110a b c  - 168300a b c  + 17325b c )d
+--R             + 
+--R                         3   4          2 3 3            5 2         7   6
+--R               (- 310464a b c  + 492912a b c  - 171360a b c  + 17640b c)d
+--R             + 
+--R                              4 4          3 2 3         2 4 2           6
+--R                     - 129360a c  + 140700a b c  + 31290a b c  - 28350a b c
+--R                   + 
+--R                          8
+--R                     3675b
+--R              *
+--R                  4
+--R                 d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  2
+--R               (- 36960a b c  + 58680a b c  - 20400a b c + 2100a b )d
+--R             + 
+--R                      5 3        4 2 2        3 4        2 6
+--R               - 1848a c  + 2934a b c  - 1020a b c + 105a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                         3 5          2 2 4           4 3        6 2  9
+--R               (- 101640a c  + 161370a b c  - 56100a b c  + 5775b c )d
+--R             + 
+--R                         3   4          2 3 3           5 2        7   7
+--R               (- 133056a b c  + 211248a b c  - 73440a b c  + 7560b c)d
+--R             + 
+--R                        4 4         3 2 3         2 4 2           6         8  5
+--R               (- 77616a c  + 84420a b c  + 18774a b c  - 17010a b c + 2205b )d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  3
+--R               (- 36960a b c  + 58680a b c  - 20400a b c + 2100a b )d
+--R             + 
+--R                       5 3        4 2 2        3 4        2 6
+--R               (- 5544a c  + 8802a b c  - 3060a b c + 315a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                        3 5         2 2 4           4 3        6 2  10
+--R               (- 20328a c  + 32274a b c  - 11220a b c  + 1155b c )d
+--R             + 
+--R                        3   4         2 3 3           5 2        7   8
+--R               (- 33264a b c  + 52812a b c  - 18360a b c  + 1890b c)d
+--R             + 
+--R                        4 4         3 2 3        2 4 2          6        8  6
+--R               (- 25872a c  + 28140a b c  + 6258a b c  - 5670a b c + 735b )d
+--R             + 
+--R                        4   3         3 3 2         2 5           7  4
+--R               (- 18480a b c  + 29340a b c  - 10200a b c + 1050a b )d
+--R             + 
+--R                       5 3        4 2 2        3 4        2 6  2
+--R               (- 5544a c  + 8802a b c  - 3060a b c + 315a b )d
+--R          *
+--R             e x
+--R         + 
+--R                   3 5        2 2 4          4 3       6 2  11
+--R           (- 1848a c  + 2934a b c  - 1020a b c  + 105b c )d
+--R         + 
+--R                   3   4        2 3 3          5 2       7   9
+--R           (- 3696a b c  + 5868a b c  - 2040a b c  + 210b c)d
+--R         + 
+--R                   4 4        3 2 3       2 4 2         6        8  7
+--R           (- 3696a c  + 4020a b c  + 894a b c  - 810a b c + 105b )d
+--R         + 
+--R                   4   3        3 3 2        2 5          7  5
+--R           (- 3696a b c  + 5868a b c  - 2040a b c + 210a b )d
+--R         + 
+--R                   5 3        4 2 2        3 4        2 6  3
+--R           (- 1848a c  + 2934a b c  - 1020a b c + 105a b )d
+--R      *
+--R              +------------------+
+--R              | +-----------+                       +-+ +-+
+--R          +-+ | |          2              (e x + d)\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                     2   4         3 3       5 2  11 11
+--R               (1524a b c  - 810a b c  + 105b c )e  x
+--R             + 
+--R                      2   4          3 3        5 2    10 10
+--R               (16764a b c  - 8910a b c  + 1155b c )d e  x
+--R             + 
+--R                          2   4           3 3        5 2  2        2 2 3
+--R                   (83820a b c  - 44550a b c  + 5775b c )d  + 3048a b c
+--R                 + 
+--R                            4 2       6
+--R                   - 1620a b c  + 210b c
+--R              *
+--R                  9 9
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  3
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                          2 2 3           4 2        6
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R              *
+--R                  8 8
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  4
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   2        3   3
+--R                   (109728a b c  - 58320a b c  + 7560b c)d  + 3048a b c
+--R                 + 
+--R                        2 3 2         5        7
+--R                   - 96a b c  - 600a b c + 105b
+--R              *
+--R                  7 7
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  5
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   3
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R              *
+--R                  6 6
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  6
+--R                   (704088a b c  - 374220a b c  + 48510b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   4
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  2
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                        3 2 2        2 4          6
+--R                   3048a b c  - 1620a b c + 210a b
+--R              *
+--R                  5 5
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  7
+--R                   (502920a b c  - 267300a b c  + 34650b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   5
+--R                   (384048a b c  - 204120a b c  + 26460b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  3
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2        2 4           6
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R              *
+--R                  4 4
+--R                 e x
+--R             + 
+--R                           2   4            3 3         5 2  8
+--R                   (251460a b c  - 133650a b c  + 17325b c )d
+--R                 + 
+--R                           2 2 3            4 2         6   6
+--R                   (256032a b c  - 136080a b c  + 17640b c)d
+--R                 + 
+--R                           3   3        2 3 2           5         7  4
+--R                   (106680a b c  - 3360a b c  - 21000a b c + 3675b )d
+--R                 + 
+--R                          3 2 2         2 4           6  2        4   2
+--R                   (30480a b c  - 16200a b c + 2100a b )d  + 1524a b c
+--R                 + 
+--R                         3 3        2 5
+--R                   - 810a b c + 105a b
+--R              *
+--R                  3 3
+--R                 e x
+--R             + 
+--R                          2   4           3 3        5 2  9
+--R                   (83820a b c  - 44550a b c  + 5775b c )d
+--R                 + 
+--R                           2 2 3           4 2        6   7
+--R                   (109728a b c  - 58320a b c  + 7560b c)d
+--R                 + 
+--R                          3   3        2 3 2           5         7  5
+--R                   (64008a b c  - 2016a b c  - 12600a b c + 2205b )d
+--R                 + 
+--R                          3 2 2         2 4           6  3
+--R                   (30480a b c  - 16200a b c + 2100a b )d
+--R                 + 
+--R                         4   2        3 3        2 5
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                  2 2
+--R                 e x
+--R             + 
+--R                          2   4          3 3        5 2  10
+--R                   (16764a b c  - 8910a b c  + 1155b c )d
+--R                 + 
+--R                          2 2 3           4 2        6   8
+--R                   (27432a b c  - 14580a b c  + 1890b c)d
+--R                 + 
+--R                          3   3       2 3 2          5        7  6
+--R                   (21336a b c  - 672a b c  - 4200a b c + 735b )d
+--R                 + 
+--R                          3 2 2        2 4           6  4
+--R                   (15240a b c  - 8100a b c + 1050a b )d
+--R                 + 
+--R                         4   2        3 3        2 5  2
+--R                   (4572a b c  - 2430a b c + 315a b )d
+--R              *
+--R                 e x
+--R             + 
+--R                     2   4         3 3       5 2  11
+--R               (1524a b c  - 810a b c  + 105b c )d
+--R             + 
+--R                     2 2 3          4 2       6   9
+--R               (3048a b c  - 1620a b c  + 210b c)d
+--R             + 
+--R                     3   3      2 3 2         5        7  7
+--R               (3048a b c  - 96a b c  - 600a b c + 105b )d
+--R             + 
+--R                     3 2 2        2 4          6  5
+--R               (3048a b c  - 1620a b c + 210a b )d
+--R             + 
+--R                     4   2       3 3        2 5  3
+--R               (1524a b c  - 810a b c + 105a b )d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 3 5        2 2 4          4 3       6 2  11 11
+--R           (1848a c  - 2934a b c  + 1020a b c  - 105b c )e  x
+--R         + 
+--R                  3 5         2 2 4           4 3        6 2    10 10
+--R           (20328a c  - 32274a b c  + 11220a b c  - 1155b c )d e  x
+--R         + 
+--R                       3 5          2 2 4           4 3        6 2  2
+--R               (101640a c  - 161370a b c  + 56100a b c  - 5775b c )d
+--R             + 
+--R                    3   4        2 3 3          5 2       7
+--R               3696a b c  - 5868a b c  + 2040a b c  - 210b c
+--R          *
+--R              9 9
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  3
+--R               (304920a c  - 484110a b c  + 168300a b c  - 17325b c )d
+--R             + 
+--R                      3   4         2 3 3           5 2        7
+--R               (33264a b c  - 52812a b c  + 18360a b c  - 1890b c)d
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  4
+--R               (609840a c  - 968220a b c  + 336600a b c  - 34650b c )d
+--R             + 
+--R                       3   4          2 3 3           5 2        7   2
+--R               (133056a b c  - 211248a b c  + 73440a b c  - 7560b c)d
+--R             + 
+--R                    4 4        3 2 3       2 4 2         6        8
+--R               3696a c  - 4020a b c  - 894a b c  + 810a b c - 105b
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                       3 5           2 2 4            4 3         6 2  5
+--R               (853776a c  - 1355508a b c  + 471240a b c  - 48510b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   3
+--R               (310464a b c  - 492912a b c  + 171360a b c  - 17640b c)d
+--R             + 
+--R                      4 4         3 2 3        2 4 2          6        8
+--R               (25872a c  - 28140a b c  - 6258a b c  + 5670a b c - 735b )d
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       3 5           2 2 4            4 3         6 2  6
+--R               (853776a c  - 1355508a b c  + 471240a b c  - 48510b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   4
+--R               (465696a b c  - 739368a b c  + 257040a b c  - 26460b c)d
+--R             + 
+--R                      4 4         3 2 3         2 4 2           6         8  2
+--R               (77616a c  - 84420a b c  - 18774a b c  + 17010a b c - 2205b )d
+--R             + 
+--R                    4   3        3 3 2        2 5          7
+--R               3696a b c  - 5868a b c  + 2040a b c - 210a b
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  7
+--R               (609840a c  - 968220a b c  + 336600a b c  - 34650b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   5
+--R               (465696a b c  - 739368a b c  + 257040a b c  - 26460b c)d
+--R             + 
+--R                       4 4          3 2 3         2 4 2           6         8  3
+--R               (129360a c  - 140700a b c  - 31290a b c  + 28350a b c - 3675b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7
+--R               (18480a b c  - 29340a b c  + 10200a b c - 1050a b )d
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       3 5          2 2 4            4 3         6 2  8
+--R               (304920a c  - 484110a b c  + 168300a b c  - 17325b c )d
+--R             + 
+--R                       3   4          2 3 3            5 2         7   6
+--R               (310464a b c  - 492912a b c  + 171360a b c  - 17640b c)d
+--R             + 
+--R                       4 4          3 2 3         2 4 2           6         8  4
+--R               (129360a c  - 140700a b c  - 31290a b c  + 28350a b c - 3675b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  2        5 3
+--R               (36960a b c  - 58680a b c  + 20400a b c - 2100a b )d  + 1848a c
+--R             + 
+--R                      4 2 2        3 4        2 6
+--R               - 2934a b c  + 1020a b c - 105a b
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                       3 5          2 2 4           4 3        6 2  9
+--R               (101640a c  - 161370a b c  + 56100a b c  - 5775b c )d
+--R             + 
+--R                       3   4          2 3 3           5 2        7   7
+--R               (133056a b c  - 211248a b c  + 73440a b c  - 7560b c)d
+--R             + 
+--R                      4 4         3 2 3         2 4 2           6         8  5
+--R               (77616a c  - 84420a b c  - 18774a b c  + 17010a b c - 2205b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  3
+--R               (36960a b c  - 58680a b c  + 20400a b c - 2100a b )d
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6
+--R               (5544a c  - 8802a b c  + 3060a b c - 315a b )d
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      3 5         2 2 4           4 3        6 2  10
+--R               (20328a c  - 32274a b c  + 11220a b c  - 1155b c )d
+--R             + 
+--R                      3   4         2 3 3           5 2        7   8
+--R               (33264a b c  - 52812a b c  + 18360a b c  - 1890b c)d
+--R             + 
+--R                      4 4         3 2 3        2 4 2          6        8  6
+--R               (25872a c  - 28140a b c  - 6258a b c  + 5670a b c - 735b )d
+--R             + 
+--R                      4   3         3 3 2         2 5           7  4
+--R               (18480a b c  - 29340a b c  + 10200a b c - 1050a b )d
+--R             + 
+--R                     5 3        4 2 2        3 4        2 6  2
+--R               (5544a c  - 8802a b c  + 3060a b c - 315a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 3 5        2 2 4          4 3       6 2  11
+--R           (1848a c  - 2934a b c  + 1020a b c  - 105b c )d
+--R         + 
+--R                 3   4        2 3 3          5 2       7   9
+--R           (3696a b c  - 5868a b c  + 2040a b c  - 210b c)d
+--R         + 
+--R                 4 4        3 2 3       2 4 2         6        8  7
+--R           (3696a c  - 4020a b c  - 894a b c  + 810a b c - 105b )d
+--R         + 
+--R                 4   3        3 3 2        2 5          7  5
+--R           (3696a b c  - 5868a b c  + 2040a b c - 210a b )d
+--R         + 
+--R                 5 3        4 2 2        3 4        2 6  3
+--R           (1848a c  - 2934a b c  + 1020a b c - 105a b )d
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                      +-+ +-+
+--R          +-+ |   |          2             (e x + d)\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                 2   4         3 3       5 2  10 10
+--R           (1524a b c  - 810a b c  + 105b c )e  x
+--R         + 
+--R                  2   4          3 3        5 2    9 9
+--R           (15240a b c  - 8100a b c  + 1050b c )d e x
+--R         + 
+--R                      2   4           3 3        5 2  2       3 4        2 2 3
+--R               (68580a b c  - 36450a b c  + 4725b c )d  - 308a c  + 3283a b c
+--R             + 
+--R                        4 2       6
+--R               - 1655a b c  + 210b c
+--R          *
+--R              8 8
+--R             e x
+--R         + 
+--R                       2   4           3 3         5 2  3
+--R               (182880a b c  - 97200a b c  + 12600b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6
+--R               (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R          *
+--R              7 7
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  4
+--R               (320040a b c  - 170100a b c  + 22050b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   2        3   3
+--R               (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d  + 2312a b c
+--R             + 
+--R                   2 3 2         5        7
+--R               395a b c  - 670a b c + 105b
+--R          *
+--R              6 6
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  5
+--R               (384048a b c  - 204120a b c  + 26460b c )d
+--R             + 
+--R                        3 4          2 2 3           4 2         6   3
+--R               (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R             + 
+--R                      3   3        2 3 2          5        7
+--R               (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R          *
+--R              5 5
+--R             e x
+--R         + 
+--R                       2   4            3 3         5 2  6
+--R               (320040a b c  - 170100a b c  + 22050b c )d
+--R             + 
+--R                        3 4          2 2 3            4 2         6   4
+--R               (- 21560a c  + 229810a b c  - 115850a b c  + 14700b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  2       4 3
+--R               (34680a b c  + 5925a b c  - 10050a b c + 1575b )d  - 484a c
+--R             + 
+--R                    3 2 2        2 4          6
+--R               2955a b c  - 1413a b c + 175a b
+--R          *
+--R              4 4
+--R             e x
+--R         + 
+--R                       2   4           3 3         5 2  7
+--R               (182880a b c  - 97200a b c  + 12600b c )d
+--R             + 
+--R                        3 4          2 2 3           4 2         6   5
+--R               (- 17248a c  + 183848a b c  - 92680a b c  + 11760b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  3
+--R               (46240a b c  + 7900a b c  - 13400a b c + 2100b )d
+--R             + 
+--R                       4 3         3 2 2        2 4          6
+--R               (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R          *
+--R              3 3
+--R             e x
+--R         + 
+--R                      2   4           3 3        5 2  8
+--R               (68580a b c  - 36450a b c  + 4725b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   6
+--R               (- 8624a c  + 91924a b c  - 46340a b c  + 5880b c)d
+--R             + 
+--R                      3   3        2 3 2           5         7  4
+--R               (34680a b c  + 5925a b c  - 10050a b c + 1575b )d
+--R             + 
+--R                       4 3         3 2 2        2 4           6  2       4   2
+--R               (- 2904a c  + 17730a b c  - 8478a b c + 1050a b )d  + 896a b c
+--R             + 
+--R                     3 3       2 5
+--R               - 448a b c + 56a b
+--R          *
+--R              2 2
+--R             e x
+--R         + 
+--R                      2   4          3 3        5 2  9
+--R               (15240a b c  - 8100a b c  + 1050b c )d
+--R             + 
+--R                       3 4         2 2 3           4 2        6   7
+--R               (- 2464a c  + 26264a b c  - 13240a b c  + 1680b c)d
+--R             + 
+--R                      3   3        2 3 2          5        7  5
+--R               (13872a b c  + 2370a b c  - 4020a b c + 630b )d
+--R             + 
+--R                       4 3         3 2 2        2 4          6  3
+--R               (- 1936a c  + 11820a b c  - 5652a b c + 700a b )d
+--R             + 
+--R                     4   2       3 3        2 5
+--R               (1792a b c  - 896a b c + 112a b )d
+--R          *
+--R             e x
+--R         + 
+--R                 2   4         3 3       5 2  10
+--R           (1524a b c  - 810a b c  + 105b c )d
+--R         + 
+--R                  3 4        2 2 3          4 2       6   8
+--R           (- 308a c  + 3283a b c  - 1655a b c  + 210b c)d
+--R         + 
+--R                 3   3       2 3 2         5        7  6
+--R           (2312a b c  + 395a b c  - 670a b c + 105b )d
+--R         + 
+--R                  4 3        3 2 2        2 4          6  4
+--R           (- 484a c  + 2955a b c  - 1413a b c + 175a b )d
+--R         + 
+--R                4   2       3 3       2 5  2       5 2      4 2      3 4
+--R           (896a b c  - 448a b c + 56a b )d  - 128a c  + 64a b c - 8a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              6 4       5 2 3      4 4 2  12 4 11
+--R         (384a c  - 192a b c  + 24a b c )e  f x
+--R       + 
+--R               6 4        5 2 3       4 4 2    11 4 10
+--R         (4224a c  - 2112a b c  + 264a b c )d e  f x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  2       6   3       5 3 2
+--R             (21120a c  - 10560a b c  + 1320a b c )d  + 768a b c  - 384a b c
+--R           + 
+--R                4 5
+--R             48a b c
+--R        *
+--R            10 4 9
+--R           e  f x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  3
+--R             (63360a c  - 31680a b c  + 3960a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5
+--R             (6912a b c  - 3456a b c  + 432a b c)d
+--R        *
+--R            9 4 8
+--R           e f x
+--R       + 
+--R                     6 4         5 2 3        4 4 2  4
+--R             (126720a c  - 63360a b c  + 7920a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   2       7 3       5 4
+--R             (27648a b c  - 13824a b c  + 1728a b c)d  + 768a c  - 144a b c
+--R           + 
+--R                4 6
+--R             24a b
+--R        *
+--R            8 4 7
+--R           e f x
+--R       + 
+--R                     6 4         5 2 3         4 4 2  5
+--R             (177408a c  - 88704a b c  + 11088a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   3
+--R             (64512a b c  - 32256a b c  + 4032a b c)d
+--R           + 
+--R                   7 3        5 4        4 6
+--R             (5376a c  - 1008a b c + 168a b )d
+--R        *
+--R            7 4 6
+--R           e f x
+--R       + 
+--R                     6 4         5 2 3         4 4 2  6
+--R             (177408a c  - 88704a b c  + 11088a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   4
+--R             (96768a b c  - 48384a b c  + 6048a b c)d
+--R           + 
+--R                  7 3        5 4        4 6  2       7   2       6 3       5 5
+--R           (16128a c  - 3024a b c + 504a b )d  + 768a b c  - 384a b c + 48a b
+--R        *
+--R            6 4 5
+--R           e f x
+--R       + 
+--R                     6 4         5 2 3        4 4 2  7
+--R             (126720a c  - 63360a b c  + 7920a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   5
+--R             (96768a b c  - 48384a b c  + 6048a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  3
+--R             (26880a c  - 5040a b c + 840a b )d
+--R           + 
+--R                   7   2        6 3        5 5
+--R             (3840a b c  - 1920a b c + 240a b )d
+--R        *
+--R            5 4 4
+--R           e f x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  8
+--R             (63360a c  - 31680a b c  + 3960a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   6
+--R             (64512a b c  - 32256a b c  + 4032a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  4
+--R             (26880a c  - 5040a b c + 840a b )d
+--R           + 
+--R                   7   2        6 3        5 5  2       8 2       7 2       6 4
+--R             (7680a b c  - 3840a b c + 480a b )d  + 384a c  - 192a b c + 24a b
+--R        *
+--R            4 4 3
+--R           e f x
+--R       + 
+--R                    6 4         5 2 3        4 4 2  9
+--R             (21120a c  - 10560a b c  + 1320a b c )d
+--R           + 
+--R                    6   3         5 3 2        4 5   7
+--R             (27648a b c  - 13824a b c  + 1728a b c)d
+--R           + 
+--R                    7 3        5 4        4 6  5
+--R             (16128a c  - 3024a b c + 504a b )d
+--R           + 
+--R                   7   2        6 3        5 5  3
+--R             (7680a b c  - 3840a b c + 480a b )d
+--R           + 
+--R                   8 2       7 2       6 4
+--R             (1152a c  - 576a b c + 72a b )d
+--R        *
+--R            3 4 2
+--R           e f x
+--R       + 
+--R                   6 4        5 2 3       4 4 2  10
+--R             (4224a c  - 2112a b c  + 264a b c )d
+--R           + 
+--R                   6   3        5 3 2       4 5   8
+--R             (6912a b c  - 3456a b c  + 432a b c)d
+--R           + 
+--R                   7 3        5 4        4 6  6
+--R             (5376a c  - 1008a b c + 168a b )d
+--R           + 
+--R                   7   2        6 3        5 5  4
+--R             (3840a b c  - 1920a b c + 240a b )d
+--R           + 
+--R                   8 2       7 2       6 4  2
+--R             (1152a c  - 576a b c + 72a b )d
+--R        *
+--R            2 4
+--R           e f x
+--R       + 
+--R                  6 4       5 2 3      4 4 2  11
+--R             (384a c  - 192a b c  + 24a b c )d
+--R           + 
+--R                  6   3       5 3 2      4 5   9
+--R             (768a b c  - 384a b c  + 48a b c)d
+--R           + 
+--R                  7 3       5 4       4 6  7        7   2       6 3       5 5  5
+--R             (768a c  - 144a b c + 24a b )d  + (768a b c  - 384a b c + 48a b )d
+--R           + 
+--R                  8 2       7 2       6 4  3
+--R             (384a c  - 192a b c + 24a b )d
+--R        *
+--R              4
+--R           e f
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 585
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder15.input.pamphlet b/src/input/richder15.input.pamphlet
new file mode 100644
index 0000000..f5c8f5b
--- /dev/null
+++ b/src/input/richder15.input.pamphlet
@@ -0,0 +1,28594 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder15.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (d+e x^2)^n (a+b x^2+c x^4)^p|
+There are 20 derivatives that differ from Rubi
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder15.output
+)spool richder15.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1718
+t0:=(d+e*x^2)/(d^2+e^2*x^4)
+--R 
+--R
+--R            2
+--R         e x  + d
+--R   (1)  ---------
+--R         2 4    2
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1
+
+--S 2 of 1718
+r0:=-atan(1-x*sqrt(2)*sqrt(e)/sqrt(d))/(sqrt(2)*sqrt(d)*sqrt(e))+_
+   atan(1+x*sqrt(2)*sqrt(e)/sqrt(d))/(sqrt(2)*sqrt(d)*sqrt(e))
+--R 
+--R
+--R               +-+ +-+    +-+           +-+ +-+    +-+
+--R             x\|2 \|e  + \|d          x\|2 \|e  - \|d
+--R        atan(----------------) + atan(----------------)
+--R                    +-+                      +-+
+--R                   \|d                      \|d
+--R   (2)  -----------------------------------------------
+--R                           +-+ +-+ +-+
+--R                          \|2 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 1718
+t0:=(d-e*x^2)/(d^2+e^2*x^4)
+--R 
+--R
+--R             2
+--R        - e x  + d
+--R   (1)  ----------
+--R          2 4    2
+--R         e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 4
+
+--S 5 of 1718
+r0:=-1/2*log(d+e*x^2-x*sqrt(2)*sqrt(d)*sqrt(e))/(sqrt(2)*sqrt(d)*sqrt(e))+_
+   1/2*log(d+e*x^2+x*sqrt(2)*sqrt(d)*sqrt(e))/(sqrt(2)*sqrt(d)*sqrt(e))
+--R 
+--R
+--R              +-+ +-+ +-+      2                +-+ +-+ +-+      2
+--R        log(x\|2 \|d \|e  + e x  + d) - log(- x\|2 \|d \|e  + e x  + d)
+--R   (2)  ---------------------------------------------------------------
+--R                                   +-+ +-+ +-+
+--R                                 2\|2 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 1718
+t0:=(d+e*x^2)/(d^2+b*x^2+e^2*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  + b x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 7
+
+--S 8 of 1718
+r0:=-atan((-2*e*x+sqrt(-b+2*d*e))/sqrt(b+2*d*e))/sqrt(b+2*d*e)+_
+   atan((2*e*x+sqrt(-b+2*d*e))/sqrt(b+2*d*e))/sqrt(b+2*d*e)
+--R 
+--R
+--R              +--------+                 +--------+
+--R             \|2d e - b  + 2e x         \|2d e - b  - 2e x
+--R        atan(------------------) - atan(------------------)
+--R                  +--------+                 +--------+
+--R                 \|2d e + b                 \|2d e + b
+--R   (2)  ---------------------------------------------------
+--R                             +--------+
+--R                            \|2d e + b
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 1718
+t0:=(d+e*x^2)/(d^2-b*x^2+e^2*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  - b x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 10
+
+--S 11 of 1718
+r0:=atanh((-2*e*x+sqrt(b+2*d*e))/sqrt(b-2*d*e))/sqrt(b-2*d*e)-_
+   atanh((2*e*x+sqrt(b+2*d*e))/sqrt(b-2*d*e))/sqrt(b-2*d*e)
+--R 
+--R
+--R                 +--------+                  +--------+
+--R                \|2d e + b  + 2e x          \|2d e + b  - 2e x
+--R        - atanh(------------------) + atanh(------------------)
+--R                    +----------+                +----------+
+--R                   \|- 2d e + b                \|- 2d e + b
+--R   (2)  -------------------------------------------------------
+--R                              +----------+
+--R                             \|- 2d e + b
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 1718
+t0:=(d+e*x^2)/(d^2+f*x^2+e^2*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  + f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 13
+
+--S 14 of 1718
+r0:=-atan((-2*e*x+sqrt(2*d*e-f))/sqrt(2*d*e+f))/sqrt(2*d*e+f)+_
+   atan((2*e*x+sqrt(2*d*e-f))/sqrt(2*d*e+f))/sqrt(2*d*e+f)
+--R 
+--R
+--R              +----------+                 +----------+
+--R             \|- f + 2d e  + 2e x         \|- f + 2d e  - 2e x
+--R        atan(--------------------) - atan(--------------------)
+--R                   +--------+                   +--------+
+--R                  \|f + 2d e                   \|f + 2d e
+--R   (2)  -------------------------------------------------------
+--R                               +--------+
+--R                              \|f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 1718
+t0:=(d+e*x^2)/(d^2-f*x^2+e^2*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  - f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 16
+
+--S 17 of 1718
+r0:=-atan((-2*e*x+sqrt(2*d*e+f))/sqrt(2*d*e-f))/sqrt(2*d*e-f)+_
+   atan((2*e*x+sqrt(2*d*e+f))/sqrt(2*d*e-f))/sqrt(2*d*e-f)
+--R 
+--R
+--R              +--------+                 +--------+
+--R             \|f + 2d e  + 2e x         \|f + 2d e  - 2e x
+--R        atan(------------------) - atan(------------------)
+--R                 +----------+               +----------+
+--R                \|- f + 2d e               \|- f + 2d e
+--R   (2)  ---------------------------------------------------
+--R                            +----------+
+--R                           \|- f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 1718
+t0:=(d-e*x^2)/(d^2+b*x^2+e^2*x^4)
+--R 
+--R
+--R                2
+--R           - e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  + b x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 19
+
+--S 20 of 1718
+r0:=atan((-2*e*x+sqrt(-b-2*d*e))/sqrt(b-2*d*e))/sqrt(b-2*d*e)-_
+   atan((2*e*x+sqrt(-b-2*d*e))/sqrt(b-2*d*e))/sqrt(b-2*d*e)
+--R 
+--R
+--R                +----------+                 +----------+
+--R               \|- 2d e - b  + 2e x         \|- 2d e - b  - 2e x
+--R        - atan(--------------------) + atan(--------------------)
+--R                    +----------+                 +----------+
+--R                   \|- 2d e + b                 \|- 2d e + b
+--R   (2)  ---------------------------------------------------------
+--R                               +----------+
+--R                              \|- 2d e + b
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 1718
+t0:=(d-e*x^2)/(d^2-b*x^2+e^2*x^4)
+--R 
+--R
+--R                2
+--R           - e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  - b x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 22
+
+--S 23 of 1718
+r0:=-atanh((-2*e*x+sqrt(b-2*d*e))/sqrt(b+2*d*e))/sqrt(b+2*d*e)+_
+   atanh((2*e*x+sqrt(b-2*d*e))/sqrt(b+2*d*e))/sqrt(b+2*d*e)
+--R 
+--R
+--R               +----------+                  +----------+
+--R              \|- 2d e + b  + 2e x          \|- 2d e + b  - 2e x
+--R        atanh(--------------------) - atanh(--------------------)
+--R                    +--------+                    +--------+
+--R                   \|2d e + b                    \|2d e + b
+--R   (2)  ---------------------------------------------------------
+--R                                +--------+
+--R                               \|2d e + b
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 1718
+t0:=(d-e*x^2)/(d^2+f*x^2+e^2*x^4)
+--R 
+--R
+--R                2
+--R           - e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  + f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 25
+
+--S 26 of 1718
+r0:=-1/2*log(d+e*x^2-x*sqrt(2*d*e-f))/sqrt(2*d*e-f)+_
+   1/2*log(d+e*x^2+x*sqrt(2*d*e-f))/sqrt(2*d*e-f)
+--R 
+--R
+--R              +----------+      2                +----------+      2
+--R        log(x\|- f + 2d e  + e x  + d) - log(- x\|- f + 2d e  + e x  + d)
+--R   (2)  -----------------------------------------------------------------
+--R                                    +----------+
+--R                                  2\|- f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 1718
+t0:=(d-e*x^2)/(d^2-f*x^2+e^2*x^4)
+--R 
+--R
+--R                2
+--R           - e x  + d
+--R   (1)  ----------------
+--R         2 4      2    2
+--R        e x  - f x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 28
+
+--S 29 of 1718
+r0:=-1/2*log(d+e*x^2-x*sqrt(2*d*e+f))/sqrt(2*d*e+f)+_
+   1/2*log(d+e*x^2+x*sqrt(2*d*e+f))/sqrt(2*d*e+f)
+--R 
+--R
+--R              +--------+      2                +--------+      2
+--R        log(x\|f + 2d e  + e x  + d) - log(- x\|f + 2d e  + e x  + d)
+--R   (2)  -------------------------------------------------------------
+--R                                   +--------+
+--R                                 2\|f + 2d e
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 1718
+t0:=(1+2*x^2)/(1+b*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R            2x  + 1
+--R   (1)  --------------
+--R          4      2
+--R        4x  + b x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 31
+
+--S 32 of 1718
+r0:=-atan((-4*x+sqrt(4-b))/sqrt(4+b))/sqrt(4+b)+_
+   atan((4*x+sqrt(4-b))/sqrt(4+b))/sqrt(4+b)
+--R 
+--R
+--R              +-------+               +-------+
+--R             \|- b + 4  + 4x         \|- b + 4  - 4x
+--R        atan(---------------) - atan(---------------)
+--R                  +-----+                 +-----+
+--R                 \|b + 4                 \|b + 4
+--R   (2)  ---------------------------------------------
+--R                            +-----+
+--R                           \|b + 4
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 1718
+t0:=(1+2*x^2)/(1-b*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R            2x  + 1
+--R   (1)  --------------
+--R          4      2
+--R        4x  - b x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 34
+
+--S 35 of 1718
+r0:=-atan((-4*x+sqrt(4+b))/sqrt(4-b))/sqrt(4-b)+_
+   atan((4*x+sqrt(4+b))/sqrt(4-b))/sqrt(4-b)
+--R 
+--R
+--R              +-----+               +-----+
+--R             \|b + 4  + 4x         \|b + 4  - 4x
+--R        atan(-------------) - atan(-------------)
+--R                +-------+             +-------+
+--R               \|- b + 4             \|- b + 4
+--R   (2)  -----------------------------------------
+--R                         +-------+
+--R                        \|- b + 4
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 1718
+t0:=(1+2*x^2)/(1+6*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 6x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 37
+
+--S 38 of 1718
+r0:=atan(2*x/sqrt(3-sqrt(5)))/sqrt(10)+atan(2*x/sqrt(3+sqrt(5)))/sqrt(10)
+--R 
+--R
+--R                            +--------+                      +----------+
+--R                  +-+       | +-+                 +-+       |   +-+
+--R               (x\|5  - 3x)\|\|5  + 3          (x\|5  + 3x)\|- \|5  + 3
+--R        - atan(-----------------------) + atan(-------------------------)
+--R                          2                                2
+--R   (2)  -----------------------------------------------------------------
+--R                                       +--+
+--R                                      \|10
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                             +--------+                           +----------+
+--R         +-+     2      +--+ | +-+            +-+     2      +--+ |   +-+
+--R       (\|5  - 4x  - 3)\|10 \|\|5  + 3  + (- \|5  - 4x  - 3)\|10 \|- \|5  + 3
+--R     + 
+--R          2
+--R       40x  + 20
+--R  /
+--R        4       2
+--R     80x  + 120x  + 20
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 1718
+t0:=(1+2*x^2)/(1+5*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 40
+
+--S 41 of 1718
+r0:=1/3*atan(x)+1/3*atan(2*x)
+--R 
+--R
+--R        atan(2x) + atan(x)
+--R   (2)  ------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 1718
+t0:=(1+2*x^2)/(1+4*x^2+4*x^4)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R          2
+--R        2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 43
+
+--S 44 of 1718
+r0:=atan(x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R               +-+
+--R        atan(x\|2 )
+--R   (2)  -----------
+--R             +-+
+--R            \|2
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 1718
+t0:=(1+2*x^2)/(1+3*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 46
+
+--S 47 of 1718
+r0:=-atan((1-4*x)/sqrt(7))/sqrt(7)+atan((1+4*x)/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                      +-+                  +-+
+--R             (4x + 1)\|7          (4x - 1)\|7
+--R        atan(------------) + atan(------------)
+--R                   7                    7
+--R   (2)  ---------------------------------------
+--R                           +-+
+--R                          \|7
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 1718
+t0:=(1+2*x^2)/(1+2*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 49
+
+--S 50 of 1718
+r0:=-atan((-4*x+sqrt(2))/sqrt(6))/sqrt(6)+atan((4*x+sqrt(2))/sqrt(6))/sqrt(6)
+--R 
+--R
+--R               +-+       +-+           +-+       +-+
+--R             (\|2  + 4x)\|6          (\|2  - 4x)\|6
+--R        atan(---------------) - atan(---------------)
+--R                    6                       6
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                             \|6
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 1718
+t0:=(1+2*x^2)/(1+x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  ------------
+--R          4    2
+--R        4x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 52
+
+--S 53 of 1718
+r0:=-atan((-4*x+sqrt(3))/sqrt(5))/sqrt(5)+atan((4*x+sqrt(3))/sqrt(5))/sqrt(5)
+--R 
+--R
+--R               +-+       +-+           +-+       +-+
+--R             (\|3  + 4x)\|5          (\|3  - 4x)\|5
+--R        atan(---------------) - atan(---------------)
+--R                    5                       5
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                             \|5
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 1718
+t0:=(1+2*x^2)/(1+4*x^4)
+--R 
+--R
+--R          2
+--R        2x  + 1
+--R   (1)  -------
+--R          4
+--R        4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 55
+
+--S 56 of 1718
+r0:=-1/2*atan(1-2*x)+1/2*atan(1+2*x)
+--R 
+--R
+--R        atan(2x + 1) + atan(2x - 1)
+--R   (2)  ---------------------------
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 1718
+t0:=(1+2*x^2)/(1-x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  ------------
+--R          4    2
+--R        4x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 58
+
+--S 59 of 1718
+r0:=-atan((-4*x+sqrt(5))/sqrt(3))/sqrt(3)+atan((4*x+sqrt(5))/sqrt(3))/sqrt(3)
+--R 
+--R
+--R              +-+ +-+      +-+          +-+ +-+      +-+
+--R             \|3 \|5  + 4x\|3          \|3 \|5  - 4x\|3
+--R        atan(-----------------) - atan(-----------------)
+--R                     3                         3
+--R   (2)  -------------------------------------------------
+--R                                +-+
+--R                               \|3
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 1718
+t0:=(1+2*x^2)/(1-2*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 61
+
+--S 62 of 1718
+r0:=-atan((-4*x+sqrt(6))/sqrt(2))/sqrt(2)+atan((4*x+sqrt(6))/sqrt(2))/sqrt(2)
+--R 
+--R
+--R              +-+ +-+      +-+          +-+ +-+      +-+
+--R             \|2 \|6  + 4x\|2          \|2 \|6  - 4x\|2
+--R        atan(-----------------) - atan(-----------------)
+--R                     2                         2
+--R   (2)  -------------------------------------------------
+--R                                +-+
+--R                               \|2
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 1718
+t0:=(1+2*x^2)/(1-3*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 64
+
+--S 65 of 1718
+r0:=-atan(-4*x+sqrt(7))+atan(4*x+sqrt(7))
+--R 
+--R
+--R              +-+               +-+
+--R   (2)  atan(\|7  + 4x) - atan(\|7  - 4x)
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 1718
+t0:=(1+2*x^2)/(1-4*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 67
+
+--S 68 of 1718
+r0:=x/(1-2*x^2)
+--R 
+--R
+--R             x
+--R   (2)  - -------
+--R            2
+--R          2x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 68
+
+--S 69 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 1718
+t0:=(1+2*x^2)/(1-5*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 70
+
+--S 71 of 1718
+r0:=atanh(3-4*x)-atanh(3+4*x)
+--R 
+--R
+--R   (2)  - atanh(4x + 3) - atanh(4x - 3)
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 1718
+t0:=(1+2*x^2)/(1-6*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 6x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 73
+
+--S 74 of 1718
+r0:=atanh((-4*x+sqrt(10))/sqrt(2))/sqrt(2)-_
+   atanh((4*x+sqrt(10))/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                 +-+ +--+      +-+           +-+ +--+      +-+
+--R                \|2 \|10  + 4x\|2           \|2 \|10  - 4x\|2
+--R        - atanh(------------------) + atanh(------------------)
+--R                         2                           2
+--R   (2)  -------------------------------------------------------
+--R                                   +-+
+--R                                  \|2
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 1718
+t0:=(1-2*x^2)/(1+b*x^2+4*x^4)
+--R 
+--R
+--R               2
+--R           - 2x  + 1
+--R   (1)  --------------
+--R          4      2
+--R        4x  + b x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 76
+
+--S 77 of 1718
+r0:=-1/2*log(1+2*x^2-x*sqrt(4-b))/sqrt(4-b)+_
+   1/2*log(1+2*x^2+x*sqrt(4-b))/sqrt(4-b)
+--R 
+--R
+--R              +-------+     2                +-------+     2
+--R        log(x\|- b + 4  + 2x  + 1) - log(- x\|- b + 4  + 2x  + 1)
+--R   (2)  ---------------------------------------------------------
+--R                                 +-------+
+--R                               2\|- b + 4
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 1718
+t0:=(1-2*x^2)/(1+6*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 6x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 79
+
+--S 80 of 1718
+r0:=atan(2*x/sqrt(3-sqrt(5)))/sqrt(2)-atan(2*x/sqrt(3+sqrt(5)))/sqrt(2)
+--R 
+--R
+--R                          +--------+                      +----------+
+--R                +-+       | +-+                 +-+       |   +-+
+--R             (x\|5  - 3x)\|\|5  + 3          (x\|5  + 3x)\|- \|5  + 3
+--R        atan(-----------------------) + atan(-------------------------)
+--R                        2                                2
+--R   (2)  ---------------------------------------------------------------
+--R                                       +-+
+--R                                      \|2
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                    +--------+
+--R           +-+ +-+      2      +-+  | +-+
+--R       (- \|2 \|5  + (4x  + 3)\|2 )\|\|5  + 3
+--R     + 
+--R                                      +----------+
+--R           +-+ +-+        2      +-+  |   +-+          2
+--R       (- \|2 \|5  + (- 4x  - 3)\|2 )\|- \|5  + 3  - 8x  + 4
+--R  /
+--R        4      2
+--R     16x  + 24x  + 4
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 1718
+t0:=(1-2*x^2)/(1+5*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 82
+
+--S 83 of 1718
+r0:=-atan(x)+atan(2*x)
+--R 
+--R
+--R        3atan(2x) - %pi
+--R   (2)  ---------------
+--R               3
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R             1
+--R   (3)  - ------
+--R           2
+--R          x  + 1
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 1718
+t0:=(1-2*x^2)/(1+4*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 85
+
+--S 86 of 1718
+r0:=x/(1+2*x^2)
+--R 
+--R
+--R           x
+--R   (2)  -------
+--R          2
+--R        2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 86
+
+--S 87 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 1718
+t0:=(1-2*x^2)/(1+3*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 88
+
+--S 89 of 1718
+r0:=-1/2*log(1-x+2*x^2)+1/2*log(1+x+2*x^2)
+--R 
+--R
+--R              2                  2
+--R        log(2x  + x + 1) - log(2x  - x + 1)
+--R   (2)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 1718
+t0:=(1-2*x^2)/(1+2*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 91
+
+--S 92 of 1718
+r0:=-1/2*log(1+2*x^2-x*sqrt(2))/sqrt(2)+1/2*log(1+2*x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R              +-+     2                +-+     2
+--R        log(x\|2  + 2x  + 1) - log(- x\|2  + 2x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            2\|2
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 1718
+t0:=(1-2*x^2)/(1+x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  ------------
+--R          4    2
+--R        4x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 94
+
+--S 95 of 1718
+r0:=-1/2*log(1+2*x^2-x*sqrt(3))/sqrt(3)+1/2*log(1+2*x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R              +-+     2                +-+     2
+--R        log(x\|3  + 2x  + 1) - log(- x\|3  + 2x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            2\|3
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 1718
+t0:=(1-2*x^2)/(1+4*x^4)
+--R 
+--R
+--R            2
+--R        - 2x  + 1
+--R   (1)  ---------
+--R           4
+--R         4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 97
+
+--S 98 of 1718
+r0:=-1/4*log(1-2*x+2*x^2)+1/4*log(1+2*x+2*x^2)
+--R 
+--R
+--R              2                   2
+--R        log(2x  + 2x + 1) - log(2x  - 2x + 1)
+--R   (2)  -------------------------------------
+--R                          4
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 1718
+t0:=(1-2*x^2)/(1-x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  ------------
+--R          4    2
+--R        4x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 100
+
+--S 101 of 1718
+r0:=-1/2*log(1+2*x^2-x*sqrt(5))/sqrt(5)+1/2*log(1+2*x^2+x*sqrt(5))/sqrt(5)
+--R 
+--R
+--R              +-+     2                +-+     2
+--R        log(x\|5  + 2x  + 1) - log(- x\|5  + 2x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            2\|5
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 1718
+t0:=(1-2*x^2)/(1-2*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 103
+
+--S 104 of 1718
+r0:=-1/2*log(1+2*x^2-x*sqrt(6))/sqrt(6)+1/2*log(1+2*x^2+x*sqrt(6))/sqrt(6)
+--R 
+--R
+--R              +-+     2                +-+     2
+--R        log(x\|6  + 2x  + 1) - log(- x\|6  + 2x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            2\|6
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 1718
+t0:=(1-2*x^2)/(1-3*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 106
+
+--S 107 of 1718
+r0:=-1/2*log(1+2*x^2-x*sqrt(7))/sqrt(7)+1/2*log(1+2*x^2+x*sqrt(7))/sqrt(7)
+--R 
+--R
+--R              +-+     2                +-+     2
+--R        log(x\|7  + 2x  + 1) - log(- x\|7  + 2x  + 1)
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                            2\|7
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 1718
+t0:=(1-2*x^2)/(1-4*x^2+4*x^4)
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R            2
+--R          2x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 109
+
+--S 110 of 1718
+r0:=atanh(x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R                +-+
+--R        atanh(x\|2 )
+--R   (2)  ------------
+--R             +-+
+--R            \|2
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 1718
+t0:=(1-2*x^2)/(1-5*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 112
+
+--S 113 of 1718
+r0:=-1/6*log(1-2*x)-1/6*log(1-x)+1/6*log(1+x)+1/6*log(1+2*x)
+--R 
+--R
+--R        log(2x + 1) + log(x + 1) - log(- x + 1) - log(- 2x + 1)
+--R   (2)  -------------------------------------------------------
+--R                                   6
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 1718
+t0:=(1-2*x^2)/(1-6*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 6x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 115
+
+--S 116 of 1718
+r0:=-atanh((-4*x+sqrt(2))/sqrt(10))/sqrt(10)+_
+   atanh((4*x+sqrt(2))/sqrt(10))/sqrt(10)
+--R 
+--R
+--R                +-+       +--+            +-+       +--+
+--R              (\|2  + 4x)\|10           (\|2  - 4x)\|10
+--R        atanh(----------------) - atanh(----------------)
+--R                     10                        10
+--R   (2)  -------------------------------------------------
+--R                               +--+
+--R                              \|10
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 1718
+t0:=x^m*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R              6               4        2  m
+--R   (1)  (B c x  + (A c + B b)x  + A b x )x
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 1718
+r0:=A*b*x^(3+m)/(3+m)+(b*B+A*c)*x^(5+m)/(5+m)+B*c*x^(7+m)/(7+m)
+--R 
+--R
+--R   (2)
+--R             2                   m + 7
+--R       (B c m  + 8B c m + 15B c)x
+--R     + 
+--R                    2                                     m + 5
+--R       ((A c + B b)m  + (10A c + 10B b)m + 21A c + 21B b)x
+--R     + 
+--R             2                    m + 3
+--R       (A b m  + 12A b m + 35A b)x
+--R  /
+--R      3      2
+--R     m  + 15m  + 71m + 105
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 1718
+t0:=x^2*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R             8               6        4
+--R   (1)  B c x  + (A c + B b)x  + A b x
+--R                                                    Type: Polynomial(Integer)
+--E 121
+
+--S 122 of 1718
+r0:=1/5*A*b*x^5+1/7*(b*B+A*c)*x^7+1/9*B*c*x^9
+--R 
+--R
+--R        1      9    1       1      7   1      5
+--R   (2)  - B c x  + (- A c + - B b)x  + - A b x
+--R        9           7       7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 122
+
+--S 123 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 1718
+t0:=x*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R             7               5        3
+--R   (1)  B c x  + (A c + B b)x  + A b x
+--R                                                    Type: Polynomial(Integer)
+--E 124
+
+--S 125 of 1718
+r0:=1/4*A*b*x^4+1/6*(b*B+A*c)*x^6+1/8*B*c*x^8
+--R 
+--R
+--R        1      8    1       1      6   1      4
+--R   (2)  - B c x  + (- A c + - B b)x  + - A b x
+--R        8           6       6          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 125
+
+--S 126 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R             6               4        2
+--R   (1)  B c x  + (A c + B b)x  + A b x
+--R                                                    Type: Polynomial(Integer)
+--E 127
+
+--S 128 of 1718
+r0:=1/3*A*b*x^3+1/5*(b*B+A*c)*x^5+1/7*B*c*x^7
+--R 
+--R
+--R        1      7    1       1      5   1      3
+--R   (2)  - B c x  + (- A c + - B b)x  + - A b x
+--R        7           5       5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 128
+
+--S 129 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x
+--R 
+--R
+--R             5               3
+--R   (1)  B c x  + (A c + B b)x  + A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 130
+
+--S 131 of 1718
+r0:=1/2*A*b*x^2+1/4*(b*B+A*c)*x^4+1/6*B*c*x^6
+--R 
+--R
+--R        1      6    1       1      4   1      2
+--R   (2)  - B c x  + (- A c + - B b)x  + - A b x
+--R        6           4       4          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 131
+
+--S 132 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R             4               2
+--R   (1)  B c x  + (A c + B b)x  + A b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 133
+
+--S 134 of 1718
+r0:=A*b*x+1/3*(b*B+A*c)*x^3+1/5*B*c*x^5
+--R 
+--R
+--R        1      5    1       1      3
+--R   (2)  - B c x  + (- A c + - B b)x  + A b x
+--R        5           3       3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 134
+
+--S 135 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^3
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 136
+
+--S 137 of 1718
+r0:=1/2*(b*B+A*c)*x^2+1/4*B*c*x^4+A*b*log(x)
+--R 
+--R
+--R                           4                 2
+--R        4A b log(x) + B c x  + (2A c + 2B b)x
+--R   (2)  --------------------------------------
+--R                           4
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^4
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      2
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 139
+
+--S 140 of 1718
+r0:=-A*b/x+(b*B+A*c)*x+1/3*B*c*x^3
+--R 
+--R
+--R             4                 2
+--R        B c x  + (3A c + 3B b)x  - 3A b
+--R   (2)  -------------------------------
+--R                       3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 140
+
+--S 141 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^5
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      3
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 142
+
+--S 143 of 1718
+r0:=-1/2*A*b/x^2+1/2*B*c*x^2+(b*B+A*c)*log(x)
+--R 
+--R
+--R                      2              4
+--R        (2A c + 2B b)x log(x) + B c x  - A b
+--R   (2)  ------------------------------------
+--R                           2
+--R                         2x
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^6
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      4
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 145
+
+--S 146 of 1718
+r0:=-1/3*A*b/x^3+(-b*B-A*c)/x+B*c*x
+--R 
+--R
+--R             4                 2   1
+--R        B c x  + (- A c - B b)x  - - A b
+--R                                   3
+--R   (2)  --------------------------------
+--R                        3
+--R                       x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 146
+
+--S 147 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^7
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      5
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 148
+
+--S 149 of 1718
+r0:=-1/4*A*b/x^4+1/2*(-b*B-A*c)/x^2+B*c*log(x)
+--R 
+--R
+--R              4                         2
+--R        4B c x log(x) + (- 2A c - 2B b)x  - A b
+--R   (2)  ---------------------------------------
+--R                            4
+--R                          4x
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^8
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      6
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 151
+
+--S 152 of 1718
+r0:=-1/5*A*b/x^5+1/3*(-b*B-A*c)/x^3-B*c/x
+--R 
+--R
+--R               4      1       1      2   1
+--R        - B c x  + (- - A c - - B b)x  - - A b
+--R                      3       3          5
+--R   (2)  --------------------------------------
+--R                           5
+--R                          x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 152
+
+--S 153 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 1718
+t0:=x^m*(A+B*x^2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R            2 10       2           8                2  6      2 4  m
+--R   (1)  (B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )x
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 1718
+r0:=A*b^2*x^(5+m)/(5+m)+b*(b*B+2*A*c)*x^(7+m)/(7+m)+_
+   c*(2*b*B+A*c)*x^(9+m)/(9+m)+B*c^2*x^(11+m)/(11+m)
+--R 
+--R
+--R   (2)
+--R           2 3        2 2         2          2  m + 11
+--R       (B c m  + 21B c m  + 143B c m + 315B c )x
+--R     + 
+--R               2           3         2            2          2
+--R           (A c  + 2B b c)m  + (23A c  + 46B b c)m  + (167A c  + 334B b c)m
+--R         + 
+--R                 2
+--R           385A c  + 770B b c
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                        2  3                   2  2                     2
+--R           (2A b c + B b )m  + (50A b c + 25B b )m  + (398A b c + 199B b )m
+--R         + 
+--R                            2
+--R           990A b c + 495B b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R           2 3        2 2         2          2  m + 5
+--R       (A b m  + 27A b m  + 239A b m + 693A b )x
+--R  /
+--R      4      3       2
+--R     m  + 32m  + 374m  + 1888m + 3465
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R           2 10       2           8                2  6      2 4
+--R   (1)  B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R                                                    Type: Polynomial(Integer)
+--E 157
+
+--S 158 of 1718
+r0:=1/5*A*b^2*x^5+1/7*b*(b*B+2*A*c)*x^7+1/9*c*(2*b*B+A*c)*x^9+1/11*B*c^2*x^11
+--R 
+--R
+--R         1    2 11    1    2   2        9    2         1    2  7   1    2 5
+--R   (2)  -- B c x   + (- A c  + - B b c)x  + (- A b c + - B b )x  + - A b x
+--R        11            9        9             7         7           5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 158
+
+--S 159 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x
+--R 
+--R
+--R           2 9       2           7                2  5      2 3
+--R   (1)  B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 160
+
+--S 161 of 1718
+r0:=1/4*A*b^2*x^4+1/6*b*(b*B+2*A*c)*x^6+1/8*c*(2*b*B+A*c)*x^8+1/10*B*c^2*x^10
+--R 
+--R
+--R         1    2 10    1    2   1        8    1         1    2  6   1    2 4
+--R   (2)  -- B c x   + (- A c  + - B b c)x  + (- A b c + - B b )x  + - A b x
+--R        10            8        4             3         6           4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 161
+
+--S 162 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^2
+--R 
+--R
+--R           2 8       2           6                2  4      2 2
+--R   (1)  B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 163
+
+--S 164 of 1718
+r0:=1/3*A*b^2*x^3+1/5*b*(b*B+2*A*c)*x^5+1/7*c*(2*b*B+A*c)*x^7+1/9*B*c^2*x^9
+--R 
+--R
+--R        1    2 9    1    2   2        7    2         1    2  5   1    2 3
+--R   (2)  - B c x  + (- A c  + - B b c)x  + (- A b c + - B b )x  + - A b x
+--R        9           7        7             5         5           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 164
+
+--S 165 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^3
+--R 
+--R
+--R           2 7       2           5                2  3      2
+--R   (1)  B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 166
+
+--S 167 of 1718
+r0:=-1/6*(b*B-A*c)*(b+c*x^2)^3/c^2+1/8*B*(b+c*x^2)^4/c^2
+--R 
+--R
+--R   (2)
+--R       1    4 8    1    4   1      3  6    1      3   1    2 2  4   1    2 2 2
+--R       - B c x  + (- A c  + - B b c )x  + (- A b c  + - B b c )x  + - A b c x
+--R       8           6        3              2          4             2
+--R     + 
+--R       1    3     1    4
+--R       - A b c - -- B b
+--R       6         24
+--R  /
+--R      2
+--R     c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 167
+
+--S 168 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^4
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R   (1)  B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 169
+
+--S 170 of 1718
+r0:=A*b^2*x+1/3*b*(b*B+2*A*c)*x^3+1/5*c*(2*b*B+A*c)*x^5+1/7*B*c^2*x^7
+--R 
+--R
+--R        1    2 7    1    2   2        5    2         1    2  3      2
+--R   (2)  - B c x  + (- A c  + - B b c)x  + (- A b c + - B b )x  + A b x
+--R        7           5        5             3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 170
+
+--S 171 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^5
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 172
+
+--S 173 of 1718
+r0:=A*b*c*x^2+1/4*A*c^2*x^4+1/6*B*(b+c*x^2)^3/c+A*b^2*log(x)
+--R 
+--R
+--R   (2)
+--R            2               3 6        3         2  4           2       2   2
+--R       12A b c log(x) + 2B c x  + (3A c  + 6B b c )x  + (12A b c  + 6B b c)x
+--R     + 
+--R           3
+--R       2B b
+--R  /
+--R     12c
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^6
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   2
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 175
+
+--S 176 of 1718
+r0:=-A*b^2/x+b*(b*B+2*A*c)*x+1/3*c*(2*b*B+A*c)*x^3+1/5*B*c^2*x^5
+--R 
+--R
+--R            2 6        2            4                   2  2        2
+--R        3B c x  + (5A c  + 10B b c)x  + (30A b c + 15B b )x  - 15A b
+--R   (2)  -------------------------------------------------------------
+--R                                     15x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 176
+
+--S 177 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^7
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   3
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 178
+
+--S 179 of 1718
+r0:=-1/2*A*b^2/x^2+1/2*c*(2*b*B+A*c)*x^2+1/4*B*c^2*x^4+b*(b*B+2*A*c)*log(x)
+--R 
+--R
+--R                      2  2            2 6        2           4       2
+--R        (8A b c + 4B b )x log(x) + B c x  + (2A c  + 4B b c)x  - 2A b
+--R   (2)  --------------------------------------------------------------
+--R                                        2
+--R                                      4x
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^8
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   4
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 181
+
+--S 182 of 1718
+r0:=-1/3*A*b^2/x^3-b*(b*B+2*A*c)/x+c*(2*b*B+A*c)*x+1/3*B*c^2*x^3
+--R 
+--R
+--R        1    2 6       2           4                  2  2   1    2
+--R        - B c x  + (A c  + 2B b c)x  + (- 2A b c - B b )x  - - A b
+--R        3                                                    3
+--R   (2)  -----------------------------------------------------------
+--R                                      3
+--R                                     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 182
+
+--S 183 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^9
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   5
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 184
+
+--S 185 of 1718
+r0:=-1/4*A*b^2/x^4-1/2*b*(b*B+2*A*c)/x^2+1/2*B*c^2*x^2+c*(2*b*B+A*c)*log(x)
+--R 
+--R
+--R             2           4             2 6                   2  2      2
+--R        (4A c  + 8B b c)x log(x) + 2B c x  + (- 4A b c - 2B b )x  - A b
+--R   (2)  ----------------------------------------------------------------
+--R                                         4
+--R                                       4x
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^10
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   6
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 187
+
+--S 188 of 1718
+r0:=-1/5*A*b^2/x^5-1/3*b*(b*B+2*A*c)/x^3-c*(2*b*B+A*c)/x+B*c^2*x
+--R 
+--R
+--R           2 6         2           4      2         1    2  2   1    2
+--R        B c x  + (- A c  - 2B b c)x  + (- - A b c - - B b )x  - - A b
+--R                                          3         3           5
+--R   (2)  --------------------------------------------------------------
+--R                                       5
+--R                                      x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 188
+
+--S 189 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^11
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   7
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 190
+
+--S 191 of 1718
+r0:=-1/4*b^2*B/x^4-b*B*c/x^2-1/6*A*(b+c*x^2)^3/(b*x^6)+B*c^2*log(x)
+--R 
+--R
+--R   (2)
+--R              2 6             3 6            2        2   4
+--R       12B b c x log(x) - 2A c x  + (- 6A b c  - 12B b c)x
+--R     + 
+--R              2        3  2       3
+--R       (- 6A b c - 3B b )x  - 2A b
+--R  /
+--R          6
+--R     12b x
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^12
+--R 
+--R
+--R           2 6       2           4                2  2      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b
+--R   (1)  -----------------------------------------------------
+--R                                   8
+--R                                  x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 193
+
+--S 194 of 1718
+r0:=-1/7*A*b^2/x^7-1/5*b*(b*B+2*A*c)/x^5-1/3*c*(2*b*B+A*c)/x^3-B*c^2/x
+--R 
+--R
+--R             2 6      1    2   2        4      2         1    2  2   1    2
+--R        - B c x  + (- - A c  - - B b c)x  + (- - A b c - - B b )x  - - A b
+--R                      3        3               5         5           7
+--R   (2)  -------------------------------------------------------------------
+--R                                          7
+--R                                         x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 194
+
+--S 195 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 1718
+t0:=x^m*(A+B*x^2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R          3 14       3         2  12          2       2   10        2       3  8
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x   + (3A b c + B b )x
+--R     + 
+--R          3 6
+--R       A b x
+--R  *
+--R      m
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1718
+r0:=A*b^3*x^(7+m)/(7+m)+b^2*(b*B+3*A*c)*x^(9+m)/(9+m)+3*b*c*(b*B+A*c)*_
+   x^(11+m)/(11+m)+c^2*(3*b*B+A*c)*x^(13+m)/(13+m)+B*c^3*x^(15+m)/(15+m)
+--R 
+--R
+--R   (2)
+--R           3 4        3 3         3 2          3           3  m + 15
+--R       (B c m  + 40B c m  + 590B c m  + 3800B c m + 9009B c )x
+--R     + 
+--R               3         2  4         3           2  3
+--R           (A c  + 3B b c )m  + (42A c  + 126B b c )m
+--R         + 
+--R                  3            2  2           3             2             3
+--R           (644A c  + 1932B b c )m  + (4278A c  + 12834B b c )m + 10395A c
+--R         + 
+--R                     2
+--R           31185B b c
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                  2       2   4            2         2   3
+--R           (3A b c  + 3B b c)m  + (132A b c  + 132B b c)m
+--R         + 
+--R                     2          2   2              2           2
+--R           (2118A b c  + 2118B b c)m  + (14652A b c  + 14652B b c)m
+--R         + 
+--R                     2           2
+--R           36855A b c  + 36855B b c
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                2       3  4          2         3  3           2          3  2
+--R           (3A b c + B b )m  + (138A b c + 46B b )m  + (2328A b c + 776B b )m
+--R         + 
+--R                    2           3             2            3
+--R           (16998A b c + 5666B b )m + 45045A b c + 15015B b
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R           3 4        3 3         3 2          3            3  m + 7
+--R       (A b m  + 48A b m  + 854A b m  + 6672A b m + 19305A b )x
+--R  /
+--R      5      4        3         2
+--R     m  + 55m  + 1190m  + 12650m  + 66009m + 135135
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^2
+--R 
+--R
+--R   (1)
+--R        3 12       3         2  10          2       2   8        2       3  6
+--R     B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R   + 
+--R        3 4
+--R     A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 199
+
+--S 200 of 1718
+r0:=1/5*A*b^3*x^5+1/7*b^2*(b*B+3*A*c)*x^7+1/3*b*c*(b*B+A*c)*x^9+_
+   1/11*c^2*(3*b*B+A*c)*x^11+1/13*B*c^3*x^13
+--R 
+--R
+--R   (2)
+--R      1    3 13     1    3    3      2  11    1      2   1    2   9
+--R     -- B c x   + (-- A c  + -- B b c )x   + (- A b c  + - B b c)x
+--R     13            11        11               3          3
+--R   + 
+--R      3    2    1    3  7   1    3 5
+--R     (- A b c + - B b )x  + - A b x
+--R      7         7           5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 200
+
+--S 201 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^3
+--R 
+--R
+--R   (1)
+--R        3 11       3         2  9          2       2   7        2       3  5
+--R     B c x   + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R   + 
+--R        3 3
+--R     A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 202
+
+--S 203 of 1718
+r0:=1/8*b*(b*B-A*c)*(b+c*x^2)^4/c^3-1/10*(2*b*B-A*c)*(b+c*x^2)^5/c^3+_
+   1/12*B*(b+c*x^2)^6/c^3
+--R 
+--R
+--R   (2)
+--R        1    6 12     1    6    3      5  10    3      5   3    2 4  8
+--R       -- B c x   + (-- A c  + -- B b c )x   + (- A b c  + - B b c )x
+--R       12            10        10               8          8
+--R     + 
+--R        1    2 4   1    3 3  6   1    3 3 4    1    5     1     6
+--R       (- A b c  + - B b c )x  + - A b c x  - -- A b c + --- B b
+--R        2          6             4            40         120
+--R  /
+--R      3
+--R     c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 203
+
+--S 204 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^4
+--R 
+--R
+--R   (1)
+--R        3 10       3         2  8          2       2   6        2       3  4
+--R     B c x   + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R   + 
+--R        3 2
+--R     A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 205
+
+--S 206 of 1718
+r0:=1/3*A*b^3*x^3+1/5*b^2*(b*B+3*A*c)*x^5+3/7*b*c*(b*B+A*c)*x^7+_
+   1/9*c^2*(3*b*B+A*c)*x^9+1/11*B*c^3*x^11
+--R 
+--R
+--R   (2)
+--R      1    3 11    1    3   1      2  9    3      2   3    2   7
+--R     -- B c x   + (- A c  + - B b c )x  + (- A b c  + - B b c)x
+--R     11            9        3              7          7
+--R   + 
+--R      3    2    1    3  5   1    3 3
+--R     (- A b c + - B b )x  + - A b x
+--R      5         5           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 206
+
+--S 207 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^5
+--R 
+--R
+--R   (1)
+--R        3 9       3         2  7          2       2   5        2       3  3
+--R     B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R   + 
+--R        3
+--R     A b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 208
+
+--S 209 of 1718
+r0:=-1/8*(b*B-A*c)*(b+c*x^2)^4/c^2+1/10*B*(b+c*x^2)^5/c^2
+--R 
+--R
+--R   (2)
+--R        1    5 10    1    5   3      4  8    1      4   1    2 3  6
+--R       -- B c x   + (- A c  + - B b c )x  + (- A b c  + - B b c )x
+--R       10            8        8              2          2
+--R     + 
+--R        3    2 3   1    3 2  4   1    3 2 2   1    4     1    5
+--R       (- A b c  + - B b c )x  + - A b c x  + - A b c - -- B b
+--R        4          4             2            8         40
+--R  /
+--R      2
+--R     c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 209
+
+--S 210 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^6
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 211
+
+--S 212 of 1718
+r0:=A*b^3*x+1/3*b^2*(b*B+3*A*c)*x^3+3/5*b*c*(b*B+A*c)*x^5+_
+   1/7*c^2*(3*b*B+A*c)*x^7+1/9*B*c^3*x^9
+--R 
+--R
+--R   (2)
+--R     1    3 9    1    3   3      2  7    3      2   3    2   5
+--R     - B c x  + (- A c  + - B b c )x  + (- A b c  + - B b c)x
+--R     9           7        7              5          5
+--R   + 
+--R         2    1    3  3      3
+--R     (A b c + - B b )x  + A b x
+--R              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 212
+
+--S 213 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^7
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 214
+
+--S 215 of 1718
+r0:=3/2*A*b^2*c*x^2+3/4*A*b*c^2*x^4+1/6*A*c^3*x^6+1/8*B*(b+c*x^2)^4/c+_
+   A*b^3*log(x)
+--R 
+--R
+--R   (2)
+--R            3               4 8        4          3  6           3        2 2  4
+--R       24A b c log(x) + 3B c x  + (4A c  + 12B b c )x  + (18A b c  + 18B b c )x
+--R     + 
+--R             2 2        3   2       4
+--R       (36A b c  + 12B b c)x  + 3B b
+--R  /
+--R     24c
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^8
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          2
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 217
+
+--S 218 of 1718
+r0:=-A*b^3/x+b^2*(b*B+3*A*c)*x+b*c*(b*B+A*c)*x^3+1/5*c^2*(3*b*B+A*c)*x^5+_
+   1/7*B*c^3*x^7
+--R 
+--R
+--R   (2)
+--R           3 8        3          2  6           2        2   4
+--R       5B c x  + (7A c  + 21B b c )x  + (35A b c  + 35B b c)x
+--R     + 
+--R              2         3  2        3
+--R       (105A b c + 35B b )x  - 35A b
+--R  /
+--R     35x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 218
+
+--S 219 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^9
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          3
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 220
+
+--S 221 of 1718
+r0:=-1/2*A*b^3/x^2+3/2*b*c*(b*B+A*c)*x^2+1/4*c^2*(3*b*B+A*c)*x^4+_
+   1/6*B*c^3*x^6+b^2*(b*B+3*A*c)*log(x)
+--R 
+--R
+--R   (2)
+--R             2         3  2             3 8        3         2  6
+--R       (36A b c + 12B b )x log(x) + 2B c x  + (3A c  + 9B b c )x
+--R     + 
+--R               2        2   4       3
+--R       (18A b c  + 18B b c)x  - 6A b
+--R  /
+--R        2
+--R     12x
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^10
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          4
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 223
+
+--S 224 of 1718
+r0:=-1/3*A*b^3/x^3-b^2*(b*B+3*A*c)/x+3*b*c*(b*B+A*c)*x+_
+   1/3*c^2*(3*b*B+A*c)*x^3+1/5*B*c^3*x^5
+--R 
+--R
+--R   (2)
+--R       1    3 8    1    3        2  6          2       2   4
+--R       - B c x  + (- A c  + B b c )x  + (3A b c  + 3B b c)x
+--R       5           3
+--R     + 
+--R              2       3  2   1    3
+--R       (- 3A b c - B b )x  - - A b
+--R                             3
+--R  /
+--R      3
+--R     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 224
+
+--S 225 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^11
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          5
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 226
+
+--S 227 of 1718
+r0:=-1/4*A*b^3/x^4-1/2*b^2*(b*B+3*A*c)/x^2+1/2*c^2*(3*b*B+A*c)*x^2+_
+   1/4*B*c^3*x^4+3*b*c*(b*B+A*c)*log(x)
+--R 
+--R
+--R   (2)
+--R               2        2   4            3 8        3         2  6
+--R       (12A b c  + 12B b c)x log(x) + B c x  + (2A c  + 6B b c )x
+--R     + 
+--R              2        3  2      3
+--R       (- 6A b c - 2B b )x  - A b
+--R  /
+--R       4
+--R     4x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^12
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          6
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 229
+
+--S 230 of 1718
+r0:=-1/5*A*b^3/x^5-1/3*b^2*(b*B+3*A*c)/x^3-3*b*c*(b*B+A*c)/x+_
+   c^2*(3*b*B+A*c)*x+1/3*B*c^3*x^3
+--R 
+--R
+--R   (2)
+--R       1    3 8       3         2  6            2       2   4
+--R       - B c x  + (A c  + 3B b c )x  + (- 3A b c  - 3B b c)x
+--R       3
+--R     + 
+--R             2    1    3  2   1    3
+--R       (- A b c - - B b )x  - - A b
+--R                  3           5
+--R  /
+--R      5
+--R     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 230
+
+--S 231 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^13
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          7
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 232
+
+--S 233 of 1718
+r0:=-1/6*A*b^3/x^6-1/4*b^2*(b*B+3*A*c)/x^4-3/2*b*c*(b*B+A*c)/x^2+_
+   1/2*B*c^3*x^2+c^2*(3*b*B+A*c)*log(x)
+--R 
+--R
+--R   (2)
+--R             3          2  6             3 8             2        2   4
+--R       (12A c  + 36B b c )x log(x) + 6B c x  + (- 18A b c  - 18B b c)x
+--R     + 
+--R              2        3  2       3
+--R       (- 9A b c - 3B b )x  - 2A b
+--R  /
+--R        6
+--R     12x
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^14
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          8
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 235
+
+--S 236 of 1718
+r0:=-1/7*A*b^3/x^7-1/5*b^2*(b*B+3*A*c)/x^5-b*c*(b*B+A*c)/x^3-_
+   c^2*(3*b*B+A*c)/x+B*c^3*x
+--R 
+--R
+--R   (2)
+--R          3 8         3         2  6           2      2   4
+--R       B c x  + (- A c  - 3B b c )x  + (- A b c  - B b c)x
+--R     + 
+--R          3    2    1    3  2   1    3
+--R       (- - A b c - - B b )x  - - A b
+--R          5         5           7
+--R  /
+--R      7
+--R     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 236
+
+--S 237 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^15
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                          9
+--R                                         x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 238
+
+--S 239 of 1718
+r0:=-1/6*b^3*B/x^6-3/4*b^2*B*c/x^4-3/2*b*B*c^2/x^2-_
+   1/8*A*(b+c*x^2)^4/(b*x^8)+B*c^3*log(x)
+--R 
+--R
+--R   (2)
+--R              3 8             4 8             3        2 2  6
+--R       24B b c x log(x) - 3A c x  + (- 12A b c  - 36B b c )x
+--R     + 
+--R               2 2        3   4           3        4  2       4
+--R       (- 18A b c  - 18B b c)x  + (- 12A b c - 4B b )x  - 3A b
+--R  /
+--R          8
+--R     24b x
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^16
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                         10
+--R                                        x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 241
+
+--S 242 of 1718
+r0:=-1/9*A*b^3/x^9-1/7*b^2*(b*B+3*A*c)/x^7-3/5*b*c*(b*B+A*c)/x^5-_
+   1/3*c^2*(3*b*B+A*c)/x^3-B*c^3/x
+--R 
+--R
+--R   (2)
+--R            3 8      1    3        2  6      3      2   3    2   4
+--R       - B c x  + (- - A c  - B b c )x  + (- - A b c  - - B b c)x
+--R                     3                       5          5
+--R     + 
+--R          3    2    1    3  2   1    3
+--R       (- - A b c - - B b )x  - - A b
+--R          7         7           9
+--R  /
+--R      9
+--R     x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 242
+
+--S 243 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^17
+--R 
+--R
+--R   (1)
+--R      3 8       3         2  6          2       2   4        2       3  2      3
+--R   B c x  + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x  + A b
+--R   -----------------------------------------------------------------------------
+--R                                         11
+--R                                        x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 244
+
+--S 245 of 1718
+r0:=-1/10*A*(b+c*x^2)^4/(b*x^10)-1/40*(5*b*B-A*c)*(b+c*x^2)^4/(b^2*x^8)
+--R 
+--R
+--R   (2)
+--R         1    5   1      4  10   1    2 3 8      1    2 3   3    3 2  6
+--R       (-- A c  - - B b c )x   - - B b c x  + (- - A b c  - - B b c )x
+--R        40        8              2               4          4
+--R     + 
+--R          1    3 2   1    4   4      3    4    1    5  2    1    5
+--R       (- - A b c  - - B b c)x  + (- - A b c - - B b )x  - -- A b
+--R          2          2               8         8           10
+--R  /
+--R      2 10
+--R     b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 245
+
+--S 246 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 1718
+t0:=x^10*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           10      8
+--R        B x   + A x
+--R   (1)  ------------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 247
+
+--S 248 of 1718
+r0:=b^3*(b*B-A*c)*x/c^5-1/3*b^2*(b*B-A*c)*x^3/c^4+1/5*b*(b*B-A*c)*x^5/c^3-_
+   1/7*(b*B-A*c)*x^7/c^2+1/9*B*x^9/c-b^(7/2)*(b*B-A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/c^(11/2)
+--R 
+--R
+--R   (2)
+--R                                      +-+
+--R              3          4  +-+     x\|c
+--R       (315A b c - 315B b )\|b atan(-----)
+--R                                      +-+
+--R                                     \|b
+--R     + 
+--R                4 9         4          3  7             3        2 2  5
+--R           35B c x  + (45A c  - 45B b c )x  + (- 63A b c  + 63B b c )x
+--R         + 
+--R                  2 2         3   3            3          4
+--R           (105A b c  - 105B b c)x  + (- 315A b c + 315B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R         5 +-+
+--R     315c \|c
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 1718
+t0:=x^9*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           9      7
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 250
+
+--S 251 of 1718
+r0:=-1/2*b^2*(b*B-A*c)*x^2/c^4+1/4*b*(b*B-A*c)*x^4/c^3-_
+   1/6*(b*B-A*c)*x^6/c^2+1/8*B*x^8/c+1/2*b^3*(b*B-A*c)*log(b+c*x^2)/c^5
+--R 
+--R
+--R   (2)
+--R               3         4        2            4 8        4         3  6
+--R       (- 12A b c + 12B b )log(c x  + b) + 3B c x  + (4A c  - 4B b c )x
+--R     + 
+--R                3       2 2  4         2 2        3   2
+--R       (- 6A b c  + 6B b c )x  + (12A b c  - 12B b c)x
+--R  /
+--R        5
+--R     24c
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 1718
+t0:=x^8*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           8      6
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 253
+
+--S 254 of 1718
+r0:=-b^2*(b*B-A*c)*x/c^4+1/3*b*(b*B-A*c)*x^3/c^3-1/5*(b*B-A*c)*x^5/c^2+_
+   1/7*B*x^7/c+b^(5/2)*(b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/c^(9/2)
+--R 
+--R
+--R   (2)
+--R                                        +-+
+--R                2          3  +-+     x\|c
+--R       (- 105A b c + 105B b )\|b atan(-----)
+--R                                        +-+
+--R                                       \|b
+--R     + 
+--R                3 7         3          2  5             2        2   3
+--R           15B c x  + (21A c  - 21B b c )x  + (- 35A b c  + 35B b c)x
+--R         + 
+--R                  2          3
+--R           (105A b c - 105B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R         4 +-+
+--R     105c \|c
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 1718
+t0:=x^7*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           7      5
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 256
+
+--S 257 of 1718
+r0:=1/2*b*(b*B-A*c)*x^2/c^3-1/4*(b*B-A*c)*x^4/c^2+1/6*B*x^6/c-_
+   1/2*b^2*(b*B-A*c)*log(b+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R            2        3        2            3 6        3         2  4
+--R       (6A b c - 6B b )log(c x  + b) + 2B c x  + (3A c  - 3B b c )x
+--R     + 
+--R                2       2   2
+--R       (- 6A b c  + 6B b c)x
+--R  /
+--R        4
+--R     12c
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 1718
+t0:=x^6*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           6      4
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 259
+
+--S 260 of 1718
+r0:=b*(b*B-A*c)*x/c^3-1/3*(b*B-A*c)*x^3/c^2+1/5*B*x^5/c-_
+   b^(3/2)*(b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/c^(7/2)
+--R 
+--R
+--R   (2)
+--R                                    +-+
+--R                       2  +-+     x\|c
+--R       (15A b c - 15B b )\|b atan(-----)
+--R                                    +-+
+--R                                   \|b
+--R     + 
+--R            2 5        2           3                     2    +-+
+--R       (3B c x  + (5A c  - 5B b c)x  + (- 15A b c + 15B b )x)\|c
+--R  /
+--R        3 +-+
+--R     15c \|c
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 1718
+t0:=x^5*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           5      3
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 262
+
+--S 263 of 1718
+r0:=-1/2*(b*B-A*c)*x^2/c^2+1/4*B*x^4/c+1/2*b*(b*B-A*c)*log(b+c*x^2)/c^3
+--R 
+--R
+--R                        2        2           2 4        2           2
+--R        (- 2A b c + 2B b )log(c x  + b) + B c x  + (2A c  - 2B b c)x
+--R   (2)  -------------------------------------------------------------
+--R                                       3
+--R                                     4c
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 1718
+t0:=x^4*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           4      2
+--R        B x  + A x
+--R   (1)  -----------
+--R             2
+--R          c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 265
+
+--S 266 of 1718
+r0:=-(b*B-A*c)*x/c^2+1/3*B*x^3/c+(b*B-A*c)*atan(x*sqrt(c)/sqrt(b))*_
+   sqrt(b)/c^(5/2)
+--R 
+--R
+--R                                  +-+
+--R                        +-+     x\|c           3                   +-+
+--R        (- 3A c + 3B b)\|b atan(-----) + (B c x  + (3A c - 3B b)x)\|c
+--R                                  +-+
+--R                                 \|b
+--R   (2)  --------------------------------------------------------------
+--R                                      2 +-+
+--R                                    3c \|c
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 1718
+t0:=x^3*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           3
+--R        B x  + A x
+--R   (1)  ----------
+--R            2
+--R         c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 268
+
+--S 269 of 1718
+r0:=1/2*B*x^2/c-1/2*(b*B-A*c)*log(b+c*x^2)/c^2
+--R 
+--R
+--R                          2             2
+--R        (A c - B b)log(c x  + b) + B c x
+--R   (2)  ---------------------------------
+--R                         2
+--R                       2c
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 1718
+t0:=x^2*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           2
+--R        B x  + A
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 271
+
+--S 272 of 1718
+r0:=B*x/c-(b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/(c^(3/2)*sqrt(b))
+--R 
+--R
+--R                          +-+
+--R                        x\|c         +-+ +-+
+--R        (A c - B b)atan(-----) + B x\|b \|c
+--R                          +-+
+--R                         \|b
+--R   (2)  ------------------------------------
+--R                        +-+ +-+
+--R                      c\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 1718
+t0:=x*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            2
+--R         B x  + A
+--R   (1)  ----------
+--R           3
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 274
+
+--S 275 of 1718
+r0:=A*log(x)/b+1/2*(b*B-A*c)*log(b+c*x^2)/(b*c)
+--R 
+--R
+--R                            2
+--R        (- A c + B b)log(c x  + b) + 2A c log(x)
+--R   (2)  ----------------------------------------
+--R                          2b c
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 1718
+t0:=(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           4      2
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 277
+
+--S 278 of 1718
+r0:=-A/(b*x)+(b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/(b^(3/2)*sqrt(c))
+--R 
+--R
+--R                              +-+
+--R                            x\|c       +-+ +-+
+--R        (- A c + B b)x atan(-----) - A\|b \|c
+--R                              +-+
+--R                             \|b
+--R   (2)  --------------------------------------
+--R                          +-+ +-+
+--R                      b x\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 1718
+t0:=(A+B*x^2)/(b*x^2-c*x^4)
+--R 
+--R
+--R              2
+--R         - B x  - A
+--R   (1)  -----------
+--R           4      2
+--R        c x  - b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 280
+
+--S 281 of 1718
+r0:=-A/(b*x)+(b*B+A*c)*atanh(x*sqrt(c)/sqrt(b))/(b^(3/2)*sqrt(c))
+--R 
+--R
+--R                             +-+
+--R                           x\|c       +-+ +-+
+--R        (A c + B b)x atanh(-----) - A\|b \|c
+--R                             +-+
+--R                            \|b
+--R   (2)  -------------------------------------
+--R                         +-+ +-+
+--R                     b x\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 1718
+t0:=(A+B*x^2)/(x*(b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           5      3
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 283
+
+--S 284 of 1718
+r0:=-1/2*A/(b*x^2)+(b*B-A*c)*log(x)/b^2-1/2*(b*B-A*c)*log(b+c*x^2)/b^2
+--R 
+--R
+--R                    2       2                        2
+--R        (A c - B b)x log(c x  + b) + (- 2A c + 2B b)x log(x) - A b
+--R   (2)  ----------------------------------------------------------
+--R                                     2 2
+--R                                   2b x
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 1718
+t0:=(A+B*x^2)/(x^2*(b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           6      4
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 286
+
+--S 287 of 1718
+r0:=-1/3*A/(b*x^3)+(-b*B+A*c)/(b^2*x)-(b*B-A*c)*_
+   atan(x*sqrt(c)/sqrt(b))*sqrt(c)/b^(5/2)
+--R 
+--R
+--R                                  +-+
+--R                      3 +-+     x\|c                    2        +-+
+--R        (3A c - 3B b)x \|c atan(-----) + ((3A c - 3B b)x  - A b)\|b
+--R                                  +-+
+--R                                 \|b
+--R   (2)  ------------------------------------------------------------
+--R                                    2 3 +-+
+--R                                  3b x \|b
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 1718
+t0:=(A+B*x^2)/(x^3*(b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           7      5
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 289
+
+--S 290 of 1718
+r0:=-1/4*A/(b*x^4)+1/2*(-b*B+A*c)/(b^2*x^2)-c*(b*B-A*c)*log(x)/b^3+_
+   1/2*c*(b*B-A*c)*log(b+c*x^2)/b^3
+--R 
+--R
+--R   (2)
+--R              2           4       2             2           4
+--R       (- 2A c  + 2B b c)x log(c x  + b) + (4A c  - 4B b c)x log(x)
+--R     + 
+--R                     2  2      2
+--R       (2A b c - 2B b )x  - A b
+--R  /
+--R       3 4
+--R     4b x
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 1718
+t0:=(A+B*x^2)/(x^4*(b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           8      6
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 292
+
+--S 293 of 1718
+r0:=-1/5*A/(b*x^5)+1/3*(-b*B+A*c)/(b^2*x^3)+c*(b*B-A*c)/(b^3*x)+c^(3/2)*_
+   (b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/b^(7/2)
+--R 
+--R
+--R   (2)
+--R                                        +-+
+--R               2            5 +-+     x\|c
+--R       (- 15A c  + 15B b c)x \|c atan(-----)
+--R                                        +-+
+--R                                       \|b
+--R     + 
+--R                2            4                 2  2       2  +-+
+--R       ((- 15A c  + 15B b c)x  + (5A b c - 5B b )x  - 3A b )\|b
+--R  /
+--R        3 5 +-+
+--R     15b x \|b
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 1718
+t0:=(A+B*x^2)/(x^5*(b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          B x  + A
+--R   (1)  -----------
+--R           9      7
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 295
+
+--S 296 of 1718
+r0:=-1/6*A/(b*x^6)+1/4*(-b*B+A*c)/(b^2*x^4)+1/2*c*(b*B-A*c)/(b^3*x^2)+_
+   c^2*(b*B-A*c)*log(x)/b^4-1/2*c^2*(b*B-A*c)*log(b+c*x^2)/b^4
+--R 
+--R
+--R   (2)
+--R            3         2  6       2                3          2  6
+--R       (6A c  - 6B b c )x log(c x  + b) + (- 12A c  + 12B b c )x log(x)
+--R     + 
+--R                2       2   4        2        3  2       3
+--R       (- 6A b c  + 6B b c)x  + (3A b c - 3B b )x  - 2A b
+--R  /
+--R        4 6
+--R     12b x
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 1718
+t0:=x^12*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               10      8
+--R            B x   + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 298
+
+--S 299 of 1718
+r0:=-1/2*b^2*(9*b*B-7*A*c)*x/c^5+1/6*b*(9*b*B-7*A*c)*x^3/c^4-_
+   1/10*(9*b*B-7*A*c)*x^5/c^3+1/14*(9*b*B-7*A*c)*x^7/(b*c^2)-_
+   1/2*(b*B-A*c)*x^9/(b*c*(b+c*x^2))+1/2*b^(5/2)*(9*b*B-7*A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/c^(11/2)
+--R 
+--R
+--R   (2)
+--R                                                                   +-+
+--R                 2 2         3   2         3          4  +-+     x\|c
+--R       ((- 735A b c  + 945B b c)x  - 735A b c + 945B b )\|b atan(-----)
+--R                                                                   +-+
+--R                                                                  \|b
+--R     + 
+--R                4 9         4          3  7             3         2 2  5
+--R           30B c x  + (42A c  - 54B b c )x  + (- 98A b c  + 126B b c )x
+--R         + 
+--R                  2 2         3   3          3          4
+--R           (490A b c  - 630B b c)x  + (735A b c - 945B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R          6 2         5  +-+
+--R     (210c x  + 210b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 1718
+t0:=x^11*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               9      7
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 301
+
+--S 302 of 1718
+r0:=1/2*b*(3*b*B-2*A*c)*x^2/c^4-1/4*(2*b*B-A*c)*x^4/c^3+1/6*B*x^6/c^2-_
+   1/2*b^3*(b*B-A*c)/(c^5*(b+c*x^2))-1/2*b^2*(4*b*B-3*A*c)*log(b+c*x^2)/c^5
+--R 
+--R
+--R   (2)
+--R              2 2        3   2        3         4        2            4 8
+--R       ((18A b c  - 24B b c)x  + 18A b c - 24B b )log(c x  + b) + 2B c x
+--R     + 
+--R            4         3  6            3        2 2  4           2 2        3   2
+--R       (3A c  - 4B b c )x  + (- 9A b c  + 12B b c )x  + (- 12A b c  + 18B b c)x
+--R     + 
+--R           3        4
+--R       6A b c - 6B b
+--R  /
+--R        6 2        5
+--R     12c x  + 12b c
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 1718
+t0:=x^10*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               8      6
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 304
+
+--S 305 of 1718
+r0:=1/2*b*(7*b*B-5*A*c)*x/c^4-1/6*(7*b*B-5*A*c)*x^3/c^3+1/10*(7*b*B-5*A*c)*_
+   x^5/(b*c^2)-1/2*(b*B-A*c)*x^7/(b*c*(b+c*x^2))-1/2*b^(3/2)*(7*b*B-5*A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/c^(9/2)
+--R 
+--R
+--R   (2)
+--R                                                               +-+
+--R                2         2   2        2          3  +-+     x\|c
+--R       ((75A b c  - 105B b c)x  + 75A b c - 105B b )\|b atan(-----)
+--R                                                               +-+
+--R                                                              \|b
+--R     + 
+--R               3 7         3          2  5             2        2   3
+--R           6B c x  + (10A c  - 14B b c )x  + (- 50A b c  + 70B b c)x
+--R         + 
+--R                   2          3
+--R           (- 75A b c + 105B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R         5 2        4  +-+
+--R     (30c x  + 30b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 1718
+t0:=x^9*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               7      5
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 307
+
+--S 308 of 1718
+r0:=-1/2*(2*b*B-A*c)*x^2/c^3+1/4*B*x^4/c^2+1/2*b^2*(b*B-A*c)/_
+   (c^4*(b+c*x^2))+1/2*b*(3*b*B-2*A*c)*log(b+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R                 2       2   2       2        3        2           3 6
+--R       ((- 4A b c  + 6B b c)x  - 4A b c + 6B b )log(c x  + b) + B c x
+--R     + 
+--R            3         2  4          2       2   2       2        3
+--R       (2A c  - 3B b c )x  + (2A b c  - 4B b c)x  - 2A b c + 2B b
+--R  /
+--R       5 2       4
+--R     4c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 1718
+t0:=x^8*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               6      4
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 310
+
+--S 311 of 1718
+r0:=-1/2*(5*b*B-3*A*c)*x/c^3+1/6*(5*b*B-3*A*c)*x^3/(b*c^2)-_
+   1/2*(b*B-A*c)*x^5/(b*c*(b+c*x^2))+1/2*(5*b*B-3*A*c)*_
+   atan(x*sqrt(c)/sqrt(b))*sqrt(b)/c^(7/2)
+--R 
+--R
+--R   (2)
+--R                                                           +-+
+--R               2            2                 2  +-+     x\|c
+--R       ((- 9A c  + 15B b c)x  - 9A b c + 15B b )\|b atan(-----)
+--R                                                           +-+
+--R                                                          \|b
+--R     + 
+--R            2 5        2            3                  2    +-+
+--R       (2B c x  + (6A c  - 10B b c)x  + (9A b c - 15B b )x)\|c
+--R  /
+--R        4 2       3  +-+
+--R     (6c x  + 6b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 1718
+t0:=x^7*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               5      3
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 313
+
+--S 314 of 1718
+r0:=1/2*B*x^2/c^2-1/2*b*(b*B-A*c)/(c^3*(b+c*x^2))-_
+   1/2*(2*b*B-A*c)*log(b+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R            2           2               2        2           2 4          2
+--R       ((A c  - 2B b c)x  + A b c - 2B b )log(c x  + b) + B c x  + B b c x
+--R     + 
+--R                  2
+--R       A b c - B b
+--R  /
+--R       4 2       3
+--R     2c x  + 2b c
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 1718
+t0:=x^6*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               4      2
+--R            B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 316
+
+--S 317 of 1718
+r0:=1/2*(3*b*B-A*c)*x/(b*c^2)-1/2*(b*B-A*c)*x^3/(b*c*(b+c*x^2))-_
+   1/2*(3*b*B-A*c)*atan(x*sqrt(c)/sqrt(b))/(c^(5/2)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                                                 +-+
+--R            2           2               2      x\|c
+--R       ((A c  - 3B b c)x  + A b c - 3B b )atan(-----)
+--R                                                 +-+
+--R                                                \|b
+--R     + 
+--R              3                    +-+ +-+
+--R       (2B c x  + (- A c + 3B b)x)\|b \|c
+--R  /
+--R        3 2       2  +-+ +-+
+--R     (2c x  + 2b c )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 1718
+t0:=x^5*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                3
+--R             B x  + A x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 319
+
+--S 320 of 1718
+r0:=1/2*(b*B-A*c)/(c^2*(b+c*x^2))+1/2*B*log(b+c*x^2)/c^2
+--R 
+--R
+--R              2              2
+--R        (B c x  + B b)log(c x  + b) - A c + B b
+--R   (2)  ---------------------------------------
+--R                       3 2       2
+--R                     2c x  + 2b c
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 1718
+t0:=x^4*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 322
+
+--S 323 of 1718
+r0:=-1/2*(b*B-A*c)*x/(b*c*(b+c*x^2))+1/2*(b*B+A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/(b^(3/2)*c^(3/2))
+--R 
+--R
+--R                                                +-+
+--R             2          2              2      x\|c                  +-+ +-+
+--R        ((A c  + B b c)x  + A b c + B b )atan(-----) + (A c - B b)x\|b \|c
+--R                                                +-+
+--R                                               \|b
+--R   (2)  -------------------------------------------------------------------
+--R                                   2 2     2   +-+ +-+
+--R                              (2b c x  + 2b c)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+)clear all
+
+--S 325 of 1718
+t0:=x^3*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  --------------------
+--R         2 5         3    2
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 325
+
+--S 326 of 1718
+r0:=1/2*(-b*B+A*c)/(b*c*(b+c*x^2))+A*log(x)/b^2-1/2*A*log(b+c*x^2)/b^2
+--R 
+--R
+--R   (2)
+--R         2 2                2             2 2                              2
+--R   (- A c x  - A b c)log(c x  + b) + (2A c x  + 2A b c)log(x) + A b c - B b
+--R   -------------------------------------------------------------------------
+--R                                   2 2 2     3
+--R                                 2b c x  + 2b c
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 1718
+t0:=x^2*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  2
+--R               B x  + A
+--R   (1)  ---------------------
+--R         2 6         4    2 2
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 328
+
+--S 329 of 1718
+r0:=1/2*(b*B-3*A*c)/(b^2*c*x)+1/2*(-b*B+A*c)/(b*c*x*(b+c*x^2))+_
+   1/2*(b*B-3*A*c)*atan(x*sqrt(c)/sqrt(b))/(b^(5/2)*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                                                        +-+
+--R               2          3                  2        x\|c
+--R       ((- 3A c  + B b c)x  + (- 3A b c + B b )x)atan(-----)
+--R                                                        +-+
+--R                                                       \|b
+--R     + 
+--R                       2         +-+ +-+
+--R       ((- 3A c + B b)x  - 2A b)\|b \|c
+--R  /
+--R        2   3     3   +-+ +-+
+--R     (2b c x  + 2b x)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 1718
+t0:=x*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  2
+--R               B x  + A
+--R   (1)  ---------------------
+--R         2 7         5    2 3
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 331
+
+--S 332 of 1718
+r0:=1/2*(b*B-2*A*c)/(b^2*c*x^2)+1/2*(-b*B+A*c)/(b*c*x^2*(b+c*x^2))+_
+   (b*B-2*A*c)*log(x)/b^3-1/2*(b*B-2*A*c)*log(b+c*x^2)/b^3
+--R 
+--R
+--R   (2)
+--R             2          4                2  2        2
+--R       ((2A c  - B b c)x  + (2A b c - B b )x )log(c x  + b)
+--R     + 
+--R               2           4                   2  2                         2  2
+--R       ((- 4A c  + 2B b c)x  + (- 4A b c + 2B b )x )log(x) + (- 2A b c + B b )x
+--R     + 
+--R            2
+--R       - A b
+--R  /
+--R       3   4     4 2
+--R     2b c x  + 2b x
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 1718
+t0:=(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  2
+--R               B x  + A
+--R   (1)  ---------------------
+--R         2 8         6    2 4
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 334
+
+--S 335 of 1718
+r0:=1/6*(3*b*B-5*A*c)/(b^2*c*x^3)+1/2*(-3*b*B+5*A*c)/(b^3*x)+_
+   1/2*(-b*B+A*c)/(b*c*x^3*(b+c*x^2))-_
+   1/2*(3*b*B-5*A*c)*atan(x*sqrt(c)/sqrt(b))*sqrt(c)/b^(7/2)
+--R 
+--R
+--R   (2)
+--R                                                             +-+
+--R              2           5                  2  3  +-+     x\|c
+--R       ((15A c  - 9B b c)x  + (15A b c - 9B b )x )\|c atan(-----)
+--R                                                             +-+
+--R                                                            \|b
+--R     + 
+--R              2           4                  2  2       2  +-+
+--R       ((15A c  - 9B b c)x  + (10A b c - 6B b )x  - 2A b )\|b
+--R  /
+--R        3   5     4 3  +-+
+--R     (6b c x  + 6b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 1718
+t0:=(A+B*x^2)/(x*(b*x^2+c*x^4)^2)
+--R 
+--R
+--R                  2
+--R               B x  + A
+--R   (1)  ---------------------
+--R         2 9         7    2 5
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 337
+
+--S 338 of 1718
+r0:=1/4*(2*b*B-3*A*c)/(b^2*c*x^4)+1/2*(-2*b*B+3*A*c)/(b^3*x^2)+_
+   1/2*(-b*B+A*c)/(b*c*x^4*(b+c*x^2))-c*(2*b*B-3*A*c)*log(x)/b^4+_
+   1/2*c*(2*b*B-3*A*c)*log(b+c*x^2)/b^4
+--R 
+--R
+--R   (2)
+--R               3         2  6            2       2   4        2
+--R       ((- 6A c  + 4B b c )x  + (- 6A b c  + 4B b c)x )log(c x  + b)
+--R     + 
+--R              3         2  6           2       2   4
+--R       ((12A c  - 8B b c )x  + (12A b c  - 8B b c)x )log(x)
+--R     + 
+--R              2       2   4        2        3  2      3
+--R       (6A b c  - 4B b c)x  + (3A b c - 2B b )x  - A b
+--R  /
+--R       4   6     5 4
+--R     4b c x  + 4b x
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 1718
+t0:=(A+B*x^2)/(x^2*(b*x^2+c*x^4)^2)
+--R 
+--R
+--R                  2
+--R               B x  + A
+--R   (1)  ----------------------
+--R         2 10         8    2 6
+--R        c x   + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 340
+
+--S 341 of 1718
+r0:=1/10*(5*b*B-7*A*c)/(b^2*c*x^5)+1/6*(-5*b*B+7*A*c)/(b^3*x^3)+_
+   1/2*c*(5*b*B-7*A*c)/(b^4*x)+1/2*(-b*B+A*c)/(b*c*x^5*(b+c*x^2))+_
+   1/2*c^(3/2)*(5*b*B-7*A*c)*atan(x*sqrt(c)/sqrt(b))/b^(9/2)
+--R 
+--R
+--R   (2)
+--R                                                                        +-+
+--R                 3          2  7              2        2   5  +-+     x\|c
+--R       ((- 105A c  + 75B b c )x  + (- 105A b c  + 75B b c)x )\|c atan(-----)
+--R                                                                        +-+
+--R                                                                       \|b
+--R     + 
+--R                    3          2  6             2        2   4
+--R           (- 105A c  + 75B b c )x  + (- 70A b c  + 50B b c)x
+--R         + 
+--R                 2         3  2       3
+--R           (14A b c - 10B b )x  - 6A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R         4   7      5 5  +-+
+--R     (30b c x  + 30b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 1718
+t0:=x^14*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    10      8
+--R                 B x   + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 343
+
+--S 344 of 1718
+r0:=7/8*b*(9*b*B-5*A*c)*x/c^5-7/24*(9*b*B-5*A*c)*x^3/c^4+7/40*(9*b*B-5*A*c)*_
+   x^5/(b*c^3)-1/4*(b*B-A*c)*x^9/(b*c*(b+c*x^2)^2)-1/8*(9*b*B-5*A*c)*x^7/_
+   (b*c^2*(b+c*x^2))-7/8*b^(3/2)*(9*b*B-5*A*c)*atan(x*sqrt(c)/sqrt(b))/c^(11/2)
+--R 
+--R
+--R   (2)
+--R                    3         2 2  4           2 2          3   2         3
+--R           (525A b c  - 945B b c )x  + (1050A b c  - 1890B b c)x  + 525A b c
+--R         + 
+--R                   4
+--R           - 945B b
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|b
+--R     + 
+--R                4 9         4          3  7              3         2 2  5
+--R           24B c x  + (40A c  - 72B b c )x  + (- 280A b c  + 504B b c )x
+--R         + 
+--R                    2 2          3   3            3          4
+--R           (- 875A b c  + 1575B b c)x  + (- 525A b c + 945B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R          7 4         6 2       2 5  +-+
+--R     (120c x  + 240b c x  + 120b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 1718
+t0:=x^13*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    9      7
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 346
+
+--S 347 of 1718
+r0:=-1/2*(3*b*B-A*c)*x^2/c^4+1/4*B*x^4/c^3-1/4*b^3*(b*B-A*c)/(c^5*_
+   (b+c*x^2)^2)+1/2*b^2*(4*b*B-3*A*c)/(c^5*(b+c*x^2))+3/2*b*(2*b*B-A*c)*_
+   log(b+c*x^2)/c^5
+--R 
+--R
+--R   (2)
+--R                   3        2 2  4           2 2        3   2       3         4
+--R         ((- 6A b c  + 12B b c )x  + (- 12A b c  + 24B b c)x  - 6A b c + 12B b )
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R          4 8        4         3  6          3        2 2  4
+--R       B c x  + (2A c  - 4B b c )x  + (4A b c  - 11B b c )x
+--R     + 
+--R              2 2       3   2       3        4
+--R       (- 4A b c  + 2B b c)x  - 5A b c + 7B b
+--R  /
+--R       7 4       6 2     2 5
+--R     4c x  + 8b c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 1718
+t0:=x^12*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    8      6
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 349
+
+--S 350 of 1718
+r0:=-5/8*(7*b*B-3*A*c)*x/c^4+5/24*(7*b*B-3*A*c)*x^3/(b*c^3)-_
+   1/4*(b*B-A*c)*x^7/(b*c*(b+c*x^2)^2)-1/8*(7*b*B-3*A*c)*x^5/(b*c^2*_
+   (b+c*x^2))+5/8*(7*b*B-3*A*c)*atan(x*sqrt(c)/sqrt(b))*sqrt(b)/c^(9/2)
+--R 
+--R
+--R   (2)
+--R                   3           2  4             2         2   2        2
+--R           (- 45A c  + 105B b c )x  + (- 90A b c  + 210B b c)x  - 45A b c
+--R         + 
+--R                 3
+--R           105B b
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|b atan(-----)
+--R                    +-+
+--R                   \|b
+--R     + 
+--R               3 7         3          2  5           2         2   3
+--R           8B c x  + (24A c  - 56B b c )x  + (75A b c  - 175B b c)x
+--R         + 
+--R                 2          3
+--R           (45A b c - 105B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R         6 4        5 2      2 4  +-+
+--R     (24c x  + 48b c x  + 24b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 1718
+t0:=x^11*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    7      5
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 352
+
+--S 353 of 1718
+r0:=1/2*B*x^2/c^3+1/4*b^2*(b*B-A*c)/(c^4*(b+c*x^2)^2)-_
+   1/2*b*(3*b*B-2*A*c)/(c^4*(b+c*x^2))-1/2*(3*b*B-A*c)*log(b+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R               3         2  4          2        2   2       2        3
+--R         ((2A c  - 6B b c )x  + (4A b c  - 12B b c)x  + 2A b c - 6B b )
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R           3 6         2 4          2       2   2       2        3
+--R       2B c x  + 4B b c x  + (4A b c  - 4B b c)x  + 3A b c - 5B b
+--R  /
+--R       6 4       5 2     2 4
+--R     4c x  + 8b c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 1718
+t0:=x^10*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    6      4
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 355
+
+--S 356 of 1718
+r0:=3/8*(5*b*B-A*c)*x/(b*c^3)-1/4*(b*B-A*c)*x^5/(b*c*(b+c*x^2)^2)-_
+   1/8*(5*b*B-A*c)*x^3/(b*c^2*(b+c*x^2))-3/8*(5*b*B-A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/(c^(7/2)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R               3          2  4          2        2   2       2         3
+--R         ((3A c  - 15B b c )x  + (6A b c  - 30B b c)x  + 3A b c - 15B b )
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|b
+--R     + 
+--R            2 5          2            3                    2    +-+ +-+
+--R       (8B c x  + (- 5A c  + 25B b c)x  + (- 3A b c + 15B b )x)\|b \|c
+--R  /
+--R        5 4        4 2     2 3  +-+ +-+
+--R     (8c x  + 16b c x  + 8b c )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 1718
+t0:=x^9*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    5      3
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 358
+
+--S 359 of 1718
+r0:=-1/4*b*(b*B-A*c)/(c^3*(b+c*x^2)^2)+1/2*(2*b*B-A*c)/(c^3*(b+c*x^2))+_
+   1/2*B*log(b+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R            2 4           2       2        2               2           2
+--R       (2B c x  + 4B b c x  + 2B b )log(c x  + b) + (- 2A c  + 4B b c)x  - A b c
+--R     + 
+--R           2
+--R       3B b
+--R  /
+--R       5 4       4 2     2 3
+--R     4c x  + 8b c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 1718
+t0:=x^8*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    4      2
+--R                 B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 361
+
+--S 362 of 1718
+r0:=-1/4*(b*B-A*c)*x^3/(b*c*(b+c*x^2)^2)-1/8*(3*b*B+A*c)*_
+   x/(b*c^2*(b+c*x^2))+1/8*(3*b*B+A*c)*atan(x*sqrt(c)/sqrt(b))/_
+   (b^(3/2)*c^(5/2))
+--R 
+--R
+--R   (2)
+--R                                                                         +-+
+--R            3         2  4          2       2   2      2        3      x\|c
+--R       ((A c  + 3B b c )x  + (2A b c  + 6B b c)x  + A b c + 3B b )atan(-----)
+--R                                                                         +-+
+--R                                                                        \|b
+--R     + 
+--R            2           3                  2    +-+ +-+
+--R       ((A c  - 5B b c)x  + (- A b c - 3B b )x)\|b \|c
+--R  /
+--R          4 4      2 3 2     3 2  +-+ +-+
+--R     (8b c x  + 16b c x  + 8b c )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 1718
+t0:=x^7*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     3
+--R                  B x  + A x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 364
+
+--S 365 of 1718
+r0:=1/4*(A+B*x^2)^2/((b*B-A*c)*(b+c*x^2)^2)
+--R 
+--R
+--R                         1  2 4   1      2   1  2
+--R                       - - B x  - - A B x  - - A
+--R                         4        2          4
+--R   (2)  -------------------------------------------------------
+--R            3        2  4          2       2   2      2       3
+--R        (A c  - B b c )x  + (2A b c  - 2B b c)x  + A b c - B b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 365
+
+--S 366 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 1718
+t0:=x^6*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      2
+--R                   B x  + A
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 367
+
+--S 368 of 1718
+r0:=-1/4*(b*B-A*c)*x/(b*c*(b+c*x^2)^2)+1/8*(b*B+3*A*c)*x/(b^2*c*(b+c*x^2))+_
+   1/8*(b*B+3*A*c)*atan(x*sqrt(c)/sqrt(b))/(b^(5/2)*c^(3/2))
+--R 
+--R
+--R   (2)
+--R                                                                         +-+
+--R             3        2  4          2       2   2       2       3      x\|c
+--R       ((3A c  + B b c )x  + (6A b c  + 2B b c)x  + 3A b c + B b )atan(-----)
+--R                                                                         +-+
+--R                                                                        \|b
+--R     + 
+--R             2          3                2    +-+ +-+
+--R       ((3A c  + B b c)x  + (5A b c - B b )x)\|b \|c
+--R  /
+--R        2 3 4      3 2 2     4   +-+ +-+
+--R     (8b c x  + 16b c x  + 8b c)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 1718
+t0:=x^5*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      2
+--R                   B x  + A
+--R   (1)  ------------------------------
+--R         3 7       2 5     2   3    3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 370
+
+--S 371 of 1718
+r0:=1/4*(-b*B+A*c)/(b*c*(b+c*x^2)^2)+1/2*A/(b^2*(b+c*x^2))+A*log(x)/b^3-_
+   1/2*A*log(b+c*x^2)/b^3
+--R 
+--R
+--R   (2)
+--R              3 4         2 2       2         2
+--R       (- 2A c x  - 4A b c x  - 2A b c)log(c x  + b)
+--R     + 
+--R            3 4         2 2       2                 2 2       2       3
+--R       (4A c x  + 8A b c x  + 4A b c)log(x) + 2A b c x  + 3A b c - B b
+--R  /
+--R       3 3 4     4 2 2     5
+--R     4b c x  + 8b c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 1718
+t0:=x^4*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R         3 8       2 6     2   4    3 2
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 373
+
+--S 374 of 1718
+r0:=3/8*(b*B-5*A*c)/(b^3*c*x)+1/4*(-b*B+A*c)/(b*c*x*(b+c*x^2)^2)+_
+   1/8*(-b*B+5*A*c)/(b^2*c*x*(b+c*x^2))+3/8*(b*B-5*A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/(b^(7/2)*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                     3         2  5             2       2   3
+--R             (- 15A c  + 3B b c )x  + (- 30A b c  + 6B b c)x
+--R           + 
+--R                     2        3
+--R             (- 15A b c + 3B b )x
+--R      *
+--R                +-+
+--R              x\|c
+--R         atan(-----)
+--R                +-+
+--R               \|b
+--R     + 
+--R                2           4                    2  2       2  +-+ +-+
+--R       ((- 15A c  + 3B b c)x  + (- 25A b c + 5B b )x  - 8A b )\|b \|c
+--R  /
+--R        3 2 5      4   3     5   +-+ +-+
+--R     (8b c x  + 16b c x  + 8b x)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 1718
+t0:=x^3*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R         3 9       2 7     2   5    3 3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 376
+
+--S 377 of 1718
+r0:=1/2*(b*B-3*A*c)/(b^3*c*x^2)+1/4*(-b*B+A*c)/(b*c*x^2*(b+c*x^2)^2)+_
+   1/4*(-b*B+3*A*c)/(b^2*c*x^2*(b+c*x^2))+(b*B-3*A*c)*log(x)/b^4-_
+   1/2*(b*B-3*A*c)*log(b+c*x^2)/b^4
+--R 
+--R
+--R   (2)
+--R               3         2  6           2       2   4        2        3  2
+--R         ((6A c  - 2B b c )x  + (12A b c  - 4B b c)x  + (6A b c - 2B b )x )
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R                   3         2  6             2       2   4
+--R           (- 12A c  + 4B b c )x  + (- 24A b c  + 8B b c)x
+--R         + 
+--R                   2        3  2
+--R           (- 12A b c + 4B b )x
+--R      *
+--R         log(x)
+--R     + 
+--R                2       2   4          2        3  2       3
+--R       (- 6A b c  + 2B b c)x  + (- 9A b c + 3B b )x  - 2A b
+--R  /
+--R       4 2 6     5   4     6 2
+--R     4b c x  + 8b c x  + 4b x
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 1718
+t0:=x^2*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  --------------------------------
+--R         3 10       2 8     2   6    3 4
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 379
+
+--S 380 of 1718
+r0:=5/24*(3*b*B-7*A*c)/(b^3*c*x^3)-5/8*(3*b*B-7*A*c)/(b^4*x)+_
+   1/4*(-b*B+A*c)/(b*c*x^3*(b+c*x^2)^2)+1/8*(-3*b*B+7*A*c)/_
+   (b^2*c*x^3*(b+c*x^2))-5/8*(3*b*B-7*A*c)*atan(x*sqrt(c)/sqrt(b))*_
+   sqrt(c)/b^(9/2)
+--R 
+--R
+--R   (2)
+--R                  3          2  7            2        2   5
+--R           (105A c  - 45B b c )x  + (210A b c  - 90B b c)x
+--R         + 
+--R                  2         3  3
+--R           (105A b c - 45B b )x
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|c atan(-----)
+--R                    +-+
+--R                   \|b
+--R     + 
+--R                  3          2  6            2        2   4
+--R           (105A c  - 45B b c )x  + (175A b c  - 75B b c)x
+--R         + 
+--R                 2         3  2       3
+--R           (56A b c - 24B b )x  - 8A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R         4 2 7      5   5      6 3  +-+
+--R     (24b c x  + 48b c x  + 24b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 1718
+t0:=x*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  --------------------------------
+--R         3 11       2 9     2   7    3 5
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 382
+
+--S 383 of 1718
+r0:=3/4*(b*B-2*A*c)/(b^3*c*x^4)-3/2*(b*B-2*A*c)/(b^4*x^2)+1/4*(-b*B+A*c)/_
+   (b*c*x^4*(b+c*x^2)^2)+1/2*(-b*B+2*A*c)/(b^2*c*x^4*(b+c*x^2))-_
+   3*c*(b*B-2*A*c)*log(x)/b^5+3/2*c*(b*B-2*A*c)*log(b+c*x^2)/b^5
+--R 
+--R
+--R   (2)
+--R                   4         3  8             3        2 2  6
+--R           (- 12A c  + 6B b c )x  + (- 24A b c  + 12B b c )x
+--R         + 
+--R                   2 2       3   4
+--R           (- 12A b c  + 6B b c)x
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R                 4          3  8           3        2 2  6
+--R           (24A c  - 12B b c )x  + (48A b c  - 24B b c )x
+--R         + 
+--R                 2 2        3   4
+--R           (24A b c  - 12B b c)x
+--R      *
+--R         log(x)
+--R     + 
+--R             3       2 2  6         2 2       3   4        3        4  2      4
+--R     (12A b c  - 6B b c )x  + (18A b c  - 9B b c)x  + (4A b c - 2B b )x  - A b
+--R  /
+--R       5 2 8     6   6     7 4
+--R     4b c x  + 8b c x  + 4b x
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 1718
+t0:=(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                        2
+--R                     B x  + A
+--R   (1)  ---------------------------------
+--R         3 12       2 10     2   8    3 6
+--R        c x   + 3b c x   + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 385
+
+--S 386 of 1718
+r0:=7/40*(5*b*B-9*A*c)/(b^3*c*x^5)-7/24*(5*b*B-9*A*c)/(b^4*x^3)+_
+   7/8*c*(5*b*B-9*A*c)/(b^5*x)+1/4*(-b*B+A*c)/(b*c*x^5*(b+c*x^2)^2)+_
+   1/8*(-5*b*B+9*A*c)/(b^2*c*x^5*(b+c*x^2))+7/8*c^(3/2)*(5*b*B-9*A*c)*_
+   atan(x*sqrt(c)/sqrt(b))/b^(11/2)
+--R 
+--R
+--R   (2)
+--R                    4           3  9               3          2 2  7
+--R           (- 945A c  + 525B b c )x  + (- 1890A b c  + 1050B b c )x
+--R         + 
+--R                    2 2         3   5
+--R           (- 945A b c  + 525B b c)x
+--R      *
+--R                    +-+
+--R          +-+     x\|c
+--R         \|c atan(-----)
+--R                    +-+
+--R                   \|b
+--R     + 
+--R                    4           3  8               3         2 2  6
+--R           (- 945A c  + 525B b c )x  + (- 1575A b c  + 875B b c )x
+--R         + 
+--R                    2 2         3   4         3         4  2        4
+--R           (- 504A b c  + 280B b c)x  + (72A b c - 40B b )x  - 24A b
+--R      *
+--R          +-+
+--R         \|b
+--R  /
+--R          5 2 9       6   7       7 5  +-+
+--R     (120b c x  + 240b c x  + 120b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 1718
+t0:=(A+B*x^2)/(x*(b*x^2+c*x^4)^3)
+--R 
+--R
+--R                        2
+--R                     B x  + A
+--R   (1)  ---------------------------------
+--R         3 13       2 11     2   9    3 7
+--R        c x   + 3b c x   + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 388
+
+--S 389 of 1718
+r0:=1/3*(3*b*B-5*A*c)/(b^3*c*x^6)+1/2*(-3*b*B+5*A*c)/(b^4*x^4)+_
+   c*(3*b*B-5*A*c)/(b^5*x^2)+1/4*(-b*B+A*c)/(b*c*x^6*(b+c*x^2)^2)+_
+   1/4*(-3*b*B+5*A*c)/(b^2*c*x^6*(b+c*x^2))+2*c^2*(3*b*B-5*A*c)*log(x)/b^6-_
+   c^2*(3*b*B-5*A*c)*log(b+c*x^2)/b^6
+--R 
+--R
+--R   (2)
+--R                 5          4  10            4        2 3  8
+--R           (60A c  - 36B b c )x   + (120A b c  - 72B b c )x
+--R         + 
+--R                 2 3        3 2  6
+--R           (60A b c  - 36B b c )x
+--R      *
+--R                2
+--R         log(c x  + b)
+--R     + 
+--R                    5          4  10              4         2 3  8
+--R           (- 120A c  + 72B b c )x   + (- 240A b c  + 144B b c )x
+--R         + 
+--R                    2 3        3 2  6
+--R           (- 120A b c  + 72B b c )x
+--R      *
+--R         log(x)
+--R     + 
+--R                 4        2 3  8           2 3        3 2  6
+--R       (- 60A b c  + 36B b c )x  + (- 90A b c  + 54B b c )x
+--R     + 
+--R               3 2        4   4        4        5  2       5
+--R       (- 20A b c  + 12B b c)x  + (5A b c - 3B b )x  - 2A b
+--R  /
+--R        6 2 10      7   8      8 6
+--R     12b c x   + 24b c x  + 12b x
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 1718
+t0:=x^7*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      +-----------+
+--R            9      7  |   4      2
+--R   (1)  (B x  + A x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1718
+r0:=1/12*B*x^6*(b*x^2+c*x^4)^(3/2)/c-7/1024*b^5*(3*b*B-4*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(11/2)+7/1024*b^4*(3*b*B-4*A*c)*_
+   sqrt(b*x^2+c*x^4)/c^5-7/1536*b^3*(3*b*B-4*A*c)*x^2*sqrt(b*x^2+c*x^4)/_
+   c^4+7/1920*b^2*(3*b*B-4*A*c)*x^4*sqrt(b*x^2+c*x^4)/c^3-_
+   1/320*b*(3*b*B-4*A*c)*x^6*sqrt(b*x^2+c*x^4)/c^2-1/40*(3*b*B-4*A*c)*_
+   x^8*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                      2 +-+
+--R              5          6           x \|c
+--R       (420A b c - 315B b )atanh(--------------)
+--R                                  +-----------+
+--R                                  |   4      2
+--R                                 \|c x  + b x
+--R     + 
+--R                  5 10           5           4  8            4         2 3  6
+--R           1280B c x   + (1536A c  + 128B b c )x  + (192A b c  - 144B b c )x
+--R         + 
+--R                    2 3         3 2  4          3 2         4   2         4
+--R           (- 224A b c  + 168B b c )x  + (280A b c  - 210B b c)x  - 420A b c
+--R         + 
+--R                 5
+--R           315B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R           5 +-+
+--R     15360c \|c
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 1718
+t0:=x^5*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      +-----------+
+--R            7      5  |   4      2
+--R   (1)  (B x  + A x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 1718
+r0:=1/10*B*x^4*(b*x^2+c*x^4)^(3/2)/c+1/256*b^4*(7*b*B-10*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(9/2)-1/256*b^3*(7*b*B-10*A*c)*_
+   sqrt(b*x^2+c*x^4)/c^4+1/384*b^2*(7*b*B-10*A*c)*x^2*_
+   sqrt(b*x^2+c*x^4)/c^3-1/480*b*(7*b*B-10*A*c)*x^4*sqrt(b*x^2+c*x^4)/c^2-_
+   1/80*(7*b*B-10*A*c)*x^6*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                        2 +-+
+--R                4          5           x \|c
+--R       (- 150A b c + 105B b )atanh(--------------)
+--R                                    +-----------+
+--R                                    |   4      2
+--R                                   \|c x  + b x
+--R     + 
+--R                 4 8          4          3  6           3        2 2  4
+--R           384B c x  + (480A c  + 48B b c )x  + (80A b c  - 56B b c )x
+--R         + 
+--R                    2 2        3   2         3          4
+--R           (- 100A b c  + 70B b c)x  + 150A b c - 105B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R          4 +-+
+--R     3840c \|c
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 1718
+t0:=x^3*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      +-----------+
+--R            5      3  |   4      2
+--R   (1)  (B x  + A x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 1718
+r0:=1/8*B*x^2*(b*x^2+c*x^4)^(3/2)/c-1/128*b^3*(5*b*B-8*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(7/2)+1/128*b^2*(5*b*B-8*A*c)*_
+   sqrt(b*x^2+c*x^4)/c^3-1/192*b*(5*b*B-8*A*c)*x^2*sqrt(b*x^2+c*x^4)/c^2-_
+   1/48*(5*b*B-8*A*c)*x^4*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                    2 +-+
+--R             3         4           x \|c
+--R       (24A b c - 15B b )atanh(--------------)
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R     + 
+--R                3 6         3         2  4           2        2   2        2
+--R           48B c x  + (64A c  + 8B b c )x  + (16A b c  - 10B b c)x  - 24A b c
+--R         + 
+--R                3
+--R           15B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R         3 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 1718
+t0:=x*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                     +-----------+
+--R            3        |   4      2
+--R   (1)  (B x  + A x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 1718
+r0:=1/6*B*(b*x^2+c*x^4)^(3/2)/c+1/16*b^2*(b*B-2*A*c)*atanh(x^2*sqrt(c)/_
+   sqrt(b*x^2+c*x^4))/c^(5/2)-1/16*b*(b*B-2*A*c)*sqrt(b*x^2+c*x^4)/c^2-_
+   1/8*(b*B-2*A*c)*x^2*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                    2 +-+
+--R              2        3           x \|c
+--R       (- 6A b c + 3B b )atanh(--------------)
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R     + 
+--R                                                            +-----------+
+--R            2 4         2           2                2  +-+ |   4      2
+--R       (8B c x  + (12A c  + 2B b c)x  + 6A b c - 3B b )\|c \|c x  + b x
+--R  /
+--R        2 +-+
+--R     48c \|c
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 1718
+r0:=1/4*B*(b*x^2+c*x^4)^(3/2)/(c*x^2)-1/8*b*(b*B-4*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)-1/8*(b*B-4*A*c)*_
+   sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                 2 +-+
+--R                    2           x \|c
+--R       (4A b c - B b )atanh(--------------)
+--R                             +-----------+
+--R                             |   4      2
+--R                            \|c x  + b x
+--R     + 
+--R                                  +-----------+
+--R              2               +-+ |   4      2
+--R       (2B c x  + 4A c + B b)\|c \|c x  + b x
+--R  /
+--R        +-+
+--R     8c\|c
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^3
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    3
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 1718
+r0:=-A*(b*x^2+c*x^4)^(3/2)/(b*x^4)+1/2*(b*B+2*A*c)*atanh(x^2*sqrt(c)/_
+   sqrt(b*x^2+c*x^4))/sqrt(c)+1/2*(b*B+2*A*c)*sqrt(b*x^2+c*x^4)/b
+--R 
+--R
+--R                                 2 +-+                        +-----------+
+--R                     2          x \|c             2       +-+ |   4      2
+--R        (2A c + B b)x atanh(--------------) + (B x  - 2A)\|c \|c x  + b x
+--R                             +-----------+
+--R                             |   4      2
+--R                            \|c x  + b x
+--R   (2)  -------------------------------------------------------------------
+--R                                        2 +-+
+--R                                      2x \|c
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^5
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    5
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 1718
+r0:=-1/3*A*(b*x^2+c*x^4)^(3/2)/(b*x^6)+B*atanh(x^2*sqrt(c)/_
+   sqrt(b*x^2+c*x^4))*sqrt(c)-B*sqrt(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                         2 +-+                                 +-----------+
+--R         4 +-+          x \|c                         2        |   4      2
+--R   3B b x \|c atanh(--------------) + ((- A c - 3B b)x  - A b)\|c x  + b x
+--R                     +-----------+
+--R                     |   4      2
+--R                    \|c x  + b x
+--R   -------------------------------------------------------------------------
+--R                                         4
+--R                                     3b x
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^7
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    7
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 1718
+r0:=-1/5*A*(b*x^2+c*x^4)^(3/2)/(b*x^8)-1/15*(5*b*B-2*A*c)*_
+   (b*x^2+c*x^4)^(3/2)/(b^2*x^6)
+--R 
+--R
+--R                                                           +-----------+
+--R              2           4                  2  2       2  |   4      2
+--R        ((2A c  - 5B b c)x  + (- A b c - 5B b )x  - 3A b )\|c x  + b x
+--R   (2)  ----------------------------------------------------------------
+--R                                        2 6
+--R                                     15b x
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^9
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    9
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 1718
+r0:=-1/7*A*(b*x^2+c*x^4)^(3/2)/(b*x^10)-1/35*(7*b*B-4*A*c)*_
+   (b*x^2+c*x^4)^(3/2)/(b^2*x^8)+2/105*c*(7*b*B-4*A*c)*(b*x^2+_
+   c*x^4)^(3/2)/(b^3*x^6)
+--R 
+--R
+--R   (2)
+--R                3          2  6          2       2   4          2         3  2
+--R         (- 8A c  + 14B b c )x  + (4A b c  - 7B b c)x  + (- 3A b c - 21B b )x
+--R       + 
+--R                3
+--R         - 15A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         3 8
+--R     105b x
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^11
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    11
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 1718
+r0:=-1/9*A*(b*x^2+c*x^4)^(3/2)/(b*x^12)-1/21*(3*b*B-2*A*c)*_
+   (b*x^2+c*x^4)^(3/2)/(b^2*x^10)+4/105*c*(3*b*B-2*A*c)*(b*x^2+_
+   c*x^4)^(3/2)/(b^3*x^8)-8/315*c^2*(3*b*B-2*A*c)*(b*x^2+c*x^4)^(3/2)/(b^4*x^6)
+--R 
+--R
+--R   (2)
+--R               4          3  8            3        2 2  6        2 2       3   4
+--R         (16A c  - 24B b c )x  + (- 8A b c  + 12B b c )x  + (6A b c  - 9B b c)x
+--R       + 
+--R                3         4  2        4
+--R         (- 5A b c - 45B b )x  - 35A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         4 10
+--R     315b x
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^13
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    13
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 1718
+r0:=-1/11*A*(b*x^2+c*x^4)^(3/2)/(b*x^14)-1/99*(11*b*B-8*A*c)*_
+   (b*x^2+c*x^4)^(3/2)/(b^2*x^12)+2/231*c*(11*b*B-8*A*c)*(b*x^2+_
+   c*x^4)^(3/2)/(b^3*x^10)-8/1155*c^2*(11*b*B-8*A*c)*(b*x^2+_
+   c*x^4)^(3/2)/(b^4*x^8)+16/3465*c^3*(11*b*B-8*A*c)*(b*x^2+_
+   c*x^4)^(3/2)/(b^5*x^6)
+--R 
+--R
+--R   (2)
+--R                  5           4  10           4        2 3  8
+--R         (- 128A c  + 176B b c )x   + (64A b c  - 88B b c )x
+--R       + 
+--R                 2 3        3 2  6         3 2        4   4
+--R         (- 48A b c  + 66B b c )x  + (40A b c  - 55B b c)x
+--R       + 
+--R                 4          5  2         5
+--R         (- 35A b c - 385B b )x  - 315A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R          5 12
+--R     3465b x
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 1718
+t0:=x^4*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      +-----------+
+--R            6      4  |   4      2
+--R   (1)  (B x  + A x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 1718
+r0:=-8/315*b^2*(2*b*B-3*A*c)*(b*x^2+c*x^4)^(3/2)/(c^4*x^3)+_
+   4/105*b*(2*b*B-3*A*c)*(b*x^2+c*x^4)^(3/2)/(c^3*x)-1/21*(2*b*B-_
+   3*A*c)*x*(b*x^2+c*x^4)^(3/2)/c^2+1/9*B*x^3*(b*x^2+c*x^4)^(3/2)/c
+--R 
+--R
+--R   (2)
+--R              4 8         4         3  6          3       2 2  4
+--R         35B c x  + (45A c  + 5B b c )x  + (9A b c  - 6B b c )x
+--R       + 
+--R                 2 2       3   2        3         4
+--R         (- 12A b c  + 8B b c)x  + 24A b c - 16B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         4
+--R     315c x
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 1718
+t0:=x^2*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      +-----------+
+--R            4      2  |   4      2
+--R   (1)  (B x  + A x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 1718
+r0:=2/105*b*(4*b*B-7*A*c)*(b*x^2+c*x^4)^(3/2)/(c^3*x^3)-_
+   1/35*(4*b*B-7*A*c)*(b*x^2+c*x^4)^(3/2)/(c^2*x)+1/7*B*x*_
+   (b*x^2+c*x^4)^(3/2)/c
+--R 
+--R
+--R   (2)
+--R                3 6         3         2  4          2       2   2        2
+--R           15B c x  + (21A c  + 3B b c )x  + (7A b c  - 4B b c)x  - 14A b c
+--R         + 
+--R               3
+--R           8B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         3
+--R     105c x
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R   (1)  (B x  + A)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 1718
+r0:=-1/15*(2*b*B-5*A*c)*(b*x^2+c*x^4)^(3/2)/(c^2*x^3)+_
+   1/5*B*(b*x^2+c*x^4)^(3/2)/(c*x)
+--R 
+--R
+--R                                                       +-----------+
+--R             2 4        2          2                2  |   4      2
+--R        (3B c x  + (5A c  + B b c)x  + 5A b c - 2B b )\|c x  + b x
+--R   (2)  ------------------------------------------------------------
+--R                                       2
+--R                                    15c x
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    2
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 1718
+r0:=1/3*B*(b*x^2+c*x^4)^(3/2)/(c*x^3)-A*atanh(x*sqrt(b)/_
+   sqrt(b*x^2+c*x^4))*sqrt(b)+A*sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R   (2)
+--R                            +-+                              +-----------+
+--R            +-+           x\|b               2               |   4      2
+--R   - 3A c x\|b atanh(--------------) + (B c x  + 3A c + B b)\|c x  + b x
+--R                      +-----------+
+--R                      |   4      2
+--R                     \|c x  + b x
+--R   -----------------------------------------------------------------------
+--R                                     3c x
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^4
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    4
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 1718
+r0:=-1/2*A*(b*x^2+c*x^4)^(3/2)/(b*x^5)-1/2*(2*b*B+A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/sqrt(b)+1/2*(2*b*B+A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*x)
+--R 
+--R
+--R                                     +-+                        +-----------+
+--R                       3           x\|b              2      +-+ |   4      2
+--R        (- A c - 2B b)x atanh(--------------) + (2B x  - A)\|b \|c x  + b x
+--R                               +-----------+
+--R                               |   4      2
+--R                              \|c x  + b x
+--R   (2)  ---------------------------------------------------------------------
+--R                                         3 +-+
+--R                                       2x \|b
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^6
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    6
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 1718
+r0:=-1/4*A*(b*x^2+c*x^4)^(3/2)/(b*x^7)-1/8*c*(4*b*B-A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-1/8*(4*b*B-A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R   (2)
+--R                                     +-+
+--R           2           5           x\|b
+--R       (A c  - 4B b c)x atanh(--------------)
+--R                               +-----------+
+--R                               |   4      2
+--R                              \|c x  + b x
+--R     + 
+--R                                     +-----------+
+--R                       2         +-+ |   4      2
+--R       ((- A c - 4B b)x  - 2A b)\|b \|c x  + b x
+--R  /
+--R         5 +-+
+--R     8b x \|b
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 1718
+t0:=x^5*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                           +-----------+
+--R              11               9        7  |   4      2
+--R   (1)  (B c x   + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 1718
+r0:=-1/168*(9*b*B-14*A*c)*x^6*(b*x^2+c*x^4)^(3/2)/c+_
+   1/14*B*x^4*(b*x^2+c*x^4)^(5/2)/c-1/2048*b^6*(9*b*B-14*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(11/2)+1/2048*b^5*(9*b*B-_
+   14*A*c)*sqrt(b*x^2+c*x^4)/c^5-1/3072*b^4*(9*b*B-14*A*c)*x^2*_
+   sqrt(b*x^2+c*x^4)/c^4+1/3840*b^3*(9*b*B-14*A*c)*x^4*sqrt(b*x^2+_
+   c*x^4)/c^3-1/4480*b^2*(9*b*B-14*A*c)*x^6*sqrt(b*x^2+c*x^4)/c^2-_
+   1/560*b*(9*b*B-14*A*c)*x^8*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                       2 +-+
+--R               6          7           x \|c
+--R       (1470A b c - 945B b )atanh(--------------)
+--R                                   +-----------+
+--R                                   |   4      2
+--R                                  \|c x  + b x
+--R     + 
+--R                   6 12            6             5  10
+--R           15360B c x   + (17920A c  + 19200B b c )x
+--R         + 
+--R                      5         2 4  8          2 4         3 3  6
+--R           (23296A b c  + 384B b c )x  + (672A b c  - 432B b c )x
+--R         + 
+--R                    3 3         4 2  4          4 2         5   2          5
+--R           (- 784A b c  + 504B b c )x  + (980A b c  - 630B b c)x  - 1470A b c
+--R         + 
+--R                 6
+--R           945B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R            5 +-+
+--R     215040c \|c
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 444
+
+)clear all
+
+--S 445 of 1718
+t0:=x^4*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                           +-----------+
+--R              10               8        6  |   4      2
+--R   (1)  (B c x   + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 1718
+r0:=16/15015*b^3*(8*b*B-13*A*c)*(b*x^2+c*x^4)^(5/2)/(c^5*x^5)-_
+   8/3003*b^2*(8*b*B-13*A*c)*(b*x^2+c*x^4)^(5/2)/(c^4*x^3)+2/429*b*_
+   (8*b*B-13*A*c)*(b*x^2+c*x^4)^(5/2)/(c^3*x)-1/143*(8*b*B-13*A*c)*x*_
+   (b*x^2+c*x^4)^(5/2)/c^2+1/13*B*x^3*(b*x^2+c*x^4)^(5/2)/c
+--R 
+--R
+--R   (2)
+--R                6 12           6            5  10             5        2 4  8
+--R         1155B c x   + (1365A c  + 1470B b c )x   + (1820A b c  + 35B b c )x
+--R       + 
+--R               2 4        3 3  6           3 3        4 2  4
+--R         (65A b c  - 40B b c )x  + (- 78A b c  + 48B b c )x
+--R       + 
+--R                4 2        5   2         5          6
+--R         (104A b c  - 64B b c)x  - 208A b c + 128B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R           5
+--R     15015c x
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 1718
+t0:=x^3*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                          +-----------+
+--R              9               7        5  |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 1718
+r0:=-1/120*(7*b*B-12*A*c)*x^4*(b*x^2+c*x^4)^(3/2)/c+1/12*B*x^2*_
+   (b*x^2+c*x^4)^(5/2)/c+1/1024*b^5*(7*b*B-12*A*c)*atanh(x^2*sqrt(c)/_
+   sqrt(b*x^2+c*x^4))/c^(9/2)-1/1024*b^4*(7*b*B-12*A*c)*sqrt(b*x^2+_
+   c*x^4)/c^4+1/1536*b^3*(7*b*B-12*A*c)*x^2*sqrt(b*x^2+c*x^4)/c^3-_
+   1/1920*b^2*(7*b*B-12*A*c)*x^4*sqrt(b*x^2+c*x^4)/c^2-1/320*b*(7*b*B-_
+   12*A*c)*x^6*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                        2 +-+
+--R                5          6           x \|c
+--R       (- 180A b c + 105B b )atanh(--------------)
+--R                                    +-----------+
+--R                                    |   4      2
+--R                                   \|c x  + b x
+--R     + 
+--R                  5 10           5            4  8             4        2 3  6
+--R           1280B c x   + (1536A c  + 1664B b c )x  + (2112A b c  + 48B b c )x
+--R         + 
+--R                 2 3        3 2  4            3 2        4   2         4
+--R           (96A b c  - 56B b c )x  + (- 120A b c  + 70B b c)x  + 180A b c
+--R         + 
+--R                   5
+--R           - 105B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R           4 +-+
+--R     15360c \|c
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 1718
+t0:=x^2*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                          +-----------+
+--R              8               6        4  |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 1718
+r0:=-8/3465*b^2*(6*b*B-11*A*c)*(b*x^2+c*x^4)^(5/2)/(c^4*x^5)+_
+   4/693*b*(6*b*B-11*A*c)*(b*x^2+c*x^4)^(5/2)/(c^3*x^3)-_
+   1/99*(6*b*B-11*A*c)*(b*x^2+c*x^4)^(5/2)/(c^2*x)+_
+   1/11*B*x*(b*x^2+c*x^4)^(5/2)/c
+--R 
+--R
+--R   (2)
+--R               5 10          5           4  8            4        2 3  6
+--R         315B c x   + (385A c  + 420B b c )x  + (550A b c  + 15B b c )x
+--R       + 
+--R               2 3        3 2  4           3 2        4   2        4         5
+--R         (33A b c  - 18B b c )x  + (- 44A b c  + 24B b c)x  + 88A b c - 48B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R          4
+--R     3465c x
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 1718
+t0:=x*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                          +-----------+
+--R              7               5        3  |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 1718
+r0:=-1/16*(b*B-2*A*c)*x^2*(b*x^2+c*x^4)^(3/2)/c+1/10*B*(b*x^2+_
+   c*x^4)^(5/2)/c-3/256*b^4*(b*B-2*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+_
+   c*x^4))/c^(7/2)+3/256*b^3*(b*B-2*A*c)*sqrt(b*x^2+c*x^4)/c^3-_
+   1/128*b^2*(b*B-2*A*c)*x^2*sqrt(b*x^2+c*x^4)/c^2-1/32*b*(b*B-2*A*c)*_
+   x^4*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                    2 +-+
+--R             4         5           x \|c
+--R       (30A b c - 15B b )atanh(--------------)
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R     + 
+--R                 4 8          4           3  6            3       2 2  4
+--R           128B c x  + (160A c  + 176B b c )x  + (240A b c  + 8B b c )x
+--R         + 
+--R                 2 2        3   2        3         4
+--R           (20A b c  - 10B b c)x  - 30A b c + 15B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R          3 +-+
+--R     1280c \|c
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                          +-----------+
+--R              6               4        2  |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 1718
+r0:=2/315*b*(4*b*B-9*A*c)*(b*x^2+c*x^4)^(5/2)/(c^3*x^5)-_
+   1/63*(4*b*B-9*A*c)*(b*x^2+c*x^4)^(5/2)/(c^2*x^3)+_
+   1/9*B*(b*x^2+c*x^4)^(5/2)/(c*x)
+--R 
+--R
+--R   (2)
+--R              4 8         4          3  6           3       2 2  4
+--R         35B c x  + (45A c  + 50B b c )x  + (72A b c  + 3B b c )x
+--R       + 
+--R              2 2       3   2        3        4
+--R         (9A b c  - 4B b c)x  - 18A b c + 8B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         3
+--R     315c x
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x
+--R 
+--R
+--R                                         +-----------+
+--R              5               3          |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 1718
+r0:=-1/48*(3*b*B-8*A*c)*(b*x^2+c*x^4)^(3/2)/c+1/8*B*(b*x^2+c*x^4)^(5/2)/_
+   (c*x^2)+1/128*b^3*(3*b*B-8*A*c)*atanh(x^2*sqrt(c)/_
+   sqrt(b*x^2+c*x^4))/c^(5/2)-1/128*b^2*(3*b*B-8*A*c)*sqrt(b*x^2+_
+   c*x^4)/c^2-1/64*b*(3*b*B-8*A*c)*x^2*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                     2 +-+
+--R               3        4           x \|c
+--R       (- 24A b c + 9B b )atanh(--------------)
+--R                                 +-----------+
+--R                                 |   4      2
+--R                                \|c x  + b x
+--R     + 
+--R                3 6         3          2  4            2       2   2        2
+--R           48B c x  + (64A c  + 72B b c )x  + (112A b c  + 6B b c)x  + 24A b c
+--R         + 
+--R                 3
+--R           - 9B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R         2 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^2
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 1718
+r0:=-1/35*(2*b*B-7*A*c)*(b*x^2+c*x^4)^(5/2)/(c^2*x^5)+_
+   1/7*B*(b*x^2+c*x^4)^(5/2)/(c*x^3)
+--R 
+--R
+--R   (2)
+--R            3 6        3         2  4           2      2   2       2        3
+--R       (5B c x  + (7A c  + 8B b c )x  + (14A b c  + B b c)x  + 7A b c - 2B b )
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R        2
+--R     35c x
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^3
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              x
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 1718
+r0:=-1/24*(b*B-6*A*c)*(b*x^2+c*x^4)^(3/2)/(c*x^2)+_
+   1/6*B*(b*x^2+c*x^4)^(5/2)/(c*x^4)-1/16*b^2*(b*B-6*A*c)*atanh(x^2*_
+   sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)-1/16*b*(b*B-6*A*c)*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                   2 +-+
+--R             2        3           x \|c
+--R       (18A b c - 3B b )atanh(--------------)
+--R                               +-----------+
+--R                               |   4      2
+--R                              \|c x  + b x
+--R     + 
+--R                                                              +-----------+
+--R            2 4         2            2                 2  +-+ |   4      2
+--R       (8B c x  + (12A c  + 14B b c)x  + 30A b c + 3B b )\|c \|c x  + b x
+--R  /
+--R         +-+
+--R     48c\|c
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^4
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              2
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 1718
+r0:=1/3*A*(b*x^2+c*x^4)^(3/2)/x^3+1/5*B*(b*x^2+c*x^4)^(5/2)/(c*x^5)-_
+   A*b^(3/2)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))+A*b*sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R   (2)
+--R                                   +-+
+--R                   +-+           x\|b
+--R       - 15A b c x\|b atanh(--------------)
+--R                             +-----------+
+--R                             |   4      2
+--R                            \|c x  + b x
+--R     + 
+--R                                                        +-----------+
+--R            2 4        2           2                 2  |   4      2
+--R       (3B c x  + (5A c  + 6B b c)x  + 20A b c + 3B b )\|c x  + b x
+--R  /
+--R     15c x
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^5
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              3
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 1718
+r0:=1/4*(b*B+4*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^2)-A*(b*x^2+c*x^4)^(5/2)/_
+   (b*x^6)+3/8*b*(b*B+4*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/_
+   sqrt(c)+3/8*(b*B+4*A*c)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R   (2)
+--R                                     2 +-+
+--R                      2  2          x \|c
+--R       (12A b c + 3B b )x atanh(--------------)
+--R                                 +-----------+
+--R                                 |   4      2
+--R                                \|c x  + b x
+--R     + 
+--R                                              +-----------+
+--R              4                 2         +-+ |   4      2
+--R       (2B c x  + (4A c + 5B b)x  - 8A b)\|c \|c x  + b x
+--R  /
+--R       2 +-+
+--R     8x \|c
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^6
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              4
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 1718
+r0:=1/6*(2*b*B+3*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^3)-_
+   1/2*A*(b*x^2+c*x^4)^(5/2)/(b*x^7)-1/2*(2*b*B+3*A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))*sqrt(b)+1/2*(2*b*B+3*A*c)*_
+   sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R   (2)
+--R                                         +-+
+--R                       3 +-+           x\|b
+--R       (- 9A c - 6B b)x \|b atanh(--------------)
+--R                                   +-----------+
+--R                                   |   4      2
+--R                                  \|c x  + b x
+--R     + 
+--R                                          +-----------+
+--R              4                 2         |   4      2
+--R       (2B c x  + (6A c + 8B b)x  - 3A b)\|c x  + b x
+--R  /
+--R       3
+--R     6x
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^7
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              5
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 1718
+r0:=-1/3*(3*b*B+2*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^4)-_
+   1/3*A*(b*x^2+c*x^4)^(5/2)/(b*x^8)+1/2*(3*b*B+2*A*c)*_
+   atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))*sqrt(c)+1/2*c*(3*b*B+2*A*c)*_
+   sqrt(b*x^2+c*x^4)/b
+--R 
+--R
+--R   (2)
+--R                                     2 +-+
+--R                     4 +-+          x \|c
+--R       (6A c + 9B b)x \|c atanh(--------------)
+--R                                 +-----------+
+--R                                 |   4      2
+--R                                \|c x  + b x
+--R     + 
+--R                                            +-----------+
+--R              4                   2         |   4      2
+--R       (3B c x  + (- 8A c - 6B b)x  - 2A b)\|c x  + b x
+--R  /
+--R       4
+--R     6x
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^8
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              6
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 1718
+r0:=-1/8*(4*b*B+A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^5)-_
+   1/4*A*(b*x^2+c*x^4)^(5/2)/(b*x^9)-3/8*c*(4*b*B+A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/sqrt(b)+3/8*c*(4*b*B+A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*x)
+--R 
+--R
+--R   (2)
+--R                                         +-+
+--R              2            5           x\|b
+--R       (- 3A c  - 12B b c)x atanh(--------------)
+--R                                   +-----------+
+--R                                   |   4      2
+--R                                  \|c x  + b x
+--R     + 
+--R                                                +-----------+
+--R              4                   2         +-+ |   4      2
+--R       (8B c x  + (- 5A c - 4B b)x  - 2A b)\|b \|c x  + b x
+--R  /
+--R       5 +-+
+--R     8x \|b
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+)clear all
+
+--S 484 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^9
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              7
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 1718
+r0:=-1/3*B*(b*x^2+c*x^4)^(3/2)/x^6-1/5*A*(b*x^2+c*x^4)^(5/2)/(b*x^10)+_
+   B*c^(3/2)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))-B*c*sqrt(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                                2 +-+
+--R                6 +-+          x \|c
+--R       15B b c x \|c atanh(--------------)
+--R                            +-----------+
+--R                            |   4      2
+--R                           \|c x  + b x
+--R     + 
+--R                                                              +-----------+
+--R               2            4                   2  2       2  |   4      2
+--R       ((- 3A c  - 20B b c)x  + (- 6A b c - 5B b )x  - 3A b )\|c x  + b x
+--R  /
+--R          6
+--R     15b x
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^10
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              8
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 1718
+r0:=-1/24*(6*b*B-A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^7)-_
+   1/6*A*(b*x^2+c*x^4)^(5/2)/(b*x^11)-1/16*c^2*(6*b*B-A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-1/16*c*(6*b*B-A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R   (2)
+--R                                        +-+
+--R            3          2  7           x\|b
+--R       (3A c  - 18B b c )x atanh(--------------)
+--R                                  +-----------+
+--R                                  |   4      2
+--R                                 \|c x  + b x
+--R     + 
+--R                                                                  +-----------+
+--R             2            4                     2  2       2  +-+ |   4      2
+--R     ((- 3A c  - 30B b c)x  + (- 14A b c - 12B b )x  - 8A b )\|b \|c x  + b x
+--R  /
+--R          7 +-+
+--R     48b x \|b
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^11
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              9
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 1718
+r0:=-1/7*A*(b*x^2+c*x^4)^(5/2)/(b*x^12)-1/35*(7*b*B-2*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^10)
+--R 
+--R
+--R   (2)
+--R              3         2  6           2        2   4          2        3  2
+--R         (2A c  - 7B b c )x  + (- A b c  - 14B b c)x  + (- 8A b c - 7B b )x
+--R       + 
+--R               3
+--R         - 5A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R        2 8
+--R     35b x
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^12
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              10
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 1718
+r0:=1/192*c*(8*b*B-3*A*c)*(b*x^2+c*x^4)^(3/2)/(b^2*x^7)-_
+   1/8*A*(b*x^2+c*x^4)^(5/2)/(b*x^13)-1/48*(8*b*B-3*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^11)+1/128*c^3*(8*b*B-3*A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)+1/128*c^2*(8*b*B-3*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^3)
+--R 
+--R
+--R   (2)
+--R                                          +-+
+--R              4          3  9           x\|b
+--R       (- 9A c  + 24B b c )x atanh(--------------)
+--R                                    +-----------+
+--R                                    |   4      2
+--R                                   \|c x  + b x
+--R     + 
+--R                3          2  6            2         2   4
+--R           (9A c  - 24B b c )x  + (- 6A b c  - 112B b c)x
+--R         + 
+--R                   2         3  2        3
+--R           (- 72A b c - 64B b )x  - 48A b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|b \|c x  + b x
+--R  /
+--R         2 9 +-+
+--R     384b x \|b
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^13
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              11
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 1718
+r0:=-1/9*A*(b*x^2+c*x^4)^(5/2)/(b*x^14)-1/63*(9*b*B-4*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^12)+2/315*c*(9*b*B-4*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^3*x^10)
+--R 
+--R
+--R   (2)
+--R                4          3  8          3       2 2  6
+--R         (- 8A c  + 18B b c )x  + (4A b c  - 9B b c )x
+--R       + 
+--R                2 2        3   4           3         4  2        4
+--R         (- 3A b c  - 72B b c)x  + (- 50A b c - 45B b )x  - 35A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         3 10
+--R     315b x
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^14
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              12
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 1718
+r0:=-1/128*c^2*(2*b*B-A*c)*(b*x^2+c*x^4)^(3/2)/(b^3*x^7)-_
+   1/10*A*(b*x^2+c*x^4)^(5/2)/(b*x^15)-1/16*(2*b*B-A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^13)+1/32*c*(2*b*B-A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^3*x^11)-3/256*c^4*(2*b*B-A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(7/2)-3/256*c^3*(2*b*B-A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^3*x^3)
+--R 
+--R
+--R   (2)
+--R                                          +-+
+--R             5          4  11           x\|b
+--R       (15A c  - 30B b c )x  atanh(--------------)
+--R                                    +-----------+
+--R                                    |   4      2
+--R                                   \|c x  + b x
+--R     + 
+--R                   4          3  8           3        2 2  6
+--R           (- 15A c  + 30B b c )x  + (10A b c  - 20B b c )x
+--R         + 
+--R                  2 2         3   4            3          4  2         4
+--R           (- 8A b c  - 240B b c)x  + (- 176A b c - 160B b )x  - 128A b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|b \|c x  + b x
+--R  /
+--R          3 11 +-+
+--R     1280b x  \|b
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^15
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              13
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 1718
+r0:=-1/11*A*(b*x^2+c*x^4)^(5/2)/(b*x^16)-1/99*(11*b*B-6*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^14)+4/693*c*(11*b*B-6*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^3*x^12)-8/3465*c^2*(11*b*B-6*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^4*x^10)
+--R 
+--R
+--R   (2)
+--R               5          4  10             4        2 3  8
+--R         (48A c  - 88B b c )x   + (- 24A b c  + 44B b c )x
+--R       + 
+--R               2 3        3 2  6           3 2         4   4
+--R         (18A b c  - 33B b c )x  + (- 15A b c  - 550B b c)x
+--R       + 
+--R                  4          5  2         5
+--R         (- 420A b c - 385B b )x  - 315A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R          4 12
+--R     3465b x
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^16
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              14
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 1718
+r0:=1/1536*c^3*(12*b*B-7*A*c)*(b*x^2+c*x^4)^(3/2)/(b^4*x^7)-_
+   1/12*A*(b*x^2+c*x^4)^(5/2)/(b*x^17)-1/120*(12*b*B-7*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^2*x^15)+1/192*c*(12*b*B-7*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^3*x^13)-1/384*c^2*(12*b*B-7*A*c)*_
+   (b*x^2+c*x^4)^(5/2)/(b^4*x^11)+1/1024*c^5*(12*b*B-7*A*c)*_
+   atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(9/2)+_
+   1/1024*c^4*(12*b*B-7*A*c)*sqrt(b*x^2+c*x^4)/(b^4*x^3)
+--R 
+--R
+--R   (2)
+--R                                              +-+
+--R                6           5  13           x\|b
+--R       (- 105A c  + 180B b c )x  atanh(--------------)
+--R                                        +-----------+
+--R                                        |   4      2
+--R                                       \|c x  + b x
+--R     + 
+--R                  5           4  10             4         2 3  8
+--R           (105A c  - 180B b c )x   + (- 70A b c  + 120B b c )x
+--R         + 
+--R                 2 3        3 2  6           3 2          4   4
+--R           (56A b c  - 96B b c )x  + (- 48A b c  - 2112B b c)x
+--R         + 
+--R                     4           5  2          5
+--R           (- 1664A b c - 1536B b )x  - 1280A b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|b \|c x  + b x
+--R  /
+--R           4 13 +-+
+--R     15360b x  \|b
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 1718
+t0:=x^7*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             9      7
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 1718
+r0:=5/128*b^3*(7*b*B-8*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(9/2)-_
+   5/128*b^2*(7*b*B-8*A*c)*sqrt(b*x^2+c*x^4)/c^4+5/192*b*(7*b*B-8*A*c)*_
+   x^2*sqrt(b*x^2+c*x^4)/c^3-1/48*(7*b*B-8*A*c)*x^4*sqrt(b*x^2+c*x^4)/c^2+_
+   1/8*B*x^6*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                        2 +-+
+--R                3          4           x \|c
+--R       (- 120A b c + 105B b )atanh(--------------)
+--R                                    +-----------+
+--R                                    |   4      2
+--R                                   \|c x  + b x
+--R     + 
+--R                3 6         3          2  4             2        2   2
+--R           48B c x  + (64A c  - 56B b c )x  + (- 80A b c  + 70B b c)x
+--R         + 
+--R                 2          3
+--R           120A b c - 105B b
+--R      *
+--R              +-----------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x
+--R  /
+--R         4 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 1718
+t0:=x^5*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             7      5
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 1718
+r0:=-1/16*b^2*(5*b*B-6*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(7/2)+_
+   1/16*b*(5*b*B-6*A*c)*sqrt(b*x^2+c*x^4)/c^3-1/24*(5*b*B-6*A*c)*x^2*_
+   sqrt(b*x^2+c*x^4)/c^2+1/6*B*x^4*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                    2 +-+
+--R             2         3           x \|c
+--R       (18A b c - 15B b )atanh(--------------)
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R     + 
+--R                                                               +-----------+
+--R            2 4         2            2                  2  +-+ |   4      2
+--R       (8B c x  + (12A c  - 10B b c)x  - 18A b c + 15B b )\|c \|c x  + b x
+--R  /
+--R        3 +-+
+--R     48c \|c
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 513
+
+)clear all
+
+--S 514 of 1718
+t0:=x^3*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             5      3
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 1718
+r0:=1/8*b*(3*b*B-4*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(5/2)-_
+   1/8*(3*b*B-4*A*c)*sqrt(b*x^2+c*x^4)/c^2+1/4*B*x^2*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                    2 +-+
+--R                       2           x \|c
+--R       (- 4A b c + 3B b )atanh(--------------)
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R     + 
+--R                                   +-----------+
+--R              2                +-+ |   4      2
+--R       (2B c x  + 4A c - 3B b)\|c \|c x  + b x
+--R  /
+--R       2 +-+
+--R     8c \|c
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 1718
+t0:=x*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             3
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 1718
+r0:=-1/2*(b*B-2*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)+_
+   1/2*B*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                               2 +-+              +-----------+
+--R                              x \|c           +-+ |   4      2
+--R        (2A c - B b)atanh(--------------) + B\|c \|c x  + b x
+--R                           +-----------+
+--R                           |   4      2
+--R                          \|c x  + b x
+--R   (2)  -------------------------------------------------------
+--R                                    +-+
+--R                                 2c\|c
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 519
+
+)clear all
+
+--S 520 of 1718
+t0:=(A+B*x^2)/(x*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ---------------
+--R          +-----------+
+--R          |   4      2
+--R        x\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 1718
+r0:=B*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/sqrt(c)-A*sqrt(b*x^2+c*x^4)/(b*x^2)
+--R 
+--R
+--R                         2 +-+              +-----------+
+--R             2          x \|c           +-+ |   4      2
+--R        B b x atanh(--------------) - A\|c \|c x  + b x
+--R                     +-----------+
+--R                     |   4      2
+--R                    \|c x  + b x
+--R   (2)  -------------------------------------------------
+--R                                2 +-+
+--R                             b x \|c
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 1718
+t0:=(A+B*x^2)/(x^3*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         3 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 1718
+r0:=-1/3*A*sqrt(b*x^2+c*x^4)/(b*x^4)-1/3*(3*b*B-2*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^2)
+--R 
+--R
+--R                                +-----------+
+--R                       2        |   4      2
+--R        ((2A c - 3B b)x  - A b)\|c x  + b x
+--R   (2)  -------------------------------------
+--R                          2 4
+--R                        3b x
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 1718
+t0:=(A+B*x^2)/(x^5*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         5 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 1718
+r0:=-1/5*A*sqrt(b*x^2+c*x^4)/(b*x^6)-1/15*(5*b*B-4*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^4)+2/15*c*(5*b*B-4*A*c)*sqrt(b*x^2+c*x^4)/(b^3*x^2)
+--R 
+--R
+--R                                                             +-----------+
+--R                2            4                 2  2       2  |   4      2
+--R        ((- 8A c  + 10B b c)x  + (4A b c - 5B b )x  - 3A b )\|c x  + b x
+--R   (2)  ------------------------------------------------------------------
+--R                                         3 6
+--R                                      15b x
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 1718
+t0:=(A+B*x^2)/(x^7*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         7 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 1718
+r0:=-1/7*A*sqrt(b*x^2+c*x^4)/(b*x^8)-1/35*(7*b*B-6*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^6)+4/105*c*(7*b*B-6*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^3*x^4)-8/105*c^2*(7*b*B-6*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^4*x^2)
+--R 
+--R
+--R   (2)
+--R               3          2  6             2        2   4         2         3  2
+--R         (48A c  - 56B b c )x  + (- 24A b c  + 28B b c)x  + (18A b c - 21B b )x
+--R       + 
+--R                3
+--R         - 15A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         4 8
+--R     105b x
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 531
+
+)clear all
+
+--S 532 of 1718
+t0:=(A+B*x^2)/(x^9*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         9 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 1718
+r0:=-1/9*A*sqrt(b*x^2+c*x^4)/(b*x^10)-1/63*(9*b*B-8*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^8)+2/105*c*(9*b*B-8*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^3*x^6)-8/315*c^2*(9*b*B-8*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^4*x^4)+16/315*c^3*(9*b*B-8*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^5*x^2)
+--R 
+--R
+--R   (2)
+--R                  4           3  8           3        2 2  6
+--R         (- 128A c  + 144B b c )x  + (64A b c  - 72B b c )x
+--R       + 
+--R                 2 2        3   4         3         4  2        4
+--R         (- 48A b c  + 54B b c)x  + (40A b c - 45B b )x  - 35A b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         5 10
+--R     315b x
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 534
+
+)clear all
+
+--S 535 of 1718
+t0:=x^6*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             8      6
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 1718
+r0:=-8/105*b^2*(6*b*B-7*A*c)*sqrt(b*x^2+c*x^4)/(c^4*x)+_
+   4/105*b*(6*b*B-7*A*c)*x*sqrt(b*x^2+c*x^4)/c^3-1/35*(6*b*B-7*A*c)*x^3*_
+   sqrt(b*x^2+c*x^4)/c^2+1/7*B*x^5*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R              3 6         3          2  4             2        2   2        2
+--R         15B c x  + (21A c  - 18B b c )x  + (- 28A b c  + 24B b c)x  + 56A b c
+--R       + 
+--R                3
+--R         - 48B b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R         4
+--R     105c x
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 537
+
+)clear all
+
+--S 538 of 1718
+t0:=x^4*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             6      4
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 1718
+r0:=2/15*b*(4*b*B-5*A*c)*sqrt(b*x^2+c*x^4)/(c^3*x)-1/15*(4*b*B-5*A*c)*x*_
+   sqrt(b*x^2+c*x^4)/c^2+1/5*B*x^3*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                                                         +-----------+
+--R             2 4        2           2                 2  |   4      2
+--R        (3B c x  + (5A c  - 4B b c)x  - 10A b c + 8B b )\|c x  + b x
+--R   (2)  --------------------------------------------------------------
+--R                                        3
+--R                                     15c x
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 1718
+t0:=x^2*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R             4      2
+--R          B x  + A x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 1718
+r0:=-1/3*(2*b*B-3*A*c)*sqrt(b*x^2+c*x^4)/(c^2*x)+1/3*B*x*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                               +-----------+
+--R              2                |   4      2
+--R        (B c x  + 3A c - 2B b)\|c x  + b x
+--R   (2)  ------------------------------------
+--R                          2
+--R                        3c x
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 543
+
+)clear all
+
+--S 544 of 1718
+t0:=(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R              2
+--R           B x  + A
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 1718
+r0:=-A*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/sqrt(b)+B*sqrt(b*x^2+c*x^4)/(c*x)
+--R 
+--R
+--R                             +-+              +-----------+
+--R                           x\|b           +-+ |   4      2
+--R        - A c x atanh(--------------) + B\|b \|c x  + b x
+--R                       +-----------+
+--R                       |   4      2
+--R                      \|c x  + b x
+--R   (2)  ---------------------------------------------------
+--R                                  +-+
+--R                              c x\|b
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 546
+
+)clear all
+
+--S 547 of 1718
+t0:=(A+B*x^2)/(x^2*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         2 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 1718
+r0:=-1/2*(2*b*B-A*c)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-_
+   1/2*A*sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R                                   +-+              +-----------+
+--R                     3           x\|b           +-+ |   4      2
+--R        (A c - 2B b)x atanh(--------------) - A\|b \|c x  + b x
+--R                             +-----------+
+--R                             |   4      2
+--R                            \|c x  + b x
+--R   (2)  ---------------------------------------------------------
+--R                                    3 +-+
+--R                                2b x \|b
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 549
+
+)clear all
+
+--S 550 of 1718
+t0:=(A+B*x^2)/(x^4*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ----------------
+--R           +-----------+
+--R         4 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 1718
+r0:=1/8*c*(4*b*B-3*A*c)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)-_
+   1/4*A*sqrt(b*x^2+c*x^4)/(b*x^5)-1/8*(4*b*B-3*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b^2*x^3)
+--R 
+--R
+--R   (2)
+--R                                        +-+
+--R              2           5           x\|b
+--R       (- 3A c  + 4B b c)x atanh(--------------)
+--R                                  +-----------+
+--R                                  |   4      2
+--R                                 \|c x  + b x
+--R     + 
+--R                                    +-----------+
+--R                      2         +-+ |   4      2
+--R       ((3A c - 4B b)x  - 2A b)\|b \|c x  + b x
+--R  /
+--R       2 5 +-+
+--R     8b x \|b
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 1718
+t0:=x^9*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  9      7
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 1718
+r0:=-5/16*b^2*(7*b*B-6*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(9/2)-_
+   (b*B-A*c)*x^8/(b*c*sqrt(b*x^2+c*x^4))+5/16*b*(7*b*B-6*A*c)*_
+   sqrt(b*x^2+c*x^4)/c^4-5/24*(7*b*B-6*A*c)*x^2*sqrt(b*x^2+c*x^4)/c^3+_
+   1/6*(7*b*B-6*A*c)*x^4*sqrt(b*x^2+c*x^4)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R                           +-----------+           2 +-+
+--R             2          3  |   4      2           x \|c
+--R       (90A b c - 105B b )\|c x  + b x  atanh(--------------)
+--R                                               +-----------+
+--R                                               |   4      2
+--R                                              \|c x  + b x
+--R     + 
+--R               3 8         3          2  6             2        2   4
+--R           8B c x  + (12A c  - 14B b c )x  + (- 30A b c  + 35B b c)x
+--R         + 
+--R                   2          3  2
+--R           (- 90A b c + 105B b )x
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R              +-----------+
+--R        4 +-+ |   4      2
+--R     48c \|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 1718
+t0:=x^7*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  7      5
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 1718
+r0:=3/8*b*(5*b*B-4*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(7/2)-_
+   (b*B-A*c)*x^6/(b*c*sqrt(b*x^2+c*x^4))-3/8*(5*b*B-4*A*c)*_
+   sqrt(b*x^2+c*x^4)/c^3+1/4*(5*b*B-4*A*c)*x^2*sqrt(b*x^2+c*x^4)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R                            +-----------+           2 +-+
+--R                         2  |   4      2           x \|c
+--R       (- 12A b c + 15B b )\|c x  + b x  atanh(--------------)
+--R                                                +-----------+
+--R                                                |   4      2
+--R                                               \|c x  + b x
+--R     + 
+--R            2 6        2           4                   2  2  +-+
+--R       (2B c x  + (4A c  - 5B b c)x  + (12A b c - 15B b )x )\|c
+--R  /
+--R             +-----------+
+--R       3 +-+ |   4      2
+--R     8c \|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 558
+
+)clear all
+
+--S 559 of 1718
+t0:=x^5*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  5      3
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 1718
+r0:=-1/2*(3*b*B-2*A*c)*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(5/2)-_
+   (b*B-A*c)*x^4/(b*c*sqrt(b*x^2+c*x^4))+1/2*(3*b*B-2*A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R                     +-----------+           2 +-+
+--R                     |   4      2           x \|c
+--R       (2A c - 3B b)\|c x  + b x  atanh(--------------)
+--R                                         +-----------+
+--R                                         |   4      2
+--R                                        \|c x  + b x
+--R     + 
+--R             4                   2  +-+
+--R       (B c x  + (- 2A c + 3B b)x )\|c
+--R  /
+--R             +-----------+
+--R       2 +-+ |   4      2
+--R     2c \|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 1718
+t0:=x^3*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  3
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 1718
+r0:=B*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)-(b*B-A*c)*x^2/_
+   (b*c*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R            +-----------+           2 +-+
+--R            |   4      2           x \|c                     2 +-+
+--R        B b\|c x  + b x  atanh(--------------) + (A c - B b)x \|c
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R   (2)  ----------------------------------------------------------
+--R                                   +-----------+
+--R                               +-+ |   4      2
+--R                           b c\|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 1718
+t0:=x*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    2
+--R                 B x  + A
+--R   (1)  --------------------------
+--R                     +-----------+
+--R            3        |   4      2
+--R        (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 1718
+r0:=-A/(b*sqrt(b*x^2+c*x^4))+(b*B-2*A*c)*x^2/(b^2*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                       2
+--R        (- 2A c + B b)x  - A b
+--R   (2)  ----------------------
+--R              +-----------+
+--R            2 |   4      2
+--R           b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 567
+
+)clear all
+
+--S 568 of 1718
+t0:=(A+B*x^2)/(x*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            5      3  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 1718
+r0:=1/3*(3*b*B-4*A*c)/(b^2*sqrt(b*x^2+c*x^4))-1/3*A/(b*x^2*sqrt(b*x^2+_
+   c*x^4))-2/3*(3*b*B-4*A*c)*sqrt(b*x^2+c*x^4)/(b^3*x^2)
+--R 
+--R
+--R             2           4                 2  2      2
+--R        (8A c  - 6B b c)x  + (4A b c - 3B b )x  - A b
+--R   (2)  ----------------------------------------------
+--R                            +-----------+
+--R                        3 2 |   4      2
+--R                      3b x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 1718
+t0:=(A+B*x^2)/(x^3*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            7      5  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 1718
+r0:=-1/5*A/(b*x^4*sqrt(b*x^2+c*x^4))+1/5*(5*b*B-6*A*c)/(b^2*x^2*_
+   sqrt(b*x^2+c*x^4))-4/15*(5*b*B-6*A*c)*sqrt(b*x^2+c*x^4)/(b^3*x^4)+_
+   8/15*c*(5*b*B-6*A*c)*sqrt(b*x^2+c*x^4)/(b^4*x^2)
+--R 
+--R
+--R   (2)
+--R               3          2  6             2        2   4        2        3  2
+--R       (- 48A c  + 40B b c )x  + (- 24A b c  + 20B b c)x  + (6A b c - 5B b )x
+--R     + 
+--R             3
+--R       - 3A b
+--R  /
+--R            +-----------+
+--R        4 4 |   4      2
+--R     15b x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+)clear all
+
+--S 574 of 1718
+t0:=(A+B*x^2)/(x^5*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            9      7  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 1718
+r0:=-1/7*A/(b*x^6*sqrt(b*x^2+c*x^4))+1/7*(7*b*B-8*A*c)/(b^2*x^4*_
+   sqrt(b*x^2+c*x^4))-6/35*(7*b*B-8*A*c)*sqrt(b*x^2+c*x^4)/(b^3*x^6)+_
+   8/35*c*(7*b*B-8*A*c)*sqrt(b*x^2+c*x^4)/(b^4*x^4)-16/35*c^2*(7*b*B-_
+   8*A*c)*sqrt(b*x^2+c*x^4)/(b^5*x^2)
+--R 
+--R
+--R   (2)
+--R              4           3  8           3        2 2  6
+--R       (128A c  - 112B b c )x  + (64A b c  - 56B b c )x
+--R     + 
+--R               2 2        3   4        3        4  2       4
+--R       (- 16A b c  + 14B b c)x  + (8A b c - 7B b )x  - 5A b
+--R  /
+--R            +-----------+
+--R        5 6 |   4      2
+--R     35b x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 1718
+t0:=x^8*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  8      6
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 1718
+r0:=-(b*B-A*c)*x^7/(b*c*sqrt(b*x^2+c*x^4))+8/15*b*(6*b*B-5*A*c)*_
+   sqrt(b*x^2+c*x^4)/(c^4*x)-4/15*(6*b*B-5*A*c)*x*sqrt(b*x^2+c*x^4)/c^3+_
+   1/5*(6*b*B-5*A*c)*x^3*sqrt(b*x^2+c*x^4)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R           3 7        3         2  5             2        2   3
+--R       3B c x  + (5A c  - 6B b c )x  + (- 20A b c  + 24B b c)x
+--R     + 
+--R               2         3
+--R       (- 40A b c + 48B b )x
+--R  /
+--R          +-----------+
+--R        4 |   4      2
+--R     15c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 579
+
+)clear all
+
+--S 580 of 1718
+t0:=x^6*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  6      4
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 1718
+r0:=-(b*B-A*c)*x^5/(b*c*sqrt(b*x^2+c*x^4))-2/3*(4*b*B-3*A*c)*_
+   sqrt(b*x^2+c*x^4)/(c^3*x)+1/3*(4*b*B-3*A*c)*x*sqrt(b*x^2+c*x^4)/(b*c^2)
+--R 
+--R
+--R           2 5        2           3                 2
+--R        B c x  + (3A c  - 4B b c)x  + (6A b c - 8B b )x
+--R   (2)  -----------------------------------------------
+--R                           +-----------+
+--R                         3 |   4      2
+--R                       3c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 1718
+t0:=x^4*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  4      2
+--R               B x  + A x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 1718
+r0:=-(b*B-A*c)*x^3/(b*c*sqrt(b*x^2+c*x^4))+(2*b*B-A*c)*_
+   sqrt(b*x^2+c*x^4)/(b*c^2*x)
+--R 
+--R
+--R             3
+--R        B c x  + (- A c + 2B b)x
+--R   (2)  ------------------------
+--R               +-----------+
+--R             2 |   4      2
+--R            c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 1718
+t0:=x^2*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                   2
+--R                B x  + A
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 1718
+r0:=-A*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-_
+   (b*B-A*c)*x/(b*c*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R              +-----------+             +-+
+--R              |   4      2            x\|b                      +-+
+--R        - A c\|c x  + b x  atanh(--------------) + (A c - B b)x\|b
+--R                                  +-----------+
+--R                                  |   4      2
+--R                                 \|c x  + b x
+--R   (2)  -----------------------------------------------------------
+--R                                   +-----------+
+--R                               +-+ |   4      2
+--R                           b c\|b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 588
+
+)clear all
+
+--S 589 of 1718
+t0:=(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            4      2  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 1718
+r0:=-1/2*(2*b*B-3*A*c)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)-_
+   1/3*B/(c*x*sqrt(b*x^2+c*x^4))+1/3*(-2*b*B+3*A*c)/(b*c*x*_
+   sqrt(b*x^2+c*x^4))+1/2*(2*b*B-3*A*c)*sqrt(b*x^2+c*x^4)/(b^2*c*x^3)
+--R 
+--R
+--R   (2)
+--R                      +-----------+             +-+
+--R                      |   4      2            x\|b
+--R       (3A c - 2B b)x\|c x  + b x  atanh(--------------)
+--R                                          +-----------+
+--R                                          |   4      2
+--R                                         \|c x  + b x
+--R     + 
+--R                        2        +-+
+--R       ((- 3A c + 2B b)x  - A b)\|b
+--R  /
+--R              +-----------+
+--R       2  +-+ |   4      2
+--R     2b x\|b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 591
+
+)clear all
+
+--S 592 of 1718
+t0:=(A+B*x^2)/(x^2*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            6      4  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 1718
+r0:=3/8*c*(4*b*B-5*A*c)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(7/2)-_
+   1/4*A/(b*x^3*sqrt(b*x^2+c*x^4))+1/4*(4*b*B-5*A*c)/(b^2*x*_
+   sqrt(b*x^2+c*x^4))-3/8*(4*b*B-5*A*c)*sqrt(b*x^2+c*x^4)/(b^3*x^3)
+--R 
+--R
+--R   (2)
+--R                              +-----------+             +-+
+--R               2            3 |   4      2            x\|b
+--R       (- 15A c  + 12B b c)x \|c x  + b x  atanh(--------------)
+--R                                                  +-----------+
+--R                                                  |   4      2
+--R                                                 \|c x  + b x
+--R     + 
+--R              2            4                 2  2       2  +-+
+--R       ((15A c  - 12B b c)x  + (5A b c - 4B b )x  - 2A b )\|b
+--R  /
+--R               +-----------+
+--R       3 3 +-+ |   4      2
+--R     8b x \|b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 594
+
+)clear all
+
+--S 595 of 1718
+t0:=x^(7/2)*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R              9               7        5  +-+
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 1718
+r0:=2/13*A*b*x^(13/2)+2/17*(b*B+A*c)*x^(17/2)+2/21*B*c*x^(21/2)
+--R 
+--R
+--R                 10                     8           6  +-+
+--R        (442B c x   + (546A c + 546B b)x  + 714A b x )\|x
+--R   (2)  --------------------------------------------------
+--R                               4641
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 597
+
+)clear all
+
+--S 598 of 1718
+t0:=x^(5/2)*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R              8               6        4  +-+
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 1718
+r0:=2/11*A*b*x^(11/2)+2/15*(b*B+A*c)*x^(15/2)+2/19*B*c*x^(19/2)
+--R 
+--R
+--R                 9                     7           5  +-+
+--R        (330B c x  + (418A c + 418B b)x  + 570A b x )\|x
+--R   (2)  -------------------------------------------------
+--R                               3135
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)clear all
+
+--S 601 of 1718
+t0:=x^(3/2)*(A+B*x^2)*(b*x^2+c*x^4)
+--R 
+--R
+--R              7               5        3  +-+
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 1718
+r0:=2/9*A*b*x^(9/2)+2/13*(b*B+A*c)*x^(13/2)+2/17*B*c*x^(17/2)
+--R 
+--R
+--R                 8                     6           4  +-+
+--R        (234B c x  + (306A c + 306B b)x  + 442A b x )\|x
+--R   (2)  -------------------------------------------------
+--R                               1989
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 603
+
+)clear all
+
+--S 604 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)*sqrt(x)
+--R 
+--R
+--R              6               4        2  +-+
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 1718
+r0:=2/7*A*b*x^(7/2)+2/11*(b*B+A*c)*x^(11/2)+2/15*B*c*x^(15/2)
+--R 
+--R
+--R                 7                     5           3  +-+
+--R        (154B c x  + (210A c + 210B b)x  + 330A b x )\|x
+--R   (2)  -------------------------------------------------
+--R                               1155
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 606
+
+)clear all
+
+--S 607 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/sqrt(x)
+--R 
+--R
+--R             6               4        2
+--R        B c x  + (A c + B b)x  + A b x
+--R   (1)  -------------------------------
+--R                       +-+
+--R                      \|x
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 1718
+r0:=2/5*A*b*x^(5/2)+2/9*(b*B+A*c)*x^(9/2)+2/13*B*c*x^(13/2)
+--R 
+--R
+--R                6                     4           2  +-+
+--R        (90B c x  + (130A c + 130B b)x  + 234A b x )\|x
+--R   (2)  ------------------------------------------------
+--R                               585
+--R                                                    Type: Expression(Integer)
+--E 608
+
+--S 609 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 609
+
+)clear all
+
+--S 610 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^(3/2)
+--R 
+--R
+--R             5               3
+--R        B c x  + (A c + B b)x  + A b x
+--R   (1)  ------------------------------
+--R                      +-+
+--R                     \|x
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 1718
+r0:=2/3*A*b*x^(3/2)+2/7*(b*B+A*c)*x^(7/2)+2/11*B*c*x^(11/2)
+--R 
+--R
+--R                5                   3             +-+
+--R        (42B c x  + (66A c + 66B b)x  + 154A b x)\|x
+--R   (2)  ---------------------------------------------
+--R                             231
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 612
+
+)clear all
+
+--S 613 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^(5/2)
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                     +-+
+--R                    \|x
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 1718
+r0:=2/5*(b*B+A*c)*x^(5/2)+2/9*B*c*x^(9/2)+2*A*b*sqrt(x)
+--R 
+--R
+--R                4                   2          +-+
+--R        (10B c x  + (18A c + 18B b)x  + 90A b)\|x
+--R   (2)  ------------------------------------------
+--R                            45
+--R                                                    Type: Expression(Integer)
+--E 614
+
+--S 615 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 615
+
+)clear all
+
+--S 616 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)/x^(7/2)
+--R 
+--R
+--R             4               2
+--R        B c x  + (A c + B b)x  + A b
+--R   (1)  ----------------------------
+--R                      +-+
+--R                    x\|x
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 1718
+r0:=2/3*(b*B+A*c)*x^(3/2)+2/7*B*c*x^(7/2)-2*A*b/sqrt(x)
+--R 
+--R
+--R              4                   2
+--R        6B c x  + (14A c + 14B b)x  - 42A b
+--R   (2)  -----------------------------------
+--R                          +-+
+--R                       21\|x
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 618
+
+)clear all
+
+--S 619 of 1718
+t0:=x^(7/2)*(A+B*x^2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R            2 13       2           11                2  9      2 7  +-+
+--R   (1)  (B c x   + (A c  + 2B b c)x   + (2A b c + B b )x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 619
+
+--S 620 of 1718
+r0:=2/17*A*b^2*x^(17/2)+2/21*b*(b*B+2*A*c)*x^(21/2)+_
+   2/25*c*(2*b*B+A*c)*x^(25/2)+2/29*B*c^2*x^(29/2)
+--R 
+--R
+--R   (2)
+--R                 2 14            2               12
+--R         17850B c x   + (20706A c  + 41412B b c)x
+--R       + 
+--R                               2  10           2 8
+--R         (49300A b c + 24650B b )x   + 30450A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     258825
+--R                                                    Type: Expression(Integer)
+--E 620
+
+--S 621 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 621
+
+)clear all
+
+--S 622 of 1718
+t0:=x^(5/2)*(A+B*x^2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R            2 12       2           10                2  8      2 6  +-+
+--R   (1)  (B c x   + (A c  + 2B b c)x   + (2A b c + B b )x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 1718
+r0:=2/15*A*b^2*x^(15/2)+2/19*b*(b*B+2*A*c)*x^(19/2)+_
+   2/23*c*(2*b*B+A*c)*x^(23/2)+2/27*B*c^2*x^(27/2)
+--R 
+--R
+--R   (2)
+--R                2 13           2               11                        2  9
+--R         4370B c x   + (5130A c  + 10260B b c)x   + (12420A b c + 6210B b )x
+--R       + 
+--R                2 7
+--R         7866A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     58995
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 624
+
+)clear all
+
+--S 625 of 1718
+t0:=x^(3/2)*(A+B*x^2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R            2 11       2           9                2  7      2 5  +-+
+--R   (1)  (B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 1718
+r0:=2/13*A*b^2*x^(13/2)+2/17*b*(b*B+2*A*c)*x^(17/2)+_
+   2/21*c*(2*b*B+A*c)*x^(21/2)+2/25*B*c^2*x^(25/2)
+--R 
+--R
+--R   (2)
+--R                2 12            2               10                         2  8
+--R         9282B c x   + (11050A c  + 22100B b c)x   + (27300A b c + 13650B b )x
+--R       + 
+--R                 2 6
+--R         17850A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     116025
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 627
+
+)clear all
+
+--S 628 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2*sqrt(x)
+--R 
+--R
+--R            2 10       2           8                2  6      2 4  +-+
+--R   (1)  (B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 628
+
+--S 629 of 1718
+r0:=2/11*A*b^2*x^(11/2)+2/15*b*(b*B+2*A*c)*x^(15/2)+_
+   2/19*c*(2*b*B+A*c)*x^(19/2)+2/23*B*c^2*x^(23/2)
+--R 
+--R
+--R   (2)
+--R                2 11           2               9                        2  7
+--R         6270B c x   + (7590A c  + 15180B b c)x  + (19228A b c + 9614B b )x
+--R       + 
+--R                 2 5
+--R         13110A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     72105
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 630
+
+)clear all
+
+--S 631 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/sqrt(x)
+--R 
+--R
+--R           2 10       2           8                2  6      2 4
+--R        B c x   + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  --------------------------------------------------------
+--R                                   +-+
+--R                                  \|x
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 1718
+r0:=2/9*A*b^2*x^(9/2)+2/13*b*(b*B+2*A*c)*x^(13/2)+_
+   2/17*c*(2*b*B+A*c)*x^(17/2)+2/21*B*c^2*x^(21/2)
+--R 
+--R
+--R   (2)
+--R                2 10           2              8                       2  6
+--R         1326B c x   + (1638A c  + 3276B b c)x  + (4284A b c + 2142B b )x
+--R       + 
+--R                2 4
+--R         3094A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     13923
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 633
+
+)clear all
+
+--S 634 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^(3/2)
+--R 
+--R
+--R           2 9       2           7                2  5      2 3
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                                   +-+
+--R                                  \|x
+--R                                                    Type: Expression(Integer)
+--E 634
+
+--S 635 of 1718
+r0:=2/7*A*b^2*x^(7/2)+2/11*b*(b*B+2*A*c)*x^(11/2)+_
+   2/15*c*(2*b*B+A*c)*x^(15/2)+2/19*B*c^2*x^(19/2)
+--R 
+--R
+--R   (2)
+--R                2 9           2              7                       2  5
+--R         2310B c x  + (2926A c  + 5852B b c)x  + (7980A b c + 3990B b )x
+--R       + 
+--R                2 3
+--R         6270A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     21945
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 636
+
+)clear all
+
+--S 637 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^(5/2)
+--R 
+--R
+--R           2 8       2           6                2  4      2 2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  -------------------------------------------------------
+--R                                   +-+
+--R                                  \|x
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 1718
+r0:=2/5*A*b^2*x^(5/2)+2/9*b*(b*B+2*A*c)*x^(9/2)+_
+   2/13*c*(2*b*B+A*c)*x^(13/2)+2/17*B*c^2*x^(17/2)
+--R 
+--R
+--R   (2)
+--R                2 8           2              6                       2  4
+--R         1170B c x  + (1530A c  + 3060B b c)x  + (4420A b c + 2210B b )x
+--R       + 
+--R                2 2
+--R         3978A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     9945
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 639
+
+)clear all
+
+--S 640 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^2/x^(7/2)
+--R 
+--R
+--R           2 7       2           5                2  3      2
+--R        B c x  + (A c  + 2B b c)x  + (2A b c + B b )x  + A b x
+--R   (1)  ------------------------------------------------------
+--R                                  +-+
+--R                                 \|x
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 1718
+r0:=2/3*A*b^2*x^(3/2)+2/7*b*(b*B+2*A*c)*x^(7/2)+_
+   2/11*c*(2*b*B+A*c)*x^(11/2)+2/15*B*c^2*x^(15/2)
+--R 
+--R
+--R   (2)
+--R          2 7          2             5                     2  3         2   +-+
+--R   (154B c x  + (210A c  + 420B b c)x  + (660A b c + 330B b )x  + 770A b x)\|x
+--R   ----------------------------------------------------------------------------
+--R                                       1155
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 642
+
+)clear all
+
+--S 643 of 1718
+t0:=x^(7/2)*(A+B*x^2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R          3 17       3         2  15          2       2   13
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x
+--R     + 
+--R            2       3  11      3 9
+--R       (3A b c + B b )x   + A b x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 1718
+r0:=2/21*A*b^3*x^(21/2)+2/25*b^2*(b*B+3*A*c)*x^(25/2)+_
+   6/29*b*c*(b*B+A*c)*x^(29/2)+2/33*c^2*(3*b*B+A*c)*x^(33/2)+_
+   2/37*B*c^3*x^(37/2)
+--R 
+--R
+--R   (2)
+--R                  3 18             3               2  16
+--R         334950B c x   + (375550A c  + 1126650B b c )x
+--R       + 
+--R                      2             2   14              2             3  12
+--R         (1282050A b c  + 1282050B b c)x   + (1487178A b c + 495726B b )x
+--R       + 
+--R                  3 10
+--R         590150A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     6196575
+--R                                                    Type: Expression(Integer)
+--E 644
+
+--S 645 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 645
+
+)clear all
+
+--S 646 of 1718
+t0:=x^(5/2)*(A+B*x^2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R          3 16       3         2  14          2       2   12
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x
+--R     + 
+--R            2       3  10      3 8
+--R       (3A b c + B b )x   + A b x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 1718
+r0:=2/19*A*b^3*x^(19/2)+2/23*b^2*(b*B+3*A*c)*x^(23/2)+_
+   2/9*b*c*(b*B+A*c)*x^(27/2)+2/31*c^2*(3*b*B+A*c)*x^(31/2)+2/35*B*c^3*x^(35/2)
+--R 
+--R
+--R   (2)
+--R                  3 17             3              2  15
+--R         243846B c x   + (275310A c  + 825930B b c )x
+--R       + 
+--R                     2            2   13              2             3  11
+--R         (948290A b c  + 948290B b c)x   + (1113210A b c + 371070B b )x
+--R       + 
+--R                  3 9
+--R         449190A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     4267305
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 648
+
+)clear all
+
+--S 649 of 1718
+t0:=x^(3/2)*(A+B*x^2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R          3 15       3         2  13          2       2   11        2       3  9
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x   + (3A b c + B b )x
+--R     + 
+--R          3 7
+--R       A b x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 649
+
+--S 650 of 1718
+r0:=2/17*A*b^3*x^(17/2)+2/21*b^2*(b*B+3*A*c)*x^(21/2)+_
+   6/25*b*c*(b*B+A*c)*x^(25/2)+2/29*c^2*(3*b*B+A*c)*x^(29/2)+_
+   2/33*B*c^3*x^(33/2)
+--R 
+--R
+--R   (2)
+--R                  3 16             3              2  14
+--R         172550B c x   + (196350A c  + 589050B b c )x
+--R       + 
+--R                     2            2   12             2             3  10
+--R         (683298A b c  + 683298B b c)x   + (813450A b c + 271150B b )x
+--R       + 
+--R                  3 8
+--R         334950A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     2847075
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 651
+
+)clear all
+
+--S 652 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3*sqrt(x)
+--R 
+--R
+--R   (1)
+--R          3 14       3         2  12          2       2   10        2       3  8
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x   + (3A b c + B b )x
+--R     + 
+--R          3 6
+--R       A b x
+--R  *
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 1718
+r0:=2/15*A*b^3*x^(15/2)+2/19*b^2*(b*B+3*A*c)*x^(19/2)+_
+   6/23*b*c*(b*B+A*c)*x^(23/2)+2/27*c^2*(3*b*B+A*c)*x^(27/2)+_
+   2/31*B*c^3*x^(31/2)
+--R 
+--R
+--R   (2)
+--R                  3 15             3              2  13
+--R         117990B c x   + (135470A c  + 406410B b c )x
+--R       + 
+--R                     2            2   11             2             3  9
+--R         (477090A b c  + 477090B b c)x   + (577530A b c + 192510B b )x
+--R       + 
+--R                  3 7
+--R         243846A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     1828845
+--R                                                    Type: Expression(Integer)
+--E 653
+
+--S 654 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 654
+
+)clear all
+
+--S 655 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/sqrt(x)
+--R 
+--R
+--R   (1)
+--R          3 14       3         2  12          2       2   10        2       3  8
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x   + (3A b c + B b )x
+--R     + 
+--R          3 6
+--R       A b x
+--R  /
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 1718
+r0:=2/13*A*b^3*x^(13/2)+2/17*b^2*(b*B+3*A*c)*x^(17/2)+_
+   2/7*b*c*(b*B+A*c)*x^(21/2)+2/25*c^2*(3*b*B+A*c)*x^(25/2)+2/29*B*c^3*x^(29/2)
+--R 
+--R
+--R   (2)
+--R                 3 14            3              2  12
+--R         77350B c x   + (89726A c  + 269178B b c )x
+--R       + 
+--R                     2            2   10             2             3  8
+--R         (320450A b c  + 320450B b c)x   + (395850A b c + 131950B b )x
+--R       + 
+--R                  3 6
+--R         172550A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     1121575
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 657
+
+)clear all
+
+--S 658 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^(3/2)
+--R 
+--R
+--R   (1)
+--R          3 13       3         2  11          2       2   9        2       3  7
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 5
+--R       A b x
+--R  /
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 658
+
+--S 659 of 1718
+r0:=2/11*A*b^3*x^(11/2)+2/15*b^2*(b*B+3*A*c)*x^(15/2)+_
+   6/19*b*c*(b*B+A*c)*x^(19/2)+2/23*c^2*(3*b*B+A*c)*x^(23/2)+_
+   2/27*B*c^3*x^(27/2)
+--R 
+--R
+--R   (2)
+--R                 3 13            3              2  11
+--R         48070B c x   + (56430A c  + 169290B b c )x
+--R       + 
+--R                     2            2   9             2            3  7
+--R         (204930A b c  + 204930B b c)x  + (259578A b c + 86526B b )x
+--R       + 
+--R                  3 5
+--R         117990A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     648945
+--R                                                    Type: Expression(Integer)
+--E 659
+
+--S 660 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 660
+
+)clear all
+
+--S 661 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^(5/2)
+--R 
+--R
+--R   (1)
+--R          3 12       3         2  10          2       2   8        2       3  6
+--R       B c x   + (A c  + 3B b c )x   + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 4
+--R       A b x
+--R  /
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 1718
+r0:=2/9*A*b^3*x^(9/2)+2/13*b^2*(b*B+3*A*c)*x^(13/2)+_
+   6/17*b*c*(b*B+A*c)*x^(17/2)+2/21*c^2*(3*b*B+A*c)*x^(21/2)+_
+   2/25*B*c^3*x^(25/2)
+--R 
+--R
+--R   (2)
+--R                 3 12            3             2  10
+--R         27846B c x   + (33150A c  + 99450B b c )x
+--R       + 
+--R                     2            2   8             2            3  6
+--R         (122850A b c  + 122850B b c)x  + (160650A b c + 53550B b )x
+--R       + 
+--R                 3 4
+--R         77350A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     348075
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 663
+
+)clear all
+
+--S 664 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^3/x^(7/2)
+--R 
+--R
+--R   (1)
+--R          3 11       3         2  9          2       2   7        2       3  5
+--R       B c x   + (A c  + 3B b c )x  + (3A b c  + 3B b c)x  + (3A b c + B b )x
+--R     + 
+--R          3 3
+--R       A b x
+--R  /
+--R      +-+
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 664
+
+--S 665 of 1718
+r0:=2/7*A*b^3*x^(7/2)+2/11*b^2*(b*B+3*A*c)*x^(11/2)+_
+   2/5*b*c*(b*B+A*c)*x^(15/2)+2/19*c^2*(3*b*B+A*c)*x^(19/2)+2/23*B*c^3*x^(23/2)
+--R 
+--R
+--R   (2)
+--R                 3 11            3             2  9
+--R         14630B c x   + (17710A c  + 53130B b c )x
+--R       + 
+--R                  2           2   7            2            3  5           3 3
+--R       (67298A b c  + 67298B b c)x  + (91770A b c + 30590B b )x  + 48070A b x
+--R    *
+--R        +-+
+--R       \|x
+--R  /
+--R     168245
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 666
+
+)clear all
+
+--S 667 of 1718
+t0:=x^(13/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            6      4  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R                2
+--R             c x  + b
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 1718
+r0:=2/3*b*(b*B-A*c)*x^(3/2)/c^3-2/7*(b*B-A*c)*x^(7/2)/c^2+_
+   2/11*B*x^(11/2)/c+b^(7/4)*(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(c^(15/4)*sqrt(2))-b^(7/4)*(b*B-A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(c^(15/4)*sqrt(2))-1/2*b^(7/4)*(b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(15/4)*_
+   sqrt(2))+1/2*b^(7/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+_
+   b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                           2 4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 231A b c + 231B b )\|b  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                         2 4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (231A b c - 231B b )\|b  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                      +-+4+-+ +-+   4+-+
+--R                         2 4+-+3     \|2 \|c \|x  + \|b
+--R       (462A b c - 462B b )\|b  atan(-------------------)
+--R                                             4+-+
+--R                                             \|b
+--R     + 
+--R                                      +-+4+-+ +-+   4+-+
+--R                         2 4+-+3     \|2 \|c \|x  - \|b
+--R       (462A b c - 462B b )\|b  atan(-------------------)
+--R                                             4+-+
+--R                                             \|b
+--R     + 
+--R           2 5          2             3                       2    +-+4+-+3 +-+
+--R     (84B c x  + (132A c  - 132B b c)x  + (- 308A b c + 308B b )x)\|2 \|c  \|x
+--R  /
+--R         3 +-+4+-+3
+--R     462c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 668
+
+--S 669 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 669
+
+)clear all
+
+--S 670 of 1718
+t0:=x^(11/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            5      3  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R                2
+--R             c x  + b
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 1718
+r0:=-2/5*(b*B-A*c)*x^(5/2)/c^2+2/9*B*x^(9/2)/c+b^(5/4)*(b*B-A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(13/4)*sqrt(2))-b^(5/4)*_
+   (b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(13/4)*sqrt(2))+_
+   1/2*b^(5/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(c^(13/4)*sqrt(2))-1/2*b^(5/4)*(b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(13/4)*_
+   sqrt(2))+2*b*(b*B-A*c)*sqrt(x)/c^3
+--R 
+--R
+--R   (2)
+--R                       2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45A b c - 45B b )\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                         2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45A b c + 45B b )\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                       2 4+-+     \|2 \|c \|x  + \|b
+--R       (90A b c - 90B b )\|b atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                       2 4+-+     \|2 \|c \|x  - \|b
+--R       (90A b c - 90B b )\|b atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R             2 4         2            2                    2  +-+4+-+ +-+
+--R       (20B c x  + (36A c  - 36B b c)x  - 180A b c + 180B b )\|2 \|c \|x
+--R  /
+--R        3 +-+4+-+
+--R     90c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 672
+
+)clear all
+
+--S 673 of 1718
+t0:=x^(9/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            4      2  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R                2
+--R             c x  + b
+--R                                                    Type: Expression(Integer)
+--E 673
+
+--S 674 of 1718
+r0:=-2/3*(b*B-A*c)*x^(3/2)/c^2+2/7*B*x^(7/2)/c-b^(3/4)*(b*B-A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(11/4)*sqrt(2))+b^(3/4)*_
+   (b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(11/4)*sqrt(2))+_
+   1/2*b^(3/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(c^(11/4)*sqrt(2))-1/2*b^(3/4)*(b*B-A*c)*log(sqrt(b)+x*_
+   sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                      4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21A c - 21B b)\|b  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                        4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21A c + 21B b)\|b  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                        4+-+3     \|2 \|c \|x  + \|b
+--R       (- 42A c + 42B b)\|b  atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R                                   +-+4+-+ +-+   4+-+
+--R                        4+-+3     \|2 \|c \|x  - \|b
+--R       (- 42A c + 42B b)\|b  atan(-------------------)
+--R                                          4+-+
+--R                                          \|b
+--R     + 
+--R               3                     +-+4+-+3 +-+
+--R       (12B c x  + (28A c - 28B b)x)\|2 \|c  \|x
+--R  /
+--R        2 +-+4+-+3
+--R     42c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+)clear all
+
+--S 676 of 1718
+t0:=x^(7/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            3        +-+
+--R        (B x  + A x)\|x
+--R   (1)  ----------------
+--R               2
+--R            c x  + b
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 1718
+r0:=2/5*B*x^(5/2)/c-b^(1/4)*(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(c^(9/4)*sqrt(2))+b^(1/4)*(b*B-A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(c^(9/4)*sqrt(2))-1/2*b^(1/4)*(b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(9/4)*_
+   sqrt(2))+1/2*b^(1/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(c^(9/4)*sqrt(2))-2*(b*B-A*c)*sqrt(x)/c^2
+--R 
+--R
+--R   (2)
+--R                      4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5A c + 5B b)\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5A c - 5B b)\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R                        4+-+     \|2 \|c \|x  + \|b
+--R       (- 10A c + 10B b)\|b atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R                        4+-+     \|2 \|c \|x  - \|b
+--R       (- 10A c + 10B b)\|b atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R              2                  +-+4+-+ +-+
+--R       (4B c x  + 20A c - 20B b)\|2 \|c \|x
+--R  /
+--R        2 +-+4+-+
+--R     10c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 678
+
+)clear all
+
+--S 679 of 1718
+t0:=x^(5/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            2      +-+
+--R        (B x  + A)\|x
+--R   (1)  --------------
+--R              2
+--R           c x  + b
+--R                                                    Type: Expression(Integer)
+--E 679
+
+--S 680 of 1718
+r0:=2/3*B*x^(3/2)/c+(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (b^(1/4)*c^(7/4)*sqrt(2))-(b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(1/4)*c^(7/4)*sqrt(2))-1/2*(b*B-A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*c^(7/4)*_
+   sqrt(2))+1/2*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(1/4)*c^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3A c + 3B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3A c - 3B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  + \|b
+--R       (6A c - 6B b)atan(-------------------)
+--R                                 4+-+
+--R                                 \|b
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  - \|b          +-+4+-+4+-+3 +-+
+--R       (6A c - 6B b)atan(-------------------) + 4B x\|2 \|b \|c  \|x
+--R                                 4+-+
+--R                                 \|b
+--R  /
+--R        +-+4+-+4+-+3
+--R     6c\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 681
+
+)clear all
+
+--S 682 of 1718
+t0:=x^(3/2)*(A+B*x^2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            2      +-+
+--R        (B x  + A)\|x
+--R   (1)  --------------
+--R             3
+--R          c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 1718
+r0:=(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(5/4)*_
+   sqrt(2))-(b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*_
+   c^(5/4)*sqrt(2))+1/2*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(3/4)*c^(5/4)*sqrt(2))-1/2*(b*B-A*c)*log(sqrt(b)+_
+   x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*c^(5/4)*_
+   sqrt(2))+2*B*sqrt(x)/c
+--R 
+--R
+--R   (2)
+--R                       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  + \|b
+--R       (2A c - 2B b)atan(-------------------)
+--R                                 4+-+
+--R                                 \|b
+--R     + 
+--R                          +-+4+-+ +-+   4+-+
+--R                         \|2 \|c \|x  - \|b        +-+4+-+3 4+-+ +-+
+--R       (2A c - 2B b)atan(-------------------) + 4B\|2 \|b   \|c \|x
+--R                                 4+-+
+--R                                 \|b
+--R  /
+--R        +-+4+-+3 4+-+
+--R     2c\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 683
+
+--S 684 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 684
+
+)clear all
+
+--S 685 of 1718
+t0:=(A+B*x^2)*sqrt(x)/(b*x^2+c*x^4)
+--R 
+--R
+--R            2      +-+
+--R        (B x  + A)\|x
+--R   (1)  --------------
+--R             4      2
+--R          c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 685
+
+--S 686 of 1718
+r0:=-(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*c^(3/4)*_
+   sqrt(2))+(b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*_
+   c^(3/4)*sqrt(2))+1/2*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(5/4)*c^(3/4)*sqrt(2))-1/2*(b*B-A*c)*log(sqrt(b)+_
+   x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*c^(3/4)*sqrt(2))-_
+   2*A/(b*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                   +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (A c - B b)\|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- A c + B b)\|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                +-+4+-+ +-+   4+-+
+--R                       +-+     \|2 \|c \|x  + \|b
+--R       (- 2A c + 2B b)\|x atan(-------------------)
+--R                                       4+-+
+--R                                       \|b
+--R     + 
+--R                                +-+4+-+ +-+   4+-+
+--R                       +-+     \|2 \|c \|x  - \|b        +-+4+-+4+-+3
+--R       (- 2A c + 2B b)\|x atan(-------------------) - 4A\|2 \|b \|c
+--R                                       4+-+
+--R                                       \|b
+--R  /
+--R        +-+4+-+4+-+3 +-+
+--R     2b\|2 \|b \|c  \|x
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 687
+
+)clear all
+
+--S 688 of 1718
+t0:=(A+B*x^2)/((b*x^2+c*x^4)*sqrt(x))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R            4      2  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 688
+
+--S 689 of 1718
+r0:=-2/3*A/(b*x^(3/2))-(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (b^(7/4)*c^(1/4)*sqrt(2))+(b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(7/4)*c^(1/4)*sqrt(2))-1/2*(b*B-A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*c^(1/4)*sqrt(2))+_
+   1/2*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(7/4)*c^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                        +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3A c + 3B b)x\|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                      +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3A c - 3B b)x\|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R                        +-+     \|2 \|c \|x  + \|b
+--R       (- 6A c + 6B b)x\|x atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R                        +-+     \|2 \|c \|x  - \|b        +-+4+-+3 4+-+
+--R       (- 6A c + 6B b)x\|x atan(-------------------) - 4A\|2 \|b   \|c
+--R                                        4+-+
+--R                                        \|b
+--R  /
+--R          +-+4+-+3 4+-+ +-+
+--R     6b x\|2 \|b   \|c \|x
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 690
+
+)clear all
+
+--S 691 of 1718
+t0:=(A+B*x^2)/(x^(3/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R            5      3  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 691
+
+--S 692 of 1718
+r0:=-2/5*A/(b*x^(5/2))+c^(1/4)*(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(9/4)*sqrt(2))-c^(1/4)*(b*B-A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(9/4)*sqrt(2))-1/2*c^(1/4)*(b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*_
+   sqrt(2))+1/2*c^(1/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(9/4)*sqrt(2))-2*(b*B-A*c)/(b^2*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                       2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5A c + 5B b)x  \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     2 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5A c - 5B b)x  \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R                       2 4+-+ +-+     \|2 \|c \|x  + \|b
+--R       (10A c - 10B b)x  \|c \|x atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R                       2 4+-+ +-+     \|2 \|c \|x  - \|b
+--R       (10A c - 10B b)x  \|c \|x atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R                        2         +-+4+-+
+--R       ((20A c - 20B b)x  - 4A b)\|2 \|b
+--R  /
+--R        2 2 +-+4+-+ +-+
+--R     10b x \|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 693
+
+)clear all
+
+--S 694 of 1718
+t0:=(A+B*x^2)/(x^(5/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R            6      4  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 694
+
+--S 695 of 1718
+r0:=-2/7*A/(b*x^(7/2))-2/3*(b*B-A*c)/(b^2*x^(3/2))+c^(3/4)*(b*B-A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*sqrt(2))-c^(3/4)*_
+   (b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*sqrt(2))+_
+   1/2*c^(3/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(11/4)*sqrt(2))-1/2*c^(3/4)*(b*B-A*c)*log(sqrt(b)+x*_
+   sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                       3 4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21A c - 21B b)x  \|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                         3 4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21A c + 21B b)x  \|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R                       3 4+-+3 +-+     \|2 \|c \|x  + \|b
+--R       (42A c - 42B b)x  \|c  \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|b
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R                       3 4+-+3 +-+     \|2 \|c \|x  - \|b
+--R       (42A c - 42B b)x  \|c  \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|b
+--R     + 
+--R                        2          +-+4+-+3
+--R       ((28A c - 28B b)x  - 12A b)\|2 \|b
+--R  /
+--R        2 3 +-+4+-+3 +-+
+--R     42b x \|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 696
+
+)clear all
+
+--S 697 of 1718
+t0:=(A+B*x^2)/(x^(7/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R            7      5  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 1718
+r0:=-2/9*A/(b*x^(9/2))-2/5*(b*B-A*c)/(b^2*x^(5/2))-c^(5/4)*(b*B-A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*sqrt(2))+c^(5/4)*_
+   (b*B-A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*sqrt(2))+_
+   1/2*c^(5/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(13/4)*sqrt(2))-1/2*c^(5/4)*(b*B-A*c)*log(sqrt(b)+x*_
+   sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*sqrt(2))+_
+   2*c*(b*B-A*c)/(b^3*sqrt(x))
+--R 
+--R
+--R   (2)
+--R             2            4 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45A c  - 45B b c)x  \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               2            4 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45A c  + 45B b c)x  \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                            +-+4+-+ +-+   4+-+
+--R               2            4 4+-+ +-+     \|2 \|c \|x  + \|b
+--R       (- 90A c  + 90B b c)x  \|c \|x atan(-------------------)
+--R                                                   4+-+
+--R                                                   \|b
+--R     + 
+--R                                            +-+4+-+ +-+   4+-+
+--R               2            4 4+-+ +-+     \|2 \|c \|x  - \|b
+--R       (- 90A c  + 90B b c)x  \|c \|x atan(-------------------)
+--R                                                   4+-+
+--R                                                   \|b
+--R     + 
+--R                 2             4                   2  2        2  +-+4+-+
+--R       ((- 180A c  + 180B b c)x  + (36A b c - 36B b )x  - 20A b )\|2 \|b
+--R  /
+--R        3 4 +-+4+-+ +-+
+--R     90b x \|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 698
+
+--S 699 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 699
+
+)clear all
+
+--S 700 of 1718
+t0:=(A+B*x^2)/(x^(9/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R            8      6  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 700
+
+--S 701 of 1718
+r0:=-2/11*A/(b*x^(11/2))-2/7*(b*B-A*c)/(b^2*x^(7/2))+2/3*c*(b*B-A*c)/_
+   (b^3*x^(3/2))-c^(7/4)*(b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(15/4)*sqrt(2))+c^(7/4)*(b*B-A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(15/4)*sqrt(2))-1/2*c^(7/4)*(b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(15/4)*_
+   sqrt(2))+1/2*c^(7/4)*(b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                2             5 4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 231A c  + 231B b c)x  \|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              2             5 4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (231A c  - 231B b c)x  \|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                               +-+4+-+ +-+   4+-+
+--R                2             5 4+-+3 +-+     \|2 \|c \|x  + \|b
+--R       (- 462A c  + 462B b c)x  \|c  \|x atan(-------------------)
+--R                                                      4+-+
+--R                                                      \|b
+--R     + 
+--R                                               +-+4+-+ +-+   4+-+
+--R                2             5 4+-+3 +-+     \|2 \|c \|x  - \|b
+--R       (- 462A c  + 462B b c)x  \|c  \|x atan(-------------------)
+--R                                                      4+-+
+--R                                                      \|b
+--R     + 
+--R                 2             4                     2  2        2  +-+4+-+3
+--R       ((- 308A c  + 308B b c)x  + (132A b c - 132B b )x  - 84A b )\|2 \|b
+--R  /
+--R         3 5 +-+4+-+3 +-+
+--R     462b x \|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 702
+
+)clear all
+
+--S 703 of 1718
+t0:=x^(19/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R             7      5  +-+
+--R         (B x  + A x )\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 703
+
+--S 704 of 1718
+r0:=-1/10*(13*b*B-9*A*c)*x^(5/2)/c^3+1/18*(13*b*B-9*A*c)*x^(9/2)/(b*c^2)-_
+   1/2*(b*B-A*c)*x^(13/2)/(b*c*(b+c*x^2))+1/4*b^(5/4)*(13*b*B-9*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(17/4)*sqrt(2))-_
+   1/4*b^(5/4)*(13*b*B-9*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (c^(17/4)*sqrt(2))+1/8*b^(5/4)*(13*b*B-9*A*c)*log(sqrt(b)+x*sqrt(c)-_
+   b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(17/4)*sqrt(2))-1/8*b^(5/4)*_
+   (13*b*B-9*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(c^(17/4)*sqrt(2))+1/2*b*(13*b*B-9*A*c)*sqrt(x)/c^4
+--R 
+--R
+--R   (2)
+--R                   2         2   2         2          3 4+-+
+--R         ((405A b c  - 585B b c)x  + 405A b c - 585B b )\|b
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     2         2   2         2          3 4+-+
+--R         ((- 405A b c  + 585B b c)x  - 405A b c + 585B b )\|b
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   2          2   2         2           3 4+-+
+--R         ((810A b c  - 1170B b c)x  + 810A b c - 1170B b )\|b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                   2          2   2         2           3 4+-+
+--R         ((810A b c  - 1170B b c)x  + 810A b c - 1170B b )\|b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                3 6          3           2  4               2          2   2
+--R           80B c x  + (144A c  - 208B b c )x  + (- 1296A b c  + 1872B b c)x
+--R         + 
+--R                    2           3
+--R           - 1620A b c + 2340B b
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|c \|x
+--R  /
+--R          5 2         4  +-+4+-+
+--R     (360c x  + 360b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 705
+
+)clear all
+
+--S 706 of 1718
+t0:=x^(17/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R             6      4  +-+
+--R         (B x  + A x )\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 1718
+r0:=-1/6*(11*b*B-7*A*c)*x^(3/2)/c^3+1/14*(11*b*B-7*A*c)*x^(7/2)/(b*c^2)-_
+   1/2*(b*B-A*c)*x^(11/2)/(b*c*(b+c*x^2))-1/4*b^(3/4)*(11*b*B-7*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(15/4)*sqrt(2))+_
+   1/4*b^(3/4)*(11*b*B-7*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (c^(15/4)*sqrt(2))+1/8*b^(3/4)*(11*b*B-7*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(15/4)*sqrt(2))-_
+   1/8*b^(3/4)*(11*b*B-7*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(c^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 2             2                    2 4+-+3
+--R         ((147A c  - 231B b c)x  + 147A b c - 231B b )\|b
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   2             2                    2 4+-+3
+--R         ((- 147A c  + 231B b c)x  - 147A b c + 231B b )\|b
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   2             2                    2 4+-+3
+--R         ((- 294A c  + 462B b c)x  - 294A b c + 462B b )\|b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                   2             2                    2 4+-+3
+--R         ((- 294A c  + 462B b c)x  - 294A b c + 462B b )\|b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R             2 5          2             3                     2    +-+4+-+3 +-+
+--R       (48B c x  + (112A c  - 176B b c)x  + (196A b c - 308B b )x)\|2 \|c  \|x
+--R  /
+--R          4 2         3  +-+4+-+3
+--R     (168c x  + 168b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 708
+
+)clear all
+
+--S 709 of 1718
+t0:=x^(15/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R             5      3  +-+
+--R         (B x  + A x )\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 1718
+r0:=1/10*(9*b*B-5*A*c)*x^(5/2)/(b*c^2)-1/2*(b*B-A*c)*x^(9/2)/(b*c*_
+   (b+c*x^2))-1/4*b^(1/4)*(9*b*B-5*A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(c^(13/4)*sqrt(2))+1/4*b^(1/4)*(9*b*B-5*A*c)*_
+   atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(13/4)*sqrt(2))-_
+   1/8*b^(1/4)*(9*b*B-5*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(c^(13/4)*sqrt(2))+1/8*b^(1/4)*(9*b*B-5*A*c)*_
+   log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(13/4)*_
+   sqrt(2))-1/2*(9*b*B-5*A*c)*sqrt(x)/c^3
+--R 
+--R
+--R   (2)
+--R                  2            2                  2 4+-+
+--R         ((- 25A c  + 45B b c)x  - 25A b c + 45B b )\|b
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                2            2                  2 4+-+
+--R         ((25A c  - 45B b c)x  + 25A b c - 45B b )\|b
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                            +-+4+-+ +-+   4+-+
+--R                2            2                  2 4+-+     \|2 \|c \|x  + \|b
+--R       ((- 50A c  + 90B b c)x  - 50A b c + 90B b )\|b atan(-------------------)
+--R                                                                   4+-+
+--R                                                                   \|b
+--R     + 
+--R                                                            +-+4+-+ +-+   4+-+
+--R                2            2                  2 4+-+     \|2 \|c \|x  - \|b
+--R       ((- 50A c  + 90B b c)x  - 50A b c + 90B b )\|b atan(-------------------)
+--R                                                                   4+-+
+--R                                                                   \|b
+--R     + 
+--R             2 4         2             2                    2  +-+4+-+ +-+
+--R       (16B c x  + (80A c  - 144B b c)x  + 100A b c - 180B b )\|2 \|c \|x
+--R  /
+--R         4 2        3  +-+4+-+
+--R     (40c x  + 40b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 711
+
+)clear all
+
+--S 712 of 1718
+t0:=x^(13/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R             4      2  +-+
+--R         (B x  + A x )\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 712
+
+--S 713 of 1718
+r0:=1/6*(7*b*B-3*A*c)*x^(3/2)/(b*c^2)-1/2*(b*B-A*c)*x^(7/2)/(b*c*_
+   (b+c*x^2))+1/4*(7*b*B-3*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(1/4)*c^(11/4)*sqrt(2))-1/4*(7*b*B-3*A*c)*atan(1+_
+   c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(1/4)*c^(11/4)*sqrt(2))-_
+   1/8*(7*b*B-3*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(1/4)*c^(11/4)*sqrt(2))+1/8*(7*b*B-3*A*c)*log(sqrt(b)+_
+   x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*c^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 2            2                 2
+--R         ((- 9A c  + 21B b c)x  - 9A b c + 21B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               2            2                 2
+--R         ((9A c  - 21B b c)x  + 9A b c - 21B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R              2            2                  2      \|2 \|c \|x  + \|b
+--R       ((18A c  - 42B b c)x  + 18A b c - 42B b )atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|b
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R              2            2                  2      \|2 \|c \|x  - \|b
+--R       ((18A c  - 42B b c)x  + 18A b c - 42B b )atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|b
+--R     + 
+--R               3                       +-+4+-+4+-+3 +-+
+--R       (16B c x  + (- 12A c + 28B b)x)\|2 \|b \|c  \|x
+--R  /
+--R         3 2        2  +-+4+-+4+-+3
+--R     (24c x  + 24b c )\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 714
+
+)clear all
+
+--S 715 of 1718
+t0:=x^(11/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R              3        +-+
+--R          (B x  + A x)\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 715
+
+--S 716 of 1718
+r0:=-1/2*(b*B-A*c)*x^(5/2)/(b*c*(b+c*x^2))+1/4*(5*b*B-A*c)*atan(1-c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(9/4)*sqrt(2))-1/4*(5*b*B-A*c)*_
+   atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(9/4)*sqrt(2))+_
+   1/8*(5*b*B-A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(3/4)*c^(9/4)*sqrt(2))-1/8*(5*b*B-A*c)*log(sqrt(b)+_
+   x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*c^(9/4)*sqrt(2))+_
+   1/2*(5*b*B-A*c)*sqrt(x)/(b*c^2)
+--R 
+--R
+--R   (2)
+--R            2           2               2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       ((A c  - 5B b c)x  + A b c - 5B b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                2           2               2
+--R         ((- A c  + 5B b c)x  - A b c + 5B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R             2            2                 2      \|2 \|c \|x  + \|b
+--R       ((2A c  - 10B b c)x  + 2A b c - 10B b )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|b
+--R     + 
+--R                                                    +-+4+-+ +-+   4+-+
+--R             2            2                 2      \|2 \|c \|x  - \|b
+--R       ((2A c  - 10B b c)x  + 2A b c - 10B b )atan(-------------------)
+--R                                                           4+-+
+--R                                                           \|b
+--R     + 
+--R               2                 +-+4+-+3 4+-+ +-+
+--R       (16B c x  - 4A c + 20B b)\|2 \|b   \|c \|x
+--R  /
+--R        3 2       2  +-+4+-+3 4+-+
+--R     (8c x  + 8b c )\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 717
+
+)clear all
+
+--S 718 of 1718
+t0:=x^(9/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               2      +-+
+--R           (B x  + A)\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 1718
+r0:=-1/2*(b*B-A*c)*x^(3/2)/(b*c*(b+c*x^2))-1/4*(3*b*B+A*c)*atan(1-c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*c^(7/4)*sqrt(2))+1/4*(3*b*B+A*c)*_
+   atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*c^(7/4)*sqrt(2))+_
+   1/8*(3*b*B+A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(5/4)*c^(7/4)*sqrt(2))-1/8*(3*b*B+A*c)*log(sqrt(b)+_
+   x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*c^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              2           2               2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       ((- A c  - 3B b c)x  - A b c - 3B b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            2           2               2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       ((A c  + 3B b c)x  + A b c + 3B b )log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2           2                2      \|2 \|c \|x  + \|b
+--R       ((2A c  + 6B b c)x  + 2A b c + 6B b )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|b
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2           2                2      \|2 \|c \|x  - \|b
+--R       ((2A c  + 6B b c)x  + 2A b c + 6B b )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|b
+--R     + 
+--R                      +-+4+-+4+-+3 +-+
+--R       (4A c - 4B b)x\|2 \|b \|c  \|x
+--R  /
+--R          2 2     2   +-+4+-+4+-+3
+--R     (8b c x  + 8b c)\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 720
+
+)clear all
+
+--S 721 of 1718
+t0:=x^(7/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R               2      +-+
+--R           (B x  + A)\|x
+--R   (1)  --------------------
+--R         2 5         3    2
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 721
+
+--S 722 of 1718
+r0:=-1/4*(b*B+3*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(7/4)*_
+   c^(5/4)*sqrt(2))+1/4*(b*B+3*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(7/4)*c^(5/4)*sqrt(2))-1/8*(b*B+3*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*c^(5/4)*sqrt(2))+_
+   1/8*(b*B+3*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(7/4)*c^(5/4)*sqrt(2))-1/2*(b*B-A*c)*sqrt(x)/(b*c*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R             2          2               2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       ((3A c  + B b c)x  + 3A b c + B b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 2          2               2
+--R         ((- 3A c  - B b c)x  - 3A b c - B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2           2                2      \|2 \|c \|x  + \|b
+--R       ((6A c  + 2B b c)x  + 6A b c + 2B b )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|b
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2           2                2      \|2 \|c \|x  - \|b
+--R       ((6A c  + 2B b c)x  + 6A b c + 2B b )atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|b
+--R     + 
+--R                     +-+4+-+3 4+-+ +-+
+--R       (4A c - 4B b)\|2 \|b   \|c \|x
+--R  /
+--R          2 2     2   +-+4+-+3 4+-+
+--R     (8b c x  + 8b c)\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 722
+
+--S 723 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 723
+
+)clear all
+
+--S 724 of 1718
+t0:=x^(5/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                2      +-+
+--R            (B x  + A)\|x
+--R   (1)  ---------------------
+--R         2 6         4    2 2
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 724
+
+--S 725 of 1718
+r0:=-1/4*(b*B-5*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(9/4)*_
+   c^(3/4)*sqrt(2))+1/4*(b*B-5*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(9/4)*c^(3/4)*sqrt(2))+1/8*(b*B-5*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*c^(3/4)*sqrt(2))-_
+   1/8*(b*B-5*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(9/4)*c^(3/4)*sqrt(2))+1/2*(b*B-5*A*c)/(b^2*c*sqrt(x))+_
+   1/2*(-b*B+A*c)/(b*c*(b+c*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R               2          2               2  +-+
+--R         ((5A c  - B b c)x  + 5A b c - B b )\|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 2          2               2  +-+
+--R         ((- 5A c  + B b c)x  - 5A b c + B b )\|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                          +-+4+-+ +-+   4+-+
+--R                2           2                 2  +-+     \|2 \|c \|x  + \|b
+--R       ((- 10A c  + 2B b c)x  - 10A b c + 2B b )\|x atan(-------------------)
+--R                                                                 4+-+
+--R                                                                 \|b
+--R     + 
+--R                                                          +-+4+-+ +-+   4+-+
+--R                2           2                 2  +-+     \|2 \|c \|x  - \|b
+--R       ((- 10A c  + 2B b c)x  - 10A b c + 2B b )\|x atan(-------------------)
+--R                                                                 4+-+
+--R                                                                 \|b
+--R     + 
+--R                         2          +-+4+-+4+-+3
+--R       ((- 20A c + 4B b)x  - 16A b)\|2 \|b \|c
+--R  /
+--R        2   2     3  +-+4+-+4+-+3 +-+
+--R     (8b c x  + 8b )\|2 \|b \|c  \|x
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 726
+
+)clear all
+
+--S 727 of 1718
+t0:=x^(3/2)*(A+B*x^2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                2      +-+
+--R            (B x  + A)\|x
+--R   (1)  ---------------------
+--R         2 7         5    2 3
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 727
+
+--S 728 of 1718
+r0:=1/6*(3*b*B-7*A*c)/(b^2*c*x^(3/2))+1/2*(-b*B+A*c)/(b*c*x^(3/2)*_
+   (b+c*x^2))-1/4*(3*b*B-7*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (b^(11/4)*c^(1/4)*sqrt(2))+1/4*(3*b*B-7*A*c)*atan(1+c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(11/4)*c^(1/4)*sqrt(2))-1/8*(3*b*B-7*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*_
+   c^(1/4)*sqrt(2))+1/8*(3*b*B-7*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*c^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  2           3                    2    +-+
+--R         ((- 21A c  + 9B b c)x  + (- 21A b c + 9B b )x)\|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                2           3                  2    +-+
+--R         ((21A c  - 9B b c)x  + (21A b c - 9B b )x)\|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  2            3                     2    +-+
+--R         ((- 42A c  + 18B b c)x  + (- 42A b c + 18B b )x)\|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                  2            3                     2    +-+
+--R         ((- 42A c  + 18B b c)x  + (- 42A b c + 18B b )x)\|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                          2          +-+4+-+3 4+-+
+--R       ((- 28A c + 12B b)x  - 16A b)\|2 \|b   \|c
+--R  /
+--R         2   3      3   +-+4+-+3 4+-+ +-+
+--R     (24b c x  + 24b x)\|2 \|b   \|c \|x
+--R                                                    Type: Expression(Integer)
+--E 728
+
+--S 729 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 729
+
+)clear all
+
+--S 730 of 1718
+t0:=(A+B*x^2)*sqrt(x)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                2      +-+
+--R            (B x  + A)\|x
+--R   (1)  ---------------------
+--R         2 8         6    2 4
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 730
+
+--S 731 of 1718
+r0:=1/10*(5*b*B-9*A*c)/(b^2*c*x^(5/2))+1/2*(-b*B+A*c)/(b*c*x^(5/2)*_
+   (b+c*x^2))+1/4*c^(1/4)*(5*b*B-9*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(13/4)*sqrt(2))-1/4*c^(1/4)*(5*b*B-9*A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*sqrt(2))-1/8*c^(1/4)*(5*b*B-9*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*_
+   sqrt(2))+1/8*c^(1/4)*(5*b*B-9*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*sqrt(2))+1/2*(-5*b*B+9*A*c)/(b^3*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                  2            4                     2  2 4+-+ +-+
+--R         ((- 45A c  + 25B b c)x  + (- 45A b c + 25B b )x )\|c \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                2            4                   2  2 4+-+ +-+
+--R         ((45A c  - 25B b c)x  + (45A b c - 25B b )x )\|c \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                2            4                   2  2 4+-+ +-+
+--R         ((90A c  - 50B b c)x  + (90A b c - 50B b )x )\|c \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                2            4                   2  2 4+-+ +-+
+--R         ((90A c  - 50B b c)x  + (90A b c - 50B b )x )\|c \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R               2             4                    2  2        2  +-+4+-+
+--R       ((180A c  - 100B b c)x  + (144A b c - 80B b )x  - 16A b )\|2 \|b
+--R  /
+--R         3   4      4 2  +-+4+-+ +-+
+--R     (40b c x  + 40b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 732
+
+)clear all
+
+--S 733 of 1718
+t0:=(A+B*x^2)/((b*x^2+c*x^4)^2*sqrt(x))
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R          2 8         6    2 4  +-+
+--R        (c x  + 2b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 733
+
+--S 734 of 1718
+r0:=1/14*(7*b*B-11*A*c)/(b^2*c*x^(7/2))+1/6*(-7*b*B+11*A*c)/(b^3*x^(3/2))+_
+   1/2*(-b*B+A*c)/(b*c*x^(7/2)*(b+c*x^2))+1/4*c^(3/4)*(7*b*B-11*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(15/4)*sqrt(2))-1/4*c^(3/4)*_
+   (7*b*B-11*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(15/4)*_
+   sqrt(2))+1/8*c^(3/4)*(7*b*B-11*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(15/4)*sqrt(2))-1/8*c^(3/4)*(7*b*B-_
+   11*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+   (b^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 2             5                     2  3 4+-+3 +-+
+--R         ((231A c  - 147B b c)x  + (231A b c - 147B b )x )\|c  \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   2             5                       2  3 4+-+3 +-+
+--R         ((- 231A c  + 147B b c)x  + (- 231A b c + 147B b )x )\|c  \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 2             5                     2  3 4+-+3 +-+
+--R         ((462A c  - 294B b c)x  + (462A b c - 294B b )x )\|c  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                 2             5                     2  3 4+-+3 +-+
+--R         ((462A c  - 294B b c)x  + (462A b c - 294B b )x )\|c  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R               2             4                     2  2        2  +-+4+-+3
+--R       ((308A c  - 196B b c)x  + (176A b c - 112B b )x  - 48A b )\|2 \|b
+--R  /
+--R          3   5       4 3  +-+4+-+3 +-+
+--R     (168b c x  + 168b x )\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 734
+
+--S 735 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 735
+
+)clear all
+
+--S 736 of 1718
+t0:=(A+B*x^2)/(x^(3/2)*(b*x^2+c*x^4)^2)
+--R 
+--R
+--R                     2
+--R                  B x  + A
+--R   (1)  ---------------------------
+--R          2 9         7    2 5  +-+
+--R        (c x  + 2b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 736
+
+--S 737 of 1718
+r0:=1/18*(9*b*B-13*A*c)/(b^2*c*x^(9/2))+1/10*(-9*b*B+13*A*c)/(b^3*x^(5/2))+_
+   1/2*(-b*B+A*c)/(b*c*x^(9/2)*(b+c*x^2))-1/4*c^(5/4)*(9*b*B-13*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(17/4)*sqrt(2))+1/4*c^(5/4)*_
+   (9*b*B-13*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(17/4)*_
+   sqrt(2))+1/8*c^(5/4)*(9*b*B-13*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*sqrt(2))-1/8*c^(5/4)*(9*b*B-13*A*c)*_
+   log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*_
+   sqrt(2))+1/2*c*(9*b*B-13*A*c)/(b^4*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                 3           2  6            2         2   4 4+-+ +-+
+--R         ((585A c  - 405B b c )x  + (585A b c  - 405B b c)x )\|c \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   3           2  6              2         2   4 4+-+ +-+
+--R         ((- 585A c  + 405B b c )x  + (- 585A b c  + 405B b c)x )\|c \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    3           2  6               2         2   4 4+-+ +-+
+--R         ((- 1170A c  + 810B b c )x  + (- 1170A b c  + 810B b c)x )\|c \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                    3           2  6               2         2   4 4+-+ +-+
+--R         ((- 1170A c  + 810B b c )x  + (- 1170A b c  + 810B b c)x )\|c \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                     3            2  6               2          2   4
+--R           (- 2340A c  + 1620B b c )x  + (- 1872A b c  + 1296B b c)x
+--R         + 
+--R                  2          3  2        3
+--R           (208A b c - 144B b )x  - 80A b
+--R      *
+--R          +-+4+-+
+--R         \|2 \|b
+--R  /
+--R          4   6       5 4  +-+4+-+ +-+
+--R     (360b c x  + 360b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 738
+
+)clear all
+
+--S 739 of 1718
+t0:=x^(23/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                  7      5  +-+
+--R              (B x  + A x )\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 1718
+r0:=9/80*(13*b*B-5*A*c)*x^(5/2)/(b*c^3)-1/4*(b*B-A*c)*x^(13/2)/(b*c*(b+_
+   c*x^2)^2)-1/16*(13*b*B-5*A*c)*x^(9/2)/(b*c^2*(b+c*x^2))-9/32*b^(1/4)*_
+   (13*b*B-5*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(17/4)*_
+   sqrt(2))+9/32*b^(1/4)*(13*b*B-5*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(c^(17/4)*sqrt(2))-9/64*b^(1/4)*(13*b*B-5*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(17/4)*sqrt(2))+_
+   9/64*b^(1/4)*(13*b*B-5*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(c^(17/4)*sqrt(2))-9/16*(13*b*B-5*A*c)*sqrt(x)/c^4
+--R 
+--R
+--R   (2)
+--R                    3           2  4              2          2   2         2
+--R           (- 225A c  + 585B b c )x  + (- 450A b c  + 1170B b c)x  - 225A b c
+--R         + 
+--R                 3
+--R           585B b
+--R      *
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  3           2  4            2          2   2         2
+--R           (225A c  - 585B b c )x  + (450A b c  - 1170B b c)x  + 225A b c
+--R         + 
+--R                   3
+--R           - 585B b
+--R      *
+--R         4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    3            2  4              2          2   2         2
+--R           (- 450A c  + 1170B b c )x  + (- 900A b c  + 2340B b c)x  - 450A b c
+--R         + 
+--R                  3
+--R           1170B b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|c \|x  + \|b
+--R         \|b atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R                    3            2  4              2          2   2         2
+--R           (- 450A c  + 1170B b c )x  + (- 900A b c  + 2340B b c)x  - 450A b c
+--R         + 
+--R                  3
+--R           1170B b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R         4+-+     \|2 \|c \|x  - \|b
+--R         \|b atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R                 3 6          3            2  4             2          2   2
+--R           128B c x  + (640A c  - 1664B b c )x  + (1620A b c  - 4212B b c)x
+--R         + 
+--R                 2           3
+--R           900A b c - 2340B b
+--R      *
+--R          +-+4+-+ +-+
+--R         \|2 \|c \|x
+--R  /
+--R          6 4         5 2       2 4  +-+4+-+
+--R     (320c x  + 640b c x  + 320b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 741
+
+)clear all
+
+--S 742 of 1718
+t0:=x^(21/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                  6      4  +-+
+--R              (B x  + A x )\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 1718
+r0:=7/48*(11*b*B-3*A*c)*x^(3/2)/(b*c^3)-1/4*(b*B-A*c)*x^(11/2)/(b*c*_
+   (b+c*x^2)^2)-1/16*(11*b*B-3*A*c)*x^(7/2)/(b*c^2*(b+c*x^2))+_
+   7/32*(11*b*B-3*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(1/4)*_
+   c^(15/4)*sqrt(2))-7/32*(11*b*B-3*A*c)*atan(1+c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(1/4)*c^(15/4)*sqrt(2))-7/64*(11*b*B-3*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*_
+   c^(15/4)*sqrt(2))+7/64*(11*b*B-3*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*c^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   3           2  4              2         2   2        2
+--R           (- 63A c  + 231B b c )x  + (- 126A b c  + 462B b c)x  - 63A b c
+--R         + 
+--R                 3
+--R           231B b
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                3           2  4            2         2   2        2          3
+--R         ((63A c  - 231B b c )x  + (126A b c  - 462B b c)x  + 63A b c - 231B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    3           2  4            2         2   2         2
+--R             (126A c  - 462B b c )x  + (252A b c  - 924B b c)x  + 126A b c
+--R           + 
+--R                     3
+--R             - 462B b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                    3           2  4            2         2   2         2
+--R             (126A c  - 462B b c )x  + (252A b c  - 924B b c)x  + 126A b c
+--R           + 
+--R                     3
+--R             - 462B b
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                2 5            2             3                      2    +-+4+-+
+--R         (128B c x  + (- 132A c  + 484B b c)x  + (- 84A b c + 308B b )x)\|2 \|b
+--R      *
+--R         4+-+3 +-+
+--R         \|c  \|x
+--R  /
+--R          5 4         4 2       2 3  +-+4+-+4+-+3
+--R     (192c x  + 384b c x  + 192b c )\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 743
+
+--S 744 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 744
+
+)clear all
+
+--S 745 of 1718
+t0:=x^(19/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                  5      3  +-+
+--R              (B x  + A x )\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 745
+
+--S 746 of 1718
+r0:=-1/4*(b*B-A*c)*x^(9/2)/(b*c*(b+c*x^2)^2)-1/16*(9*b*B-A*c)*x^(5/2)/_
+   (b*c^2*(b+c*x^2))+5/32*(9*b*B-A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(3/4)*c^(13/4)*sqrt(2))-5/32*(9*b*B-A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(13/4)*sqrt(2))+5/64*(9*b*B-A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*_
+   c^(13/4)*sqrt(2))-5/64*(9*b*B-A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*c^(13/4)*sqrt(2))+5/16*(9*b*B-A*c)*_
+   sqrt(x)/(b*c^3)
+--R 
+--R
+--R   (2)
+--R               3          2  4           2        2   2       2         3
+--R         ((5A c  - 45B b c )x  + (10A b c  - 90B b c)x  + 5A b c - 45B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 3          2  4             2        2   2       2         3
+--R         ((- 5A c  + 45B b c )x  + (- 10A b c  + 90B b c)x  - 5A b c + 45B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                3          2  4           2         2   2        2         3
+--R         ((10A c  - 90B b c )x  + (20A b c  - 180B b c)x  + 10A b c - 90B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                3          2  4           2         2   2        2         3
+--R         ((10A c  - 90B b c )x  + (20A b c  - 180B b c)x  + 10A b c - 90B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R            2 4           2             2                   2  +-+4+-+3 4+-+ +-+
+--R     (128B c x  + (- 36A c  + 324B b c)x  - 20A b c + 180B b )\|2 \|b   \|c \|x
+--R  /
+--R         5 4         4 2      2 3  +-+4+-+3 4+-+
+--R     (64c x  + 128b c x  + 64b c )\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 747
+
+)clear all
+
+--S 748 of 1718
+t0:=x^(17/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                  4      2  +-+
+--R              (B x  + A x )\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 748
+
+--S 749 of 1718
+r0:=-1/4*(b*B-A*c)*x^(7/2)/(b*c*(b+c*x^2)^2)-1/16*(7*b*B+A*c)*x^(3/2)/_
+   (b*c^2*(b+c*x^2))-3/32*(7*b*B+A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(5/4)*c^(11/4)*sqrt(2))+3/32*(7*b*B+A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*c^(11/4)*sqrt(2))+3/64*(7*b*B+A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*_
+   c^(11/4)*sqrt(2))-3/64*(7*b*B+A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*c^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 3          2  4            2        2   2       2         3
+--R         ((- 3A c  - 21B b c )x  + (- 6A b c  - 42B b c)x  - 3A b c - 21B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               3          2  4          2        2   2       2         3
+--R         ((3A c  + 21B b c )x  + (6A b c  + 42B b c)x  + 3A b c + 21B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               3          2  4           2        2   2       2         3
+--R         ((6A c  + 42B b c )x  + (12A b c  + 84B b c)x  + 6A b c + 42B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R               3          2  4           2        2   2       2         3
+--R         ((6A c  + 42B b c )x  + (12A b c  + 84B b c)x  + 6A b c + 42B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R              2            3                    2    +-+4+-+4+-+3 +-+
+--R       ((12A c  - 44B b c)x  + (- 4A b c - 28B b )x)\|2 \|b \|c  \|x
+--R  /
+--R           4 4       2 3 2      3 2  +-+4+-+4+-+3
+--R     (64b c x  + 128b c x  + 64b c )\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 750
+
+)clear all
+
+--S 751 of 1718
+t0:=x^(15/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                   3        +-+
+--R               (B x  + A x)\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 1718
+r0:=-1/4*(b*B-A*c)*x^(5/2)/(b*c*(b+c*x^2)^2)-1/32*(5*b*B+3*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(7/4)*c^(9/4)*sqrt(2))+_
+   1/32*(5*b*B+3*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(7/4)*_
+   c^(9/4)*sqrt(2))-1/64*(5*b*B+3*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*c^(9/4)*sqrt(2))+1/64*(5*b*B+3*A*c)*_
+   log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*_
+   c^(9/4)*sqrt(2))-1/16*(5*b*B+3*A*c)*sqrt(x)/(b*c^2*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R               3         2  4          2        2   2       2        3
+--R         ((3A c  + 5B b c )x  + (6A b c  + 10B b c)x  + 3A b c + 5B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 3         2  4            2        2   2       2        3
+--R         ((- 3A c  - 5B b c )x  + (- 6A b c  - 10B b c)x  - 3A b c - 5B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               3          2  4           2        2   2       2         3
+--R         ((6A c  + 10B b c )x  + (12A b c  + 20B b c)x  + 6A b c + 10B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R               3          2  4           2        2   2       2         3
+--R         ((6A c  + 10B b c )x  + (12A b c  + 20B b c)x  + 6A b c + 10B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R             2            2                  2  +-+4+-+3 4+-+ +-+
+--R       ((4A c  - 36B b c)x  - 12A b c - 20B b )\|2 \|b   \|c \|x
+--R  /
+--R           4 4       2 3 2      3 2  +-+4+-+3 4+-+
+--R     (64b c x  + 128b c x  + 64b c )\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 753
+
+)clear all
+
+--S 754 of 1718
+t0:=x^(13/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    2      +-+
+--R                (B x  + A)\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 1718
+r0:=-1/4*(b*B-A*c)*x^(3/2)/(b*c*(b+c*x^2)^2)+1/16*(3*b*B+5*A*c)*x^(3/2)/_
+   (b^2*c*(b+c*x^2))-1/32*(3*b*B+5*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(9/4)*c^(7/4)*sqrt(2))+1/32*(3*b*B+5*A*c)*atan(1+c^(1/4)*_
+   sqrt(2)*sqrt(x)/b^(1/4))/(b^(9/4)*c^(7/4)*sqrt(2))+1/64*(3*b*B+5*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*c^(7/4)*_
+   sqrt(2))-1/64*(3*b*B+5*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(9/4)*c^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 3         2  4             2       2   2       2        3
+--R         ((- 5A c  - 3B b c )x  + (- 10A b c  - 6B b c)x  - 5A b c - 3B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               3         2  4           2       2   2       2        3
+--R         ((5A c  + 3B b c )x  + (10A b c  + 6B b c)x  + 5A b c + 3B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                3         2  4           2        2   2        2        3
+--R         ((10A c  + 6B b c )x  + (20A b c  + 12B b c)x  + 10A b c + 6B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                3         2  4           2        2   2        2        3
+--R         ((10A c  + 6B b c )x  + (20A b c  + 12B b c)x  + 10A b c + 6B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R              2            3                  2    +-+4+-+4+-+3 +-+
+--R       ((20A c  + 12B b c)x  + (36A b c - 4B b )x)\|2 \|b \|c  \|x
+--R  /
+--R         2 3 4       3 2 2      4   +-+4+-+4+-+3
+--R     (64b c x  + 128b c x  + 64b c)\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 755
+
+--S 756 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 756
+
+)clear all
+
+--S 757 of 1718
+t0:=x^(11/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                    2      +-+
+--R                (B x  + A)\|x
+--R   (1)  ------------------------------
+--R         3 7       2 5     2   3    3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 1718
+r0:=-3/32*(b*B+7*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*_
+   c^(5/4)*sqrt(2))+3/32*(b*B+7*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(11/4)*c^(5/4)*sqrt(2))-3/64*(b*B+7*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*c^(5/4)*sqrt(2))+_
+   3/64*(b*B+7*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(11/4)*c^(5/4)*sqrt(2))-1/4*(b*B-A*c)*sqrt(x)/(b*c*(b+_
+   c*x^2)^2)+1/16*(b*B+7*A*c)*sqrt(x)/(b^2*c*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R                3         2  4           2       2   2        2        3
+--R         ((21A c  + 3B b c )x  + (42A b c  + 6B b c)x  + 21A b c + 3B b )
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  3         2  4             2       2   2        2        3
+--R         ((- 21A c  - 3B b c )x  + (- 42A b c  - 6B b c)x  - 21A b c - 3B b )
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                3         2  4           2        2   2        2        3
+--R         ((42A c  + 6B b c )x  + (84A b c  + 12B b c)x  + 42A b c + 6B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                3         2  4           2        2   2        2        3
+--R         ((42A c  + 6B b c )x  + (84A b c  + 12B b c)x  + 42A b c + 6B b )
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R              2           2                  2  +-+4+-+3 4+-+ +-+
+--R       ((28A c  + 4B b c)x  + 44A b c - 12B b )\|2 \|b   \|c \|x
+--R  /
+--R         2 3 4       3 2 2      4   +-+4+-+3 4+-+
+--R     (64b c x  + 128b c x  + 64b c)\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 758
+
+--S 759 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 759
+
+)clear all
+
+--S 760 of 1718
+t0:=x^(9/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     2      +-+
+--R                 (B x  + A)\|x
+--R   (1)  -------------------------------
+--R         3 8       2 6     2   4    3 2
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 760
+
+--S 761 of 1718
+r0:=-5/32*(b*B-9*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*_
+   c^(3/4)*sqrt(2))+5/32*(b*B-9*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(13/4)*c^(3/4)*sqrt(2))+5/64*(b*B-9*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*c^(3/4)*sqrt(2))-_
+   5/64*(b*B-9*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(13/4)*c^(3/4)*sqrt(2))+5/16*(b*B-9*A*c)/(b^3*c*sqrt(x))+_
+   1/4*(-b*B+A*c)/(b*c*(b+c*x^2)^2*sqrt(x))+1/16*(-b*B+9*A*c)/_
+   (b^2*c*(b+c*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                3         2  4           2        2   2        2        3  +-+
+--R         ((45A c  - 5B b c )x  + (90A b c  - 10B b c)x  + 45A b c - 5B b )\|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  3         2  4             2        2   2        2        3
+--R         ((- 45A c  + 5B b c )x  + (- 90A b c  + 10B b c)x  - 45A b c + 5B b )
+--R      *
+--R          +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     3          2  4              2        2   2        2
+--R             (- 90A c  + 10B b c )x  + (- 180A b c  + 20B b c)x  - 90A b c
+--R           + 
+--R                  3
+--R             10B b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|c \|x  + \|b
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R                     3          2  4              2        2   2        2
+--R             (- 90A c  + 10B b c )x  + (- 180A b c  + 20B b c)x  - 90A b c
+--R           + 
+--R                  3
+--R             10B b
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|c \|x  - \|b
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R               2            4                      2  2         2  +-+4+-+4+-+3
+--R     ((- 180A c  + 20B b c)x  + (- 324A b c + 36B b )x  - 128A b )\|2 \|b \|c
+--R  /
+--R         3 2 4       4   2      5  +-+4+-+4+-+3 +-+
+--R     (64b c x  + 128b c x  + 64b )\|2 \|b \|c  \|x
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 762
+
+)clear all
+
+--S 763 of 1718
+t0:=x^(7/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     2      +-+
+--R                 (B x  + A)\|x
+--R   (1)  -------------------------------
+--R         3 9       2 7     2   5    3 3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 763
+
+--S 764 of 1718
+r0:=7/48*(3*b*B-11*A*c)/(b^3*c*x^(3/2))+1/4*(-b*B+A*c)/(b*c*x^(3/2)*_
+   (b+c*x^2)^2)+1/16*(-3*b*B+11*A*c)/(b^2*c*x^(3/2)*(b+c*x^2))-_
+   7/32*(3*b*B-11*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(15/4)*_
+   c^(1/4)*sqrt(2))+7/32*(3*b*B-11*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/_
+   b^(1/4))/(b^(15/4)*c^(1/4)*sqrt(2))-7/64*(3*b*B-11*A*c)*log(sqrt(b)+_
+   x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(15/4)*c^(1/4)*sqrt(2))+_
+   7/64*(3*b*B-11*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(15/4)*c^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                    3          2  5              2         2   3
+--R           (- 231A c  + 63B b c )x  + (- 462A b c  + 126B b c)x
+--R         + 
+--R                    2         3
+--R           (- 231A b c + 63B b )x
+--R      *
+--R          +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  3          2  5            2         2   3
+--R           (231A c  - 63B b c )x  + (462A b c  - 126B b c)x
+--R         + 
+--R                  2         3
+--R           (231A b c - 63B b )x
+--R      *
+--R          +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    3           2  5              2         2   3
+--R           (- 462A c  + 126B b c )x  + (- 924A b c  + 252B b c)x
+--R         + 
+--R                    2          3
+--R           (- 462A b c + 126B b )x
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|c \|x  + \|b
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R                    3           2  5              2         2   3
+--R           (- 462A c  + 126B b c )x  + (- 924A b c  + 252B b c)x
+--R         + 
+--R                    2          3
+--R           (- 462A b c + 126B b )x
+--R      *
+--R                   +-+4+-+ +-+   4+-+
+--R          +-+     \|2 \|c \|x  - \|b
+--R         \|x atan(-------------------)
+--R                          4+-+
+--R                          \|b
+--R     + 
+--R               2            4                       2  2         2  +-+4+-+3 4+-+
+--R     ((- 308A c  + 84B b c)x  + (- 484A b c + 132B b )x  - 128A b )\|2 \|b   \|c
+--R  /
+--R          3 2 5       4   3       5   +-+4+-+3 4+-+ +-+
+--R     (192b c x  + 384b c x  + 192b x)\|2 \|b   \|c \|x
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 765
+
+)clear all
+
+--S 766 of 1718
+t0:=x^(5/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     2      +-+
+--R                 (B x  + A)\|x
+--R   (1)  --------------------------------
+--R         3 10       2 8     2   6    3 4
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 766
+
+--S 767 of 1718
+r0:=9/80*(5*b*B-13*A*c)/(b^3*c*x^(5/2))+1/4*(-b*B+A*c)/(b*c*x^(5/2)*_
+   (b+c*x^2)^2)+1/16*(-5*b*B+13*A*c)/(b^2*c*x^(5/2)*(b+c*x^2))+_
+   9/32*c^(1/4)*(5*b*B-13*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (b^(17/4)*sqrt(2))-9/32*c^(1/4)*(5*b*B-13*A*c)*atan(1+c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(17/4)*sqrt(2))-9/64*c^(1/4)*(5*b*B-13*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*_
+   sqrt(2))+9/64*c^(1/4)*(5*b*B-13*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*sqrt(2))-9/16*(5*b*B-13*A*c)/_
+   (b^4*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                    3           2  6               2         2   4
+--R           (- 585A c  + 225B b c )x  + (- 1170A b c  + 450B b c)x
+--R         + 
+--R                    2          3  2
+--R           (- 585A b c + 225B b )x
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  3           2  6             2         2   4
+--R           (585A c  - 225B b c )x  + (1170A b c  - 450B b c)x
+--R         + 
+--R                  2          3  2
+--R           (585A b c - 225B b )x
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   3           2  6             2         2   4
+--R           (1170A c  - 450B b c )x  + (2340A b c  - 900B b c)x
+--R         + 
+--R                   2          3  2
+--R           (1170A b c - 450B b )x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|c \|x  + \|b
+--R         \|c \|x atan(-------------------)
+--R                              4+-+
+--R                              \|b
+--R     + 
+--R                   3           2  6             2         2   4
+--R           (1170A c  - 450B b c )x  + (2340A b c  - 900B b c)x
+--R         + 
+--R                   2          3  2
+--R           (1170A b c - 450B b )x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|c \|x  - \|b
+--R         \|c \|x atan(-------------------)
+--R                              4+-+
+--R                              \|b
+--R     + 
+--R                   3           2  6             2          2   4
+--R           (2340A c  - 900B b c )x  + (4212A b c  - 1620B b c)x
+--R         + 
+--R                   2          3  2         3
+--R           (1664A b c - 640B b )x  - 128A b
+--R      *
+--R          +-+4+-+
+--R         \|2 \|b
+--R  /
+--R          4 2 6       5   4       6 2  +-+4+-+ +-+
+--R     (320b c x  + 640b c x  + 320b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 768
+
+)clear all
+
+--S 769 of 1718
+t0:=x^(3/2)*(A+B*x^2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     2      +-+
+--R                 (B x  + A)\|x
+--R   (1)  --------------------------------
+--R         3 11       2 9     2   7    3 5
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 769
+
+--S 770 of 1718
+r0:=11/112*(7*b*B-15*A*c)/(b^3*c*x^(7/2))-11/48*(7*b*B-15*A*c)/_
+   (b^4*x^(3/2))+1/4*(-b*B+A*c)/(b*c*x^(7/2)*(b+c*x^2)^2)+_
+   1/16*(-7*b*B+15*A*c)/(b^2*c*x^(7/2)*(b+c*x^2))+11/32*c^(3/4)*_
+   (7*b*B-15*A*c)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(19/4)*_
+   sqrt(2))-11/32*c^(3/4)*(7*b*B-15*A*c)*atan(1+c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(19/4)*sqrt(2))+11/64*c^(3/4)*(7*b*B-15*A*c)*_
+   log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(19/4)*_
+   sqrt(2))-11/64*c^(3/4)*(7*b*B-15*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+   c^(1/4)*sqrt(2)*sqrt(x))/(b^(19/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   3            2  7             2          2   5
+--R           (3465A c  - 1617B b c )x  + (6930A b c  - 3234B b c)x
+--R         + 
+--R                   2           3  3
+--R           (3465A b c - 1617B b )x
+--R      *
+--R         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     3            2  7               2          2   5
+--R           (- 3465A c  + 1617B b c )x  + (- 6930A b c  + 3234B b c)x
+--R         + 
+--R                     2           3  3
+--R           (- 3465A b c + 1617B b )x
+--R      *
+--R         4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                   3            2  7              2          2   5
+--R           (6930A c  - 3234B b c )x  + (13860A b c  - 6468B b c)x
+--R         + 
+--R                   2           3  3
+--R           (6930A b c - 3234B b )x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|c \|x  + \|b
+--R         \|c  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|b
+--R     + 
+--R                   3            2  7              2          2   5
+--R           (6930A c  - 3234B b c )x  + (13860A b c  - 6468B b c)x
+--R         + 
+--R                   2           3  3
+--R           (6930A b c - 3234B b )x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|c \|x  - \|b
+--R         \|c  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|b
+--R     + 
+--R                   3            2  6             2          2   4
+--R           (4620A c  - 2156B b c )x  + (7260A b c  - 3388B b c)x
+--R         + 
+--R                   2          3  2         3
+--R           (1920A b c - 896B b )x  - 384A b
+--R      *
+--R          +-+4+-+3
+--R         \|2 \|b
+--R  /
+--R           4 2 7        5   5        6 3  +-+4+-+3 +-+
+--R     (1344b c x  + 2688b c x  + 1344b x )\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 770
+
+--S 771 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 771
+
+)clear all
+
+--S 772 of 1718
+t0:=(A+B*x^2)*sqrt(x)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      2      +-+
+--R                  (B x  + A)\|x
+--R   (1)  ---------------------------------
+--R         3 12       2 10     2   8    3 6
+--R        c x   + 3b c x   + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 772
+
+--S 773 of 1718
+r0:=13/144*(9*b*B-17*A*c)/(b^3*c*x^(9/2))-13/80*(9*b*B-17*A*c)/(b^4*_
+   x^(5/2))+1/4*(-b*B+A*c)/(b*c*x^(9/2)*(b+c*x^2)^2)+1/16*(-9*b*B+_
+   17*A*c)/(b^2*c*x^(9/2)*(b+c*x^2))-13/32*c^(5/4)*(9*b*B-17*A*c)*_
+   atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(21/4)*sqrt(2))+_
+   13/32*c^(5/4)*(9*b*B-17*A*c)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+   (b^(21/4)*sqrt(2))+13/64*c^(5/4)*(9*b*B-17*A*c)*log(sqrt(b)+x*sqrt(c)-_
+   b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(21/4)*sqrt(2))-13/64*c^(5/4)*_
+   (9*b*B-17*A*c)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+   sqrt(x))/(b^(21/4)*sqrt(2))+13/16*c*(9*b*B-17*A*c)/(b^5*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                   4            3  8              3           2 2  6
+--R           (9945A c  - 5265B b c )x  + (19890A b c  - 10530B b c )x
+--R         + 
+--R                   2 2          3   4
+--R           (9945A b c  - 5265B b c)x
+--R      *
+--R         4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     4            3  8                3           2 2  6
+--R           (- 9945A c  + 5265B b c )x  + (- 19890A b c  + 10530B b c )x
+--R         + 
+--R                     2 2          3   4
+--R           (- 9945A b c  + 5265B b c)x
+--R      *
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                      4             3  8                3           2 2  6
+--R           (- 19890A c  + 10530B b c )x  + (- 39780A b c  + 21060B b c )x
+--R         + 
+--R                      2 2           3   4
+--R           (- 19890A b c  + 10530B b c)x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|c \|x  + \|b
+--R         \|c \|x atan(-------------------)
+--R                              4+-+
+--R                              \|b
+--R     + 
+--R                      4             3  8                3           2 2  6
+--R           (- 19890A c  + 10530B b c )x  + (- 39780A b c  + 21060B b c )x
+--R         + 
+--R                      2 2           3   4
+--R           (- 19890A b c  + 10530B b c)x
+--R      *
+--R                       +-+4+-+ +-+   4+-+
+--R         4+-+ +-+     \|2 \|c \|x  - \|b
+--R         \|c \|x atan(-------------------)
+--R                              4+-+
+--R                              \|b
+--R     + 
+--R                      4             3  8                3           2 2  6
+--R           (- 39780A c  + 21060B b c )x  + (- 71604A b c  + 37908B b c )x
+--R         + 
+--R                      2 2           3   4           3           4  2         4
+--R           (- 28288A b c  + 14976B b c)x  + (2176A b c - 1152B b )x  - 640A b
+--R      *
+--R          +-+4+-+
+--R         \|2 \|b
+--R  /
+--R           5 2 8        6   6        7 4  +-+4+-+ +-+
+--R     (2880b c x  + 5760b c x  + 2880b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 773
+
+--S 774 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 774
+
+)clear all
+
+--S 775 of 1718
+t0:=(A+B*x^2)/((b*x^2+c*x^4)^3*sqrt(x))
+--R 
+--R
+--R                           2
+--R                        B x  + A
+--R   (1)  ---------------------------------------
+--R          3 12       2 10     2   8    3 6  +-+
+--R        (c x   + 3b c x   + 3b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 775
+
+--S 776 of 1718
+r0:=15/176*(11*b*B-19*A*c)/(b^3*c*x^(11/2))-15/112*(11*b*B-19*A*c)/_
+   (b^4*x^(7/2))+5/16*c*(11*b*B-19*A*c)/(b^5*x^(3/2))+1/4*(-b*B+A*c)/_
+   (b*c*x^(11/2)*(b+c*x^2)^2)+1/16*(-11*b*B+19*A*c)/(b^2*c*x^(11/2)*_
+   (b+c*x^2))-15/32*c^(7/4)*(11*b*B-19*A*c)*atan(1-c^(1/4)*sqrt(2)*_
+   sqrt(x)/b^(1/4))/(b^(23/4)*sqrt(2))+15/32*c^(7/4)*(11*b*B-19*A*c)*_
+   atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(23/4)*sqrt(2))-_
+   15/64*c^(7/4)*(11*b*B-19*A*c)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+   sqrt(2)*sqrt(x))/(b^(23/4)*sqrt(2))+15/64*c^(7/4)*(11*b*B-19*A*c)*_
+   log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(23/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                      4             3  9                3           2 2  7
+--R           (- 21945A c  + 12705B b c )x  + (- 43890A b c  + 25410B b c )x
+--R         + 
+--R                      2 2           3   5
+--R           (- 21945A b c  + 12705B b c)x
+--R      *
+--R         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    4             3  9              3           2 2  7
+--R           (21945A c  - 12705B b c )x  + (43890A b c  - 25410B b c )x
+--R         + 
+--R                    2 2           3   5
+--R           (21945A b c  - 12705B b c)x
+--R      *
+--R         4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R         \|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                      4             3  9                3           2 2  7
+--R           (- 43890A c  + 25410B b c )x  + (- 87780A b c  + 50820B b c )x
+--R         + 
+--R                      2 2           3   5
+--R           (- 43890A b c  + 25410B b c)x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|c \|x  + \|b
+--R         \|c  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|b
+--R     + 
+--R                      4             3  9                3           2 2  7
+--R           (- 43890A c  + 25410B b c )x  + (- 87780A b c  + 50820B b c )x
+--R         + 
+--R                      2 2           3   5
+--R           (- 43890A b c  + 25410B b c)x
+--R      *
+--R                        +-+4+-+ +-+   4+-+
+--R         4+-+3 +-+     \|2 \|c \|x  - \|b
+--R         \|c  \|x atan(-------------------)
+--R                               4+-+
+--R                               \|b
+--R     + 
+--R                      4             3  8                3           2 2  6
+--R           (- 29260A c  + 16940B b c )x  + (- 45980A b c  + 26620B b c )x
+--R         + 
+--R                      2 2          3   4           3           4  2         4
+--R           (- 12160A b c  + 7040B b c)x  + (2432A b c - 1408B b )x  - 896A b
+--R      *
+--R          +-+4+-+3
+--R         \|2 \|b
+--R  /
+--R           5 2 9        6   7        7 5  +-+4+-+3 +-+
+--R     (4928b c x  + 9856b c x  + 4928b x )\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 777
+
+)clear all
+
+--S 778 of 1718
+t0:=x^(9/2)*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                          +-----------+
+--R            6      4  +-+ |   4      2
+--R   (1)  (B x  + A x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 778
+
+--S 779 of 1718
+--r0:=2/19*B*x^(7/2)*(b*x^2+c*x^4)^(3/2)/c+4/1463*b^(17/4)*(13*b*B-19*A*c)*_
+---  x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(17/4)*sqrt(b*x^2+c*x^4))+12/7315*b^2*(13*b*B-19*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^3-4/3135*b*(13*b*B-19*A*c)*x^(7/2)*sqrt(b*x^2+_
+---  c*x^4)/c^2-2/285*(13*b*B-19*A*c)*x^(11/2)*sqrt(b*x^2+c*x^4)/c-_
+---  4/1463*b^3*(13*b*B-19*A*c)*sqrt(b*x^2+c*x^4)/(c^4*sqrt(x))
+--E 779
+
+--S 780 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 780
+
+)clear all
+
+--S 781 of 1718
+t0:=x^(7/2)*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                          +-----------+
+--R            5      3  +-+ |   4      2
+--R   (1)  (B x  + A x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 781
+
+--S 782 of 1718
+--r0:=2/17*B*x^(5/2)*(b*x^2+c*x^4)^(3/2)/c+28/3315*b^(15/4)*(11*b*B-17*A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(15/4)*sqrt(b*x^2+c*x^4))-28/3315*b^(15/4)*(11*b*B-17*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(15/4)*sqrt(b*x^2+c*x^4))-4/1989*b*(11*b*B-17*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-2/221*(11*b*B-17*A*c)*x^(9/2)*sqrt(b*x^2+c*x^4)/_
+---  c+28/9945*b^2*(11*b*B-17*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^3
+--E 782
+
+--S 783 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 783
+
+)clear all
+
+--S 784 of 1718
+t0:=x^(5/2)*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                          +-----------+
+--R            4      2  +-+ |   4      2
+--R   (1)  (B x  + A x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 784
+
+--S 785 of 1718
+--r0:=2/15*B*x^(3/2)*(b*x^2+c*x^4)^(3/2)/c+4/231*b^(13/4)*(3*b*B-5*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(13/4)*sqrt(b*x^2+c*x^4))-4/385*b*(3*b*B-5*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-2/55*(3*b*B-5*A*c)*x^(7/2)*sqrt(b*x^2+c*x^4)/c+_
+---  4/231*b^2*(3*b*B-5*A*c)*sqrt(b*x^2+c*x^4)/(c^3*sqrt(x))
+--E 785
+
+--S 786 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 786
+
+)clear all
+
+--S 787 of 1718
+t0:=x^(3/2)*(A+B*x^2)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                         +-----------+
+--R            3        +-+ |   4      2
+--R   (1)  (B x  + A x)\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 787
+
+--S 788 of 1718
+--r0:=2/13*B*(b*x^2+c*x^4)^(3/2)*sqrt(x)/c+4/195*b^(11/4)*(7*b*B-13*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))-4/195*b^(11/4)*(7*b*B-13*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))-2/117*(7*b*B-13*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c-4/585*b*(7*b*B-13*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^2
+--E 788
+
+--S 789 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 789
+
+)clear all
+
+--S 790 of 1718
+t0:=(A+B*x^2)*sqrt(x)*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                       +-----------+
+--R            2      +-+ |   4      2
+--R   (1)  (B x  + A)\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 790
+
+--S 791 of 1718
+--r0:=2/11*B*(b*x^2+c*x^4)^(3/2)/(c*sqrt(x))+4/231*b^(9/4)*(5*b*B-11*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(9/4)*sqrt(b*x^2+c*x^4))-2/77*(5*b*B-11*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c-4/231*b*(5*b*B-11*A*c)*sqrt(b*x^2+c*x^4)/(c^2*sqrt(x))
+--E 791
+
+--S 792 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 792
+
+)clear all
+
+--S 793 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/sqrt(x)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                   +-+
+--R                  \|x
+--R                                                    Type: Expression(Integer)
+--E 793
+
+--S 794 of 1718
+--r0:=2/9*B*(b*x^2+c*x^4)^(3/2)/(c*x^(3/2))+4/15*b^(7/4)*(b*B-3*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(7/4)*sqrt(b*x^2+c*x^4))-4/15*b^(7/4)*(b*B-3*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(7/4)*sqrt(b*x^2+c*x^4))-2/15*(b*B-3*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/c
+--E 794
+
+--S 795 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 795
+
+)clear all
+
+--S 796 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(3/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                    +-+
+--R                  x\|x
+--R                                                    Type: Expression(Integer)
+--E 796
+
+--S 797 of 1718
+--r0:=2/7*B*(b*x^2+c*x^4)^(3/2)/(c*x^(5/2))+4/21*b^(5/4)*(b*B-7*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(5/4)*sqrt(b*x^2+c*x^4))-2/21*(b*B-7*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (c*sqrt(x))
+--E 797
+
+--S 798 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 798
+
+)clear all
+
+--S 799 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(5/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  2 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 799
+
+--S 800 of 1718
+--r0:=-2*A*(b*x^2+c*x^4)^(3/2)/(b*x^(7/2))+4/5*b^(3/4)*(b*B+5*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(3/4)*sqrt(b*x^2+c*x^4))-4/5*b^(3/4)*(b*B+5*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(3/4)*sqrt(b*x^2+c*x^4))+2/5*(b*B+5*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/b
+--E 800
+
+--S 801 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 801
+
+)clear all
+
+--S 802 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(7/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  3 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 802
+
+--S 803 of 1718
+--r0:=-2/3*A*(b*x^2+c*x^4)^(3/2)/(b*x^(9/2))+4/3*b^(1/4)*(b*B+A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(1/4)*sqrt(b*x^2+c*x^4))+2/3*(b*B+A*c)*sqrt(b*x^2+c*x^4)/(b*sqrt(x))
+--E 803
+
+--S 804 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 804
+
+)clear all
+
+--S 805 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(9/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  4 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 805
+
+--S 806 of 1718
+--r0:=-2/5*A*(b*x^2+c*x^4)^(3/2)/(b*x^(11/2))-4/5*(-c)^(1/4)*(5*b*B+A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*sqrt(b*x^2+c*x^4))+4/5*(-c)^(1/4)*(5*b*B+A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*sqrt(b*x^2+c*x^4))-2/5*(5*b*B+A*c)*sqrt(b*x^2+c*x^4)/(b*x^(3/2))
+--E 806
+
+--S 807 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 807
+
+)clear all
+
+--S 808 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(11/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  5 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 808
+
+--S 809 of 1718
+--r0:=-2/7*A*(b*x^2+c*x^4)^(3/2)/(b*x^(13/2))-4/21*(-c)^(3/4)*(7*b*B-A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(3/4)*sqrt(b*x^2+c*x^4))-2/21*(7*b*B-A*c)*sqrt(b*x^2+c*x^4)/(b*x^(5/2))
+--E 809
+
+--S 810 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 810
+
+)clear all
+
+--S 811 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(13/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  6 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 811
+
+--S 812 of 1718
+--r0:=-2/9*A*(b*x^2+c*x^4)^(3/2)/(b*x^(15/2))+4/15*(-c)^(5/4)*(3*b*B-A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(5/4)*sqrt(b*x^2+c*x^4))-4/15*(-c)^(5/4)*(3*b*B-A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(5/4)*sqrt(b*x^2+c*x^4))-2/15*(3*b*B-A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b*x^(7/2))-4/15*c*(3*b*B-A*c)*sqrt(b*x^2+c*x^4)/(b^2*x^(3/2))
+--E 812
+
+--S 813 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 813
+
+)clear all
+
+--S 814 of 1718
+t0:=(A+B*x^2)*sqrt(b*x^2+c*x^4)/x^(15/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (B x  + A)\|c x  + b x
+--R   (1)  ------------------------
+--R                  7 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 814
+
+--S 815 of 1718
+--r0:=-2/11*A*(b*x^2+c*x^4)^(3/2)/(b*x^(17/2))-4/231*(-c)^(7/4)*_
+---  (11*b*B-5*A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/(b^(7/4)*sqrt(b*x^2+c*x^4))-2/77*(11*b*B-5*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b*x^(9/2))-4/231*c*(11*b*B-5*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^2*x^(5/2))
+--E 815
+
+--S 816 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 816
+
+)clear all
+
+--S 817 of 1718
+t0:=x^(7/2)*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                              +-----------+
+--R              9               7        5  +-+ |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 817
+
+--S 818 of 1718
+--r0:=-2/105*(3*b*B-5*A*c)*x^(9/2)*(b*x^2+c*x^4)^(3/2)/c+2/25*B*x^(5/2)*_
+---  (b*x^2+c*x^4)^(5/2)/c+88/16575*b^(23/4)*(3*b*B-5*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(19/4)*sqrt(b*x^2+c*x^4))-88/16575*b^(23/4)*(3*b*B-5*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(19/4)*sqrt(b*x^2+c*x^4))+88/69615*b^3*(3*b*B-5*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c^3-8/7735*b^2*(3*b*B-5*A*c)*x^(9/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-4/595*b*(3*b*B-5*A*c)*x^(13/2)*_
+---  sqrt(b*x^2+c*x^4)/c-88/49725*b^4*(3*b*B-5*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/c^4
+--E 818
+
+--S 819 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 819
+
+)clear all
+
+--S 820 of 1718
+t0:=x^(5/2)*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                              +-----------+
+--R              8               6        4  +-+ |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 820
+
+--S 821 of 1718
+--r0:=-2/437*(13*b*B-23*A*c)*x^(7/2)*(b*x^2+c*x^4)^(3/2)/c+2/23*B*x^(3/2)*_
+---  (b*x^2+c*x^4)^(5/2)/c+24/33649*b^(21/4)*(13*b*B-23*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(17/4)*sqrt(b*x^2+c*x^4))+72/168245*b^3*(13*b*B-23*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^3-8/24035*b^2*(13*b*B-23*A*c)*x^(7/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-4/2185*b*(13*b*B-23*A*c)*x^(11/2)*_
+---  sqrt(b*x^2+c*x^4)/c-24/33649*b^4*(13*b*B-23*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (c^4*sqrt(x))
+--E 821
+
+--S 822 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 822
+
+)clear all
+
+--S 823 of 1718
+t0:=x^(3/2)*(A+B*x^2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                              +-----------+
+--R              7               5        3  +-+ |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 823
+
+--S 824 of 1718
+--r0:=-2/357*(11*b*B-21*A*c)*x^(5/2)*(b*x^2+c*x^4)^(3/2)/c+_
+---  2/21*B*(b*x^2+c*x^4)^(5/2)*sqrt(x)/c+8/3315*b^(19/4)*(11*b*B-21*A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(15/4)*sqrt(b*x^2+c*x^4))-8/3315*b^(19/4)*(11*b*B-21*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(15/4)*sqrt(b*x^2+c*x^4))-8/13923*b^2*(11*b*B-21*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-4/1547*b*(11*b*B-21*A*c)*x^(9/2)*_
+---  sqrt(b*x^2+c*x^4)/c+8/9945*b^3*(11*b*B-21*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/c^3
+--E 824
+
+--S 825 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 825
+
+)clear all
+
+--S 826 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)*sqrt(x)
+--R 
+--R
+--R                                              +-----------+
+--R              6               4        2  +-+ |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + A b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 826
+
+--S 827 of 1718
+--r0:=-2/285*(9*b*B-19*A*c)*x^(3/2)*(b*x^2+c*x^4)^(3/2)/c+2/19*B*_
+---  (b*x^2+c*x^4)^(5/2)/(c*sqrt(x))+8/4389*b^(17/4)*(9*b*B-19*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(13/4)*sqrt(b*x^2+c*x^4))-8/7315*b^2*(9*b*B-19*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2-4/1045*b*(9*b*B-19*A*c)*x^(7/2)*_
+---  sqrt(b*x^2+c*x^4)/c+8/4389*b^3*(9*b*B-19*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (c^3*sqrt(x))
+--E 827
+
+--S 828 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 828
+
+)clear all
+
+--S 829 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/sqrt(x)
+--R 
+--R
+--R                                          +-----------+
+--R              6               4        2  |   4      2
+--R        (B c x  + (A c + B b)x  + A b x )\|c x  + b x
+--R   (1)  -----------------------------------------------
+--R                               +-+
+--R                              \|x
+--R                                                    Type: Expression(Integer)
+--E 829
+
+--S 830 of 1718
+--r0:=2/17*B*(b*x^2+c*x^4)^(5/2)/(c*x^(3/2))-2/221*(7*b*B-17*A*c)*_
+---  (b*x^2+c*x^4)^(3/2)*sqrt(x)/c+8/1105*b^(15/4)*(7*b*B-17*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))-8/1105*b^(15/4)*(7*b*B-17*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))-4/663*b*(7*b*B-17*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c-8/3315*b^2*(7*b*B-17*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/c^2
+--E 830
+
+--S 831 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 831
+
+)clear all
+
+--S 832 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(3/2)
+--R 
+--R
+--R                                         +-----------+
+--R              5               3          |   4      2
+--R        (B c x  + (A c + B b)x  + A b x)\|c x  + b x
+--R   (1)  ----------------------------------------------
+--R                              +-+
+--R                             \|x
+--R                                                    Type: Expression(Integer)
+--E 832
+
+--S 833 of 1718
+--r0:=2/15*B*(b*x^2+c*x^4)^(5/2)/(c*x^(5/2))-2/33*(b*B-3*A*c)*_
+---  (b*x^2+c*x^4)^(3/2)/(c*sqrt(x))+8/231*b^(13/4)*(b*B-3*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(9/4)*sqrt(b*x^2+c*x^4))-4/77*b*(b*B-3*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c-8/231*b^2*(b*B-3*A*c)*sqrt(b*x^2+c*x^4)/(c^2*sqrt(x))
+--E 833
+
+--S 834 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 834
+
+)clear all
+
+--S 835 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(5/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                             +-+
+--R                            \|x
+--R                                                    Type: Expression(Integer)
+--E 835
+
+--S 836 of 1718
+--r0:=-2/117*(3*b*B-13*A*c)*(b*x^2+c*x^4)^(3/2)/(c*x^(3/2))+_
+---  2/13*B*(b*x^2+c*x^4)^(5/2)/(c*x^(7/2))+8/195*b^(11/4)*(3*b*B-13*A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(7/4)*sqrt(b*x^2+c*x^4))-8/195*b^(11/4)*(3*b*B-13*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(7/4)*sqrt(b*x^2+c*x^4))-4/195*b*(3*b*B-13*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/c
+--E 836
+
+--S 837 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 837
+
+)clear all
+
+--S 838 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(7/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                              +-+
+--R                            x\|x
+--R                                                    Type: Expression(Integer)
+--E 838
+
+--S 839 of 1718
+--r0:=-2/77*(b*B-11*A*c)*(b*x^2+c*x^4)^(3/2)/(c*x^(5/2))+_
+---  2/11*B*(b*x^2+c*x^4)^(5/2)/(c*x^(9/2))+8/77*b^(9/4)*(b*B-11*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(5/4)*sqrt(b*x^2+c*x^4))-4/77*b*(b*B-11*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(c*sqrt(x))
+--E 839
+
+--S 840 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 840
+
+)clear all
+
+--S 841 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(9/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                            2 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 841
+
+--S 842 of 1718
+--r0:=2/9*(b*B+9*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^(3/2))-_
+---  2*A*(b*x^2+c*x^4)^(5/2)/(b*x^(11/2))+8/15*b^(7/4)*(b*B+9*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(3/4)*sqrt(b*x^2+c*x^4))-8/15*b^(7/4)*(b*B+9*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(3/4)*sqrt(b*x^2+c*x^4))+4/15*(b*B+9*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)
+--E 842
+
+--S 843 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 843
+
+)clear all
+
+--S 844 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(11/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                            3 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 844
+
+--S 845 of 1718
+--r0:=2/21*(3*b*B+7*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^(5/2))-_
+---  2/3*A*(b*x^2+c*x^4)^(5/2)/(b*x^(13/2))+8/21*b^(5/4)*(3*b*B+7*A*c)*_
+---  x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(1/4)*sqrt(b*x^2+c*x^4))+4/21*(3*b*B+7*A*c)*sqrt(b*x^2+c*x^4)/_
+---  sqrt(x)
+--E 845
+
+--S 846 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 846
+
+)clear all
+
+--S 847 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(13/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                            4 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 847
+
+--S 848 of 1718
+--r0:=-2*(b*B+A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^(7/2))-2/5*A*_
+---  (b*x^2+c*x^4)^(5/2)/(b*x^(15/2))-24/5*b^(3/4)*(-c)^(1/4)*(b*B+A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  sqrt(b*x^2+c*x^4)+24/5*b^(3/4)*(-c)^(1/4)*(b*B+A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  sqrt(b*x^2+c*x^4)+12/5*c*(b*B+A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/b
+--E 848
+
+--S 849 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 849
+
+)clear all
+
+--S 850 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(15/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                            5 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 850
+
+--S 851 of 1718
+--r0:=-2/21*(7*b*B+3*A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^(9/2))-_
+---  2/7*A*(b*x^2+c*x^4)^(5/2)/(b*x^(17/2))-8/21*b^(1/4)*(-c)^(3/4)*_
+---  (7*b*B+3*A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/sqrt(b*x^2+c*x^4)+4/21*c*(7*b*B+3*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b*sqrt(x))
+--E 851
+
+--S 852 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 852
+
+)clear all
+
+--S 853 of 1718
+t0:=(A+B*x^2)*(b*x^2+c*x^4)^(3/2)/x^(17/2)
+--R 
+--R
+--R                                       +-----------+
+--R              4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + A b)\|c x  + b x
+--R   (1)  --------------------------------------------
+--R                            6 +-+
+--R                           x \|x
+--R                                                    Type: Expression(Integer)
+--E 853
+
+--S 854 of 1718
+--r0:=-2/45*(9*b*B+A*c)*(b*x^2+c*x^4)^(3/2)/(b*x^(11/2))-_
+---  2/9*A*(b*x^2+c*x^4)^(5/2)/(b*x^(19/2))+8/15*(-c)^(5/4)*(9*b*B+A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*sqrt(b*x^2+c*x^4))-8/15*(-c)^(5/4)*(9*b*B+A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*sqrt(b*x^2+c*x^4))-4/15*c*(9*b*B+A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b*x^(3/2))
+--E 854
+
+--S 855 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 855
+
+)clear all
+
+--S 856 of 1718
+t0:=x^(15/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            9      7  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 856
+
+--S 857 of 1718
+--r0:=154/3315*b^(15/4)*(15*b*B-17*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(19/4)*sqrt(b*x^2+_
+---  c*x^4))-154/3315*b^(15/4)*(15*b*B-17*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(19/4)*sqrt(b*x^2+c*x^4))+22/1989*b*(15*b*B-17*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c^3-2/221*(15*b*B-17*A*c)*x^(9/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2+2/17*B*x^(13/2)*sqrt(b*x^2+c*x^4)/c-_
+---  154/9945*b^2*(15*b*B-17*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^4
+--E 857
+
+--S 858 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 858
+
+)clear all
+
+--S 859 of 1718
+t0:=x^(13/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            8      6  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 859
+
+--S 860 of 1718
+--r0:=2/77*b^(13/4)*(13*b*B-15*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(17/4)*_
+---  sqrt(b*x^2+c*x^4))+6/385*b*(13*b*B-15*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^3-2/165*(13*b*B-15*A*c)*x^(7/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2+2/15*B*x^(11/2)*sqrt(b*x^2+c*x^4)/c-_
+---  2/77*b^2*(13*b*B-15*A*c)*sqrt(b*x^2+c*x^4)/(c^4*sqrt(x))
+--E 860
+
+--S 861 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 861
+
+)clear all
+
+--S 862 of 1718
+t0:=x^(11/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            7      5  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 862
+
+--S 863 of 1718
+--r0:=14/195*b^(11/4)*(11*b*B-13*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(15/4)*_
+---  sqrt(b*x^2+c*x^4))-14/195*b^(11/4)*(11*b*B-13*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(15/4)*sqrt(b*x^2+c*x^4))-2/117*(11*b*B-13*A*c)*x^(5/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2+2/13*B*x^(9/2)*sqrt(b*x^2+c*x^4)/c+_
+---  14/585*b*(11*b*B-13*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^3
+--E 863
+
+--S 864 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 864
+
+)clear all
+
+--S 865 of 1718
+t0:=x^(9/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            6      4  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 865
+
+--S 866 of 1718
+--r0:=10/231*b^(9/4)*(9*b*B-11*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(13/4)*_
+---  sqrt(b*x^2+c*x^4))-2/77*(9*b*B-11*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/c^2+2/11*B*x^(7/2)*sqrt(b*x^2+c*x^4)/c+10/231*b*_
+---  (9*b*B-11*A*c)*sqrt(b*x^2+c*x^4)/(c^3*sqrt(x))
+--E 866
+
+--S 867 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 867
+
+)clear all
+
+--S 868 of 1718
+t0:=x^(7/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            5      3  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 868
+
+--S 869 of 1718
+--r0:=2/15*b^(7/4)*(7*b*B-9*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(11/4)*_
+---  sqrt(b*x^2+c*x^4))-2/15*b^(7/4)*(7*b*B-9*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))+2/9*B*x^(5/2)*sqrt(b*x^2+c*x^4)/c-_
+---  2/45*(7*b*B-9*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^2
+--E 869
+
+--S 870 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 870
+
+)clear all
+
+--S 871 of 1718
+t0:=x^(5/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            4      2  +-+
+--R        (B x  + A x )\|x
+--R   (1)  -----------------
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 871
+
+--S 872 of 1718
+--r0:=2/21*b^(5/4)*(5*b*B-7*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(9/4)*sqrt(b*x^2+c*x^4))+_
+---  2/7*B*x^(3/2)*sqrt(b*x^2+c*x^4)/c-2/21*(5*b*B-7*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(c^2*sqrt(x))
+--E 872
+
+--S 873 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 873
+
+)clear all
+
+--S 874 of 1718
+t0:=x^(3/2)*(A+B*x^2)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            3        +-+
+--R        (B x  + A x)\|x
+--R   (1)  ----------------
+--R          +-----------+
+--R          |   4      2
+--R         \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 874
+
+--S 875 of 1718
+--r0:=2/5*b^(3/4)*(3*b*B-5*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(7/4)*sqrt(b*x^2+c*x^4))-_
+---  2/5*b^(3/4)*(3*b*B-5*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(7/4)*_
+---  sqrt(b*x^2+c*x^4))+2/5*B*sqrt(x)*sqrt(b*x^2+c*x^4)/c
+--E 875
+
+--S 876 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 876
+
+)clear all
+
+--S 877 of 1718
+t0:=(A+B*x^2)*sqrt(x)/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R            2      +-+
+--R        (B x  + A)\|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 877
+
+--S 878 of 1718
+--r0:=2/3*b^(1/4)*(b*B-3*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(5/4)*_
+---  sqrt(b*x^2+c*x^4))+2/3*B*sqrt(b*x^2+c*x^4)/(c*sqrt(x))
+--E 878
+
+--S 879 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 879
+
+)clear all
+
+--S 880 of 1718
+t0:=(A+B*x^2)/(sqrt(x)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  ------------------
+--R             +-----------+
+--R         +-+ |   4      2
+--R        \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 880
+
+--S 881 of 1718
+--r0:=2*(b*B+A*c)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/(b^(1/4)*(-c)^(3/4)*sqrt(b*x^2+c*x^4))-_
+---  2*(b*B+A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/(b^(1/4)*(-c)^(3/4)*sqrt(b*x^2+c*x^4))-_
+---  2*A*sqrt(b*x^2+c*x^4)/(b*x^(3/2))
+--E 881
+
+--S 882 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 882
+
+)clear all
+
+--S 883 of 1718
+t0:=(A+B*x^2)/(x^(3/2)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  -------------------
+--R              +-----------+
+--R          +-+ |   4      2
+--R        x\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 883
+
+--S 884 of 1718
+--r0:=2/3*(3*b*B-A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/(b^(3/4)*(-c)^(1/4)*sqrt(b*x^2+c*x^4))-_
+---  2/3*A*sqrt(b*x^2+c*x^4)/(b*x^(5/2))
+--E 884
+
+--S 885 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 885
+
+)clear all
+
+--S 886 of 1718
+t0:=(A+B*x^2)/(x^(5/2)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  --------------------
+--R               +-----------+
+--R         2 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 886
+
+--S 887 of 1718
+--r0:=-2/5*(-c)^(1/4)*(5*b*B-3*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(5/4)*sqrt(b*x^2+c*x^4))+_
+---  2/5*(-c)^(1/4)*(5*b*B-3*A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/_
+---  b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(5/4)*sqrt(b*x^2+c*x^4))-_
+---  2/5*A*sqrt(b*x^2+c*x^4)/(b*x^(7/2))-2/5*(5*b*B-3*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^2*x^(3/2))
+--E 887
+
+--S 888 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 888
+
+)clear all
+
+--S 889 of 1718
+t0:=(A+B*x^2)/(x^(7/2)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  --------------------
+--R               +-----------+
+--R         3 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 889
+
+--S 890 of 1718
+--r0:=2/21*(-c)^(3/4)*(7*b*B-5*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(7/4)*sqrt(b*x^2+c*x^4))-_
+---  2/7*A*sqrt(b*x^2+c*x^4)/(b*x^(9/2))-2/21*(7*b*B-5*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^2*x^(5/2))
+--E 890
+
+--S 891 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 891
+
+)clear all
+
+--S 892 of 1718
+t0:=(A+B*x^2)/(x^(9/2)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  --------------------
+--R               +-----------+
+--R         4 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 892
+
+--S 893 of 1718
+--r0:=-2/15*(-c)^(5/4)*(9*b*B-7*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(9/4)*sqrt(b*x^2+c*x^4))+_
+---  2/15*(-c)^(5/4)*(9*b*B-7*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(9/4)*sqrt(b*x^2+c*x^4))-_
+---  2/9*A*sqrt(b*x^2+c*x^4)/(b*x^(11/2))-2/45*(9*b*B-7*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^2*x^(7/2))+2/15*c*(9*b*B-7*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^3*x^(3/2))
+--E 893
+
+--S 894 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 894
+
+)clear all
+
+--S 895 of 1718
+t0:=(A+B*x^2)/(x^(11/2)*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 2
+--R              B x  + A
+--R   (1)  --------------------
+--R               +-----------+
+--R         5 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 895
+
+--S 896 of 1718
+--r0:=10/231*(-c)^(7/4)*(11*b*B-9*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(11/4)*sqrt(b*x^2+c*x^4))-_
+---  2/11*A*sqrt(b*x^2+c*x^4)/(b*x^(13/2))-2/77*(11*b*B-9*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^2*x^(9/2))+10/231*c*(11*b*B-9*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(b^3*x^(5/2))
+--E 896
+
+--S 897 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 897
+
+)clear all
+
+--S 898 of 1718
+t0:=x^(17/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                8      6  +-+
+--R            (B x  + A x )\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 898
+
+--S 899 of 1718
+--r0:=-(b*B-A*c)*x^(15/2)/(b*c*sqrt(b*x^2+c*x^4))-15/77*b^(9/4)*_
+---  (13*b*B-11*A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/((-c)^(17/4)*sqrt(b*x^2+c*x^4))-9/77*(13*b*B-11*A*c)*_
+---  x^(3/2)*sqrt(b*x^2+c*x^4)/c^3+1/11*(13*b*B-11*A*c)*x^(7/2)*_
+---  sqrt(b*x^2+c*x^4)/(b*c^2)+15/77*b*(13*b*B-11*A*c)*_
+---  sqrt(b*x^2+c*x^4)/(c^4*sqrt(x))
+--E 899
+
+--S 900 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 900
+
+)clear all
+
+--S 901 of 1718
+t0:=x^(15/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                7      5  +-+
+--R            (B x  + A x )\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 1718
+--r0:=-(b*B-A*c)*x^(13/2)/(b*c*sqrt(b*x^2+c*x^4))-7/15*b^(7/4)*_
+---  (11*b*B-9*A*c)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/((-c)^(15/4)*sqrt(b*x^2+c*x^4))+7/15*b^(7/4)*_
+---  (11*b*B-9*A*c)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+---  sqrt((b+c*x^2)/b)/((-c)^(15/4)*sqrt(b*x^2+c*x^4))+_
+---  1/9*(11*b*B-9*A*c)*x^(5/2)*sqrt(b*x^2+c*x^4)/(b*c^2)-_
+---  7/45*(11*b*B-9*A*c)*sqrt(x)*sqrt(b*x^2+c*x^4)/c^3
+--E 902
+
+--S 903 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 903
+
+)clear all
+
+--S 904 of 1718
+t0:=x^(13/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                6      4  +-+
+--R            (B x  + A x )\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 1718
+--r0:=-(b*B-A*c)*x^(11/2)/(b*c*sqrt(b*x^2+c*x^4))-5/21*b^(5/4)*(9*b*B-7*A*c)*_
+---  x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(13/4)*sqrt(b*x^2+c*x^4))+1/7*(9*b*B-7*A*c)*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4)/(b*c^2)-5/21*(9*b*B-7*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (c^3*sqrt(x))
+--E 905
+
+--S 906 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 906
+
+)clear all
+
+--S 907 of 1718
+t0:=x^(11/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                5      3  +-+
+--R            (B x  + A x )\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 907
+
+--S 908 of 1718
+--r0:=-(b*B-A*c)*x^(9/2)/(b*c*sqrt(b*x^2+c*x^4))-3/5*b^(3/4)*(7*b*B-5*A*c)*_
+---  x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))+3/5*b^(3/4)*(7*b*B-5*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(11/4)*sqrt(b*x^2+c*x^4))+1/5*(7*b*B-5*A*c)*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4)/(b*c^2)
+--E 908
+
+--S 909 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 909
+
+)clear all
+
+--S 910 of 1718
+t0:=x^(9/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                4      2  +-+
+--R            (B x  + A x )\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 910
+
+--S 911 of 1718
+--r0:=-(b*B-A*c)*x^(7/2)/(b*c*sqrt(b*x^2+c*x^4))-1/3*b^(1/4)*(5*b*B-3*A*c)*_
+---  x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  ((-c)^(9/4)*sqrt(b*x^2+c*x^4))+1/3*(5*b*B-3*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b*c^2*sqrt(x))
+--E 911
+
+--S 912 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 912
+
+)clear all
+
+--S 913 of 1718
+t0:=x^(7/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                3        +-+
+--R            (B x  + A x)\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 913
+
+--S 914 of 1718
+--r0:=-(b*B-A*c)*x^(5/2)/(b*c*sqrt(b*x^2+c*x^4))-(3*b*B-A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*(-c)^(7/4)*sqrt(b*x^2+c*x^4))+(3*b*B-A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(1/4)*(-c)^(7/4)*sqrt(b*x^2+c*x^4))
+--E 914
+
+--S 915 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 915
+
+)clear all
+
+--S 916 of 1718
+t0:=x^(5/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                 2      +-+
+--R             (B x  + A)\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 916
+
+--S 917 of 1718
+--r0:=-(b*B-A*c)*x^(3/2)/(b*c*sqrt(b*x^2+c*x^4))-(b*B+A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(3/4)*(-c)^(5/4)*sqrt(b*x^2+c*x^4))
+--E 917
+
+--S 918 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 918
+
+)clear all
+
+--S 919 of 1718
+t0:=x^(3/2)*(A+B*x^2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  2      +-+
+--R              (B x  + A)\|x
+--R   (1)  --------------------------
+--R                     +-----------+
+--R            3        |   4      2
+--R        (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 919
+
+--S 920 of 1718
+--r0:=(b*B-3*A*c)*x^(5/2)/(b^2*sqrt(b*x^2+c*x^4))-2*A*sqrt(x)/(b*_
+---  sqrt(b*x^2+c*x^4))-(b*B-3*A*c)*x*elliptic_e(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(5/4)*(-c)^(3/4)*_
+---  sqrt(b*x^2+c*x^4))+(b*B-3*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(5/4)*(-c)^(3/4)*_
+---  sqrt(b*x^2+c*x^4))
+--E 920
+
+--S 921 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 921
+
+)clear all
+
+--S 922 of 1718
+t0:=(A+B*x^2)*sqrt(x)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                   2      +-+
+--R               (B x  + A)\|x
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            4      2  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 1718
+--r0:=1/3*(3*b*B-5*A*c)*x^(3/2)/(b^2*sqrt(b*x^2+c*x^4))-2/3*A/(b*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4))+1/3*(3*b*B-5*A*c)*x*elliptic_f(asin((-c)^(1/4)*_
+---  sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(7/4)*(-c)^(1/4)*_
+---  sqrt(b*x^2+c*x^4))
+--E 923
+
+--S 924 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 924
+
+)clear all
+
+--S 925 of 1718
+t0:=(A+B*x^2)/((b*x^2+c*x^4)^(3/2)*sqrt(x))
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            4      2  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 925
+
+--S 926 of 1718
+--r0:=-2/5*A/(b*x^(3/2)*sqrt(b*x^2+c*x^4))+1/5*(5*b*B-7*A*c)*_
+---  sqrt(x)/(b^2*sqrt(b*x^2+c*x^4))-3/5*(-c)^(1/4)*(5*b*B-7*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(9/4)*sqrt(b*x^2+c*x^4))+3/5*(-c)^(1/4)*(5*b*B-7*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(9/4)*sqrt(b*x^2+c*x^4))-3/5*(5*b*B-7*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b^3*x^(3/2))
+--E 926
+
+--S 927 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 927
+
+)clear all
+
+--S 928 of 1718
+t0:=(A+B*x^2)/(x^(3/2)*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            5      3  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 928
+
+--S 929 of 1718
+--r0:=-2/7*A/(b*x^(5/2)*sqrt(b*x^2+c*x^4))+1/7*(7*b*B-9*A*c)/(b^2*sqrt(x)*_
+---  sqrt(b*x^2+c*x^4))+5/21*(-c)^(3/4)*(7*b*B-9*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(11/4)*sqrt(b*x^2+c*x^4))-5/21*(7*b*B-9*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b^3*x^(5/2))
+--E 929
+
+--S 930 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 930
+
+)clear all
+
+--S 931 of 1718
+t0:=(A+B*x^2)/(x^(5/2)*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            6      4  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 931
+
+--S 932 of 1718
+--r0:=-2/9*A/(b*x^(7/2)*sqrt(b*x^2+c*x^4))+1/9*(9*b*B-11*A*c)/(b^2*x^(3/2)*_
+---  sqrt(b*x^2+c*x^4))-7/15*(-c)^(5/4)*(9*b*B-11*A*c)*x*_
+---  elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(13/4)*sqrt(b*x^2+c*x^4))+7/15*(-c)^(5/4)*(9*b*B-11*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(13/4)*sqrt(b*x^2+c*x^4))-7/45*(9*b*B-11*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b^3*x^(7/2))+7/15*c*(9*b*B-11*A*c)*sqrt(b*x^2+c*x^4)/(b^4*x^(3/2))
+--E 932
+
+--S 933 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 933
+
+)clear all
+
+--S 934 of 1718
+t0:=(A+B*x^2)/(x^(7/2)*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                       2
+--R                    B x  + A
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            7      5  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 934
+
+--S 935 of 1718
+--r0:=-2/11*A/(b*x^(9/2)*sqrt(b*x^2+c*x^4))+1/11*(11*b*B-13*A*c)/_
+---  (b^2*x^(5/2)*sqrt(b*x^2+c*x^4))+15/77*(-c)^(7/4)*(11*b*B-13*A*c)*x*_
+---  elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+---  (b^(15/4)*sqrt(b*x^2+c*x^4))-9/77*(11*b*B-13*A*c)*sqrt(b*x^2+c*x^4)/_
+---  (b^3*x^(9/2))+15/77*c*(11*b*B-13*A*c)*sqrt(b*x^2+c*x^4)/(b^4*x^(5/2))
+--E 935
+
+--S 936 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 936
+
+)clear all
+
+--S 937 of 1718
+t0:=x^3*(d+e*x^2)*(a+c*x^4)^5
+--R 
+--R
+--R   (1)
+--R      5   25    5   23       4   21       4   19      2 3   17      2 3   15
+--R     c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R   + 
+--R        3 2   13      3 2   11     4     9     4     7    5   5    5   3
+--R     10a c e x   + 10a c d x   + 5a c e x  + 5a c d x  + a e x  + a d x
+--R                                                    Type: Polynomial(Integer)
+--E 937
+
+--S 938 of 1718
+r0:=1/4*a^5*d*x^4+1/6*a^5*e*x^6+5/8*a^4*c*d*x^8+1/2*a^4*c*e*x^10+_
+   5/6*a^3*c^2*d*x^12+5/7*a^3*c^2*e*x^14+5/8*a^2*c^3*d*x^16+_
+   5/9*a^2*c^3*e*x^18+1/4*a*c^4*d*x^20+5/22*a*c^4*e*x^22+1/24*c^5*d*x^24+_
+   1/26*c^5*e*x^26
+--R 
+--R
+--R   (2)
+--R      1  5   26    1  5   24    5    4   22   1    4   20   5  2 3   18
+--R     -- c e x   + -- c d x   + -- a c e x   + - a c d x   + - a c e x
+--R     26           24           22             4             9
+--R   + 
+--R     5  2 3   16   5  3 2   14   5  3 2   12   1  4     10   5  4     8
+--R     - a c d x   + - a c e x   + - a c d x   + - a c e x   + - a c d x
+--R     8             7             6             2             8
+--R   + 
+--R     1  5   6   1  5   4
+--R     - a e x  + - a d x
+--R     6          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 938
+
+--S 939 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 939
+
+)clear all
+
+--S 940 of 1718
+t0:=x^2*(d+e*x^2)*(a+c*x^4)^5
+--R 
+--R
+--R   (1)
+--R      5   24    5   22       4   20       4   18      2 3   16      2 3   14
+--R     c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R   + 
+--R        3 2   12      3 2   10     4     8     4     6    5   4    5   2
+--R     10a c e x   + 10a c d x   + 5a c e x  + 5a c d x  + a e x  + a d x
+--R                                                    Type: Polynomial(Integer)
+--E 940
+
+--S 941 of 1718
+r0:=1/3*a^5*d*x^3+1/5*a^5*e*x^5+5/7*a^4*c*d*x^7+5/9*a^4*c*e*x^9+_
+   10/11*a^3*c^2*d*x^11+10/13*a^3*c^2*e*x^13+2/3*a^2*c^3*d*x^15+_
+   10/17*a^2*c^3*e*x^17+5/19*a*c^4*d*x^19+5/21*a*c^4*e*x^21+_
+   1/23*c^5*d*x^23+1/25*c^5*e*x^25
+--R 
+--R
+--R   (2)
+--R      1  5   25    1  5   23    5    4   21    5    4   19   10  2 3   17
+--R     -- c e x   + -- c d x   + -- a c e x   + -- a c d x   + -- a c e x
+--R     25           23           21             19             17
+--R   + 
+--R     2  2 3   15   10  3 2   13   10  3 2   11   5  4     9   5  4     7
+--R     - a c d x   + -- a c e x   + -- a c d x   + - a c e x  + - a c d x
+--R     3             13             11             9            7
+--R   + 
+--R     1  5   5   1  5   3
+--R     - a e x  + - a d x
+--R     5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 941
+
+--S 942 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 942
+
+)clear all
+
+--S 943 of 1718
+t0:=x*(d+e*x^2)*(a+c*x^4)^5
+--R 
+--R
+--R   (1)
+--R      5   23    5   21       4   19       4   17      2 3   15      2 3   13
+--R     c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R   + 
+--R        3 2   11      3 2   9     4     7     4     5    5   3    5
+--R     10a c e x   + 10a c d x  + 5a c e x  + 5a c d x  + a e x  + a d x
+--R                                                    Type: Polynomial(Integer)
+--E 943
+
+--S 944 of 1718
+r0:=1/2*a^5*d*x^2+5/6*a^4*c*d*x^6+a^3*c^2*d*x^10+5/7*a^2*c^3*d*x^14+_
+   5/18*a*c^4*d*x^18+1/22*c^5*d*x^22+1/24*e*(a+c*x^4)^6/c
+--R 
+--R
+--R   (2)
+--R        1  6   24    1  6   22   1    5   20    5    5   18   5  2 4   16
+--R       -- c e x   + -- c d x   + - a c e x   + -- a c d x   + - a c e x
+--R       24           22           4             18             8
+--R     + 
+--R       5  2 4   14   5  3 3   12    3 3   10   5  4 2   8   5  4 2   6
+--R       - a c d x   + - a c e x   + a c d x   + - a c e x  + - a c d x
+--R       7             6                         8            6
+--R     + 
+--R       1  5     4   1  5     2    1  6
+--R       - a c e x  + - a c d x  + -- a e
+--R       4            2            24
+--R  /
+--R     c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 944
+
+--S 945 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 945
+
+)clear all
+
+--S 946 of 1718
+t0:=(d+e*x^2)*(a+c*x^4)^5
+--R 
+--R
+--R   (1)
+--R      5   22    5   20       4   18       4   16      2 3   14      2 3   12
+--R     c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R   + 
+--R        3 2   10      3 2   8     4     6     4     4    5   2    5
+--R     10a c e x   + 10a c d x  + 5a c e x  + 5a c d x  + a e x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 946
+
+--S 947 of 1718
+r0:=a^5*d*x+1/3*a^5*e*x^3+a^4*c*d*x^5+5/7*a^4*c*e*x^7+10/9*a^3*c^2*d*x^9+_
+   10/11*a^3*c^2*e*x^11+10/13*a^2*c^3*d*x^13+2/3*a^2*c^3*e*x^15+_
+   5/17*a*c^4*d*x^17+5/19*a*c^4*e*x^19+1/21*c^5*d*x^21+1/23*c^5*e*x^23
+--R 
+--R
+--R   (2)
+--R      1  5   23    1  5   21    5    4   19    5    4   17   2  2 3   15
+--R     -- c e x   + -- c d x   + -- a c e x   + -- a c d x   + - a c e x
+--R     23           21           19             17             3
+--R   + 
+--R     10  2 3   13   10  3 2   11   10  3 2   9   5  4     7    4     5
+--R     -- a c d x   + -- a c e x   + -- a c d x  + - a c e x  + a c d x
+--R     13             11              9            7
+--R   + 
+--R     1  5   3    5
+--R     - a e x  + a d x
+--R     3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 947
+
+--S 948 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 948
+
+)clear all
+
+--S 949 of 1718
+t0:=(d+e*x^2)*(a+c*x^4)^5/x
+--R 
+--R
+--R   (1)
+--R        5   22    5   20       4   18       4   16      2 3   14      2 3   12
+--R       c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R     + 
+--R          3 2   10      3 2   8     4     6     4     4    5   2    5
+--R       10a c e x   + 10a c d x  + 5a c e x  + 5a c d x  + a e x  + a d
+--R  /
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 949
+
+--S 950 of 1718
+r0:=1/2*a^5*e*x^2+5/4*a^4*c*d*x^4+5/6*a^4*c*e*x^6+5/4*a^3*c^2*d*x^8+_
+   a^3*c^2*e*x^10+5/6*a^2*c^3*d*x^12+5/7*a^2*c^3*e*x^14+_
+   5/16*a*c^4*d*x^16+5/18*a*c^4*e*x^18+1/20*c^5*d*x^20+_
+   1/22*c^5*e*x^22+a^5*d*log(x)
+--R 
+--R
+--R   (2)
+--R             5                5   22        5   20           4   18
+--R       55440a d log(x) + 2520c e x   + 2772c d x   + 15400a c e x
+--R     + 
+--R               4   16         2 3   14         2 3   12         3 2   10
+--R       17325a c d x   + 39600a c e x   + 46200a c d x   + 55440a c e x
+--R     + 
+--R             3 2   8         4     6         4     4         5   2
+--R       69300a c d x  + 46200a c e x  + 69300a c d x  + 27720a e x
+--R  /
+--R     55440
+--R                                                    Type: Expression(Integer)
+--E 950
+
+--S 951 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 951
+
+)clear all
+
+--S 952 of 1718
+t0:=(d+e*x^2)*(a+c*x^4)^5/x^2
+--R 
+--R
+--R   (1)
+--R        5   22    5   20       4   18       4   16      2 3   14      2 3   12
+--R       c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R     + 
+--R          3 2   10      3 2   8     4     6     4     4    5   2    5
+--R       10a c e x   + 10a c d x  + 5a c e x  + 5a c d x  + a e x  + a d
+--R  /
+--R      2
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 952
+
+--S 953 of 1718
+r0:=-a^5*d/x+a^5*e*x+5/3*a^4*c*d*x^3+a^4*c*e*x^5+10/7*a^3*c^2*d*x^7+_
+   10/9*a^3*c^2*e*x^9+10/11*a^2*c^3*d*x^11+10/13*a^2*c^3*e*x^13+_
+   1/3*a*c^4*d*x^15+5/17*a*c^4*e*x^17+1/19*c^5*d*x^19+1/21*c^5*e*x^21
+--R 
+--R
+--R   (2)
+--R              5   22          5   20            4   18            4   16
+--R       138567c e x   + 153153c d x   + 855855a c e x   + 969969a c d x
+--R     + 
+--R               2 3   14           2 3   12           3 2   10           3 2   8
+--R       2238390a c e x   + 2645370a c d x   + 3233230a c e x   + 4157010a c d x
+--R     + 
+--R               4     6           4     4           5   2           5
+--R       2909907a c e x  + 4849845a c d x  + 2909907a e x  - 2909907a d
+--R  /
+--R     2909907x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 953
+
+--S 954 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 954
+
+)clear all
+
+--S 955 of 1718
+t0:=(d+e*x^2)*(a+c*x^4)^5/x^3
+--R 
+--R
+--R   (1)
+--R        5   22    5   20       4   18       4   16      2 3   14      2 3   12
+--R       c e x   + c d x   + 5a c e x   + 5a c d x   + 10a c e x   + 10a c d x
+--R     + 
+--R          3 2   10      3 2   8     4     6     4     4    5   2    5
+--R       10a c e x   + 10a c d x  + 5a c e x  + 5a c d x  + a e x  + a d
+--R  /
+--R      3
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 955
+
+--S 956 of 1718
+r0:=-1/2*a^5*d/x^2+5/2*a^4*c*d*x^2+5/4*a^4*c*e*x^4+5/3*a^3*c^2*d*x^6+_
+   5/4*a^3*c^2*e*x^8+a^2*c^3*d*x^10+5/6*a^2*c^3*e*x^12+5/14*a*c^4*d*x^14+_
+   5/16*a*c^4*e*x^16+1/18*c^5*d*x^18+1/20*c^5*e*x^20+a^5*e*log(x)
+--R 
+--R
+--R   (2)
+--R            5   2             5   22       5   20          4   18
+--R       5040a e x log(x) + 252c e x   + 280c d x   + 1575a c e x
+--R     + 
+--R              4   16        2 3   14        2 3   12        3 2   10
+--R       1800a c d x   + 4200a c e x   + 5040a c d x   + 6300a c e x
+--R     + 
+--R            3 2   8        4     6         4     4        5
+--R       8400a c d x  + 6300a c e x  + 12600a c d x  - 2520a d
+--R  /
+--R          2
+--R     5040x
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 957
+
+)clear all
+
+--S 958 of 1718
+t0:=(1+x^2)/(1+x^4)
+--R 
+--R
+--R         2
+--R        x  + 1
+--R   (1)  ------
+--R         4
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 958
+
+--S 959 of 1718
+r0:=-atan(1-x*sqrt(2))/sqrt(2)+atan(1+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R               +-+               +-+
+--R        atan(x\|2  + 1) + atan(x\|2  - 1)
+--R   (2)  ---------------------------------
+--R                        +-+
+--R                       \|2
+--R                                                    Type: Expression(Integer)
+--E 959
+
+--S 960 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 960
+
+)clear all
+
+--S 961 of 1718
+t0:=(1-x^2)/(1+x^4)
+--R 
+--R
+--R           2
+--R        - x  + 1
+--R   (1)  --------
+--R          4
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 961
+
+--S 962 of 1718
+r0:=-1/2*log(1+x^2-x*sqrt(2))/sqrt(2)+1/2*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R              +-+    2                +-+    2
+--R        log(x\|2  + x  + 1) - log(- x\|2  + x  + 1)
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           2\|2
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 963
+
+)clear all
+
+--S 964 of 1718
+t0:=(1+x^2)/(1-x^4)
+--R 
+--R
+--R             1
+--R   (1)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 964
+
+--S 965 of 1718
+r0:=atanh(x)
+--R 
+--R
+--R   (2)  atanh(x)
+--R                                                    Type: Expression(Integer)
+--E 965
+
+--S 966 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 966
+
+)clear all
+
+--S 967 of 1718
+t0:=(1-x^2)/(1-x^4)
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         2
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 967
+
+--S 968 of 1718
+r0:=atan(x)
+--R 
+--R
+--R        %pi
+--R   (2)  ---
+--R         3
+--R                                                    Type: Expression(Integer)
+--E 968
+
+--S 969 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           1
+--R   (3)  ------
+--R         2
+--R        x  + 1
+--R                                                    Type: Expression(Integer)
+--E 969
+
+)clear all
+
+--S 970 of 1718
+t0:=(2+3*x^2)/(4+9*x^4)
+--R 
+--R
+--R          2
+--R        3x  + 2
+--R   (1)  -------
+--R          4
+--R        9x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 970
+
+--S 971 of 1718
+r0:=-1/2*atan(1-x*sqrt(3))/sqrt(3)+1/2*atan(1+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R               +-+               +-+
+--R        atan(x\|3  + 1) + atan(x\|3  - 1)
+--R   (2)  ---------------------------------
+--R                        +-+
+--R                      2\|3
+--R                                                    Type: Expression(Integer)
+--E 971
+
+--S 972 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 972
+
+)clear all
+
+--S 973 of 1718
+t0:=(2-3*x^2)/(4+9*x^4)
+--R 
+--R
+--R            2
+--R        - 3x  + 2
+--R   (1)  ---------
+--R           4
+--R         9x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 973
+
+--S 974 of 1718
+r0:=-1/4*log(2+3*x^2-2*x*sqrt(3))/sqrt(3)+1/4*log(2+3*x^2+2*x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R               +-+     2                 +-+     2
+--R        log(2x\|3  + 3x  + 2) - log(- 2x\|3  + 3x  + 2)
+--R   (2)  -----------------------------------------------
+--R                               +-+
+--R                             4\|3
+--R                                                    Type: Expression(Integer)
+--E 974
+
+--S 975 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 975
+
+)clear all
+
+--S 976 of 1718
+t0:=(2+3*x^2)/(4-9*x^4)
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R            2
+--R          3x  - 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 976
+
+--S 977 of 1718
+r0:=atanh(x*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R                +-+
+--R              x\|3
+--R        atanh(-----)
+--R                +-+
+--R               \|2
+--R   (2)  ------------
+--R             +-+
+--R            \|6
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +-+ +-+ +-+
+--R        \|2 \|3 \|6  - 6
+--R   (3)  ----------------
+--R               2
+--R            18x  - 12
+--R                                                    Type: Expression(Integer)
+--E 978
+
+)clear all
+
+--S 979 of 1718
+t0:=(2-3*x^2)/(4-9*x^4)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R          2
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 979
+
+--S 980 of 1718
+r0:=atan(x*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R               +-+
+--R             x\|3
+--R        atan(-----)
+--R               +-+
+--R              \|2
+--R   (2)  -----------
+--R             +-+
+--R            \|6
+--R                                                    Type: Expression(Integer)
+--E 980
+
+--S 981 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           +-+ +-+ +-+
+--R        - \|2 \|3 \|6  + 6
+--R   (3)  ------------------
+--R                2
+--R             18x  + 12
+--R                                                    Type: Expression(Integer)
+--E 981
+
+)clear all
+
+--S 982 of 1718
+t0:=(c+d*x^2)/(a+b*x^4)
+--R 
+--R
+--R           2
+--R        d x  + c
+--R   (1)  --------
+--R           4
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 982
+
+--S 983 of 1718
+r0:=-1/4*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-d*sqrt(a)+_
+   c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))+1/4*log(a^(1/4)*b^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(b))*(-d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))-_
+   1/2*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(d*sqrt(a)+c*sqrt(b))/(a^(3/4)*_
+   b^(3/4)*sqrt(2))+1/2*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(d*sqrt(a)+_
+   c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R          +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (c\|b  - d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R            +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- c\|b  + d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|b  + \|a
+--R       (2c\|b  + 2d\|a )atan(----------------)
+--R                                   4+-+
+--R                                   \|a
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|b  - \|a
+--R       (2c\|b  + 2d\|a )atan(----------------)
+--R                                   4+-+
+--R                                   \|a
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 983
+
+--S 984 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 984
+
+)clear all
+
+--S 985 of 1718
+t0:=(c-d*x^2)/(a+b*x^4)
+--R 
+--R
+--R             2
+--R        - d x  + c
+--R   (1)  ----------
+--R            4
+--R         b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 985
+
+--S 986 of 1718
+r0:=-1/2*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(-d*sqrt(a)+c*sqrt(b))/(a^(3/4)*_
+   b^(3/4)*sqrt(2))+1/2*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(-d*sqrt(a)+_
+   c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))-1/4*log(-a^(1/4)*b^(1/4)*x*_
+   sqrt(2)+sqrt(a)+x^2*sqrt(b))*(d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4)*_
+   sqrt(2))+1/4*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*_
+   (d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R          +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (c\|b  + d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R            +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- c\|b  - d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|b  + \|a
+--R       (2c\|b  - 2d\|a )atan(----------------)
+--R                                   4+-+
+--R                                   \|a
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|b  - \|a
+--R       (2c\|b  - 2d\|a )atan(----------------)
+--R                                   4+-+
+--R                                   \|a
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 986
+
+--S 987 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 987
+
+)clear all
+
+--S 988 of 1718
+t0:=(c+d*x^2)/(a-b*x^4)
+--R 
+--R
+--R             2
+--R        - d x  - c
+--R   (1)  ----------
+--R            4
+--R         b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 988
+
+--S 989 of 1718
+r0:=1/2*atan(b^(1/4)*x/a^(1/4))*(-d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4))+_
+   1/2*atanh(b^(1/4)*x/a^(1/4))*(d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4))
+--R 
+--R
+--R                              4+-+                         4+-+
+--R           +-+     +-+       x\|b        +-+     +-+      x\|b
+--R        (c\|b  + d\|a )atanh(-----) + (c\|b  - d\|a )atan(-----)
+--R                              4+-+                         4+-+
+--R                              \|a                          \|a
+--R   (2)  --------------------------------------------------------
+--R                                4+-+3 4+-+3
+--R                               2\|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 989
+
+--S 990 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 990
+
+)clear all
+
+--S 991 of 1718
+t0:=(c-d*x^2)/(a-b*x^4)
+--R 
+--R
+--R           2
+--R        d x  - c
+--R   (1)  --------
+--R           4
+--R        b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 991
+
+--S 992 of 1718
+r0:=1/2*atanh(b^(1/4)*x/a^(1/4))*(-d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4))+_
+   1/2*atan(b^(1/4)*x/a^(1/4))*(d*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4))
+--R 
+--R
+--R                              4+-+                         4+-+
+--R           +-+     +-+       x\|b        +-+     +-+      x\|b
+--R        (c\|b  - d\|a )atanh(-----) + (c\|b  + d\|a )atan(-----)
+--R                              4+-+                         4+-+
+--R                              \|a                          \|a
+--R   (2)  --------------------------------------------------------
+--R                                4+-+3 4+-+3
+--R                               2\|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 993
+
+)clear all
+
+--S 994 of 1718
+t0:=(5+2*x^2)/(-1+x^4)
+--R 
+--R
+--R          2
+--R        2x  + 5
+--R   (1)  -------
+--R          4
+--R         x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 994
+
+--S 995 of 1718
+r0:=-3/2*atan(x)-7/2*atanh(x)
+--R 
+--R
+--R        - 7atanh(x) - %pi
+--R   (2)  -----------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 995
+
+--S 996 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R             3
+--R   (3)  - -------
+--R            2
+--R          2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 996
+
+)clear all
+
+--S 997 of 1718
+t0:=x^m*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R          22             20               18                16
+--R       e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x
+--R     + 
+--R                     14                 12                 10                 8
+--R       (210e + 120d)x   + (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x
+--R     + 
+--R                    6               4             2
+--R       (45e + 120d)x  + (10e + 45d)x  + (e + 10d)x  + d
+--R  *
+--R      m
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 1718
+r0:=d*x^(1+m)/(1+m)+(10*d+e)*x^(3+m)/(3+m)+5*(9*d+2*e)*x^(5+m)/(5+m)+_
+   15*(8*d+3*e)*x^(7+m)/(7+m)+30*(7*d+4*e)*x^(9+m)/(9+m)+42*(6*d+5*e)*_
+   x^(11+m)/(11+m)+42*(5*d+6*e)*x^(13+m)/(13+m)+30*(4*d+7*e)*x^(15+m)/_
+   (15+m)+15*(3*d+8*e)*x^(17+m)/(17+m)+5*(2*d+9*e)*x^(19+m)/(19+m)+_
+   (d+10*e)*x^(21+m)/(21+m)+e*x^(23+m)/(23+m)
+--R 
+--R
+--R   (2)
+--R              11         10          9            8             7              6
+--R           e m   + 121e m   + 6435e m  + 197835e m  + 3889578e m  + 51069018e m
+--R         + 
+--R                       5                4                 3                 2
+--R           453714470e m  + 2702025590e m  + 10431670821e m  + 24372200061e m
+--R         + 
+--R           29985521895e m + 13749310575e
+--R      *
+--R          m + 23
+--R         x
+--R     + 
+--R                     11                  10                    9
+--R           (10e + d)m   + (1230e + 123d)m   + (66350e + 6635d)m
+--R         + 
+--R                                8                          7
+--R           (2065050e + 206505d)m  + (41031780e + 4103178d)m
+--R         + 
+--R                                    6                              5
+--R           (543625740e + 54362574d)m  + (4866878300e + 486687830d)m
+--R         + 
+--R                                        4                                  3
+--R           (29170139700e + 2917013970d)m  + (113209660210e + 11320966021d)m
+--R         + 
+--R                                          2
+--R           (265603425030e + 26560342503d)m  + (327789307350e + 32778930735d)m
+--R         + 
+--R           150587687250e + 15058768725d
+--R      *
+--R          m + 21
+--R         x
+--R     + 
+--R                       11                   10                      9
+--R           (45e + 10d)m   + (5625e + 1250d)m   + (307935e + 68430d)m
+--R         + 
+--R                                 8                            7
+--R           (9712035e + 2158230d)m  + (195261570e + 43391460d)m
+--R         + 
+--R                                      6                                5
+--R           (2613849210e + 580855380d)m  + (23610449790e + 5246766620d)m
+--R         + 
+--R                                          4                                   3
+--R           (142587081990e + 31686018220d)m  + (556867114785e + 123748247730d)m
+--R         + 
+--R                                            2
+--R           (1313053121565e + 291789582570d)m
+--R         + 
+--R           (1626566238675e + 361459164150d)m + 748975602375e + 166439022750d
+--R      *
+--R          m + 19
+--R         x
+--R     + 
+--R                        11                    10                       9
+--R           (120e + 45d)m   + (15240e + 5715d)m   + (847080e + 317655d)m
+--R         + 
+--R                                   8                             7
+--R           (27100440e + 10162665d)m  + (552066480e + 207024930d)m
+--R         + 
+--R                                       6                                 5
+--R           (7478387280e + 2804395230d)m  + (68263642320e + 25598865870d)m
+--R         + 
+--R                                           4
+--R           (416013088560e + 156004908210d)m
+--R         + 
+--R                                            3
+--R           (1637168621400e + 613938233025d)m
+--R         + 
+--R                                             2
+--R           (3884208909480e + 1456578341055d)m
+--R         + 
+--R           (4833983334600e + 1812743750475d)m + 2232241011000e + 837090379125d
+--R      *
+--R          m + 17
+--R         x
+--R     + 
+--R                         11                     10                        9
+--R           (210e + 120d)m   + (27090e + 15480d)m   + (1529430e + 873960d)m
+--R         + 
+--R                                   8                              7
+--R           (49684950e + 28391400d)m  + (1027080180e + 586902960d)m
+--R         + 
+--R                                        6                                  5
+--R           (14104952820e + 8059973040d)m  + (130369103340e + 74496630480d)m
+--R         + 
+--R                                           4
+--R           (803329713900e + 459045550800d)m
+--R         + 
+--R                                             3
+--R           (3191488763610e + 1823707864920d)m
+--R         + 
+--R                                             2
+--R           (7630800624090e + 4360457499480d)m
+--R         + 
+--R           (9552676531230e + 5458672303560d)m + 4427278005150e + 2529873145800d
+--R      *
+--R          m + 15
+--R         x
+--R     + 
+--R                         11                     10                         9
+--R           (252e + 210d)m   + (33012e + 27510d)m   + (1893780e + 1578150d)m
+--R         + 
+--R                                   8                               7
+--R           (62532540e + 52110450d)m  + (1313902296e + 1094918580d)m
+--R         + 
+--R                                         6                                   5
+--R           (18332656776e + 15277213980d)m  + (172007536680e + 143339613900d)m
+--R         + 
+--R                                            4
+--R           (1074541539960e + 895451283300d)m
+--R         + 
+--R                                             3
+--R           (4320681347052e + 3600567789210d)m
+--R         + 
+--R                                              2
+--R           (10434900982212e + 8695750818510d)m
+--R         + 
+--R         (13163910302340e + 10969925251950d)m + 6130077237900e + 5108397698250d
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                         11                     10                         9
+--R           (210e + 252d)m   + (27930e + 33516d)m   + (1628550e + 1954260d)m
+--R         + 
+--R                                   8                               7
+--R           (54712350e + 65654820d)m  + (1170518580e + 1404622296d)m
+--R         + 
+--R                                         6                                   5
+--R           (16635451140e + 19962541368d)m  + (158953433100e + 190744119720d)m
+--R         + 
+--R                                             4
+--R           (1010378499900e + 1212454199880d)m
+--R         + 
+--R                                             3
+--R           (4127270973210e + 4952725167852d)m
+--R         + 
+--R                                               2
+--R           (10103151372930e + 12123781647516d)m
+--R         + 
+--R         (12880020790350e + 15456024948420d)m + 6037197279750e + 7244636735700d
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                         11                     10                        9
+--R           (120e + 210d)m   + (16200e + 28350d)m   + (960360e + 1680630d)m
+--R         + 
+--R                                   8                              7
+--R           (32857560e + 57500730d)m  + (717055920e + 1254847860d)m
+--R         + 
+--R                                         6                                   5
+--R           (10410014160e + 18217524780d)m  + (101706098640e + 177985672620d)m
+--R         + 
+--R                                            4
+--R           (661140120240e + 1156995210420d)m
+--R         + 
+--R                                             3
+--R           (2759130044760e + 4828477578330d)m
+--R         + 
+--R                                              2
+--R           (6883905070440e + 12046833873270d)m
+--R         + 
+--R         (8910389161800e + 15593181033150d)m + 4216455243000e + 7378796675250d
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                        11                    10                       9
+--R           (45e + 120d)m   + (6165e + 16440d)m   + (371655e + 991080d)m
+--R         + 
+--R                                   8                             7
+--R           (12961215e + 34563240d)m  + (289061730e + 770831280d)m
+--R         + 
+--R                                        6                                  5
+--R           (4300386930e + 11467698480d)m  + (43170876270e + 115122336720d)m
+--R         + 
+--R                                           4
+--R           (288989494110e + 770638650960d)m
+--R         + 
+--R                                             3
+--R           (1243095213825e + 3314920570200d)m
+--R         + 
+--R                                             2
+--R           (3191861805705e + 8511631481880d)m
+--R         + 
+--R         (4231542908475e + 11284114422600d)m + 2032933777875e + 5421156741000d
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R                       11                   10                      9
+--R           (10e + 45d)m   + (1390e + 6255d)m   + (85230e + 383535d)m
+--R         + 
+--R                                  8                            7
+--R           (3032250e + 13645125d)m  + (69236580e + 311564610d)m
+--R         + 
+--R                                       6                                 5
+--R           (1059110220e + 4765995990d)m  + (10987467740e + 49443604830d)m
+--R         + 
+--R                                          4                                    3
+--R           (76437245300e + 343967603850d)m  + (343596367410e + 1546183653345d)m
+--R         + 
+--R                                            2
+--R           (925024452390e + 4162610035755d)m
+--R         + 
+--R           (1280338971030e + 5761525369635d)m + 632468286450e + 2846107289025d
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R                     11                  10                    9
+--R           (e + 10d)m   + (141e + 1410d)m   + (8795e + 87950d)m
+--R         + 
+--R                                8                          7
+--R           (319455e + 3194550d)m  + (7481418e + 74814180d)m
+--R         + 
+--R                                      6                                5
+--R           (118085058e + 1180850580d)m  + (1274046710e + 12740467100d)m
+--R         + 
+--R                                        4                                  3
+--R           (9315318270e + 93153182700d)m  + (44632304581e + 446323045810d)m
+--R         + 
+--R                                            2
+--R           (130403715201e + 1304037152010d)m
+--R         + 
+--R           (199334977695e + 1993349776950d)m + 105411381075e + 1054113810750d
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R              11         10          9            8             7
+--R           d m   + 143d m   + 9075d m  + 336765d m  + 8103018d m
+--R         + 
+--R                       6                5                 4                 3
+--R           132426294d m  + 1495875590d m  + 11641582810d m  + 60936676581d m
+--R         + 
+--R                          2
+--R           203363952363d m  + 387182170935d m + 316234143225d
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R        12       11        10          9           8             7
+--R       m   + 144m   + 9218m   + 345840m  + 8439783m  + 140529312m
+--R     + 
+--R                  6               5               4                3
+--R       1628301884m  + 13137458400m  + 72578259391m  + 264300628944m
+--R     + 
+--R                    2
+--R       590546123298m  + 703416314160m + 316234143225
+--R                                                    Type: Expression(Integer)
+--E 998
+
+--S 999 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 999
+
+)clear all
+
+--S 1000 of 1718
+t0:=x^5*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        27             25               23                21                 19
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   17                 15                 13                11
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x   + (45e + 120d)x
+--R   + 
+--R                 9             7      5
+--R     (10e + 45d)x  + (e + 10d)x  + d x
+--R                                                    Type: Polynomial(Integer)
+--E 1000
+
+--S 1001 of 1718
+r0:=1/22*(d-e)*(1+x^2)^11-1/24*(2*d-3*e)*(1+x^2)^12+1/26*(d-3*e)*(1+x^2)^13+_
+   1/28*e*(1+x^2)^14
+--R 
+--R
+--R   (2)
+--R      1    28     5      1    26    15      5    24    60     45    22
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (-- e + -- d)x
+--R     28          13     26           8     12          11     22
+--R   + 
+--R      21         20          35    18    105     63    16    60          14
+--R     (-- e + 6d)x   + (14e + -- d)x   + (--- e + -- d)x   + (-- e + 15d)x
+--R       2                      3           8       4           7
+--R   + 
+--R      15          12        9    10    1     5    8   1    6     1        1
+--R     (-- e + 10d)x   + (e + - d)x   + (- e + - d)x  + - d x  - ---- e + ---- d
+--R       4                    2          8     4        6        8008     1716
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1001
+
+--S 1002 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+)clear all
+
+--S 1003 of 1718
+t0:=x^4*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        26             24               22                20                 18
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   16                 14                 12                10
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x   + (45e + 120d)x
+--R   + 
+--R                 8             6      4
+--R     (10e + 45d)x  + (e + 10d)x  + d x
+--R                                                    Type: Polynomial(Integer)
+--E 1003
+
+--S 1004 of 1718
+r0:=1/5*d*x^5+1/7*(10*d+e)*x^7+5/9*(9*d+2*e)*x^9+15/11*(8*d+3*e)*x^11+_
+   30/13*(7*d+4*e)*x^13+14/5*(6*d+5*e)*x^15+42/17*(5*d+6*e)*x^17+_
+   30/19*(4*d+7*e)*x^19+5/7*(3*d+8*e)*x^21+5/23*(2*d+9*e)*x^23+_
+   1/25*(d+10*e)*x^25+1/27*e*x^27
+--R 
+--R
+--R   (2)
+--R      1    27    2      1    25    45     10    23    40     15    21
+--R     -- e x   + (- e + -- d)x   + (-- e + -- d)x   + (-- e + -- d)x
+--R     27          5     25          23     23           7      7
+--R   + 
+--R      210     120    19    252     210    17          84    15
+--R     (--- e + --- d)x   + (--- e + --- d)x   + (14e + -- d)x
+--R       19      19           17      17                 5
+--R   + 
+--R      120     210    13    45     120    11    10         9    1     10    7
+--R     (--- e + --- d)x   + (-- e + --- d)x   + (-- e + 5d)x  + (- e + -- d)x
+--R       13      13          11      11           9              7      7
+--R   + 
+--R     1    5
+--R     - d x
+--R     5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1004
+
+--S 1005 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1005
+
+)clear all
+
+--S 1006 of 1718
+t0:=x^3*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        25             23               21                19                 17
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   15                 13                 11                9
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x   + (45e + 120d)x
+--R   + 
+--R                 7             5      3
+--R     (10e + 45d)x  + (e + 10d)x  + d x
+--R                                                    Type: Polynomial(Integer)
+--E 1006
+
+--S 1007 of 1718
+r0:=-1/22*(d-e)*(1+x^2)^11+1/24*(d-2*e)*(1+x^2)^12+1/26*e*(1+x^2)^13
+--R 
+--R
+--R   (2)
+--R      1    26     5      1    24    45      5    22         9    20
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (6e + - d)x
+--R     26          12     24          22     11               4
+--R   + 
+--R      35     20    18    63     105    16               14          35    12
+--R     (-- e + -- d)x   + (-- e + --- d)x   + (15e + 18d)x   + (10e + -- d)x
+--R       3      3           4      8                                   2
+--R   + 
+--R      9          10    5     45    8    1     5    6   1    4     1       1
+--R     (- e + 12d)x   + (- e + -- d)x  + (- e + - d)x  + - d x  + ---- e - --- d
+--R      2                4      8         6     3        4        1716     264
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1007
+
+--S 1008 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1008
+
+)clear all
+
+--S 1009 of 1718
+t0:=x^2*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        24             22               20                18                 16
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   14                 12                 10                8
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x   + (45e + 120d)x
+--R   + 
+--R                 6             4      2
+--R     (10e + 45d)x  + (e + 10d)x  + d x
+--R                                                    Type: Polynomial(Integer)
+--E 1009
+
+--S 1010 of 1718
+r0:=1/3*d*x^3+1/5*(10*d+e)*x^5+5/7*(9*d+2*e)*x^7+5/3*(8*d+3*e)*x^9+_
+   30/11*(7*d+4*e)*x^11+42/13*(6*d+5*e)*x^13+14/5*(5*d+6*e)*x^15+_
+   30/17*(4*d+7*e)*x^17+15/19*(3*d+8*e)*x^19+5/21*(2*d+9*e)*x^21+_
+   1/23*(d+10*e)*x^23+1/25*e*x^25
+--R 
+--R
+--R   (2)
+--R      1    25    10      1    23    15     10    21    120     45    19
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (--- e + -- d)x
+--R     25          23     23           7     21           19     19
+--R   + 
+--R      210     120    17    84          15    210     252    13
+--R     (--- e + --- d)x   + (-- e + 14d)x   + (--- e + --- d)x
+--R       17      17           5                 13      13
+--R   + 
+--R    120     210    11         40    9    10     45    7    1         5   1    3
+--R   (--- e + --- d)x   + (5e + -- d)x  + (-- e + -- d)x  + (- e + 2d)x  + - d x
+--R     11      11                3          7      7         5             3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1010
+
+--S 1011 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1011
+
+)clear all
+
+--S 1012 of 1718
+t0:=x*(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        23             21               19                17                 15
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   13                 11                 9                7
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x  + (45e + 120d)x
+--R   + 
+--R                 5             3
+--R     (10e + 45d)x  + (e + 10d)x  + d x
+--R                                                    Type: Polynomial(Integer)
+--E 1012
+
+--S 1013 of 1718
+r0:=1/22*(d-e)*(1+x^2)^11+1/24*e*(1+x^2)^12
+--R 
+--R
+--R   (2)
+--R      1    24     5      1    22    9     1    20    20     5    18
+--R     -- e x   + (-- e + -- d)x   + (- e + - d)x   + (-- e + - d)x
+--R     24          11     22          4     2           3     2
+--R   + 
+--R      105     15    16               14    35          12               10
+--R     (--- e + -- d)x   + (18e + 15d)x   + (-- e + 21d)x   + (12e + 21d)x
+--R       8       2                            2
+--R   + 
+--R      45          8    5     15    6    1     5    4   1    2    1       1
+--R     (-- e + 15d)x  + (- e + -- d)x  + (- e + - d)x  + - d x  - --- e + -- d
+--R       8               3      2         4     2        2        264     22
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1013
+
+--S 1014 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1014
+
+)clear all
+
+--S 1015 of 1718
+t0:=(d+e*x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        22             20               18                16                 14
+--R     e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x   + (210e + 120d)x
+--R   + 
+--R                   12                 10                 8                6
+--R     (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x  + (45e + 120d)x
+--R   + 
+--R                 4             2
+--R     (10e + 45d)x  + (e + 10d)x  + d
+--R                                                    Type: Polynomial(Integer)
+--E 1015
+
+--S 1016 of 1718
+r0:=d*x+1/3*(10*d+e)*x^3+(9*d+2*e)*x^5+15/7*(8*d+3*e)*x^7+10/3*(7*d+4*e)*_
+   x^9+42/11*(6*d+5*e)*x^11+42/13*(5*d+6*e)*x^13+2*(4*d+7*e)*x^15+_
+   15/17*(3*d+8*e)*x^17+5/19*(2*d+9*e)*x^19+1/21*(d+10*e)*x^21+1/23*e*x^23
+--R 
+--R
+--R   (2)
+--R      1    23    10      1    21    45     10    19    120     45    17
+--R     -- e x   + (-- e + -- d)x   + (-- e + -- d)x   + (--- e + -- d)x
+--R     23          21     21          19     19           17     17
+--R   + 
+--R                15    252     210    13    210     252    11    40     70    9
+--R     (14e + 8d)x   + (--- e + --- d)x   + (--- e + --- d)x   + (-- e + -- d)x
+--R                       13      13           11      11           3      3
+--R   + 
+--R      45     120    7             5    1     10    3
+--R     (-- e + --- d)x  + (2e + 9d)x  + (- e + -- d)x  + d x
+--R       7      7                        3      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1016
+
+--S 1017 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1017
+
+)clear all
+
+--S 1018 of 1718
+t0:=(d+e*x^2)*(1+2*x^2+x^4)^5/x
+--R 
+--R
+--R   (1)
+--R          22             20               18                16
+--R       e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x
+--R     + 
+--R                     14                 12                 10                 8
+--R       (210e + 120d)x   + (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x
+--R     + 
+--R                    6               4             2
+--R       (45e + 120d)x  + (10e + 45d)x  + (e + 10d)x  + d
+--R  /
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1018
+
+--S 1019 of 1718
+r0:=5*d*x^2+45/4*d*x^4+20*d*x^6+105/4*d*x^8+126/5*d*x^10+35/2*d*x^12+_
+   60/7*d*x^14+45/16*d*x^16+5/9*d*x^18+1/20*d*x^20+1/22*e*(1+x^2)^11+d*log(x)
+--R 
+--R
+--R   (2)
+--R                              22                    20                      18
+--R       55440d log(x) + 2520e x   + (27720e + 2772d)x   + (138600e + 30800d)x
+--R     + 
+--R                           16                       14                        12
+--R       (415800e + 155925d)x   + (831600e + 475200d)x   + (1164240e + 970200d)x
+--R     + 
+--R                             10                        8
+--R       (1164240e + 1397088d)x   + (831600e + 1455300d)x
+--R     + 
+--R                            6                       4                      2
+--R       (415800e + 1108800d)x  + (138600e + 623700d)x  + (27720e + 277200d)x
+--R     + 
+--R       2520e
+--R  /
+--R     55440
+--R                                                    Type: Expression(Integer)
+--E 1019
+
+--S 1020 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1020
+
+)clear all
+
+--S 1021 of 1718
+t0:=(d+e*x^2)*(1+2*x^2+x^4)^5/x^2
+--R 
+--R
+--R   (1)
+--R          22             20               18                16
+--R       e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x
+--R     + 
+--R                     14                 12                 10                 8
+--R       (210e + 120d)x   + (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x
+--R     + 
+--R                    6               4             2
+--R       (45e + 120d)x  + (10e + 45d)x  + (e + 10d)x  + d
+--R  /
+--R      2
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1021
+
+--S 1022 of 1718
+r0:=-d/x+(10*d+e)*x+5/3*(9*d+2*e)*x^3+3*(8*d+3*e)*x^5+30/7*(7*d+4*e)*x^7+_
+   14/3*(6*d+5*e)*x^9+42/11*(5*d+6*e)*x^11+30/13*(4*d+7*e)*x^13+(3*d+8*e)*_
+   x^15+5/17*(2*d+9*e)*x^17+1/19*(d+10*e)*x^19+1/21*e*x^21
+--R 
+--R
+--R   (2)
+--R               22                      20                        18
+--R       46189e x   + (510510e + 51051d)x   + (2567565e + 570570d)x
+--R     + 
+--R                             16                          14
+--R       (7759752e + 2909907d)x   + (15668730e + 8953560d)x
+--R     + 
+--R                               12                           10
+--R       (22221108e + 18517590d)x   + (22632610e + 27159132d)x
+--R     + 
+--R                               8                          6
+--R       (16628040e + 29099070d)x  + (8729721e + 23279256d)x
+--R     + 
+--R                              4                        2
+--R       (3233230e + 14549535d)x  + (969969e + 9699690d)x  - 969969d
+--R  /
+--R     969969x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1022
+
+--S 1023 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1023
+
+)clear all
+
+--S 1024 of 1718
+t0:=(d+e*x^2)*(1+2*x^2+x^4)^5/x^3
+--R 
+--R
+--R   (1)
+--R          22             20               18                16
+--R       e x   + (10e + d)x   + (45e + 10d)x   + (120e + 45d)x
+--R     + 
+--R                     14                 12                 10                 8
+--R       (210e + 120d)x   + (252e + 210d)x   + (210e + 252d)x   + (120e + 210d)x
+--R     + 
+--R                    6               4             2
+--R       (45e + 120d)x  + (10e + 45d)x  + (e + 10d)x  + d
+--R  /
+--R      3
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1024
+
+--S 1025 of 1718
+r0:=-1/2*d/x^2+5/2*(9*d+2*e)*x^2+15/4*(8*d+3*e)*x^4+5*(7*d+4*e)*x^6+_
+   21/4*(6*d+5*e)*x^8+21/5*(5*d+6*e)*x^10+5/2*(4*d+7*e)*x^12+_
+   15/14*(3*d+8*e)*x^14+5/16*(2*d+9*e)*x^16+1/18*(d+10*e)*x^18+_
+   1/20*e*x^20+(10*d+e)*log(x)
+--R 
+--R
+--R   (2)
+--R                        2               22                  20
+--R       (5040e + 50400d)x log(x) + 252e x   + (2800e + 280d)x
+--R     + 
+--R                        18                     16                     14
+--R       (14175e + 3150d)x   + (43200e + 16200d)x   + (88200e + 50400d)x
+--R     + 
+--R                           12                       10                       8
+--R       (127008e + 105840d)x   + (132300e + 158760d)x   + (100800e + 176400d)x
+--R     + 
+--R                          6                      4
+--R       (56700e + 151200d)x  + (25200e + 113400d)x  - 2520d
+--R  /
+--R          2
+--R     5040x
+--R                                                    Type: Expression(Integer)
+--E 1025
+
+--S 1026 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1026
+
+)clear all
+
+--S 1027 of 1718
+t0:=x^m*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R        22      20      18       16       14       12       10       8       6
+--R       x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R     + 
+--R          4      2
+--R       55x  + 11x  + 1
+--R  *
+--R      m
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 1027
+
+--S 1028 of 1718
+r0:=x^(1+m)/(1+m)+11*x^(3+m)/(3+m)+55*x^(5+m)/(5+m)+165*x^(7+m)/(7+m)+_
+   330*x^(9+m)/(9+m)+462*x^(11+m)/(11+m)+462*x^(13+m)/(13+m)+_
+   330*x^(15+m)/(15+m)+165*x^(17+m)/(17+m)+55*x^(19+m)/(19+m)+_
+   11*x^(21+m)/(21+m)+x^(23+m)/(23+m)
+--R 
+--R
+--R   (2)
+--R            11       10        9          8           7            6
+--R           m   + 121m   + 6435m  + 197835m  + 3889578m  + 51069018m
+--R         + 
+--R                     5              4               3               2
+--R           453714470m  + 2702025590m  + 10431670821m  + 24372200061m
+--R         + 
+--R           29985521895m + 13749310575
+--R      *
+--R          m + 23
+--R         x
+--R     + 
+--R              11        10         9           8            7             6
+--R           11m   + 1353m   + 72985m  + 2271555m  + 45134958m  + 597988314m
+--R         + 
+--R                      5               4                3                2
+--R           5353566130m  + 32087153670m  + 124530626231m  + 292163767533m
+--R         + 
+--R           360568238085m + 165646455975
+--R      *
+--R          m + 21
+--R         x
+--R     + 
+--R              11        10          9            8             7              6
+--R           55m   + 6875m   + 376365m  + 11870265m  + 238653030m  + 3194704590m
+--R         + 
+--R                       5                4                3                 2
+--R           28857216410m  + 174273100210m  + 680615362515m  + 1604842704135m
+--R         + 
+--R           1988025402825m + 915414625125
+--R      *
+--R          m + 19
+--R         x
+--R     + 
+--R               11         10           9            8             7
+--R           165m   + 20955m   + 1164735m  + 37263105m  + 759091410m
+--R         + 
+--R                       6               5                4                 3
+--R           10282782510m  + 93862508190m  + 572017996770m  + 2251106854425m
+--R         + 
+--R                         2
+--R           5340787250535m  + 6646727085075m + 3069331390125
+--R      *
+--R          m + 17
+--R         x
+--R     + 
+--R               11         10           9            8              7
+--R           330m   + 42570m   + 2403390m  + 78076350m  + 1613983140m
+--R         + 
+--R                       6                5                 4                 3
+--R           22164925860m  + 204865733820m  + 1262375264700m  + 5015196628530m
+--R         + 
+--R                          2
+--R           11991258123570m  + 15011348834790m + 6957151150950
+--R      *
+--R          m + 15
+--R         x
+--R     + 
+--R               11         10           9             8              7
+--R           462m   + 60522m   + 3471930m  + 114642990m  + 2408820876m
+--R         + 
+--R                       6                5                 4                 3
+--R           33609870756m  + 315347150580m  + 1969992823260m  + 7921249136262m
+--R         + 
+--R                          2
+--R           19130651800722m  + 24133835554290m + 11238474936150
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R               11         10           9             8              7
+--R           462m   + 61446m   + 3582810m  + 120367170m  + 2575140876m
+--R         + 
+--R                       6                5                 4                 3
+--R           36597992508m  + 349697552820m  + 2222832699780m  + 9079996141062m
+--R         + 
+--R                          2
+--R           22226933020446m  + 28336045738770m + 13281834015450
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R               11         10           9            8              7
+--R           330m   + 44550m   + 2640990m  + 90358290m  + 1971903780m
+--R         + 
+--R                       6                5                 4                 3
+--R           28627538940m  + 279691771260m  + 1818135330660m  + 7587607623090m
+--R         + 
+--R                          2
+--R           18930738943710m  + 24503570194950m + 11595251918250
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R               11         10           9            8              7
+--R           165m   + 22605m   + 1362735m  + 47524455m  + 1059893010m
+--R         + 
+--R                       6                5                 4                 3
+--R           15768085410m  + 158293212990m  + 1059628145070m  + 4558015784025m
+--R         + 
+--R                          2
+--R           11703493287585m  + 15515657331075m + 7454090518875
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R              11        10          9            8             7              6
+--R           55m   + 7645m   + 468765m  + 16677375m  + 380801190m  + 5825106210m
+--R         + 
+--R                       5                4                 3                 2
+--R           60431072570m  + 420404849150m  + 1889780020755m  + 5087634488145m
+--R         + 
+--R           7041864340665m + 3478575575475
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R              11        10         9           8            7              6
+--R           11m   + 1551m   + 96745m  + 3514005m  + 82295598m  + 1298935638m
+--R         + 
+--R                       5                4                3                 2
+--R           14014513810m  + 102468500970m  + 490955350391m  + 1434440867211m
+--R         + 
+--R           2192684754645m + 1159525191825
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R            11       10        9          8           7             6
+--R           m   + 143m   + 9075m  + 336765m  + 8103018m  + 132426294m
+--R         + 
+--R                      5               4               3                2
+--R           1495875590m  + 11641582810m  + 60936676581m  + 203363952363m
+--R         + 
+--R           387182170935m + 316234143225
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R        12       11        10          9           8             7
+--R       m   + 144m   + 9218m   + 345840m  + 8439783m  + 140529312m
+--R     + 
+--R                  6               5               4                3
+--R       1628301884m  + 13137458400m  + 72578259391m  + 264300628944m
+--R     + 
+--R                    2
+--R       590546123298m  + 703416314160m + 316234143225
+--R                                                    Type: Expression(Integer)
+--E 1028
+
+--S 1029 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1029
+
+)clear all
+
+--S 1030 of 1718
+t0:=x^5*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      27      25      23       21       19       17       15       13       11
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x   + 165x
+--R   + 
+--R        9      7    5
+--R     55x  + 11x  + x
+--R                                                    Type: Polynomial(Integer)
+--E 1030
+
+--S 1031 of 1718
+r0:=1/24*(1+x^2)^12-1/13*(1+x^2)^13+1/28*(1+x^2)^14
+--R 
+--R
+--R   (2)
+--R      1  28   11  26   55  24   15  22   33  20   77  18   231  16   165  14
+--R     -- x   + -- x   + -- x   + -- x   + -- x   + -- x   + --- x   + --- x
+--R     28       26       24        2        2        3        8         7
+--R   + 
+--R     55  12   11  10   11  8   1  6     1
+--R     -- x   + -- x   + -- x  + - x  + ----
+--R      4        2        8      6      2184
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1031
+
+--S 1032 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1032
+
+)clear all
+
+--S 1033 of 1718
+t0:=x^4*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      26      24      22       20       18       16       14       12       10
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x   + 165x
+--R   + 
+--R        8      6    4
+--R     55x  + 11x  + x
+--R                                                    Type: Polynomial(Integer)
+--E 1033
+
+--S 1034 of 1718
+r0:=1/5*x^5+11/7*x^7+55/9*x^9+15*x^11+330/13*x^13+154/5*x^15+462/17*x^17+_
+   330/19*x^19+55/7*x^21+55/23*x^23+11/25*x^25+1/27*x^27
+--R 
+--R
+--R   (2)
+--R      1  27   11  25   55  23   55  21   330  19   462  17   154  15   330  13
+--R     -- x   + -- x   + -- x   + -- x   + --- x   + --- x   + --- x   + --- x
+--R     27       25       23        7        19        17        5         13
+--R   + 
+--R        11   55  9   11  7   1  5
+--R     15x   + -- x  + -- x  + - x
+--R              9       7      5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1034
+
+--S 1035 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1035
+
+)clear all
+
+--S 1036 of 1718
+t0:=x^3*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      25      23      21       19       17       15       13       11       9
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x   + 165x
+--R   + 
+--R        7      5    3
+--R     55x  + 11x  + x
+--R                                                    Type: Polynomial(Integer)
+--E 1036
+
+--S 1037 of 1718
+r0:=-1/24*(1+x^2)^12+1/26*(1+x^2)^13
+--R 
+--R
+--R   (2)
+--R      1  26   11  24   5  22   33  20   55  18   231  16      14   55  12
+--R     -- x   + -- x   + - x   + -- x   + -- x   + --- x   + 33x   + -- x
+--R     26       24       2        4        3        8                 2
+--R   + 
+--R     33  10   55  8   11  6   1  4    1
+--R     -- x   + -- x  + -- x  + - x  - ---
+--R      2        8       6      4      312
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1037
+
+--S 1038 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1038
+
+)clear all
+
+--S 1039 of 1718
+t0:=x^2*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      24      22      20       18       16       14       12       10       8
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x   + 165x
+--R   + 
+--R        6      4    2
+--R     55x  + 11x  + x
+--R                                                    Type: Polynomial(Integer)
+--E 1039
+
+--S 1040 of 1718
+r0:=1/3*x^3+11/5*x^5+55/7*x^7+55/3*x^9+30*x^11+462/13*x^13+154/5*x^15+_
+   330/17*x^17+165/19*x^19+55/21*x^21+11/23*x^23+1/25*x^25
+--R 
+--R
+--R   (2)
+--R      1  25   11  23   55  21   165  19   330  17   154  15   462  13      11
+--R     -- x   + -- x   + -- x   + --- x   + --- x   + --- x   + --- x   + 30x
+--R     25       23       21        19        17        5         13
+--R   + 
+--R     55  9   55  7   11  5   1  3
+--R     -- x  + -- x  + -- x  + - x
+--R      3       7       5      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1040
+
+--S 1041 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1041
+
+)clear all
+
+--S 1042 of 1718
+t0:=x*(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      23      21      19       17       15       13       11       9       7
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R   + 
+--R        5      3
+--R     55x  + 11x  + x
+--R                                                    Type: Polynomial(Integer)
+--E 1042
+
+--S 1043 of 1718
+r0:=1/24*(1+x^2)^12
+--R 
+--R
+--R   (2)
+--R      1  24   1  22   11  20   55  18   165  16      14   77  12      10
+--R     -- x   + - x   + -- x   + -- x   + --- x   + 33x   + -- x   + 33x
+--R     24       2        4        6        8                 2
+--R   + 
+--R     165  8   55  6   11  4   1  2    1
+--R     --- x  + -- x  + -- x  + - x  + --
+--R      8        6       4      2      24
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1043
+
+--S 1044 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1044
+
+)clear all
+
+--S 1045 of 1718
+t0:=(1+x^2)*(1+2*x^2+x^4)^5
+--R 
+--R
+--R   (1)
+--R      22      20      18       16       14       12       10       8       6
+--R     x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R   + 
+--R        4      2
+--R     55x  + 11x  + 1
+--R                                                    Type: Polynomial(Integer)
+--E 1045
+
+--S 1046 of 1718
+r0:=x+11/3*x^3+11*x^5+165/7*x^7+110/3*x^9+42*x^11+462/13*x^13+22*x^15+_
+   165/17*x^17+55/19*x^19+11/21*x^21+1/23*x^23
+--R 
+--R
+--R   (2)
+--R      1  23   11  21   55  19   165  17      15   462  13      11   110  9
+--R     -- x   + -- x   + -- x   + --- x   + 22x   + --- x   + 42x   + --- x
+--R     23       21       19        17                13                3
+--R   + 
+--R     165  7      5   11  3
+--R     --- x  + 11x  + -- x  + x
+--R      7               3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1046
+
+--S 1047 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1047
+
+)clear all
+
+--S 1048 of 1718
+t0:=(1+x^2)*(1+2*x^2+x^4)^5/x
+--R 
+--R
+--R   (1)
+--R        22      20      18       16       14       12       10       8       6
+--R       x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R     + 
+--R          4      2
+--R       55x  + 11x  + 1
+--R  /
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1048
+
+--S 1049 of 1718
+r0:=11/2*x^2+55/4*x^4+55/2*x^6+165/4*x^8+231/5*x^10+77/2*x^12+165/7*x^14+_
+   165/16*x^16+55/18*x^18+11/20*x^20+1/22*x^22+log(x)
+--R 
+--R
+--R   (2)
+--R                          22         20          18          16           14
+--R       55440log(x) + 2520x   + 30492x   + 169400x   + 571725x   + 1306800x
+--R     + 
+--R               12           10           8           6          4          2
+--R       2134440x   + 2561328x   + 2286900x  + 1524600x  + 762300x  + 304920x
+--R  /
+--R     55440
+--R                                                    Type: Expression(Integer)
+--E 1049
+
+--S 1050 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1050
+
+)clear all
+
+--S 1051 of 1718
+t0:=(1+x^2)*(1+2*x^2+x^4)^5/x^2
+--R 
+--R
+--R   (1)
+--R        22      20      18       16       14       12       10       8       6
+--R       x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R     + 
+--R          4      2
+--R       55x  + 11x  + 1
+--R  /
+--R      2
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1051
+
+--S 1052 of 1718
+r0:=(-1)/x+11*x+55/3*x^3+33*x^5+330/7*x^7+154/3*x^9+42*x^11+330/13*x^13+_
+   11*x^15+55/17*x^17+11/19*x^19+1/21*x^21
+--R 
+--R
+--R   (2)
+--R            22         20          18          16           14           12
+--R       4199x   + 51051x   + 285285x   + 969969x   + 2238390x   + 3703518x
+--R     + 
+--R               10           8           6           4          2
+--R       4526522x   + 4157010x  + 2909907x  + 1616615x  + 969969x  - 88179
+--R  /
+--R     88179x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1052
+
+--S 1053 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1053
+
+)clear all
+
+--S 1054 of 1718
+t0:=(1+x^2)*(1+2*x^2+x^4)^5/x^3
+--R 
+--R
+--R   (1)
+--R        22      20      18       16       14       12       10       8       6
+--R       x   + 11x   + 55x   + 165x   + 330x   + 462x   + 462x   + 330x  + 165x
+--R     + 
+--R          4      2
+--R       55x  + 11x  + 1
+--R  /
+--R      3
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1054
+
+--S 1055 of 1718
+r0:=(-1/2)/x^2+55/2*x^2+165/4*x^4+55*x^6+231/4*x^8+231/5*x^10+55/2*x^12+_
+   165/14*x^14+55/16*x^16+11/18*x^18+1/20*x^20+11*log(x)
+--R 
+--R
+--R   (2)
+--R             2             22        20         18         16          14
+--R       55440x log(x) + 252x   + 3080x   + 17325x   + 59400x   + 138600x
+--R     + 
+--R              12          10          8          6          4
+--R       232848x   + 291060x   + 277200x  + 207900x  + 138600x  - 2520
+--R  /
+--R          2
+--R     5040x
+--R                                                    Type: Expression(Integer)
+--E 1055
+
+--S 1056 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1056
+
+)clear all
+
+--S 1057 of 1718
+t0:=(3+2*x^2)/(1-2*x^2+x^4)
+--R 
+--R
+--R             2
+--R           2x  + 3
+--R   (1)  ------------
+--R         4     2
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1057
+
+--S 1058 of 1718
+r0:=5/2*x/(1-x^2)+1/2*atanh(x)
+--R 
+--R
+--R          2
+--R        (x  - 1)atanh(x) - 5x
+--R   (2)  ---------------------
+--R                 2
+--R               2x  - 2
+--R                                                    Type: Expression(Integer)
+--E 1058
+
+--S 1059 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1059
+
+)clear all
+
+--S 1060 of 1718
+t0:=x*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R            3         2 4         2    2 p
+--R   (1)  (b x  + a x)(b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1060
+
+--S 1061 of 1718
+r0:=1/4*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b*(1+p))
+--R 
+--R
+--R          2 4         2    2 p + 1
+--R        (b x  + 2a b x  + a )
+--R   (2)  --------------------------
+--R                 4b p + 4b
+--R                                                    Type: Expression(Integer)
+--E 1061
+
+--S 1062 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1062
+
+)clear all
+
+--S 1063 of 1718
+t0:=x^3*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R            5      3   2 4         2    2 p
+--R   (1)  (b x  + a x )(b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1063
+
+--S 1064 of 1718
+r0:=-1/4*a*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^2*(1+p)*(3+2*p))+_
+   1/2*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b*(3+2*p))
+--R 
+--R
+--R                     2       2 4         2    2 p + 1
+--R        ((2b p + 2b)x  - a)(b x  + 2a b x  + a )
+--R   (2)  ---------------------------------------------
+--R                       2 2      2       2
+--R                     8b p  + 20b p + 12b
+--R                                                    Type: Expression(Integer)
+--E 1064
+
+--S 1065 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1065
+
+)clear all
+
+--S 1066 of 1718
+t0:=x^5*(a+b*x^2)*(a^2+2*a*b*x^2+b^2*x^4)^p
+--R 
+--R
+--R            7      5   2 4         2    2 p
+--R   (1)  (b x  + a x )(b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1066
+
+--S 1067 of 1718
+r0:=1/4*a^2*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^3*(1+p)*(2+p)*(3+2*p))-_
+   1/2*a*x^2*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b^2*(2+p)*(3+2*p))+_
+   1/4*x^4*(a^2+2*a*b*x^2+b^2*x^4)^(1+p)/(b*(2+p))
+--R 
+--R
+--R   (2)
+--R       2 2     2      2  4                     2    2   2 4         2    2 p + 1
+--R   ((2b p  + 5b p + 3b )x  + (- 2a b p - 2a b)x  + a )(b x  + 2a b x  + a )
+--R   -----------------------------------------------------------------------------
+--R                             3 3      3 2      3       3
+--R                           8b p  + 36b p  + 52b p + 24b
+--R                                                    Type: Expression(Integer)
+--E 1067
+
+--S 1068 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1068
+
+)clear all
+
+--S 1069 of 1718
+t0:=(d-e*x^2)/(c*d^2/e^2+b*x^2+c*x^4)
+--R 
+--R
+--R                3 2      2
+--R             - e x  + d e
+--R   (1)  ----------------------
+--R           2 4      2 2      2
+--R        c e x  + b e x  + c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1069
+
+--S 1070 of 1718
+r0:=-1/2*e^(3/2)*log(d+e*x^2-x*sqrt(e)*sqrt(2*c*d-b*e)/sqrt(c))/(sqrt(c)*_
+   sqrt(2*c*d-b*e))+1/2*e^(3/2)*log(d+e*x^2+x*sqrt(e)*sqrt(2*c*d-b*e)/_
+   sqrt(c))/(sqrt(c)*sqrt(2*c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                  +------------+ +-+       2      +-+
+--R         +-+    x\|- b e + 2c d \|e  + (e x  + d)\|c
+--R       e\|e log(-------------------------------------)
+--R                                  +-+
+--R                                 \|c
+--R     + 
+--R                      +------------+ +-+       2      +-+
+--R           +-+    - x\|- b e + 2c d \|e  + (e x  + d)\|c
+--R       - e\|e log(---------------------------------------)
+--R                                     +-+
+--R                                    \|c
+--R  /
+--R       +------------+ +-+
+--R     2\|- b e + 2c d \|c
+--R                                                    Type: Expression(Integer)
+--E 1070
+
+--S 1071 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1071
+
+)clear all
+
+--S 1072 of 1718
+t0:=(d+e*x^2)/(c*d^2/e^2+b*x^2+c*x^4)
+--R 
+--R
+--R               3 2      2
+--R              e x  + d e
+--R   (1)  ----------------------
+--R           2 4      2 2      2
+--R        c e x  + b e x  + c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1072
+
+--S 1073 of 1718
+r0:=-e^(3/2)*atan((-2*x*sqrt(c)*sqrt(e)+sqrt(2*c*d-b*e))/sqrt(2*c*d+b*e))/_
+   (sqrt(c)*sqrt(2*c*d+b*e))+e^(3/2)*atan((2*x*sqrt(c)*sqrt(e)+_
+   sqrt(2*c*d-b*e))/sqrt(2*c*d+b*e))/(sqrt(c)*sqrt(2*c*d+b*e))
+--R 
+--R
+--R   (2)
+--R                    +-+ +-+    +------------+
+--R         +-+     2x\|c \|e  + \|- b e + 2c d
+--R       e\|e atan(----------------------------)
+--R                          +----------+
+--R                         \|b e + 2c d
+--R     + 
+--R                    +-+ +-+    +------------+
+--R         +-+     2x\|c \|e  - \|- b e + 2c d
+--R       e\|e atan(----------------------------)
+--R                          +----------+
+--R                         \|b e + 2c d
+--R  /
+--R      +-+ +----------+
+--R     \|c \|b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1073
+
+--S 1074 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1074
+
+)clear all
+
+--S 1075 of 1718
+t0:=(d+e*x^2)/(b*x^2+c*(d^2/e^2+x^4))
+--R 
+--R
+--R               3 2      2
+--R              e x  + d e
+--R   (1)  ----------------------
+--R           2 4      2 2      2
+--R        c e x  + b e x  + c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1075
+
+--S 1076 of 1718
+r0:=-e^(3/2)*atan((-2*x*sqrt(c)*sqrt(e)+sqrt(2*c*d-b*e))/sqrt(2*c*d+b*e))/_
+   (sqrt(c)*sqrt(2*c*d+b*e))+e^(3/2)*atan((2*x*sqrt(c)*sqrt(e)+_
+   sqrt(2*c*d-b*e))/sqrt(2*c*d+b*e))/(sqrt(c)*sqrt(2*c*d+b*e))
+--R 
+--R
+--R   (2)
+--R                    +-+ +-+    +------------+
+--R         +-+     2x\|c \|e  + \|- b e + 2c d
+--R       e\|e atan(----------------------------)
+--R                          +----------+
+--R                         \|b e + 2c d
+--R     + 
+--R                    +-+ +-+    +------------+
+--R         +-+     2x\|c \|e  - \|- b e + 2c d
+--R       e\|e atan(----------------------------)
+--R                          +----------+
+--R                         \|b e + 2c d
+--R  /
+--R      +-+ +----------+
+--R     \|c \|b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1076
+
+--S 1077 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1077
+
+)clear all
+
+--S 1078 of 1718
+t0:=(a-b*x^2)/(a^2+(-1+2*a*b)*x^2+b^2*x^4)
+--R 
+--R
+--R                    2
+--R               - b x  + a
+--R   (1)  ------------------------
+--R         2 4              2    2
+--R        b x  + (2a b - 1)x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1078
+
+--S 1079 of 1718
+r0:=-atanh(-2*b*x+sqrt(1-4*a*b))+atanh(2*b*x+sqrt(1-4*a*b))
+--R 
+--R
+--R               +----------+                  +----------+
+--R   (2)  atanh(\|- 4a b + 1  + 2b x) - atanh(\|- 4a b + 1  - 2b x)
+--R                                                    Type: Expression(Integer)
+--E 1079
+
+--S 1080 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1080
+
+)clear all
+
+--S 1081 of 1718
+t0:=(a+b*x^2)/(a^2+(-1+2*a*b)*x^2+b^2*x^4)
+--R 
+--R
+--R                   2
+--R                b x  + a
+--R   (1)  ------------------------
+--R         2 4              2    2
+--R        b x  + (2a b - 1)x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1081
+
+--S 1082 of 1718
+r0:=atanh((1-2*b*x)/sqrt(1-4*a*b))/sqrt(1-4*a*b)-atanh((1+2*b*x)/_
+   sqrt(1-4*a*b))/sqrt(1-4*a*b)
+--R 
+--R
+--R                   2b x + 1               2b x - 1
+--R        - atanh(-------------) - atanh(-------------)
+--R                 +----------+           +----------+
+--R                \|- 4a b + 1           \|- 4a b + 1
+--R   (2)  ---------------------------------------------
+--R                         +----------+
+--R                        \|- 4a b + 1
+--R                                                    Type: Expression(Integer)
+--E 1082
+
+--S 1083 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1083
+
+)clear all
+
+--S 1084 of 1718
+t0:=(1-x^2)/(1+b*x^2+x^4)
+--R 
+--R
+--R              2
+--R           - x  + 1
+--R   (1)  -------------
+--R         4      2
+--R        x  + b x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1084
+
+--S 1085 of 1718
+r0:=-1/2*log(1+x^2-x*sqrt(2-b))/sqrt(2-b)+1/2*log(1+x^2+x*sqrt(2-b))/sqrt(2-b)
+--R 
+--R
+--R              +-------+    2                +-------+    2
+--R        log(x\|- b + 2  + x  + 1) - log(- x\|- b + 2  + x  + 1)
+--R   (2)  -------------------------------------------------------
+--R                                +-------+
+--R                              2\|- b + 2
+--R                                                    Type: Expression(Integer)
+--E 1085
+
+--S 1086 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1086
+
+)clear all
+
+--S 1087 of 1718
+t0:=(1-x^2)/(1+5*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1087
+
+--S 1088 of 1718
+r0:=-atan(x*sqrt(2/(5+sqrt(21))))/sqrt(3)+atan(x*sqrt(1/2*(5+sqrt(21))))/_
+   sqrt(3)
+--R 
+--R
+--R               +---------+           +-----------+
+--R               | +--+                |   +--+
+--R             x\|\|21  + 5          x\|- \|21  + 5
+--R        atan(-------------) - atan(---------------)
+--R                   +-+                    +-+
+--R                  \|2                    \|2
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                            \|3
+--R                                                    Type: Expression(Integer)
+--E 1088
+
+--S 1089 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                               +---------+
+--R         2 +-+ +-+ +--+        2      +-+ +-+  | +--+
+--R       (x \|2 \|3 \|21  + (- 5x  - 2)\|2 \|3 )\|\|21  + 5
+--R     + 
+--R                                             +-----------+
+--R         2 +-+ +-+ +--+      2      +-+ +-+  |   +--+           2
+--R       (x \|2 \|3 \|21  + (5x  + 2)\|2 \|3 )\|- \|21  + 5  - 12x  + 12
+--R  /
+--R        4      2
+--R     12x  + 60x  + 12
+--R                                                    Type: Expression(Integer)
+--E 1089
+
+)clear all
+
+--S 1090 of 1718
+t0:=(1-x^2)/(1+4*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1090
+
+--S 1091 of 1718
+r0:=atan(x/sqrt(2-sqrt(3)))/sqrt(2)-atan(x/sqrt(2+sqrt(3)))/sqrt(2)
+--R 
+--R
+--R                          +--------+                      +----------+
+--R                +-+       | +-+                 +-+       |   +-+
+--R        atan((x\|3  - 2x)\|\|3  + 2 ) + atan((x\|3  + 2x)\|- \|3  + 2 )
+--R   (2)  ---------------------------------------------------------------
+--R                                       +-+
+--R                                      \|2
+--R                                                    Type: Expression(Integer)
+--E 1091
+
+--S 1092 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                   +--------+
+--R           +-+ +-+     2      +-+  | +-+
+--R       (- \|2 \|3  + (x  + 2)\|2 )\|\|3  + 2
+--R     + 
+--R                                     +----------+
+--R           +-+ +-+       2      +-+  |   +-+          2
+--R       (- \|2 \|3  + (- x  - 2)\|2 )\|- \|3  + 2  - 2x  + 2
+--R  /
+--R       4     2
+--R     2x  + 8x  + 2
+--R                                                    Type: Expression(Integer)
+--E 1092
+
+)clear all
+
+--S 1093 of 1718
+t0:=(1-x^2)/(1+3*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1093
+
+--S 1094 of 1718
+r0:=-atan(x*sqrt(2/(3+sqrt(5))))+atan(x*sqrt(1/2*(3+sqrt(5))))
+--R 
+--R
+--R               +--------+           +----------+
+--R               | +-+                |   +-+
+--R             x\|\|5  + 3          x\|- \|5  + 3
+--R   (2)  atan(------------) - atan(--------------)
+--R                  +-+                   +-+
+--R                 \|2                   \|2
+--R                                                    Type: Expression(Integer)
+--E 1094
+
+--S 1095 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                      +--------+
+--R         2 +-+ +-+        2      +-+  | +-+
+--R       (x \|2 \|5  + (- 3x  - 2)\|2 )\|\|5  + 3
+--R     + 
+--R                                    +----------+
+--R         2 +-+ +-+      2      +-+  |   +-+          2
+--R       (x \|2 \|5  + (3x  + 2)\|2 )\|- \|5  + 3  - 4x  + 4
+--R  /
+--R       4      2
+--R     4x  + 12x  + 4
+--R                                                    Type: Expression(Integer)
+--E 1095
+
+)clear all
+
+--S 1096 of 1718
+t0:=(1-x^2)/(1+2*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1096
+
+--S 1097 of 1718
+r0:=x/(1+x^2)
+--R 
+--R
+--R           x
+--R   (2)  ------
+--R         2
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1097
+
+--S 1098 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1098
+
+)clear all
+
+--S 1099 of 1718
+t0:=(1-x^2)/(1+x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1099
+
+--S 1100 of 1718
+r0:=-1/2*log(1-x+x^2)+1/2*log(1+x+x^2)
+--R 
+--R
+--R             2                 2
+--R        log(x  + x + 1) - log(x  - x + 1)
+--R   (2)  ---------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 1100
+
+--S 1101 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1101
+
+)clear all
+
+--S 1102 of 1718
+t0:=(1-x^2)/(1+x^4)
+--R 
+--R
+--R           2
+--R        - x  + 1
+--R   (1)  --------
+--R          4
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1102
+
+--S 1103 of 1718
+r0:=-1/2*log(1+x^2-x*sqrt(2))/sqrt(2)+1/2*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R              +-+    2                +-+    2
+--R        log(x\|2  + x  + 1) - log(- x\|2  + x  + 1)
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           2\|2
+--R                                                    Type: Expression(Integer)
+--E 1103
+
+--S 1104 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1104
+
+)clear all
+
+--S 1105 of 1718
+t0:=(1-x^2)/(1-x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  -----------
+--R         4    2
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1105
+
+--S 1106 of 1718
+r0:=-1/2*log(1+x^2-x*sqrt(3))/sqrt(3)+1/2*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R              +-+    2                +-+    2
+--R        log(x\|3  + x  + 1) - log(- x\|3  + x  + 1)
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           2\|3
+--R                                                    Type: Expression(Integer)
+--E 1106
+
+--S 1107 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1107
+
+)clear all
+
+--S 1108 of 1718
+t0:=(1-x^2)/(1-2*x^2+x^4)
+--R 
+--R
+--R             1
+--R   (1)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1108
+
+--S 1109 of 1718
+r0:=atanh(x)
+--R 
+--R
+--R   (2)  atanh(x)
+--R                                                    Type: Expression(Integer)
+--E 1109
+
+--S 1110 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1110
+
+)clear all
+
+--S 1111 of 1718
+t0:=(1-x^2)/(1-3*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1111
+
+--S 1112 of 1718
+r0:=-atanh((1-2*x)/sqrt(5))/sqrt(5)+atanh((1+2*x)/sqrt(5))/sqrt(5)
+--R 
+--R
+--R                       +-+                   +-+
+--R              (2x + 1)\|5           (2x - 1)\|5
+--R        atanh(------------) + atanh(------------)
+--R                    5                     5
+--R   (2)  -----------------------------------------
+--R                            +-+
+--R                           \|5
+--R                                                    Type: Expression(Integer)
+--E 1112
+
+--S 1113 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1113
+
+)clear all
+
+--S 1114 of 1718
+t0:=(1-x^2)/(1-4*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1114
+
+--S 1115 of 1718
+r0:=atanh((1+x*sqrt(2))/sqrt(3))/sqrt(6)-atanh((-2*x+sqrt(2))/sqrt(6))/sqrt(6)
+--R 
+--R
+--R                  +-+       +-+             +-+      +-+
+--R                (\|2  - 2x)\|6           (x\|2  + 1)\|3
+--R        - atanh(---------------) + atanh(---------------)
+--R                       6                        3
+--R   (2)  -------------------------------------------------
+--R                                +-+
+--R                               \|6
+--R                                                    Type: Expression(Integer)
+--E 1115
+
+--S 1116 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           2      +-+       +-+ +-+      +-+     2
+--R        ((x  - 1)\|2  - 2x)\|3 \|6  + 6x\|2  - 6x  + 6
+--R   (3)  ----------------------------------------------
+--R                          4      2
+--R                       12x  - 48x  + 12
+--R                                                    Type: Expression(Integer)
+--E 1116
+
+)clear all
+
+--S 1117 of 1718
+t0:=(1-x^2)/(1-5*x^2+x^4)
+--R 
+--R
+--R             2
+--R          - x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1117
+
+--S 1118 of 1718
+r0:=-atanh((-2*x+sqrt(3))/sqrt(7))/sqrt(7)+atanh((2*x+sqrt(3))/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                +-+       +-+            +-+       +-+
+--R              (\|3  + 2x)\|7           (\|3  - 2x)\|7
+--R        atanh(---------------) - atanh(---------------)
+--R                     7                        7
+--R   (2)  -----------------------------------------------
+--R                               +-+
+--R                              \|7
+--R                                                    Type: Expression(Integer)
+--E 1118
+
+--S 1119 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1119
+
+)clear all
+
+--S 1120 of 1718
+t0:=(1-2*x^2)/(1-5*x^2+4*x^4)
+--R 
+--R
+--R              2
+--R          - 2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  - 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1120
+
+--S 1121 of 1718
+r0:=-1/6*log(1-2*x)-1/6*log(1-x)+1/6*log(1+x)+1/6*log(1+2*x)
+--R 
+--R
+--R        log(2x + 1) + log(x + 1) - log(- x + 1) - log(- 2x + 1)
+--R   (2)  -------------------------------------------------------
+--R                                   6
+--R                                                    Type: Expression(Integer)
+--E 1121
+
+--S 1122 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1122
+
+)clear all
+
+--S 1123 of 1718
+t0:=(1+x^2)/(1+b*x^2+x^4)
+--R 
+--R
+--R             2
+--R            x  + 1
+--R   (1)  -------------
+--R         4      2
+--R        x  + b x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1123
+
+--S 1124 of 1718
+r0:=-atan((-2*x+sqrt(2-b))/sqrt(2+b))/sqrt(2+b)+_
+   atan((2*x+sqrt(2-b))/sqrt(2+b))/sqrt(2+b)
+--R 
+--R
+--R              +-------+               +-------+
+--R             \|- b + 2  + 2x         \|- b + 2  - 2x
+--R        atan(---------------) - atan(---------------)
+--R                  +-----+                 +-----+
+--R                 \|b + 2                 \|b + 2
+--R   (2)  ---------------------------------------------
+--R                            +-----+
+--R                           \|b + 2
+--R                                                    Type: Expression(Integer)
+--E 1124
+
+--S 1125 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1125
+
+)clear all
+
+--S 1126 of 1718
+t0:=(1+x^2)/(1+5*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1126
+
+--S 1127 of 1718
+r0:=atan(x*sqrt(2/(5+sqrt(21))))/sqrt(7)+atan(x*sqrt(1/2*(5+sqrt(21))))/sqrt(7)
+--R 
+--R
+--R               +---------+           +-----------+
+--R               | +--+                |   +--+
+--R             x\|\|21  + 5          x\|- \|21  + 5
+--R        atan(-------------) + atan(---------------)
+--R                   +-+                    +-+
+--R                  \|2                    \|2
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                            \|7
+--R                                                    Type: Expression(Integer)
+--E 1127
+
+--S 1128 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                               +---------+
+--R         2 +-+ +-+ +--+        2      +-+ +-+  | +--+
+--R       (x \|2 \|7 \|21  + (- 5x  - 2)\|2 \|7 )\|\|21  + 5
+--R     + 
+--R                                                 +-----------+
+--R           2 +-+ +-+ +--+        2      +-+ +-+  |   +--+           2
+--R       (- x \|2 \|7 \|21  + (- 5x  - 2)\|2 \|7 )\|- \|21  + 5  + 28x  + 28
+--R  /
+--R        4       2
+--R     28x  + 140x  + 28
+--R                                                    Type: Expression(Integer)
+--E 1128
+
+)clear all
+
+--S 1129 of 1718
+t0:=(1+x^2)/(1+4*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1129
+
+--S 1130 of 1718
+r0:=atan(x/sqrt(2-sqrt(3)))/sqrt(6)+atan(x/sqrt(2+sqrt(3)))/sqrt(6)
+--R 
+--R
+--R                            +--------+                      +----------+
+--R                  +-+       | +-+                 +-+       |   +-+
+--R        - atan((x\|3  - 2x)\|\|3  + 2 ) + atan((x\|3  + 2x)\|- \|3  + 2 )
+--R   (2)  -----------------------------------------------------------------
+--R                                        +-+
+--R                                       \|6
+--R                                                    Type: Expression(Integer)
+--E 1130
+
+--S 1131 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                       +--------+                         +----------+
+--R     +-+    2      +-+ | +-+            +-+    2      +-+ |   +-+          2
+--R   (\|3  - x  - 2)\|6 \|\|3  + 2  + (- \|3  - x  - 2)\|6 \|- \|3  + 2  + 6x  + 6
+--R   -----------------------------------------------------------------------------
+--R                                     4      2
+--R                                   6x  + 24x  + 6
+--R                                                    Type: Expression(Integer)
+--E 1131
+
+)clear all
+
+--S 1132 of 1718
+t0:=(1+x^2)/(1+3*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1132
+
+--S 1133 of 1718
+r0:=atan(x*sqrt(2/(3+sqrt(5))))/sqrt(5)+atan(x*sqrt(1/2*(3+sqrt(5))))/sqrt(5)
+--R 
+--R
+--R               +--------+           +----------+
+--R               | +-+                |   +-+
+--R             x\|\|5  + 3          x\|- \|5  + 3
+--R        atan(------------) + atan(--------------)
+--R                  +-+                   +-+
+--R                 \|2                   \|2
+--R   (2)  -----------------------------------------
+--R                            +-+
+--R                           \|5
+--R                                                    Type: Expression(Integer)
+--E 1133
+
+--S 1134 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                       +--------+
+--R             2      +-+ +-+     2 +-+  | +-+
+--R       ((- 3x  - 2)\|2 \|5  + 5x \|2 )\|\|5  + 3
+--R     + 
+--R                                       +----------+
+--R             2      +-+ +-+     2 +-+  |   +-+           2
+--R       ((- 3x  - 2)\|2 \|5  - 5x \|2 )\|- \|5  + 3  + 20x  + 20
+--R  /
+--R        4      2
+--R     20x  + 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 1134
+
+)clear all
+
+--S 1135 of 1718
+t0:=(1+x^2)/(1+2*x^2+x^4)
+--R 
+--R
+--R           1
+--R   (1)  ------
+--R         2
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1135
+
+--S 1136 of 1718
+r0:=atan(x)
+--R 
+--R
+--R        %pi
+--R   (2)  ---
+--R         3
+--R                                                    Type: Expression(Integer)
+--E 1136
+
+--S 1137 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           1
+--R   (3)  ------
+--R         2
+--R        x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1137
+
+)clear all
+
+--S 1138 of 1718
+t0:=(1+x^2)/(1+x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1138
+
+--S 1139 of 1718
+r0:=-atan((1-2*x)/sqrt(3))/sqrt(3)+atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                      +-+                  +-+
+--R             (2x + 1)\|3          (2x - 1)\|3
+--R        atan(------------) + atan(------------)
+--R                   3                    3
+--R   (2)  ---------------------------------------
+--R                           +-+
+--R                          \|3
+--R                                                    Type: Expression(Integer)
+--E 1139
+
+--S 1140 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1140
+
+)clear all
+
+--S 1141 of 1718
+t0:=(1+x^2)/(1+x^4)
+--R 
+--R
+--R         2
+--R        x  + 1
+--R   (1)  ------
+--R         4
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1141
+
+--S 1142 of 1718
+r0:=-atan(1-x*sqrt(2))/sqrt(2)+atan(1+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R               +-+               +-+
+--R        atan(x\|2  + 1) + atan(x\|2  - 1)
+--R   (2)  ---------------------------------
+--R                        +-+
+--R                       \|2
+--R                                                    Type: Expression(Integer)
+--E 1142
+
+--S 1143 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1143
+
+)clear all
+
+--S 1144 of 1718
+t0:=(1+x^2)/(1-x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  -----------
+--R         4    2
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1144
+
+--S 1145 of 1718
+r0:=-atan(-2*x+sqrt(3))+atan(2*x+sqrt(3))
+--R 
+--R
+--R              +-+               +-+
+--R   (2)  atan(\|3  + 2x) - atan(\|3  - 2x)
+--R                                                    Type: Expression(Integer)
+--E 1145
+
+--S 1146 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1146
+
+)clear all
+
+--S 1147 of 1718
+t0:=(1+x^2)/(1-2*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1147
+
+--S 1148 of 1718
+r0:=x/(1-x^2)
+--R 
+--R
+--R             x
+--R   (2)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1148
+
+--S 1149 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1149
+
+)clear all
+
+--S 1150 of 1718
+t0:=(1+x^2)/(1-3*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1150
+
+--S 1151 of 1718
+r0:=atanh(-2*x+sqrt(5))-atanh(2*x+sqrt(5))
+--R 
+--R
+--R                 +-+                +-+
+--R   (2)  - atanh(\|5  + 2x) + atanh(\|5  - 2x)
+--R                                                    Type: Expression(Integer)
+--E 1151
+
+--S 1152 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1152
+
+)clear all
+
+--S 1153 of 1718
+t0:=(1+x^2)/(1-4*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 4x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1153
+
+--S 1154 of 1718
+r0a:=atanh(-x*sqrt(2)+sqrt(3))/sqrt(2)-atanh(x*sqrt(2)+sqrt(3))/sqrt(2)
+--R 
+--R
+--R                 +-+     +-+           +-+     +-+
+--R        - atanh(\|3  + x\|2 ) + atanh(\|3  - x\|2 )
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                            \|2
+--R                                                    Type: Expression(Integer)
+--E 1154
+
+--S 1155 of 1718
+r0b:=atanh((-2*x+sqrt(6))/sqrt(2))/sqrt(2)-atanh((2*x+sqrt(6))/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                 +-+ +-+      +-+           +-+ +-+      +-+
+--R                \|2 \|6  + 2x\|2           \|2 \|6  - 2x\|2
+--R        - atanh(-----------------) + atanh(-----------------)
+--R                        2                          2
+--R   (3)  -----------------------------------------------------
+--R                                  +-+
+--R                                 \|2
+--R                                                    Type: Expression(Integer)
+--E 1155
+
+--S 1156 of 1718
+d0a:=t0-D(r0a,x)
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 1156
+
+--S 1157 of 1718
+d0b:=t0-D(r0b,x)
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 1157
+
+)clear all
+
+--S 1158 of 1718
+t0:=(1+x^2)/(1-5*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         4     2
+--R        x  - 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1158
+
+--S 1159 of 1718
+r0:=atanh((-2*x+sqrt(7))/sqrt(3))/sqrt(3)-atanh((2*x+sqrt(7))/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                 +-+ +-+      +-+           +-+ +-+      +-+
+--R                \|3 \|7  + 2x\|3           \|3 \|7  - 2x\|3
+--R        - atanh(-----------------) + atanh(-----------------)
+--R                        3                          3
+--R   (2)  -----------------------------------------------------
+--R                                  +-+
+--R                                 \|3
+--R                                                    Type: Expression(Integer)
+--E 1159
+
+--S 1160 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1160
+
+)clear all
+
+--S 1161 of 1718
+t0:=(1+2*x^2)/(1+5*x^2+4*x^4)
+--R 
+--R
+--R             2
+--R           2x  + 1
+--R   (1)  -------------
+--R          4     2
+--R        4x  + 5x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1161
+
+--S 1162 of 1718
+r0:=1/3*atan(x)+1/3*atan(2*x)
+--R 
+--R
+--R        3atan(2x) + %pi
+--R   (2)  ---------------
+--R               9
+--R                                                    Type: Expression(Integer)
+--E 1162
+
+--S 1163 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           1
+--R   (3)  -------
+--R          2
+--R        3x  + 3
+--R                                                    Type: Expression(Integer)
+--E 1163
+
+)clear all
+
+--S 1164 of 1718
+t0:=x^m*(A+B*x^2)*(a+b*x^2+c*x^4)^4
+--R 
+--R
+--R   (1)
+--R          4 18       4         3  16                  3       2 2  14
+--R       B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R     + 
+--R              3        2            2       3   12
+--R       (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R     + 
+--R                       2  2        3          2        4  10
+--R       ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R     + 
+--R            2 2           2        2         4         3  8
+--R       (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R     + 
+--R              2        3           3       2 2  6
+--R       ((12A a b + 4B a )c + 4A a b  + 6B a b )x
+--R     + 
+--R            3        2 2       3   4        3       4  2      4
+--R       (4A a c + 6A a b  + 4B a b)x  + (4A a b + B a )x  + A a
+--R  *
+--R      m
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 1164
+
+--S 1165 of 1718
+r0:=a^4*A*x^(1+m)/(1+m)+a^3*(4*A*b+a*B)*x^(3+m)/(3+m)+2*a^2*(3*A*b^2+_
+   2*a*b*B+2*a*A*c)*x^(5+m)/(5+m)+2*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*_
+   x^(7+m)/(7+m)+(4*a*b*B*(b^2+3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*_
+   x^(9+m)/(9+m)+(b^4*B+4*A*b^3*c+12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*_
+   x^(11+m)/(11+m)+2*c*(2*b^3*B+3*A*b^2*c+6*a*b*B*c+2*a*A*c^2)*_
+   x^(13+m)/(13+m)+2*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^(15+m)/(15+m)+_
+   c^3*(4*b*B+A*c)*x^(17+m)/(17+m)+B*c^4*x^(19+m)/(19+m)
+--R 
+--R
+--R   (2)
+--R              4 9        4 8          4 7           4 6            4 5
+--R           B c m  + 81B c m  + 2796B c m  + 53676B c m  + 626934B c m
+--R         + 
+--R                     4 4              4 3              4 2              4
+--R           4574934B c m  + 20570444B c m  + 53809164B c m  + 71697105B c m
+--R         + 
+--R                      4
+--R           34459425B c
+--R      *
+--R          m + 19
+--R         x
+--R     + 
+--R               4         3  9         4           3  8
+--R           (A c  + 4B b c )m  + (83A c  + 332B b c )m
+--R         + 
+--R                   4             3  7            4              3  6
+--R           (2924A c  + 11696B b c )m  + (57092A c  + 228368B b c )m
+--R         + 
+--R                     4               3  5              4                3  4
+--R           (676214A c  + 2704856B b c )m  + (4991042A c  + 19964168B b c )m
+--R         + 
+--R                       4                3  3
+--R           (22646476A c  + 90585904B b c )m
+--R         + 
+--R                       4                 3  2
+--R           (59657508A c  + 238630032B b c )m
+--R         + 
+--R                       4                 3                4                 3
+--R           (79893585A c  + 319574340B b c )m + 38513475A c  + 154053900B b c
+--R      *
+--R          m + 17
+--R         x
+--R     + 
+--R                          3       2 2  9                      3         2 2  8
+--R           ((4A b + 4B a)c  + 6B b c )m  + ((340A b + 340B a)c  + 510B b c )m
+--R         + 
+--R                                  3           2 2  7
+--R           ((12240A b + 12240B a)c  + 18360B b c )m
+--R         + 
+--R                                    3            2 2  6
+--R           ((243600A b + 243600B a)c  + 365400B b c )m
+--R         + 
+--R                                      3             2 2  5
+--R           ((2933112A b + 2933112B a)c  + 4399668B b c )m
+--R         + 
+--R                                        3              2 2  4
+--R           ((21950040A b + 21950040B a)c  + 32925060B b c )m
+--R         + 
+--R                                          3               2 2  3
+--R           ((100726160A b + 100726160B a)c  + 151089240B b c )m
+--R         + 
+--R                                          3               2 2  2
+--R           ((267698000A b + 267698000B a)c  + 401547000B b c )m
+--R         + 
+--R                                          3               2 2
+--R           ((360814884A b + 360814884B a)c  + 541222326B b c )m
+--R         + 
+--R                                         3               2 2
+--R           (174594420A b + 174594420B a)c  + 261891630B b c
+--R      *
+--R          m + 15
+--R         x
+--R     + 
+--R                  3        2            2       3   9
+--R           (4A a c  + (6A b  + 12B a b)c  + 4B b c)m
+--R         + 
+--R                    3          2              2         3   8
+--R           (348A a c  + (522A b  + 1044B a b)c  + 348B b c)m
+--R         + 
+--R                      3            2               2           3   7
+--R           (12816A a c  + (19224A b  + 38448B a b)c  + 12816B b c)m
+--R         + 
+--R                       3             2                2            3   6
+--R           (260592A a c  + (390888A b  + 781776B a b)c  + 260592B b c)m
+--R         + 
+--R                        3              2                 2             3   5
+--R           (3199416A a c  + (4799124A b  + 9598248B a b)c  + 3199416B b c)m
+--R         + 
+--R                         3               2                  2              3   4
+--R           (24354312A a c  + (36531468A b  + 73062936B a b)c  + 24354312B b c)m
+--R         + 
+--R                             3                2                   2
+--R               113370704A a c  + (170056056A b  + 340112112B a b)c
+--R             + 
+--R                           3
+--R               113370704B b c
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                             3                2                   2
+--R               304771248A a c  + (457156872A b  + 914313744B a b)c
+--R             + 
+--R                           3
+--R               304771248B b c
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                             3                2                    2
+--R               414258660A a c  + (621387990A b  + 1242775980B a b)c
+--R             + 
+--R                           3
+--R               414258660B b c
+--R          *
+--R             m
+--R         + 
+--R                       3                2                   2               3
+--R         201455100A a c  + (302182650A b  + 604365300B a b)c  + 201455100B b c
+--R      *
+--R          m + 13
+--R         x
+--R     + 
+--R                           2  2        3          2        4  9
+--R           ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )m
+--R         + 
+--R                               2  2          3            2          4  8
+--R           ((1068A a b + 534B a )c  + (356A b  + 1068B a b )c + 89B b )m
+--R         + 
+--R                                       2  2            3             2
+--R                 (40272A a b + 20136B a )c  + (13424A b  + 40272B a b )c
+--R               + 
+--R                        4
+--R                 3356B b
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                                       2  2             3              2
+--R               (838608A a b + 419304B a )c  + (279536A b  + 838608B a b )c
+--R             + 
+--R                       4
+--R               69884B b
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                                          2  2              3                2
+--R               (10536648A a b + 5268324B a )c  + (3512216A b  + 10536648B a b )c
+--R             + 
+--R                        4
+--R               878054B b
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                                           2  2
+--R               (81937032A a b + 40968516B a )c
+--R             + 
+--R                           3                2               4
+--R               (27312344A b  + 81937032B a b )c + 6828086B b
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                                             2  2
+--R               (388622928A a b + 194311464B a )c
+--R             + 
+--R                            3                 2                4
+--R               (129540976A b  + 388622928B a b )c + 32385244B b
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                                              2  2
+--R               (1060918992A a b + 530459496B a )c
+--R             + 
+--R                            3                  2                4
+--R               (353639664A b  + 1060918992B a b )c + 88409916B b
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                                              2  2
+--R               (1458745740A a b + 729372870B a )c
+--R             + 
+--R                            3                  2                 4
+--R               (486248580A b  + 1458745740B a b )c + 121562145B b
+--R          *
+--R             m
+--R         + 
+--R                                         2  2
+--R           (714249900A a b + 357124950B a )c
+--R         + 
+--R                        3                 2                4
+--R           (238083300A b  + 714249900B a b )c + 59520825B b
+--R      *
+--R          m + 11
+--R         x
+--R     + 
+--R                2 2           2        2         4         3  9
+--R           (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )m
+--R         + 
+--R                  2 2             2          2           4           3  8
+--R           (546A a c  + (1092A a b  + 1092B a b)c + 91A b  + 364B a b )m
+--R         + 
+--R                         2 2              2           2             4
+--R                 21096A a c  + (42192A a b  + 42192B a b)c + 3516A b
+--R               + 
+--R                           3
+--R                 14064B a b
+--R          *
+--R              7
+--R             m
+--R         + 
+--R                        2 2               2            2              4
+--R               450936A a c  + (901872A a b  + 901872B a b)c + 75156A b
+--R             + 
+--R                          3
+--R               300624B a b
+--R          *
+--R              6
+--R             m
+--R         + 
+--R                         2 2                 2              2               4
+--R               5822244A a c  + (11644488A a b  + 11644488B a b)c + 970374A b
+--R             + 
+--R                           3
+--R               3881496B a b
+--R          *
+--R              5
+--R             m
+--R         + 
+--R                          2 2                 2              2                4
+--R               46519884A a c  + (93039768A a b  + 93039768B a b)c + 7753314A b
+--R             + 
+--R                            3
+--R               31013256B a b
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                           2 2                  2               2
+--R               226286184A a c  + (452572368A a b  + 452572368B a b)c
+--R             + 
+--R                          4                 3
+--R               37714364A b  + 150857456B a b
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                           2 2                   2                2
+--R               631309944A a c  + (1262619888A a b  + 1262619888B a b)c
+--R             + 
+--R                           4                 3
+--R               105218324A b  + 420873296B a b
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                           2 2                   2                2
+--R               882637830A a c  + (1765275660A a b  + 1765275660B a b)c
+--R             + 
+--R                           4                 3
+--R               147106305A b  + 588425220B a b
+--R          *
+--R             m
+--R         + 
+--R                       2 2                  2               2                 4
+--R           436486050A a c  + (872972100A a b  + 872972100B a b)c + 72747675A b
+--R         + 
+--R                         3
+--R           290990700B a b
+--R      *
+--R          m + 9
+--R         x
+--R     + 
+--R                  2        3           3       2 2  9
+--R           ((12A a b + 4B a )c + 4A a b  + 6B a b )m
+--R         + 
+--R                    2          3             3         2 2  8
+--R           ((1116A a b + 372B a )c + 372A a b  + 558B a b )m
+--R         + 
+--R                     2            3               3           2 2  7
+--R           ((44208A a b + 14736B a )c + 14736A a b  + 22104B a b )m
+--R         + 
+--R                      2             3                3            2 2  6
+--R           ((972144A a b + 324048B a )c + 324048A a b  + 486072B a b )m
+--R         + 
+--R                        2              3                 3             2 2  5
+--R           ((12956328A a b + 4318776B a )c + 4318776A a b  + 6478164B a b )m
+--R         + 
+--R                              2               3                  3
+--R                 (107145864A a b + 35715288B a )c + 35715288A a b
+--R               + 
+--R                            2 2
+--R                 53572932B a b
+--R          *
+--R              4
+--R             m
+--R         + 
+--R                            2                3                   3
+--R               (539909232A a b + 179969744B a )c + 179969744A a b
+--R             + 
+--R                           2 2
+--R               269954616B a b
+--R          *
+--R              3
+--R             m
+--R         + 
+--R                             2                3                   3
+--R               (1556406576A a b + 518802192B a )c + 518802192A a b
+--R             + 
+--R                           2 2
+--R               778203288B a b
+--R          *
+--R              2
+--R             m
+--R         + 
+--R                             2                3                   3
+--R               (2234008620A a b + 744669540B a )c + 744669540A a b
+--R             + 
+--R                            2 2
+--R               1117004310B a b
+--R          *
+--R             m
+--R         + 
+--R                       2                3                   3               2 2
+--R         (1122392700A a b + 374130900B a )c + 374130900A a b  + 561196350B a b
+--R      *
+--R          m + 7
+--R         x
+--R     + 
+--R                3        2 2       3   9          3          2 2         3   8
+--R           (4A a c + 6A a b  + 4B a b)m  + (380A a c + 570A a b  + 380B a b)m
+--R         + 
+--R                    3            2 2           3   7
+--R           (15440A a c + 23160A a b  + 15440B a b)m
+--R         + 
+--R                     3             2 2            3   6
+--R           (350000A a c + 525000A a b  + 350000B a b)m
+--R         + 
+--R                      3              2 2             3   5
+--R           (4837112A a c + 7255668A a b  + 4837112B a b)m
+--R         + 
+--R                       3               2 2              3   4
+--R           (41761160A a c + 62641740A a b  + 41761160B a b)m
+--R         + 
+--R                        3                2 2               3   3
+--R           (221170960A a c + 331756440A a b  + 221170960B a b)m
+--R         + 
+--R                        3                 2 2               3   2
+--R           (672735600A a c + 1009103400A a b  + 672735600B a b)m
+--R         + 
+--R                         3                 2 2                3
+--R           (1012606884A a c + 1518910326A a b  + 1012606884B a b)m
+--R         + 
+--R                       3                2 2               3
+--R           523783260A a c + 785674890A a b  + 523783260B a b
+--R      *
+--R          m + 5
+--R         x
+--R     + 
+--R                3       4  9          3         4  8            3           4  7
+--R           (4A a b + B a )m  + (388A a b + 97B a )m  + (16176A a b + 4044B a )m
+--R         + 
+--R                     3            4  6              3              4  5
+--R           (378672A a b + 94668B a )m  + (5451096A a b + 1362774B a )m
+--R         + 
+--R                       3               4  4                3               4  3
+--R           (49593432A a b + 12398358B a )m  + (281196464A a b + 70299116B a )m
+--R         + 
+--R                        3                4  2
+--R           (935001008A a b + 233750252B a )m
+--R         + 
+--R                         3                4                 3                4
+--R           (1571281860A a b + 392820465B a )m + 872972100A a b + 218243025B a
+--R      *
+--R          m + 3
+--R         x
+--R     + 
+--R              4 9        4 8          4 7            4 6             4 5
+--R           A a m  + 99A a m  + 4236A a m  + 102564A a m  + 1544214A a m
+--R         + 
+--R                      4 4              4 3               4 2               4
+--R           14942466A a m  + 92551724A a m  + 352095876A a m  + 741975345A a m
+--R         + 
+--R                       4
+--R           654729075A a
+--R      *
+--R          m + 1
+--R         x
+--R  /
+--R        10       9        8          7           6            5             4
+--R       m   + 100m  + 4335m  + 106800m  + 1646778m  + 16486680m  + 107494190m
+--R     + 
+--R                 3              2
+--R       444647600m  + 1094071221m  + 1396704420m + 654729075
+--R                                                    Type: Expression(Integer)
+--E 1165
+
+--S 1166 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1166
+
+)clear all
+
+--S 1167 of 1718
+t0:=x^3*(A+B*x^2)*(a+b*x^2+c*x^4)^4
+--R 
+--R
+--R   (1)
+--R        4 21       4         3  19                  3       2 2  17
+--R     B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R   + 
+--R            3        2            2       3   15
+--R     (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R   + 
+--R                     2  2        3          2        4  13
+--R     ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R   + 
+--R          2 2           2        2         4         3  11
+--R     (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R   + 
+--R            2        3           3       2 2  9        3        2 2       3   7
+--R     ((12A a b + 4B a )c + 4A a b  + 6B a b )x  + (4A a c + 6A a b  + 4B a b)x
+--R   + 
+--R          3       4  5      4 3
+--R     (4A a b + B a )x  + A a x
+--R                                                    Type: Polynomial(Integer)
+--E 1167
+
+--S 1168 of 1718
+r0:=1/4*a^4*A*x^4+1/6*a^3*(4*A*b+a*B)*x^6+1/4*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*_
+   x^8+1/5*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^10+1/12*(4*a*b*B*(b^2+_
+   3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^12+1/14*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^14+1/8*c*(2*b^3*B+3*A*b^2*c+_
+   6*a*b*B*c+2*a*A*c^2)*x^16+1/9*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^18+_
+   1/20*c^3*(4*b*B+A*c)*x^20+1/22*B*c^4*x^22
+--R 
+--R
+--R   (2)
+--R      1    4 22     1    4   1      3  20     2       2      3   1    2 2  18
+--R     -- B c x   + (-- A c  + - B b c )x   + ((- A b + - B a)c  + - B b c )x
+--R     22            20        5                9       9          3
+--R   + 
+--R      1      3    3    2   3        2   1    3   16
+--R     (- A a c  + (- A b  + - B a b)c  + - B b c)x
+--R      4           8        4            4
+--R   + 
+--R       6         3    2  2    2    3   6      2      1    4  14
+--R     ((- A a b + - B a )c  + (- A b  + - B a b )c + -- B b )x
+--R       7         7            7        7            14
+--R   + 
+--R      1    2 2         2      2       1    4   1      3  12
+--R     (- A a c  + (A a b  + B a b)c + -- A b  + - B a b )x
+--R      2                              12        3
+--R   + 
+--R       6    2    2    3     2      3   3    2 2  10
+--R     ((- A a b + - B a )c + - A a b  + - B a b )x
+--R       5         5          5          5
+--R   + 
+--R      1    3    3    2 2   1    3   8    2    3    1    4  6   1    4 4
+--R     (- A a c + - A a b  + - B a b)x  + (- A a b + - B a )x  + - A a x
+--R      2         4          2             3         6           4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1168
+
+--S 1169 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1169
+
+)clear all
+
+--S 1170 of 1718
+t0:=x^2*(A+B*x^2)*(a+b*x^2+c*x^4)^4
+--R 
+--R
+--R   (1)
+--R        4 20       4         3  18                  3       2 2  16
+--R     B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R   + 
+--R            3        2            2       3   14
+--R     (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R   + 
+--R                     2  2        3          2        4  12
+--R     ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R   + 
+--R          2 2           2        2         4         3  10
+--R     (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R   + 
+--R            2        3           3       2 2  8        3        2 2       3   6
+--R     ((12A a b + 4B a )c + 4A a b  + 6B a b )x  + (4A a c + 6A a b  + 4B a b)x
+--R   + 
+--R          3       4  4      4 2
+--R     (4A a b + B a )x  + A a x
+--R                                                    Type: Polynomial(Integer)
+--E 1170
+
+--S 1171 of 1718
+r0:=1/3*a^4*A*x^3+1/5*a^3*(4*A*b+a*B)*x^5+2/7*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*_
+   x^7+2/9*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^9+1/11*(4*a*b*B*(b^2+_
+   3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^11+1/13*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^13+2/15*c*(2*b^3*B+_
+   3*A*b^2*c+6*a*b*B*c+2*a*A*c^2)*x^15+2/17*c^2*(3*b^2*B+2*A*b*c+_
+   2*a*B*c)*x^17+1/19*c^3*(4*b*B+A*c)*x^19+1/21*B*c^4*x^21
+--R 
+--R
+--R   (2)
+--R      1    4 21     1    4    4      3  19
+--R     -- B c x   + (-- A c  + -- B b c )x
+--R     21            19        19
+--R   + 
+--R        4        4      3    6    2 2  17
+--R     ((-- A b + -- B a)c  + -- B b c )x
+--R       17       17          17
+--R   + 
+--R       4      3    2    2   4        2    4    3   15
+--R     (-- A a c  + (- A b  + - B a b)c  + -- B b c)x
+--R      15           5        5            15
+--R   + 
+--R       12          6    2  2     4    3   12      2      1    4  13
+--R     ((-- A a b + -- B a )c  + (-- A b  + -- B a b )c + -- B b )x
+--R       13         13            13        13            13
+--R   + 
+--R       6    2 2    12      2   12    2       1    4    4      3  11
+--R     (-- A a c  + (-- A a b  + -- B a b)c + -- A b  + -- B a b )x
+--R      11           11          11           11        11
+--R   + 
+--R       4    2    4    3     4      3   2    2 2  9
+--R     ((- A a b + - B a )c + - A a b  + - B a b )x
+--R       3         9          9          3
+--R   + 
+--R      4    3    6    2 2   4    3   7    4    3    1    4  5   1    4 3
+--R     (- A a c + - A a b  + - B a b)x  + (- A a b + - B a )x  + - A a x
+--R      7         7          7             5         5           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1171
+
+--S 1172 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1172
+
+)clear all
+
+--S 1173 of 1718
+t0:=x*(A+B*x^2)*(a+b*x^2+c*x^4)^4
+--R 
+--R
+--R   (1)
+--R        4 19       4         3  17                  3       2 2  15
+--R     B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R   + 
+--R            3        2            2       3   13
+--R     (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R   + 
+--R                     2  2        3          2        4  11
+--R     ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R   + 
+--R          2 2           2        2         4         3  9
+--R     (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R   + 
+--R            2        3           3       2 2  7        3        2 2       3   5
+--R     ((12A a b + 4B a )c + 4A a b  + 6B a b )x  + (4A a c + 6A a b  + 4B a b)x
+--R   + 
+--R          3       4  3      4
+--R     (4A a b + B a )x  + A a x
+--R                                                    Type: Polynomial(Integer)
+--E 1173
+
+--S 1174 of 1718
+r0:=1/2*a^4*A*x^2+1/4*a^3*(4*A*b+a*B)*x^4+1/3*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*_
+   x^6+1/4*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^8+1/10*(4*a*b*B*_
+   (b^2+3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^10+1/12*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^12+1/7*c*(2*b^3*B+3*A*b^2*c+_
+   6*a*b*B*c+2*a*A*c^2)*x^14+1/8*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^16+_
+   1/18*c^3*(4*b*B+A*c)*x^18+1/20*B*c^4*x^20
+--R 
+--R
+--R   (2)
+--R      1    4 20     1    4   2      3  18     1       1      3   3    2 2  16
+--R     -- B c x   + (-- A c  + - B b c )x   + ((- A b + - B a)c  + - B b c )x
+--R     20            18        9                4       4          8
+--R   + 
+--R      2      3    3    2   6        2   2    3   14
+--R     (- A a c  + (- A b  + - B a b)c  + - B b c)x
+--R      7           7        7            7
+--R   + 
+--R               1    2  2    1    3        2      1    4  12
+--R     ((A a b + - B a )c  + (- A b  + B a b )c + -- B b )x
+--R               2            3                   12
+--R   + 
+--R      3    2 2    6      2   6    2       1    4   2      3  10
+--R     (- A a c  + (- A a b  + - B a b)c + -- A b  + - B a b )x
+--R      5           5          5           10        5
+--R   + 
+--R       3    2    1    3     1      3   3    2 2  8
+--R     ((- A a b + - B a )c + - A a b  + - B a b )x
+--R       2         2          2          4
+--R   + 
+--R      2    3       2 2   2    3   6       3    1    4  4   1    4 2
+--R     (- A a c + A a b  + - B a b)x  + (A a b + - B a )x  + - A a x
+--R      3                  3                     4           2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1174
+
+--S 1175 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1175
+
+)clear all
+
+--S 1176 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^4
+--R 
+--R
+--R   (1)
+--R        4 18       4         3  16                  3       2 2  14
+--R     B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R   + 
+--R            3        2            2       3   12
+--R     (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R   + 
+--R                     2  2        3          2        4  10
+--R     ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R   + 
+--R          2 2           2        2         4         3  8
+--R     (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R   + 
+--R            2        3           3       2 2  6        3        2 2       3   4
+--R     ((12A a b + 4B a )c + 4A a b  + 6B a b )x  + (4A a c + 6A a b  + 4B a b)x
+--R   + 
+--R          3       4  2      4
+--R     (4A a b + B a )x  + A a
+--R                                                    Type: Polynomial(Integer)
+--E 1176
+
+--S 1177 of 1718
+r0:=a^4*A*x+1/3*a^3*(4*A*b+a*B)*x^3+2/5*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*x^5+_
+   2/7*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^7+1/9*(4*a*b*B*(b^2+_
+   3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^9+1/11*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^11+2/13*c*(2*b^3*B+3*A*b^2*c+_
+   6*a*b*B*c+2*a*A*c^2)*x^13+2/15*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^15+_
+   1/17*c^3*(4*b*B+A*c)*x^17+1/19*B*c^4*x^19
+--R 
+--R
+--R   (2)
+--R      1    4 19     1    4    4      3  17      4        4      3   2    2 2  15
+--R     -- B c x   + (-- A c  + -- B b c )x   + ((-- A b + -- B a)c  + - B b c )x
+--R     19            17        17                15       15          5
+--R   + 
+--R       4      3     6    2   12        2    4    3   13
+--R     (-- A a c  + (-- A b  + -- B a b)c  + -- B b c)x
+--R      13           13        13            13
+--R   + 
+--R       12          6    2  2     4    3   12      2      1    4  11
+--R     ((-- A a b + -- B a )c  + (-- A b  + -- B a b )c + -- B b )x
+--R       11         11            11        11            11
+--R   + 
+--R      2    2 2    4      2   4    2      1    4   4      3  9
+--R     (- A a c  + (- A a b  + - B a b)c + - A b  + - B a b )x
+--R      3           3          3           9        9
+--R   + 
+--R       12    2    4    3     4      3   6    2 2  7
+--R     ((-- A a b + - B a )c + - A a b  + - B a b )x
+--R        7         7          7          7
+--R   + 
+--R      4    3    6    2 2   4    3   5    4    3    1    4  3      4
+--R     (- A a c + - A a b  + - B a b)x  + (- A a b + - B a )x  + A a x
+--R      5         5          5             3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1177
+
+--S 1178 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1178
+
+)clear all
+
+--S 1179 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^4/x
+--R 
+--R
+--R   (1)
+--R          4 18       4         3  16                  3       2 2  14
+--R       B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R     + 
+--R              3        2            2       3   12
+--R       (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R     + 
+--R                       2  2        3          2        4  10
+--R       ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R     + 
+--R            2 2           2        2         4         3  8
+--R       (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R     + 
+--R              2        3           3       2 2  6
+--R       ((12A a b + 4B a )c + 4A a b  + 6B a b )x
+--R     + 
+--R            3        2 2       3   4        3       4  2      4
+--R       (4A a c + 6A a b  + 4B a b)x  + (4A a b + B a )x  + A a
+--R  /
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1179
+
+--S 1180 of 1718
+r0:=1/2*a^3*(4*A*b+a*B)*x^2+1/2*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*x^4+_
+   1/3*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^6+1/8*(4*a*b*B*(b^2+_
+   3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^8+1/10*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^10+1/6*c*(2*b^3*B+3*A*b^2*c+_
+   6*a*b*B*c+2*a*A*c^2)*x^12+1/7*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^14+_
+   1/16*c^3*(4*b*B+A*c)*x^16+1/18*B*c^4*x^18+a^4*A*log(x)
+--R 
+--R
+--R   (2)
+--R              4               4 18          4            3  16
+--R       5040A a log(x) + 280B c x   + (315A c  + 1260B b c )x
+--R     + 
+--R                            3          2 2  14
+--R       ((1440A b + 1440B a)c  + 2160B b c )x
+--R     + 
+--R                 3           2              2          3   12
+--R       (1680A a c  + (2520A b  + 5040B a b)c  + 1680B b c)x
+--R     + 
+--R                            2  2           3            2           4  10
+--R       ((6048A a b + 3024B a )c  + (2016A b  + 6048B a b )c + 504B b )x
+--R     + 
+--R               2 2             2          2            4            3  8
+--R       (3780A a c  + (7560A a b  + 7560B a b)c + 630A b  + 2520B a b )x
+--R     + 
+--R                 2           3              3          2 2  6
+--R       ((10080A a b + 3360B a )c + 3360A a b  + 5040B a b )x
+--R     + 
+--R               3           2 2          3   4            3           4  2
+--R       (5040A a c + 7560A a b  + 5040B a b)x  + (10080A a b + 2520B a )x
+--R  /
+--R     5040
+--R                                                    Type: Expression(Integer)
+--E 1180
+
+--S 1181 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1181
+
+)clear all
+
+--S 1182 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^4/x^2
+--R 
+--R
+--R   (1)
+--R          4 18       4         3  16                  3       2 2  14
+--R       B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R     + 
+--R              3        2            2       3   12
+--R       (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R     + 
+--R                       2  2        3          2        4  10
+--R       ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R     + 
+--R            2 2           2        2         4         3  8
+--R       (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R     + 
+--R              2        3           3       2 2  6
+--R       ((12A a b + 4B a )c + 4A a b  + 6B a b )x
+--R     + 
+--R            3        2 2       3   4        3       4  2      4
+--R       (4A a c + 6A a b  + 4B a b)x  + (4A a b + B a )x  + A a
+--R  /
+--R      2
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1182
+
+--S 1183 of 1718
+r0:=-a^4*A/x+a^3*(4*A*b+a*B)*x+2/3*a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*x^3+_
+   2/5*a*(a*B*(3*b^2+2*a*c)+2*A*(b^3+3*a*b*c))*x^5+1/7*(4*a*b*B*(b^2+_
+   3*a*c)+A*(b^4+12*a*b^2*c+6*a^2*c^2))*x^7+1/9*(b^4*B+4*A*b^3*c+_
+   12*a*b^2*B*c+12*a*A*b*c^2+6*a^2*B*c^2)*x^9+2/11*c*(2*b^3*B+3*A*b^2*c+_
+   6*a*b*B*c+2*a*A*c^2)*x^11+2/13*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^13+_
+   1/15*c^3*(4*b*B+A*c)*x^15+1/17*B*c^4*x^17
+--R 
+--R
+--R   (2)
+--R               4 18            4              3  16
+--R       45045B c x   + (51051A c  + 204204B b c )x
+--R     + 
+--R                                3            2 2  14
+--R       ((235620A b + 235620B a)c  + 353430B b c )x
+--R     + 
+--R                   3             2                2            3   12
+--R       (278460A a c  + (417690A b  + 835380B a b)c  + 278460B b c)x
+--R     + 
+--R                                    2  2             3               2
+--R           (1021020A a b + 510510B a )c  + (340340A b  + 1021020B a b )c
+--R         + 
+--R                   4
+--R           85085B b
+--R      *
+--R          10
+--R         x
+--R     + 
+--R                    2 2                2             2               4
+--R           656370A a c  + (1312740A a b  + 1312740B a b)c + 109395A b
+--R         + 
+--R                      3
+--R           437580B a b
+--R      *
+--R          8
+--R         x
+--R     + 
+--R                   2             3                3            2 2  6
+--R       ((1837836A a b + 612612B a )c + 612612A a b  + 918918B a b )x
+--R     + 
+--R                  3              2 2             3   4
+--R       (1021020A a c + 1531530A a b  + 1021020B a b)x
+--R     + 
+--R                  3             4  2            4
+--R       (3063060A a b + 765765B a )x  - 765765A a
+--R  /
+--R     765765x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1183
+
+--S 1184 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1184
+
+)clear all
+
+--S 1185 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^4/x^3
+--R 
+--R
+--R   (1)
+--R          4 18       4         3  16                  3       2 2  14
+--R       B c x   + (A c  + 4B b c )x   + ((4A b + 4B a)c  + 6B b c )x
+--R     + 
+--R              3        2            2       3   12
+--R       (4A a c  + (6A b  + 12B a b)c  + 4B b c)x
+--R     + 
+--R                       2  2        3          2        4  10
+--R       ((12A a b + 6B a )c  + (4A b  + 12B a b )c + B b )x
+--R     + 
+--R            2 2           2        2         4         3  8
+--R       (6A a c  + (12A a b  + 12B a b)c + A b  + 4B a b )x
+--R     + 
+--R              2        3           3       2 2  6
+--R       ((12A a b + 4B a )c + 4A a b  + 6B a b )x
+--R     + 
+--R            3        2 2       3   4        3       4  2      4
+--R       (4A a c + 6A a b  + 4B a b)x  + (4A a b + B a )x  + A a
+--R  /
+--R      3
+--R     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1185
+
+--S 1186 of 1718
+r0:=-1/2*a^4*A/x^2+a^2*(3*A*b^2+2*a*b*B+2*a*A*c)*x^2+1/2*a*(a*B*(3*b^2+_
+   2*a*c)+2*A*(b^3+3*a*b*c))*x^4+1/6*(4*a*b*B*(b^2+3*a*c)+A*(b^4+12*a*b^2*c+_
+   6*a^2*c^2))*x^6+1/8*(b^4*B+4*A*b^3*c+12*a*b^2*B*c+12*a*A*b*c^2+_
+   6*a^2*B*c^2)*x^8+1/5*c*(2*b^3*B+3*A*b^2*c+6*a*b*B*c+2*a*A*c^2)*x^10+_
+   1/6*c^2*(3*b^2*B+2*A*b*c+2*a*B*c)*x^12+1/14*c^3*(4*b*B+A*c)*x^14+_
+   1/16*B*c^4*x^16+a^3*(4*A*b+a*B)*log(x)
+--R 
+--R
+--R   (2)
+--R               3           4  2               4 18          4           3  16
+--R       (6720A a b + 1680B a )x log(x) + 105B c x   + (120A c  + 480B b c )x
+--R     + 
+--R                          3         2 2  14
+--R       ((560A b + 560B a)c  + 840B b c )x
+--R     + 
+--R                3           2              2         3   12
+--R       (672A a c  + (1008A b  + 2016B a b)c  + 672B b c)x
+--R     + 
+--R                            2  2          3            2           4  10
+--R       ((2520A a b + 1260B a )c  + (840A b  + 2520B a b )c + 210B b )x
+--R     + 
+--R               2 2             2          2            4            3  8
+--R       (1680A a c  + (3360A a b  + 3360B a b)c + 280A b  + 1120B a b )x
+--R     + 
+--R                2           3              3          2 2  6
+--R       ((5040A a b + 1680B a )c + 1680A a b  + 2520B a b )x
+--R     + 
+--R               3           2 2          3   4         4
+--R       (3360A a c + 5040A a b  + 3360B a b)x  - 840A a
+--R  /
+--R          2
+--R     1680x
+--R                                                    Type: Expression(Integer)
+--E 1186
+
+--S 1187 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1187
+
+)clear all
+
+--S 1188 of 1718
+t0:=x^5*(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R             7      5
+--R          B x  + A x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1188
+
+--S 1189 of 1718
+r0:=-1/2*(b*B-A*c)*x^2/c^2+1/4*B*x^4/c+1/4*(b^2*B-A*b*c-a*B*c)*_
+   log(a+b*x^2+c*x^4)/c^3+1/2*(b^3*B-A*b^2*c-3*a*b*B*c+2*a*A*c^2)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                                           2
+--R              2          2                  3          2c x  + b
+--R       (4A a c  + (- 2A b  - 6B a b)c + 2B b )atanh(--------------)
+--R                                                     +-----------+
+--R                                                     |          2
+--R                                                    \|- 4a c + b
+--R     + 
+--R                                2        4      2           2 4
+--R           ((- A b - B a)c + B b )log(c x  + b x  + a) + B c x
+--R         + 
+--R                2           2
+--R           (2A c  - 2B b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1189
+
+--S 1190 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1190
+
+)clear all
+
+--S 1191 of 1718
+t0:=x^3*(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R             5      3
+--R          B x  + A x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1191
+
+--S 1192 of 1718
+r0:=1/2*B*x^2/c-1/4*(b*B-A*c)*log(a+b*x^2+c*x^4)/c^2-1/2*(b^2*B-A*b*c-_
+   2*a*B*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                            2
+--R                             2          2c x  + b
+--R       ((2A b + 4B a)c - 2B b )atanh(--------------)
+--R                                      +-----------+
+--R                                      |          2
+--R                                     \|- 4a c + b
+--R     + 
+--R                                                   +-----------+
+--R                          4      2              2  |          2
+--R       ((A c - B b)log(c x  + b x  + a) + 2B c x )\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     4c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1192
+
+--S 1193 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1193
+
+)clear all
+
+--S 1194 of 1718
+t0:=x*(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R              3
+--R           B x  + A x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1194
+
+--S 1195 of 1718
+r0:=1/4*B*log(a+b*x^2+c*x^4)/c+1/2*(b*B-2*A*c)*atanh((b+2*c*x^2)/sqrt(b^2-_
+   4*a*c))/(c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                               2                                 +-----------+
+--R                           2c x  + b               4      2      |          2
+--R   (- 4A c + 2B b)atanh(--------------) + B log(c x  + b x  + a)\|- 4a c + b
+--R                         +-----------+
+--R                         |          2
+--R                        \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                    +-----------+
+--R                                    |          2
+--R                                 4c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1195
+
+--S 1196 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1196
+
+)clear all
+
+--S 1197 of 1718
+t0:=(A+B*x^2)/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1197
+
+--S 1198 of 1718
+r0:=A*log(x)/a-1/4*A*log(a+b*x^2+c*x^4)/a+1/2*(A*b-2*a*B)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                 2
+--R                             2c x  + b
+--R       (2A b - 4B a)atanh(--------------)
+--R                           +-----------+
+--R                           |          2
+--R                          \|- 4a c + b
+--R     + 
+--R                                              +-----------+
+--R                   4      2                   |          2
+--R       (- A log(c x  + b x  + a) + 4A log(x))\|- 4a c + b
+--R  /
+--R        +-----------+
+--R        |          2
+--R     4a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1198
+
+--S 1199 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1199
+
+)clear all
+
+--S 1200 of 1718
+t0:=(A+B*x^2)/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1200
+
+--S 1201 of 1718
+r0:=-1/2*A/(a*x^2)-(A*b-a*B)*log(x)/a^2+1/4*(A*b-a*B)*log(a+b*x^2+c*x^4)/a^2-_
+   1/2*(A*b^2-a*b*B-2*a*A*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^2*_
+   sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                               2
+--R                     2           2         2c x  + b
+--R       (4A a c - 2A b  + 2B a b)x atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R                      2       4      2                        2
+--R         ((A b - B a)x log(c x  + b x  + a) + (- 4A b + 4B a)x log(x) - 2A a)
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       2 2 |          2
+--R     4a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1201
+
+--S 1202 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1202
+
+)clear all
+
+--S 1203 of 1718
+t0:=x^4*(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R             6      4
+--R          B x  + A x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1203
+
+--S 1204 of 1718
+r0:=-(b*B-A*c)*x/c^2+1/3*B*x^3/c+atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*(b^2*B-A*b*c-a*B*c+(-b^3*B+A*b^2*c+3*a*b*B*c-_
+   2*a*A*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^2*B-A*b*c-a*B*c+_
+   (b^3*B-A*b^2*c-3*a*b*B*c+2*a*A*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                      +-----------+
+--R                                   2  |          2          2
+--R           ((- 3A b - 3B a)c + 3B b )\|- 4a c + b   - 6A a c
+--R         + 
+--R                2                  3
+--R           (3A b  + 9B a b)c - 3B b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                      +-----------+
+--R                                   2  |          2          2
+--R           ((- 3A b - 3B a)c + 3B b )\|- 4a c + b   + 6A a c
+--R         + 
+--R                  2                  3
+--R           (- 3A b  - 9B a b)c + 3B b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                         +--------------------+
+--R                                       +-----------+     |   +-----------+
+--R               3                   +-+ |          2  +-+ |   |          2
+--R         (B c x  + (3A c - 3B b)x)\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     3c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1204
+
+--S 1205 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1205
+
+)clear all
+
+--S 1206 of 1718
+t0:=x^2*(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R             4      2
+--R          B x  + A x
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1206
+
+--S 1207 of 1718
+r0:=B*x/c-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b*B-A*c+_
+   (-b^2*B+A*b*c+2*a*B*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (b*B-A*c+(b^2*B-A*b*c-2*a*B*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      +-----------+
+--R                      |          2                         2
+--R         ((A c - B b)\|- 4a c + b   + (- A b - 2B a)c + B b )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                      +-----------+
+--R                      |          2                       2
+--R         ((A c - B b)\|- 4a c + b   + (A b + 2B a)c - B b )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R           +-+ |          2  +-+ |   |          2       | |          2
+--R       B x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1207
+
+--S 1208 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1208
+
+)clear all
+
+--S 1209 of 1718
+t0:=(A+B*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               2
+--R            B x  + A
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1209
+
+--S 1210 of 1718
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(B+(-b*B+2*A*c)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(B+(b*B-2*A*c)/sqrt(b^2-_
+   4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2                | |          2
+--R         (B\|- 4a c + b   + 2A c - B b)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2                |   |          2
+--R         (B\|- 4a c + b   - 2A c + B b)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1210
+
+--S 1211 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1211
+
+)clear all
+
+--S 1212 of 1718
+t0:=(A+B*x^2)/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1212
+
+--S 1213 of 1718
+r0:=-A/(a*x)-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (A+(A*b-2*a*B)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(A+(-A*b+_
+   2*a*B)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                     +------------------+
+--R                +-----------+                        | +-----------+
+--R                |          2                     +-+ | |          2
+--R         (- A x\|- 4a c + b   + (- A b + 2B a)x)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                   +--------------------+
+--R                +-----------+                      |   +-----------+
+--R                |          2                   +-+ |   |          2
+--R         (- A x\|- 4a c + b   + (A b - 2B a)x)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R           +-+ |          2  |   |          2       | |          2
+--R       - A\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                           +--------------------+ +------------------+
+--R             +-----------+ |   +-----------+      | +-----------+
+--R         +-+ |          2  |   |          2       | |          2
+--R     a x\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1213
+
+--S 1214 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1214
+
+)clear all
+
+--S 1215 of 1718
+t0:=(A+B*x^2)/(x^4*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R             B x  + A
+--R   (1)  ------------------
+--R           8      6      4
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1215
+
+--S 1216 of 1718
+r0:=-1/3*A/(a*x^3)+(A*b-a*B)/(a^2*x)+atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(A*b-a*B+(-a*b*B+A*(b^2-2*a*c))/sqrt(b^2-_
+   4*a*c))/(a^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(A*b-a*B+(-A*b^2+a*b*B+2*a*A*c)/_
+   sqrt(b^2-4*a*c))/(a^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R                        3 |          2                    2           3  +-+
+--R         ((3A b - 3B a)x \|- 4a c + b   + (- 6A a c + 3A b  - 3B a b)x )\|c
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                          +-----------+
+--R                        3 |          2                  2           3  +-+
+--R         ((3A b - 3B a)x \|- 4a c + b   + (6A a c - 3A b  + 3B a b)x )\|c
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                   +--------------------+
+--R                                     +-----------+ |   +-----------+
+--R                        2        +-+ |          2  |   |          2
+--R         ((3A b - 3B a)x  - A a)\|2 \|- 4a c + b  \|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R       2 3 +-+ |          2  |   |          2       | |          2
+--R     3a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1216
+
+--S 1217 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1217
+
+)clear all
+
+--S 1218 of 1718
+t0:=x^7*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            9      7
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1218
+
+--S 1219 of 1718
+r0:=1/2*(2*b^2*B-A*b*c-6*a*B*c)*x^2/(c^2*(b^2-4*a*c))-1/2*(b*B-2*A*c)*_
+   x^4/(c*(b^2-4*a*c))-1/2*x^6*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))-1/2*(2*b^4*B-A*b^3*c-12*a*b^2*B*c+6*a*A*b*c^2+_
+   12*a^2*B*c^2)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^3*(b^2-_
+   4*a*c)^(3/2))-1/4*(2*b*B-A*c)*log(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R                            2  3          3          2  2       4   4
+--R           ((12A a b + 24B a )c  + (- 2A b  - 24B a b )c  + 4B b c)x
+--R         + 
+--R                    2        2   2          4          3         5  2
+--R           ((12A a b  + 24B a b)c  + (- 2A b  - 24B a b )c + 4B b )x
+--R         + 
+--R                 2         3  2            3        2 2           4
+--R           (12A a b + 24B a )c  + (- 2A a b  - 24B a b )c + 4B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                      3         2           2       3   4
+--R               (4A a c  + (- A b  - 8B a b)c  + 2B b c)x
+--R             + 
+--R                        2         3         2         4  2       2 2
+--R               (4A a b c  + (- A b  - 8B a b )c + 2B b )x  + 4A a c
+--R             + 
+--R                       2       2            3
+--R               (- A a b  - 8B a b)c + 2B a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                  3       2 2  6            3        2            2       3   4
+--R           (8B a c  - 2B b c )x  + (- 4A a c  + (2A b  + 14B a b)c  - 4B b c)x
+--R         + 
+--R                           2  2         2   2
+--R           ((2A a b + 12B a )c  - 4B a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              5     2 4  4           4     3 3  2      2 4       2 3
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1219
+
+--S 1220 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1220
+
+)clear all
+
+--S 1221 of 1718
+t0:=x^5*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            7      5
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1221
+
+--S 1222 of 1718
+r0:=1/2*(2*A-b*B/c)*x^2/(b^2-4*a*c)-1/2*x^4*(A*b-2*a*B-(b*B-2*A*c)*x^2)/_
+   ((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*(b^3*B-6*a*b*B*c+4*a*A*c^2)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*(b^2-4*a*c)^(3/2))+_
+   1/4*B*log(a+b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                    3            2       3   4
+--R           (- 8A a c  + 12B a b c  - 2B b c)x
+--R         + 
+--R                      2          2        4  2       2 2        2            3
+--R           (- 8A a b c  + 12B a b c - 2B b )x  - 8A a c  + 12B a b c - 2B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2      2   4                  3  2       2         2
+--R             ((4B a c  - B b c)x  + (4B a b c - B b )x  + 4B a c - B a b )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                            2       2   4            2             2
+--R           ((- 2A b - 4B a)c  + 2B b c)x  + (- 4A a c  + 2B a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R              4     2 3  4           3     3 2  2      2 3       2 2
+--R       ((16a c  - 4b c )x  + (16a b c  - 4b c )x  + 16a c  - 4a b c )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1222
+
+--S 1223 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1223
+
+)clear all
+
+--S 1224 of 1718
+t0:=x^3*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            5      3
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1224
+
+--S 1225 of 1718
+r0:=1/2*(2*a+b*x^2)*(A+B*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-_
+   (A*b-2*a*B)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                          4        2           2                2
+--R         ((2A b - 4B a)c x  + (2A b  - 4B a b)x  + 2A a b - 4B a )
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                            +-----------+
+--R               4                  2         |          2
+--R       (- B b x  + (- A b - 2B a)x  - 2A a)\|- 4a c + b
+--R  /
+--R                                                          +-----------+
+--R           2     2   4               3  2     2        2  |          2
+--R     ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1225
+
+--S 1226 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1226
+
+)clear all
+
+--S 1227 of 1718
+t0:=x*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                             3
+--R                          B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1227
+
+--S 1228 of 1718
+r0:=1/2*(-A*b+2*a*B+(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-_
+   (b*B-2*A*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                 2           4                   2  2
+--R         ((- 4A c  + 2B b c)x  + (- 4A b c + 2B b )x  - 4A a c + 2B a b)
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                     +-----------+
+--R                     2               |          2
+--R       ((2A c - B b)x  + A b - 2B a)\|- 4a c + b
+--R  /
+--R                                                          +-----------+
+--R           2     2   4               3  2     2        2  |          2
+--R     ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1228
+
+--S 1229 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1229
+
+)clear all
+
+--S 1230 of 1718
+t0:=(A+B*x^2)/(x*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                              2
+--R                           B x  + A
+--R   (1)  ----------------------------------------------
+--R         2 9         7            2  5         3    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1230
+
+--S 1231 of 1718
+r0:=1/2*(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/2*(4*a^2*B*c+A*(b^3-6*a*b*c))*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^(3/2))+A*log(x)/a^2-_
+   1/4*A*log(a+b*x^2+c*x^4)/a^2
+--R 
+--R
+--R   (2)
+--R                           2  2       3   4            2       2          4  2
+--R           ((12A a b - 8B a )c  - 2A b c)x  + ((12A a b  - 8B a b)c - 2A b )x
+--R         + 
+--R                 2        3           3
+--R           (12A a b - 8B a )c - 2A a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                       2      2   4                    3  2       2         2
+--R             ((- 4A a c  + A b c)x  + (- 4A a b c + A b )x  - 4A a c + A a b )
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                      2       2   4                    3  2        2          2
+--R             ((16A a c  - 4A b c)x  + (16A a b c - 4A b )x  + 16A a c - 4A a b )
+--R          *
+--R             log(x)
+--R         + 
+--R                           2    2       2          2       2
+--R           (- 2A a b + 4B a )c x  + 4A a c - 2A a b  + 2B a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                 +-----------+
+--R          3 2     2 2   4       3        2 3  2      4      3 2  |          2
+--R     ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + 16a c - 4a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1231
+
+--S 1232 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1232
+
+)clear all
+
+--S 1233 of 1718
+t0:=(A+B*x^2)/(x^3*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                               2
+--R                            B x  + A
+--R   (1)  ------------------------------------------------
+--R         2 11         9            2  7         5    2 3
+--R        c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1233
+
+--S 1234 of 1718
+r0:=1/2*(-2*A*b^2+a*b*B+6*a*A*c)/(a^2*(b^2-4*a*c)*x^2)+1/2*(-a*b*B+_
+   A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*x^2*(a+b*x^2+c*x^4))+_
+   1/2*(a*b*B*(b^2-6*a*c)-2*A*(b^4-6*a*b^2*c+6*a^2*c^2))*atanh((b+_
+   2*c*x^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(3/2))-(2*A*b-a*B)*_
+   log(x)/a^3+1/4*(2*A*b-a*B)*log(a+b*x^2+c*x^4)/a^3
+--R 
+--R
+--R   (2)
+--R                 2 3             2        2   2        4         3    6
+--R           (24A a c  + (- 24A a b  + 12B a b)c  + (4A b  - 2B a b )c)x
+--R         + 
+--R                 2   2             3        2 2         5         4  4
+--R           (24A a b c  + (- 24A a b  + 12B a b )c + 4A b  - 2B a b )x
+--R         + 
+--R                 3 2           2 2        3            4       2 3  2
+--R           (24A a c  + (- 24A a b  + 12B a b)c + 4A a b  - 2B a b )x
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                              2  2          3        2    6
+--R               ((8A a b - 4B a )c  + (- 2A b  + B a b )c)x
+--R             + 
+--R                       2       2          4        3  4
+--R               ((8A a b  - 4B a b)c - 2A b  + B a b )x
+--R             + 
+--R                     2        3           3      2 2  2
+--R               ((8A a b - 4B a )c - 2A a b  + B a b )x
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                                  2  2        3         2    6
+--R               ((- 32A a b + 16B a )c  + (8A b  - 4B a b )c)x
+--R             + 
+--R                          2        2          4         3  4
+--R               ((- 32A a b  + 16B a b)c + 8A b  - 4B a b )x
+--R             + 
+--R                        2         3           3       2 2  2
+--R               ((- 32A a b + 16B a )c + 8A a b  - 4B a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R                   2 2          2       2     4
+--R           (- 12A a c  + (4A a b  - 2B a b)c)x
+--R         + 
+--R                    2        3           3       2 2  2       3        2 2
+--R           ((- 14A a b + 4B a )c + 4A a b  - 2B a b )x  - 8A a c + 2A a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R            4 2     3 2   6       4        3 3  4       5      4 2  2
+--R       ((16a c  - 4a b c)x  + (16a b c - 4a b )x  + (16a c - 4a b )x )
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1234
+
+--S 1235 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1235
+
+)clear all
+
+--S 1236 of 1718
+t0:=x^6*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            8      6
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1236
+
+--S 1237 of 1718
+r0:=1/2*(3*b^2*B-A*b*c-10*a*B*c)*x/(c^2*(b^2-4*a*c))-1/2*(b*B-2*A*c)*x^3/_
+   (c*(b^2-4*a*c))-1/2*x^5*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))-1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (3*b^3*B-A*b^2*c-13*a*b*B*c+6*a*A*c^2+(-3*b^4*B+A*b^3*c+19*a*b^2*B*c-_
+   8*a*A*b*c^2-20*a^2*B*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*(b^2-4*a*c)*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-1/2*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*(3*b^3*B-A*b^2*c-13*a*b*B*c+6*a*A*c^2+_
+   (3*b^4*B-A*b^3*c-19*a*b^2*B*c+8*a*A*b*c^2+20*a^2*B*c^2)/_
+   sqrt(b^2-4*a*c))/(c^(5/2)*(b^2-4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                      3         2            2       3   4
+--R               (6A a c  + (- A b  - 13B a b)c  + 3B b c)x
+--R             + 
+--R                        2         3          2         4  2       2 2
+--R               (6A a b c  + (- A b  - 13B a b )c + 3B b )x  + 6A a c
+--R             + 
+--R                       2        2            3
+--R               (- A a b  - 13B a b)c + 3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                             2  3       3          2  2       4   4
+--R           ((- 8A a b - 20B a )c  + (A b  + 19B a b )c  - 3B b c)x
+--R         + 
+--R                     2        2   2       4          3         5  2
+--R           ((- 8A a b  - 20B a b)c  + (A b  + 19B a b )c - 3B b )x
+--R         + 
+--R                  2         3  2         3        2 2           4
+--R           (- 8A a b - 20B a )c  + (A a b  + 19B a b )c - 3B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                      3         2            2       3   4
+--R               (6A a c  + (- A b  - 13B a b)c  + 3B b c)x
+--R             + 
+--R                        2         3          2         4  2       2 2
+--R               (6A a b c  + (- A b  - 13B a b )c + 3B b )x  + 6A a c
+--R             + 
+--R                       2        2            3
+--R               (- A a b  - 13B a b)c + 3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                           2  3         3          2  2       4   4
+--R           ((8A a b + 20B a )c  + (- A b  - 19B a b )c  + 3B b c)x
+--R         + 
+--R                   2        2   2         4          3         5  2
+--R           ((8A a b  + 20B a b)c  + (- A b  - 19B a b )c + 3B b )x
+--R         + 
+--R                2         3  2           3        2 2           4
+--R           (8A a b + 20B a )c  + (- A a b  - 19B a b )c + 3B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                  2       2   5            2       2                   3  3
+--R           (8B a c  - 2B b c)x  + (- 2A a c  + (A b  + 11B a b)c - 3B b )x
+--R         + 
+--R                          2           2
+--R           ((A a b + 10B a )c - 3B a b )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R             4     2 3  4          3     3 2  2     2 3       2 2  +-+
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c )x  + 8a c  - 2a b c )\|2
+--R    *
+--R                          +--------------------+ +------------------+
+--R        +-----------+     |   +-----------+      | +-----------+
+--R        |          2  +-+ |   |          2       | |          2
+--R       \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1237
+
+--S 1238 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1238
+
+)clear all
+
+--S 1239 of 1718
+t0:=x^4*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            6      4
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1239
+
+--S 1240 of 1718
+r0:=-1/2*(b*B-2*A*c)*x/(c*(b^2-4*a*c))-1/2*x^3*(A*b-2*a*B-(b*B-2*A*c)*_
+   x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*(b^2*B+A*b*c-6*a*B*c+(-b^3*B-A*b^2*c+_
+   8*a*b*B*c-4*a*A*c^2)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*(b^2*B+A*b*c-6*a*B*c+(b^3*B+A*b^2*c-8*a*b*B*c+4*a*A*c^2)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                               2      2   4          2                 3  2
+--R               ((- A b + 6B a)c  - B b c)x  + ((- A b  + 6B a b)c - B b )x
+--R             + 
+--R                              2          2
+--R               (- A a b + 6B a )c - B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  3       2           2      3   4
+--R           (4A a c  + (A b  - 8B a b)c  + B b c)x
+--R         + 
+--R                    2       3         2        4  2       2 2
+--R           (4A a b c  + (A b  - 8B a b )c + B b )x  + 4A a c
+--R         + 
+--R                 2       2           3
+--R           (A a b  - 8B a b)c + B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                               2      2   4          2                 3  2
+--R               ((- A b + 6B a)c  - B b c)x  + ((- A b  + 6B a b)c - B b )x
+--R             + 
+--R                              2          2
+--R               (- A a b + 6B a )c - B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    3         2           2      3   4
+--R           (- 4A a c  + (- A b  + 8B a b)c  - B b c)x
+--R         + 
+--R                      2         3         2        4  2       2 2
+--R           (- 4A a b c  + (- A b  + 8B a b )c - B b )x  - 4A a c
+--R         + 
+--R                   2       2           3
+--R           (- A a b  + 8B a b)c - B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                                +-----------+
+--R                                2  3                        +-+ |          2
+--R         (((- A b - 2B a)c + B b )x  + (- 2A a c + B a b)x)\|2 \|- 4a c + b
+--R      *
+--R              +--------------------+ +------------------+
+--R              |   +-----------+      | +-----------+
+--R          +-+ |   |          2       | |          2
+--R         \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R             3     2 2  4          2     3   2     2 2       2   +-+
+--R       ((8a c  - 2b c )x  + (8a b c  - 2b c)x  + 8a c  - 2a b c)\|2
+--R    *
+--R                          +--------------------+ +------------------+
+--R        +-----------+     |   +-----------+      | +-----------+
+--R        |          2  +-+ |   |          2       | |          2
+--R       \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1240
+
+--S 1241 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1241
+
+)clear all
+
+--S 1242 of 1718
+t0:=x^2*(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                            4      2
+--R                         B x  + A x
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1242
+
+--S 1243 of 1718
+r0:=-1/2*x*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b*B-2*A*c+_
+   (-b^2*B+4*A*b*c-4*a*B*c)/sqrt(b^2-4*a*c))/((b^2-4*a*c)*sqrt(2)*_
+   sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*(b*B-2*A*c+(b^2*B-4*A*b*c+4*a*B*c)/_
+   sqrt(b^2-4*a*c))/((b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                   2          4                2  2
+--R             ((2A c  - B b c)x  + (2A b c - B b )x  + 2A a c - B a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                            2      2   4           2                 3  2
+--R           ((- 4A b + 4B a)c  + B b c)x  + ((- 4A b  + 4B a b)c + B b )x
+--R         + 
+--R                           2          2
+--R           (- 4A a b + 4B a )c + B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                   2          4                2  2
+--R             ((2A c  - B b c)x  + (2A b c - B b )x  + 2A a c - B a b)
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                          2      2   4         2                 3  2
+--R           ((4A b - 4B a)c  - B b c)x  + ((4A b  - 4B a b)c - B b )x
+--R         + 
+--R                         2          2
+--R           (4A a b - 4B a )c - B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                              +-----------+
+--R                       3                  +-+ |          2  +-+
+--R         ((2A c - B b)x  + (A b - 2B a)x)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                                                +-----------+
+--R             2     2   4               3  2     2        2  +-+ |          2
+--R       ((8a c  - 2b c)x  + (8a b c - 2b )x  + 8a c - 2a b )\|2 \|- 4a c + b
+--R    *
+--R            +--------------------+ +------------------+
+--R            |   +-----------+      | +-----------+
+--R        +-+ |   |          2       | |          2
+--R       \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1243
+
+--S 1244 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1244
+
+)clear all
+
+--S 1245 of 1718
+t0:=(A+B*x^2)/(a+b*x^2+c*x^4)^2
+--R 
+--R
+--R                              2
+--R                           B x  + A
+--R   (1)  ---------------------------------------------
+--R         2 8         6            2  4         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1245
+
+--S 1246 of 1718
+r0:=-1/2*x*(a*b*B-A*(b^2-2*a*c)-(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(A*b-2*a*B+(4*a*b*B+A*(b^2-12*a*c))/sqrt(b^2-4*a*c))/(a*(b^2-_
+   4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(A*b-2*a*B+(-A*b^2-4*a*b*B+_
+   12*a*A*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                               4         2           2               2
+--R             ((- A b + 2B a)c x  + (- A b  + 2B a b)x  - A a b + 2B a )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2         2             4                   3         2  2
+--R           (12A a c  + (- A b  - 4B a b)c)x  + (12A a b c - A b  - 4B a b )x
+--R         + 
+--R                2         2       2
+--R           12A a c - A a b  - 4B a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                               4         2           2               2
+--R             ((- A b + 2B a)c x  + (- A b  + 2B a b)x  - A a b + 2B a )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     2       2             4                     3         2  2
+--R           (- 12A a c  + (A b  + 4B a b)c)x  + (- 12A a b c + A b  + 4B a b )x
+--R         + 
+--R                  2         2       2
+--R           - 12A a c + A a b  + 4B a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                                                             +-----------+
+--R                           3                2            +-+ |          2
+--R         ((- A b + 2B a)c x  + (2A a c - A b  + B a b)x)\|2 \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R           2 2       2   4      2          3  2     3      2 2  +-+
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + 8a c - 2a b )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1246
+
+--S 1247 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1247
+
+)clear all
+
+--S 1248 of 1718
+t0:=(A+B*x^2)/(x^2*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                               2
+--R                            B x  + A
+--R   (1)  ------------------------------------------------
+--R         2 10         8            2  6         4    2 2
+--R        c x   + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1248
+
+--S 1249 of 1718
+r0:=1/2*(-3*A*b^2+a*b*B+10*a*A*c)/(a^2*(b^2-4*a*c)*x)+1/2*(-a*b*B+_
+   A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*x*(a+b*x^2+c*x^4))-_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(3*A*b^2-_
+   a*b*B-10*a*A*c+(-a*B*(b^2-12*a*c)+A*(3*b^3-16*a*b*c))/sqrt(b^2-4*a*c))/_
+   (a^2*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*A*b^2-a*b*B-10*a*A*c+_
+   (a*B*(b^2-12*a*c)-A*(3*b^3-16*a*b*c))/sqrt(b^2-4*a*c))/(a^2*(b^2-_
+   4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                         2        2            5
+--R               (- 10A a c  + (3A b  - B a b)c)x
+--R             + 
+--R                                3        2  3           2          2      2
+--R             (- 10A a b c + 3A b  - B a b )x  + (- 10A a c + 3A a b  - B a b)x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                              2  2        3        2    5
+--R           ((- 16A a b + 12B a )c  + (3A b  - B a b )c)x
+--R         + 
+--R                      2        2          4        3  3
+--R           ((- 16A a b  + 12B a b)c + 3A b  - B a b )x
+--R         + 
+--R                    2         3           3      2 2
+--R           ((- 16A a b + 12B a )c + 3A a b  - B a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                         2        2            5
+--R               (- 10A a c  + (3A b  - B a b)c)x
+--R             + 
+--R                                3        2  3           2          2      2
+--R             (- 10A a b c + 3A b  - B a b )x  + (- 10A a c + 3A a b  - B a b)x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                            2  2          3        2    5
+--R           ((16A a b - 12B a )c  + (- 3A b  + B a b )c)x
+--R         + 
+--R                    2        2          4        3  3
+--R           ((16A a b  - 12B a b)c - 3A b  + B a b )x
+--R         + 
+--R                  2         3           3      2 2
+--R           ((16A a b - 12B a )c - 3A a b  + B a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                     2        2            4
+--R           (- 10A a c  + (3A b  - B a b)c)x
+--R         + 
+--R                             2         3        2  2       2          2
+--R           ((- 11A a b + 2B a )c + 3A b  - B a b )x  - 8A a c + 2A a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R           3 2     2 2   5      3        2 3  3      4      3 2    +-+
+--R       ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x)\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1249
+
+--S 1250 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1250
+
+)clear all
+
+--S 1251 of 1718
+t0:=(A+B*x^2)/(x^4*(a+b*x^2+c*x^4)^2)
+--R 
+--R
+--R                                2
+--R                             B x  + A
+--R   (1)  -------------------------------------------------
+--R         2 12         10            2  8         6    2 4
+--R        c x   + 2b c x   + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1251
+
+--S 1252 of 1718
+r0:=1/6*(-5*A*b^2+3*a*b*B+14*a*A*c)/(a^2*(b^2-4*a*c)*x^3)+_
+   1/2*(-a*B*(3*b^2-10*a*c)+A*(5*b^3-19*a*b*c))/(a^3*(b^2-4*a*c)*x)+_
+   1/2*(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+   x^3*(a+b*x^2+c*x^4))-1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(a*B*(3*b^2-10*a*c)-A*(5*b^3-19*a*b*c)+_
+   (a*b*B*(3*b^2-16*a*c)-A*(5*b^4-29*a*b^2*c+28*a^2*c^2))/sqrt(b^2-_
+   4*a*c))/(a^3*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (a*B*(3*b^2-10*a*c)-A*(5*b^3-19*a*b*c)+(-a*b*B*(3*b^2-16*a*c)+_
+   A*(5*b^4-29*a*b^2*c+28*a^2*c^2))/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                2  2           3         2    7
+--R               ((57A a b - 30B a )c  + (- 15A b  + 9B a b )c)x
+--R             + 
+--R                        2        2           4         3  5
+--R               ((57A a b  - 30B a b)c - 15A b  + 9B a b )x
+--R             + 
+--R                      2         3            3       2 2  3
+--R               ((57A a b - 30B a )c - 15A a b  + 9B a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   2 3           2        2   2           4         3    7
+--R           (- 84A a c  + (87A a b  - 48B a b)c  + (- 15A b  + 9B a b )c)x
+--R         + 
+--R                   2   2           3        2 2          5         4  5
+--R           (- 84A a b c  + (87A a b  - 48B a b )c - 15A b  + 9B a b )x
+--R         + 
+--R                   3 2         2 2        3             4       2 3  3
+--R           (- 84A a c  + (87A a b  - 48B a b)c - 15A a b  + 9B a b )x
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                2  2           3         2    7
+--R               ((57A a b - 30B a )c  + (- 15A b  + 9B a b )c)x
+--R             + 
+--R                        2        2           4         3  5
+--R               ((57A a b  - 30B a b)c - 15A b  + 9B a b )x
+--R             + 
+--R                      2         3            3       2 2  3
+--R               ((57A a b - 30B a )c - 15A a b  + 9B a b )x
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 3             2        2   2         4         3    7
+--R           (84A a c  + (- 87A a b  + 48B a b)c  + (15A b  - 9B a b )c)x
+--R         + 
+--R                 2   2             3        2 2          5         4  5
+--R           (84A a b c  + (- 87A a b  + 48B a b )c + 15A b  - 9B a b )x
+--R         + 
+--R                 3 2           2 2        3             4       2 3  3
+--R           (84A a c  + (- 87A a b  + 48B a b)c + 15A a b  - 9B a b )x
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                            2  2           3         2    6
+--R           ((57A a b - 30B a )c  + (- 15A b  + 9B a b )c)x
+--R         + 
+--R                   2 2           2        2           4         3  4
+--R           (- 14A a c  + (62A a b  - 33B a b)c - 15A b  + 9B a b )x
+--R         + 
+--R                  2         3            3       2 2  2       3        2 2
+--R           ((40A a b - 24B a )c - 10A a b  + 6B a b )x  - 8A a c + 2A a b
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            4 2     3 2   7       4        3 3  5       5      4 2  3  +-+
+--R       ((24a c  - 6a b c)x  + (24a b c - 6a b )x  + (24a c - 6a b )x )\|2
+--R    *
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R       \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1252
+
+--S 1253 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1253
+
+)clear all
+
+--S 1254 of 1718
+t0:=x^11*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        13      11
+--R     B x   + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1254
+
+--S 1255 of 1718
+r0:=1/2*(3*b^4*B-A*b^3*c-21*a*b^2*B*c+7*a*A*b*c^2+30*a^2*B*c^2)*x^2/_
+   (c^3*(b^2-4*a*c)^2)-1/4*(3*b^3*B-A*b^2*c-18*a*b*B*c+16*a*A*c^2)*_
+   x^4/(c^2*(b^2-4*a*c)^2)+1/2*(b^2*B+3*A*b*c-10*a*B*c)*x^6/(c*(b^2-_
+   4*a*c)^2)-1/4*x^10*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4)^2)-1/4*x^8*(5*A*b^2-6*a*b*B-8*a*A*c+2*(b^2*B+3*A*b*c-_
+   10*a*B*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))-1/2*(3*b^6*B-_
+   A*b^5*c-30*a*b^4*B*c+10*a*A*b^3*c^2+90*a^2*b^2*B*c^2-_
+   30*a^2*A*b*c^3-60*a^3*B*c^3)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c^4*(b^2-4*a*c)^(5/2))-1/4*(3*b*B-A*c)*log(a+b*x^2+c*x^4)/c^4
+--R 
+--R
+--R   (2)
+--R                     2          3  5             3         2 2  4
+--R               (60A a b + 120B a )c  + (- 20A a b  - 180B a b )c
+--R             + 
+--R                    5          4  3       6 2
+--R               (2A b  + 60B a b )c  - 6B b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      2 2         3   4             4         2 3  3
+--R               (120A a b  + 240B a b)c  + (- 40A a b  - 360B a b )c
+--R             + 
+--R                    6           5  2        7
+--R               (4A b  + 120B a b )c  - 12B b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      3          4  4         2 3         3 2  3
+--R               (120A a b + 240B a )c  + (20A a b  - 240B a b )c
+--R             + 
+--R                         5        2 4  2        7          6         8
+--R               (- 16A a b  - 60B a b )c  + (2A b  + 48B a b )c - 6B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      3 2         4   3           2 4         3 3  2
+--R               (120A a b  + 240B a b)c  + (- 40A a b  - 360B a b )c
+--R             + 
+--R                      6         2 5            7
+--R               (4A a b  + 120B a b )c - 12B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                 4          5  3           3 3         4 2  2
+--R           (60A a b + 120B a )c  + (- 20A a b  - 180B a b )c
+--R         + 
+--R                2 5        3 4         2 6
+--R           (2A a b  + 60B a b )c - 6B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                        2 5            2        2   4       4          3  3
+--R                   16A a c  + (- 8A a b  - 48B a b)c  + (A b  + 24B a b )c
+--R                 + 
+--R                         5 2
+--R                   - 3B b c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                        2   4             3        2 2  3        5          4  2
+--R                   32A a b c  + (- 16A a b  - 96B a b )c  + (2A b  + 48B a b )c
+--R                 + 
+--R                         6
+--R                   - 6B b c
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                          3 4        3   3         4 2       6          5
+--R                     32A a c  - 96B a b c  - 6A a b c  + (A b  + 18B a b )c
+--R                   + 
+--R                           7
+--R                     - 3B b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        3   3           2 3        3 2  2
+--R                   32A a b c  + (- 16A a b  - 96B a b )c
+--R                 + 
+--R                          5        2 4           6
+--R                   (2A a b  + 48B a b )c - 6B a b
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                  4 3          3 2        4   2       2 4        3 3         2 5
+--R             16A a c  + (- 8A a b  - 48B a b)c  + (A a b  + 24B a b )c - 3B a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                 2 5          2 4       4 3  10
+--R           (32B a c  - 16B a b c  + 2B b c )x
+--R         + 
+--R                      2 5           2         2   4          4          3  3
+--R               - 24A a c  + (21A a b  + 122B a b)c  + (- 3A b  - 68B a b )c
+--R             + 
+--R                   5 2
+--R               9B b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    2          3  4           3        2 2  3
+--R               (2A a b + 100B a )c  + (12A a b  + 14B a b )c
+--R             + 
+--R                      5          4  2       6
+--R               (- 2A b  - 36B a b )c  + 6B b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      3 4         2 2         3   3            4        2 3  2
+--R               - 16A a c  + (29A a b  + 138B a b)c  + (- 4A a b  - 87B a b )c
+--R             + 
+--R                      5
+--R               12B a b c
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                  3         4  3          2 3        3 2  2       2 4   2
+--R           ((14A a b + 60B a )c  + (- 2A a b  - 42B a b )c  + 6B a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 8        2 7     4 6  8        2   7        3 6     5 5  6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R       + 
+--R              3 7        4 5     6 4  4        3   6      2 3 5       5 4  2
+--R         (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R       + 
+--R            4 6      3 2 5     2 4 4
+--R         64a c  - 32a b c  + 4a b c
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1255
+
+--S 1256 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1256
+
+)clear all
+
+--S 1257 of 1718
+t0:=x^9*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        11      9
+--R     B x   + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1257
+
+--S 1258 of 1718
+r0:=-1/2*(b^3*B-7*a*b*B*c+6*a*A*c^2)*x^2/(c^2*(b^2-4*a*c)^2)+_
+   1/4*(b^2*B+6*A*b*c-16*a*B*c)*x^4/(c*(b^2-4*a*c)^2)-1/4*x^8*(A*b-2*a*B-_
+   (b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-1/4*x^6*(2*(2*A*b^2-_
+   3*a*b*B-2*a*A*c)+(b^2*B+6*A*b*c-16*a*B*c)*x^2)/((b^2-4*a*c)^2*(a+b*x^2+_
+   c*x^4))+1/2*(b^5*B-10*a*b^3*B*c+30*a^2*b*B*c^2-12*a^2*A*c^3)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^3*(b^2-4*a*c)^(5/2))+_
+   1/4*B*log(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R                   2 5        2   4          3 3       5 2  8
+--R           (- 24A a c  + 60B a b c  - 20B a b c  + 2B b c )x
+--R         + 
+--R                   2   4         2 2 3          4 2       6   6
+--R           (- 48A a b c  + 120B a b c  - 40B a b c  + 4B b c)x
+--R         + 
+--R                      3 4           2 2         3   3        2 3 2          5
+--R               - 48A a c  + (- 24A a b  + 120B a b)c  + 20B a b c  - 16B a b c
+--R             + 
+--R                   7
+--R               2B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   3   3         3 2 2        2 4          6  2        4 3
+--R           (- 48A a b c  + 120B a b c  - 40B a b c + 4B a b )x  - 24A a c
+--R         + 
+--R                4   2        3 3        2 5
+--R           60B a b c  - 20B a b c + 2B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2 4         2 3      4 2  8
+--R               (16B a c  - 8B a b c  + B b c )x
+--R             + 
+--R                     2   3          3 2       5   6
+--R               (32B a b c  - 16B a b c  + 2B b c)x
+--R             + 
+--R                     3 3         4       6  4
+--R               (32B a c  - 6B a b c + B b )x
+--R             + 
+--R                   3   2        2 3          5  2        4 2       3 2       2 4
+--R             (32B a b c  - 16B a b c + 2B a b )x  + 16B a c  - 8B a b c + B a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                              2  4       3          2  3       4 2  8
+--R           ((- 10A a b - 24B a )c  + (A b  + 21B a b )c  - 3B b c )x
+--R         + 
+--R                   2 4            2       2   3          3 2       5   6
+--R           (- 20A a c  + (- 4A a b  + 2B a b)c  + 12B a b c  - 2B b c)x
+--R         + 
+--R                    2         3  3        2 2 2         4   4
+--R           ((- 18A a b - 16B a )c  + 29B a b c  - 4B a b c)x
+--R         + 
+--R                   3 3        3   2       2 3   2
+--R           (- 12A a c  + 14B a b c  - 2B a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 7        2 6     4 5  8        2   6        3 5     5 4  6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c )x
+--R       + 
+--R              3 6        4 4     6 3  4        3   5      2 3 4       5 3  2
+--R         (128a c  - 24a b c  + 4b c )x  + (128a b c  - 64a b c  + 8a b c )x
+--R       + 
+--R            4 5      3 2 4     2 4 3
+--R         64a c  - 32a b c  + 4a b c
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1258
+
+--S 1259 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1259
+
+)clear all
+
+--S 1260 of 1718
+t0:=x^7*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        9      7
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1260
+
+--S 1261 of 1718
+r0:=-1/4*x^6*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   3/4*(A*b-2*a*B)*x^2*(2*a+b*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+_
+   3*a*(A*b-2*a*B)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                           2  2 8           2        2     6
+--R           (12A a b - 24B a )c x  + (24A a b  - 48B a b)c x
+--R         + 
+--R                  2         3            3        2 2  4
+--R           ((24A a b - 48B a )c + 12A a b  - 24B a b )x
+--R         + 
+--R                 2 2        3   2        3         4
+--R           (24A a b  - 48B a b)x  + 12A a b - 24B a
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                  2       2                  3  8
+--R           (8A a c  + (A b  - 10B a b)c + B b )x
+--R         + 
+--R                            2         3         2  6          2        2   4
+--R           ((10A a b - 20B a )c + 2A b  - 4B a b )x  + (9A a b  - 18B a b)x
+--R         + 
+--R                2         3  2
+--R           (6A a b - 12B a )x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1261
+
+--S 1262 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1262
+
+)clear all
+
+--S 1263 of 1718
+t0:=x^5*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        7      5
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1263
+
+--S 1264 of 1718
+r0:=-1/4*x^4*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/4*(2*a+b*x^2)*(2*(A*b-2*a*B)+(b*B-2*A*c)*x^2)/((b^2-4*a*c)^2*_
+   (a+b*x^2+c*x^4))+(3*a*b*B-A*(b^2+2*a*c))*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                    3          2            2  8
+--R           (- 8A a c  + (- 4A b  + 12B a b)c )x
+--R         + 
+--R                       2          3          2    6
+--R           (- 16A a b c  + (- 8A b  + 24B a b )c)x
+--R         + 
+--R                   2 2             2        2          4          3  4
+--R           (- 16A a c  + (- 16A a b  + 24B a b)c - 4A b  + 12B a b )x
+--R         + 
+--R                   2            3        2 2  2       3        2 2        3
+--R           (- 16A a b c - 8A a b  + 24B a b )x  - 8A a c - 4A a b  + 12B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                    2      2   8          2          2                  3  6
+--R           (- 2A b c  + B b c)x  + (4A a c  + (- 2A b  - 6B a b)c + 2B b )x
+--R         + 
+--R                           2        3        2  4
+--R           ((2A a b - 16B a )c + A b  + B a b )x
+--R         + 
+--R                  2          2        2   2       2        3
+--R           (- 4A a c + 6A a b  - 10B a b)x  + 4A a b - 8B a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1264
+
+--S 1265 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1265
+
+)clear all
+
+--S 1266 of 1718
+t0:=x^3*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        5      3
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1266
+
+--S 1267 of 1718
+r0:=1/4*(2*a+b*x^2)*(A+B*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   1/4*(-3*b*(A*b-2*a*B)+2*(b^2*B-3*A*b*c+2*a*B*c)*x^2)/((b^2-4*a*c)^2*_
+   (a+b*x^2+c*x^4))-(b^2*B-3*A*b*c+2*a*B*c)*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                           3       2 2  8          2            2       3   6
+--R           ((12A b - 8B a)c  - 4B b c )x  + ((24A b  - 16B a b)c  - 8B b c)x
+--R         + 
+--R                            2  2         3          2         4  4
+--R           ((24A a b - 16B a )c  + (12A b  - 16B a b )c - 4B b )x
+--R         + 
+--R                    2        2            3  2         2        3         2 2
+--R           ((24A a b  - 16B a b)c - 8B a b )x  + (12A a b - 8B a )c - 4B a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                            2       2   6           2                  3  4
+--R           ((- 6A b + 4B a)c  + 2B b c)x  + ((- 9A b  + 6B a b)c + 3B b )x
+--R         + 
+--R                           2         3          2  2       2         2       2
+--R         ((- 10A a b - 4B a )c - 2A b  + 10B a b )x  - 8A a c - A a b  + 6B a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1267
+
+--S 1268 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1268
+
+)clear all
+
+--S 1269 of 1718
+t0:=x*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        3
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1269
+
+--S 1270 of 1718
+r0:=1/4*(-A*b+2*a*B+(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-_
+   3/4*(b*B-2*A*c)*(b+2*c*x^2)/((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+_
+   3*c*(b*B-2*A*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                   4          3  8             3        2 2  6
+--R           (- 24A c  + 12B b c )x  + (- 48A b c  + 24B b c )x
+--R         + 
+--R                     3           2            2        3   4
+--R           (- 48A a c  + (- 24A b  + 24B a b)c  + 12B b c)x
+--R         + 
+--R                       2          2   2        2 2        2
+--R           (- 48A a b c  + 24B a b c)x  - 24A a c  + 12B a b c
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 3         2  6           2       2   4
+--R           (12A c  - 6B b c )x  + (18A b c  - 9B b c)x
+--R         + 
+--R                   2        2                   3  2                  2        3
+--R           (20A a c  + (4A b  - 10B a b)c - 2B b )x  + (10A a b - 8B a )c - A b
+--R         + 
+--R                  2
+--R           - B a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  8        2   3        3 2     5   6
+--R         (64a c  - 32a b c  + 4b c )x  + (128a b c  - 64a b c  + 8b c)x
+--R       + 
+--R              3 3        4      6  4        3   2      2 3        5  2      4 2
+--R         (128a c  - 24a b c + 4b )x  + (128a b c  - 64a b c + 8a b )x  + 64a c
+--R       + 
+--R              3 2      2 4
+--R         - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1270
+
+--S 1271 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1271
+
+)clear all
+
+--S 1272 of 1718
+t0:=(A+B*x^2)/(x*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R        2
+--R     B x  + A
+--R  /
+--R        3 13       2 11        2     2   9              3  7      2        2  5
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   3    3
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1272
+
+--S 1273 of 1718
+r0:=1/4*(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+   (a+b*x^2+c*x^4)^2)+1/4*(6*a^2*b*B*c+A*(2*b^4-15*a*b^2*c+16*a^2*c^2)+_
+   2*c*(6*a^2*B*c+A*(b^3-7*a*b*c))*x^2)/(a^2*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))-_
+   1/2*(12*a^3*B*c^2-A*(b^5-10*a*b^3*c+30*a^2*b*c^2))*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(5/2))+A*log(x)/a^3-_
+   1/4*A*log(a+b*x^2+c*x^4)/a^3
+--R 
+--R
+--R   (2)
+--R                  2         3  4          3 3       5 2  8
+--R           ((60A a b - 24B a )c  - 20A a b c  + 2A b c )x
+--R         + 
+--R                   2 2        3   3          4 2       6   6
+--R           ((120A a b  - 48B a b)c  - 40A a b c  + 4A b c)x
+--R         + 
+--R                        3         4  3         2 3        3 2  2          5
+--R                 (120A a b - 48B a )c  + (20A a b  - 24B a b )c  - 16A a b c
+--R               + 
+--R                     7
+--R                 2A b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   3 2        4   2        2 4          6  2
+--R           ((120A a b  - 48B a b)c  - 40A a b c + 4A a b )x
+--R         + 
+--R                 4         5  2        3 3        2 5
+--R           (60A a b - 24B a )c  - 20A a b c + 2A a b
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                       2 4         2 3      4 2  8
+--R               (- 16A a c  + 8A a b c  - A b c )x
+--R             + 
+--R                       2   3          3 2       5   6
+--R               (- 32A a b c  + 16A a b c  - 2A b c)x
+--R             + 
+--R                       3 3         4       6  4
+--R               (- 32A a c  + 6A a b c - A b )x
+--R             + 
+--R                       3   2        2 3          5  2        4 2       3 2
+--R               (- 32A a b c  + 16A a b c - 2A a b )x  - 16A a c  + 8A a b c
+--R             + 
+--R                    2 4
+--R               - A a b
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                     2 4          2 3       4 2  8
+--R               (64A a c  - 32A a b c  + 4A b c )x
+--R             + 
+--R                      2   3          3 2       5   6
+--R               (128A a b c  - 64A a b c  + 8A b c)x
+--R             + 
+--R                      3 3          4        6  4
+--R               (128A a c  - 24A a b c + 4A b )x
+--R             + 
+--R                      3   2        2 3          5  2        4 2        3 2
+--R               (128A a b c  - 64A a b c + 8A a b )x  + 64A a c  - 32A a b c
+--R             + 
+--R                   2 4
+--R               4A a b
+--R          *
+--R             log(x)
+--R         + 
+--R                    2         3  3         3 2  6
+--R           ((- 14A a b + 12B a )c  + 2A a b c )x
+--R         + 
+--R                 3 3           2 2        3   2         4   4
+--R           (16A a c  + (- 29A a b  + 18B a b)c  + 4A a b c)x
+--R         + 
+--R                   3         4  2           2 3       3 2           5  2
+--R           ((- 2A a b + 20B a )c  + (- 12A a b  + 4B a b )c + 2A a b )x
+--R         + 
+--R                4 2           3 2        4          2 4      3 3
+--R           24A a c  + (- 21A a b  + 10B a b)c + 3A a b  - B a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             5 4      4 2 3     3 4 2  8        5   3      4 3 2     3 5   6
+--R         (64a c  - 32a b c  + 4a b c )x  + (128a b c  - 64a b c  + 8a b c)x
+--R       + 
+--R              6 3      4 4      3 6  4        6   2      5 3      4 5  2
+--R         (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R       + 
+--R            7 2      6 2      5 4
+--R         64a c  - 32a b c + 4a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1273
+
+--S 1274 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1274
+
+)clear all
+
+--S 1275 of 1718
+t0:=(A+B*x^2)/(x^3*(a+b*x^2+c*x^4)^3)
+--R 
+--R
+--R   (1)
+--R        2
+--R     B x  + A
+--R  /
+--R        3 15       2 13        2     2   11              3  9      2        2  7
+--R       c x   + 3b c x   + (3a c  + 3b c)x   + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   5    3 3
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1275
+
+--S 1276 of 1718
+r0:=1/2*(a*b*B*(b^2-7*a*c)-3*A*(b^4-7*a*b^2*c+10*a^2*c^2))/(a^3*(b^2-_
+   4*a*c)^2*x^2)+1/4*(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-_
+   4*a*c)*x^2*(a+b*x^2+c*x^4)^2)+1/4*(-a*b*B*(b^2-10*a*c)+A*(3*b^4-_
+   20*a*b^2*c+20*a^2*c^2)-c*(a*B*(b^2-16*a*c)-3*A*(b^3-6*a*b*c))*x^2)/_
+   (a^2*(b^2-4*a*c)^2*x^2*(a+b*x^2+c*x^4))+1/2*(a*b*B*(b^4-10*a*b^2*c+_
+   30*a^2*c^2)-3*A*(b^6-10*a*b^4*c+30*a^2*b^2*c^2-20*a^3*c^3))*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(5/2))-_
+   (3*A*b-a*B)*log(x)/a^4+1/4*(3*A*b-a*B)*log(a+b*x^2+c*x^4)/a^4
+--R 
+--R
+--R   (2)
+--R                     3 5            2 2        3   4           4        2 3  3
+--R               120A a c  + (- 180A a b  + 60B a b)c  + (60A a b  - 20B a b )c
+--R             + 
+--R                      6         5  2
+--R               (- 6A b  + 2B a b )c
+--R          *
+--R              10
+--R             x
+--R         + 
+--R                     3   4            2 3         3 2  3
+--R               240A a b c  + (- 360A a b  + 120B a b )c
+--R             + 
+--R                        5        2 4  2           7         6
+--R               (120A a b  - 40B a b )c  + (- 12A b  + 4B a b )c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                     4 4            3 2         4   3
+--R               240A a c  + (- 240A a b  + 120B a b)c
+--R             + 
+--R                       2 4        3 3  2           6        2 5         8
+--R               (- 60A a b  + 20B a b )c  + (48A a b  - 16B a b )c - 6A b
+--R             + 
+--R                     7
+--R               2B a b
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                     4   3            3 3         4 2  2
+--R               240A a b c  + (- 360A a b  + 120B a b )c
+--R             + 
+--R                      2 5        3 4            7       2 6
+--R               (120A a b  - 40B a b )c - 12A a b  + 4B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     5 3            4 2        5   2         3 4        4 3
+--R               120A a c  + (- 180A a b  + 60B a b)c  + (60A a b  - 20B a b )c
+--R             + 
+--R                     2 6       3 5
+--R               - 6A a b  + 2B a b
+--R          *
+--R              2
+--R             x
+--R      *
+--R                      2
+--R                  2c x  + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                         2         3  4             3       2 2  3
+--R                   (48A a b - 16B a )c  + (- 24A a b  + 8B a b )c
+--R                 + 
+--R                        5        4  2
+--R                   (3A b  - B a b )c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                         2 2        3   3             4        2 3  2
+--R                   (96A a b  - 32B a b)c  + (- 48A a b  + 16B a b )c
+--R                 + 
+--R                        6         5
+--R                   (6A b  - 2B a b )c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                           3         4  3             5       2 4         7
+--R                     (96A a b - 32B a )c  + (- 18A a b  + 6B a b )c + 3A b
+--R                   + 
+--R                            6
+--R                     - B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                         3 2        4   2           2 4        3 3           6
+--R                   (96A a b  - 32B a b)c  + (- 48A a b  + 16B a b )c + 6A a b
+--R                 + 
+--R                         2 5
+--R                   - 2B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                         4         5  2           3 3       4 2         2 5
+--R                   (48A a b - 16B a )c  + (- 24A a b  + 8B a b )c + 3A a b
+--R                 + 
+--R                        3 4
+--R                   - B a b
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R                    4      2
+--R             log(c x  + b x  + a)
+--R         + 
+--R                            2         3  4           3        2 2  3
+--R                   (- 192A a b + 64B a )c  + (96A a b  - 32B a b )c
+--R                 + 
+--R                           5         4  2
+--R                   (- 12A b  + 4B a b )c
+--R              *
+--R                  10
+--R                 x
+--R             + 
+--R                            2 2         3   3            4        2 3  2
+--R                   (- 384A a b  + 128B a b)c  + (192A a b  - 64B a b )c
+--R                 + 
+--R                           6         5
+--R                   (- 24A b  + 8B a b )c
+--R              *
+--R                  8
+--R                 x
+--R             + 
+--R                            3          4  3           5        2 4          7
+--R                   (- 384A a b + 128B a )c  + (72A a b  - 24B a b )c - 12A b
+--R                 + 
+--R                         6
+--R                   4B a b
+--R              *
+--R                  6
+--R                 x
+--R             + 
+--R                            3 2         4   2          2 4        3 3
+--R                   (- 384A a b  + 128B a b)c  + (192A a b  - 64B a b )c
+--R                 + 
+--R                            6       2 5
+--R                   - 24A a b  + 8B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                            4         5  2         3 3        4 2          2 5
+--R                   (- 192A a b + 64B a )c  + (96A a b  - 32B a b )c - 12A a b
+--R                 + 
+--R                       3 4
+--R                   4B a b
+--R              *
+--R                  2
+--R                 x
+--R          *
+--R             log(x)
+--R         + 
+--R                   3 4         2 2        3   3            4       2 3  2  8
+--R           (- 60A a c  + (42A a b  - 14B a b)c  + (- 6A a b  + 2B a b )c )x
+--R         + 
+--R                        3         4  3         2 3        3 2  2
+--R               (- 138A a b + 16B a )c  + (87A a b  - 29B a b )c
+--R             + 
+--R                         5       2 4
+--R               (- 12A a b  + 4B a b )c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                       4 3           3 2       4   2         2 4        3 3
+--R               - 100A a c  + (- 14A a b  - 2B a b)c  + (36A a b  - 12B a b )c
+--R             + 
+--R                       6       2 5
+--R               - 6A a b  + 2B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                        4         5  2         3 3        4 2         2 5
+--R               (- 122A a b + 24B a )c  + (68A a b  - 21B a b )c - 9A a b
+--R             + 
+--R                   3 4
+--R               3B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                  5 2        4 2        3 4
+--R           - 32A a c  + 16A a b c - 2A a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             6 4      5 2 3     4 4 2  10        6   3      5 3 2     4 5   8
+--R         (64a c  - 32a b c  + 4a b c )x   + (128a b c  - 64a b c  + 8a b c)x
+--R       + 
+--R              7 3      5 4      4 6  6        7   2      6 3      5 5  4
+--R         (128a c  - 24a b c + 4a b )x  + (128a b c  - 64a b c + 8a b )x
+--R       + 
+--R             8 2      7 2      6 4  2
+--R         (64a c  - 32a b c + 4a b )x
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1276
+
+--S 1277 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1277
+
+)clear all
+
+--S 1278 of 1718
+t0:=x^8*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        10      8
+--R     B x   + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1278
+
+--S 1279 of 1718
+r0:=-1/8*(3*b^3*B+A*b^2*c-24*a*b*B*c+20*a*A*c^2)*x/(c^2*(b^2-4*a*c)^2)+_
+   1/8*(b^2*B+12*A*b*c-28*a*B*c)*x^3/(c*(b^2-4*a*c)^2)-1/4*x^7*(A*b-_
+   2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-1/8*x^5*_
+   (7*A*b^2-12*a*b*B-4*a*A*c+(b^2*B+12*A*b*c-28*a*B*c)*x^2)/_
+   ((b^2-4*a*c)^2*(a+b*x^2+c*x^4))+1/8*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*(3*b^4*B+A*b^3*c-27*a*b^2*B*c-_
+   16*a*A*b*c^2+84*a^2*B*c^2+(-3*b^5*B-A*b^4*c+33*a*b^3*B*c+_
+   18*a*A*b^2*c^2-132*a^2*b*B*c^2+40*a^2*A*c^3)/sqrt(b^2-4*a*c))/_
+   (c^(5/2)*(b^2-4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(3*b^4*B+A*b^3*c-_
+   27*a*b^2*B*c-16*a*A*b*c^2+84*a^2*B*c^2+(3*b^5*B+A*b^4*c-33*a*b^3*B*c-_
+   18*a*A*b^2*c^2+132*a^2*b*B*c^2-40*a^2*A*c^3)/sqrt(b^2-4*a*c))/_
+   (c^(5/2)*(b^2-4*a*c)^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                  2  4       3          2  3       4 2  8
+--R               ((- 16A a b + 84B a )c  + (A b  - 27B a b )c  + 3B b c )x
+--R             + 
+--R                          2         2   3        4          3  2       5   6
+--R               ((- 32A a b  + 168B a b)c  + (2A b  - 54B a b )c  + 6B b c)x
+--R             + 
+--R                           2          3  3             3        2 2  2
+--R                   (- 32A a b + 168B a )c  + (- 14A a b  + 30B a b )c
+--R                 + 
+--R                       5          4         6
+--R                   (A b  - 21B a b )c + 3B b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        2 2         3   2          4        2 3           5  2
+--R               ((- 32A a b  + 168B a b)c  + (2A a b  - 54B a b )c + 6B a b )x
+--R             + 
+--R                       3         4  2       2 3        3 2         2 4
+--R               (- 16A a b + 84B a )c  + (A a b  - 27B a b )c + 3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    2 5           2         2   4         4          3  3
+--R               40A a c  + (18A a b  - 132B a b)c  + (- A b  + 33B a b )c
+--R             + 
+--R                     5 2
+--R               - 3B b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                    2   4           3         2 2  3          5          4  2
+--R               80A a b c  + (36A a b  - 264B a b )c  + (- 2A b  + 66B a b )c
+--R             + 
+--R                     6
+--R               - 6B b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                    3 4         2 2         3   3           4        2 3  2
+--R               80A a c  + (76A a b  - 264B a b)c  + (16A a b  - 66B a b )c
+--R             + 
+--R                     6          5         7
+--R               (- A b  + 27B a b )c - 3B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    3   3         2 3         3 2  2            5        2 4
+--R               80A a b c  + (36A a b  - 264B a b )c  + (- 2A a b  + 66B a b )c
+--R             + 
+--R                       6
+--R               - 6B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R              4 3         3 2         4   2         2 4        3 3         2 5
+--R         40A a c  + (18A a b  - 132B a b)c  + (- A a b  + 33B a b )c - 3B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                  2  4       3          2  3       4 2  8
+--R               ((- 16A a b + 84B a )c  + (A b  - 27B a b )c  + 3B b c )x
+--R             + 
+--R                          2         2   3        4          3  2       5   6
+--R               ((- 32A a b  + 168B a b)c  + (2A b  - 54B a b )c  + 6B b c)x
+--R             + 
+--R                           2          3  3             3        2 2  2
+--R                   (- 32A a b + 168B a )c  + (- 14A a b  + 30B a b )c
+--R                 + 
+--R                       5          4         6
+--R                   (A b  - 21B a b )c + 3B b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        2 2         3   2          4        2 3           5  2
+--R               ((- 32A a b  + 168B a b)c  + (2A a b  - 54B a b )c + 6B a b )x
+--R             + 
+--R                       3         4  2       2 3        3 2         2 4
+--R               (- 16A a b + 84B a )c  + (A a b  - 27B a b )c + 3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                      2 5             2         2   4       4          3  3
+--R               - 40A a c  + (- 18A a b  + 132B a b)c  + (A b  - 33B a b )c
+--R             + 
+--R                   5 2
+--R               3B b c
+--R          *
+--R              8
+--R             x
+--R         + 
+--R                      2   4             3         2 2  3        5          4  2
+--R               - 80A a b c  + (- 36A a b  + 264B a b )c  + (2A b  - 66B a b )c
+--R             + 
+--R                   6
+--R               6B b c
+--R          *
+--R              6
+--R             x
+--R         + 
+--R                      3 4           2 2         3   3
+--R               - 80A a c  + (- 76A a b  + 264B a b)c
+--R             + 
+--R                         4        2 3  2       6          5         7
+--R               (- 16A a b  + 66B a b )c  + (A b  - 27B a b )c + 3B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                      3   3           2 3         3 2  2          5        2 4
+--R               - 80A a b c  + (- 36A a b  + 264B a b )c  + (2A a b  - 66B a b )c
+--R             + 
+--R                     6
+--R               6B a b
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                4 3           3 2         4   2       2 4        3 3         2 5
+--R         - 40A a c  + (- 18A a b  + 132B a b)c  + (A a b  - 33B a b )c + 3B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                              2  3       3          2  2       4   7
+--R           ((- 16A a b - 44B a )c  + (A b  + 37B a b )c  - 5B b c)x
+--R         + 
+--R                        2 3            2       2   2         4          3
+--R                 - 36A a c  + (- 5A a b  + 4B a b)c  + (- A b  + 20B a b )c
+--R               + 
+--R                       5
+--R                 - 3B b
+--R          *
+--R              5
+--R             x
+--R         + 
+--R                    2         3  2            3        2 2           4  3
+--R           ((- 28A a b - 28B a )c  + (- 2A a b  + 49B a b )c - 6B a b )x
+--R         + 
+--R                   3 2         2 2        3          2 3
+--R           (- 20A a c  + (- A a b  + 24B a b)c - 3B a b )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 6        2 5     4 4  8        2   5         3 4      5 3  6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R       + 
+--R              3 5        4 3     6 2  4        3   4       2 3 3        5 2  2
+--R         (256a c  - 48a b c  + 8b c )x  + (256a b c  - 128a b c  + 16a b c )x
+--R       + 
+--R             4 4      3 2 3     2 4 2
+--R         128a c  - 64a b c  + 8a b c
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1279
+
+--S 1280 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1280
+
+)clear all
+
+--S 1281 of 1718
+t0:=x^6*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        8      6
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1281
+
+--S 1282 of 1718
+r0:=-1/8*(b^2*B-12*A*b*c+20*a*B*c)*x/(c*(b^2-4*a*c)^2)-1/4*x^5*(A*b-2*a*B-_
+   (b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-1/8*x^3*(5*A*b^2-_
+   12*a*b*B+4*a*A*c-(b^2*B-12*A*b*c+20*a*B*c)*x^2)/((b^2-4*a*c)^2*_
+   (a+b*x^2+c*x^4))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b^3*B+3*A*b^2*c-16*a*b*B*c+12*a*A*c^2+(-b^4*B-3*A*b^3*c+18*a*b^2*B*c-_
+   36*a*A*b*c^2+40*a^2*B*c^2)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)^2*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*(b^3*B+3*A*b^2*c-16*a*b*B*c+12*a*A*c^2+(b^4*B+_
+   3*A*b^3*c-18*a*b^2*B*c+36*a*A*b*c^2-40*a^2*B*c^2)/sqrt(b^2-4*a*c))/_
+   (c^(3/2)*(b^2-4*a*c)^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       4        2            3      3 2  8
+--R               (12A a c  + (3A b  - 16B a b)c  + B b c )x
+--R             + 
+--R                         3        3          2  2       4   6
+--R               (24A a b c  + (6A b  - 32B a b )c  + 2B b c)x
+--R             + 
+--R                          2 3           2        2   2        4          3
+--R                     24A a c  + (18A a b  - 32B a b)c  + (3A b  - 14B a b )c
+--R                   + 
+--R                        5
+--R                     B b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                     2   2          3        2 2           4  2        3 2
+--R               (24A a b c  + (6A a b  - 32B a b )c + 2B a b )x  + 12A a c
+--R             + 
+--R                    2 2        3         2 3
+--R               (3A a b  - 16B a b)c + B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                              2  4          3          2  3      4 2  8
+--R           ((- 36A a b + 40B a )c  + (- 3A b  + 18B a b )c  - B b c )x
+--R         + 
+--R                      2        2   3          4          3  2       5   6
+--R           ((- 72A a b  + 80B a b)c  + (- 6A b  + 36B a b )c  - 2B b c)x
+--R         + 
+--R                       2         3  3             3        2 2  2
+--R               (- 72A a b + 80B a )c  + (- 42A a b  + 76B a b )c
+--R             + 
+--R                      5          4        6
+--R               (- 3A b  + 16B a b )c - B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    2 2        3   2            4        2 3           5  2
+--R           ((- 72A a b  + 80B a b)c  + (- 6A a b  + 36B a b )c - 2B a b )x
+--R         + 
+--R                   3         4  2          2 3        3 2        2 4
+--R           (- 36A a b + 40B a )c  + (- 3A a b  + 18B a b )c - B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                       4        2            3      3 2  8
+--R               (12A a c  + (3A b  - 16B a b)c  + B b c )x
+--R             + 
+--R                         3        3          2  2       4   6
+--R               (24A a b c  + (6A b  - 32B a b )c  + 2B b c)x
+--R             + 
+--R                          2 3           2        2   2        4          3
+--R                     24A a c  + (18A a b  - 32B a b)c  + (3A b  - 14B a b )c
+--R                   + 
+--R                        5
+--R                     B b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                     2   2          3        2 2           4  2        3 2
+--R               (24A a b c  + (6A a b  - 32B a b )c + 2B a b )x  + 12A a c
+--R             + 
+--R                    2 2        3         2 3
+--R               (3A a b  - 16B a b)c + B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                            2  4        3          2  3      4 2  8
+--R           ((36A a b - 40B a )c  + (3A b  - 18B a b )c  + B b c )x
+--R         + 
+--R                    2        2   3        4          3  2       5   6
+--R           ((72A a b  - 80B a b)c  + (6A b  - 36B a b )c  + 2B b c)x
+--R         + 
+--R                     2         3  3           3        2 2  2
+--R               (72A a b - 80B a )c  + (42A a b  - 76B a b )c
+--R             + 
+--R                    5          4        6
+--R               (3A b  - 16B a b )c + B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                  2 2        3   2          4        2 3           5  2
+--R           ((72A a b  - 80B a b)c  + (6A a b  - 36B a b )c + 2B a b )x
+--R         + 
+--R                 3         4  2        2 3        3 2        2 4
+--R           (36A a b - 40B a )c  + (3A a b  - 18B a b )c + B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                   3        2            2      3   7
+--R           (12A a c  + (3A b  - 16B a b)c  + B b c)x
+--R         + 
+--R                            2  2        3         2        4  5
+--R           ((16A a b - 36B a )c  + (5A b  - 5B a b )c - B b )x
+--R         + 
+--R                  2 2           2        2            3  3
+--R           (- 4A a c  + (19A a b  - 28B a b)c - 2B a b )x
+--R         + 
+--R                  2         3        2 2
+--R           ((12A a b - 20B a )c - B a b )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 5        2 4     4 3  8        2   4         3 3      5 2  6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c )x
+--R       + 
+--R              3 4        4 2     6   4        3   3       2 3 2        5   2
+--R         (256a c  - 48a b c  + 8b c)x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R             4 3      3 2 2     2 4
+--R         128a c  - 64a b c  + 8a b c
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1282
+
+-- Table construction failed in MLIFT
+--S 1283 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1283
+
+)clear all
+
+--S 1284 of 1718
+t0:=x^4*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        6      4
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1284
+
+--S 1285 of 1718
+r0:=-1/4*x^3*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)+_
+   3/8*x*(4*a*b*B-A*(b^2+4*a*c)+(b^2*B-4*A*b*c+4*a*B*c)*x^2)/((b^2-_
+   4*a*c)^2*(a+b*x^2+c*x^4))+3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*(b^2*B-4*A*b*c+4*a*B*c+(-b^3*B+6*A*b^2*c-_
+   12*a*b*B*c+8*a*A*c^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^2*sqrt(2)*sqrt(c)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+3/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*(b^2*B-4*A*b*c+4*a*B*c+(b^3*B-6*A*b^2*c+12*a*b*B*c-_
+   8*a*A*c^2)/sqrt(b^2-4*a*c))/((b^2-4*a*c)^2*sqrt(2)*sqrt(c)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                  3       2 2  8
+--R               ((- 12A b + 12B a)c  + 3B b c )x
+--R             + 
+--R                        2            2       3   6
+--R               ((- 24A b  + 24B a b)c  + 6B b c)x
+--R             + 
+--R                                  2  2           3          2         4  4
+--R               ((- 24A a b + 24B a )c  + (- 12A b  + 18B a b )c + 3B b )x
+--R             + 
+--R                          2        2            3  2           2         3
+--R               ((- 24A a b  + 24B a b)c + 6B a b )x  + (- 12A a b + 12B a )c
+--R             + 
+--R                   2 2
+--R               3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                   4         2            3       3 2  8
+--R           (24A a c  + (18A b  - 36B a b)c  - 3B b c )x
+--R         + 
+--R                     3         3          2  2       4   6
+--R           (48A a b c  + (36A b  - 72B a b )c  - 6B b c)x
+--R         + 
+--R                 2 3           2        2   2         4          3         5  4
+--R           (48A a c  + (60A a b  - 72B a b)c  + (18A b  - 42B a b )c - 3B b )x
+--R         + 
+--R                 2   2           3        2 2           4  2        3 2
+--R           (48A a b c  + (36A a b  - 72B a b )c - 6B a b )x  + 24A a c
+--R         + 
+--R                 2 2        3          2 3
+--R           (18A a b  - 36B a b)c - 3B a b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                  3       2 2  8
+--R               ((- 12A b + 12B a)c  + 3B b c )x
+--R             + 
+--R                        2            2       3   6
+--R               ((- 24A b  + 24B a b)c  + 6B b c)x
+--R             + 
+--R                                  2  2           3          2         4  4
+--R               ((- 24A a b + 24B a )c  + (- 12A b  + 18B a b )c + 3B b )x
+--R             + 
+--R                          2        2            3  2           2         3
+--R               ((- 24A a b  + 24B a b)c + 6B a b )x  + (- 12A a b + 12B a )c
+--R             + 
+--R                   2 2
+--R               3B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                     4           2            3       3 2  8
+--R           (- 24A a c  + (- 18A b  + 36B a b)c  + 3B b c )x
+--R         + 
+--R                       3           3          2  2       4   6
+--R           (- 48A a b c  + (- 36A b  + 72B a b )c  + 6B b c)x
+--R         + 
+--R                      2 3             2        2   2           4          3
+--R               - 48A a c  + (- 60A a b  + 72B a b)c  + (- 18A b  + 42B a b )c
+--R             + 
+--R                   5
+--R               3B b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                   2   2             3        2 2           4  2        3 2
+--R           (- 48A a b c  + (- 36A a b  + 72B a b )c + 6B a b )x  - 24A a c
+--R         + 
+--R                   2 2        3          2 3
+--R           (- 18A a b  + 36B a b)c + 3B a b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                              2       2   7
+--R           ((- 12A b + 12B a)c  + 3B b c)x
+--R         + 
+--R                  2           2                   3  5
+--R           (4A a c  + (- 19A b  + 16B a b)c + 5B b )x
+--R         + 
+--R                             2         3          2  3
+--R           ((- 16A a b - 4B a )c - 5A b  + 19B a b )x
+--R         + 
+--R                   2          2        2
+--R           (- 12A a c - 3A a b  + 12B a b)x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              2 4        2 3     4 2  8        2   3         3 2      5   6
+--R         (128a c  - 64a b c  + 8b c )x  + (256a b c  - 128a b c  + 16b c)x
+--R       + 
+--R              3 3        4      6  4        3   2       2 3         5  2
+--R         (256a c  - 48a b c + 8b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             4 2      3 2      2 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1285
+
+--S 1286 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1286
+
+)clear all
+
+--S 1287 of 1718
+t0:=x^2*(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        4      2
+--R     B x  + A x
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1287
+
+--S 1288 of 1718
+r0:=-1/4*x*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4)^2)-_
+   1/8*x*(a*B*(7*b^2-4*a*c)-A*(b^3+8*a*b*c)+c*(12*a*b*B-A*(b^2+20*a*c))*_
+   x^2)/(a*(b^2-4*a*c)^2*(a+b*x^2+c*x^4))-1/8*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(12*a*b*B-A*(b^2+20*a*c)+(-6*a*B*_
+   (3*b^2+4*a*c)-A*(b^3-52*a*b*c))/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(12*a*b*B-A*(b^2+20*a*c)+(6*a*B*(3*b^2+_
+   4*a*c)+A*(b^3-52*a*b*c))/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)^2*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                       3       2            2  8
+--R               (20A a c  + (A b  - 12B a b)c )x
+--R             + 
+--R                         2        3          2    6
+--R               (40A a b c  + (2A b  - 24B a b )c)x
+--R             + 
+--R                     2 2           2        2         4          3  4
+--R               (40A a c  + (22A a b  - 24B a b)c + A b  - 12B a b )x
+--R             + 
+--R                     2            3        2 2  2        3       2 2        3
+--R               (40A a b c + 2A a b  - 24B a b )x  + 20A a c + A a b  - 12B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                              2  3       3          2  2  8
+--R           ((- 52A a b + 24B a )c  + (A b  + 18B a b )c )x
+--R         + 
+--R                       2        2   2        4          3    6
+--R           ((- 104A a b  + 48B a b)c  + (2A b  + 36B a b )c)x
+--R         + 
+--R                        2         3  2             3        2 2        5
+--R               (- 104A a b + 48B a )c  + (- 50A a b  + 60B a b )c + A b
+--R             + 
+--R                      4
+--R               18B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                     2 2        3            4        2 3  2
+--R           ((- 104A a b  + 48B a b)c + 2A a b  + 36B a b )x
+--R         + 
+--R                   3         4        2 3        3 2
+--R           (- 52A a b + 24B a )c + A a b  + 18B a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                       3       2            2  8
+--R               (20A a c  + (A b  - 12B a b)c )x
+--R             + 
+--R                         2        3          2    6
+--R               (40A a b c  + (2A b  - 24B a b )c)x
+--R             + 
+--R                     2 2           2        2         4          3  4
+--R               (40A a c  + (22A a b  - 24B a b)c + A b  - 12B a b )x
+--R             + 
+--R                     2            3        2 2  2        3       2 2        3
+--R               (40A a b c + 2A a b  - 24B a b )x  + 20A a c + A a b  - 12B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                            2  3         3          2  2  8
+--R           ((52A a b - 24B a )c  + (- A b  - 18B a b )c )x
+--R         + 
+--R                     2        2   2          4          3    6
+--R           ((104A a b  - 48B a b)c  + (- 2A b  - 36B a b )c)x
+--R         + 
+--R                   2         3  2           3        2 2        5          4  4
+--R           ((104A a b - 48B a )c  + (50A a b  - 60B a b )c - A b  - 18B a b )x
+--R         + 
+--R                   2 2        3            4        2 3  2         3         4
+--R           ((104A a b  - 48B a b)c - 2A a b  - 36B a b )x  + (52A a b - 24B a )c
+--R         + 
+--R                2 3        3 2
+--R           - A a b  - 18B a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                   3       2            2  7
+--R           (20A a c  + (A b  - 12B a b)c )x
+--R         + 
+--R                           2  2        3          2    5
+--R           ((28A a b + 4B a )c  + (2A b  - 19B a b )c)x
+--R         + 
+--R                 2 2          2        2         4         3  3
+--R           (36A a c  + (5A a b  - 16B a b)c + A b  - 5B a b )x
+--R         + 
+--R                  2         3          3       2 2
+--R           ((16A a b - 12B a )c - A a b  - 3B a b )x
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              3 4      2 2 3       4 2  8        3   3       2 3 2        5   6
+--R         (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R              4 3      2 4        6  4        4   2       3 3       2 5  2
+--R         (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             5 2      4 2      3 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1288
+
+--S 1289 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1289
+
+)clear all
+
+--S 1290 of 1718
+t0:=(A+B*x^2)/(a+b*x^2+c*x^4)^3
+--R 
+--R
+--R   (1)
+--R        2
+--R     B x  + A
+--R  /
+--R        3 12       2 10        2     2   8              3  6      2        2  4
+--R       c x   + 3b c x   + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1290
+
+--S 1291 of 1718
+r0:=-1/4*x*(a*b*B-A*(b^2-2*a*c)-(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+   (a+b*x^2+c*x^4)^2)+1/8*x*(a*b*B*(b^2+8*a*c)+A*(3*b^4-25*a*b^2*c+_
+   28*a^2*c^2)+c*(a*B*(b^2+20*a*c)+3*A*(b^3-8*a*b*c))*x^2)/(a^2*(b^2-_
+   4*a*c)^2*(a+b*x^2+c*x^4))+1/8*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(a*B*(b^2+20*a*c)+3*A*(b^3-8*a*b*c)+(a*b*B*(b^2-_
+   52*a*c)+3*A*(b^4-10*a*b^2*c+56*a^2*c^2))/sqrt(b^2-4*a*c))/(a^2*(b^2-_
+   4*a*c)^2*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/8*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(a*B*(b^2+20*a*c)+3*A*(b^3-8*a*b*c)+_
+   (-a*b*B*(b^2-52*a*c)-3*A*(b^4-10*a*b^2*c+56*a^2*c^2))/sqrt(b^2-4*a*c))/_
+   (a^2*(b^2-4*a*c)^2*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                  2  3        3        2  2  8
+--R               ((- 24A a b + 20B a )c  + (3A b  + B a b )c )x
+--R             + 
+--R                          2        2   2        4         3    6
+--R               ((- 48A a b  + 40B a b)c  + (6A b  + 2B a b )c)x
+--R             + 
+--R                           2         3  2             3        2 2         5
+--R                   (- 48A a b + 40B a )c  + (- 18A a b  + 22B a b )c + 3A b
+--R                 + 
+--R                        4
+--R                   B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        2 2        3            4       2 3  2
+--R               ((- 48A a b  + 40B a b)c + 6A a b  + 2B a b )x
+--R             + 
+--R                       3         4         2 3      3 2
+--R               (- 24A a b + 20B a )c + 3A a b  + B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                  2 4             2        2   3        4        3  2  8
+--R           (168A a c  + (- 30A a b  - 52B a b)c  + (3A b  + B a b )c )x
+--R         + 
+--R                  2   3             3         2 2  2        5         4    6
+--R           (336A a b c  + (- 60A a b  - 104B a b )c  + (6A b  + 2B a b )c)x
+--R         + 
+--R                     3 3          2 2         3   2             4        2 3
+--R               336A a c  + (108A a b  - 104B a b)c  + (- 24A a b  - 50B a b )c
+--R             + 
+--R                   6        5
+--R               3A b  + B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                  3   2           2 3         3 2           5       2 4  2
+--R           (336A a b c  + (- 60A a b  - 104B a b )c + 6A a b  + 2B a b )x
+--R         + 
+--R                 4 2           3 2        4          2 4      3 3
+--R           168A a c  + (- 30A a b  - 52B a b)c + 3A a b  + B a b
+--R      *
+--R              +------------------+
+--R              | +-----------+                   +-+ +-+
+--R          +-+ | |          2                  x\|2 \|c
+--R         \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                        |   |          2
+--R                                       \|- \|- 4a c + b   + b
+--R     + 
+--R                                  2  3        3        2  2  8
+--R               ((- 24A a b + 20B a )c  + (3A b  + B a b )c )x
+--R             + 
+--R                          2        2   2        4         3    6
+--R               ((- 48A a b  + 40B a b)c  + (6A b  + 2B a b )c)x
+--R             + 
+--R                           2         3  2             3        2 2         5
+--R                   (- 48A a b + 40B a )c  + (- 18A a b  + 22B a b )c + 3A b
+--R                 + 
+--R                        4
+--R                   B a b
+--R              *
+--R                  4
+--R                 x
+--R             + 
+--R                        2 2        3            4       2 3  2
+--R               ((- 48A a b  + 40B a b)c + 6A a b  + 2B a b )x
+--R             + 
+--R                       3         4         2 3      3 2
+--R               (- 24A a b + 20B a )c + 3A a b  + B a b
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                    2 4           2        2   3          4        3  2  8
+--R           (- 168A a c  + (30A a b  + 52B a b)c  + (- 3A b  - B a b )c )x
+--R         + 
+--R                    2   3           3         2 2  2          5         4    6
+--R           (- 336A a b c  + (60A a b  + 104B a b )c  + (- 6A b  - 2B a b )c)x
+--R         + 
+--R                       3 3            2 2         3   2           4        2 3
+--R               - 336A a c  + (- 108A a b  + 104B a b)c  + (24A a b  + 50B a b )c
+--R             + 
+--R                     6        5
+--R               - 3A b  - B a b
+--R          *
+--R              4
+--R             x
+--R         + 
+--R                    3   2         2 3         3 2           5       2 4  2
+--R           (- 336A a b c  + (60A a b  + 104B a b )c - 6A a b  - 2B a b )x
+--R         + 
+--R                   4 2         3 2        4          2 4      3 3
+--R           - 168A a c  + (30A a b  + 52B a b)c - 3A a b  - B a b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+                  +-+ +-+
+--R          +-+ |   |          2                 x\|2 \|c
+--R         \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R     + 
+--R                              2  3        3        2  2  7
+--R           ((- 24A a b + 20B a )c  + (3A b  + B a b )c )x
+--R         + 
+--R                 2 3             2        2   2        4         3    5
+--R           (28A a c  + (- 49A a b  + 28B a b)c  + (6A b  + 2B a b )c)x
+--R         + 
+--R                   2         3  2             3       2 2         5        4  3
+--R           ((- 4A a b + 36B a )c  + (- 20A a b  + 5B a b )c + 3A b  + B a b )x
+--R         + 
+--R                 3 2           2 2        3            4      2 3
+--R           (44A a c  + (- 37A a b  + 16B a b)c + 5A a b  - B a b )x
+--R      *
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R              4 4      3 2 3     2 4 2  8        4   3       3 3 2      2 5   6
+--R         (128a c  - 64a b c  + 8a b c )x  + (256a b c  - 128a b c  + 16a b c)x
+--R       + 
+--R              5 3      3 4      2 6  4        5   2       4 3       3 5  2
+--R         (256a c  - 48a b c + 8a b )x  + (256a b c  - 128a b c + 16a b )x
+--R       + 
+--R             6 2      5 2      4 4
+--R         128a c  - 64a b c + 8a b
+--R    *
+--R                          +--------------------+ +------------------+
+--R            +-----------+ |   +-----------+      | +-----------+
+--R        +-+ |          2  |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1291
+
+--S 1292 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1292
+
+)clear all
+
+--S 1293 of 1718
+t0:=(3+x^2)/(1+3*x^2+x^4)
+--R 
+--R
+--R            2
+--R           x  + 3
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1293
+
+--S 1294 of 1718
+r0:=1/2*atan(x*sqrt(1/2*(3+sqrt(5))))*(3+sqrt(5))^(3/2)/sqrt(10)-_
+   atan(x*sqrt(2/(3+sqrt(5))))*sqrt(1/5*(9-4*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                    +--------+
+--R                   +--------+       | +-+
+--R          +-+      | +-+          x\|\|5  + 3
+--R       (3\|5  + 5)\|\|5  + 3 atan(------------)
+--R                                       +-+
+--R                                      \|2
+--R     + 
+--R                                    +----------+
+--R                +-----------+       |   +-+
+--R           +--+ |    +-+          x\|- \|5  + 3
+--R       - 2\|10 \|- 4\|5  + 9 atan(--------------)
+--R                                        +-+
+--R                                       \|2
+--R  /
+--R       +-+ +--+
+--R     2\|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 1294
+
+--S 1295 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                     +-----------+ +----------+
+--R           2      +-+ +-+     2 +-+  |    +-+      |   +-+
+--R       ((3x  + 2)\|2 \|5  + 5x \|2 )\|- 4\|5  + 9 \|- \|5  + 3
+--R     + 
+--R            2      +-+ +-+        2      +-+  +--+      2
+--R       ((- x  - 3)\|2 \|5  + (- 3x  - 7)\|2 )\|10  + 20x  + 60
+--R  /
+--R        4      2
+--R     20x  + 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 1295
+
+)clear all
+
+--S 1296 of 1718
+t0:=(a+b*x^2)/(1+x^2+x^4)
+--R 
+--R
+--R             2
+--R          b x  + a
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1296
+
+--S 1297 of 1718
+r0:=-1/4*(a-b)*log(1-x+x^2)+1/4*(a-b)*log(1+x+x^2)-_
+   1/2*(a+b)*atan((1-2*x)/sqrt(3))/sqrt(3)+1/2*(a+b)*atan((1+2*x)/_
+   sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                 +-+     2                    +-+     2
+--R       (- b + a)\|3 log(x  + x + 1) + (b - a)\|3 log(x  - x + 1)
+--R     + 
+--R                              +-+                           +-+
+--R                     (2x + 1)\|3                   (2x - 1)\|3
+--R       (2b + 2a)atan(------------) + (2b + 2a)atan(------------)
+--R                           3                             3
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 1297
+
+--S 1298 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1298
+
+)clear all
+
+--S 1299 of 1718
+t0:=(a+b*x^2)/(1+x^2+x^4)^2
+--R 
+--R
+--R                   2
+--R                b x  + a
+--R   (1)  ------------------------
+--R         8     6     4     2
+--R        x  + 2x  + 3x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1299
+
+--S 1300 of 1718
+r0:=1/6*x*(a+b-(a-2*b)*x^2)/(1+x^2+x^4)-1/8*(2*a-b)*log(1-x+x^2)+_
+   1/8*(2*a-b)*log(1+x+x^2)-1/12*(4*a+b)*atan((1-2*x)/sqrt(3))/sqrt(3)+_
+   1/12*(4*a+b)*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                    4               2            +-+     2
+--R       ((- 3b + 6a)x  + (- 3b + 6a)x  - 3b + 6a)\|3 log(x  + x + 1)
+--R     + 
+--R                  4             2            +-+     2
+--R       ((3b - 6a)x  + (3b - 6a)x  + 3b - 6a)\|3 log(x  - x + 1)
+--R     + 
+--R                                                          +-+
+--R                  4             2                (2x + 1)\|3
+--R       ((2b + 8a)x  + (2b + 8a)x  + 2b + 8a)atan(------------)
+--R                                                       3
+--R     + 
+--R                                                          +-+
+--R                  4             2                (2x - 1)\|3
+--R       ((2b + 8a)x  + (2b + 8a)x  + 2b + 8a)atan(------------)
+--R                                                       3
+--R     + 
+--R                  3               +-+
+--R       ((8b - 4a)x  + (4b + 4a)x)\|3
+--R  /
+--R         4      2       +-+
+--R     (24x  + 24x  + 24)\|3
+--R                                                    Type: Expression(Integer)
+--E 1300
+
+--S 1301 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1301
+
+)clear all
+
+--S 1302 of 1718
+t0:=(a+b*x^2)/(2+x^2+x^4)
+--R 
+--R
+--R             2
+--R          b x  + a
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1302
+
+--S 1303 of 1718
+r0:=-1/4*log(x^2+sqrt(2)-x*sqrt(-1+2*sqrt(2)))*(a-b*sqrt(2))*sqrt(1/14*_
+   (1+2*sqrt(2)))+1/4*log(x^2+sqrt(2)+x*sqrt(-1+2*sqrt(2)))*(a-b*sqrt(2))*_
+   sqrt(1/14*(1+2*sqrt(2)))-1/2*atan((-2*x+sqrt(-1+2*sqrt(2)))/sqrt(1+_
+   2*sqrt(2)))*(a+b*sqrt(2))/sqrt(2*(1+2*sqrt(2)))+1/2*atan((2*x+sqrt(-1+_
+   2*sqrt(2)))/sqrt(1+2*sqrt(2)))*(a+b*sqrt(2))/sqrt(2*(1+2*sqrt(2)))
+--R 
+--R
+--R   (2)
+--R                     +---------+ +---------+      +---------+
+--R            +-+      |  +-+      |  +-+           |  +-+         +-+    2
+--R       (- b\|2  + a)\|2\|2  + 1 \|4\|2  + 2 log(x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R                   +---------+ +---------+        +---------+
+--R          +-+      |  +-+      |  +-+             |  +-+         +-+    2
+--R       (b\|2  - a)\|2\|2  + 1 \|4\|2  + 2 log(- x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R             +-+       +--+
+--R         (2b\|2  + 2a)\|14
+--R      *
+--R                           +---------+                +---------+
+--R                  +-+      |  +-+           +-+       |  +-+
+--R              ((2\|2  - 1)\|2\|2  - 1  + 4x\|2  - 2x)\|2\|2  + 1
+--R         atan(---------------------------------------------------)
+--R                                       7
+--R     + 
+--R               +-+       +--+
+--R         (- 2b\|2  - 2a)\|14
+--R      *
+--R                           +---------+                +---------+
+--R                  +-+      |  +-+           +-+       |  +-+
+--R              ((2\|2  - 1)\|2\|2  - 1  - 4x\|2  + 2x)\|2\|2  + 1
+--R         atan(---------------------------------------------------)
+--R                                       7
+--R  /
+--R            +---------+
+--R       +--+ |  +-+
+--R     4\|14 \|4\|2  + 2
+--R                                                    Type: Expression(Integer)
+--E 1303
+
+--S 1304 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                                  +---------+
+--R                       2            +-+             2             |  +-+
+--R         (((- 9b + 4a)x  + 8b - 9a)\|2  + (8b - 9a)x  - 18b + 8a)\|2\|2  + 1
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|4\|2  + 2
+--R     + 
+--R                                                                   +---------+
+--R                    2           +-+              2            +--+ |  +-+
+--R         (((b + 2a)x  + 4b + a)\|2  + (- 4b - a)x  - 2b - 4a)\|14 \|2\|2  - 1
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|2  + 1
+--R     + 
+--R             2        +-+        2
+--R       (56b x  + 56a)\|2  - 28b x  - 28a
+--R  /
+--R         4      2        +-+      4      2
+--R     (56x  + 56x  + 112)\|2  - 28x  - 28x  - 56
+--R                                                    Type: Expression(Integer)
+--E 1304
+
+)clear all
+
+--S 1305 of 1718
+t0:=(a+b*x^2)/(2+x^2+x^4)^2
+--R 
+--R
+--R                   2
+--R                b x  + a
+--R   (1)  ------------------------
+--R         8     6     4     2
+--R        x  + 2x  + 5x  + 4x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1305
+
+--S 1306 of 1718
+r0:=1/28*x*(3*a+2*b-(a-4*b)*x^2)/(2+x^2+x^4)-1/112*log(x^2+sqrt(2)-_
+   x*sqrt(-1+2*sqrt(2)))*(a*(11+sqrt(2))-2*(b+2*b*sqrt(2)))*sqrt(1/14*(1+_
+   2*sqrt(2)))+1/112*log(x^2+sqrt(2)+x*sqrt(-1+2*sqrt(2)))*(a*(11+sqrt(2))-_
+   2*(b+2*b*sqrt(2)))*sqrt(1/14*(1+2*sqrt(2)))-1/56*atan((-2*x+sqrt(-1+_
+   2*sqrt(2)))/sqrt(1+2*sqrt(2)))*(11*a-2*b-(a-4*b)*sqrt(2))/sqrt(2*(1+_
+   2*sqrt(2)))+1/56*atan((2*x+sqrt(-1+2*sqrt(2)))/sqrt(1+2*sqrt(2)))*_
+   (11*a-2*b-(a-4*b)*sqrt(2))/sqrt(2*(1+2*sqrt(2)))
+--R 
+--R
+--R   (2)
+--R                       4              2            +-+                4
+--R           ((- 4b + a)x  + (- 4b + a)x  - 8b + 2a)\|2  + (- 2b + 11a)x
+--R         + 
+--R                        2
+--R           (- 2b + 11a)x  - 4b + 22a
+--R      *
+--R          +---------+ +---------+      +---------+
+--R          |  +-+      |  +-+           |  +-+         +-+    2
+--R         \|2\|2  + 1 \|4\|2  + 2 log(x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R                     4            2            +-+              4              2
+--R           ((4b - a)x  + (4b - a)x  + 8b - 2a)\|2  + (2b - 11a)x  + (2b - 11a)x
+--R         + 
+--R           4b - 22a
+--R      *
+--R          +---------+ +---------+        +---------+
+--R          |  +-+      |  +-+             |  +-+         +-+    2
+--R         \|2\|2  + 1 \|4\|2  + 2 log(- x\|2\|2  - 1  + \|2  + x )
+--R     + 
+--R                      4             2             +-+                4
+--R           ((8b - 2a)x  + (8b - 2a)x  + 16b - 4a)\|2  + (- 4b + 22a)x
+--R         + 
+--R                        2
+--R           (- 4b + 22a)x  - 8b + 44a
+--R      *
+--R                                +---------+                +---------+
+--R                       +-+      |  +-+           +-+       |  +-+
+--R          +--+     ((2\|2  - 1)\|2\|2  - 1  + 4x\|2  - 2x)\|2\|2  + 1
+--R         \|14 atan(---------------------------------------------------)
+--R                                            7
+--R     + 
+--R                        4               2             +-+              4
+--R           ((- 8b + 2a)x  + (- 8b + 2a)x  - 16b + 4a)\|2  + (4b - 22a)x
+--R         + 
+--R                      2
+--R           (4b - 22a)x  + 8b - 44a
+--R      *
+--R                                +---------+                +---------+
+--R                       +-+      |  +-+           +-+       |  +-+
+--R          +--+     ((2\|2  - 1)\|2\|2  - 1  - 4x\|2  + 2x)\|2\|2  + 1
+--R         \|14 atan(---------------------------------------------------)
+--R                                            7
+--R     + 
+--R                                         +---------+
+--R                   3                +--+ |  +-+
+--R       ((16b - 4a)x  + (8b + 12a)x)\|14 \|4\|2  + 2
+--R  /
+--R                                +---------+
+--R          4       2        +--+ |  +-+
+--R     (112x  + 112x  + 224)\|14 \|4\|2  + 2
+--R                                                    Type: Expression(Integer)
+--E 1306
+
+--S 1307 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                         2               +-+                2
+--R         (((- 44b + 53a)x  + 50b - 107a)\|2  + (50b - 107a)x  - 88b + 106a)
+--R      *
+--R          +---------+ +---------+
+--R          |  +-+      |  +-+
+--R         \|2\|2  + 1 \|4\|2  + 2
+--R     + 
+--R                                                               +---------+
+--R                2             +-+                2        +--+ |  +-+
+--R         ((21a x  + 14b + 7a)\|2  + (- 14b - 7a)x  - 42a)\|14 \|2\|2  - 1
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|2  + 1
+--R     + 
+--R                     2                +-+                  2
+--R       ((224b - 56a)x  - 112b + 616a)\|2  + (- 112b + 28a)x  + 56b - 308a
+--R  /
+--R           4        2         +-+       4       2
+--R     (1568x  + 1568x  + 3136)\|2  - 784x  - 784x  - 1568
+--R                                                    Type: Expression(Integer)
+--E 1307
+
+)clear all
+
+--S 1308 of 1718
+t0:=(-x^2+sqrt(2))/(1+x^4-x^2*sqrt(2))
+--R 
+--R
+--R             2    +-+
+--R          - x  + \|2
+--R   (1)  ---------------
+--R         4    +-+ 2
+--R        x  - \|2 x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 1308
+
+--S 1309 of 1718
+r0:=-1/2*atan((-2*x+sqrt(2+sqrt(2)))/sqrt(2-sqrt(2)))*sqrt(1+(-1)/sqrt(2))+_
+   1/2*atan((2*x+sqrt(2+sqrt(2)))/sqrt(2-sqrt(2)))*sqrt(1+(-1)/sqrt(2))-_
+   1/4*log(1+x^2-x*sqrt(2+sqrt(2)))*sqrt(1+1/sqrt(2))+1/4*log(1+x^2+_
+   x*sqrt(2+sqrt(2)))*sqrt(1+1/sqrt(2))
+--R 
+--R
+--R   (2)
+--R        +--------+      +--------+
+--R        | +-+           | +-+         2
+--R       \|\|2  + 2 log(x\|\|2  + 2  + x  + 1)
+--R     + 
+--R          +--------+        +--------+
+--R          | +-+             | +-+         2
+--R       - \|\|2  + 2 log(- x\|\|2  + 2  + x  + 1)
+--R     + 
+--R           +----------+
+--R           |   +-+
+--R         2\|- \|2  + 2
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R              (\|2  + 2)\|- \|2  + 2 \|\|2  + 2  + (2x\|2  + 4x)\|- \|2  + 2
+--R         atan(---------------------------------------------------------------)
+--R                                             2
+--R     + 
+--R       -
+--R              +----------+
+--R              |   +-+
+--R            2\|- \|2  + 2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|2  + 2)\|- \|2  + 2 \|\|2  + 2  + (- 2x\|2  - 4x)\|- \|2  + 2
+--R               -----------------------------------------------------------------
+--R                                               2
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 1309
+
+--S 1310 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1310
+
+)clear all
+
+--S 1311 of 1718
+t0:=(x^2+sqrt(2))/(1+x^4+x^2*sqrt(2))
+--R 
+--R
+--R            2    +-+
+--R           x  + \|2
+--R   (1)  ---------------
+--R         4    +-+ 2
+--R        x  + \|2 x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 1311
+
+--S 1312 of 1718
+r0:=-1/4*log(1+x^2-x*sqrt(2-sqrt(2)))*sqrt(1+(-1)/sqrt(2))+1/4*log(1+x^2+_
+   x*sqrt(2-sqrt(2)))*sqrt(1+(-1)/sqrt(2))-1/2*atan((-2*x+sqrt(2-sqrt(2)))/_
+   sqrt(2+sqrt(2)))*sqrt(1+1/sqrt(2))+1/2*atan((2*x+sqrt(2-sqrt(2)))/_
+   sqrt(2+sqrt(2)))*sqrt(1+1/sqrt(2))
+--R 
+--R
+--R   (2)
+--R        +----------+      +----------+
+--R        |   +-+           |   +-+         2
+--R       \|- \|2  + 2 log(x\|- \|2  + 2  + x  + 1)
+--R     + 
+--R          +----------+        +----------+
+--R          |   +-+             |   +-+         2
+--R       - \|- \|2  + 2 log(- x\|- \|2  + 2  + x  + 1)
+--R     + 
+--R                                      +----------+                +--------+
+--R           +--------+        +-+      |   +-+           +-+       | +-+
+--R           | +-+          ((\|2  - 2)\|- \|2  + 2  + 2x\|2  - 4x)\|\|2  + 2
+--R       - 2\|\|2  + 2 atan(--------------------------------------------------)
+--R                                                   2
+--R     + 
+--R                                    +----------+                +--------+
+--R         +--------+        +-+      |   +-+           +-+       | +-+
+--R         | +-+          ((\|2  - 2)\|- \|2  + 2  - 2x\|2  + 4x)\|\|2  + 2
+--R       2\|\|2  + 2 atan(--------------------------------------------------)
+--R                                                 2
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 1312
+
+--S 1313 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1313
+
+)clear all
+
+--S 1314 of 1718
+t0:=(-x^2+sqrt(2))/(1+b*x^2+x^4)
+--R 
+--R
+--R            2    +-+
+--R         - x  + \|2
+--R   (1)  -------------
+--R         4      2
+--R        x  + b x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 1314
+
+--S 1315 of 1718
+r0:=-atan(x*sqrt(2)/sqrt(b-sqrt(-4+b^2)))*(1+(-b-2*sqrt(2))/sqrt(-4+b^2))/_
+   (sqrt(2)*sqrt(b-sqrt(-4+b^2)))-atan(x*sqrt(2)/sqrt(b+sqrt(-4+b^2)))*_
+   (1+(b+2*sqrt(2))/sqrt(-4+b^2))/(sqrt(2)*sqrt(b+sqrt(-4+b^2)))
+--R 
+--R
+--R   (2)
+--R                                 +-------------+
+--R           +------+              | +------+                   +-+
+--R           | 2          +-+      | | 2                      x\|2
+--R       (- \|b  - 4  + 2\|2  + b)\|\|b  - 4  + b atan(------------------)
+--R                                                      +---------------+
+--R                                                      |   +------+
+--R                                                      |   | 2
+--R                                                     \|- \|b  - 4  + b
+--R     + 
+--R                                 +---------------+
+--R           +------+              |   +------+                  +-+
+--R           | 2          +-+      |   | 2                     x\|2
+--R       (- \|b  - 4  - 2\|2  - b)\|- \|b  - 4  + b atan(----------------)
+--R                                                        +-------------+
+--R                                                        | +------+
+--R                                                        | | 2
+--R                                                       \|\|b  - 4  + b
+--R  /
+--R                   +---------------+ +-------------+
+--R          +------+ |   +------+      | +------+
+--R      +-+ | 2      |   | 2           | | 2
+--R     \|2 \|b  - 4 \|- \|b  - 4  + b \|\|b  - 4  + b
+--R                                                    Type: Expression(Integer)
+--E 1315
+
+--S 1316 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1316
+
+)clear all
+
+--S 1317 of 1718
+t0:=(x^2+sqrt(2))/(1+b*x^2+x^4)
+--R 
+--R
+--R           2    +-+
+--R          x  + \|2
+--R   (1)  -------------
+--R         4      2
+--R        x  + b x  + 1
+--R                                  Type: Fraction(Polynomial(AlgebraicNumber))
+--E 1317
+
+--S 1318 of 1718
+r0:=atan(x*sqrt(2)/sqrt(b-sqrt(-4+b^2)))*(1+(-b+2*sqrt(2))/sqrt(-4+b^2))/_
+   (sqrt(2)*sqrt(b-sqrt(-4+b^2)))+atan(x*sqrt(2)/sqrt(b+sqrt(-4+b^2)))*_
+   (1+(b-2*sqrt(2))/sqrt(-4+b^2))/(sqrt(2)*sqrt(b+sqrt(-4+b^2)))
+--R 
+--R
+--R   (2)
+--R                               +-------------+
+--R         +------+              | +------+                   +-+
+--R         | 2          +-+      | | 2                      x\|2
+--R       (\|b  - 4  + 2\|2  - b)\|\|b  - 4  + b atan(------------------)
+--R                                                    +---------------+
+--R                                                    |   +------+
+--R                                                    |   | 2
+--R                                                   \|- \|b  - 4  + b
+--R     + 
+--R                               +---------------+
+--R         +------+              |   +------+                  +-+
+--R         | 2          +-+      |   | 2                     x\|2
+--R       (\|b  - 4  - 2\|2  + b)\|- \|b  - 4  + b atan(----------------)
+--R                                                      +-------------+
+--R                                                      | +------+
+--R                                                      | | 2
+--R                                                     \|\|b  - 4  + b
+--R  /
+--R                   +---------------+ +-------------+
+--R          +------+ |   +------+      | +------+
+--R      +-+ | 2      |   | 2           | | 2
+--R     \|2 \|b  - 4 \|- \|b  - 4  + b \|\|b  - 4  + b
+--R                                                    Type: Expression(Integer)
+--E 1318
+
+--S 1319 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1319
+
+)clear all
+
+--S 1320 of 1718
+t0:=(2*a-x^2)/(a^2-a*x^2+x^4)
+--R 
+--R
+--R              2
+--R           - x  + 2a
+--R   (1)  --------------
+--R         4      2    2
+--R        x  - a x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1320
+
+--S 1321 of 1718
+r0:=atanh(x*sqrt(2)/sqrt(a-sqrt(3)*sqrt(-a^2)))*sqrt(a-sqrt(3)*sqrt(-a^2))/_
+   (a*sqrt(2))+atanh(x*sqrt(2)/sqrt(a+sqrt(3)*sqrt(-a^2)))*sqrt(a+sqrt(3)*_
+   sqrt(-a^2))/(a*sqrt(2))
+--R 
+--R
+--R   (2)
+--R        +-----------------+
+--R        |       +----+                     +-+
+--R        |   +-+ |   2                    x\|2
+--R       \|- \|3 \|- a   + a atanh(--------------------)
+--R                                  +-----------------+
+--R                                  |       +----+
+--R                                  |   +-+ |   2
+--R                                 \|- \|3 \|- a   + a
+--R     + 
+--R        +---------------+
+--R        |     +----+                    +-+
+--R        | +-+ |   2                   x\|2
+--R       \|\|3 \|- a   + a atanh(------------------)
+--R                                +---------------+
+--R                                |     +----+
+--R                                | +-+ |   2
+--R                               \|\|3 \|- a   + a
+--R  /
+--R       +-+
+--R     a\|2
+--R                                                    Type: Expression(Integer)
+--E 1321
+
+--S 1322 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1322
+
+)clear all
+
+--S 1323 of 1718
+t0:=(-x^2+2*sqrt(a))/(a+x^4-x^2*sqrt(a))
+--R 
+--R
+--R              +-+    2
+--R          - 2\|a  + x
+--R   (1)  ---------------
+--R         2 +-+    4
+--R        x \|a  - x  - a
+--R                                                    Type: Expression(Integer)
+--E 1323
+
+--S 1324 of 1718
+r0:=atan(x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)-sqrt(a)))*sqrt(sqrt(3)*sqrt(-a)-_
+   sqrt(a))/(sqrt(2)*sqrt(a))+atanh(x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)+_
+   sqrt(a)))*sqrt(sqrt(3)*sqrt(-a)+sqrt(a))/(sqrt(2)*sqrt(a))
+--R 
+--R
+--R   (2)
+--R        +-----------------+                +-+
+--R        | +-+    +-+ +---+               x\|2
+--R       \|\|a  + \|3 \|- a  atanh(--------------------)
+--R                                  +-----------------+
+--R                                  | +-+    +-+ +---+
+--R                                 \|\|a  + \|3 \|- a
+--R     + 
+--R        +-------------------+                +-+
+--R        |   +-+    +-+ +---+               x\|2
+--R       \|- \|a  + \|3 \|- a  atan(----------------------)
+--R                                   +-------------------+
+--R                                   |   +-+    +-+ +---+
+--R                                  \|- \|a  + \|3 \|- a
+--R  /
+--R      +-+ +-+
+--R     \|2 \|a
+--R                                                    Type: Expression(Integer)
+--E 1324
+
+--S 1325 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1325
+
+)clear all
+
+--S 1326 of 1718
+t0:=(A+B*x^2)/(a^2-a*x^2+x^4)
+--R 
+--R
+--R              2
+--R           B x  + A
+--R   (1)  --------------
+--R         4      2    2
+--R        x  - a x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1326
+
+--S 1327 of 1718
+r0:=-atanh(x*sqrt(2)/sqrt(a-sqrt(3)*sqrt(-a^2)))*(B*sqrt(3)+(-2*A-a*B)/_
+   sqrt(-a^2))/(sqrt(6)*sqrt(a-sqrt(3)*sqrt(-a^2)))-atanh(x*sqrt(2)/_
+   sqrt(a+sqrt(3)*sqrt(-a^2)))*(B*sqrt(3)+(2*A+a*B)/sqrt(-a^2))/(sqrt(6)*_
+   sqrt(a+sqrt(3)*sqrt(-a^2)))
+--R 
+--R
+--R   (2)
+--R                                   +---------------+
+--R                +----+             |     +----+                     +-+
+--R            +-+ |   2              | +-+ |   2                    x\|2
+--R       (- B\|3 \|- a   + B a + 2A)\|\|3 \|- a   + a atanh(--------------------)
+--R                                                           +-----------------+
+--R                                                           |       +----+
+--R                                                           |   +-+ |   2
+--R                                                          \|- \|3 \|- a   + a
+--R     + 
+--R                                   +-----------------+
+--R                +----+             |       +----+                    +-+
+--R            +-+ |   2              |   +-+ |   2                   x\|2
+--R       (- B\|3 \|- a   - B a - 2A)\|- \|3 \|- a   + a atanh(------------------)
+--R                                                             +---------------+
+--R                                                             |     +----+
+--R                                                             | +-+ |   2
+--R                                                            \|\|3 \|- a   + a
+--R  /
+--R                 +-----------------+ +---------------+
+--R          +----+ |       +----+      |     +----+
+--R      +-+ |   2  |   +-+ |   2       | +-+ |   2
+--R     \|6 \|- a  \|- \|3 \|- a   + a \|\|3 \|- a   + a
+--R                                                    Type: Expression(Integer)
+--E 1327
+
+--S 1328 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              2      +-+ +-+ +-+       2
+--R        (- B x  - A)\|2 \|3 \|6  + 6B x  + 6A
+--R   (3)  -------------------------------------
+--R                    4       2     2
+--R                  6x  - 6a x  + 6a
+--R                                                    Type: Expression(Integer)
+--E 1328
+
+)clear all
+
+--S 1329 of 1718
+t0:=(A+B*x^2)/(a+x^4-x^2*sqrt(a))
+--R 
+--R
+--R                2
+--R           - B x  - A
+--R   (1)  ---------------
+--R         2 +-+    4
+--R        x \|a  - x  - a
+--R                                                    Type: Expression(Integer)
+--E 1329
+
+--S 1330 of 1718
+r0:=atan(x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)-sqrt(a)))*(B*sqrt(3)+_
+   (-2*A-B*sqrt(a))/sqrt(-a))/(sqrt(6)*sqrt(sqrt(3)*sqrt(-a)-sqrt(a)))-_
+   atanh(x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)+sqrt(a)))*(B*sqrt(3)+_
+   (2*A+B*sqrt(a))/sqrt(-a))/(sqrt(6)*sqrt(sqrt(3)*sqrt(-a)+sqrt(a)))
+--R 
+--R
+--R   (2)
+--R                                      +-------------------+
+--R              +-+     +-+ +---+       |   +-+    +-+ +---+
+--R         (- B\|a  - B\|3 \|- a  - 2A)\|- \|a  + \|3 \|- a
+--R      *
+--R                         +-+
+--R                       x\|2
+--R         atanh(--------------------)
+--R                +-----------------+
+--R                | +-+    +-+ +---+
+--R               \|\|a  + \|3 \|- a
+--R     + 
+--R                                      +-----------------+
+--R              +-+     +-+ +---+       | +-+    +-+ +---+
+--R         (- B\|a  + B\|3 \|- a  - 2A)\|\|a  + \|3 \|- a
+--R      *
+--R                         +-+
+--R                       x\|2
+--R         atan(----------------------)
+--R               +-------------------+
+--R               |   +-+    +-+ +---+
+--R              \|- \|a  + \|3 \|- a
+--R  /
+--R                +-------------------+ +-----------------+
+--R      +-+ +---+ |   +-+    +-+ +---+  | +-+    +-+ +---+
+--R     \|6 \|- a \|- \|a  + \|3 \|- a  \|\|a  + \|3 \|- a
+--R                                                    Type: Expression(Integer)
+--E 1330
+
+--S 1331 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R            2      +-+ +-+ +-+       2
+--R        (B x  + A)\|2 \|3 \|6  - 6B x  - 6A
+--R   (3)  -----------------------------------
+--R                   2 +-+     4
+--R                 6x \|a  - 6x  - 6a
+--R                                                    Type: Expression(Integer)
+--E 1331
+
+)clear all
+
+--S 1332 of 1718
+t0:=(A+B*x^2)/(a+c*x^4-x^2*sqrt(a*c))
+--R 
+--R
+--R                  2
+--R             - B x  - A
+--R   (1)  -------------------
+--R         2 +---+      4
+--R        x \|a c  - c x  - a
+--R                                                    Type: Expression(Integer)
+--E 1332
+
+--S 1333 of 1718
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(sqrt(3)*sqrt(-a)*sqrt(c)-sqrt(a*c)))*_
+   (B*sqrt(3)+a*(2*A*c+B*sqrt(a*c))/((-a)^(3/2)*sqrt(c)))/(sqrt(6)*sqrt(c)*_
+   sqrt(sqrt(3)*sqrt(-a)*sqrt(c)-sqrt(a*c)))-atanh(x*sqrt(2)*sqrt(c)/_
+   sqrt(sqrt(3)*sqrt(-a)*sqrt(c)+sqrt(a*c)))*(B*sqrt(3)+(2*A*c+_
+   B*sqrt(a*c))/(sqrt(-a)*sqrt(c)))/(sqrt(6)*sqrt(c)*sqrt(sqrt(3)*_
+   sqrt(-a)*sqrt(c)+sqrt(a*c)))
+--R 
+--R
+--R   (2)
+--R                                              +-------------------------+
+--R              +---+     +-+ +---+ +-+         |   +---+    +-+ +---+ +-+
+--R         (- B\|a c  - B\|3 \|- a \|c  - 2A c)\|- \|a c  + \|3 \|- a \|c
+--R      *
+--R                          +-+ +-+
+--R                        x\|2 \|c
+--R         atanh(--------------------------)
+--R                +-----------------------+
+--R                | +---+    +-+ +---+ +-+
+--R               \|\|a c  + \|3 \|- a \|c
+--R     + 
+--R                                              +-----------------------+
+--R              +---+     +-+ +---+ +-+         | +---+    +-+ +---+ +-+
+--R         (- B\|a c  + B\|3 \|- a \|c  - 2A c)\|\|a c  + \|3 \|- a \|c
+--R      *
+--R                          +-+ +-+
+--R                        x\|2 \|c
+--R         atan(----------------------------)
+--R               +-------------------------+
+--R               |   +---+    +-+ +---+ +-+
+--R              \|- \|a c  + \|3 \|- a \|c
+--R  /
+--R                 +-------------------------+ +-----------------------+
+--R       +-+ +---+ |   +---+    +-+ +---+ +-+  | +---+    +-+ +---+ +-+
+--R     c\|6 \|- a \|- \|a c  + \|3 \|- a \|c  \|\|a c  + \|3 \|- a \|c
+--R                                                    Type: Expression(Integer)
+--E 1333
+
+--S 1334 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R            2      +-+ +-+ +-+       2
+--R        (B x  + A)\|2 \|3 \|6  - 6B x  - 6A
+--R   (3)  -----------------------------------
+--R                 2 +---+       4
+--R               6x \|a c  - 6c x  - 6a
+--R                                                    Type: Expression(Integer)
+--E 1334
+
+)clear all
+
+--S 1335 of 1718
+t0:=(A+B*x^2)/(a+c*x^4-x^2*sqrt(a)*sqrt(c))
+--R 
+--R
+--R                   2
+--R              - B x  - A
+--R   (1)  ---------------------
+--R         2 +-+ +-+      4
+--R        x \|a \|c  - c x  - a
+--R                                                    Type: Expression(Integer)
+--E 1335
+
+--S 1336 of 1718
+r0:=atan(c^(1/4)*x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)-sqrt(a)))*(B*sqrt(3)+_
+   (-B*sqrt(a)-2*A*sqrt(c))/sqrt(-a))/(c^(3/4)*sqrt(6)*sqrt(sqrt(3)*_
+   sqrt(-a)-sqrt(a)))-atanh(c^(1/4)*x*sqrt(2)/sqrt(sqrt(3)*sqrt(-a)+_
+   sqrt(a)))*(B*sqrt(3)+(B*sqrt(a)+2*A*sqrt(c))/sqrt(-a))/(c^(3/4)*_
+   sqrt(6)*sqrt(sqrt(3)*sqrt(-a)+sqrt(a)))
+--R 
+--R
+--R   (2)
+--R                                          +-------------------+
+--R               +-+     +-+     +-+ +---+  |   +-+    +-+ +---+
+--R         (- 2A\|c  - B\|a  - B\|3 \|- a )\|- \|a  + \|3 \|- a
+--R      *
+--R                       +-+4+-+
+--R                     x\|2 \|c
+--R         atanh(--------------------)
+--R                +-----------------+
+--R                | +-+    +-+ +---+
+--R               \|\|a  + \|3 \|- a
+--R     + 
+--R                                          +-----------------+
+--R               +-+     +-+     +-+ +---+  | +-+    +-+ +---+
+--R         (- 2A\|c  - B\|a  + B\|3 \|- a )\|\|a  + \|3 \|- a
+--R      *
+--R                       +-+4+-+
+--R                     x\|2 \|c
+--R         atan(----------------------)
+--R               +-------------------+
+--R               |   +-+    +-+ +---+
+--R              \|- \|a  + \|3 \|- a
+--R  /
+--R                     +-------------------+ +-----------------+
+--R      +-+ +---+4+-+3 |   +-+    +-+ +---+  | +-+    +-+ +---+
+--R     \|6 \|- a \|c  \|- \|a  + \|3 \|- a  \|\|a  + \|3 \|- a
+--R                                                    Type: Expression(Integer)
+--E 1336
+
+--S 1337 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                   6        4        2        +-+ +-+ +-+         6         4
+--R           (- B c x  - A c x  - B a x  - A a)\|2 \|3 \|6  + 6B c x  + 6A c x
+--R         + 
+--R                 2
+--R           6B a x  + 6A a
+--R      *
+--R         4+-+2
+--R         \|c
+--R     + 
+--R              4        2  +-+ +-+ +-+         4         2  +-+
+--R       ((B c x  + A c x )\|2 \|3 \|6  - 6B c x  - 6A c x )\|a
+--R  /
+--R        2 8          4     2 4+-+2         2 6          2  +-+
+--R     (6c x  + 18a c x  + 6a )\|c   + (- 12c x  - 12a c x )\|a
+--R                                                    Type: Expression(Integer)
+--E 1337
+
+)clear all
+
+--S 1338 of 1718
+t0:=x*(-7+4*x^2)/(4-5*x^2+x^4)
+--R 
+--R
+--R            3
+--R          4x  - 7x
+--R   (1)  ------------
+--R         4     2
+--R        x  - 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1338
+
+--S 1339 of 1718
+r0:=1/2*log(1-x^2)+3/2*log(4-x^2)
+--R 
+--R
+--R                2               2
+--R        3log(- x  + 4) + log(- x  + 1)
+--R   (2)  ------------------------------
+--R                       2
+--R                                                    Type: Expression(Integer)
+--E 1339
+
+--S 1340 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1340
+
+)clear all
+
+--S 1341 of 1718
+t0:=(-7*x+4*x^3)/(4-5*x^2+x^4)
+--R 
+--R
+--R            3
+--R          4x  - 7x
+--R   (1)  ------------
+--R         4     2
+--R        x  - 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1341
+
+--S 1342 of 1718
+r0:=1/2*log(1-x^2)+3/2*log(4-x^2)
+--R 
+--R
+--R                2               2
+--R        3log(- x  + 4) + log(- x  + 1)
+--R   (2)  ------------------------------
+--R                       2
+--R                                                    Type: Expression(Integer)
+--E 1342
+
+--S 1343 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1343
+
+)clear all
+
+--S 1344 of 1718
+t0:=x*(2+x^2)/(1+x^2+x^4)
+--R 
+--R
+--R           3
+--R          x  + 2x
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1344
+
+--S 1345 of 1718
+r0:=1/4*log(1+x^2+x^4)+1/2*atan((1+2*x^2)/sqrt(3))*sqrt(3)
+--R 
+--R
+--R                                        2      +-+
+--R             4    2          +-+     (2x  + 1)\|3
+--R        log(x  + x  + 1) + 2\|3 atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             4
+--R                                                    Type: Expression(Integer)
+--E 1345
+
+--S 1346 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1346
+
+)clear all
+
+--S 1347 of 1718
+t0:=(2*x+x^3)/(1+x^2+x^4)
+--R 
+--R
+--R           3
+--R          x  + 2x
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1347
+
+--S 1348 of 1718
+r0:=1/4*log(1+x^2+x^4)+1/2*atan((1+2*x^2)/sqrt(3))*sqrt(3)
+--R 
+--R
+--R                                        2      +-+
+--R             4    2          +-+     (2x  + 1)\|3
+--R        log(x  + x  + 1) + 2\|3 atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             4
+--R                                                    Type: Expression(Integer)
+--E 1348
+
+--S 1349 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1349
+
+)clear all
+
+--S 1350 of 1718
+t0:=(11*x+2*x^3)/(3+2*x^2+x^4)^2
+--R 
+--R
+--R                   3
+--R                 2x  + 11x
+--R   (1)  --------------------------
+--R         8     6      4      2
+--R        x  + 4x  + 10x  + 12x  + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1350
+
+--S 1351 of 1718
+r0:=1/8*(5+9*x^2)/(3+2*x^2+x^4)+9/8*atan((1+x^2)/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                2      +-+
+--R           4      2           (x  + 1)\|2        2      +-+
+--R        (9x  + 18x  + 27)atan(------------) + (9x  + 5)\|2
+--R                                    2
+--R   (2)  ---------------------------------------------------
+--R                          4      2       +-+
+--R                       (8x  + 16x  + 24)\|2
+--R                                                    Type: Expression(Integer)
+--E 1351
+
+--S 1352 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1352
+
+)clear all
+
+--S 1353 of 1718
+t0:=x^3*(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                                          +---------------+
+--R              9               7               5        3  |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + (A b + B a)x  + A a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1353
+
+--S 1354 of 1718
+r0:=1/384*(7*b^2*B-12*A*b*c-4*a*B*c)*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^3-_
+   1/120*(7*b*B-2*A*c)*(a+b*x^2+c*x^4)^(5/2)/c^2+1/12*(A+B*x^2)*(a+b*x^2+_
+   c*x^4)^(5/2)/c+1/2048*(b^2-4*a*c)^2*(7*b^2*B-12*A*b*c-4*a*B*c)*_
+   atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(9/2)-_
+   1/1024*(b^2-4*a*c)*(7*b^2*B-12*A*b*c-4*a*B*c)*(b+2*c*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/c^4
+--R 
+--R
+--R   (2)
+--R                     2          3  3             3          2 2  2
+--R           (- 2880A a b - 960B a )c  + (1440A a b  + 2160B a b )c
+--R         + 
+--R                    5           4           6
+--R           (- 180A b  - 900B a b )c + 105B b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                  5 10           5            4  8
+--R           2560B c x   + (3072A c  + 3328B b c )x
+--R         + 
+--R                                4        2 3  6
+--R           ((4224A b + 4480B a)c  + 96B b c )x
+--R         + 
+--R                     4          2             3         3 2  4
+--R           (6144A a c  + (192A b  + 576B a b)c  - 112B b c )x
+--R         + 
+--R                               2  3            3           2  2         4   2
+--R           ((1344A a b + 960B a )c  + (- 240A b  - 864B a b )c  + 140B b c)x
+--R         + 
+--R                  2 3               2          2   2          4            3
+--R           3072A a c  + (- 2400A a b  - 2592B a b)c  + (360A b  + 1520B a b )c
+--R         + 
+--R                   5
+--R           - 210B b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R           4 +-+
+--R     30720c \|c
+--R                                                    Type: Expression(Integer)
+--E 1354
+
+--S 1355 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1355
+
+)clear all
+
+--S 1356 of 1718
+t0:=x*(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                                         +---------------+
+--R              7               5               3          |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + (A b + B a)x  + A a x)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1356
+
+--S 1357 of 1718
+r0:=-1/32*(b*B-2*A*c)*(b+2*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c^2+_
+   1/10*B*(a+b*x^2+c*x^4)^(5/2)/c-3/512*(b^2-4*a*c)^2*(b*B-2*A*c)*_
+   atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(7/2)+_
+   3/256*(b^2-4*a*c)*(b*B-2*A*c)*(b+2*c*x^2)*sqrt(a+b*x^2+c*x^4)/c^3
+--R 
+--R
+--R   (2)
+--R                   2 3              2         2   2         4           3
+--R             480A a c  + (- 240A a b  - 240B a b)c  + (30A b  + 120B a b )c
+--R           + 
+--R                    5
+--R             - 15B b
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                 4 8          4           3  6
+--R           256B c x  + (320A c  + 352B b c )x
+--R         + 
+--R                              3        2 2  4
+--R           ((480A b + 512B a)c  + 16B b c )x
+--R         + 
+--R                    3         2             2        3   2
+--R           (800A a c  + (40A b  + 112B a b)c  - 20B b c)x
+--R         + 
+--R                             2  2           3           2          4
+--R           (400A a b + 256B a )c  + (- 60A b  - 200B a b )c + 30B b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R          3 +-+
+--R     2560c \|c
+--R                                                    Type: Expression(Integer)
+--E 1357
+
+--S 1358 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1358
+
+)clear all
+
+--S 1359 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        x
+--R                                                    Type: Expression(Integer)
+--E 1359
+
+--S 1360 of 1718
+r0:=1/48*(3*b*B+8*A*c+6*B*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c-1/2*a^(3/2)*A*_
+   atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))+1/256*(64*a*A*b*_
+   c^2+(b^2-4*a*c)*(3*b^2*B-8*A*b*c-12*a*B*c))*atanh(1/2*(b+2*c*x^2)/_
+   (sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(5/2)-1/128*(3*b^3*B-8*A*b^2*c-_
+   12*a*b*B*c-64*a*A*c^2+2*c*(3*b^2*B-8*A*b*c-12*a*B*c)*x^2)*sqrt(a+_
+   b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R                                          2
+--R                 2 +-+ +-+             b x  + 2a
+--R       - 384A a c \|a \|c atanh(-----------------------)
+--R                                      +---------------+
+--R                                  +-+ |   4      2
+--R                                2\|a \|c x  + b x  + a
+--R     + 
+--R                            2  2           3          2         4
+--R         ((288A a b + 144B a )c  + (- 24A b  - 72B a b )c + 9B b )
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                3 6          3           2  4
+--R           96B c x  + (128A c  + 144B b c )x
+--R         + 
+--R                              2        2   2           2         2
+--R           ((224A b + 240B a)c  + 12B b c)x  + 512A a c  + (48A b  + 120B a b)c
+--R         + 
+--R                  3
+--R           - 18B b
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R         2 +-+
+--R     768c \|c
+--R                                                    Type: Expression(Integer)
+--E 1360
+
+--S 1361 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1361
+
+)clear all
+
+--S 1362 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^3
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        3
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1362
+
+--S 1363 of 1718
+r0:=-1/6*(3*A-B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^2-1/32*(b^3*B-6*A*b^2*c-_
+   12*a*b*B*c-24*a*A*c^2)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+_
+   c*x^4)))/c^(3/2)-1/4*(3*A*b+2*a*B)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*_
+   sqrt(a+b*x^2+c*x^4)))*sqrt(a)+1/16*(b^2*B+18*A*b*c+8*a*B*c+2*c*(b*B+_
+   6*A*c)*x^2)*sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                                    2
+--R                           2 +-+ +-+             b x  + 2a
+--R       (- 72A b - 48B a)c x \|a \|c atanh(-----------------------)
+--R                                                +---------------+
+--R                                            +-+ |   4      2
+--R                                          2\|a \|c x  + b x  + a
+--R     + 
+--R                                                                  2
+--R               2         2                   3  2             2c x  + b
+--R       (72A a c  + (18A b  + 36B a b)c - 3B b )x atanh(-----------------------)
+--R                                                             +---------------+
+--R                                                         +-+ |   4      2
+--R                                                       2\|c \|c x  + b x  + a
+--R     + 
+--R                2 6         2            4                           2  2
+--R           16B c x  + (24A c  + 28B b c)x  + ((60A b + 64B a)c + 6B b )x
+--R         + 
+--R           - 48A a c
+--R      *
+--R              +---------------+
+--R          +-+ |   4      2
+--R         \|c \|c x  + b x  + a
+--R  /
+--R          2 +-+
+--R     96c x \|c
+--R                                                    Type: Expression(Integer)
+--E 1363
+
+--S 1364 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1364
+
+)clear all
+
+--S 1365 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^5
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        5
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1365
+
+--S 1366 of 1718
+r0:=-1/4*(A-B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^4-3/16*(4*a*b*B+A*(b^2+4*a*c))*_
+   atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)+_
+   3/16*(b^2*B+4*A*b*c+4*a*B*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*_
+   sqrt(a+b*x^2+c*x^4)))/sqrt(c)-3/8*(A*b+2*a*B-(b*B+2*A*c)*x^2)*_
+   sqrt(a+b*x^2+c*x^4)/x^2
+--R 
+--R
+--R   (2)
+--R                                                          2
+--R                        2            4 +-+             b x  + 2a
+--R       (- 12A a c - 3A b  - 12B a b)x \|c atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|a \|c x  + b x  + a
+--R     + 
+--R                                                        2
+--R                               2  4 +-+             2c x  + b
+--R       ((12A b + 12B a)c + 3B b )x \|a atanh(-----------------------)
+--R                                                   +---------------+
+--R                                               +-+ |   4      2
+--R                                             2\|c \|c x  + b x  + a
+--R     + 
+--R                6                  4                    2         +-+ +-+
+--R         (4B c x  + (8A c + 10B b)x  + (- 10A b - 8B a)x  - 4A a)\|a \|c
+--R      *
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R  /
+--R        4 +-+ +-+
+--R     16x \|a \|c
+--R                                                    Type: Expression(Integer)
+--E 1366
+
+--S 1367 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1367
+
+)clear all
+
+--S 1368 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R   (1)  (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1368
+
+--S 1369 of 1718
+--r0:=1/63*x*(3*(b*B+3*A*c)+7*B*c*x^2)*(a+b*x^2+c*x^4)^(3/2)/c-_
+---  1/315*x*(4*b^3*B-9*A*b^2*c-9*a*b*B*c-90*a*A*c^2+3*c*(4*b^2*B-_
+---  9*A*b*c-14*a*B*c)*x^2)*sqrt(a+b*x^2+c*x^4)/c^2+1/630*(8*b^4*B-_
+---  18*A*b^3*c-57*a*b^2*B*c+144*a*A*b*c^2+84*a^2*B*c^2)*_
+---  elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*_
+---  sqrt(a+b*x^2+c*x^4))-1/630*elliptic_f(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*(8*b^4*B-18*A*b^3*c-_
+---  57*a*b^2*B*c+144*a*A*b*c^2+84*a^2*B*c^2-2*a*c*(4*b^3*B-9*A*b^2*c-_
+---  24*a*b*B*c+180*a*A*c^2)/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1369
+
+--S 1370 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1370
+
+)clear all
+
+--S 1371 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^2
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        2
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1371
+
+--S 1372 of 1718
+--r0:=-1/7*(7*A-B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x+1/35*x*(b^2*B+49*A*b*c+_
+---  10*a*B*c+3*c*(b*B+14*A*c)*x^2)*sqrt(a+b*x^2+c*x^4)/c-1/70*(2*b^3*B-_
+---  7*A*b^2*c-16*a*b*B*c-84*a*A*c^2)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/_
+---  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+---  (b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+---  (c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))+1/70*elliptic_f(asin(x*_
+---  sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*(2*b^3*B-7*A*b^2*c-16*a*b*B*c-_
+---  84*a*A*c^2-2*a*c*(b^2*B-56*A*b*c-20*a*B*c)/(b+sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1372
+
+--S 1373 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1373
+
+)clear all
+
+--S 1374 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^4
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        4
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1374
+
+--S 1375 of 1718
+--r0:=-1/15*(5*A-3*B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^3-1/15*(3*(5*A*b+6*a*B)-_
+---  (3*b*B+10*A*c)*x^2)*sqrt(a+b*x^2+c*x^4)/x+1/30*(3*b^2*B+40*A*b*c+_
+---  36*a*B*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+_
+---  c*x^4))-1/30*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-_
+---  4*a*c))*(3*b^2*B+40*A*b*c+36*a*B*c-2*c*(24*a*b*B+5*A*(3*b^2+4*a*c))/_
+---  (b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+---  (c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1375
+
+--S 1376 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1376
+
+)clear all
+
+--S 1377 of 1718
+t0:=(A+B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^6
+--R 
+--R
+--R                                                       +---------------+
+--R              6               4               2        |   4      2
+--R        (B c x  + (A c + B b)x  + (A b + B a)x  + A a)\|c x  + b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        6
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 1377
+
+--S 1378 of 1718
+--r0:=-1/15*(3*A-5*B*x^2)*(a+b*x^2+c*x^4)^(3/2)/x^5-1/15*(40*a*b*B+3*A*_
+---  (b^2+12*a*c))*sqrt(a+b*x^2+c*x^4)/(a*x)-1/15*(3*A*b+10*a*B-3*(5*b*B+_
+---  6*A*c)*x^2)*sqrt(a+b*x^2+c*x^4)/x^3+1/30*(40*a*b*B+3*A*(b^2+12*a*c))*_
+---  elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*_
+---  sqrt(a+b*x^2+c*x^4))-1/30*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+---  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+---  (b+sqrt(b^2-4*a*c))*(40*a*b*B+3*A*(b^2+12*a*c)-2*a*(15*b^2*B+_
+---  24*A*b*c+20*a*B*c)/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 1378
+
+--S 1379 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1379
+
+)clear all
+
+--S 1380 of 1718
+t0:=x^5*(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                       7      5
+--R                    B x  + A x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1380
+
+--S 1381 of 1718
+r0:=-1/4*(3*b*B-2*A*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/_
+   c^(5/2)-x^4*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+_
+   c*x^4))+1/2*(3*b^2*B-4*A*b*c-4*a*B*c)*sqrt(a+b*x^2+c*x^4)/(c^2*_
+   (b^2-4*a*c))+(A*b-2*a*B-(b*B-2*A*c)*x^2)*sqrt(a+b*x^2+c*x^4)/(c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                                  +---------------+
+--R                2          2                   3  |   4      2
+--R         (8A a c  + (- 2A b  - 12B a b)c + 3B b )\|c x  + b x  + a
+--R      *
+--R                          2
+--R                      2c x  + b
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|c \|c x  + b x  + a
+--R     + 
+--R                  2       2   4            2        2                   3  2
+--R           (8B a c  - 2B b c)x  + (- 8A a c  + (4A b  + 20B a b)c - 6B b )x
+--R         + 
+--R                          2           2
+--R           (4A a b + 16B a )c - 6B a b
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R                          +---------------+
+--R           3     2 2  +-+ |   4      2
+--R     (16a c  - 4b c )\|c \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1381
+
+--S 1382 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1382
+
+)clear all
+
+--S 1383 of 1718
+t0:=x^3*(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                       5      3
+--R                    B x  + A x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1383
+
+--S 1384 of 1718
+r0:=1/2*B*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(3/2)+_
+   (2*a+b*x^2)*(A+B*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-b*B*sqrt(a+_
+   b*x^2+c*x^4)/(c*(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                       +---------------+                 2
+--R                    2  |   4      2                  2c x  + b
+--R       (4B a c - B b )\|c x  + b x  + a atanh(-----------------------)
+--R                                                    +---------------+
+--R                                                +-+ |   4      2
+--R                                              2\|c \|c x  + b x  + a
+--R     + 
+--R                                2  2                    +-+
+--R       (((- 2A b - 4B a)c + 2B b )x  - 4A a c + 2B a b)\|c
+--R  /
+--R                        +---------------+
+--R          2     2   +-+ |   4      2
+--R     (8a c  - 2b c)\|c \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1384
+
+--S 1385 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1385
+
+)clear all
+
+--S 1386 of 1718
+t0:=x*(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                        3
+--R                     B x  + A x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1386
+
+--S 1387 of 1718
+r0:=(-A*b+2*a*B+(b*B-2*A*c)*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                      2
+--R         (2A c - B b)x  + A b - 2B a
+--R   (2)  -----------------------------
+--R                    +---------------+
+--R                 2  |   4      2
+--R        (4a c - b )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1387
+
+--S 1388 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1388
+
+)clear all
+
+--S 1389 of 1718
+t0:=(A+B*x^2)/(x*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                          2
+--R                       B x  + A
+--R   (1)  -------------------------------------
+--R                            +---------------+
+--R            5      3        |   4      2
+--R        (c x  + b x  + a x)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1389
+
+--S 1390 of 1718
+r0:=-1/2*A*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(3/2)+_
+   (-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (2)
+--R                         +---------------+                2
+--R                      2  |   4      2                  b x  + 2a
+--R       (- 4A a c + A b )\|c x  + b x  + a atanh(-----------------------)
+--R                                                      +---------------+
+--R                                                  +-+ |   4      2
+--R                                                2\|a \|c x  + b x  + a
+--R     + 
+--R                          2                2           +-+
+--R       ((- 2A b + 4B a)c x  + 4A a c - 2A b  + 2B a b)\|a
+--R  /
+--R                        +---------------+
+--R        2        2  +-+ |   4      2
+--R     (8a c - 2a b )\|a \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1390
+
+--S 1391 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1391
+
+)clear all
+
+--S 1392 of 1718
+t0:=(A+B*x^2)/(x^3*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                          2
+--R                       B x  + A
+--R   (1)  --------------------------------------
+--R                             +---------------+
+--R            7      5      3  |   4      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1392
+
+--S 1393 of 1718
+r0:=1/4*(3*A*b-2*a*B)*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/_
+   a^(5/2)+(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*x^2*_
+   sqrt(a+b*x^2+c*x^4))-1/2*(3*A*b^2-2*a*b*B-8*a*A*c)*_
+   sqrt(a+b*x^2+c*x^4)/(a^2*(b^2-4*a*c)*x^2)
+--R 
+--R
+--R   (2)
+--R                                                  +---------------+
+--R                         2         3         2  2 |   4      2
+--R         ((12A a b - 8B a )c - 3A b  + 2B a b )x \|c x  + b x  + a
+--R      *
+--R                         2
+--R                      b x  + 2a
+--R         atanh(-----------------------)
+--R                     +---------------+
+--R                 +-+ |   4      2
+--R               2\|a \|c x  + b x  + a
+--R     + 
+--R                     2        2             4
+--R           (- 16A a c  + (6A b  - 4B a b)c)x
+--R         + 
+--R                             2         3         2  2       2          2
+--R           ((- 20A a b + 8B a )c + 6A b  - 4B a b )x  - 8A a c + 2A a b
+--R      *
+--R          +-+
+--R         \|a
+--R  /
+--R                           +---------------+
+--R         3      2 2  2 +-+ |   4      2
+--R     (16a c - 4a b )x \|a \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1393
+
+--S 1394 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1394
+
+)clear all
+
+--S 1395 of 1718
+t0:=x^4*(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                       6      4
+--R                    B x  + A x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1395
+
+--S 1396 of 1718
+--r0:=-x^3*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-_
+---  (b*B-2*A*c)*x*sqrt(a+b*x^2+c*x^4)/(c*(b^2-4*a*c))+1/2*(2*b^2*B-_
+---  A*b*c-6*a*B*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*(b^2-4*a*c)*sqrt(2)*_
+---  sqrt(a+b*x^2+c*x^4))-1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+---  sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+_
+---  sqrt(b^2-4*a*c))*(2*b^2*B-A*b*c-6*a*B*c-2*a*c*(b*B-2*A*c)/(b+_
+---  sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*(b^2-_
+---  4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1396
+
+--S 1397 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1397
+
+)clear all
+
+--S 1398 of 1718
+t0:=x^2*(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                       4      2
+--R                    B x  + A x
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1398
+
+--S 1399 of 1718
+--r0:=-x*(A*b-2*a*B-(b*B-2*A*c)*x^2)/((b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-_
+---  1/2*(b*B-2*A*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+_
+---  2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*_
+---  sqrt(a+b*x^2+c*x^4))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+---  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+---  (b^2*B-4*a*B*c+(b*B-2*A*c)*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1399
+
+--S 1400 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1400
+
+)clear all
+
+--S 1401 of 1718
+t0:=(A+B*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                         2
+--R                      B x  + A
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1401
+
+--S 1402 of 1718
+--r0:=-x*(a*b*B-A*(b^2-2*a*c)-(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*_
+---  sqrt(a+b*x^2+c*x^4))-1/2*(A*b-2*a*B)*elliptic_e(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-_
+---  4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-_
+---  4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))-1/2*elliptic_f(asin(x*_
+---  sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(2*a*B*sqrt(b^2-4*a*c)-A*(b^2-4*a*c+b*sqrt(b^2-_
+---  4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*_
+---  sqrt(a+b*x^2+c*x^4))
+--E 1402
+
+--S 1403 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1403
+
+)clear all
+
+--S 1404 of 1718
+t0:=(A+B*x^2)/(x^2*(a+b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                          2
+--R                       B x  + A
+--R   (1)  --------------------------------------
+--R                             +---------------+
+--R            6      4      2  |   4      2
+--R        (c x  + b x  + a x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1404
+
+--S 1405 of 1718
+--r0:=(-a*b*B+A*(b^2-2*a*c)+(A*b-2*a*B)*c*x^2)/(a*(b^2-4*a*c)*x*_
+---  sqrt(a+b*x^2+c*x^4))-(2*A*b^2-a*b*B-6*a*A*c)*sqrt(a+b*x^2+c*x^4)/_
+---  (a^2*(b^2-4*a*c)*x)+1/2*(2*A*b^2-a*b*B-6*a*A*c)*elliptic_e(asin(x*_
+---  sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-_
+---  4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+---  (a^2*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))-_
+---  1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  (2*A*b^2-a*b*B-6*a*A*c-2*a*(A*b-2*a*B)*c/(b+sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*(b^2-4*a*c)*sqrt(2)*_
+---  sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 1405
+
+--S 1406 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1406
+
+)clear all
+
+--S 1407 of 1718
+t0:=(3-x^2)/sqrt(3+x^2-x^4)
+--R 
+--R
+--R               2
+--R            - x  + 3
+--R   (1)  ----------------
+--R         +-------------+
+--R         |   4    2
+--R        \|- x  + x  + 3
+--R                                                    Type: Expression(Integer)
+--E 1407
+
+--S 1408 of 1718
+--r0:=-elliptic_e(asin(x*sqrt(2/(1+sqrt(13)))),1/6*(-7-sqrt(13)))*_
+---  sqrt(1/2*(-1+sqrt(13)))+elliptic_f(asin(x*sqrt(2/(1+sqrt(13)))),_
+---  1/6*(-7-sqrt(13)))*sqrt(7+2*sqrt(13))
+--E 1408
+
+--S 1409 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1409
+
+)clear all
+
+--S 1410 of 1718
+t0:=(3-x^2)/sqrt(3+2*x^2-x^4)
+--R 
+--R
+--R                2
+--R             - x  + 3
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   4     2
+--R        \|- x  + 2x  + 3
+--R                                                    Type: Expression(Integer)
+--E 1410
+
+--S 1411 of 1718
+--r0:=-%i*elliptic_e(%i*asinh(x),-1/3)*sqrt(3)
+--E 1411
+
+--S 1412 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1412
+
+)clear all
+
+--S 1413 of 1718
+t0:=(3-x^2)/sqrt(3+3*x^2-x^4)
+--R 
+--R
+--R                2
+--R             - x  + 3
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   4     2
+--R        \|- x  + 3x  + 3
+--R                                                    Type: Expression(Integer)
+--E 1413
+
+--S 1414 of 1718
+--r0:=-elliptic_e(asin(x*sqrt(2/(3+sqrt(21)))),1/2*(-5-sqrt(21)))*_
+---  sqrt(1/2*(-3+sqrt(21)))+elliptic_f(asin(x*sqrt(2/(3+sqrt(21)))),_
+---  1/2*(-5-sqrt(21)))*sqrt(9+2*sqrt(21))
+--E 1414
+
+--S 1415 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1415
+
+)clear all
+
+--S 1416 of 1718
+t0:=(3-x^2)/sqrt(3-x^2-x^4)
+--R 
+--R
+--R               2
+--R            - x  + 3
+--R   (1)  ----------------
+--R         +-------------+
+--R         |   4    2
+--R        \|- x  - x  + 3
+--R                                                    Type: Expression(Integer)
+--E 1416
+
+--S 1417 of 1718
+--r0:=-elliptic_e(asin(x*sqrt(2/(-1+sqrt(13)))),1/6*(-7+sqrt(13)))*_
+---  sqrt(1/2*(1+sqrt(13)))+elliptic_f(asin(x*sqrt(2/(-1+sqrt(13)))),_
+---  1/6*(-7+sqrt(13)))*sqrt(5+2*sqrt(13))
+--E 1417
+
+--S 1418 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1418
+
+)clear all
+
+--S 1419 of 1718
+t0:=(3-x^2)/sqrt(3-2*x^2-x^4)
+--R 
+--R
+--R                2
+--R             - x  + 3
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   4     2
+--R        \|- x  - 2x  + 3
+--R                                                    Type: Expression(Integer)
+--E 1419
+
+--S 1420 of 1718
+--r0:=-elliptic_e(asin(x),-1/3)*sqrt(3)+2*elliptic_f(asin(x),-1/3)*sqrt(3)
+--E 1420
+
+--S 1421 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1421
+
+)clear all
+
+--S 1422 of 1718
+t0:=(3-x^2)/sqrt(3-3*x^2-x^4)
+--R 
+--R
+--R                2
+--R             - x  + 3
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   4     2
+--R        \|- x  - 3x  + 3
+--R                                                    Type: Expression(Integer)
+--E 1422
+
+--S 1423 of 1718
+--r0:=-elliptic_e(asin(x*sqrt(2/(-3+sqrt(21)))),1/2*(-5+sqrt(21)))*_
+---  sqrt(1/2*(3+sqrt(21)))+elliptic_f(asin(x*sqrt(2/(-3+sqrt(21)))),_
+---  1/2*(-5+sqrt(21)))*sqrt(3+2*sqrt(21))
+--E 1423
+
+--S 1424 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1424
+
+)clear all
+
+--S 1425 of 1718
+t0:=(b+2*c*x^2-sqrt(b^2-4*a*c))/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +-----------+
+--R           |          2        2
+--R        - \|- 4a c + b   + 2c x  + b
+--R   (1)  ----------------------------
+--R              +---------------+
+--R              |   4      2
+--R             \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1425
+
+--S 1426 of 1718
+--r0:=elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),_
+---  (b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*(b-sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(-c)*sqrt(a+b*x^2+c*x^4))
+--E 1426
+
+--S 1427 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1427
+
+)clear all
+
+--S 1428 of 1718
+t0:=x^2*sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R           +--------+ +-------------------+
+--R         2 |   2      | 2 4         2    2
+--R   (1)  x \|d x  + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1428
+
+--S 1429 of 1718
+r0:=1/6*b*x^3*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))+_
+   1/16*c^2*(b*c-2*a*d)*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d^(5/2)*(a+b*x^2))-1/16*c*(b*c-2*a*d)*x*sqrt(c+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^2*(a+b*x^2))-1/8*(b*c-2*a*d)*x^3*_
+   sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                          +-------------------+           +-+
+--R              2        3  | 2 4         2    2          x\|d
+--R       (- 6a c d + 3b c )\|b x  + 2a b x  + a  atanh(-----------)
+--R                                                      +--------+
+--R                                                      |   2
+--R                                                     \|d x  + c
+--R     + 
+--R                                                                 +--------+
+--R              2 5         2           3                 2    +-+ |   2
+--R         (8b d x  + (12a d  + 2b c d)x  + (6a c d - 3b c )x)\|d \|d x  + c
+--R      *
+--R          +-------------------+
+--R          | 2 4         2    2
+--R         \|b x  + 2a b x  + a
+--R  /
+--R           2 2        2  +-+
+--R     (48b d x  + 48a d )\|d
+--R                                                    Type: Expression(Integer)
+--E 1429
+
+--S 1430 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1430
+
+)clear all
+
+--S 1431 of 1718
+t0:=x*sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R          +--------+ +-------------------+
+--R          |   2      | 2 4         2    2
+--R   (1)  x\|d x  + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1431
+
+--S 1432 of 1718
+r0:=1/5*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/d-2/15*(b*c-a*d)*_
+   (c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d^2*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                                      +--------+
+--R            2 4        2          2                2  |   2
+--R       (3b d x  + (5a d  + b c d)x  + 5a c d - 2b c )\|d x  + c
+--R    *
+--R        +-------------------+
+--R        | 2 4         2    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          2 2        2
+--R     15b d x  + 15a d
+--R                                                    Type: Expression(Integer)
+--E 1432
+
+--S 1433 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1433
+
+)clear all
+
+--S 1434 of 1718
+t0:=sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)
+--R 
+--R
+--R         +--------+ +-------------------+
+--R         |   2      | 2 4         2    2
+--R   (1)  \|d x  + c \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1434
+
+--S 1435 of 1718
+r0:=1/4*b*x*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))-_
+   1/8*c*(b*c-4*a*d)*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/(d^(3/2)*(a+b*x^2))-1/8*(b*c-4*a*d)*x*sqrt(c+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                       +-------------------+           +-+
+--R                    2  | 2 4         2    2          x\|d
+--R       (4a c d - b c )\|b x  + 2a b x  + a  atanh(-----------)
+--R                                                   +--------+
+--R                                                   |   2
+--R                                                  \|d x  + c
+--R     + 
+--R                                     +--------+ +-------------------+
+--R              3                  +-+ |   2      | 2 4         2    2
+--R       (2b d x  + (4a d + b c)x)\|d \|d x  + c \|b x  + 2a b x  + a
+--R  /
+--R            2         +-+
+--R     (8b d x  + 8a d)\|d
+--R                                                    Type: Expression(Integer)
+--E 1435
+
+--S 1436 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1436
+
+)clear all
+
+--S 1437 of 1718
+t0:=sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x
+--R 
+--R
+--R         +--------+ +-------------------+
+--R         |   2      | 2 4         2    2
+--R        \|d x  + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 1437
+
+--S 1438 of 1718
+r0:=1/3*b*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(d*(a+b*x^2))-_
+   a*atanh(sqrt(c+d*x^2)/sqrt(c))*sqrt(c)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/_
+   (a+b*x^2)+a*sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(a+b*x^2)
+--R 
+--R
+--R   (2)
+--R                                              +--------+
+--R                  +-------------------+       |   2
+--R              +-+ | 2 4         2    2       \|d x  + c
+--R       - 3a d\|c \|b x  + 2a b x  + a  atanh(-----------)
+--R                                                  +-+
+--R                                                 \|c
+--R     + 
+--R                             +--------+ +-------------------+
+--R             2               |   2      | 2 4         2    2
+--R       (b d x  + 3a d + b c)\|d x  + c \|b x  + 2a b x  + a
+--R  /
+--R           2
+--R     3b d x  + 3a d
+--R                                                    Type: Expression(Integer)
+--E 1438
+
+--S 1439 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1439
+
+)clear all
+
+--S 1440 of 1718
+t0:=sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^2
+--R 
+--R
+--R         +--------+ +-------------------+
+--R         |   2      | 2 4         2    2
+--R        \|d x  + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------
+--R                         2
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 1440
+
+--S 1441 of 1718
+r0:=-a*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*x*(a+b*x^2))+_
+   1/2*(b*c+2*a*d)*atanh(x*sqrt(d)/sqrt(c+d*x^2))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/((a+b*x^2)*sqrt(d))+1/2*(b*c+2*a*d)*x*sqrt(c+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                     +-------------------+           +-+
+--R                     | 2 4         2    2          x\|d
+--R       (2a d + b c)x\|b x  + 2a b x  + a  atanh(-----------)
+--R                                                 +--------+
+--R                                                 |   2
+--R                                                \|d x  + c
+--R     + 
+--R                       +--------+ +-------------------+
+--R           2       +-+ |   2      | 2 4         2    2
+--R       (b x  - 2a)\|d \|d x  + c \|b x  + 2a b x  + a
+--R  /
+--R          3         +-+
+--R     (2b x  + 2a x)\|d
+--R                                                    Type: Expression(Integer)
+--E 1441
+
+--S 1442 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1442
+
+)clear all
+
+--S 1443 of 1718
+t0:=sqrt(c+d*x^2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/x^3
+--R 
+--R
+--R         +--------+ +-------------------+
+--R         |   2      | 2 4         2    2
+--R        \|d x  + c \|b x  + 2a b x  + a
+--R   (1)  ---------------------------------
+--R                         3
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 1443
+
+--S 1444 of 1718
+r0:=-1/2*a*(c+d*x^2)^(3/2)*sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*x^2*(a+b*x^2))-_
+   1/2*(2*b*c+a*d)*atanh(sqrt(c+d*x^2)/sqrt(c))*sqrt(a^2+2*a*b*x^2+_
+   b^2*x^4)/((a+b*x^2)*sqrt(c))+1/2*(2*b*c+a*d)*sqrt(c+d*x^2)*_
+   sqrt(a^2+2*a*b*x^2+b^2*x^4)/(c*(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                                    +--------+
+--R                        +-------------------+       |   2
+--R                      2 | 2 4         2    2       \|d x  + c
+--R       (- a d - 2b c)x \|b x  + 2a b x  + a  atanh(-----------)
+--R                                                        +-+
+--R                                                       \|c
+--R     + 
+--R                       +--------+ +-------------------+
+--R            2      +-+ |   2      | 2 4         2    2
+--R       (2b x  - a)\|c \|d x  + c \|b x  + 2a b x  + a
+--R  /
+--R          4       2  +-+
+--R     (2b x  + 2a x )\|c
+--R                                                    Type: Expression(Integer)
+--E 1444
+
+--S 1445 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1445
+
+)clear all
+
+--S 1446 of 1718
+t0:=(d+e*x^2)^4/(-d^2+e^2*x^4)
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        e x  + 3d e x  + 3d e x  + d
+--R   (1)  -----------------------------
+--R                      2
+--R                   e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1446
+
+--S 1447 of 1718
+r0:=7*d^2*x+4/3*d*e*x^3+1/5*e^2*x^5-8*d^(5/2)*atanh(x*sqrt(e)/sqrt(d))/sqrt(e)
+--R 
+--R
+--R                           +-+
+--R              2 +-+      x\|e        2 5          3       2   +-+
+--R        - 120d \|d atanh(-----) + (3e x  + 20d e x  + 105d x)\|e
+--R                           +-+
+--R                          \|d
+--R   (2)  ---------------------------------------------------------
+--R                                     +-+
+--R                                  15\|e
+--R                                                    Type: Expression(Integer)
+--E 1447
+
+--S 1448 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1448
+
+)clear all
+
+--S 1449 of 1718
+t0:=(d+e*x^2)^3/(-d^2+e^2*x^4)
+--R 
+--R
+--R         2 4         2    2
+--R        e x  + 2d e x  + d
+--R   (1)  -------------------
+--R                 2
+--R              e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1449
+
+--S 1450 of 1718
+r0:=3*d*x+1/3*e*x^3-4*d^(3/2)*atanh(x*sqrt(e)/sqrt(d))/sqrt(e)
+--R 
+--R
+--R                         +-+
+--R              +-+      x\|e         3         +-+
+--R        - 12d\|d atanh(-----) + (e x  + 9d x)\|e
+--R                         +-+
+--R                        \|d
+--R   (2)  -----------------------------------------
+--R                            +-+
+--R                          3\|e
+--R                                                    Type: Expression(Integer)
+--E 1450
+
+--S 1451 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1451
+
+)clear all
+
+--S 1452 of 1718
+t0:=(d+e*x^2)^2/(-d^2+e^2*x^4)
+--R 
+--R
+--R           2
+--R        e x  + d
+--R   (1)  --------
+--R           2
+--R        e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1452
+
+--S 1453 of 1718
+r0:=x-2*atanh(x*sqrt(e)/sqrt(d))*sqrt(d)/sqrt(e)
+--R 
+--R
+--R                       +-+
+--R            +-+      x\|e       +-+
+--R        - 2\|d atanh(-----) + x\|e
+--R                       +-+
+--R                      \|d
+--R   (2)  ---------------------------
+--R                     +-+
+--R                    \|e
+--R                                                    Type: Expression(Integer)
+--E 1453
+
+--S 1454 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1454
+
+)clear all
+
+--S 1455 of 1718
+t0:=(d+e*x^2)/(-d^2+e^2*x^4)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R           2
+--R        e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1455
+
+--S 1456 of 1718
+r0:=-atanh(x*sqrt(e)/sqrt(d))/(sqrt(d)*sqrt(e))
+--R 
+--R
+--R                  +-+
+--R                x\|e
+--R          atanh(-----)
+--R                  +-+
+--R                 \|d
+--R   (2)  - ------------
+--R             +-+ +-+
+--R            \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 1456
+
+--S 1457 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1457
+
+)clear all
+
+--S 1458 of 1718
+t0:=1/((d+e*x^2)*(-d^2+e^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R         3 6      2 4    2   2    3
+--R        e x  + d e x  - d e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1458
+
+--S 1459 of 1718
+r0:=-1/4*x/(d^2*(d+e*x^2))-1/2*atan(x*sqrt(e)/sqrt(d))/(d^(5/2)*sqrt(e))-_
+   1/4*atanh(x*sqrt(e)/sqrt(d))/(d^(5/2)*sqrt(e))
+--R 
+--R
+--R                            +-+                         +-+
+--R              2           x\|e            2           x\|e       +-+ +-+
+--R        (- e x  - d)atanh(-----) + (- 2e x  - 2d)atan(-----) - x\|d \|e
+--R                            +-+                         +-+
+--R                           \|d                         \|d
+--R   (2)  ----------------------------------------------------------------
+--R                                2   2     3  +-+ +-+
+--R                             (4d e x  + 4d )\|d \|e
+--R                                                    Type: Expression(Integer)
+--E 1459
+
+--S 1460 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1460
+
+)clear all
+
+--S 1461 of 1718
+t0:=1/((d+e*x^2)^2*(-d^2+e^2*x^4))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R         4 8       3 6     3   2    4
+--R        e x  + 2d e x  - 2d e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1461
+
+--S 1462 of 1718
+r0:=-1/8*x/(d^2*(d+e*x^2)^2)-5/16*x/(d^3*(d+e*x^2))-7/16*atan(x*sqrt(e)/_
+   sqrt(d))/(d^(7/2)*sqrt(e))-1/8*atanh(x*sqrt(e)/sqrt(d))/(d^(7/2)*sqrt(e))
+--R 
+--R
+--R   (2)
+--R                                        +-+
+--R            2 4         2     2       x\|e
+--R       (- 2e x  - 4d e x  - 2d )atanh(-----)
+--R                                        +-+
+--R                                       \|d
+--R     + 
+--R                                        +-+
+--R            2 4          2     2      x\|e            3         +-+ +-+
+--R       (- 7e x  - 14d e x  - 7d )atan(-----) + (- 5e x  - 7d x)\|d \|e
+--R                                        +-+
+--R                                       \|d
+--R  /
+--R         3 2 4      4   2      5  +-+ +-+
+--R     (16d e x  + 32d e x  + 16d )\|d \|e
+--R                                                    Type: Expression(Integer)
+--E 1462
+
+--S 1463 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1463
+
+)clear all
+
+--S 1464 of 1718
+t0:=(d+e*x^2)^(3/2)/(-d^2+e^2*x^4)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|e x  + d
+--R   (1)  -----------
+--R             2
+--R          e x  - d
+--R                                                    Type: Expression(Integer)
+--E 1464
+
+--S 1465 of 1718
+r0:=atanh(x*sqrt(e)/sqrt(d+e*x^2))/sqrt(e)-atanh(x*sqrt(2)*sqrt(e)/_
+   sqrt(d+e*x^2))*sqrt(2)/sqrt(e)
+--R 
+--R
+--R                       +-+ +-+                +-+
+--R           +-+       x\|2 \|e               x\|e
+--R        - \|2 atanh(-----------) + atanh(-----------)
+--R                     +--------+           +--------+
+--R                     |   2                |   2
+--R                    \|e x  + d           \|e x  + d
+--R   (2)  ---------------------------------------------
+--R                              +-+
+--R                             \|e
+--R                                                    Type: Expression(Integer)
+--E 1465
+
+--S 1466 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1466
+
+)clear all
+
+--S 1467 of 1718
+t0:=(d+e*x^2)^(1/2)/(-d^2+e^2*x^4)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|e x  + d
+--R   (1)  -----------
+--R          2 4    2
+--R         e x  - d
+--R                                                    Type: Expression(Integer)
+--E 1467
+
+--S 1468 of 1718
+r0:=-atanh(x*sqrt(2)*sqrt(e)/sqrt(d+e*x^2))/(d*sqrt(2)*sqrt(e))
+--R 
+--R
+--R                   +-+ +-+
+--R                 x\|2 \|e
+--R          atanh(-----------)
+--R                 +--------+
+--R                 |   2
+--R                \|e x  + d
+--R   (2)  - ------------------
+--R                 +-+ +-+
+--R               d\|2 \|e
+--R                                                    Type: Expression(Integer)
+--E 1468
+
+--S 1469 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1469
+
+)clear all
+
+--S 1470 of 1718
+t0:=1/((d+e*x^2)^(1/2)*(-d^2+e^2*x^4))
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R                    +--------+
+--R          2 4    2  |   2
+--R        (e x  - d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1470
+
+--S 1471 of 1718
+r0:=-1/2*atanh(x*sqrt(2)*sqrt(e)/sqrt(d+e*x^2))/(d^2*sqrt(2)*sqrt(e))-_
+   1/2*x/(d^2*sqrt(d+e*x^2))
+--R 
+--R
+--R           +--------+         +-+ +-+
+--R           |   2            x\|2 \|e        +-+ +-+
+--R        - \|e x  + d atanh(-----------) - x\|2 \|e
+--R                            +--------+
+--R                            |   2
+--R                           \|e x  + d
+--R   (2)  -------------------------------------------
+--R                               +--------+
+--R                     2 +-+ +-+ |   2
+--R                   2d \|2 \|e \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1471
+
+--S 1472 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1472
+
+)clear all
+
+--S 1473 of 1718
+t0:=1/((d+e*x^2)^(3/2)*(-d^2+e^2*x^4))
+--R 
+--R
+--R                            1
+--R   (1)  ----------------------------------------
+--R                                      +--------+
+--R          3 6      2 4    2   2    3  |   2
+--R        (e x  + d e x  - d e x  - d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1473
+
+--S 1474 of 1718
+r0:=-1/6*x/(d^2*(d+e*x^2)^(3/2))-1/4*atanh(x*sqrt(2)*sqrt(e)/sqrt(d+e*x^2))/_
+   (d^3*sqrt(2)*sqrt(e))-7/12*x/(d^3*sqrt(d+e*x^2))
+--R 
+--R
+--R                       +--------+         +-+ +-+
+--R               2       |   2            x\|2 \|e             3         +-+ +-+
+--R        (- 3e x  - 3d)\|e x  + d atanh(-----------) + (- 7e x  - 9d x)\|2 \|e
+--R                                        +--------+
+--R                                        |   2
+--R                                       \|e x  + d
+--R   (2)  ----------------------------------------------------------------------
+--R                                                   +--------+
+--R                             3   2      4  +-+ +-+ |   2
+--R                         (12d e x  + 12d )\|2 \|e \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1474
+
+--S 1475 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1475
+
+)clear all
+
+--S 1476 of 1718
+t0:=(d+e*x^2)^4/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        e x  + 3d e x  + 3d e x  + d
+--R   (1)  -----------------------------
+--R                   2
+--R              c e x  + b e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1476
+
+--S 1477 of 1718
+r0:=(7*c^2*d^2-5*b*c*d*e+b^2*e^2)*x/c^3+1/3*e*(4*c*d-b*e)*x^3/c^2+_
+   1/5*e^2*x^5/c-(2*c*d-b*e)^3*atanh(x*sqrt(c)*sqrt(e)/sqrt(c*d-b*e))/_
+   (c^(7/2)*sqrt(e)*sqrt(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                                                              +-+ +-+
+--R           3 3      2     2         2 2        3 3          x\|c \|e
+--R       (15b e  - 90b c d e  + 180b c d e - 120c d )atanh(--------------)
+--R                                                          +-----------+
+--R                                                         \|- b e + c d
+--R     + 
+--R            2 2 5            2      2     3       2 2                   2 2
+--R         (3c e x  + (- 5b c e  + 20c d e)x  + (15b e  - 75b c d e + 105c d )x)
+--R      *
+--R          +-----------+ +-+ +-+
+--R         \|- b e + c d \|c \|e
+--R  /
+--R        3 +-----------+ +-+ +-+
+--R     15c \|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 1477
+
+--S 1478 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1478
+
+)clear all
+
+--S 1479 of 1718
+t0:=(d+e*x^2)^3/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R         2 4         2    2
+--R        e x  + 2d e x  + d
+--R   (1)  -------------------
+--R              2
+--R         c e x  + b e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1479
+
+--S 1480 of 1718
+r0:=(3*c*d-b*e)*x/c^2+1/3*e*x^3/c-(2*c*d-b*e)^2*atanh(x*sqrt(c)*sqrt(e)/_
+   sqrt(c*d-b*e))/(c^(5/2)*sqrt(e)*sqrt(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                                                +-+ +-+
+--R            2 2                  2 2          x\|c \|e
+--R       (- 3b e  + 12b c d e - 12c d )atanh(--------------)
+--R                                            +-----------+
+--R                                           \|- b e + c d
+--R     + 
+--R             3                     +-----------+ +-+ +-+
+--R       (c e x  + (- 3b e + 9c d)x)\|- b e + c d \|c \|e
+--R  /
+--R       2 +-----------+ +-+ +-+
+--R     3c \|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 1480
+
+--S 1481 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1481
+
+)clear all
+
+--S 1482 of 1718
+t0:=(d+e*x^2)^2/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R                2
+--R             e x  + d
+--R   (1)  ------------------
+--R             2
+--R        c e x  + b e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1482
+
+--S 1483 of 1718
+r0:=x/c-(2*c*d-b*e)*atanh(x*sqrt(c)*sqrt(e)/sqrt(c*d-b*e))/(c^(3/2)*sqrt(e)*_
+   sqrt(c*d-b*e))
+--R 
+--R
+--R                               +-+ +-+
+--R                             x\|c \|e         +-----------+ +-+ +-+
+--R        (b e - 2c d)atanh(--------------) + x\|- b e + c d \|c \|e
+--R                           +-----------+
+--R                          \|- b e + c d
+--R   (2)  -----------------------------------------------------------
+--R                            +-----------+ +-+ +-+
+--R                          c\|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 1483
+
+--S 1484 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1484
+
+)clear all
+
+--S 1485 of 1718
+t0:=(d+e*x^2)/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R             2
+--R        c e x  + b e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1485
+
+--S 1486 of 1718
+r0:=-atanh(x*sqrt(c)*sqrt(e)/sqrt(c*d-b*e))/(sqrt(c)*sqrt(e)*sqrt(c*d-b*e))
+--R 
+--R
+--R                      +-+ +-+
+--R                    x\|c \|e
+--R           atanh(--------------)
+--R                  +-----------+
+--R                 \|- b e + c d
+--R   (2)  - ----------------------
+--R           +-----------+ +-+ +-+
+--R          \|- b e + c d \|c \|e
+--R                                                    Type: Expression(Integer)
+--E 1486
+
+--S 1487 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1487
+
+)clear all
+
+--S 1488 of 1718
+t0:=1/((d+e*x^2)*(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4))
+--R 
+--R
+--R                                       1
+--R   (1)  ---------------------------------------------------------------
+--R           3 6       3        2  4          2      2   2      2       3
+--R        c e x  + (b e  + c d e )x  + (2b d e  - c d e)x  + b d e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1488
+
+--S 1489 of 1718
+r0:=-1/2*x/(d*(2*c*d-b*e)*(d+e*x^2))-1/2*(4*c*d-b*e)*atan(x*sqrt(e)/_
+   sqrt(d))/(d^(3/2)*(2*c*d-b*e)^2*sqrt(e))-c^(3/2)*atanh(x*sqrt(c)*_
+   sqrt(e)/sqrt(c*d-b*e))/((2*c*d-b*e)^2*sqrt(e)*sqrt(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                                               +-+ +-+
+--R                  2       2  +-+ +-+         x\|c \|e
+--R       (- 2c d e x  - 2c d )\|c \|d atanh(--------------)
+--R                                           +-----------+
+--R                                          \|- b e + c d
+--R     + 
+--R                                                               +-+
+--R            2           2               2  +-----------+     x\|e
+--R       ((b e  - 4c d e)x  + b d e - 4c d )\|- b e + c d atan(-----)
+--R                                                               +-+
+--R                                                              \|d
+--R     + 
+--R                     +-----------+ +-+ +-+
+--R       (b e - 2c d)x\|- b e + c d \|d \|e
+--R  /
+--R           2   3         2 2     2 3   2     2 2 2         3      2 4
+--R       ((2b d e  - 8b c d e  + 8c d e)x  + 2b d e  - 8b c d e + 8c d )
+--R    *
+--R        +-----------+ +-+ +-+
+--R       \|- b e + c d \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 1489
+
+--S 1490 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1490
+
+)clear all
+
+--S 1491 of 1718
+t0:=1/((d+e*x^2)^2*(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4))
+--R 
+--R
+--R   (1)
+--R                                         1
+--R   -----------------------------------------------------------------------------
+--R      4 8       4         3  6         3 4        2 2       3   2      3       4
+--R   c e x  + (b e  + 2c d e )x  + 3b d e x  + (3b d e  - 2c d e)x  + b d e - c d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1491
+
+--S 1492 of 1718
+r0:=-1/4*x/(d*(2*c*d-b*e)*(d+e*x^2)^2)-1/8*(10*c*d-3*b*e)*x/(d^2*_
+   (2*c*d-b*e)^2*(d+e*x^2))-1/8*(28*c^2*d^2-16*b*c*d*e+3*b^2*e^2)*_
+   atan(x*sqrt(e)/sqrt(d))/(d^(5/2)*(2*c*d-b*e)^3*sqrt(e))-c^(5/2)*_
+   atanh(x*sqrt(c)*sqrt(e)/sqrt(c*d-b*e))/((2*c*d-b*e)^3*sqrt(e)*sqrt(c*d-b*e))
+--R 
+--R
+--R   (2)
+--R                                                          +-+ +-+
+--R          2 2 2 4      2 3   2     2 4  +-+ +-+         x\|c \|e
+--R       (8c d e x  + 16c d e x  + 8c d )\|c \|d atanh(--------------)
+--R                                                      +-----------+
+--R                                                     \|- b e + c d
+--R     + 
+--R              2 4            3      2 2 2  4
+--R           (3b e  - 16b c d e  + 28c d e )x
+--R         + 
+--R              2   3          2 2      2 3   2     2 2 2          3       2 4
+--R           (6b d e  - 32b c d e  + 56c d e)x  + 3b d e  - 16b c d e + 28c d
+--R      *
+--R                              +-+
+--R          +-----------+     x\|e
+--R         \|- b e + c d atan(-----)
+--R                              +-+
+--R                             \|d
+--R     + 
+--R             2 3            2      2 2   3      2   2          2       2 3
+--R         ((3b e  - 16b c d e  + 20c d e)x  + (5b d e  - 24b c d e + 28c d )x)
+--R      *
+--R          +-----------+ +-+ +-+
+--R         \|- b e + c d \|d \|e
+--R  /
+--R            3 2 5      2   3 4        2 4 3      3 5 2  4
+--R         (8b d e  - 48b c d e  + 96b c d e  - 64c d e )x
+--R       + 
+--R             3 3 4      2   4 3         2 5 2       3 6   2     3 4 3
+--R         (16b d e  - 96b c d e  + 192b c d e  - 128c d e)x  + 8b d e
+--R       + 
+--R              2   5 2        2 6       3 7
+--R         - 48b c d e  + 96b c d e - 64c d
+--R    *
+--R        +-----------+ +-+ +-+
+--R       \|- b e + c d \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 1492
+
+--S 1493 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1493
+
+)clear all
+
+--S 1494 of 1718
+t0:=(d+e*x^2)^(5/2)/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R               2
+--R          c e x  + b e - c d
+--R                                                    Type: Expression(Integer)
+--E 1494
+
+--S 1495 of 1718
+r0:=1/2*(5*c*d-2*b*e)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/(c^2*sqrt(e))+_
+   (2*c*d-b*e)^(3/2)*atan(x*sqrt(e)*sqrt(2*c*d-b*e)/(sqrt(-c*d+b*e)*_
+   sqrt(d+e*x^2)))/(c^2*sqrt(e)*sqrt(-c*d+b*e))+1/2*x*sqrt(d+e*x^2)/c
+--R 
+--R
+--R   (2)
+--R                                             +-+
+--R                       +---------+         x\|e
+--R       (- 2b e + 5c d)\|b e - c d atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|e x  + d
+--R     + 
+--R                                              +------------+ +-+
+--R                       +------------+       x\|- b e + 2c d \|e
+--R       (- 2b e + 4c d)\|- b e + 2c d atan(-----------------------)
+--R                                                       +--------+
+--R                                           +---------+ |   2
+--R                                          \|b e - c d \|e x  + d
+--R     + 
+--R                           +--------+
+--R           +-+ +---------+ |   2
+--R       c x\|e \|b e - c d \|e x  + d
+--R  /
+--R       2 +-+ +---------+
+--R     2c \|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 1495
+
+--S 1496 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1496
+
+)clear all
+
+--S 1497 of 1718
+t0:=(d+e*x^2)^(3/2)/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|e x  + d
+--R   (1)  ------------------
+--R             2
+--R        c e x  + b e - c d
+--R                                                    Type: Expression(Integer)
+--E 1497
+
+--S 1498 of 1718
+r0:=atanh(x*sqrt(e)/sqrt(d+e*x^2))/(c*sqrt(e))+atan(x*sqrt(e)*_
+   sqrt(2*c*d-b*e)/(sqrt(-c*d+b*e)*sqrt(d+e*x^2)))*sqrt(2*c*d-b*e)/_
+   (c*sqrt(e)*sqrt(-c*d+b*e))
+--R 
+--R
+--R   (2)
+--R                          +-+                               +------------+ +-+
+--R    +---------+         x\|e         +------------+       x\|- b e + 2c d \|e
+--R   \|b e - c d atanh(-----------) + \|- b e + 2c d atan(-----------------------)
+--R                      +--------+                                     +--------+
+--R                      |   2                              +---------+ |   2
+--R                     \|e x  + d                         \|b e - c d \|e x  + d
+--R   -----------------------------------------------------------------------------
+--R                                   +-+ +---------+
+--R                                 c\|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 1498
+
+--S 1499 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1499
+
+)clear all
+
+--S 1500 of 1718
+t0:=(d+e*x^2)^(1/2)/(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4)
+--R 
+--R
+--R                   +--------+
+--R                   |   2
+--R                  \|e x  + d
+--R   (1)  ------------------------------
+--R           2 4      2 2              2
+--R        c e x  + b e x  + b d e - c d
+--R                                                    Type: Expression(Integer)
+--E 1500
+
+--S 1501 of 1718
+r0:=atan(x*sqrt(e)*sqrt(2*c*d-b*e)/(sqrt(-c*d+b*e)*sqrt(d+e*x^2)))/_
+   (sqrt(e)*sqrt(2*c*d-b*e)*sqrt(-c*d+b*e))
+--R 
+--R
+--R                  +------------+ +-+
+--R                x\|- b e + 2c d \|e
+--R         atan(-----------------------)
+--R                           +--------+
+--R               +---------+ |   2
+--R              \|b e - c d \|e x  + d
+--R   (2)  -------------------------------
+--R         +------------+ +-+ +---------+
+--R        \|- b e + 2c d \|e \|b e - c d
+--R                                                    Type: Expression(Integer)
+--E 1501
+
+--S 1502 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1502
+
+)clear all
+
+--S 1503 of 1718
+t0:=1/((d+e*x^2)^(1/2)*(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4))
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R                                         +--------+
+--R            2 4      2 2              2  |   2
+--R        (c e x  + b e x  + b d e - c d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1503
+
+--S 1504 of 1718
+r0:=c*atan(x*sqrt(e)*sqrt(2*c*d-b*e)/(sqrt(-c*d+b*e)*sqrt(d+e*x^2)))/_
+   ((2*c*d-b*e)^(3/2)*sqrt(e)*sqrt(-c*d+b*e))-x/(d*(2*c*d-b*e)*sqrt(d+e*x^2))
+--R 
+--R
+--R   (2)
+--R             +--------+         +------------+ +-+
+--R             |   2            x\|- b e + 2c d \|e
+--R       - c d\|e x  + d atan(-----------------------)
+--R                                         +--------+
+--R                             +---------+ |   2
+--R                            \|b e - c d \|e x  + d
+--R     + 
+--R         +------------+ +-+ +---------+
+--R       x\|- b e + 2c d \|e \|b e - c d
+--R  /
+--R                                                    +--------+
+--R                  2  +------------+ +-+ +---------+ |   2
+--R     (b d e - 2c d )\|- b e + 2c d \|e \|b e - c d \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1504
+
+--S 1505 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1505
+
+)clear all
+
+--S 1506 of 1718
+t0:=1/((d+e*x^2)^(3/2)*(-c*d^2+b*d*e+b*e^2*x^2+c*e^2*x^4))
+--R 
+--R
+--R   (1)
+--R                                         1
+--R   ----------------------------------------------------------------------------
+--R                                                                     +--------+
+--R       3 6       3        2  4          2      2   2      2       3  |   2
+--R   (c e x  + (b e  + c d e )x  + (2b d e  - c d e)x  + b d e - c d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1506
+
+--S 1507 of 1718
+r0:=-1/3*x/(d*(2*c*d-b*e)*(d+e*x^2)^(3/2))+c^2*atan(x*sqrt(e)*_
+   sqrt(2*c*d-b*e)/(sqrt(-c*d+b*e)*sqrt(d+e*x^2)))/((2*c*d-b*e)^(5/2)*_
+   sqrt(e)*sqrt(-c*d+b*e))-1/3*(7*c*d-2*b*e)*x/(d^2*(2*c*d-b*e)^2*_
+   sqrt(d+e*x^2))
+--R 
+--R
+--R   (2)
+--R                           +--------+         +------------+ +-+
+--R          2 2   2     2 3  |   2            x\|- b e + 2c d \|e
+--R       (3c d e x  + 3c d )\|e x  + d atan(-----------------------)
+--R                                                       +--------+
+--R                                           +---------+ |   2
+--R                                          \|b e - c d \|e x  + d
+--R     + 
+--R             2           3                 2    +------------+ +-+ +---------+
+--R       ((2b e  - 7c d e)x  + (3b d e - 9c d )x)\|- b e + 2c d \|e \|b e - c d
+--R  /
+--R           2 2 3          3 2      2 4   2     2 3 2          4       2 5
+--R       ((3b d e  - 12b c d e  + 12c d e)x  + 3b d e  - 12b c d e + 12c d )
+--R    *
+--R                                       +--------+
+--R        +------------+ +-+ +---------+ |   2
+--R       \|- b e + 2c d \|e \|b e - c d \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1507
+
+--S 1508 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1508
+
+)clear all
+
+--S 1509 of 1718
+t0:=(d+e*x^2)^4*(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (1)
+--R        4 12       4         3  10       4         3       2 2  8
+--R     c e x   + (b e  + 4c d e )x   + (a e  + 4b d e  + 6c d e )x
+--R   + 
+--R            3       2 2       3   6        2 2       3       4  4
+--R     (4a d e  + 6b d e  + 4c d e)x  + (6a d e  + 4b d e + c d )x
+--R   + 
+--R          3       4  2      4
+--R     (4a d e + b d )x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 1509
+
+--S 1510 of 1718
+r0:=a*d^4*x+1/3*d^3*(b*d+4*a*e)*x^3+1/5*d^2*(c*d^2+4*b*d*e+6*a*e^2)*x^5+_
+   2/7*d*e*(2*c*d^2+e*(3*b*d+2*a*e))*x^7+1/9*e^2*(6*c*d^2+e*(4*b*d+a*e))*x^9+_
+   1/11*e^3*(4*c*d+b*e)*x^11+1/13*c*e^4*x^13
+--R 
+--R
+--R   (2)
+--R      1    4 13     1    4    4      3  11    1    4   4      3   2    2 2  9
+--R     -- c e x   + (-- b e  + -- c d e )x   + (- a e  + - b d e  + - c d e )x
+--R     13            11        11               9        9          3
+--R   + 
+--R      4      3   6    2 2   4    3   7    6    2 2   4    3    1    4  5
+--R     (- a d e  + - b d e  + - c d e)x  + (- a d e  + - b d e + - c d )x
+--R      7          7          7             5          5         5
+--R   + 
+--R      4    3    1    4  3      4
+--R     (- a d e + - b d )x  + a d x
+--R      3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1510
+
+--S 1511 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1511
+
+)clear all
+
+--S 1512 of 1718
+t0:=(d+e*x^2)^3*(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (1)
+--R        3 10       3         2  8       3         2       2   6
+--R     c e x   + (b e  + 3c d e )x  + (a e  + 3b d e  + 3c d e)x
+--R   + 
+--R            2       2       3  4        2       3  2      3
+--R     (3a d e  + 3b d e + c d )x  + (3a d e + b d )x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 1512
+
+--S 1513 of 1718
+r0:=a*d^3*x+1/3*d^2*(b*d+3*a*e)*x^3+1/5*d*(c*d^2+3*e*(b*d+a*e))*x^5+_
+   1/7*e*(3*c*d^2+e*(3*b*d+a*e))*x^7+1/9*e^2*(3*c*d+b*e)*x^9+1/11*c*e^3*x^11
+--R 
+--R
+--R   (2)
+--R      1    3 11    1    3   1      2  9    1    3   3      2   3    2   7
+--R     -- c e x   + (- b e  + - c d e )x  + (- a e  + - b d e  + - c d e)x
+--R     11            9        3              7        7          7
+--R   + 
+--R      3      2   3    2    1    3  5       2    1    3  3      3
+--R     (- a d e  + - b d e + - c d )x  + (a d e + - b d )x  + a d x
+--R      5          5         5                    3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1513
+
+--S 1514 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1514
+
+)clear all
+
+--S 1515 of 1718
+t0:=(d+e*x^2)^2*(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (1)
+--R        2 8       2           6       2               2  4                2  2
+--R     c e x  + (b e  + 2c d e)x  + (a e  + 2b d e + c d )x  + (2a d e + b d )x
+--R   + 
+--R        2
+--R     a d
+--R                                                    Type: Polynomial(Integer)
+--E 1515
+
+--S 1516 of 1718
+r0:=a*d^2*x+1/3*d*(b*d+2*a*e)*x^3+1/5*(c*d^2+e*(2*b*d+a*e))*x^5+_
+   1/7*e*(2*c*d+b*e)*x^7+1/9*c*e^2*x^9
+--R 
+--R
+--R   (2)
+--R     1    2 9    1    2   2        7    1    2   2         1    2  5
+--R     - c e x  + (- b e  + - c d e)x  + (- a e  + - b d e + - c d )x
+--R     9           7        7             5        5         5
+--R   + 
+--R      2         1    2  3      2
+--R     (- a d e + - b d )x  + a d x
+--R      3         3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1516
+
+--S 1517 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1517
+
+)clear all
+
+--S 1518 of 1718
+t0:=(d+e*x^2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R             6               4               2
+--R   (1)  c e x  + (b e + c d)x  + (a e + b d)x  + a d
+--R                                                    Type: Polynomial(Integer)
+--E 1518
+
+--S 1519 of 1718
+r0:=a*d*x+1/3*(b*d+a*e)*x^3+1/5*(c*d+b*e)*x^5+1/7*c*e*x^7
+--R 
+--R
+--R        1      7    1       1      5    1       1      3
+--R   (2)  - c e x  + (- b e + - c d)x  + (- a e + - b d)x  + a d x
+--R        7           5       5           3       3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1519
+
+--S 1520 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1520
+
+)clear all
+
+--S 1521 of 1718
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R               2
+--R            e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1521
+
+--S 1522 of 1718
+r0:=-(c*d-b*e)*x/e^2+1/3*c*x^3/e+(c*d^2-b*d*e+a*e^2)*atan(x*sqrt(e)/_
+   sqrt(d))/(e^(5/2)*sqrt(d))
+--R 
+--R
+--R   (2)
+--R                                  +-+
+--R        2                2      x\|e           3                   +-+ +-+
+--R   (3a e  - 3b d e + 3c d )atan(-----) + (c e x  + (3b e - 3c d)x)\|d \|e
+--R                                  +-+
+--R                                 \|d
+--R   -----------------------------------------------------------------------
+--R                                   2 +-+ +-+
+--R                                 3e \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 1522
+
+--S 1523 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1523
+
+)clear all
+
+--S 1524 of 1718
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^2
+--R 
+--R
+--R             4      2
+--R          c x  + b x  + a
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        e x  + 2d e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1524
+
+--S 1525 of 1718
+r0:=c*x/e^2+1/2*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2))-_
+   1/2*(3*c*d^2-e*(b*d+a*e))*atan(x*sqrt(e)/sqrt(d))/(d^(3/2)*e^(5/2))
+--R 
+--R
+--R   (2)
+--R                                                                   +-+
+--R            3        2       2   2        2      2        3      x\|e
+--R       ((a e  + b d e  - 3c d e)x  + a d e  + b d e - 3c d )atan(-----)
+--R                                                                   +-+
+--R                                                                  \|d
+--R     + 
+--R                3       2               2    +-+ +-+
+--R       (2c d e x  + (a e  - b d e + 3c d )x)\|d \|e
+--R  /
+--R          3 2     2 2  +-+ +-+
+--R     (2d e x  + 2d e )\|d \|e
+--R                                                    Type: Expression(Integer)
+--E 1525
+
+--S 1526 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1526
+
+)clear all
+
+--S 1527 of 1718
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^3
+--R 
+--R
+--R                  4      2
+--R               c x  + b x  + a
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        e x  + 3d e x  + 3d e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1527
+
+--S 1528 of 1718
+r0:=1/4*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^2)-1/8*(5*c*d^2-_
+   e*(b*d+3*a*e))*x/(d^2*e^2*(d+e*x^2))+1/8*(3*c*d^2+e*(b*d+3*a*e))*_
+   atan(x*sqrt(e)/sqrt(d))/(d^(5/2)*e^(5/2))
+--R 
+--R
+--R   (2)
+--R                4        3       2 2  4          3       2 2       3   2
+--R           (3a e  + b d e  + 3c d e )x  + (6a d e  + 2b d e  + 6c d e)x
+--R         + 
+--R               2 2      3        4
+--R           3a d e  + b d e + 3c d
+--R      *
+--R                +-+
+--R              x\|e
+--R         atan(-----)
+--R                +-+
+--R               \|d
+--R     + 
+--R             3        2       2   3          2      2        3    +-+ +-+
+--R       ((3a e  + b d e  - 5c d e)x  + (5a d e  - b d e - 3c d )x)\|d \|e
+--R  /
+--R        2 4 4      3 3 2     4 2  +-+ +-+
+--R     (8d e x  + 16d e x  + 8d e )\|d \|e
+--R                                                    Type: Expression(Integer)
+--E 1528
+
+--S 1529 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1529
+
+)clear all
+
+--S 1530 of 1718
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^4
+--R 
+--R
+--R                       4      2
+--R                    c x  + b x  + a
+--R   (1)  ---------------------------------------
+--R         4 8       3 6     2 2 4     3   2    4
+--R        e x  + 4d e x  + 6d e x  + 4d e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1530
+
+--S 1531 of 1718
+r0:=1/6*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^3)-1/24*(7*c*d^2-_
+   e*(b*d+5*a*e))*x/(d^2*e^2*(d+e*x^2)^2)+1/16*(c*d^2+e*(b*d+5*a*e))*_
+   x/(d^3*e^2*(d+e*x^2))+1/16*(c*d^2+e*(b*d+5*a*e))*atan(x*sqrt(e)/_
+   sqrt(d))/(d^(7/2)*e^(5/2))
+--R 
+--R
+--R   (2)
+--R                 5         4       2 3  6           4       2 3       3 2  4
+--R           (15a e  + 3b d e  + 3c d e )x  + (45a d e  + 9b d e  + 9c d e )x
+--R         + 
+--R                 2 3       3 2       4   2        3 2       4        5
+--R           (45a d e  + 9b d e  + 9c d e)x  + 15a d e  + 3b d e + 3c d
+--R      *
+--R                +-+
+--R              x\|e
+--R         atan(-----)
+--R                +-+
+--R               \|d
+--R     + 
+--R                 4         3       2 2  5           3       2 2       3   3
+--R           (15a e  + 3b d e  + 3c d e )x  + (40a d e  + 8b d e  - 8c d e)x
+--R         + 
+--R                 2 2       3        4
+--R           (33a d e  - 3b d e - 3c d )x
+--R      *
+--R          +-+ +-+
+--R         \|d \|e
+--R  /
+--R         3 5 6       4 4 4       5 3 2      6 2  +-+ +-+
+--R     (48d e x  + 144d e x  + 144d e x  + 48d e )\|d \|e
+--R                                                    Type: Expression(Integer)
+--E 1531
+
+--S 1532 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1532
+
+)clear all
+
+--S 1533 of 1718
+t0:=(d+e*x^2)^4/(a+b*x^2+c*x^4)
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        e x  + 4d e x  + 6d e x  + 4d e x  + d
+--R   (1)  ---------------------------------------
+--R                       4      2
+--R                    c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1533
+
+--S 1534 of 1718
+r0:=e^2*(6*c^2*d^2+b^2*e^2-c*e*(4*b*d+a*e))*x/c^3+1/3*e^3*(4*c*d-b*e)*_
+   x^3/c^2+1/5*e^4*x^5/c+atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (e*(2*c*d-b*e)*(2*c^2*d^2+b^2*e^2-2*c*e*(b*d+a*e))+(2*c^4*d^4+b^4*e^4-_
+   4*b^2*c*e^3*(b*d+a*e)-4*c^3*d^2*e*(b*d+3*a*e)+2*c^2*e^2*(3*b^2*d^2+_
+   6*a*b*d*e+a^2*e^2))/sqrt(b^2-4*a*c))/(c^(7/2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (e*(2*c*d-b*e)*(2*c^2*d^2+b^2*e^2-2*c*e*(b*d+a*e))+(-2*c^4*d^4-_
+   b^4*e^4+4*b^2*c*e^3*(b*d+a*e)+4*c^3*d^2*e*(b*d+3*a*e)-2*c^2*e^2*_
+   (3*b^2*d^2+6*a*b*d*e+a^2*e^2))/sqrt(b^2-4*a*c))/(c^(7/2)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                               3  4           2      2     3        2 2 2
+--R                 (30a b c - 15b )e  + (- 60a c  + 60b c)d e  - 90b c d e
+--R               + 
+--R                    3 3
+--R                 60c d e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R               2 2        2       4  4            2      3     3
+--R           (30a c  - 60a b c + 15b )e  + (180a b c  - 60b c)d e
+--R         + 
+--R                    3      2 2  2 2        3 3       4 4
+--R           (- 180a c  + 90b c )d e  - 60b c d e + 30c d
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                               3  4           2      2     3        2 2 2
+--R                 (30a b c - 15b )e  + (- 60a c  + 60b c)d e  - 90b c d e
+--R               + 
+--R                    3 3
+--R                 60c d e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R         + 
+--R                 2 2        2       4  4              2      3     3
+--R           (- 30a c  + 60a b c - 15b )e  + (- 180a b c  + 60b c)d e
+--R         + 
+--R                  3      2 2  2 2        3 3       4 4
+--R           (180a c  - 90b c )d e  + 60b c d e - 30c d
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R             2 4 5            4      2   3  3
+--R           3c e x  + (- 5b c e  + 20c d e )x
+--R         + 
+--R                          2  4            3      2 2 2
+--R           ((- 15a c + 15b )e  - 60b c d e  + 90c d e )x
+--R      *
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R          +-+ |          2  +-+ |   |          2       | |          2
+--R         \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R        3 +-+ |          2  +-+ |   |          2       | |          2
+--R     15c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1534
+
+--S 1535 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1535
+
+)clear all
+
+--S 1536 of 1718
+t0:=(d+e*x^2)^3/(a+b*x^2+c*x^4)
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        e x  + 3d e x  + 3d e x  + d
+--R   (1)  -----------------------------
+--R                  4      2
+--R               c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1536
+
+--S 1537 of 1718
+r0:=e^2*(3*c*d-b*e)*x/c^2+1/3*e^3*x^3/c+atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*(e*(3*c^2*d^2+b^2*e^2-c*e*(3*b*d+a*e))+(2*c*d-b*e)*_
+   (c^2*d^2+b^2*e^2-c*e*(b*d+3*a*e))/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (e*(3*c^2*d^2+b^2*e^2-c*e*(3*b*d+a*e))-(2*c*d-b*e)*(c^2*d^2+b^2*e^2-_
+   c*e*(b*d+3*a*e))/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                   +-----------+
+--R                        2  3           2     2 2   |          2
+--R           ((- 3a c + 3b )e  - 9b c d e  + 9c d e)\|- 4a c + b
+--R         + 
+--R                       3  3           2     2     2       2 2      3 3
+--R           (9a b c - 3b )e  + (- 18a c  + 9b c)d e  - 9b c d e + 6c d
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                                   +-----------+
+--R                        2  3           2     2 2   |          2
+--R           ((- 3a c + 3b )e  - 9b c d e  + 9c d e)\|- 4a c + b
+--R         + 
+--R                         3  3         2     2     2       2 2      3 3
+--R           (- 9a b c + 3b )e  + (18a c  - 9b c)d e  + 9b c d e - 6c d
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                             +-----------+
+--R             3 3          3         2    +-+ |          2  +-+
+--R         (c e x  + (- 3b e  + 9c d e )x)\|2 \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     3c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1537
+
+--S 1538 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1538
+
+)clear all
+
+--S 1539 of 1718
+t0:=(d+e*x^2)^2/(a+b*x^2+c*x^4)
+--R 
+--R
+--R         2 4         2    2
+--R        e x  + 2d e x  + d
+--R   (1)  -------------------
+--R             4      2
+--R          c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1539
+
+--S 1540 of 1718
+r0:=e^2*x/c+atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(e*(2*c*d-b*e)+_
+   (2*c^2*d^2+b^2*e^2-2*c*e*(b*d+a*e))/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (e*(2*c*d-b*e)+(-2*c^2*d^2-b^2*e^2+2*c*e*(b*d+a*e))/sqrt(b^2-4*a*c))/_
+   (c^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                            +-----------+
+--R                2           |          2               2  2                2 2
+--R         ((- b e  + 2c d e)\|- 4a c + b   + (- 2a c + b )e  - 2b c d e + 2c d )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                            +-----------+
+--R                2           |          2             2  2                2 2
+--R         ((- b e  + 2c d e)\|- 4a c + b   + (2a c - b )e  + 2b c d e - 2c d )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                 +--------------------+ +------------------+
+--R               +-----------+     |   +-----------+      | +-----------+
+--R        2  +-+ |          2  +-+ |   |          2       | |          2
+--R       e x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R           +-----------+     |   +-----------+      | +-----------+
+--R       +-+ |          2  +-+ |   |          2       | |          2
+--R     c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1540
+
+--S 1541 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1541
+
+)clear all
+
+--S 1542 of 1718
+t0:=(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               2
+--R            e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1542
+
+--S 1543 of 1718
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(e+(2*c*d-b*e)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(e+(-2*c*d+b*e)/sqrt(b^2-_
+   4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2                | |          2
+--R         (e\|- 4a c + b   - b e + 2c d)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2                |   |          2
+--R         (e\|- 4a c + b   + b e - 2c d)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1543
+
+--S 1544 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1544
+
+)clear all
+
+--S 1545 of 1718
+t0:=1/(a+b*x^2+c*x^4)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1545
+
+--S 1546 of 1718
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/_
+   (sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                +------------------+
+--R                | +-----------+                   +-+ +-+
+--R        +-+ +-+ | |          2                  x\|2 \|c
+--R       \|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                          +--------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + b
+--R     + 
+--R                  +--------------------+
+--R                  |   +-----------+                  +-+ +-+
+--R          +-+ +-+ |   |          2                 x\|2 \|c
+--R       - \|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                              | |          2
+--R                                             \|\|- 4a c + b   + b
+--R  /
+--R                    +--------------------+ +------------------+
+--R      +-----------+ |   +-----------+      | +-----------+
+--R      |          2  |   |          2       | |          2
+--R     \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1546
+
+--S 1547 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1547
+
+)clear all
+
+--S 1548 of 1718
+t0:=1/((d+e*x^2)*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R             6               4               2
+--R        c e x  + (b e + c d)x  + (a e + b d)x  + a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1548
+
+--S 1549 of 1718
+r0:=e^(3/2)*atan(x*sqrt(e)/sqrt(d))/((c*d^2-b*d*e+a*e^2)*sqrt(d))-_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(e+_
+   (-2*c*d+b*e)/sqrt(b^2-4*a*c))/((c*d^2-b*d*e+a*e^2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/((c*d^2-b*d*e+a*e^2)*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                  +------------------+
+--R              +-----------+                       | +-----------+
+--R              |          2                +-+ +-+ | |          2
+--R         (- e\|- 4a c + b   - b e + 2c d)\|c \|d \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                  +--------------------+
+--R              +-----------+                       |   +-----------+
+--R              |          2                +-+ +-+ |   |          2
+--R         (- e\|- 4a c + b   + b e - 2c d)\|c \|d \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R               +-----------+           +-+  |   +-----------+
+--R           +-+ |          2  +-+     x\|e   |   |          2
+--R         e\|2 \|- 4a c + b  \|e atan(-----)\|- \|- 4a c + b   + b
+--R                                       +-+
+--R                                      \|d
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                                                   +--------------------+
+--R                                 +-----------+     |   +-----------+
+--R           2              2  +-+ |          2  +-+ |   |          2
+--R       (a e  - b d e + c d )\|2 \|- 4a c + b  \|d \|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1549
+
+--S 1550 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1550
+
+)clear all
+
+--S 1551 of 1718
+t0:=1/((d+e*x^2)^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          2 8       2           6       2               2  4                2  2
+--R       c e x  + (b e  + 2c d e)x  + (a e  + 2b d e + c d )x  + (2a d e + b d )x
+--R     + 
+--R          2
+--R       a d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1551
+
+--S 1552 of 1718
+r0:=1/2*e^2*x/(d*(c*d^2-b*d*e+a*e^2)*(d+e*x^2))+1/2*e^(3/2)*atan(x*_
+   sqrt(e)/sqrt(d))/(d^(3/2)*(c*d^2-b*d*e+a*e^2))+e^(3/2)*(2*c*d-b*e)*_
+   atan(x*sqrt(e)/sqrt(d))/((c*d^2-b*d*e+a*e^2)^2*sqrt(d))-atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(2*c*d*e-b*e^2+(-2*c^2*d^2-_
+   b^2*e^2+2*c*e*(b*d+a*e))/sqrt(b^2-4*a*c))/((c*d^2-b*d*e+a*e^2)^2*_
+   sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(2*c*d*e-b*e^2+(2*c^2*d^2+b^2*e^2-2*c*e*_
+   (b*d+a*e))/sqrt(b^2-4*a*c))/((c*d^2-b*d*e+a*e^2)^2*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                      +-----------+
+--R                   3       2 2  2       2 2       3   |          2
+--R           ((2b d e  - 4c d e )x  + 2b d e  - 4c d e)\|- 4a c + b
+--R         + 
+--R                        2    3         2 2     2 3   2               2  2 2
+--R           ((- 4a c + 2b )d e  - 4b c d e  + 4c d e)x  + (- 4a c + 2b )d e
+--R         + 
+--R                   3      2 4
+--R           - 4b c d e + 4c d
+--R      *
+--R                  +------------------+
+--R                  | +-----------+                   +-+ +-+
+--R          +-+ +-+ | |          2                  x\|2 \|c
+--R         \|c \|d \|\|- 4a c + b   + b atan(-----------------------)
+--R                                            +--------------------+
+--R                                            |   +-----------+
+--R                                            |   |          2
+--R                                           \|- \|- 4a c + b   + b
+--R     + 
+--R                                                      +-----------+
+--R                   3       2 2  2       2 2       3   |          2
+--R           ((2b d e  - 4c d e )x  + 2b d e  - 4c d e)\|- 4a c + b
+--R         + 
+--R                      2    3         2 2     2 3   2             2  2 2
+--R           ((4a c - 2b )d e  + 4b c d e  - 4c d e)x  + (4a c - 2b )d e
+--R         + 
+--R                 3      2 4
+--R           4b c d e - 4c d
+--R      *
+--R                  +--------------------+
+--R                  |   +-----------+                  +-+ +-+
+--R          +-+ +-+ |   |          2                 x\|2 \|c
+--R         \|c \|d \|- \|- 4a c + b   + b atan(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                              | |          2
+--R                                             \|\|- 4a c + b   + b
+--R     + 
+--R                  4         3       2 2  2        3       2 2       3   +-+
+--R             ((a e  - 3b d e  + 5c d e )x  + a d e  - 3b d e  + 5c d e)\|2
+--R          *
+--R              +-----------+           +-+
+--R              |          2  +-+     x\|e
+--R             \|- 4a c + b  \|e atan(-----)
+--R                                      +-+
+--R                                     \|d
+--R         + 
+--R                                         +-----------+
+--R               4        3      2 2   +-+ |          2  +-+
+--R           (a e  - b d e  + c d e )x\|2 \|- 4a c + b  \|d
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R            2   5         2 4             2  3 3         4 2     2 5   2
+--R         (2a d e  - 4a b d e  + (4a c + 2b )d e  - 4b c d e  + 2c d e)x
+--R       + 
+--R           2 2 4         3 3             2  4 2         5      2 6
+--R         2a d e  - 4a b d e  + (4a c + 2b )d e  - 4b c d e + 2c d
+--R    *
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R       \|2 \|- 4a c + b  \|d \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1552
+
+--S 1553 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1553
+
+)clear all
+
+--S 1554 of 1718
+t0:=(d+e*x^2)*sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                   +---------------+
+--R            2      |   4      2
+--R   (1)  (e x  + d)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1554
+
+--S 1555 of 1718
+--r0:=1/15*x*(5*c*d+b*e+3*c*e*x^2)*sqrt(a+b*x^2+c*x^4)/c+1/30*(5*b*c*d-_
+---  2*b^2*e+6*a*c*e)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a+b*x^2+_
+---  c*x^4))-1/30*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+---  sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+---  (b+sqrt(b^2-4*a*c))*(5*b*c*d-2*b^2*e+6*a*c*e-2*a*c*(10*c*d-b*e)/_
+---  (b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*_
+---  sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1555
+
+--S 1556 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1556
+
+)clear all
+
+--S 1557 of 1718
+t0:=sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R   (1)  \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1557
+
+--S 1558 of 1718
+--r0:=1/3*x*sqrt(a+b*x^2+c*x^4)+1/6*b*elliptic_e(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-_
+---  4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/_
+---  (c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-1/6*elliptic_f(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/_
+---  (b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1558
+
+--S 1559 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1559
+
+)clear all
+
+--S 1560 of 1718
+t0:=sqrt(a+b*x^2+c*x^4)/(d+e*x^2)
+--R 
+--R
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R   (1)  ------------------
+--R                2
+--R             e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1560
+
+--S 1561 of 1718
+--r0:=-elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)*_
+---  sqrt(a+b*x^2+c*x^4)/(e*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))+_
+---  elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)*(2*c*d-_
+---  e*(b-sqrt(b^2-4*a*c)))*sqrt(a+b*x^2+c*x^4)/(e^2*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))-2*(c*d^2-b*d*e+a*e^2)*_
+---  elliptic_pi(1/2*e*(b+sqrt(b^2-4*a*c))/(c*d),asin(x*sqrt(2)*_
+---  sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/_
+---  (b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(-c)*sqrt(a+b*x^2+c*x^4)/(d*e^2*_
+---  (b-sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))
+--E 1561
+
+--S 1562 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1562
+
+)clear all
+
+--S 1563 of 1718
+t0:=x^5/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     5
+--R                    x
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1563
+
+--S 1564 of 1718
+r0:=-1/4*b*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/c^(3/2)-_
+   1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/sqrt(c)-_
+   1/2*atanh(1/2*(2*a-b+(b-2*c)*x^2)/(sqrt(a-b+c)*sqrt(a+b*x^2+c*x^4)))/_
+   sqrt(a-b+c)+1/2*sqrt(a+b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                                  2
+--R          +-+            (2c - b)x  + b - 2a
+--R       2c\|c atanh(-------------------------------)
+--R                                 +---------------+
+--R                     +---------+ |   4      2
+--R                   2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                                              2
+--R                  +---------+             2c x  + b
+--R       (- 2c - b)\|c - b + a atanh(-----------------------)
+--R                                         +---------------+
+--R                                     +-+ |   4      2
+--R                                   2\|c \|c x  + b x  + a
+--R     + 
+--R                         +---------------+
+--R         +---------+ +-+ |   4      2
+--R       2\|c - b + a \|c \|c x  + b x  + a
+--R  /
+--R        +---------+ +-+
+--R     4c\|c - b + a \|c
+--R                                                    Type: Expression(Integer)
+--E 1564
+
+--S 1565 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1565
+
+)clear all
+
+--S 1566 of 1718
+t0:=x^4/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     4
+--R                    x
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1566
+
+--S 1567 of 1718
+--r0:=elliptic_pi(1/2*(b+sqrt(b^2-4*a*c))/c,asin(x*sqrt(2)*sqrt(-c)/_
+---  sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(a+b*x^2+c*x^4)*sqrt(b+sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(-c)*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-_
+---  4*a*c))))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(-b+sqrt(b^2-_
+---  4*a*c))^(3/2)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/_
+---  (b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))-_
+---  elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))-_
+---  1/2*elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),_
+---  (b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*(b-sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/((-c)^(3/2)*sqrt(2)*_
+---  sqrt(a+b*x^2+c*x^4))
+--E 1567
+
+--S 1568 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1568
+
+)clear all
+
+--S 1569 of 1718
+t0:=x^3/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     3
+--R                    x
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1569
+
+--S 1570 of 1718
+r0:=1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))/sqrt(c)+_
+   1/2*atanh(1/2*(2*a-b+(b-2*c)*x^2)/(sqrt(a-b+c)*sqrt(a+b*x^2+c*x^4)))/_
+   sqrt(a-b+c)
+--R 
+--R
+--R   (2)
+--R                                  2
+--R          +-+            (2c - b)x  + b - 2a
+--R       - \|c atanh(-------------------------------)
+--R                                 +---------------+
+--R                     +---------+ |   4      2
+--R                   2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                                    2
+--R        +---------+             2c x  + b
+--R       \|c - b + a atanh(-----------------------)
+--R                               +---------------+
+--R                           +-+ |   4      2
+--R                         2\|c \|c x  + b x  + a
+--R  /
+--R       +---------+ +-+
+--R     2\|c - b + a \|c
+--R                                                    Type: Expression(Integer)
+--E 1570
+
+--S 1571 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1571
+
+)clear all
+
+--S 1572 of 1718
+t0:=x^2/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     2
+--R                    x
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1572
+
+--S 1573 of 1718
+--r0:=-elliptic_pi(1/2*(b+sqrt(b^2-4*a*c))/c,asin(x*sqrt(2)*_
+---  sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(a+b*x^2+c*x^4)*sqrt(b+sqrt(b^2-4*a*c))/_
+---  (a*sqrt(2)*sqrt(-c)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))+elliptic_f(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*_
+---  sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 1573
+
+--S 1574 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1574
+
+)clear all
+
+--S 1575 of 1718
+t0:=x/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     x
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1575
+
+--S 1576 of 1718
+r0:=-1/2*atanh(1/2*(2*a-b+(b-2*c)*x^2)/(sqrt(a-b+c)*sqrt(a+b*x^2+c*x^4)))/_
+   sqrt(a-b+c)
+--R 
+--R
+--R                             2
+--R                    (2c - b)x  + b - 2a
+--R        atanh(-------------------------------)
+--R                            +---------------+
+--R                +---------+ |   4      2
+--R              2\|c - b + a \|c x  + b x  + a
+--R   (2)  --------------------------------------
+--R                       +---------+
+--R                     2\|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 1576
+
+--S 1577 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1577
+
+)clear all
+
+--S 1578 of 1718
+t0:=1/((1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          2      |   4      2
+--R        (x  + 1)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1578
+
+--S 1579 of 1718
+--r0:=elliptic_pi(1/2*(b+sqrt(b^2-4*a*c))/c,asin(x*sqrt(2)*sqrt(-c)/_
+---  sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(a+b*x^2+c*x^4)*sqrt(b+sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(-c)*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))
+--E 1579
+
+--S 1580 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1580
+
+)clear all
+
+--S 1581 of 1718
+t0:=1/(x*(1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                 +---------------+
+--R          3      |   4      2
+--R        (x  + x)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1581
+
+--S 1582 of 1718
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)+_
+   1/2*atanh(1/2*(2*a-b+(b-2*c)*x^2)/(sqrt(a-b+c)*sqrt(a+b*x^2+c*x^4)))/_
+   sqrt(a-b+c)
+--R 
+--R
+--R   (2)
+--R                                     2
+--R          +---------+             b x  + 2a
+--R       - \|c - b + a atanh(-----------------------)
+--R                                 +---------------+
+--R                             +-+ |   4      2
+--R                           2\|a \|c x  + b x  + a
+--R     + 
+--R                                  2
+--R          +-+            (2c - b)x  + b - 2a
+--R       - \|a atanh(-------------------------------)
+--R                                 +---------------+
+--R                     +---------+ |   4      2
+--R                   2\|c - b + a \|c x  + b x  + a
+--R  /
+--R       +-+ +---------+
+--R     2\|a \|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 1582
+
+--S 1583 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1583
+
+)clear all
+
+--S 1584 of 1718
+t0:=1/(x^2*(1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                  +---------------+
+--R          4    2  |   4      2
+--R        (x  + x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1584
+
+--S 1585 of 1718
+--r0:=-sqrt(a+b*x^2+c*x^4)/(a*x)-elliptic_pi(1/2*(b+sqrt(b^2-4*a*c))/c,_
+---  asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/_
+---  (b-sqrt(b^2-4*a*c)))*sqrt(a+b*x^2+c*x^4)*sqrt(b+sqrt(b^2-4*a*c))/(a*_
+---  sqrt(2)*sqrt(-c)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/_
+---  (b+sqrt(b^2-4*a*c))))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+_
+---  sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(-b+_
+---  sqrt(b^2-4*a*c))^(3/2)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+_
+---  c*x^4))+1/2*elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+_
+---  sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*_
+---  (b-sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*_
+---  sqrt(-c)*sqrt(a+b*x^2+c*x^4))
+--E 1585
+
+--S 1586 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1586
+
+)clear all
+
+--S 1587 of 1718
+t0:=1/(x^3*(1+x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                  +---------------+
+--R          5    3  |   4      2
+--R        (x  + x )\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1587
+
+--S 1588 of 1718
+r0:=1/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/a^(3/2)+_
+   1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))/sqrt(a)-_
+   1/2*atanh(1/2*(2*a-b+(b-2*c)*x^2)/(sqrt(a-b+c)*sqrt(a+b*x^2+c*x^4)))/_
+   sqrt(a-b+c)-1/2*sqrt(a+b*x^2+c*x^4)/(a*x^2)
+--R 
+--R
+--R   (2)
+--R                                             2
+--R                2 +---------+             b x  + 2a
+--R       (b + 2a)x \|c - b + a atanh(-----------------------)
+--R                                         +---------------+
+--R                                     +-+ |   4      2
+--R                                   2\|a \|c x  + b x  + a
+--R     + 
+--R                                     2
+--R           2 +-+            (2c - b)x  + b - 2a
+--R       2a x \|a atanh(-------------------------------)
+--R                                    +---------------+
+--R                        +---------+ |   4      2
+--R                      2\|c - b + a \|c x  + b x  + a
+--R     + 
+--R                           +---------------+
+--R           +-+ +---------+ |   4      2
+--R       - 2\|a \|c - b + a \|c x  + b x  + a
+--R  /
+--R         2 +-+ +---------+
+--R     4a x \|a \|c - b + a
+--R                                                    Type: Expression(Integer)
+--E 1588
+
+--S 1589 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1589
+
+)clear all
+
+--S 1590 of 1718
+t0:=(d+e*x^2)^2/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R         2 4         2    2
+--R        e x  + 2d e x  + d
+--R   (1)  -------------------
+--R          +---------------+
+--R          |   4      2
+--R         \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1590
+
+--S 1591 of 1718
+--r0:=1/3*e^2*x*sqrt(a+b*x^2+c*x^4)/c+1/12*b*e^2*elliptic_e(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-_
+---  4*a*c)))*(-b+sqrt(b^2-4*a*c))^(3/2)*(b+sqrt(b^2-4*a*c))^2*sqrt(a+_
+---  b*x^2+c*x^4)/(a^2*c^(7/2)*sqrt(2)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))-1/12*e^2*elliptic_f(asin(x*_
+---  sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+_
+---  sqrt(b^2-4*a*c)))*(-b+sqrt(b^2-4*a*c))^(3/2)*(b+sqrt(b^2-4*a*c))*_
+---  (b^2-a*c+b*sqrt(b^2-4*a*c))*sqrt(a+b*x^2+c*x^4)/(a^2*c^(7/2)*sqrt(2)*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-_
+---  4*a*c))))+d^2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-_
+---  4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(a+b*x^2+_
+---  c*x^4)*sqrt(-b+sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(c)*sqrt(1+2*c*x^2/_
+---  (b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))+d*e*_
+---  elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-_
+---  sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(a+_
+---  b*x^2+c*x^4)*sqrt(-b+sqrt(b^2-4*a*c))/(a*c^(3/2)*sqrt(2)*sqrt(1+_
+---  2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))-_
+---  d*e*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(a+b*x^2+c*x^4)*sqrt(-b+sqrt(b^2-4*a*c))/(a*c^(3/2)*sqrt(2)*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c))))
+--E 1591
+
+--S 1592 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1592
+
+)clear all
+
+--S 1593 of 1718
+t0:=(d+e*x^2)/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                2
+--R             e x  + d
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1593
+
+--S 1594 of 1718
+--r0:=1/2*e*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+_
+---  2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+_
+---  2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))+_
+---  1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(2*c*d-e*(b+sqrt(b^2-4*a*c)))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a+b*x^2+c*x^4))
+--E 1594
+
+--S 1595 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1595
+
+)clear all
+
+--S 1596 of 1718
+t0:=1/sqrt(a+b*x^2+c*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         |   4      2
+--R        \|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1596
+
+--S 1597 of 1718
+--r0:=elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b-_
+---  sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 1597
+
+--S 1598 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1598
+
+)clear all
+
+--S 1599 of 1718
+t0:=1/((d+e*x^2)*sqrt(a+b*x^2+c*x^4))
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R                   +---------------+
+--R            2      |   4      2
+--R        (e x  + d)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1599
+
+--S 1600 of 1718
+--r0:=elliptic_pi(1/2*e*(b+sqrt(b^2-4*a*c))/(c*d),asin(x*sqrt(2)*_
+---  sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-_
+---  4*a*c)))*sqrt(a+b*x^2+c*x^4)*sqrt(b+sqrt(b^2-4*a*c))/(a*d*sqrt(2)*_
+---  sqrt(-c)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+_
+---  sqrt(b^2-4*a*c))))
+--E 1600
+
+--S 1601 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1601
+
+)clear all
+
+--S 1602 of 1718
+t0:=(d+e*x^2)/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                         2
+--R                      e x  + d
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1602
+
+--S 1603 of 1718
+--r0:=x*(b^2*d-2*a*c*d-a*b*e+c*(b*d-2*a*e)*x^2)/(a*(b^2-4*a*c)*_
+---  sqrt(a+b*x^2+c*x^4))-1/2*(b*d-2*a*e)*elliptic_e(asin(x*sqrt(2)*_
+---  sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-_
+---  4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*_
+---  (b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))+_
+---  1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2*d-4*a*c*d+(b*d-2*a*e)*_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+---  sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*_
+---  sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 1603
+
+--S 1604 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1604
+
+)clear all
+
+--S 1605 of 1718
+t0:=1/(a+b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                         1
+--R   (1)  -----------------------------------
+--R                          +---------------+
+--R            4      2      |   4      2
+--R        (c x  + b x  + a)\|c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1605
+
+--S 1606 of 1718
+--r0:=x*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*sqrt(a+b*x^2+c*x^4))-_
+---  1/2*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),_
+---  (b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*_
+---  sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*_
+---  sqrt(a+b*x^2+c*x^4))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/_
+---  sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*_
+---  (b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*_
+---  sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*_
+---  (b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a+b*x^2+c*x^4))
+--E 1606
+
+--S 1607 of 1718
+--d0normalize(:=t0-D(r0,x))
+--E 1607
+
+)clear all
+
+--S 1608 of 1718
+t0:=(d+e*x^2)^(5/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R   (1)
+--R          2 8       2           6       2               2  4                2  2
+--R       c e x  + (b e  + 2c d e)x  + (a e  + 2b d e + c d )x  + (2a d e + b d )x
+--R     + 
+--R          2
+--R       a d
+--R  *
+--R      +--------+
+--R      |   2
+--R     \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1608
+
+--S 1609 of 1718
+r0:=1/384*d*(3*c*d^2-10*b*d*e+80*a*e^2)*x*(d+e*x^2)^(3/2)/e^2+_
+   1/480*(3*c*d^2-10*b*d*e+80*a*e^2)*x*(d+e*x^2)^(5/2)/e^2-1/7*(c*d^2-_
+   b*d*e+a*e^2)*x*(d+e*x^2)^(7/2)/(d*e^2)+1/560*(3*c*d^2-10*b*d*e+_
+   80*a*e^2)*x*(d+e*x^2)^(7/2)/(d*e^2)+1/10*c*x*(d+e*x^2)^(9/2)/e^2+_
+   1/256*d^3*(3*c*d^2-10*b*d*e+80*a*e^2)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/_
+   e^(5/2)+1/256*d^2*(3*c*d^2-10*b*d*e+80*a*e^2)*x*sqrt(d+e*x^2)/e^2
+--R 
+--R
+--R   (2)
+--R                                                  +-+
+--R               3 2         4         5          x\|e
+--R       (1200a d e  - 150b d e + 45c d )atanh(-----------)
+--R                                              +--------+
+--R                                              |   2
+--R                                             \|e x  + d
+--R     + 
+--R                 4 9          4            3  7
+--R           384c e x  + (480b e  + 1008c d e )x
+--R         + 
+--R                  4            3         2 2  5
+--R           (640a e  + 1360b d e  + 744c d e )x
+--R         + 
+--R                     3          2 2        3   3
+--R           (2080a d e  + 1180b d e  + 30c d e)x
+--R         + 
+--R                   2 2         3         4
+--R           (2640a d e  + 150b d e - 45c d )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|e \|e x  + d
+--R  /
+--R          2 +-+
+--R     3840e \|e
+--R                                                    Type: Expression(Integer)
+--E 1609
+
+--S 1610 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1610
+
+)clear all
+
+--S 1611 of 1718
+t0:=(d+e*x^2)^(3/2)*(a+b*x^2+c*x^4)
+--R 
+--R
+--R                                                       +--------+
+--R              6               4               2        |   2
+--R   (1)  (c e x  + (b e + c d)x  + (a e + b d)x  + a d)\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1611
+
+--S 1612 of 1718
+r0:=1/192*(3*c*d^2-8*b*d*e+48*a*e^2)*x*(d+e*x^2)^(3/2)/e^2-_
+   1/5*(c*d^2-b*d*e+a*e^2)*x*(d+e*x^2)^(5/2)/(d*e^2)+1/240*(3*c*d^2-_
+   8*b*d*e+48*a*e^2)*x*(d+e*x^2)^(5/2)/(d*e^2)+1/8*c*x*(d+e*x^2)^(7/2)/e^2+_
+   1/128*d^2*(3*c*d^2-8*b*d*e+48*a*e^2)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/_
+   e^(5/2)+1/128*d*(3*c*d^2-8*b*d*e+48*a*e^2)*x*sqrt(d+e*x^2)/e^2
+--R 
+--R
+--R   (2)
+--R                                               +-+
+--R              2 2        3        4          x\|e
+--R       (144a d e  - 24b d e + 9c d )atanh(-----------)
+--R                                           +--------+
+--R                                           |   2
+--R                                          \|e x  + d
+--R     + 
+--R                3 7         3          2  5         3           2       2   3
+--R           48c e x  + (64b e  + 72c d e )x  + (96a e  + 112b d e  + 6c d e)x
+--R         + 
+--R                    2        2        3
+--R           (240a d e  + 24b d e - 9c d )x
+--R      *
+--R              +--------+
+--R          +-+ |   2
+--R         \|e \|e x  + d
+--R  /
+--R         2 +-+
+--R     384e \|e
+--R                                                    Type: Expression(Integer)
+--E 1612
+
+--S 1613 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1613
+
+)clear all
+
+--S 1614 of 1718
+t0:=(a+b*x^2+c*x^4)*sqrt(d+e*x^2)
+--R 
+--R
+--R                          +--------+
+--R            4      2      |   2
+--R   (1)  (c x  + b x  + a)\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1614
+
+--S 1615 of 1718
+r0:=-1/3*(c*d^2-b*d*e+a*e^2)*x*(d+e*x^2)^(3/2)/(d*e^2)+1/24*(c*d^2-_
+   2*b*d*e+8*a*e^2)*x*(d+e*x^2)^(3/2)/(d*e^2)+1/6*c*x*(d+e*x^2)^(5/2)/e^2+_
+   1/16*d*(c*d^2-2*b*d*e+8*a*e^2)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/e^(5/2)+_
+   1/16*(c*d^2-2*b*d*e+8*a*e^2)*x*sqrt(d+e*x^2)/e^2
+--R 
+--R
+--R   (2)
+--R                                             +-+
+--R               2       2        3          x\|e
+--R       (24a d e  - 6b d e + 3c d )atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|e x  + d
+--R     + 
+--R                                                                      +--------+
+--R          2 5         2           3         2                2    +-+ |   2
+--R     (8c e x  + (12b e  + 2c d e)x  + (24a e  + 6b d e - 3c d )x)\|e \|e x  + d
+--R  /
+--R        2 +-+
+--R     48e \|e
+--R                                                    Type: Expression(Integer)
+--E 1615
+
+--S 1616 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1616
+
+)clear all
+
+--S 1617 of 1718
+t0:=(a+b*x^2+c*x^4)/sqrt(d+e*x^2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x  + a
+--R   (1)  ---------------
+--R           +--------+
+--R           |   2
+--R          \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1617
+
+--S 1618 of 1718
+r0:=1/4*c*x*(d+e*x^2)^(3/2)/e^2+1/8*(3*c*d^2-4*b*d*e+8*a*e^2)*atanh(x*_
+   sqrt(e)/sqrt(d+e*x^2))/e^(5/2)-(c*d^2-b*d*e+a*e^2)*x*sqrt(d+e*x^2)/_
+   (d*e^2)+1/8*(3*c*d^2-4*b*d*e+8*a*e^2)*x*sqrt(d+e*x^2)/(d*e^2)
+--R 
+--R
+--R   (2)
+--R                                          +-+
+--R            2                2          x\|e
+--R       (8a e  - 4b d e + 3c d )atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|e x  + d
+--R     + 
+--R                                      +--------+
+--R              3                   +-+ |   2
+--R       (2c e x  + (4b e - 3c d)x)\|e \|e x  + d
+--R  /
+--R       2 +-+
+--R     8e \|e
+--R                                                    Type: Expression(Integer)
+--E 1618
+
+--S 1619 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1619
+
+)clear all
+
+--S 1620 of 1718
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^(3/2)
+--R 
+--R
+--R              4      2
+--R           c x  + b x  + a
+--R   (1)  ---------------------
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1620
+
+--S 1621 of 1718
+r0:=-1/2*(3*c*d-2*b*e)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/e^(5/2)+_
+   (c*d^2-b*d*e+a*e^2)*x/(d*e^2*sqrt(d+e*x^2))+1/2*c*x*sqrt(d+e*x^2)/e^2
+--R 
+--R
+--R   (2)
+--R                        +--------+           +-+
+--R                     2  |   2              x\|e
+--R       (2b d e - 3c d )\|e x  + d atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|e x  + d
+--R     + 
+--R               3        2                2    +-+
+--R       (c d e x  + (2a e  - 2b d e + 3c d )x)\|e
+--R  /
+--R               +--------+
+--R         2 +-+ |   2
+--R     2d e \|e \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1621
+
+--S 1622 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1622
+
+)clear all
+
+--S 1623 of 1718
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^(5/2)
+--R 
+--R
+--R                    4      2
+--R                 c x  + b x  + a
+--R   (1)  --------------------------------
+--R                              +--------+
+--R          2 4         2    2  |   2
+--R        (e x  + 2d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1623
+
+--S 1624 of 1718
+r0:=1/3*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^(3/2))+c*atanh(x*sqrt(e)/_
+   sqrt(d+e*x^2))/e^(5/2)-1/3*(4*c*d^2-e*(b*d+2*a*e))*x/(d^2*e^2*sqrt(d+e*x^2))
+--R 
+--R
+--R   (2)
+--R                           +--------+           +-+
+--R            2   2       3  |   2              x\|e
+--R       (3c d e x  + 3c d )\|e x  + d atanh(-----------)
+--R                                            +--------+
+--R                                            |   2
+--R                                           \|e x  + d
+--R     + 
+--R             3        2       2   3          2       3    +-+
+--R       ((2a e  + b d e  - 4c d e)x  + (3a d e  - 3c d )x)\|e
+--R  /
+--R                           +--------+
+--R        2 3 2     3 2  +-+ |   2
+--R     (3d e x  + 3d e )\|e \|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1624
+
+--S 1625 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1625
+
+)clear all
+
+--S 1626 of 1718
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^(7/2)
+--R 
+--R
+--R                         4      2
+--R                      c x  + b x  + a
+--R   (1)  ------------------------------------------
+--R                                        +--------+
+--R          3 6       2 4     2   2    3  |   2
+--R        (e x  + 3d e x  + 3d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1626
+
+--S 1627 of 1718
+r0:=1/5*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^(5/2))-1/15*(6*c*d^2-_
+   e*(b*d+4*a*e))*x/(d^2*e^2*(d+e*x^2)^(3/2))+1/15*(3*c*d^2+2*e*(b*d+_
+   4*a*e))*x/(d^3*e^2*sqrt(d+e*x^2))
+--R 
+--R
+--R             2                2  5                  2  3        2
+--R        (8a e  + 2b d e + 3c d )x  + (20a d e + 5b d )x  + 15a d x
+--R   (2)  ----------------------------------------------------------
+--R                                               +--------+
+--R                      3 2 4      4   2      5  |   2
+--R                  (15d e x  + 30d e x  + 15d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1627
+
+--S 1628 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1628
+
+)clear all
+
+--S 1629 of 1718
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^(9/2)
+--R 
+--R
+--R                              4      2
+--R                           c x  + b x  + a
+--R   (1)  ----------------------------------------------------
+--R                                                  +--------+
+--R          4 8       3 6     2 2 4     3   2    4  |   2
+--R        (e x  + 4d e x  + 6d e x  + 4d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1629
+
+--S 1630 of 1718
+r0:=1/7*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^(7/2))-1/35*(8*c*d^2-_
+   e*(b*d+6*a*e))*x/(d^2*e^2*(d+e*x^2)^(5/2))+1/105*(3*c*d^2+4*e*(b*d+_
+   6*a*e))*x/(d^3*e^2*(d+e*x^2)^(3/2))+2/105*(3*c*d^2+4*e*(b*d+6*a*e))*x/_
+   (d^4*e^2*sqrt(d+e*x^2))
+--R 
+--R
+--R   (2)
+--R             3         2       2   7            2        2         3  5
+--R       (48a e  + 8b d e  + 6c d e)x  + (168a d e  + 28b d e + 21c d )x
+--R     + 
+--R              2         3  3         3
+--R       (210a d e + 35b d )x  + 105a d x
+--R  /
+--R                                                 +--------+
+--R          4 3 6       5 2 4       6   2       7  |   2
+--R     (105d e x  + 315d e x  + 315d e x  + 105d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1630
+
+--S 1631 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1631
+
+)clear all
+
+--S 1632 of 1718
+t0:=(a+b*x^2+c*x^4)/(d+e*x^2)^(11/2)
+--R 
+--R
+--R                                    4      2
+--R                                 c x  + b x  + a
+--R   (1)  -----------------------------------------------------------------
+--R                                                               +--------+
+--R          5 10       4 8      2 3 6      3 2 4     4   2    5  |   2
+--R        (e x   + 5d e x  + 10d e x  + 10d e x  + 5d e x  + d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1632
+
+--S 1633 of 1718
+r0:=1/9*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^2)^(9/2))-1/63*(10*c*d^2-_
+   e*(b*d+8*a*e))*x/(d^2*e^2*(d+e*x^2)^(7/2))+1/105*(c*d^2+2*e*(b*d+_
+   8*a*e))*x/(d^3*e^2*(d+e*x^2)^(5/2))+4/315*(c*d^2+2*e*(b*d+8*a*e))*_
+   x/(d^4*e^2*(d+e*x^2)^(3/2))+8/315*(c*d^2+2*e*(b*d+8*a*e))*x/(d^5*e^2*_
+   sqrt(d+e*x^2))
+--R 
+--R
+--R   (2)
+--R              4          3       2 2  9            3        2 2        3   7
+--R       (128a e  + 16b d e  + 8c d e )x  + (576a d e  + 72b d e  + 36c d e)x
+--R     + 
+--R               2 2         3         4  5          3          4  3         4
+--R       (1008a d e  + 126b d e + 63c d )x  + (840a d e + 105b d )x  + 315a d x
+--R  /
+--R                                                                +--------+
+--R          5 4 8        6 3 6        7 2 4        8   2       9  |   2
+--R     (315d e x  + 1260d e x  + 1890d e x  + 1260d e x  + 315d )\|e x  + d
+--R                                                    Type: Expression(Integer)
+--E 1633
+
+--S 1634 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1634
+
+)clear all
+
+--S 1635 of 1718
+t0:=x^4*sqrt(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          4 |   2
+--R         x \|e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1635
+
+--S 1636 of 1718
+r0:=1/2*(c*d-2*b*e)*atanh(x*sqrt(e)/sqrt(d+e*x^2))/(c^2*sqrt(e))+_
+   1/2*x*sqrt(d+e*x^2)/c+atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*(b*c*d-b^2*e+a*c*e+_
+   (-b^2*c*d+2*a*c^2*d+b^3*e-3*a*b*c*e)/sqrt(b^2-4*a*c))/(c^2*_
+   sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c)))-_
+   atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+_
+   sqrt(b^2-4*a*c))))*(b*c*d-b^2*e+a*c*e+(b^2*c*d-2*a*c^2*d-b^3*e+_
+   3*a*b*c*e)/sqrt(b^2-4*a*c))/(c^2*sqrt(b+sqrt(b^2-4*a*c))*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                                    +-----------+
+--R                      2             |          2                  3
+--R           ((2a c - 2b )e + 2b c d)\|- 4a c + b   + (- 6a b c + 2b )e
+--R         + 
+--R                2     2
+--R           (4a c  - 2b c)d
+--R      *
+--R              +------------------------------+ +------------------+
+--R              |    +-----------+               | +-----------+
+--R          +-+ |    |          2                | |          2
+--R         \|e \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                      +-----------+
+--R                        2             |          2                  3
+--R           ((- 2a c + 2b )e - 2b c d)\|- 4a c + b   + (- 6a b c + 2b )e
+--R         + 
+--R                2     2
+--R           (4a c  - 2b c)d
+--R      *
+--R              +------------------+ +----------------------------+
+--R              | +-----------+      |  +-----------+
+--R          +-+ | |          2       |  |          2
+--R         \|e \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                          +-----------+           +-+
+--R                          |          2          x\|e
+--R           (- 2b e + c d)\|- 4a c + b  atanh(-----------)
+--R                                              +--------+
+--R                                              |   2
+--R                                             \|e x  + d
+--R         + 
+--R               +-----------+     +--------+
+--R               |          2  +-+ |   2
+--R           c x\|- 4a c + b  \|e \|e x  + d
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                             +------------------------------+
+--R           +-----------+     |    +-----------+
+--R         2 |          2  +-+ |    |          2
+--R       2c \|- 4a c + b  \|e \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R      +------------------+ +------------------+ +----------------------------+
+--R      | +-----------+      | +-----------+      |  +-----------+
+--R      | |          2       | |          2       |  |          2
+--R     \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1636
+
+--S 1637 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1637
+
+)clear all
+
+--S 1638 of 1718
+t0:=x^3*sqrt(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          3 |   2
+--R         x \|e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1638
+
+--S 1639 of 1718
+r0:=sqrt(d+e*x^2)/c-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c))))*(c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-_
+   4*a*c))/(c^(3/2)*sqrt(2)*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))-_
+   atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*_
+   (c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                      +-----------+
+--R                      |          2               2
+--R         ((b e - c d)\|- 4a c + b   + (- 2a c + b )e - b c d)
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                      +-----------+
+--R                      |          2             2
+--R         ((b e - c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                           +------------------------------+
+--R              +-----------+     +--------+ |    +-----------+
+--R          +-+ |          2  +-+ |   2      |    |          2
+--R         \|2 \|- 4a c + b  \|c \|e x  + d \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                               +------------------------------+
+--R             +-----------+     |    +-----------+
+--R         +-+ |          2  +-+ |    |          2
+--R       c\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1639
+
+--S 1640 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1640
+
+)clear all
+
+--S 1641 of 1718
+t0:=x^2*sqrt(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          2 |   2
+--R         x \|e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1641
+
+--S 1642 of 1718
+r0:=atanh(x*sqrt(e)/sqrt(d+e*x^2))*sqrt(e)/c-atanh(x*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*_
+   (c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(c*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c)))+atan(x*sqrt(2*c*d-_
+   e*(b+sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*_
+   (c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-4*a*c))/(c*sqrt(b+sqrt(b^2-_
+   4*a*c))*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                      +-----------+
+--R                      |          2             2
+--R         ((b e - c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                        |          2             2
+--R         ((- b e + c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                              +------------------------------+
+--R          +-----------+               +-+     |    +-----------+
+--R          |          2  +-+         x\|e      |    |          2
+--R         \|- 4a c + b  \|e atanh(-----------)\|- e\|- 4a c + b   - b e + 2c d
+--R                                  +--------+
+--R                                  |   2
+--R                                 \|e x  + d
+--R      *
+--R        +------------------+ +------------------+ +----------------------------+
+--R        | +-----------+      | +-----------+      |  +-----------+
+--R        | |          2       | |          2       |  |          2
+--R       \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                       +------------------------------+ +------------------+
+--R         +-----------+ |    +-----------+               | +-----------+
+--R         |          2  |    |          2                | |          2
+--R       c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1642
+
+--S 1643 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1643
+
+)clear all
+
+--S 1644 of 1718
+t0:=x*sqrt(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R          x\|e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1644
+
+--S 1645 of 1718
+r0:=-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))*_
+   sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+_
+   atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +------------------------------+                      +--------+
+--R        |    +-----------+                            +-+ +-+ |   2
+--R        |    |          2                            \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                               +------------------------------+
+--R                                               |    +-----------+
+--R                                               |    |          2
+--R                                              \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R          +----------------------------+                     +--------+
+--R          |  +-----------+                           +-+ +-+ |   2
+--R          |  |          2                           \|2 \|c \|e x  + d
+--R       - \|e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R          +-----------+
+--R      +-+ |          2  +-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 1645
+
+--S 1646 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1646
+
+)clear all
+
+--S 1647 of 1718
+t0:=sqrt(d+e*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R          \|e x  + d
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1647
+
+--S 1648 of 1718
+r0:=-atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*_
+   sqrt(-b+sqrt(b^2-4*a*c))))*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (sqrt(b^2-4*a*c)*sqrt(-b+sqrt(b^2-4*a*c)))-atan(x*sqrt(2*c*d-_
+   e*(b+sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(sqrt(b^2-4*a*c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +------------------+ +----------------------------+
+--R             | +-----------+      |  +-----------+
+--R             | |          2       |  |          2
+--R            \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R         *
+--R                    +----------------------------+
+--R                    |  +-----------+
+--R                    |  |          2
+--R                  x\|e\|- 4a c + b   - b e + 2c d
+--R            atanh(--------------------------------)
+--R                              +------------------+
+--R                   +--------+ | +-----------+
+--R                   |   2      | |          2
+--R                  \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R       -
+--R             +------------------------------+ +------------------+
+--R             |    +-----------+               | +-----------+
+--R             |    |          2                | |          2
+--R            \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R         *
+--R                   +------------------------------+
+--R                   |    +-----------+
+--R                   |    |          2
+--R                 x\|- e\|- 4a c + b   - b e + 2c d
+--R            atan(----------------------------------)
+--R                              +------------------+
+--R                   +--------+ | +-----------+
+--R                   |   2      | |          2
+--R                  \|e x  + d \|\|- 4a c + b   + b
+--R  /
+--R                    +------------------+ +------------------+
+--R      +-----------+ | +-----------+      | +-----------+
+--R      |          2  | |          2       | |          2
+--R     \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1648
+
+--S 1649 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1649
+
+)clear all
+
+--S 1650 of 1718
+t0:=sqrt(d+e*x^2)/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R           \|e x  + d
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1650
+
+--S 1651 of 1718
+r0:=-atanh(sqrt(d+e*x^2)/sqrt(d))*sqrt(d)/a+atanh(sqrt(2)*sqrt(c)*_
+   sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))*sqrt(c)*(d+_
+   (b*d-2*a*e)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c))))+atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*sqrt(c)*(d+(-b*d+2*a*e)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                                            +----------------------------+
+--R            +-----------+                   |  +-----------+
+--R            |          2                +-+ |  |          2
+--R         (d\|- 4a c + b   + 2a e - b d)\|c \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                               +--------+
+--R                       +-+ +-+ |   2
+--R                      \|2 \|c \|e x  + d
+--R         atanh(---------------------------------)
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R               \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                            +------------------------------+
+--R            +-----------+                   |    +-----------+
+--R            |          2                +-+ |    |          2
+--R         (d\|- 4a c + b   - 2a e + b d)\|c \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                              +--------+
+--R                      +-+ +-+ |   2
+--R                     \|2 \|c \|e x  + d
+--R         atanh(-------------------------------)
+--R                +----------------------------+
+--R                |  +-----------+
+--R                |  |          2
+--R               \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R       -
+--R                                         +--------+
+--R                 +-----------+           |   2
+--R             +-+ |          2  +-+      \|e x  + d
+--R            \|2 \|- 4a c + b  \|d atanh(-----------)
+--R                                             +-+
+--R                                            \|d
+--R         *
+--R             +------------------------------+ +----------------------------+
+--R             |    +-----------+               |  +-----------+
+--R             |    |          2                |  |          2
+--R            \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                           +------------------------------+
+--R             +-----------+ |    +-----------+
+--R         +-+ |          2  |    |          2
+--R       a\|2 \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1651
+
+--S 1652 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1652
+
+)clear all
+
+--S 1653 of 1718
+t0:=sqrt(d+e*x^2)/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|e x  + d
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1653
+
+--S 1654 of 1718
+r0:=-sqrt(d+e*x^2)/(a*x)+c*atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*(d+(b*d-2*a*e)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))*sqrt(-b+_
+   sqrt(b^2-4*a*c)))-c*atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(d+(-b*d+2*a*e)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b+sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b+_
+   sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                +-----------+
+--R                |          2
+--R         (c d x\|- 4a c + b   + (- 2a c e + b c d)x)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                                       +------------------+
+--R                  +-----------+                        | +-----------+
+--R                  |          2                         | |          2
+--R         (- c d x\|- 4a c + b   + (- 2a c e + b c d)x)\|\|- 4a c + b   - b
+--R      *
+--R                                             +------------------------------+
+--R        +----------------------------+       |    +-----------+
+--R        |  +-----------+                     |    |          2
+--R        |  |          2                    x\|- e\|- 4a c + b   - b e + 2c d
+--R       \|e\|- 4a c + b   - b e + 2c d atan(----------------------------------)
+--R                                                        +------------------+
+--R                                             +--------+ | +-----------+
+--R                                             |   2      | |          2
+--R                                            \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                                      +------------------------------+
+--R             +-----------+ +--------+ |    +-----------+
+--R             |          2  |   2      |    |          2
+--R            \|- 4a c + b  \|e x  + d \|- e\|- 4a c + b   - b e + 2c d
+--R         *
+--R             +------------------+ +------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R         *
+--R             +----------------------------+
+--R             |  +-----------+
+--R             |  |          2
+--R            \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                         +------------------------------+ +------------------+
+--R           +-----------+ |    +-----------+               | +-----------+
+--R           |          2  |    |          2                | |          2
+--R       a x\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1654
+
+--S 1655 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1655
+
+)clear all
+
+--S 1656 of 1718
+t0:=sqrt(d+e*x^2)/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|e x  + d
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1656
+
+--S 1657 of 1718
+r0:=1/2*e*atanh(sqrt(d+e*x^2)/sqrt(d))/(a*sqrt(d))+(b*d-a*e)*atanh(sqrt(d+_
+   e*x^2)/sqrt(d))/(a^2*sqrt(d))-1/2*sqrt(d+e*x^2)/(a*x^2)-atanh(sqrt(2)*_
+   sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))*sqrt(c)*_
+   (b*d-a*e+(b^2*d-2*a*c*d-a*b*e)/sqrt(b^2-4*a*c))/(a^2*sqrt(2)*_
+   sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))-atanh(sqrt(2)*sqrt(c)*_
+   sqrt(d+e*x^2)/sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*sqrt(c)*(b*d-a*e+_
+   (-b^2*d+2*a*c*d+a*b*e)/sqrt(b^2-4*a*c))/(a^2*sqrt(2)*sqrt(2*c*d-_
+   e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R                        2 |          2                            2    2  +-+
+--R         ((2a e - 2b d)x \|- 4a c + b   + (- 2a b e + (- 4a c + 2b )d)x )\|c
+--R      *
+--R              +----------------------------+
+--R              |  +-----------+
+--R          +-+ |  |          2
+--R         \|d \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                               +--------+
+--R                       +-+ +-+ |   2
+--R                      \|2 \|c \|e x  + d
+--R         atanh(---------------------------------)
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R               \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                          +-----------+
+--R                        2 |          2                        2    2  +-+ +-+
+--R         ((2a e - 2b d)x \|- 4a c + b   + (2a b e + (4a c - 2b )d)x )\|c \|d
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                                    +--------+
+--R                                +-----------+       |   2
+--R                          2 +-+ |          2       \|e x  + d
+--R           (- a e + 2b d)x \|2 \|- 4a c + b  atanh(-----------)
+--R                                                        +-+
+--R                                                       \|d
+--R         + 
+--R                   +-----------+     +--------+
+--R               +-+ |          2  +-+ |   2
+--R           - a\|2 \|- 4a c + b  \|d \|e x  + d
+--R      *
+--R          +------------------------------+ +----------------------------+
+--R          |    +-----------+               |  +-----------+
+--R          |    |          2                |  |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                                   +------------------------------+
+--R                 +-----------+     |    +-----------+
+--R         2 2 +-+ |          2  +-+ |    |          2
+--R       2a x \|2 \|- 4a c + b  \|d \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1657
+
+--S 1658 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1658
+
+)clear all
+
+--S 1659 of 1718
+t0:=sqrt(d+e*x^2)/(x^4*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|e x  + d
+--R   (1)  ------------------
+--R           8      6      4
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1659
+
+--S 1660 of 1718
+r0:=-1/3*sqrt(d+e*x^2)/(a*x^3)+2/3*e*sqrt(d+e*x^2)/(a*d*x)+(b*d-a*e)*_
+   sqrt(d+e*x^2)/(a^2*d*x)-c*atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*(b*d-a*e+(b^2*d-2*a*c*d-_
+   a*b*e)/sqrt(b^2-4*a*c))/(a^2*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))*_
+   sqrt(-b+sqrt(b^2-4*a*c)))+c*atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*_
+   (b*d-a*e+(-b^2*d+2*a*c*d+a*b*e)/sqrt(b^2-_
+   4*a*c))/(a^2*sqrt(b+sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                                  +-----------+
+--R                             2  3 |          2
+--R           (3a c d e - 3b c d )x \|- 4a c + b
+--R         + 
+--R                              2     2   2  3
+--R           (3a b c d e + (6a c  - 3b c)d )x
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                    +-----------+
+--R                               2  3 |          2
+--R           (- 3a c d e + 3b c d )x \|- 4a c + b
+--R         + 
+--R                              2     2   2  3
+--R           (3a b c d e + (6a c  - 3b c)d )x
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                  +-----------+ +--------+
+--R                         2        |          2  |   2
+--R         ((- a e + 3b d)x  - a d)\|- 4a c + b  \|e x  + d
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                             +------------------------------+
+--R               +-----------+ |    +-----------+
+--R         2   3 |          2  |    |          2
+--R       3a d x \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R      +------------------+ +------------------+ +----------------------------+
+--R      | +-----------+      | +-----------+      |  +-----------+
+--R      | |          2       | |          2       |  |          2
+--R     \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1660
+
+--S 1661 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1661
+
+)clear all
+
+--S 1662 of 1718
+t0:=x^4*(d+e*x^2)^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                      +--------+
+--R            6      4  |   2
+--R        (e x  + d x )\|e x  + d
+--R   (1)  ------------------------
+--R                4      2
+--R             c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1662
+
+--S 1663 of 1718
+r0:=1/4*x*(d+e*x^2)^(3/2)/c+1/8*d*(3*c*d-4*b*e)*atanh(x*sqrt(e)/_
+   sqrt(d+e*x^2))/(c^2*sqrt(e))-1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*_
+   (b*c*d-b^2*e+a*c*e+(-b^2*c*d+2*a*c^2*d+b^3*e-3*a*b*c*e)/_
+   sqrt(b^2-4*a*c))*sqrt(e)/c^3-1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*_
+   (b*c*d-b^2*e+a*c*e+(b^2*c*d-2*a*c^2*d-b^3*e+3*a*b*c*e)/_
+   sqrt(b^2-4*a*c))*sqrt(e)/c^3+1/8*(3*c*d-4*b*e)*x*sqrt(d+e*x^2)/c^2+_
+   1/2*atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*_
+   sqrt(-b+sqrt(b^2-4*a*c))))*(b*c*d-b^2*e+a*c*e+(-b^2*c*d+2*a*c^2*d+_
+   b^3*e-3*a*b*c*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (c^3*sqrt(-b+sqrt(b^2-4*a*c)))-1/2*atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-_
+   4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(b*c*d-b^2*e+_
+   a*c*e+(b^2*c*d-2*a*c^2*d-b^3*e+3*a*b*c*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-_
+   e*(b+sqrt(b^2-4*a*c)))/(c^3*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                    +-----------+
+--R                      2             |          2                   3
+--R           ((4a c - 4b )e + 4b c d)\|- 4a c + b   + (- 12a b c + 4b )e
+--R         + 
+--R                2     2
+--R           (8a c  - 4b c)d
+--R      *
+--R              +------------------+ +----------------------------+
+--R              | +-----------+      |  +-----------+
+--R          +-+ | |          2       |  |          2
+--R         \|e \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                                      +-----------+
+--R                        2             |          2                   3
+--R           ((- 4a c + 4b )e - 4b c d)\|- 4a c + b   + (- 12a b c + 4b )e
+--R         + 
+--R                2     2
+--R           (8a c  - 4b c)d
+--R      *
+--R              +------------------------------+ +------------------+
+--R              |    +-----------+               | +-----------+
+--R          +-+ |    |          2                | |          2
+--R         \|e \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                                    +-----------+
+--R                          2  2                 2 2  |          2
+--R             ((- 8a c + 8b )e  - 12b c d e + 3c d )\|- 4a c + b
+--R          *
+--R                        +-+
+--R                      x\|e
+--R             atanh(-----------)
+--R                    +--------+
+--R                    |   2
+--R                   \|e x  + d
+--R         + 
+--R                                          +-----------+     +--------+
+--R              2   3                 2     |          2  +-+ |   2
+--R           (2c e x  + (- 4b c e + 5c d)x)\|- 4a c + b  \|e \|e x  + d
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R  /
+--R                           +------------------+ +------------------+
+--R         +-----------+     | +-----------+      | +-----------+
+--R       3 |          2  +-+ | |          2       | |          2
+--R     8c \|- 4a c + b  \|e \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1663
+
+--S 1664 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1664
+
+)clear all
+
+--S 1665 of 1718
+t0:=x^3*(d+e*x^2)^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                      +--------+
+--R            5      3  |   2
+--R        (e x  + d x )\|e x  + d
+--R   (1)  ------------------------
+--R                4      2
+--R             c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1665
+
+--S 1666 of 1718
+r0:=1/3*(d+e*x^2)^(3/2)/c+(c*d-b*e)*sqrt(d+e*x^2)/c^2-atanh(sqrt(2)*_
+   sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))*(c^2*d^2+_
+   b^2*e^2-c*e*(2*b*d+a*e)+(2*b^2*c*d*e-4*a*c^2*d*e-b^3*e^2-b*c*(c*d^2-_
+   3*a*e^2))/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(2*c*d-e*(b-sqrt(b^2-_
+   4*a*c))))-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b+_
+   sqrt(b^2-4*a*c))))*(c^2*d^2+b^2*e^2-c*e*(2*b*d+a*e)+(-2*b^2*c*d*e+_
+   4*a*c^2*d*e+b^3*e^2+b*c*(c*d^2-3*a*e^2))/sqrt(b^2-4*a*c))/(c^(5/2)*_
+   sqrt(2)*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                                               +-----------+
+--R                      2  2                2 2  |          2                3  2
+--R           ((3a c - 3b )e  + 6b c d e - 3c d )\|- 4a c + b   + (9a b c - 3b )e
+--R         + 
+--R                   2     2            2 2
+--R           (- 12a c  + 6b c)d e - 3b c d
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                               +-----------+
+--R                      2  2                2 2  |          2
+--R           ((3a c - 3b )e  + 6b c d e - 3c d )\|- 4a c + b
+--R         + 
+--R                         3  2         2     2            2 2
+--R           (- 9a b c + 3b )e  + (12a c  - 6b c)d e + 3b c d
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                    +-----------+     +--------+
+--R               2                +-+ |          2  +-+ |   2
+--R         (c e x  - 3b e + 4c d)\|2 \|- 4a c + b  \|c \|e x  + d
+--R      *
+--R          +------------------------------+ +----------------------------+
+--R          |    +-----------+               |  +-----------+
+--R          |    |          2                |  |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                                 +------------------------------+
+--R               +-----------+     |    +-----------+
+--R         2 +-+ |          2  +-+ |    |          2
+--R       3c \|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1666
+
+--S 1667 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1667
+
+)clear all
+
+--S 1668 of 1718
+t0:=x^2*(d+e*x^2)^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                      +--------+
+--R            4      2  |   2
+--R        (e x  + d x )\|e x  + d
+--R   (1)  ------------------------
+--R                4      2
+--R             c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1668
+
+--S 1669 of 1718
+r0:=1/2*d*atanh(x*sqrt(e)/sqrt(d+e*x^2))*sqrt(e)/c+1/2*atanh(x*sqrt(e)/_
+   sqrt(d+e*x^2))*(c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))*_
+   sqrt(e)/c^2+1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*(c*d-b*e+(b*c*d-b^2*e+_
+   2*a*c*e)/sqrt(b^2-4*a*c))*sqrt(e)/c^2+1/2*e*x*sqrt(d+e*x^2)/c-_
+   1/2*atanh(x*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*_
+   sqrt(-b+sqrt(b^2-4*a*c))))*(c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/_
+   sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(c^2*sqrt(-b+_
+   sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/_
+   (sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(c*d-b*e+(b*c*d-b^2*e+_
+   2*a*c*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(c^2*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                            +------------------+
+--R                      +-----------+                         | +-----------+
+--R                      |          2             2            | |          2
+--R         ((b e - c d)\|- 4a c + b   + (2a c - b )e + b c d)\|\|- 4a c + b   + b
+--R      *
+--R                                                +----------------------------+
+--R          +----------------------------+        |  +-----------+
+--R          |  +-----------+                      |  |          2
+--R          |  |          2                     x\|e\|- 4a c + b   - b e + 2c d
+--R         \|e\|- 4a c + b   - b e + 2c d atanh(--------------------------------)
+--R                                                          +------------------+
+--R                                               +--------+ | +-----------+
+--R                                               |   2      | |          2
+--R                                              \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                        +-----------+
+--R                        |          2             2
+--R         ((- b e + c d)\|- 4a c + b   + (2a c - b )e + b c d)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                           +-----------+               +-+
+--R                           |          2  +-+         x\|e
+--R           (- 2b e + 3c d)\|- 4a c + b  \|e atanh(-----------)
+--R                                                   +--------+
+--R                                                   |   2
+--R                                                  \|e x  + d
+--R         + 
+--R                 +-----------+ +--------+
+--R                 |          2  |   2
+--R           c e x\|- 4a c + b  \|e x  + d
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R  /
+--R                       +------------------+ +------------------+
+--R         +-----------+ | +-----------+      | +-----------+
+--R       2 |          2  | |          2       | |          2
+--R     2c \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1669
+
+--S 1670 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1670
+
+)clear all
+
+--S 1671 of 1718
+t0:=x*(d+e*x^2)^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                     +--------+
+--R            3        |   2
+--R        (e x  + d x)\|e x  + d
+--R   (1)  -----------------------
+--R               4      2
+--R            c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1671
+
+--S 1672 of 1718
+r0:=e*sqrt(d+e*x^2)/c-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c))))*(e*(2*c*d-b*e)+(2*c^2*d^2+b^2*e^2-_
+   2*c*e*(b*d+a*e))/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c))))-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*(e*(2*c*d-b*e)+(-2*c^2*d^2-_
+   b^2*e^2+2*c*e*(b*d+a*e))/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R              2           |          2               2  2                2 2
+--R         ((b e  - 2c d e)\|- 4a c + b   + (- 2a c + b )e  - 2b c d e + 2c d )
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                          +-----------+
+--R              2           |          2             2  2                2 2
+--R         ((b e  - 2c d e)\|- 4a c + b   + (2a c - b )e  + 2b c d e - 2c d )
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                            +------------------------------+
+--R               +-----------+     +--------+ |    +-----------+
+--R           +-+ |          2  +-+ |   2      |    |          2
+--R         e\|2 \|- 4a c + b  \|c \|e x  + d \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R          +----------------------------+
+--R          |  +-----------+
+--R          |  |          2
+--R         \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                               +------------------------------+
+--R             +-----------+     |    +-----------+
+--R         +-+ |          2  +-+ |    |          2
+--R       c\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1672
+
+--S 1673 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1673
+
+)clear all
+
+--S 1674 of 1718
+t0:=(d+e*x^2)^(3/2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R              4      2
+--R           c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1674
+
+--S 1675 of 1718
+r0:=1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*(3*c*d-e*(b-sqrt(b^2-4*a*c)))*_
+   sqrt(e)/(c*sqrt(b^2-4*a*c))-1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*_
+   (3*c*d-e*(b+sqrt(b^2-4*a*c)))*sqrt(e)/(c*sqrt(b^2-4*a*c))-atanh(x*_
+   sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-_
+   4*a*c))))*(2*c^2*d^2+b*e^2*(b-sqrt(b^2-4*a*c))-2*c*e*(b*d+a*e-_
+   d*sqrt(b^2-4*a*c)))/(c*sqrt(b^2-4*a*c)*sqrt(2*c*d-e*(b-sqrt(b^2-_
+   4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c)))-atan(x*sqrt(2*c*d-e*(b+sqrt(b^2-_
+   4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(2*c^2*d^2+b*e^2*_
+   (b+sqrt(b^2-4*a*c))-2*c*e*(b*d+a*e+d*sqrt(b^2-4*a*c)))/(c*_
+   sqrt(b^2-4*a*c)*sqrt(b+sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R              2           |          2             2  2                2 2
+--R         ((b e  - 2c d e)\|- 4a c + b   + (2a c - b )e  + 2b c d e - 2c d )
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   + b
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R                2           |          2             2  2                2 2
+--R         ((- b e  + 2c d e)\|- 4a c + b   + (2a c - b )e  + 2b c d e - 2c d )
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   - b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                               +------------------------------+
+--R           +-----------+               +-+     |    +-----------+
+--R           |          2  +-+         x\|e      |    |          2
+--R         e\|- 4a c + b  \|e atanh(-----------)\|- e\|- 4a c + b   - b e + 2c d
+--R                                   +--------+
+--R                                   |   2
+--R                                  \|e x  + d
+--R      *
+--R        +------------------+ +------------------+ +----------------------------+
+--R        | +-----------+      | +-----------+      |  +-----------+
+--R        | |          2       | |          2       |  |          2
+--R       \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                       +------------------------------+ +------------------+
+--R         +-----------+ |    +-----------+               | +-----------+
+--R         |          2  |    |          2                | |          2
+--R       c\|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +----------------------------+
+--R        | +-----------+      |  +-----------+
+--R        | |          2       |  |          2
+--R       \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1675
+
+--S 1676 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1676
+
+)clear all
+
+--S 1677 of 1718
+t0:=(d+e*x^2)^(3/2)/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R             5      3
+--R          c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1677
+
+--S 1678 of 1718
+r0:=-d^(3/2)*atanh(sqrt(d+e*x^2)/sqrt(d))/a+atanh(sqrt(2)*sqrt(c)*_
+   sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))*(c*d^2-a*e^2+_
+   (b*c*d^2-4*a*c*d*e+a*b*e^2)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(c)*_
+   sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c))))+atanh(sqrt(2)*sqrt(c)*_
+   sqrt(d+e*x^2)/sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*(c*d^2-a*e^2+_
+   (-b*c*d^2+4*a*c*d*e-a*b*e^2)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(c)*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R                2      2  |          2         2                   2
+--R         ((- a e  + c d )\|- 4a c + b   - a b e  + 4a c d e - b c d )
+--R      *
+--R        +----------------------------+                      +--------+
+--R        |  +-----------+                            +-+ +-+ |   2
+--R        |  |          2                            \|2 \|c \|e x  + d
+--R       \|e\|- 4a c + b   - b e + 2c d atanh(---------------------------------)
+--R                                             +------------------------------+
+--R                                             |    +-----------+
+--R                                             |    |          2
+--R                                            \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                          +-----------+
+--R                2      2  |          2         2                   2
+--R         ((- a e  + c d )\|- 4a c + b   + a b e  - 4a c d e + b c d )
+--R      *
+--R        +------------------------------+                     +--------+
+--R        |    +-----------+                           +-+ +-+ |   2
+--R        |    |          2                           \|2 \|c \|e x  + d
+--R       \|- e\|- 4a c + b   - b e + 2c d atanh(-------------------------------)
+--R                                               +----------------------------+
+--R                                               |  +-----------+
+--R                                               |  |          2
+--R                                              \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R       -
+--R                                              +--------+
+--R                  +-----------+               |   2
+--R              +-+ |          2  +-+ +-+      \|e x  + d
+--R            d\|2 \|- 4a c + b  \|c \|d atanh(-----------)
+--R                                                  +-+
+--R                                                 \|d
+--R         *
+--R             +------------------------------+ +----------------------------+
+--R             |    +-----------+               |  +-----------+
+--R             |    |          2                |  |          2
+--R            \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                               +------------------------------+
+--R             +-----------+     |    +-----------+
+--R         +-+ |          2  +-+ |    |          2
+--R       a\|2 \|- 4a c + b  \|c \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1678
+
+--S 1679 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1679
+
+)clear all
+
+--S 1680 of 1718
+t0:=(d+e*x^2)^(3/2)/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R             6      4      2
+--R          c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1680
+
+--S 1681 of 1718
+r0:=d*atanh(x*sqrt(e)/sqrt(d+e*x^2))*sqrt(e)/a-1/2*atanh(x*sqrt(e)/_
+   sqrt(d+e*x^2))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))*sqrt(e)/a-_
+   1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))*_
+   sqrt(e)/a-d*sqrt(d+e*x^2)/(a*x)+1/2*atanh(x*sqrt(2*c*d-e*(b-_
+   sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*(d+_
+   (b*d-2*a*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b-sqrt(b^2-4*a*c)))/_
+   (a*sqrt(-b+sqrt(b^2-4*a*c)))-1/2*atan(x*sqrt(2*c*d-e*(b+_
+   sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(d+_
+   (-b*d+2*a*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/_
+   (a*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                               +------------------+
+--R              +-----------+                    | +-----------+
+--R              |          2                     | |          2
+--R         (d x\|- 4a c + b   + (- 2a e + b d)x)\|\|- 4a c + b   + b
+--R      *
+--R                                                +----------------------------+
+--R          +----------------------------+        |  +-----------+
+--R          |  +-----------+                      |  |          2
+--R          |  |          2                     x\|e\|- 4a c + b   - b e + 2c d
+--R         \|e\|- 4a c + b   - b e + 2c d atanh(--------------------------------)
+--R                                                          +------------------+
+--R                                               +--------+ | +-----------+
+--R                                               |   2      | |          2
+--R                                              \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                +-----------+
+--R                |          2
+--R         (- d x\|- 4a c + b   + (- 2a e + b d)x)
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                     +------------------+ +------------------+
+--R            +-----------+ +--------+ | +-----------+      | +-----------+
+--R            |          2  |   2      | |          2       | |          2
+--R       - 2d\|- 4a c + b  \|e x  + d \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R  /
+--R                        +------------------+ +------------------+
+--R          +-----------+ | +-----------+      | +-----------+
+--R          |          2  | |          2       | |          2
+--R     2a x\|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1681
+
+--S 1682 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1682
+
+)clear all
+
+--S 1683 of 1718
+t0:=(d+e*x^2)^(3/2)/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R             7      5      3
+--R          c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1683
+
+--S 1684 of 1718
+r0:=1/2*e*atanh(sqrt(d+e*x^2)/sqrt(d))*sqrt(d)/a+(b*d-2*a*e)*_
+   atanh(sqrt(d+e*x^2)/sqrt(d))*sqrt(d)/a^2-1/2*d*sqrt(d+e*x^2)/_
+   (a*x^2)-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/sqrt(2*c*d-e*(b-_
+   sqrt(b^2-4*a*c))))*sqrt(c)*(b*d^2-2*a*d*e+(b^2*d^2-2*a*b*d*e-_
+   2*a*(c*d^2-a*e^2))/sqrt(b^2-4*a*c))/(a^2*sqrt(2)*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c))))-atanh(sqrt(2)*sqrt(c)*sqrt(d+e*x^2)/_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))*sqrt(c)*(b*d^2-2*a*d*e+_
+   (-b^2*d^2+2*a*b*d*e+2*a*(c*d^2-a*e^2))/sqrt(b^2-4*a*c))/(a^2*_
+   sqrt(2)*sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                              +-----------+
+--R                         2  2 |          2
+--R           (4a d e - 2b d )x \|- 4a c + b
+--R         + 
+--R              2 2                          2  2  2
+--R           (4a e  - 4a b d e + (- 4a c + 2b )d )x
+--R      *
+--R              +----------------------------+
+--R              |  +-----------+
+--R          +-+ |  |          2
+--R         \|c \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                               +--------+
+--R                       +-+ +-+ |   2
+--R                      \|2 \|c \|e x  + d
+--R         atanh(---------------------------------)
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R               \|- e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                              +-----------+
+--R                         2  2 |          2
+--R           (4a d e - 2b d )x \|- 4a c + b
+--R         + 
+--R                2 2                        2  2  2
+--R           (- 4a e  + 4a b d e + (4a c - 2b )d )x
+--R      *
+--R              +------------------------------+
+--R              |    +-----------+
+--R          +-+ |    |          2
+--R         \|c \|- e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                              +--------+
+--R                      +-+ +-+ |   2
+--R                     \|2 \|c \|e x  + d
+--R         atanh(-------------------------------)
+--R                +----------------------------+
+--R                |  +-----------+
+--R                |  |          2
+--R               \|e\|- 4a c + b   - b e + 2c d
+--R     + 
+--R                                                         +--------+
+--R                                 +-----------+           |   2
+--R                           2 +-+ |          2  +-+      \|e x  + d
+--R           (- 3a e + 2b d)x \|2 \|- 4a c + b  \|d atanh(-----------)
+--R                                                             +-+
+--R                                                            \|d
+--R         + 
+--R                     +-----------+ +--------+
+--R                 +-+ |          2  |   2
+--R           - a d\|2 \|- 4a c + b  \|e x  + d
+--R      *
+--R          +------------------------------+ +----------------------------+
+--R          |    +-----------+               |  +-----------+
+--R          |    |          2                |  |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|e\|- 4a c + b   - b e + 2c d
+--R  /
+--R                               +------------------------------+
+--R                 +-----------+ |    +-----------+
+--R         2 2 +-+ |          2  |    |          2
+--R       2a x \|2 \|- 4a c + b  \|- e\|- 4a c + b   - b e + 2c d
+--R    *
+--R        +----------------------------+
+--R        |  +-----------+
+--R        |  |          2
+--R       \|e\|- 4a c + b   - b e + 2c d
+--R                                                    Type: Expression(Integer)
+--E 1684
+
+--S 1685 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1685
+
+)clear all
+
+--S 1686 of 1718
+t0:=(d+e*x^2)^(3/2)/(x^4*(a+b*x^2+c*x^4))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (e x  + d)\|e x  + d
+--R   (1)  ---------------------
+--R             8      6      4
+--R          c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1686
+
+--S 1687 of 1718
+r0:=-1/3*(d+e*x^2)^(3/2)/(a*x^3)-(b*d-a*e)*atanh(x*sqrt(e)/sqrt(d+e*x^2))*_
+   sqrt(e)/a^2+1/2*atanh(x*sqrt(e)/sqrt(d+e*x^2))*(b*d-a*e+(-b^2*d+_
+   2*a*c*d+a*b*e)/sqrt(b^2-4*a*c))*sqrt(e)/a^2+1/2*atanh(x*sqrt(e)/_
+   sqrt(d+e*x^2))*(b*d-a*e+(b^2*d-2*a*c*d-a*b*e)/sqrt(b^2-4*a*c))*_
+   sqrt(e)/a^2+(b*d-a*e)*sqrt(d+e*x^2)/(a^2*x)-1/2*atanh(x*sqrt(2*c*d-_
+   e*(b-sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*_
+   (b*d-a*e+(b^2*d-2*a*c*d-a*b*e)/sqrt(b^2-4*a*c))*sqrt(2*c*d-e*(b-_
+   sqrt(b^2-4*a*c)))/(a^2*sqrt(-b+sqrt(b^2-4*a*c)))+1/2*atan(x*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(sqrt(d+e*x^2)*sqrt(b+sqrt(b^2-_
+   4*a*c))))*(b*d-a*e+(-b^2*d+2*a*c*d+a*b*e)/sqrt(b^2-4*a*c))*_
+   sqrt(2*c*d-e*(b+sqrt(b^2-4*a*c)))/(a^2*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                          +-----------+
+--R                        3 |          2                        2    3
+--R         ((3a e - 3b d)x \|- 4a c + b   + (3a b e + (6a c - 3b )d)x )
+--R      *
+--R          +------------------+ +----------------------------+
+--R          | +-----------+      |  +-----------+
+--R          | |          2       |  |          2
+--R         \|\|- 4a c + b   + b \|e\|- 4a c + b   - b e + 2c d
+--R      *
+--R                 +----------------------------+
+--R                 |  +-----------+
+--R                 |  |          2
+--R               x\|e\|- 4a c + b   - b e + 2c d
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   - b
+--R     + 
+--R                            +-----------+
+--R                          3 |          2                        2    3
+--R         ((- 3a e + 3b d)x \|- 4a c + b   + (3a b e + (6a c - 3b )d)x )
+--R      *
+--R          +------------------------------+ +------------------+
+--R          |    +-----------+               | +-----------+
+--R          |    |          2                | |          2
+--R         \|- e\|- 4a c + b   - b e + 2c d \|\|- 4a c + b   - b
+--R      *
+--R                +------------------------------+
+--R                |    +-----------+
+--R                |    |          2
+--R              x\|- e\|- 4a c + b   - b e + 2c d
+--R         atan(----------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|e x  + d \|\|- 4a c + b   + b
+--R     + 
+--R                                    +-----------+ +--------+
+--R                          2         |          2  |   2
+--R         ((- 8a e + 6b d)x  - 2a d)\|- 4a c + b  \|e x  + d
+--R      *
+--R          +------------------+ +------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R  /
+--R                         +------------------+ +------------------+
+--R           +-----------+ | +-----------+      | +-----------+
+--R       2 3 |          2  | |          2       | |          2
+--R     6a x \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1687
+
+--S 1688 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1688
+
+)clear all
+
+--S 1689 of 1718
+t0:=x^5*sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          5 |   2
+--R         x \|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1689
+
+--S 1690 of 1718
+r0:=-1/3*(1-x^2)^(3/2)/c-b*sqrt(1-x^2)/c^2+atanh(sqrt(2)*sqrt(c)*_
+   sqrt(1-x^2)/sqrt(b+2*c-sqrt(b^2-4*a*c)))*(b^2-a*c+b*c+(-b^3+_
+   3*a*b*c-b^2*c+2*a*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*_
+   sqrt(b+2*c-sqrt(b^2-4*a*c)))+atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/_
+   sqrt(b+2*c+sqrt(b^2-4*a*c)))*(b^2-a*c+b*c+(b^3-3*a*b*c+b^2*c-2*a*c^2)/_
+   sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                             +-----------+
+--R                          2  |          2        2        2              3
+--R         (((3b - 3a)c + 3b )\|- 4a c + b   + 6a c  + (- 3b  + 9a b)c - 3b )
+--R      *
+--R          +-----------------------+                +--------+
+--R          | +-----------+                      +-+ |   2      +-+
+--R          | |          2                      \|2 \|- x  + 1 \|c
+--R         \|\|- 4a c + b   + 2c + b atanh(----------------------------)
+--R                                          +-------------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                             +-----------+
+--R                          2  |          2        2      2              3
+--R         (((3b - 3a)c + 3b )\|- 4a c + b   - 6a c  + (3b  - 9a b)c + 3b )
+--R      *
+--R          +-------------------------+               +--------+
+--R          |   +-----------+                     +-+ |   2      +-+
+--R          |   |          2                     \|2 \|- x  + 1 \|c
+--R         \|- \|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            | +-----------+
+--R                                            | |          2
+--R                                           \|\|- 4a c + b   + 2c + b
+--R     + 
+--R                             +--------+ +-----------+
+--R             2           +-+ |   2      |          2  +-+
+--R         (c x  - c - 3b)\|2 \|- x  + 1 \|- 4a c + b  \|c
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                                 +-------------------------+
+--R               +-----------+     |   +-----------+
+--R         2 +-+ |          2  +-+ |   |          2
+--R       3c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R    *
+--R        +-----------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 1690
+
+--S 1691 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1691
+
+)clear all
+
+--S 1692 of 1718
+t0:=x^4*sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          4 |   2
+--R         x \|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1692
+
+--S 1693 of 1718
+r0:=1/2*(2*b+c)*asin(x)/c^2+1/2*x*sqrt(1-x^2)/c+atanh(x*sqrt(b+2*c-_
+   sqrt(b^2-4*a*c))/(sqrt(1-x^2)*sqrt(-b+sqrt(b^2-4*a*c))))*(b^2-_
+   a*c+b*c+(-b^3+3*a*b*c-b^2*c+2*a*c^2)/sqrt(b^2-4*a*c))/(c^2*_
+   sqrt(b+2*c-sqrt(b^2-4*a*c))*sqrt(-b+sqrt(b^2-4*a*c)))-atan(x*_
+   sqrt(b+2*c+sqrt(b^2-4*a*c))/(sqrt(1-x^2)*sqrt(b+sqrt(b^2-4*a*c))))*_
+   (b^2-a*c+b*c+(b^3-3*a*b*c+b^2*c-2*a*c^2)/sqrt(b^2-4*a*c))/_
+   (c^2*sqrt(b+sqrt(b^2-4*a*c))*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                             +-----------+
+--R                          2  |          2        2        2              3
+--R         (((2b - 2a)c + 2b )\|- 4a c + b   + 4a c  + (- 2b  + 6a b)c - 2b )
+--R      *
+--R          +------------------+ +-----------------------+
+--R          | +-----------+      | +-----------+
+--R          | |          2       | |          2
+--R         \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R      *
+--R                   +-------------------------+
+--R                   |   +-----------+
+--R                   |   |          2
+--R                 x\|- \|- 4a c + b   + 2c + b
+--R         atanh(--------------------------------)
+--R                           +------------------+
+--R                +--------+ | +-----------+
+--R                |   2      | |          2
+--R               \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R                               +-----------+
+--R                            2  |          2        2        2              3
+--R         (((- 2b + 2a)c - 2b )\|- 4a c + b   + 4a c  + (- 2b  + 6a b)c - 2b )
+--R      *
+--R          +-------------------------+ +------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R      *
+--R                   +-----------------------+
+--R                   | +-----------+
+--R                   | |          2
+--R                 x\|\|- 4a c + b   + 2c + b
+--R         atan(--------------------------------)
+--R                          +------------------+
+--R               +--------+ | +-----------+
+--R               |   2      | |          2
+--R              \|- x  + 1 \|\|- 4a c + b   + b
+--R     + 
+--R              +--------+                    +-----------+
+--R              |   2                         |          2
+--R         (c x\|- x  + 1  + (c + 2b)asin(x))\|- 4a c + b
+--R      *
+--R          +-------------------------+ +------------------+ +------------------+
+--R          |   +-----------+           | +-----------+      | +-----------+
+--R          |   |          2            | |          2       | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R  /
+--R                         +-------------------------+ +------------------+
+--R           +-----------+ |   +-----------+           | +-----------+
+--R         2 |          2  |   |          2            | |          2
+--R       2c \|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +-----------------------+
+--R        | +-----------+      | +-----------+
+--R        | |          2       | |          2
+--R       \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 1693
+
+--S 1694 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1694
+
+)clear all
+
+--S 1695 of 1718
+t0:=x^3*sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          3 |   2
+--R         x \|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1695
+
+--S 1696 of 1718
+r0:=sqrt(1-x^2)/c-atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/sqrt(b+2*c-_
+   sqrt(b^2-4*a*c)))*(b+c+(2*a*c-b*(b+c))/sqrt(b^2-4*a*c))/(c^(3/2)*_
+   sqrt(2)*sqrt(b+2*c-sqrt(b^2-4*a*c)))-atanh(sqrt(2)*sqrt(c)*_
+   sqrt(1-x^2)/sqrt(b+2*c+sqrt(b^2-4*a*c)))*(b+c+(b^2-2*a*c+b*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                    +-----------------------+
+--R                    +-----------+                   | +-----------+
+--R                    |          2                 2  | |          2
+--R         ((- c - b)\|- 4a c + b   + (b - 2a)c + b )\|\|- 4a c + b   + 2c + b
+--R      *
+--R                         +--------+
+--R                     +-+ |   2      +-+
+--R                    \|2 \|- x  + 1 \|c
+--R         atanh(----------------------------)
+--R                +-------------------------+
+--R                |   +-----------+
+--R                |   |          2
+--R               \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                    +-----------+
+--R                    |          2                   2
+--R         ((- c - b)\|- 4a c + b   + (- b + 2a)c - b )
+--R      *
+--R          +-------------------------+               +--------+
+--R          |   +-----------+                     +-+ |   2      +-+
+--R          |   |          2                     \|2 \|- x  + 1 \|c
+--R         \|- \|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            | +-----------+
+--R                                            | |          2
+--R                                           \|\|- 4a c + b   + 2c + b
+--R     + 
+--R                                           +-------------------------+
+--R              +--------+ +-----------+     |   +-----------+
+--R          +-+ |   2      |          2  +-+ |   |          2
+--R         \|2 \|- x  + 1 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R      *
+--R          +-----------------------+
+--R          | +-----------+
+--R          | |          2
+--R         \|\|- 4a c + b   + 2c + b
+--R  /
+--R                               +-------------------------+
+--R             +-----------+     |   +-----------+
+--R         +-+ |          2  +-+ |   |          2
+--R       c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + 2c + b
+--R    *
+--R        +-----------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 1696
+
+--S 1697 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1697
+
+)clear all
+
+--S 1698 of 1718
+t0:=x^2*sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R          2 |   2
+--R         x \|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1698
+
+--S 1699 of 1718
+r0:=-asin(x)/c-atanh(x*sqrt(b+2*c-sqrt(b^2-4*a*c))/(sqrt(1-x^2)*_
+   sqrt(-b+sqrt(b^2-4*a*c))))*(b+c+(-b^2+2*a*c-b*c)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b+2*c-sqrt(b^2-4*a*c))*sqrt(-b+sqrt(b^2-4*a*c)))+atan(x*_
+   sqrt(b+2*c+sqrt(b^2-4*a*c))/(sqrt(1-x^2)*sqrt(b+sqrt(b^2-4*a*c))))*_
+   (b+c+(b^2-2*a*c+b*c)/sqrt(b^2-4*a*c))/(c*sqrt(b+sqrt(b^2-4*a*c))*_
+   sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                    +------------------+
+--R                    +-----------+                   | +-----------+
+--R                    |          2                 2  | |          2
+--R         ((- c - b)\|- 4a c + b   + (b - 2a)c + b )\|\|- 4a c + b   + b
+--R      *
+--R                                             +-------------------------+
+--R          +-----------------------+          |   +-----------+
+--R          | +-----------+                    |   |          2
+--R          | |          2                   x\|- \|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   + 2c + b atanh(--------------------------------)
+--R                                                     +------------------+
+--R                                          +--------+ | +-----------+
+--R                                          |   2      | |          2
+--R                                         \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R                                                  +-------------------------+
+--R                  +-----------+                   |   +-----------+
+--R                  |          2                 2  |   |          2
+--R         ((c + b)\|- 4a c + b   + (b - 2a)c + b )\|- \|- 4a c + b   + 2c + b
+--R      *
+--R                                        +-----------------------+
+--R          +------------------+          | +-----------+
+--R          | +-----------+               | |          2
+--R          | |          2              x\|\|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   - b atan(--------------------------------)
+--R                                               +------------------+
+--R                                    +--------+ | +-----------+
+--R                                    |   2      | |          2
+--R                                   \|- x  + 1 \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                                  +-------------------------+
+--R                    +-----------+ |   +-----------+
+--R                    |          2  |   |          2
+--R            asin(x)\|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R         *
+--R           +------------------+ +------------------+ +-----------------------+
+--R           | +-----------+      | +-----------+      | +-----------+
+--R           | |          2       | |          2       | |          2
+--R          \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                       +-------------------------+ +------------------+
+--R         +-----------+ |   +-----------+           | +-----------+
+--R         |          2  |   |          2            | |          2
+--R       c\|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +-----------------------+
+--R        | +-----------+      | +-----------+
+--R        | |          2       | |          2
+--R       \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 1699
+
+--S 1700 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1700
+
+)clear all
+
+--S 1701 of 1718
+t0:=x*sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R          x\|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1701
+
+--S 1702 of 1718
+r0:=-atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/sqrt(b+2*c-sqrt(b^2-4*a*c)))*_
+   sqrt(b+2*c-sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+_
+   atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/sqrt(b+2*c+sqrt(b^2-4*a*c)))*_
+   sqrt(b+2*c+sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +-------------------------+                +--------+
+--R          |   +-----------+                      +-+ |   2      +-+
+--R          |   |          2                      \|2 \|- x  + 1 \|c
+--R       - \|- \|- 4a c + b   + 2c + b atanh(----------------------------)
+--R                                            +-------------------------+
+--R                                            |   +-----------+
+--R                                            |   |          2
+--R                                           \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R        +-----------------------+               +--------+
+--R        | +-----------+                     +-+ |   2      +-+
+--R        | |          2                     \|2 \|- x  + 1 \|c
+--R       \|\|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                        +-----------------------+
+--R                                        | +-----------+
+--R                                        | |          2
+--R                                       \|\|- 4a c + b   + 2c + b
+--R  /
+--R          +-----------+
+--R      +-+ |          2  +-+
+--R     \|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 1702
+
+--S 1703 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1703
+
+)clear all
+
+--S 1704 of 1718
+t0:=sqrt(1-x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R          \|- x  + 1
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1704
+
+--S 1705 of 1718
+r0:=-atanh(x*sqrt(b+2*c-sqrt(b^2-4*a*c))/(sqrt(1-x^2)*sqrt(-b+_
+   sqrt(b^2-4*a*c))))*sqrt(b+2*c-sqrt(b^2-4*a*c))/(sqrt(b^2-4*a*c)*_
+   sqrt(-b+sqrt(b^2-4*a*c)))-atan(x*sqrt(b+2*c+sqrt(b^2-4*a*c))/_
+   (sqrt(1-x^2)*sqrt(b+sqrt(b^2-4*a*c))))*sqrt(b+2*c+sqrt(b^2-4*a*c))/_
+   (sqrt(b^2-4*a*c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +-------------------------+ +------------------+
+--R             |   +-----------+           | +-----------+
+--R             |   |          2            | |          2
+--R            \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + b
+--R         *
+--R                      +-------------------------+
+--R                      |   +-----------+
+--R                      |   |          2
+--R                    x\|- \|- 4a c + b   + 2c + b
+--R            atanh(--------------------------------)
+--R                              +------------------+
+--R                   +--------+ | +-----------+
+--R                   |   2      | |          2
+--R                  \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R       -
+--R             +------------------+ +-----------------------+
+--R             | +-----------+      | +-----------+
+--R             | |          2       | |          2
+--R            \|\|- 4a c + b   - b \|\|- 4a c + b   + 2c + b
+--R         *
+--R                      +-----------------------+
+--R                      | +-----------+
+--R                      | |          2
+--R                    x\|\|- 4a c + b   + 2c + b
+--R            atan(--------------------------------)
+--R                             +------------------+
+--R                  +--------+ | +-----------+
+--R                  |   2      | |          2
+--R                 \|- x  + 1 \|\|- 4a c + b   + b
+--R  /
+--R                    +------------------+ +------------------+
+--R      +-----------+ | +-----------+      | +-----------+
+--R      |          2  | |          2       | |          2
+--R     \|- 4a c + b  \|\|- 4a c + b   - b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1705
+
+--S 1706 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1706
+
+)clear all
+
+--S 1707 of 1718
+t0:=sqrt(1-x^2)/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R           \|- x  + 1
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1707
+
+--S 1708 of 1718
+r0:=-atanh(sqrt(1-x^2))/a+atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/sqrt(b+2*c-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(1+(2*a+b)/sqrt(b^2-4*a*c))/(a*sqrt(2)*_
+   sqrt(b+2*c-sqrt(b^2-4*a*c)))+atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/_
+   sqrt(b+2*c+sqrt(b^2-4*a*c)))*sqrt(c)*(1+(-2*a-b)/sqrt(b^2-4*a*c))/_
+   (a*sqrt(2)*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                       +-----------------------+
+--R           +-----------+               | +-----------+
+--R           |          2            +-+ | |          2
+--R         (\|- 4a c + b   + b + 2a)\|c \|\|- 4a c + b   + 2c + b
+--R      *
+--R                         +--------+
+--R                     +-+ |   2      +-+
+--R                    \|2 \|- x  + 1 \|c
+--R         atanh(----------------------------)
+--R                +-------------------------+
+--R                |   +-----------+
+--R                |   |          2
+--R               \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                                       +-------------------------+
+--R           +-----------+               |   +-----------+
+--R           |          2            +-+ |   |          2
+--R         (\|- 4a c + b   - b - 2a)\|c \|- \|- 4a c + b   + 2c + b
+--R      *
+--R                        +--------+
+--R                    +-+ |   2      +-+
+--R                   \|2 \|- x  + 1 \|c
+--R         atanh(--------------------------)
+--R                +-----------------------+
+--R                | +-----------+
+--R                | |          2
+--R               \|\|- 4a c + b   + 2c + b
+--R     + 
+--R       -
+--R                                                 +-------------------------+
+--R                 +-----------+       +--------+  |   +-----------+
+--R             +-+ |          2        |   2       |   |          2
+--R            \|2 \|- 4a c + b  atanh(\|- x  + 1 )\|- \|- 4a c + b   + 2c + b
+--R         *
+--R             +-----------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + 2c + b
+--R  /
+--R                         +-------------------------+ +-----------------------+
+--R           +-----------+ |   +-----------+           | +-----------+
+--R       +-+ |          2  |   |          2            | |          2
+--R     a\|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 1708
+
+--S 1709 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1709
+
+)clear all
+
+--S 1710 of 1718
+t0:=sqrt(1-x^2)/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|- x  + 1
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1710
+
+--S 1711 of 1718
+r0:=-sqrt(1-x^2)/(a*x)+c*atanh(x*sqrt(b+2*c-sqrt(b^2-4*a*c))/(sqrt(1-x^2)*_
+   sqrt(-b+sqrt(b^2-4*a*c))))*(1+(2*a+b)/sqrt(b^2-4*a*c))/(a*sqrt(b+2*c-_
+   sqrt(b^2-4*a*c))*sqrt(-b+sqrt(b^2-4*a*c)))-c*atan(x*sqrt(b+2*c+_
+   sqrt(b^2-4*a*c))/(sqrt(1-x^2)*sqrt(b+sqrt(b^2-4*a*c))))*(1+(-2*a-b)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b+sqrt(b^2-4*a*c))*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                           +------------------+
+--R              +-----------+                | +-----------+
+--R              |          2                 | |          2
+--R         (c x\|- 4a c + b   + (b + 2a)c x)\|\|- 4a c + b   + b
+--R      *
+--R                                             +-------------------------+
+--R          +-----------------------+          |   +-----------+
+--R          | +-----------+                    |   |          2
+--R          | |          2                   x\|- \|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   + 2c + b atanh(--------------------------------)
+--R                                                     +------------------+
+--R                                          +--------+ | +-----------+
+--R                                          |   2      | |          2
+--R                                         \|- x  + 1 \|\|- 4a c + b   - b
+--R     + 
+--R                                             +-------------------------+
+--R                +-----------+                |   +-----------+
+--R                |          2                 |   |          2
+--R         (- c x\|- 4a c + b   + (b + 2a)c x)\|- \|- 4a c + b   + 2c + b
+--R      *
+--R                                        +-----------------------+
+--R          +------------------+          | +-----------+
+--R          | +-----------+               | |          2
+--R          | |          2              x\|\|- 4a c + b   + 2c + b
+--R         \|\|- 4a c + b   - b atan(--------------------------------)
+--R                                               +------------------+
+--R                                    +--------+ | +-----------+
+--R                                    |   2      | |          2
+--R                                   \|- x  + 1 \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                                      +-------------------------+
+--R             +--------+ +-----------+ |   +-----------+
+--R             |   2      |          2  |   |          2
+--R            \|- x  + 1 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R         *
+--R           +------------------+ +------------------+ +-----------------------+
+--R           | +-----------+      | +-----------+      | +-----------+
+--R           | |          2       | |          2       | |          2
+--R          \|\|- 4a c + b   - b \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                         +-------------------------+ +------------------+
+--R           +-----------+ |   +-----------+           | +-----------+
+--R           |          2  |   |          2            | |          2
+--R       a x\|- 4a c + b  \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   - b
+--R    *
+--R        +------------------+ +-----------------------+
+--R        | +-----------+      | +-----------+
+--R        | |          2       | |          2
+--R       \|\|- 4a c + b   + b \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 1711
+
+--S 1712 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1712
+
+)clear all
+
+--S 1713 of 1718
+t0:=sqrt(1-x^2)/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|- x  + 1
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1713
+
+--S 1714 of 1718
+r0:=1/2*(a+2*b)*atanh(sqrt(1-x^2))/a^2+(-1/4)/(a*(1-sqrt(1-x^2)))+_
+   1/4/(a*(1+sqrt(1-x^2)))-atanh(sqrt(2)*sqrt(c)*sqrt(1-x^2)/sqrt(b+2*c-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(a+b+(b^2+a*(b-2*c))/sqrt(b^2-4*a*c))/_
+   (a^2*sqrt(2)*sqrt(b+2*c-sqrt(b^2-4*a*c)))-atanh(sqrt(2)*sqrt(c)*_
+   sqrt(1-x^2)/sqrt(b+2*c+sqrt(b^2-4*a*c)))*sqrt(c)*(a+b+(-b^2-a*(b-2*c))/_
+   sqrt(b^2-4*a*c))/(a^2*sqrt(2)*sqrt(b+2*c+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                        +-----------+
+--R                      2 |          2              2         2  +-+
+--R         ((- 2b - 2a)x \|- 4a c + b   + (4a c - 2b  - 2a b)x )\|c
+--R      *
+--R          +-----------------------+                +--------+
+--R          | +-----------+                      +-+ |   2      +-+
+--R          | |          2                      \|2 \|- x  + 1 \|c
+--R         \|\|- 4a c + b   + 2c + b atanh(----------------------------)
+--R                                          +-------------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + 2c + b
+--R     + 
+--R                        +-----------+
+--R                      2 |          2                2         2  +-+
+--R         ((- 2b - 2a)x \|- 4a c + b   + (- 4a c + 2b  + 2a b)x )\|c
+--R      *
+--R          +-------------------------+               +--------+
+--R          |   +-----------+                     +-+ |   2      +-+
+--R          |   |          2                     \|2 \|- x  + 1 \|c
+--R         \|- \|- 4a c + b   + 2c + b atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            | +-----------+
+--R                                            | |          2
+--R                                           \|\|- 4a c + b   + 2c + b
+--R     + 
+--R                          +-----------+       +--------+
+--R                    2 +-+ |          2        |   2
+--R           (2b + a)x \|2 \|- 4a c + b  atanh(\|- x  + 1 )
+--R         + 
+--R                   +--------+ +-----------+
+--R               +-+ |   2      |          2
+--R           - a\|2 \|- x  + 1 \|- 4a c + b
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |   +-----------+           | +-----------+
+--R          |   |          2            | |          2
+--R         \|- \|- 4a c + b   + 2c + b \|\|- 4a c + b   + 2c + b
+--R  /
+--R                               +-------------------------+
+--R                 +-----------+ |   +-----------+
+--R         2 2 +-+ |          2  |   |          2
+--R       2a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + 2c + b
+--R    *
+--R        +-----------------------+
+--R        | +-----------+
+--R        | |          2
+--R       \|\|- 4a c + b   + 2c + b
+--R                                                    Type: Expression(Integer)
+--E 1714
+
+--S 1715 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1715
+
+)clear all
+
+--S 1716 of 1718
+t0:=x^2*sqrt(1-x^2)/(-1+x^2+x^4)
+--R 
+--R
+--R           +--------+
+--R         2 |   2
+--R        x \|- x  + 1
+--R   (1)  -------------
+--R          4    2
+--R         x  + x  - 1
+--R                                                    Type: Expression(Integer)
+--E 1716
+
+--S 1717 of 1718
+r0:=-asin(x)-atanh(x*sqrt(1/2*(-1+sqrt(5)))/sqrt(1-x^2))*_
+   sqrt(1/5*(-2+sqrt(5)))+atan(x*sqrt(1/2*(1+sqrt(5)))/sqrt(1-x^2))*_
+   sqrt(1/5*(2+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                              +--------+                         +--------+
+--R          +--------+          | +-+           +--------+         | +-+
+--R          | +-+             x\|\|5  - 1       | +-+            x\|\|5  + 1
+--R       - \|\|5  - 2 atanh(---------------) + \|\|5  + 2 atan(---------------)
+--R                               +--------+                         +--------+
+--R                           +-+ |   2                          +-+ |   2
+--R                          \|2 \|- x  + 1                     \|2 \|- x  + 1
+--R     + 
+--R          +-+
+--R       - \|5 asin(x)
+--R  /
+--R      +-+
+--R     \|5
+--R                                                    Type: Expression(Integer)
+--E 1717
+
+--S 1718 of 1718
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                      +--------+ +--------+
+--R            2      +-+ +-+     2 +-+  | +-+      | +-+
+--R       ((- x  + 2)\|2 \|5  - 5x \|2 )\|\|5  + 1 \|\|5  + 2
+--R     + 
+--R                                    +--------+ +--------+
+--R          2      +-+ +-+     2 +-+  | +-+      | +-+           2
+--R       ((x  - 2)\|2 \|5  - 5x \|2 )\|\|5  - 2 \|\|5  - 1  + 40x  - 20
+--R  /
+--R                        +--------+
+--R         4      2       |   2
+--R     (20x  + 20x  - 20)\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 1718
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder16.input.pamphlet b/src/input/richder16.input.pamphlet
new file mode 100644
index 0000000..951f293
--- /dev/null
+++ b/src/input/richder16.input.pamphlet
@@ -0,0 +1,22635 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder16.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a+b x^n+c x^(2n))^p|
+There are 37 answers that differ from Rubi
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder16.output
+)spool richder16.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1311
+t0:=(a*x^3+b*x^6)^(5/3)
+--R 
+--R
+--R                      +-----------+2
+--R            6      3 3|   6      3
+--R   (1)  (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 1311
+r0:=-3/88*a*(a*x^3+b*x^6)^(8/3)/(b^2*x^8)+1/11*(a*x^3+b*x^6)^(8/3)/(b*x^5)
+--R 
+--R
+--R                                           +-----------+2
+--R           3 9        2 6     2   3     3 3|   6      3
+--R        (8b x  + 13a b x  + 2a b x  - 3a )\|b x  + a x
+--R   (2)  -------------------------------------------------
+--R                                 2 2
+--R                              88b x
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 1311
+t0:=(a*x^3+b*x^6)^(2/3)
+--R 
+--R
+--R         +-----------+2
+--R        3|   6      3
+--R   (1)  \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 1311
+r0:=1/5*(a*x^3+b*x^6)^(5/3)/(b*x^5)
+--R 
+--R
+--R                   +-----------+2
+--R            3     3|   6      3
+--R        (b x  + a)\|b x  + a x
+--R   (2)  -------------------------
+--R                      2
+--R                  5b x
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 1311
+t0:=1/(a*x^3+b*x^6)^(2/3)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         +-----------+2
+--R        3|   6      3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 1311
+r0:=-(a*x^3+b*x^6)^(1/3)/(a*x^2)
+--R 
+--R
+--R           +-----------+
+--R          3|   6      3
+--R          \|b x  + a x
+--R   (2)  - --------------
+--R                  2
+--R               a x
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 1311
+t0:=1/(a*x^3+b*x^6)^(5/3)
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R                      +-----------+2
+--R            6      3 3|   6      3
+--R        (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 1311
+r0:=1/2/(a*x^2*(a*x^3+b*x^6)^(2/3))-3/4*(a*x^3+b*x^6)^(1/3)/(a^2*x^5)+_
+   9/4*b*(a*x^3+b*x^6)^(1/3)/(a^3*x^2)
+--R 
+--R
+--R          2 6         3    2
+--R        9b x  + 6a b x  - a
+--R   (2)  --------------------
+--R               +-----------+2
+--R          3 2 3|   6      3
+--R        4a x  \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 1311
+t0:=x^m*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R           +-------------------+
+--R         m | 2 6         3    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 1311
+r0:=x^(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(4+m)+3*a*x^(1+m)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/((4+5*m+m^2)*(a+b*x^3))
+--R 
+--R
+--R                                       +-------------------+
+--R                   3             m + 1 | 2 6         3    2
+--R        ((b m + b)x  + a m + 4a)x     \|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------
+--R                   2              3      2
+--R               (b m  + 5b m + 4b)x  + a m  + 5a m + 4a
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 1311
+t0:=x^5*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R           +-------------------+
+--R         5 | 2 6         3    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 1311
+r0:=1/9*x^6*sqrt(a^2+2*a*b*x^3+b^2*x^6)+1/18*a*x^6*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                        +-------------------+
+--R             9       6  | 2 6         3    2
+--R        (2b x  + 3a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          3
+--R                     18b x  + 18a
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 1311
+d0:=normalize(t-D(r0,x))
+--R 
+--R
+--R          +-------------------+
+--R          | 2 6         3    2     2 11         8    2 5
+--R        t\|b x  + 2a b x  + a   - b x   - 2a b x  - a x
+--R   (3)  ------------------------------------------------
+--R                      +-------------------+
+--R                      | 2 6         3    2
+--R                     \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 1311
+t0:=x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R           +-------------------+
+--R         4 | 2 6         3    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 1311
+r0:=1/8*x^5*sqrt(a^2+2*a*b*x^3+b^2*x^6)+3/40*a*x^5*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                        +-------------------+
+--R             8       5  | 2 6         3    2
+--R        (5b x  + 8a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          3
+--R                     40b x  + 40a
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 1311
+t0:=x^3*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R           +-------------------+
+--R         3 | 2 6         3    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 1311
+r0:=1/7*x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)+3/28*a*x^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                        +-------------------+
+--R             7       4  | 2 6         3    2
+--R        (4b x  + 7a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          3
+--R                     28b x  + 28a
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 1311
+t0:=x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R           +-------------------+
+--R         2 | 2 6         3    2
+--R   (1)  x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 1311
+r0:=1/6*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/b
+--R 
+--R
+--R                   +-------------------+
+--R            3      | 2 6         3    2
+--R        (b x  + a)\|b x  + 2a b x  + a
+--R   (2)  --------------------------------
+--R                       6b
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 1311
+t0:=x*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R          +-------------------+
+--R          | 2 6         3    2
+--R   (1)  x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 1311
+r0:=1/5*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+3/10*a*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                        +-------------------+
+--R             5       2  | 2 6         3    2
+--R        (2b x  + 5a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                          3
+--R                     10b x  + 10a
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R   (1)  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 1311
+r0:=1/4*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)+3/4*a*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                      +-------------------+
+--R            4         | 2 6         3    2
+--R        (b x  + 4a x)\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------
+--R                         3
+--R                     4b x  + 4a
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 1311
+r0:=1/3*sqrt(a^2+2*a*b*x^3+b^2*x^6)+a*log(x)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                               +-------------------+
+--R                        3      | 2 6         3    2
+--R        (3a log(x) + b x  + a)\|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------
+--R                             3
+--R                         3b x  + 3a
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   2
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 1311
+r0:=1/2*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x-_
+   3/2*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x*(a+b*x^3))
+--R 
+--R
+--R                    +-------------------+
+--R            3       | 2 6         3    2
+--R        (b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------
+--R                       4
+--R                   2b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^3
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   3
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 1311
+r0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2-3/2*a*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^2*(a+b*x^3))
+--R 
+--R
+--R                    +-------------------+
+--R             3      | 2 6         3    2
+--R        (2b x  - a)\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------
+--R                      5       2
+--R                  2b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   4
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 1311
+r0:=-1/3*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^3*(a+b*x^3))+_
+   b*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                          +-------------------+
+--R             3            | 2 6         3    2
+--R        (3b x log(x) - a)\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------
+--R                         6       3
+--R                     3b x  + 3a x
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   5
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 1311
+r0:=-sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4+3/4*a*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^4*(a+b*x^3))
+--R 
+--R
+--R                      +-------------------+
+--R               3      | 2 6         3    2
+--R        (- 4b x  - a)\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------
+--R                       7       4
+--R                   4b x  + 4a x
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^6
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   6
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 1311
+r0:=-1/2*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5+_
+   3/10*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^5*(a+b*x^3))
+--R 
+--R
+--R                       +-------------------+
+--R               3       | 2 6         3    2
+--R        (- 5b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                        8        5
+--R                   10b x  + 10a x
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   7
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 1311
+r0:=-1/6*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a*x^6)
+--R 
+--R
+--R                     +-------------------+
+--R              3      | 2 6         3    2
+--R        (- b x  - a)\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------
+--R                           6
+--R                       6a x
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   8
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 1311
+r0:=-1/4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7+_
+   3/28*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^7*(a+b*x^3))
+--R 
+--R
+--R                       +-------------------+
+--R               3       | 2 6         3    2
+--R        (- 7b x  - 4a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       10        7
+--R                  28b x   + 28a x
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^9
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   9
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 1311
+r0:=-1/5*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8+_
+   3/40*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^8*(a+b*x^3))
+--R 
+--R
+--R                       +-------------------+
+--R               3       | 2 6         3    2
+--R        (- 8b x  - 5a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       11        8
+--R                  40b x   + 40a x
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   10
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 1311
+r0:=-1/6*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^9+_
+   1/18*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^9*(a+b*x^3))
+--R 
+--R
+--R                       +-------------------+
+--R               3       | 2 6         3    2
+--R        (- 3b x  - 2a)\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------
+--R                       12        9
+--R                  18b x   + 18a x
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 1311
+t0:=sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^11
+--R 
+--R
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R   (1)  ----------------------
+--R                   11
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 1311
+r0:=-1/7*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10+_
+   3/70*a*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^10*(a+b*x^3))
+--R 
+--R
+--R                        +-------------------+
+--R                3       | 2 6         3    2
+--R        (- 10b x  - 7a)\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------
+--R                       13        10
+--R                  70b x   + 70a x
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 1311
+t0:=x^m*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 6         3    2  m | 2 6         3    2
+--R   (1)  (b x  + 2a b x  + a )x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 1311
+r0:=x^(1+m)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/(10+m)+_
+   54*a^2*x^(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/((4+m)*(7+m)*(10+m))+_
+   162*a^3*x^(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/((7+m)*(10+m)*_
+   (4+5*m+m^2)*(a+b*x^3))+9*a*x^(1+m)*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(70+17*m+m^2)
+--R 
+--R
+--R   (2)
+--R           3 3      3 2      3       3  9
+--R         (b m  + 12b m  + 39b m + 28b )x
+--R       + 
+--R              2 3        2 2         2          2  6
+--R         (3a b m  + 45a b m  + 162a b m + 120a b )x
+--R       + 
+--R            2   3      2   2       2          2   3    3 3      3 2       3
+--R         (3a b m  + 54a b m  + 261a b m + 210a b)x  + a m  + 21a m  + 138a m
+--R       + 
+--R             3
+--R         280a
+--R    *
+--R              +-------------------+
+--R        m + 1 | 2 6         3    2
+--R       x     \|b x  + 2a b x  + a
+--R  /
+--R           4        3         2                  3      4        3         2
+--R       (b m  + 22b m  + 159b m  + 418b m + 280b)x  + a m  + 22a m  + 159a m
+--R     + 
+--R       418a m + 280a
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 1311
+t0:=x^9*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 15         12    2 9  | 2 6         3    2
+--R   (1)  (b x   + 2a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 1311
+r0:=1/19*x^10*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/1976*a^2*x^10*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/19760*a^3*x^10*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/304*a*x^10*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R                                                       +-------------------+
+--R         3 19          2 16        2   13        3 10  | 2 6         3    2
+--R   (1040b x   + 3705a b x   + 4560a b x   + 1976a x  )\|b x  + 2a b x  + a
+--R   -------------------------------------------------------------------------
+--R                                       3
+--R                               19760b x  + 19760a
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 1311
+t0:=x^8*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 14         11    2 8  | 2 6         3    2
+--R   (1)  (b x   + 2a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 1311
+r0:=1/36*a^2*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/b^3+_
+   1/18*x^6*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/b-_
+   1/45*a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^3
+--R 
+--R
+--R   (2)
+--R                                                           +-------------------+
+--R       5 15        4 12      2 3 9    3 2 6    4   3    5  | 2 6         3    2
+--R   (10b x   + 26a b x   + 19a b x  + a b x  - a b x  + a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------------
+--R                                           3
+--R                                       180b
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 1311
+t0:=x^7*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                  +-------------------+
+--R          2 13         10    2 7  | 2 6         3    2
+--R   (1)  (b x   + 2a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 1311
+r0:=1/17*x^8*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/1309*a^2*x^8*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/10472*a^3*x^8*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+9/238*a*x^8*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R        3 17          2 14        2   11        3 8  | 2 6         3    2
+--R   (616b x   + 2244a b x   + 2856a b x   + 1309a x )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                      3
+--R                              10472b x  + 10472a
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 1311
+t0:=x^6*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                 +-------------------+
+--R          2 12         9    2 6  | 2 6         3    2
+--R   (1)  (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 1311
+r0:=1/16*x^7*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/1040*a^2*x^7*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/7280*a^3*x^7*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/208*a*x^7*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R        3 16          2 13        2   10        3 7  | 2 6         3    2
+--R   (455b x   + 1680a b x   + 2184a b x   + 1040a x )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                      3
+--R                               7280b x  + 7280a
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 1311
+t0:=x^5*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                 +-------------------+
+--R          2 11         8    2 5  | 2 6         3    2
+--R   (1)  (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 1311
+r0:=-1/12*a*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/b^2+_
+   1/15*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^2
+--R 
+--R
+--R                                                    +-------------------+
+--R           4 12        3 9     2 2 6    3   3    4  | 2 6         3    2
+--R        (4b x   + 11a b x  + 9a b x  + a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------------
+--R                                          2
+--R                                       60b
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 1311
+t0:=x^4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                 +-------------------+
+--R          2 10         7    2 4  | 2 6         3    2
+--R   (1)  (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 1311
+r0:=1/14*x^5*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/616*a^2*x^5*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/3080*a^3*x^5*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/154*a*x^5*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                                                       +-------------------+
+--R             3 14         2 11        2   8       3 5  | 2 6         3    2
+--R        (220b x   + 840a b x   + 1155a b x  + 616a x )\|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------------------------------
+--R                                         3
+--R                                  3080b x  + 3080a
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 1311
+t0:=x^3*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 9         6    2 3  | 2 6         3    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 1311
+r0:=1/13*x^4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/455*a^2*x^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/1820*a^3*x^4*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/130*a*x^4*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                                                      +-------------------+
+--R             3 13         2 10       2   7       3 4  | 2 6         3    2
+--R        (140b x   + 546a b x   + 780a b x  + 455a x )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------------------
+--R                                         3
+--R                                  1820b x  + 1820a
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 1311
+t0:=x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                                +-------------------+
+--R          2 8         5    2 2  | 2 6         3    2
+--R   (1)  (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 1311
+r0:=1/12*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/b
+--R 
+--R
+--R                                        +-------------------+
+--R          3 9       2 6     2   3    3  | 2 6         3    2
+--R        (b x  + 3a b x  + 3a b x  + a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------
+--R                                 12b
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 1311
+t0:=x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                               +-------------------+
+--R          2 7         4    2   | 2 6         3    2
+--R   (1)  (b x  + 2a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 1311
+r0:=1/11*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/220*a^2*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/440*a^3*x^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/88*a*x^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                                                    +-------------------+
+--R            3 11         2 8       2   5       3 2  | 2 6         3    2
+--R        (40b x   + 165a b x  + 264a b x  + 220a x )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------------
+--R                                        3
+--R                                  440b x  + 440a
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R   (1)  (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 1311
+r0:=1/10*x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+27/140*a^2*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/140*a^3*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)/_
+   (a+b*x^3)+9/70*a*x*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                                                  +-------------------+
+--R            3 10        2 7       2   4       3   | 2 6         3    2
+--R        (14b x   + 60a b x  + 105a b x  + 140a x)\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------------------------------
+--R                                       3
+--R                                 140b x  + 140a
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 1311
+r0:=1/9*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/3*a^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+_
+   1/6*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)+a^3*log(x)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R                                                         +-------------------+
+--R            3           3 9       2 6      2   3      3  | 2 6         3    2
+--R        (18a log(x) + 2b x  + 9a b x  + 18a b x  + 11a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------------
+--R                                          3
+--R                                     18b x  + 18a
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^2
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              2
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 1311
+r0:=1/8*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x+27/20*a*b*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/40*a^2*b*x^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)-9/8*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x
+--R 
+--R
+--R                                             +-------------------+
+--R           3 9        2 6      2   3      3  | 2 6         3    2
+--R        (5b x  + 24a b x  + 60a b x  - 40a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------
+--R                                   4
+--R                              40b x  + 40a x
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^3
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              3
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 1311
+r0:=4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^2-27/7*b^2*x^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)-81/28*a*b^2*x^4*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)-9/2*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2
+--R 
+--R
+--R                                             +-------------------+
+--R           3 9        2 6      2   3      3  | 2 6         3    2
+--R        (4b x  + 21a b x  + 84a b x  - 14a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------
+--R                                   5        2
+--R                              28b x  + 28a x
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^4
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              4
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 1311
+r0:=1/6*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^3-a^3*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^3*(a+b*x^3))+1/2*a*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^3+3*a^2*b*log(x)*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R       2   3          3 9       2 6     2   3     3  | 2 6         3    2
+--R   (18a b x log(x) + b x  + 6a b x  + 9a b x  - 2a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    6       3
+--R                                6b x  + 6a x
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^5
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              5
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 1311
+r0:=-5/2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^4+27/10*b^2*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/20*a*b^2*x^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/4*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4
+--R 
+--R
+--R                                            +-------------------+
+--R           3 9        2 6      2   3     3  | 2 6         3    2
+--R        (4b x  + 30a b x  - 60a b x  - 5a )\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------------------------
+--R                                  7        4
+--R                             20b x  + 20a x
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^6
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              6
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 1311
+r0:=-11/10*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^5+27/20*b^2*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+81/20*a*b^2*x*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)+9/10*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5
+--R 
+--R
+--R                                            +-------------------+
+--R           3 9        2 6      2   3     3  | 2 6         3    2
+--R        (5b x  + 60a b x  - 30a b x  - 4a )\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------------------------
+--R                                  8        5
+--R                             20b x  + 20a x
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^7
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              7
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 1311
+r0:=-2/3*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^6+b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)+1/2*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^6+_
+   3*a*b^2*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R         2 6           3 9       2 6     2   3    3  | 2 6         3    2
+--R   (18a b x log(x) + 2b x  - 3a b x  - 6a b x  - a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    9       6
+--R                                6b x  + 6a x
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^8
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              8
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 1311
+r0:=-13/28*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^7+27/28*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x-81/28*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x*(a+b*x^3))+9/28*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7
+--R 
+--R
+--R                                             +-------------------+
+--R            3 9        2 6      2   3     3  | 2 6         3    2
+--R        (14b x  - 84a b x  - 21a b x  - 4a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------
+--R                                  10        7
+--R                             28b x   + 28a x
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^9
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                              9
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 1311
+r0:=-7/20*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^8+27/20*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2-81/40*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^2*(a+b*x^3))+9/40*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8
+--R 
+--R
+--R                                             +-------------------+
+--R            3 9        2 6      2   3     3  | 2 6         3    2
+--R        (40b x  - 60a b x  - 24a b x  - 5a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------
+--R                                  11        8
+--R                             40b x   + 40a x
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^10
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             10
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 1311
+r0:=-5/18*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^9-1/3*a*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^3*(a+b*x^3))+1/6*a*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^9+b^3*log(x)*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R                                                     +-------------------+
+--R       3 9           3 9        2 6     2   3     3  | 2 6         3    2
+--R   (18b x log(x) - 5b x  - 18a b x  - 9a b x  - 2a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------
+--R                                    12        9
+--R                               18b x   + 18a x
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^11
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             11
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 1311
+r0:=-8/35*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^10-27/35*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4+81/140*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^4*(a+b*x^3))+9/70*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10
+--R 
+--R
+--R                                                  +-------------------+
+--R               3 9         2 6      2   3      3  | 2 6         3    2
+--R        (- 140b x  - 105a b x  - 60a b x  - 14a )\|b x  + 2a b x  + a
+--R   (2)  ---------------------------------------------------------------
+--R                                    13         10
+--R                              140b x   + 140a x
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^12
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             12
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 1311
+r0:=-17/88*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^11-27/88*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5+81/440*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^5*(a+b*x^3))+9/88*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^11
+--R 
+--R
+--R                                                   +-------------------+
+--R               3 9         2 6       2   3      3  | 2 6         3    2
+--R        (- 220b x  - 264a b x  - 165a b x  - 40a )\|b x  + 2a b x  + a
+--R   (2)  ----------------------------------------------------------------
+--R                                     14         11
+--R                               440b x   + 440a x
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^13
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             13
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 1311
+r0:=-1/12*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/(a*x^12)
+--R 
+--R
+--R                                          +-------------------+
+--R            3 9       2 6     2   3    3  | 2 6         3    2
+--R        (- b x  - 3a b x  - 3a b x  - a )\|b x  + 2a b x  + a
+--R   (2)  -------------------------------------------------------
+--R                                     12
+--R                                12a x
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^14
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             14
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 1311
+r0:=-19/130*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^13-27/260*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7+81/1820*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^7*(a+b*x^3))+9/130*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^13
+--R 
+--R
+--R                                                    +-------------------+
+--R               3 9         2 6       2   3       3  | 2 6         3    2
+--R        (- 455b x  - 780a b x  - 546a b x  - 140a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------------
+--R                                     16          13
+--R                              1820b x   + 1820a x
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^15
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             15
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 1311
+r0:=-10/77*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^14-27/385*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8+81/3080*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^8*(a+b*x^3))+9/154*a*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^14
+--R 
+--R
+--R                                                     +-------------------+
+--R               3 9          2 6       2   3       3  | 2 6         3    2
+--R        (- 616b x  - 1155a b x  - 840a b x  - 220a )\|b x  + 2a b x  + a
+--R   (2)  ------------------------------------------------------------------
+--R                                      17          14
+--R                               3080b x   + 3080a x
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^16
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             16
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 1311
+r0:=-1/12*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/(a*x^15)+_
+   1/60*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(a^2*x^15)
+--R 
+--R
+--R                                                    +-------------------+
+--R          4 12      3 9     2 2 6      3   3     4  | 2 6         3    2
+--R        (b x   - a b x  - 9a b x  - 11a b x  - 4a )\|b x  + 2a b x  + a
+--R   (2)  -----------------------------------------------------------------
+--R                                        2 15
+--R                                     60a x
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^17
+--R 
+--R
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  -------------------------------------------
+--R                             17
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 1311
+r0:=-11/104*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^16-27/728*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10+81/7280*a*b^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(x^10*(a+b*x^3))+9/208*a*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^16
+--R 
+--R
+--R                                                       +-------------------+
+--R                3 9          2 6        2   3       3  | 2 6         3    2
+--R        (- 1040b x  - 2184a b x  - 1680a b x  - 455a )\|b x  + 2a b x  + a
+--R   (2)  --------------------------------------------------------------------
+--R                                       19          16
+--R                                7280b x   + 7280a x
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 1311
+t0:=x^m*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                     +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  m | 2 6         3    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a )x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 1311
+r0:=180*a^2*x^(1+m)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/((10+m)*(13+m)*(16+m))+_
+   15*a*x^(1+m)*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/(208+29*m+m^2)+_
+   x^(1+m)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(16+m)+9720*a^4*x^(1+m)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/((4+m)*(7+m)*(10+m)*(13+m)*(16+m))+29160*_
+   a^5*x^(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/((7+m)*(10+m)*(13+m)*(16+m)*_
+   (4+5*m+m^2)*(a+b*x^3))+1620*a^3*x^(1+m)*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/((13+m)*(16+m)*(70+17*m+m^2))
+--R 
+--R
+--R   (2)
+--R           5 5      5 4       5 3        5 2        5         5  15
+--R         (b m  + 35b m  + 445b m  + 2485b m  + 5714b m + 3640b )x
+--R       + 
+--R                 4 5         4 4          4 3           4 2           4
+--R             5a b m  + 190a b m  + 2555a b m  + 14810a b m  + 34840a b m
+--R           + 
+--R                     4
+--R             22400a b
+--R        *
+--R            12
+--R           x
+--R       + 
+--R                2 3 5       2 3 4        2 3 3         2 3 2         2 3
+--R             10a b m  + 410a b m  + 5950a b m  + 36550a b m  + 89240a b m
+--R           + 
+--R                   2 3
+--R             58240a b
+--R        *
+--R            9
+--R           x
+--R       + 
+--R                3 2 5       3 2 4        3 2 3         3 2 2          3 2
+--R             10a b m  + 440a b m  + 6970a b m  + 47260a b m  + 123920a b m
+--R           + 
+--R                   3 2
+--R             83200a b
+--R        *
+--R            6
+--R           x
+--R       + 
+--R               4   5       4   4        4   3         4   2          4
+--R             5a b m  + 235a b m  + 4085a b m  + 31685a b m  + 100630a b m
+--R           + 
+--R                   4
+--R             72800a b
+--R        *
+--R            3
+--R           x
+--R       + 
+--R          5 5      5 4       5 3        5 2         5          5
+--R         a m  + 50a m  + 955a m  + 8650a m  + 36824a m + 58240a
+--R    *
+--R              +-------------------+
+--R        m + 1 | 2 6         3    2
+--R       x     \|b x  + 2a b x  + a
+--R  /
+--R           6        5          4          3           2                      3
+--R       (b m  + 51b m  + 1005b m  + 9605b m  + 45474b m  + 95064b m + 58240b)x
+--R     + 
+--R          6        5          4          3           2
+--R       a m  + 51a m  + 1005a m  + 9605a m  + 45474a m  + 95064a m + 58240a
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 1311
+t0:=x^13*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 25       3 22     2 2 19     3   16    4 13  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 1311
+r0:=90/8671*a^2*x^14*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/754*a*x^14*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/29*x^14*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/147407*a^4*x^14*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/2063698*_
+   a^5*x^14*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/17342*a^3*x^14*_
+   (a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 29            4 26          2 3 23           3 2 20
+--R         71162b x   + 396865a b x   + 897260a b x   + 1031849a b x
+--R       + 
+--R                4   17          5 14
+--R         606970a b x   + 147407a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R               3
+--R     2063698b x  + 2063698a
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 1311
+t0:=x^12*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 24       3 21     2 2 18     3   15    4 12  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 1311
+r0:=9/770*a^2*x^13*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+3/140*a*x^13*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/28*x^13*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/117040*a^4*x^13*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/1521520*a^5*_
+   x^13*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/14630*a^3*_
+   x^13*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 28            4 25          2 3 22          3 2 19
+--R         54340b x   + 304304a b x   + 691600a b x   + 800800a b x
+--R       + 
+--R                4   16          5 13
+--R         475475a b x   + 117040a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R               3
+--R     1521520b x  + 1521520a
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 1311
+t0:=x^11*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 23       3 20     2 2 17     3   14    4 11  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 1311
+r0:=-1/216*a^3*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^4-1/72*a*x^6*_
+   (a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^2+1/27*x^9*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b+1/252*a^2*(a^2+2*a*b*x^3+b^2*x^6)^(7/2)/b^4
+--R 
+--R
+--R   (2)
+--R            8 24         7 21       2 6 18       3 5 15       4 4 12    5 3 9
+--R         56b x   + 259a b x   + 461a b x   + 379a b x   + 125a b x   + a b x
+--R       + 
+--R            6 2 6    7   3    8
+--R         - a b x  + a b x  - a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          4
+--R     1512b
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 1311
+t0:=x^10*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                         +-------------------+
+--R          4 22       3 19     2 2 16     3   13    4 10  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x  )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 1311
+r0:=9/598*a^2*x^11*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/598*a*x^11*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/26*x^11*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/71162*a^4*x^11*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/782782*a^5*_
+   x^11*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/10166*a^3*x^11*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 26            4 23          2 3 20          3 2 17
+--R         30107b x   + 170170a b x   + 391391a b x   + 460460a b x
+--R       + 
+--R                4   14         5 11
+--R         279565a b x   + 71162a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              3
+--R     782782b x  + 782782a
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 1311
+t0:=x^9*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                        +-------------------+
+--R          4 21       3 18     2 2 15     3   12    4 9  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 1311
+r0:=18/1045*a^2*x^10*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+3/110*a*x^10*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/25*x^10*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/54340*a^4*x^10*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/543400*a^5*x^10*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/8360*a^3*x^10*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 25            4 22          2 3 19          3 2 16
+--R         21736b x   + 123500a b x   + 286000a b x   + 339625a b x
+--R       + 
+--R                4   13         5 10
+--R         209000a b x   + 54340a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              3
+--R     543400b x  + 543400a
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 1311
+t0:=x^8*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                        +-------------------+
+--R          4 20       3 17     2 2 14     3   11    4 8  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 1311
+r0:=1/72*a^2*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^3+1/24*x^6*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b-1/84*a*(a^2+2*a*b*x^3+b^2*x^6)^(7/2)/b^3
+--R 
+--R
+--R   (2)
+--R            7 21        6 18       2 5 15       3 4 12      4 3 9    5 2 6
+--R         21b x   + 99a b x   + 181a b x   + 155a b x   + 55a b x  + a b x
+--R       + 
+--R            6   3    7
+--R         - a b x  + a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         3
+--R     504b
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 1311
+t0:=x^7*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                        +-------------------+
+--R          4 19       3 16     2 2 13     3   10    4 7  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x   + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 1311
+r0:=9/391*a^2*x^8*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+3/92*a*x^8*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/23*x^8*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/30107*a^4*x^8*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/240856*a^5*x^8*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/5474*a^3*x^8*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 23           4 20          2 3 17          3 2 14
+--R         10472b x   + 60214a b x   + 141680a b x   + 172040a b x
+--R       + 
+--R                4   11         5 8
+--R         109480a b x   + 30107a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              3
+--R     240856b x  + 240856a
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 1311
+t0:=x^6*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 18       3 15     2 2 12     3   9    4 6  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 1311
+r0:=45/1672*a^2*x^7*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/418*a*x^7*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/22*x^7*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/21736*a^4*x^7*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/152152*a^5*x^7*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+405/21736*a^3*x^7*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R              5 22           4 19         2 3 16          3 2 13         4   10
+--R         6916b x   + 40040a b x   + 95095a b x   + 117040a b x   + 76076a b x
+--R       + 
+--R               5 7
+--R         21736a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              3
+--R     152152b x  + 152152a
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 1311
+t0:=x^5*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 17       3 14     2 2 11     3   8    4 5  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 1311
+r0:=-1/18*a*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b^2+_
+   1/21*(a^2+2*a*b*x^3+b^2*x^6)^(7/2)/b^2
+--R 
+--R
+--R   (2)
+--R          6 18        5 15      2 4 12      3 3 9      4 2 6    5   3    6
+--R       (6b x   + 29a b x   + 55a b x   + 50a b x  + 20a b x  + a b x  - a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         2
+--R     126b
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 1311
+t0:=x^4*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                       +-------------------+
+--R          4 16       3 13     2 2 10     3   7    4 4  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 1311
+r0:=9/238*a^2*x^5*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+3/68*a*x^5*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/20*x^5*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/10472*a^4*x^5*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/52360*a^5*x^5*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/2618*a^3*x^5*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R              5 20           4 17         2 3 14         3 2 11         4   8
+--R         2618b x   + 15400a b x   + 37400a b x   + 47600a b x   + 32725a b x
+--R       + 
+--R               5 5
+--R         10472a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             3
+--R     52360b x  + 52360a
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 1311
+t0:=x^3*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                      +-------------------+
+--R          4 15       3 12     2 2 9     3   6    4 3  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 1311
+r0:=45/988*a^2*x^4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/304*a*x^4*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/19*x^4*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/6916*a^4*x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/27664*a^5*x^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/1976*a^3*x^4*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R              5 19          4 16         2 3 13         3 2 10         4   7
+--R         1456b x   + 8645a b x   + 21280a b x   + 27664a b x   + 19760a b x
+--R       + 
+--R              5 4
+--R         6916a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             3
+--R     27664b x  + 27664a
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 1311
+t0:=x^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                      +-------------------+
+--R          4 14       3 11     2 2 8     3   5    4 2  | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 1311
+r0:=1/18*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/b
+--R 
+--R
+--R   (2)
+--R                                                           +-------------------+
+--R     5 15       4 12      2 3 9      3 2 6     4   3    5  | 2 6         3    2
+--R   (b x   + 5a b x   + 10a b x  + 10a b x  + 5a b x  + a )\|b x  + 2a b x  + a
+--R   -----------------------------------------------------------------------------
+--R                                        18b
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 1311
+t0:=x*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                     +-------------------+
+--R          4 13       3 10     2 2 7     3   4    4   | 2 6         3    2
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 1311
+r0:=90/1309*a^2*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/238*a*x^2*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/17*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/2618*a^4*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/5236*a^5*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+405/5236*a^3*x^2*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R               5 17          4 14        2 3 11        3 2 8        4   5
+--R           308b x   + 1870a b x   + 4760a b x   + 6545a b x  + 5236a b x
+--R         + 
+--R                5 2
+--R           2618a x
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            3
+--R     5236b x  + 5236a
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 1311
+r0:=9/104*a^2*x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/208*a*x*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/16*x*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   243/1456*a^4*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/1456*a^5*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/728*a^3*x*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R           5 16         4 13        2 3 10        3 2 7        4   4        5
+--R       (91b x   + 560a b x   + 1456a b x   + 2080a b x  + 1820a b x  + 1456a x)
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            3
+--R     1456b x  + 1456a
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 1311
+r0:=1/9*a^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/12*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)+1/15*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)+_
+   1/3*a^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)+1/6*a^3*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+a^5*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R             5            5 15        4 12       2 3 9       3 2 6       4   3
+--R         180a log(x) + 12b x   + 75a b x   + 200a b x  + 300a b x  + 300a b x
+--R       + 
+--R             5
+--R         137a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           3
+--R     180b x  + 180a
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^2
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        2
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 1311
+r0:=90/77*a*b*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)-15/14*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x+1/14*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x+_
+   243/154*a^3*b*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/308*a^4*b*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+405/308*a^2*b*x^2*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R           5 15         4 12       2 3 9       3 2 6       4   3       5
+--R       (22b x   + 140a b x   + 385a b x  + 616a b x  + 770a b x  - 308a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           4
+--R     308b x  + 308a x
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^3
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        3
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 1311
+r0:=-90/13*b^2*x^4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)-15/2*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^2+7*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^2-_
+   486/91*a^2*b^2*x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)-729/182*a^3*b^2*x^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)-81/13*a*b^2*x^4*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R           5 15        4 12       2 3 9       3 2 6       4   3      5
+--R       (14b x   + 91a b x   + 260a b x  + 455a b x  + 910a b x  - 91a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           5         2
+--R     182b x  + 182a x
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^4
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        4
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 1311
+r0:=5/18*a^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^3+5/36*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^3+1/12*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^3-_
+   5/3*a^5*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^3*(a+b*x^3))+5/6*a^3*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^3+5*a^4*b*log(x)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R             4   3           5 15        4 12      2 3 9       3 2 6       4   3
+--R         180a b x log(x) + 3b x   + 20a b x   + 60a b x  + 120a b x  + 125a b x
+--R       + 
+--R              5
+--R         - 12a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          6        3
+--R     36b x  + 36a x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^5
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        5
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 1311
+r0:=45/11*b^2*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+15/4*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^4-4*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^4+_
+   243/44*a^2*b^2*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/88*a^3*b^2*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+405/88*a*b^2*x^2*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R          5 15        4 12       2 3 9       3 2 6       4   3      5
+--R       (8b x   + 55a b x   + 176a b x  + 440a b x  - 440a b x  - 22a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          7        4
+--R     88b x  + 88a x
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^6
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        6
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 1311
+r0:=9/5*b^2*x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+3/2*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^5-17/10*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^5+_
+   243/70*a^2*b^2*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/70*a^3*b^2*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+81/35*a*b^2*x*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R   (2)
+--R          5 15        4 12       2 3 9       3 2 6       4   3      5
+--R       (7b x   + 50a b x   + 175a b x  + 700a b x  - 175a b x  - 14a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          8        5
+--R     70b x  + 70a x
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^7
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        7
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 1311
+r0:=10/9*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)+5/6*a*(a+b*x^3)*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(3/2)/x^6-(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^6+10/3*a^2*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)+5/3*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)+10*a^3*b^2*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R             3 2 6           5 15        4 12      2 3 9      3 2 6      4   3
+--R         180a b x log(x) + 2b x   + 15a b x   + 60a b x  + 20a b x  - 30a b x
+--R       + 
+--R             5
+--R         - 3a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          9        6
+--R     18b x  + 18a x
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^8
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        8
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 1311
+r0:=45/56*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x+15/28*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^7-19/28*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/_
+   x^7+243/28*a*b^3*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+729/56*a^2*b^3*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)-405/56*a*b^2*(a+b*x^3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6)/x
+--R 
+--R
+--R   (2)
+--R          5 15        4 12       2 3 9       3 2 6      4   3     5
+--R       (7b x   + 56a b x   + 280a b x  - 560a b x  - 70a b x  - 8a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          10        7
+--R     56b x   + 56a x
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^9
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        9
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 1311
+r0:=18*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^2+3/8*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^8-1/2*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^8-243/14*b^4*x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)-_
+   729/56*a*b^4*x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)-81/4*a*_
+   b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2
+--R 
+--R
+--R   (2)
+--R          5 15        4 12       2 3 9       3 2 6      4   3     5
+--R       (8b x   + 70a b x   + 560a b x  - 280a b x  - 56a b x  - 7a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          11        8
+--R     56b x   + 56a x
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^10
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        10
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 1311
+r0:=5/9*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^3+5/18*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^9-7/18*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^9-10/3*a^3*b^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)/_
+   (x^3*(a+b*x^3))+5/3*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^3+_
+   10*a^2*b^3*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R             2 3 9           5 15        4 12      2 3 9      3 2 6      4   3
+--R         180a b x log(x) + 3b x   + 30a b x   + 40a b x  - 60a b x  - 15a b x
+--R       + 
+--R             5
+--R         - 2a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          12        9
+--R     18b x   + 18a x
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^11
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        11
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 1311
+r0:=-45/7*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^4+3/14*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^10-11/35*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^10+243/35*b^4*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)+_
+   729/70*a*b^4*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+_
+   81/14*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4
+--R 
+--R
+--R   (2)
+--R           5 15         4 12       2 3 9       3 2 6      4   3     5
+--R       (14b x   + 175a b x   - 700a b x  - 175a b x  - 50a b x  - 7a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          13        10
+--R     70b x   + 70a x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^12
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        12
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 1311
+r0:=-9/4*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^5+15/88*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^11-23/88*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^11+243/88*b^4*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)+_
+   729/88*a*b^4*x*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)+_
+   81/44*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5
+--R 
+--R
+--R   (2)
+--R           5 15         4 12       2 3 9       3 2 6      4   3     5
+--R       (22b x   + 440a b x   - 440a b x  - 176a b x  - 55a b x  - 8a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          14        11
+--R     88b x   + 88a x
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^13
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        13
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 1311
+r0:=-10/9*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^6+5/36*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^12-2/9*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^12+5/3*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)+_
+   5/6*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^6+_
+   5*a*b^4*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R               4 12            5 15        4 12       2 3 9      3 2 6
+--R         180a b x  log(x) + 12b x   - 65a b x   - 120a b x  - 60a b x
+--R       + 
+--R              4   3     5
+--R         - 20a b x  - 3a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          15        12
+--R     36b x   + 36a x
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^14
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        14
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 1311
+r0:=-9/14*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^7+3/26*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^13-5/26*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^13+243/182*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x-_
+   729/182*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x*(a+b*x^3))+_
+   81/182*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7
+--R 
+--R
+--R   (2)
+--R           5 15         4 12       2 3 9       3 2 6      4   3      5
+--R       (91b x   - 910a b x   - 455a b x  - 260a b x  - 91a b x  - 14a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           16         13
+--R     182b x   + 182a x
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^15
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        15
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 1311
+r0:=-9/22*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^8+15/154*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^14-13/77*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^14+243/154*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^2-_
+   729/308*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^2*(a+b*x^3))+_
+   81/308*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8
+--R 
+--R
+--R   (2)
+--R            5 15         4 12       2 3 9       3 2 6       4   3      5
+--R       (308b x   - 770a b x   - 616a b x  - 385a b x  - 140a b x  - 22a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           17         14
+--R     308b x   + 308a x
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^16
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        16
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 1311
+r0:=-5/18*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^9+1/12*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^15-3/20*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^15-1/3*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/_
+   (x^3*(a+b*x^3))+1/6*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^9+_
+   b^5*log(x)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a+b*x^3)
+--R 
+--R
+--R   (2)
+--R             5 15            5 15         4 12       2 3 9       3 2 6
+--R         180b x  log(x) - 77b x   - 300a b x   - 300a b x  - 200a b x
+--R       + 
+--R              4   3      5
+--R         - 75a b x  - 12a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R           18         15
+--R     180b x   + 180a x
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^17
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        17
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 1311
+r0:=-18/91*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^10+15/208*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^16-7/52*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^16-243/364*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^4+_
+   729/1456*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^4*(a+b*x^3))+_
+   81/728*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10
+--R 
+--R
+--R   (2)
+--R               5 15          4 12        2 3 9        3 2 6       4   3      5
+--R       (- 1456b x   - 1820a b x   - 2080a b x  - 1456a b x  - 560a b x  - 91a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            19          16
+--R     1456b x   + 1456a x
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^18
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        18
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 1311
+r0:=-45/308*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^11+15/238*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^17-29/238*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^17-1215/5236*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^5+_
+   729/5236*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^5*(a+b*x^3))+_
+   405/5236*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^11
+--R 
+--R
+--R   (2)
+--R                  5 15          4 12        2 3 9        3 2 6        4   3
+--R           - 2618b x   - 5236a b x   - 6545a b x  - 4760a b x  - 1870a b x
+--R         + 
+--R                 5
+--R           - 308a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R            20          17
+--R     5236b x   + 5236a x
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^19
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        19
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 1311
+r0:=-1/18*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(a*x^18)
+--R 
+--R
+--R   (2)
+--R           5 15       4 12      2 3 9      3 2 6     4   3    5
+--R       (- b x   - 5a b x   - 10a b x  - 10a b x  - 5a b x  - a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R          18
+--R     18a x
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^20
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        20
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 1311
+r0:=-9/104*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^13+15/304*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^19-31/304*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^19-243/3952*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^7+_
+   729/27664*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^7*(a+b*x^3))+_
+   81/1976*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^13
+--R 
+--R
+--R   (2)
+--R                5 15           4 12         2 3 9         3 2 6        4   3
+--R         - 6916b x   - 19760a b x   - 27664a b x  - 21280a b x  - 8645a b x
+--R       + 
+--R                5
+--R         - 1456a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             22           19
+--R     27664b x   + 27664a x
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^21
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        21
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 1311
+r0:=-90/1309*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^14+3/68*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^20-8/85*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^20-243/6545*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^8+_
+   729/52360*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^8*(a+b*x^3))+_
+   81/2618*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^14
+--R 
+--R
+--R   (2)
+--R                 5 15           4 12         2 3 9         3 2 6         4   3
+--R         - 10472b x   - 32725a b x   - 47600a b x  - 37400a b x  - 15400a b x
+--R       + 
+--R                5
+--R         - 2618a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R             23           20
+--R     52360b x   + 52360a x
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^22
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        22
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 1311
+r0:=-1/18*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(a*x^21)+_
+   1/126*(a^2+2*a*b*x^3+b^2*x^6)^(7/2)/(a^2*x^21)
+--R 
+--R
+--R   (2)
+--R         6 18      5 15      2 4 12      3 3 9      4 2 6      5   3     6
+--R       (b x   - a b x   - 20a b x   - 50a b x  - 55a b x  - 29a b x  - 6a )
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         2 21
+--R     126a x
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^23
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        23
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 1311
+r0:=-45/988*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^16+15/418*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^22-17/209*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^22-1215/76076*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^10+_
+   729/152152*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^10*(a+b*x^3))+_
+   405/21736*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^16
+--R 
+--R
+--R   (2)
+--R                 5 15           4 12          2 3 9         3 2 6         4   3
+--R         - 21736b x   - 76076a b x   - 117040a b x  - 95095a b x  - 40040a b x
+--R       + 
+--R                5
+--R         - 6916a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              25            22
+--R     152152b x   + 152152a x
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^24
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        24
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 1311
+r0:=-9/238*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^17+3/92*a*(a+b*x^3)*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2)/x^23-7/92*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(5/2)/x^23-243/21896*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^11+_
+   729/240856*a*b^4*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(x^11*(a+b*x^3))+_
+   81/5474*a*b^2*(a+b*x^3)*sqrt(a^2+2*a*b*x^3+b^2*x^6)/x^17
+--R 
+--R
+--R   (2)
+--R                 5 15            4 12          2 3 9          3 2 6
+--R         - 30107b x   - 109480a b x   - 172040a b x  - 141680a b x
+--R       + 
+--R                 4   3         5
+--R         - 60214a b x  - 10472a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R              26            23
+--R     240856b x   + 240856a x
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/x^25
+--R 
+--R
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R   (1)  ----------------------------------------------------------------
+--R                                        25
+--R                                       x
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 1311
+r0:=-1/24*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(a*x^24)+_
+   1/72*b*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^(5/2)/(a^2*x^21)-_
+   1/504*b*(a^2+2*a*b*x^3+b^2*x^6)^(7/2)/(a^3*x^21)
+--R 
+--R
+--R   (2)
+--R            7 21      6 18    2 5 15      3 4 12       4 3 9       5 2 6
+--R         - b x   + a b x   - a b x   - 55a b x   - 155a b x  - 181a b x
+--R       + 
+--R              6   3      7
+--R         - 99a b x  - 21a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R  /
+--R         3 24
+--R     504a x
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 1311
+t0:=x^m/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   m
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 1311
+--r0:=x^(1+m)*(a+b*x^3)*hypergeometric(1,1/3*(1+m),1/3*(4+m),_
+--   -b*x^3/a)/(a*(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--E 272
+
+--S 273 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 273
+
+)clear all
+
+--S 274 of 1311
+t0:=x^4/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   4
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 1311
+r0:=1/2*x^2*(a+b*x^3)/(b*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   1/3*a^(2/3)*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(b^(5/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/6*a^(2/3)*(a+b*x^3)*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(b^(5/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   a^(2/3)*(a+b*x^3)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/_
+   (b^(5/3)*sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             3      +-+3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - a)\|3 \|a  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            3       +-+3+-+2     3+-+   3+-+
+--R       (2b x  + 2a)\|3 \|a  log(x\|b  + \|a )
+--R     + 
+--R                                 3+-+   3+-+
+--R              3      3+-+2     2x\|b  - \|a          5       2  +-+3+-+2
+--R       (- 6b x  - 6a)\|a  atan(-------------) + (3b x  + 3a x )\|3 \|b
+--R                                   +-+3+-+
+--R                                  \|3 \|a
+--R  /
+--R                 +-------------------+
+--R        +-+3+-+2 | 2 6         3    2
+--R     6b\|3 \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 1311
+t0:=x^3/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   3
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 1311
+r0:=x*(a+b*x^3)/(b*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*a^(1/3)*(a+b*x^3)*_
+   log(a^(1/3)+b^(1/3)*x)/(b^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   1/6*a^(1/3)*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (b^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+a^(1/3)*(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(b^(4/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R           3      +-+3+-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + a)\|3 \|a log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              3       +-+3+-+     3+-+   3+-+
+--R       (- 2b x  - 2a)\|3 \|a log(x\|b  + \|a )
+--R     + 
+--R                                3+-+   3+-+
+--R              3      3+-+     2x\|b  - \|a          4         +-+3+-+
+--R       (- 6b x  - 6a)\|a atan(-------------) + (6b x  + 6a x)\|3 \|b
+--R                                  +-+3+-+
+--R                                 \|3 \|a
+--R  /
+--R                +-------------------+
+--R        +-+3+-+ | 2 6         3    2
+--R     6b\|3 \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 1311
+t0:=x^2/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   2
+--R                  x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 1311
+r0:=1/3*(a+b*x^3)*log(a+b*x^3)/(b*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R             3            3
+--R         (b x  + a)log(b x  + a)
+--R   (2)  ------------------------
+--R           +-------------------+
+--R           | 2 6         3    2
+--R        3b\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 1311
+t0:=x/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   x
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 1311
+r0:=-1/3*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(1/3)*b^(2/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/6*(a+b*x^3)*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(1/3)*b^(2/3)*sqrt(a^2+_
+   2*a*b*x^3+b^2*x^6))-(a+b*x^3)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(1/3)*b^(2/3)*sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R           3      +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + a)\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                                                                3+-+   3+-+
+--R              3       +-+     3+-+   3+-+         3           2x\|b  - \|a
+--R       (- 2b x  - 2a)\|3 log(x\|b  + \|a ) + (6b x  + 6a)atan(-------------)
+--R                                                                  +-+3+-+
+--R                                                                 \|3 \|a
+--R  /
+--R                    +-------------------+
+--R       +-+3+-+3+-+2 | 2 6         3    2
+--R     6\|3 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 1311
+t0:=1/sqrt(a^2+2*a*b*x^3+b^2*x^6)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         | 2 6         3    2
+--R        \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 1311
+r0:=1/3*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*b^(1/3)*sqrt(a^2+_
+   2*a*b*x^3+b^2*x^6))-1/6*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+_
+   b^(2/3)*x^2)/(a^(2/3)*b^(1/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(1/3)*_
+   sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             3      +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - a)\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                                                              3+-+   3+-+
+--R            3       +-+     3+-+   3+-+         3           2x\|b  - \|a
+--R       (2b x  + 2a)\|3 log(x\|b  + \|a ) + (6b x  + 6a)atan(-------------)
+--R                                                                +-+3+-+
+--R                                                               \|3 \|a
+--R  /
+--R                     +-------------------+
+--R       +-+3+-+2 3+-+ | 2 6         3    2
+--R     6\|3 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 1311
+t0:=1/(x*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R          +-------------------+
+--R          | 2 6         3    2
+--R        x\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 1311
+r0:=(a+b*x^3)*log(x)/(a*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*(a+b*x^3)*_
+   log(a+b*x^3)/(a*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R              3            3             3
+--R        (- b x  - a)log(b x  + a) + (3b x  + 3a)log(x)
+--R   (2)  ----------------------------------------------
+--R                      +-------------------+
+--R                      | 2 6         3    2
+--R                   3a\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 1311
+t0:=1/(x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         2 | 2 6         3    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 1311
+r0:=(-a-b*x^3)/(a*x*sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/3*b^(1/3)*(a+b*x^3)*_
+   log(a^(1/3)+b^(1/3)*x)/(a^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   1/6*b^(1/3)*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+b^(1/3)*(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(4/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             4        +-+3+-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - a x)\|3 \|b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            4         +-+3+-+     3+-+   3+-+
+--R       (2b x  + 2a x)\|3 \|b log(x\|b  + \|a )
+--R     + 
+--R                                  3+-+   3+-+
+--R              4        3+-+     2x\|b  - \|a            3       +-+3+-+
+--R       (- 6b x  - 6a x)\|b atan(-------------) + (- 6b x  - 6a)\|3 \|a
+--R                                    +-+3+-+
+--R                                   \|3 \|a
+--R  /
+--R                  +-------------------+
+--R          +-+3+-+ | 2 6         3    2
+--R     6a x\|3 \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 1311
+t0:=1/(x^3*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         3 | 2 6         3    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 1311
+r0:=1/2*(-a-b*x^3)/(a*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*b^(2/3)*_
+   (a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(5/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   1/6*b^(2/3)*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(5/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+b^(2/3)*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(5/3)*sqrt(3)*sqrt(a^2+_
+   2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R           5      2  +-+3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + a x )\|3 \|b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              5       2  +-+3+-+2     3+-+   3+-+
+--R       (- 2b x  - 2a x )\|3 \|b  log(x\|b  + \|a )
+--R     + 
+--R                                    3+-+   3+-+
+--R              5       2 3+-+2     2x\|b  - \|a            3       +-+3+-+2
+--R       (- 6b x  - 6a x )\|b  atan(-------------) + (- 3b x  - 3a)\|3 \|a
+--R                                      +-+3+-+
+--R                                     \|3 \|a
+--R  /
+--R                    +-------------------+
+--R         2 +-+3+-+2 | 2 6         3    2
+--R     6a x \|3 \|a  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 1311
+t0:=1/(x^4*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R           +-------------------+
+--R         4 | 2 6         3    2
+--R        x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 1311
+r0:=-b*(a+b*x^3)*log(x)/(a^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/3*b*(a+b*x^3)*_
+   log(a+b*x^3)/(a^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6)/(a^2*x^3)
+--R 
+--R
+--R   (2)
+--R         2 6        3        3             2 6         3           2 6         3
+--R       (b x  + a b x )log(b x  + a) + (- 3b x  - 3a b x )log(x) - b x  - 2a b x
+--R     + 
+--R          2
+--R       - a
+--R  /
+--R           +-------------------+
+--R       2 3 | 2 6         3    2
+--R     3a x \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 1311
+t0:=x^m/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                              m
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 1311
+--r0:=1/6*x^(1+m)*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+_
+--   1/18*(5-m)*x^(1+m)/(a^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+--   1/18*(2-m)*(5-m)*x^(1+m)*(a+b*x^3)*hypergeometric(1,1/3*(1+m),_
+--   1/3*(4+m),-b*x^3/a)/(a^3*(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--E 302
+
+--S 303 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 303
+
+)clear all
+
+--S 304 of 1311
+t0:=x^4/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                              4
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 1311
+r0:=1/6*x^5*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))-1/18*x^2/_
+   (a*b*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/27*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/_
+   (a^(4/3)*b^(5/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/54*(a+b*x^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(4/3)*b^(5/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/9*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(4/3)*b^(5/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R         2 6         3    2  +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (b x  + 2a b x  + a )\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            2 6         3     2  +-+     3+-+   3+-+
+--R       (- 2b x  - 4a b x  - 2a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                    3+-+   3+-+
+--R        2 6          3     2      2x\|b  - \|a          5       2  +-+3+-+3+-+2
+--R     (6b x  + 12a b x  + 6a )atan(-------------) + (6b x  - 3a x )\|3 \|a \|b
+--R                                      +-+3+-+
+--R                                     \|3 \|a
+--R  /
+--R                                     +-------------------+
+--R           2 3      2   +-+3+-+3+-+2 | 2 6         3    2
+--R     (54a b x  + 54a b)\|3 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 1311
+t0:=x^3/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                              3
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 1311
+r0:=1/6*x^4*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))-_
+   1/9*x/(a*b*sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/27*(a+b*x^3)*log(a^(1/3)+_
+   b^(1/3)*x)/(a^(5/3)*b^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   1/54*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(5/3)*b^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/9*(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(5/3)*b^(4/3)*_
+   sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R           2 6         3    2  +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b x  - 2a b x  - a )\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R          2 6         3     2  +-+     3+-+   3+-+
+--R       (2b x  + 4a b x  + 2a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                    3+-+   3+-+
+--R        2 6          3     2      2x\|b  - \|a          4         +-+3+-+2 3+-+
+--R     (6b x  + 12a b x  + 6a )atan(-------------) + (3b x  - 6a x)\|3 \|a   \|b
+--R                                      +-+3+-+
+--R                                     \|3 \|a
+--R  /
+--R                                      +-------------------+
+--R           2 3      2   +-+3+-+2 3+-+ | 2 6         3    2
+--R     (54a b x  + 54a b)\|3 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 1311
+t0:=x^2/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                              2
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 1311
+r0:=1/6*(-a-b*x^3)/(b*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                            1
+--R   (2)  - ------------------------------------
+--R                         +-------------------+
+--R             2 3         | 2 6         3    2
+--R          (6b x  + 6a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 1311
+t0:=x/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                             x
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 1311
+r0:=1/6*x^2*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+2/9*x^2/(a^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-2/27*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/_
+   (a^(7/3)*b^(2/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/27*(a+b*x^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(7/3)*b^(2/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-2/9*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(7/3)*b^(2/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R          2 6         3     2  +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (2b x  + 4a b x  + 2a )\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R            2 6         3     2  +-+     3+-+   3+-+
+--R       (- 4b x  - 8a b x  - 4a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                        3+-+   3+-+
+--R           2 6          3      2      2x\|b  - \|a
+--R       (12b x  + 24a b x  + 12a )atan(-------------)
+--R                                          +-+3+-+
+--R                                         \|3 \|a
+--R     + 
+--R             5        2  +-+3+-+3+-+2
+--R       (12b x  + 21a x )\|3 \|a \|b
+--R  /
+--R                                    +-------------------+
+--R         2   3      3  +-+3+-+3+-+2 | 2 6         3    2
+--R     (54a b x  + 54a )\|3 \|a \|b  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 1311
+t0:=1/(a^2+2*a*b*x^3+b^2*x^6)^(3/2)
+--R 
+--R
+--R                             1
+--R   (1)  -------------------------------------------
+--R                              +-------------------+
+--R          2 6         3    2  | 2 6         3    2
+--R        (b x  + 2a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 1311
+r0:=1/6*x*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+5/18*x/(a^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+5/27*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/_
+   (a^(8/3)*b^(1/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-5/54*(a+b*x^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(8/3)*b^(1/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-5/9*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(8/3)*b^(1/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R            2 6          3     2  +-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- 5b x  - 10a b x  - 5a )\|3 log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           2 6          3      2  +-+     3+-+   3+-+
+--R       (10b x  + 20a b x  + 10a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                        3+-+   3+-+
+--R           2 6          3      2      2x\|b  - \|a
+--R       (30b x  + 60a b x  + 30a )atan(-------------)
+--R                                          +-+3+-+
+--R                                         \|3 \|a
+--R     + 
+--R             4          +-+3+-+2 3+-+
+--R       (15b x  + 24a x)\|3 \|a   \|b
+--R  /
+--R                                     +-------------------+
+--R         2   3      3  +-+3+-+2 3+-+ | 2 6         3    2
+--R     (54a b x  + 54a )\|3 \|a   \|b \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 1311
+t0:=1/(x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R                               +-------------------+
+--R          2 7         4    2   | 2 6         3    2
+--R        (b x  + 2a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 1311
+r0:=1/6*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+_
+   1/3/(a^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))+(a+b*x^3)*log(x)/_
+   (a^3*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*(a+b*x^3)*log(a+b*x^3)/_
+   (a^3*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R            2 6         3     2        3           2 6          3     2
+--R       (- 2b x  - 4a b x  - 2a )log(b x  + a) + (6b x  + 12a b x  + 6a )log(x)
+--R     + 
+--R             3     2
+--R       2a b x  + 3a
+--R  /
+--R                     +-------------------+
+--R        3   3     4  | 2 6         3    2
+--R     (6a b x  + 6a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 1311
+t0:=1/(x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                +-------------------+
+--R          2 8         5    2 2  | 2 6         3    2
+--R        (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 1311
+r0:=1/6*(a+b*x^3)/(a*x*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+_
+   7/18/(a^2*x*sqrt(a^2+2*a*b*x^3+b^2*x^6))-14/9*(a+b*x^3)/(a^3*x*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+14/27*b^(1/3)*(a+b*x^3)*log(a^(1/3)+_
+   b^(1/3)*x)/(a^(10/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-7/27*b^(1/3)*_
+   (a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(10/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+14/9*b^(1/3)*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(10/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             2 7          4      2   +-+3+-+     2 3+-+2   3+-+3+-+   3+-+2
+--R       (- 14b x  - 28a b x  - 14a x)\|3 \|b log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           2 7          4      2   +-+3+-+     3+-+   3+-+
+--R       (28b x  + 56a b x  + 28a x)\|3 \|b log(x\|b  + \|a )
+--R     + 
+--R                                                3+-+   3+-+
+--R             2 7           4      2  3+-+     2x\|b  - \|a
+--R       (- 84b x  - 168a b x  - 84a x)\|b atan(-------------)
+--R                                                  +-+3+-+
+--R                                                 \|3 \|a
+--R     + 
+--R             2 6           3      2  +-+3+-+
+--R       (- 84b x  - 147a b x  - 54a )\|3 \|a
+--R  /
+--R                                +-------------------+
+--R         3   4      4   +-+3+-+ | 2 6         3    2
+--R     (54a b x  + 54a x)\|3 \|a \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+)clear all
+
+--S 325 of 1311
+t0:=1/(x^3*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                +-------------------+
+--R          2 9         6    2 3  | 2 6         3    2
+--R        (b x  + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 1311
+r0:=1/6*(a+b*x^3)/(a*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+4/9/(a^2*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-10/9*(a+b*x^3)/(a^3*x^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-20/27*b^(2/3)*(a+b*x^3)*log(a^(1/3)+_
+   b^(1/3)*x)/(a^(11/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+10/27*b^(2/3)*_
+   (a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(11/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+20/9*b^(2/3)*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(11/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R           2 8          5      2 2  +-+3+-+2     2 3+-+2   3+-+3+-+   3+-+2
+--R       (20b x  + 40a b x  + 20a x )\|3 \|b  log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             2 8          5      2 2  +-+3+-+2     3+-+   3+-+
+--R       (- 40b x  - 80a b x  - 40a x )\|3 \|b  log(x\|b  + \|a )
+--R     + 
+--R                                                    3+-+   3+-+
+--R              2 8           5       2 2 3+-+2     2x\|b  - \|a
+--R       (- 120b x  - 240a b x  - 120a x )\|b  atan(-------------)
+--R                                                      +-+3+-+
+--R                                                     \|3 \|a
+--R     + 
+--R             2 6          3      2  +-+3+-+2
+--R       (- 60b x  - 96a b x  - 27a )\|3 \|a
+--R  /
+--R                                  +-------------------+
+--R         3   5      4 2  +-+3+-+2 | 2 6         3    2
+--R     (54a b x  + 54a x )\|3 \|a  \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 1311
+t0:=1/(x^4*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R                                 +-------------------+
+--R          2 10         7    2 4  | 2 6         3    2
+--R        (b x   + 2a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 1311
+r0:=1/6*(a+b*x^3)/(a*x^3*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+1/2/(a^2*x^3*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-3*b*(a+b*x^3)*log(x)/(a^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+b*(a+b*x^3)*log(a+b*x^3)/(a^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a^4*x^3)
+--R 
+--R
+--R   (2)
+--R          3 9        2 6     2   3        3
+--R       (6b x  + 12a b x  + 6a b x )log(b x  + a)
+--R     + 
+--R           3 9        2 6      2   3            3 9        2 6      2   3     3
+--R     (- 18b x  - 36a b x  - 18a b x )log(x) - 6b x  - 18a b x  - 15a b x  - 2a
+--R  /
+--R                       +-------------------+
+--R        4   6     5 3  | 2 6         3    2
+--R     (6a b x  + 6a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 1311
+t0:=x^m/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        m
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 1311
+--r0:=1/12*x^(1+m)*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+_
+--   1/108*(11-m)*x^(1+m)/(a^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+_
+--   1/648*(8-m)*(11-m)*x^(1+m)*(a+b*x^3)/(a^3*(a^2+2*a*b*x^3+_
+--   b^2*x^6)^(3/2))+1/1944*(5-m)*(8-m)*(11-m)*x^(1+m)/(a^4*_
+--   sqrt(a^2+2*a*b*x^3+b^2*x^6))+1/1944*(2-m)*(5-m)*(8-m)*(11-m)*_
+--   x^(1+m)*(a+b*x^3)*hypergeometric(1,1/3*(1+m),1/3*(4+m),_
+--   -b*x^3/a)/(a^5*(1+m)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--E 332
+
+--S 333 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 333
+
+)clear all
+
+--S 334 of 1311
+t0:=x^6/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        6
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 1311
+r0:=1/12*a*x*(a+b*x^3)/(b^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))-_
+   13/108*x/(b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+1/162*x*(a+b*x^3)/_
+   (a*b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+5/486*x/(a^2*b^2*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+5/729*(a+b*x^3)*log(a^(1/3)+_
+   b^(1/3)*x)/(a^(8/3)*b^(7/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   5/1458*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(8/3)*b^(7/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-5/243*(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(8/3)*b^(7/3)*_
+   sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R               4 12        3 9      2 2 6      3   3      4  +-+
+--R         (- 10b x   - 40a b x  - 60a b x  - 40a b x  - 10a )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           4 12        3 9       2 2 6      3   3      4  +-+     3+-+   3+-+
+--R       (20b x   + 80a b x  + 120a b x  + 80a b x  + 20a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                                                  3+-+   3+-+
+--R           4 12         3 9       2 2 6       3   3      4      2x\|b  - \|a
+--R       (60b x   + 240a b x  + 360a b x  + 240a b x  + 60a )atan(-------------)
+--R                                                                    +-+3+-+
+--R                                                                   \|3 \|a
+--R     + 
+--R           3 10         2 7       2   4      3   +-+3+-+2 3+-+
+--R       (30b x   + 108a b x  - 225a b x  - 60a x)\|3 \|a   \|b
+--R  /
+--R             2 5 9        3 4 6        4 3 3        5 2  +-+3+-+2 3+-+
+--R       (2916a b x  + 8748a b x  + 8748a b x  + 2916a b )\|3 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 1311
+t0:=x^5/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        5
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 1311
+r0:=1/12*a*(a+b*x^3)/(b^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+(-1/9)/_
+   (b^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))
+--R 
+--R
+--R                                        3
+--R                                  - 4b x  - a
+--R   (2)  ---------------------------------------------------------------
+--R                                                  +-------------------+
+--R            5 9         4 6       2 3 3      3 2  | 2 6         3    2
+--R        (36b x  + 108a b x  + 108a b x  + 36a b )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 1311
+t0:=x^4/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        4
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 1311
+r0:=1/12*x^5*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))-_
+   7/108*x^2/(a*b*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+7/324*x^2*(a+b*x^3)/_
+   (a^2*b*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+7/243*x^2/(a^3*b*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-7/729*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/_
+   (a^(10/3)*b^(5/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+7/1458*(a+b*x^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(10/3)*b^(5/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-7/243*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(10/3)*b^(5/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             4 12        3 9      2 2 6      3   3      4  +-+
+--R         (14b x   + 56a b x  + 84a b x  + 56a b x  + 14a )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               4 12         3 9       2 2 6       3   3      4  +-+
+--R         (- 28b x   - 112a b x  - 168a b x  - 112a b x  - 28a )\|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                                                                  3+-+   3+-+
+--R           4 12         3 9       2 2 6       3   3      4      2x\|b  - \|a
+--R       (84b x   + 336a b x  + 504a b x  + 336a b x  + 84a )atan(-------------)
+--R                                                                    +-+3+-+
+--R                                                                   \|3 \|a
+--R     + 
+--R           3 11         2 8       2   5      3 2  +-+3+-+3+-+2
+--R       (84b x   + 315a b x  + 432a b x  - 42a x )\|3 \|a \|b
+--R  /
+--R             3 4 9        4 3 6        5 2 3        6   +-+3+-+3+-+2
+--R       (2916a b x  + 8748a b x  + 8748a b x  + 2916a b)\|3 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 1311
+t0:=x^3/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        3
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 1311
+r0:=1/12*x^4*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))-_
+   2/27*x/(a*b*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+1/81*x*(a+b*x^3)/_
+   (a^2*b*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+5/243*x/(a^3*b*sqrt(a^2+_
+   2*a*b*x^3+b^2*x^6))+10/729*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/_
+   (a^(11/3)*b^(4/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-5/729*(a+b*x^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(11/3)*b^(4/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-10/243*(a+b*x^3)*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(11/3)*b^(4/3)*sqrt(3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R               4 12        3 9       2 2 6      3   3      4  +-+
+--R         (- 20b x   - 80a b x  - 120a b x  - 80a b x  - 20a )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           4 12         3 9       2 2 6       3   3      4  +-+     3+-+   3+-+
+--R       (40b x   + 160a b x  + 240a b x  + 160a b x  + 40a )\|3 log(x\|b  + \|a )
+--R     + 
+--R                                                                    3+-+   3+-+
+--R            4 12         3 9       2 2 6       3   3       4      2x\|b  - \|a
+--R       (120b x   + 480a b x  + 720a b x  + 480a b x  + 120a )atan(-------------)
+--R                                                                      +-+3+-+
+--R                                                                     \|3 \|a
+--R     + 
+--R           3 10         2 7       2   4       3   +-+3+-+2 3+-+
+--R       (60b x   + 216a b x  + 279a b x  - 120a x)\|3 \|a   \|b
+--R  /
+--R             3 4 9        4 3 6        5 2 3        6   +-+3+-+2 3+-+
+--R       (2916a b x  + 8748a b x  + 8748a b x  + 2916a b)\|3 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 1311
+t0:=x^2/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        2
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 1311
+r0:=1/12*(-a-b*x^3)/(b*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))
+--R 
+--R
+--R                                        1
+--R   (2)  - ------------------------------------------------------------
+--R                                                 +-------------------+
+--R              4 9        3 6      2 2 3      3   | 2 6         3    2
+--R          (12b x  + 36a b x  + 36a b x  + 12a b)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 1311
+t0:=x/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        x
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 1311
+r0:=1/12*x^2*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+5/54*x^2/_
+   (a^2*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+35/324*x^2*(a+b*x^3)/_
+   (a^3*(a^2+2*a*b*x^3+b^2*x^6)^(3/2))+35/243*x^2/(a^4*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-35/729*(a+b*x^3)*log(a^(1/3)+_
+   b^(1/3)*x)/(a^(13/3)*b^(2/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   35/1458*(a+b*x^3)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(13/3)*b^(2/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))-35/243*(a+b*x^3)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(13/3)*b^(2/3)*_
+   sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             4 12         3 9       2 2 6       3   3      4  +-+
+--R         (70b x   + 280a b x  + 420a b x  + 280a b x  + 70a )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                4 12         3 9       2 2 6       3   3       4  +-+
+--R         (- 140b x   - 560a b x  - 840a b x  - 560a b x  - 140a )\|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R              4 12          3 9        2 2 6        3   3       4
+--R         (420b x   + 1680a b x  + 2520a b x  + 1680a b x  + 420a )
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R            3 11          2 8        2   5        3 2  +-+3+-+3+-+2
+--R       (420b x   + 1575a b x  + 2160a b x  + 1248a x )\|3 \|a \|b
+--R  /
+--R             4 3 9        5 2 6        6   3        7  +-+3+-+3+-+2
+--R       (2916a b x  + 8748a b x  + 8748a b x  + 2916a )\|3 \|a \|b
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 1311
+t0:=1/(a^2+2*a*b*x^3+b^2*x^6)^(5/2)
+--R 
+--R
+--R                                        1
+--R   (1)  ----------------------------------------------------------------
+--R                                                   +-------------------+
+--R          4 12       3 9     2 2 6     3   3    4  | 2 6         3    2
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 1311
+r0:=1/12*x*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+11/108*x/(a^2*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2))+11/81*x*(a+b*x^3)/(a^3*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(3/2))+55/243*x/(a^4*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   110/729*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(14/3)*b^(1/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-55/729*(a+b*x^3)*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(14/3)*b^(1/3)*sqrt(a^2+2*a*b*_
+   x^3+b^2*x^6))-110/243*(a+b*x^3)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(14/3)*b^(1/3)*sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R                4 12         3 9        2 2 6       3   3       4  +-+
+--R         (- 220b x   - 880a b x  - 1320a b x  - 880a b x  - 220a )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              4 12          3 9        2 2 6        3   3       4  +-+
+--R         (440b x   + 1760a b x  + 2640a b x  + 1760a b x  + 440a )\|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R               4 12          3 9        2 2 6        3   3        4
+--R         (1320b x   + 5280a b x  + 7920a b x  + 5280a b x  + 1320a )
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R            3 10          2 7        2   4        3   +-+3+-+2 3+-+
+--R       (660b x   + 2376a b x  + 3069a b x  + 1596a x)\|3 \|a   \|b
+--R  /
+--R             4 3 9        5 2 6        6   3        7  +-+3+-+2 3+-+
+--R       (2916a b x  + 8748a b x  + 8748a b x  + 2916a )\|3 \|a   \|b
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 1311
+t0:=1/(x*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  ------------------------------------------------------------------
+--R                                                     +-------------------+
+--R          4 13       3 10     2 2 7     3   4    4   | 2 6         3    2
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x)\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 1311
+r0:=1/12*(a+b*x^3)/(a*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+1/9/(a^2*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2))+1/6*(a+b*x^3)/(a^3*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(3/2))+1/3/(a^4*sqrt(a^2+2*a*b*x^3+b^2*x^6))+(a+b*x^3)*_
+   log(x)/(a^5*sqrt(a^2+2*a*b*x^3+b^2*x^6))-1/3*(a+b*x^3)*_
+   log(a+b*x^3)/(a^5*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R             4 12        3 9      2 2 6      3   3      4        3
+--R       (- 12b x   - 48a b x  - 72a b x  - 48a b x  - 12a )log(b x  + a)
+--R     + 
+--R           4 12         3 9       2 2 6       3   3      4               3 9
+--R       (36b x   + 144a b x  + 216a b x  + 144a b x  + 36a )log(x) + 12a b x
+--R     + 
+--R          2 2 6      3   3      4
+--R       42a b x  + 52a b x  + 25a
+--R  /
+--R                                               +-------------------+
+--R         5 3 9       6 2 6       7   3      8  | 2 6         3    2
+--R     (36a b x  + 108a b x  + 108a b x  + 36a )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 1311
+t0:=1/(x^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R                                                      +-------------------+
+--R          4 14       3 11     2 2 8     3   5    4 2  | 2 6         3    2
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 1311
+r0:=1/12*(a+b*x^3)/(a*x*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+13/108/(a^2*x*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2))+65/324*(a+b*x^3)/(a^3*x*(a^2+_
+   2*a*b*x^3+b^2*x^6)^(3/2))+455/972/(a^4*x*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6))-455/243*(a+b*x^3)/(a^5*x*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   455/729*b^(1/3)*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(16/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))-455/1458*b^(1/3)*(a+b*x^3)*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(16/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   455/243*b^(1/3)*(a+b*x^3)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(16/3)*sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R                4 13          3 10        2 2 7        3   4       4   +-+3+-+
+--R         (- 910b x   - 3640a b x   - 5460a b x  - 3640a b x  - 910a x)\|3 \|b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               4 13          3 10         2 2 7        3   4        4   +-+3+-+
+--R         (1820b x   + 7280a b x   + 10920a b x  + 7280a b x  + 1820a x)\|3 \|b
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                 4 13           3 10         2 2 7         3   4        4  3+-+
+--R         (- 5460b x   - 21840a b x   - 32760a b x  - 21840a b x  - 5460a x)\|b
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R               4 12           3 9         2 2 6         3   3        4  +-+3+-+
+--R       (- 5460b x   - 20475a b x  - 28080a b x  - 16224a b x  - 2916a )\|3 \|a
+--R  /
+--R             5 3 10        6 2 7        7   4        8   +-+3+-+
+--R       (2916a b x   + 8748a b x  + 8748a b x  + 2916a x)\|3 \|a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 1311
+t0:=1/(x^3*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R                                                      +-------------------+
+--R          4 15       3 12     2 2 9     3   6    4 3  | 2 6         3    2
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 1311
+r0:=1/12*(a+b*x^3)/(a*x^2*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+7/54/(a^2*x^2*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2))+77/324*(a+b*x^3)/(a^3*x^2*(a^2+_
+   2*a*b*x^3+b^2*x^6)^(3/2))+154/243/(a^4*x^2*sqrt(a^2+2*a*b*x^3+_
+   b^2*x^6))-385/243*(a+b*x^3)/(a^5*x^2*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   770/729*b^(2/3)*(a+b*x^3)*log(a^(1/3)+b^(1/3)*x)/(a^(17/3)*_
+   sqrt(a^2+2*a*b*x^3+b^2*x^6))+385/729*b^(2/3)*(a+b*x^3)*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(17/3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   770/243*b^(2/3)*(a+b*x^3)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(17/3)*sqrt(3)*sqrt(a^2+2*a*b*x^3+b^2*x^6))
+--R 
+--R
+--R   (2)
+--R               4 14          3 11        2 2 8        3   5        4 2  +-+3+-+2
+--R         (1540b x   + 6160a b x   + 9240a b x  + 6160a b x  + 1540a x )\|3 \|b
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                 4 14           3 11         2 2 8         3   5        4 2  +-+
+--R         (- 3080b x   - 12320a b x   - 18480a b x  - 12320a b x  - 3080a x )\|3
+--R      *
+--R         3+-+2     3+-+   3+-+
+--R         \|b  log(x\|b  + \|a )
+--R     + 
+--R                 4 14           3 11         2 2 8         3   5        4 2
+--R         (- 9240b x   - 36960a b x   - 55440a b x  - 36960a b x  - 9240a x )
+--R      *
+--R                     3+-+   3+-+
+--R         3+-+2     2x\|b  - \|a
+--R         \|b  atan(-------------)
+--R                       +-+3+-+
+--R                      \|3 \|a
+--R     + 
+--R             4 12           3 9         2 2 6         3   3        4  +-+3+-+2
+--R     (- 4620b x   - 16632a b x  - 21483a b x  - 11172a b x  - 1458a )\|3 \|a
+--R  /
+--R             5 3 11        6 2 8        7   5        8 2  +-+3+-+2
+--R       (2916a b x   + 8748a b x  + 8748a b x  + 2916a x )\|3 \|a
+--R    *
+--R        +-------------------+
+--R        | 2 6         3    2
+--R       \|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 1311
+t0:=1/(x^4*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R                                                       +-------------------+
+--R          4 16       3 13     2 2 10     3   7    4 4  | 2 6         3    2
+--R        (b x   + 4a b x   + 6a b x   + 4a b x  + a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 1311
+r0:=1/12*(a+b*x^3)/(a*x^3*(a^2+2*a*b*x^3+b^2*x^6)^(5/2))+5/36/(a^2*x^3*_
+   (a^2+2*a*b*x^3+b^2*x^6)^(3/2))+5/18*(a+b*x^3)/(a^3*x^3*(a^2+2*a*b*x^3+_
+   b^2*x^6)^(3/2))+5/6/(a^4*x^3*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   5*b*(a+b*x^3)*log(x)/(a^6*sqrt(a^2+2*a*b*x^3+b^2*x^6))+_
+   5/3*b*(a+b*x^3)*log(a+b*x^3)/(a^6*sqrt(a^2+2*a*b*x^3+b^2*x^6))-_
+   5/3*sqrt(a^2+2*a*b*x^3+b^2*x^6)/(a^6*x^3)
+--R 
+--R
+--R   (2)
+--R           5 15         4 12       2 3 9       3 2 6      4   3        3
+--R       (60b x   + 240a b x   + 360a b x  + 240a b x  + 60a b x )log(b x  + a)
+--R     + 
+--R              5 15         4 12        2 3 9       3 2 6       4   3
+--R       (- 180b x   - 720a b x   - 1080a b x  - 720a b x  - 180a b x )log(x)
+--R     + 
+--R            5 15         4 12       2 3 9       3 2 6       4   3      5
+--R       - 60b x   - 300a b x   - 570a b x  - 500a b x  - 185a b x  - 12a
+--R  /
+--R                                                  +-------------------+
+--R         6 3 12       7 2 9       8   6      9 3  | 2 6         3    2
+--R     (36a b x   + 108a b x  + 108a b x  + 36a x )\|b x  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 1311
+t0:=x^m*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         m  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 1311
+--r0:=x^(1+m)*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(1/3*(1+m),_
+--   -2*p,1/3*(4+m),-b*x^3/a)/((1+m)*((a+b*x^3)/a)^(2*p))
+--E 368
+
+--S 369 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 369
+
+)clear all
+
+--S 370 of 1311
+t0:=x^11*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         11  2 6         3    2 p
+--R   (1)  x  (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 1311
+r0:=-a^3*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b^4*(2+p)*(1+2*p)*(3+2*p))-_
+   1/2*a*x^6*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b^2*(2+p)*(3+2*p))+_
+   1/6*x^9*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b*(2+p))+_
+   1/2*a^2*(a^2+2*a*b*x^3+b^2*x^6)^(1+p)/(b^4*(1+p)*(2+p)*(3+2*p))
+--R 
+--R
+--R   (2)
+--R          2      2   2 6         3    2 p + 1
+--R       (6a p + 3a )(b x  + 2a b x  + a )
+--R     + 
+--R              4 3      4 2      4      4  12        3 3       3 2       3   9
+--R           (4b p  + 12b p  + 11b p + 3b )x   + (4a b p  + 6a b p  + 2a b p)x
+--R         + 
+--R                2 2 2     2 2      2 2  6        3        3   3     4      4
+--R           (- 6a b p  - 9a b p - 3a b )x  + (- 6a b p - 6a b)x  - 6a p - 6a
+--R      *
+--R           2 6         3    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        4 4       4 3       4 2       4       4
+--R     24b p  + 120b p  + 210b p  + 150b p + 36b
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 1311
+t0:=x^8*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         8  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 1311
+r0:=2/3*a^2*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b^3*(1+2*p)*(3+2*p))+_
+   1/3*x^6*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b*(3+2*p))-_
+   1/3*a*(a^2+2*a*b*x^3+b^2*x^6)^(1+p)/(b^3*(1+p)*(3+2*p))
+--R 
+--R
+--R   (2)
+--R                     2 6         3    2 p + 1
+--R       (- 2a p - a)(b x  + 2a b x  + a )
+--R     + 
+--R              3 2     3     3  9        2 2       2       2  6
+--R           (2b p  + 3b p + b )x  + (2a b p  + 3a b p + a b )x
+--R         + 
+--R              2        2   3     3      3
+--R           (2a b p + 2a b)x  + 2a p + 2a
+--R      *
+--R           2 6         3    2 p
+--R         (b x  + 2a b x  + a )
+--R  /
+--R        3 3      3 2      3      3
+--R     12b p  + 36b p  + 33b p + 9b
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 1311
+t0:=x^5*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         5  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 1311
+r0:=-1/3*a*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b^2*(1+2*p))+_
+   1/6*(a^2+2*a*b*x^3+b^2*x^6)^(1+p)/(b^2*(1+p))
+--R 
+--R
+--R   (2)
+--R                 2 6         3    2 p + 1
+--R       (2p + 1)(b x  + 2a b x  + a )
+--R     + 
+--R                          3     2      2   2 6         3    2 p
+--R       ((- 2a b p - 2a b)x  - 2a p - 2a )(b x  + 2a b x  + a )
+--R  /
+--R        2 2      2      2
+--R     12b p  + 18b p + 6b
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 1311
+t0:=x^4*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         4  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 1311
+--r0:=x^2*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b*(5+6*p))-_
+--   a*x^2*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(2/3,-2*p,_
+--   5/3,-b*x^3/a)/(b*(5+6*p)*((a+b*x^3)/a)^(2*p))
+--E 380
+
+--S 381 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 381
+
+)clear all
+
+--S 382 of 1311
+t0:=x^3*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         3  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 1311
+--r0:=1/2*x*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b*(2+3*p))-_
+--   1/2*a*x*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(1/3,-2*p,4/3,_
+--   -b*x^3/a)/(b*(2+3*p)*((a+b*x^3)/a)^(2*p))
+--E 383
+
+--S 384 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 384
+
+)clear all
+
+--S 385 of 1311
+t0:=x^2*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R         2  2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 1311
+r0:=1/3*(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(b*(1+2*p))
+--R 
+--R
+--R            3       2 6         3    2 p
+--R        (b x  + a)(b x  + 2a b x  + a )
+--R   (2)  --------------------------------
+--R                    6b p + 3b
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 1311
+t0:=x*(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R            2 6         3    2 p
+--R   (1)  x (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 1311
+--r0:=1/2*x^2*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(2/3,-2*p,5/3,_
+--   -b*x^3/a)/((a+b*x^3)/a)^(2*p)
+--E 389
+
+--S 390 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 390
+
+)clear all
+
+--S 391 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^p
+--R 
+--R
+--R          2 6         3    2 p
+--R   (1)  (b x  + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 1311
+--r0:=x*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(1/3,-2*p,4/3,_
+--   -b*x^3/a)/((a+b*x^3)/a)^(2*p)
+--E 392
+
+--S 393 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 393
+
+)clear all
+
+--S 394 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^p/x
+--R 
+--R
+--R          2 6         3    2 p
+--R        (b x  + 2a b x  + a )
+--R   (1)  ----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 1311
+--r0:=1/6*(a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(-2*p,-2*p,1-2*p,_
+--   -a/(b*x^3))/(p*((a+b*x^3)/(b*x^3))^(2*p))
+--E 395
+
+--S 396 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 396
+
+)clear all
+
+--S 397 of 1311
+t0:=(a^2+2*a*b*x^3+b^2*x^6)^p/x^2
+--R 
+--R
+--R          2 6         3    2 p
+--R        (b x  + 2a b x  + a )
+--R   (1)  ----------------------
+--R                   2
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 1311
+--r0:=-(a+b*x^3)*(a^2+2*a*b*x^3+b^2*x^6)^p/(a*x)+b*(1+3*p)*x^2*_
+--   (a^2+2*a*b*x^3+b^2*x^6)^p*hypergeometric(2/3,-2*p,5/3,_
+--   -b*x^3/a)/(a*((a+b*x^3)/a)^(2*p))
+--E 398
+
+--S 399 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 399
+
+)clear all
+
+--S 400 of 1311
+t0:=x^m/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 1311
+--r0:=2*c*x^(1+m)*hypergeometric(1,1/3*(1+m),1/3*(4+m),_
+--   -2*c*x^3/(b-sqrt(b^2-4*a*c)))/((1+m)*(b-sqrt(b^2-4*a*c))*_
+--   sqrt(b^2-4*a*c))-2*c*x^(1+m)*hypergeometric(1,1/3*(1+m),_
+--   1/3*(4+m),-2*c*x^3/(b+sqrt(b^2-4*a*c)))/((1+m)*sqrt(b^2-4*a*c)*_
+--   (b+sqrt(b^2-4*a*c)))
+--E 401
+
+--S 402 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 402
+
+)clear all
+
+--S 403 of 1311
+t0:=x^8/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                8
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 403
+
+--S 404 of 1311
+r0:=1/3*x^3/c-1/6*b*log(a+b*x^3+c*x^6)/c^2-1/3*(b^2-2*a*c)*_
+   atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                3
+--R                 2          2c x  + b
+--R       (4a c - 2b )atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                          +-----------+
+--R                   6      3            3  |          2
+--R       (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     6c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 1311
+t0:=x^7/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                7
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 406
+
+--S 407 of 1311
+r0:=1/2*x^2/c+1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*_
+   (b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*(b-_
+   sqrt(b^2-4*a*c))^(1/3))-1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*_
+   x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(b+(-b^2+2*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*(b-sqrt(b^2-4*a*c))^(1/3))+_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(2/3)*c^(5/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3))+1/3*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(2/3)*c^(5/3)*(b+sqrt(b^2-4*a*c))^(1/3))-1/6*log(2^(2/3)*c^(2/3)*_
+   x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-_
+   4*a*c))^(2/3))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*_
+   (b+sqrt(b^2-4*a*c))^(1/3))+atan((-4*c^(1/3)*x+2^(2/3)*(b+_
+   sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*sqrt(3)*_
+   (b+sqrt(b^2-4*a*c))^(1/3))
+--R 
+--R
+--R   (2)
+--R                                                   +--------------------+
+--R                  +-----------+                    |   +-----------+
+--R              +-+ |          2             2  +-+ 3|   |          2
+--R         (- b\|3 \|- 4a c + b   + (2a c - b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                     +--------------------+
+--R                 +-----------+                       |   +-----------+
+--R             +-+ |          2                2  +-+ 3|   |          2
+--R         (2b\|3 \|- 4a c + b   + (- 4a c + 2b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                     +------------------+
+--R                  +-----------+                      | +-----------+
+--R              +-+ |          2               2  +-+ 3| |          2
+--R         (- b\|3 \|- 4a c + b   + (- 2a c + b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                   +------------------+
+--R                 +-----------+                     | +-----------+
+--R             +-+ |          2              2  +-+ 3| |          2
+--R         (2b\|3 \|- 4a c + b   + (4a c - 2b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                          +--------------------+
+--R             +-----------+                |   +-----------+
+--R             |          2              2 3|   |          2
+--R         (6b\|- 4a c + b   - 12a c + 6b )\|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                          +------------------+
+--R             +-----------+                | +-----------+
+--R             |          2              2 3| |          2
+--R         (6b\|- 4a c + b   + 12a c - 6b )\|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                       +--------------------+ +------------------+
+--R                   +-----------+       |   +-----------+      | +-----------+
+--R       2 3+-+2 +-+ |          2 3+-+2 3|   |          2      3| |          2
+--R     3x  \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                      +--------------------+ +------------------+
+--R                  +-----------+       |   +-----------+      | +-----------+
+--R        3+-+2 +-+ |          2 3+-+2 3|   |          2      3| |          2
+--R     6c \|2  \|3 \|- 4a c + b  \|c   \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 1311
+t0:=x^6/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                6
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 409
+
+--S 410 of 1311
+r0:=x/c-1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(b+_
+   (-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b-sqrt(b^2-_
+   4*a*c))^(2/3))+1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*_
+   (b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(b+(-b^2+2*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b-sqrt(b^2-4*a*c))^(2/3))+_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*c^(4/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(2/3))-1/3*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*c^(4/3)*(b+sqrt(b^2-4*a*c))^(2/3))+1/6*log(2^(2/3)*c^(2/3)*x^2-_
+   2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b+sqrt(b^2-_
+   4*a*c))^(2/3))+atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                                                   +--------------------+2
+--R                +-----------+                      |   +-----------+
+--R            +-+ |          2               2  +-+ 3|   |          2
+--R         (b\|3 \|- 4a c + b   + (- 2a c + b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                     +--------------------+2
+--R                   +-----------+                     |   +-----------+
+--R               +-+ |          2              2  +-+ 3|   |          2
+--R         (- 2b\|3 \|- 4a c + b   + (4a c - 2b )\|3 )\|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                 +------------------+2
+--R                +-----------+                    | +-----------+
+--R            +-+ |          2             2  +-+ 3| |          2
+--R         (b\|3 \|- 4a c + b   + (2a c - b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                       +------------------+2
+--R                   +-----------+                       | +-----------+
+--R               +-+ |          2                2  +-+ 3| |          2
+--R         (- 2b\|3 \|- 4a c + b   + (- 4a c + 2b )\|3 )\|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                          +--------------------+2
+--R             +-----------+                |   +-----------+
+--R             |          2              2 3|   |          2
+--R         (6b\|- 4a c + b   - 12a c + 6b )\|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                          +------------------+2
+--R             +-----------+                | +-----------+
+--R             |          2              2 3| |          2
+--R         (6b\|- 4a c + b   + 12a c - 6b )\|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                  +--------------------+2  +------------------+2
+--R                +-----------+     |   +-----------+        | +-----------+
+--R       3+-+ +-+ |          2 3+-+3|   |          2        3| |          2
+--R     6x\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+2  +------------------+2
+--R                +-----------+     |   +-----------+        | +-----------+
+--R       3+-+ +-+ |          2 3+-+3|   |          2        3| |          2
+--R     6c\|2 \|3 \|- 4a c + b  \|c \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 1311
+t0:=x^5/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                5
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 412
+
+--S 413 of 1311
+r0:=1/6*log(a+b*x^3+c*x^6)/c+1/3*b*atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                        3                               +-----------+
+--R                    2c x  + b             6      3      |          2
+--R        2b atanh(--------------) + log(c x  + b x  + a)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  -------------------------------------------------------------
+--R                                  +-----------+
+--R                                  |          2
+--R                               6c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 1311
+t0:=x^4/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 415
+
+--S 416 of 1311
+r0:=1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(b-sqrt(b^2-_
+   4*a*c))^(2/3)/(2^(2/3)*c^(2/3)*sqrt(b^2-4*a*c))-1/6*log(2^(2/3)*_
+   c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-_
+   sqrt(b^2-4*a*c))^(2/3))*(b-sqrt(b^2-4*a*c))^(2/3)/(2^(2/3)*c^(2/3)*_
+   sqrt(b^2-4*a*c))+atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(b-sqrt(b^2-4*a*c))^(2/3)/_
+   (2^(2/3)*c^(2/3)*sqrt(3)*sqrt(b^2-4*a*c))-1/3*log(2^(1/3)*c^(1/3)*x+_
+   (b+sqrt(b^2-4*a*c))^(1/3))*(b+sqrt(b^2-4*a*c))^(2/3)/(2^(2/3)*c^(2/3)*_
+   sqrt(b^2-4*a*c))+1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*_
+   (b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*(b+_
+   sqrt(b^2-4*a*c))^(2/3)/(2^(2/3)*c^(2/3)*sqrt(b^2-4*a*c))-_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(b+sqrt(b^2-4*a*c))^(2/3)/_
+   (2^(2/3)*c^(2/3)*sqrt(3)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R              +------------------+2
+--R              | +-----------+
+--R          +-+3| |          2
+--R         \|3 \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R               +------------------+2     +------------------+
+--R               | +-----------+           | +-----------+
+--R           +-+3| |          2           3| |          2          3+-+3+-+
+--R       - 2\|3 \|\|- 4a c + b   + b  log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                 +--------------------+2
+--R                 |   +-----------+
+--R             +-+3|   |          2
+--R            \|3 \|- \|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +--------------------+2             +--------------------+
+--R                  |   +-----------+                   |   +-----------+
+--R                 3|   |          2           3+-+3+-+3|   |          2
+--R                 \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R             +--------------------+2     +--------------------+
+--R             |   +-----------+           |   +-----------+
+--R         +-+3|   |          2           3|   |          2          3+-+3+-+
+--R       2\|3 \|- \|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                            +------------------+
+--R           +------------------+2            | +-----------+
+--R           | +-----------+           3+-+2 3| |          2          3+-+
+--R          3| |          2            \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       - 6\|\|- 4a c + b   + b  atan(-----------------------------------)
+--R                                                  +------------------+
+--R                                                  | +-----------+
+--R                                        3+-+2 +-+3| |          2
+--R                                        \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R         +--------------------+2            |   +-----------+
+--R         |   +-----------+           3+-+2 3|   |          2          3+-+
+--R        3|   |          2            \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R       6\|- \|- 4a c + b   + b  atan(-------------------------------------)
+--R                                                  +--------------------+
+--R                                                  |   +-----------+
+--R                                        3+-+2 +-+3|   |          2
+--R                                        \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                +-----------+
+--R      3+-+2 +-+ |          2 3+-+2
+--R     6\|2  \|3 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 1311
+t0:=x^3/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 418
+
+--S 419 of 1311
+r0:=-1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(b-_
+   sqrt(b^2-4*a*c))^(1/3)/(2^(1/3)*c^(1/3)*sqrt(b^2-4*a*c))+_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-_
+   4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(b-sqrt(b^2-4*a*c))^(1/3)/_
+   (2^(1/3)*c^(1/3)*sqrt(b^2-4*a*c))+atan((-4*c^(1/3)*x+2^(2/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*_
+   (b-sqrt(b^2-4*a*c))^(1/3)/(2^(1/3)*c^(1/3)*sqrt(3)*sqrt(b^2-4*a*c))+_
+   1/3*log(2^(1/3)*c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(b+_
+   sqrt(b^2-4*a*c))^(1/3)/(2^(1/3)*c^(1/3)*sqrt(b^2-4*a*c))-_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+_
+   (b+sqrt(b^2-4*a*c))^(2/3))*(b+sqrt(b^2-4*a*c))^(1/3)/(2^(1/3)*c^(1/3)*_
+   sqrt(b^2-4*a*c))-atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(b+sqrt(b^2-4*a*c))^(1/3)/_
+   (2^(1/3)*c^(1/3)*sqrt(3)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R       -
+--R                 +------------------+
+--R                 | +-----------+
+--R             +-+3| |          2
+--R            \|3 \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +------------------+2             +------------------+
+--R                  | +-----------+                   | +-----------+
+--R                 3| |          2           3+-+3+-+3| |          2
+--R                 \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R             +------------------+     +------------------+
+--R             | +-----------+          | +-----------+
+--R         +-+3| |          2          3| |          2          3+-+3+-+
+--R       2\|3 \|\|- 4a c + b   + b log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R              +--------------------+
+--R              |   +-----------+
+--R          +-+3|   |          2
+--R         \|3 \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R               +--------------------+     +--------------------+
+--R               |   +-----------+          |   +-----------+
+--R           +-+3|   |          2          3|   |          2          3+-+3+-+
+--R       - 2\|3 \|- \|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                           +------------------+
+--R           +------------------+            | +-----------+
+--R           | +-----------+          3+-+2 3| |          2          3+-+
+--R          3| |          2           \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       - 6\|\|- 4a c + b   + b atan(-----------------------------------)
+--R                                                 +------------------+
+--R                                                 | +-----------+
+--R                                       3+-+2 +-+3| |          2
+--R                                       \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                           +--------------------+
+--R         +--------------------+            |   +-----------+
+--R         |   +-----------+          3+-+2 3|   |          2          3+-+
+--R        3|   |          2           \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R       6\|- \|- 4a c + b   + b atan(-------------------------------------)
+--R                                                 +--------------------+
+--R                                                 |   +-----------+
+--R                                       3+-+2 +-+3|   |          2
+--R                                       \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R               +-----------+
+--R      3+-+ +-+ |          2 3+-+
+--R     6\|2 \|3 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 1311
+t0:=x^2/(a+b*x^3+c*x^6)
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 421
+
+--S 422 of 1311
+r0:=-2/3*atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                        3
+--R                    2c x  + b
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  - ----------------------
+--R                +-----------+
+--R                |          2
+--R              3\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 1311
+t0:=x/(a+b*x^3+c*x^6)
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 424
+
+--S 425 of 1311
+r0:=-1/3*2^(1/3)*c^(1/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-_
+   4*a*c))^(1/3))/((b-sqrt(b^2-4*a*c))^(1/3)*sqrt(b^2-4*a*c))+_
+   1/3*c^(1/3)*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-_
+   sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))/(2^(2/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3)*sqrt(b^2-4*a*c))-2^(1/3)*c^(1/3)*_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))/(sqrt(3)*(b-sqrt(b^2-_
+   4*a*c))^(1/3)*sqrt(b^2-4*a*c))+1/3*2^(1/3)*c^(1/3)*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))/(sqrt(b^2-4*a*c)*(b+_
+   sqrt(b^2-4*a*c))^(1/3))-1/3*c^(1/3)*log(2^(2/3)*c^(2/3)*x^2-_
+   2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-_
+   4*a*c))^(2/3))/(2^(2/3)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(1/3))+_
+   2^(1/3)*c^(1/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))/_
+   (sqrt(3)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(1/3))
+--R 
+--R
+--R   (2)
+--R       -
+--R                     +--------------------+
+--R                     |   +-----------+
+--R             +-+3+-+3|   |          2
+--R            \|3 \|c \|- \|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +------------------+2             +------------------+
+--R                  | +-----------+                   | +-----------+
+--R                 3| |          2           3+-+3+-+3| |          2
+--R                 \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R                 +--------------------+     +------------------+
+--R                 |   +-----------+          | +-----------+
+--R         +-+3+-+3|   |          2          3| |          2          3+-+3+-+
+--R       2\|3 \|c \|- \|- 4a c + b   + b log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                  +------------------+
+--R                  | +-----------+
+--R          +-+3+-+3| |          2
+--R         \|3 \|c \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                   +------------------+     +--------------------+
+--R                   | +-----------+          |   +-----------+
+--R           +-+3+-+3| |          2          3|   |          2          3+-+3+-+
+--R       - 2\|3 \|c \|\|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                               +------------------+
+--R             +--------------------+            | +-----------+
+--R             |   +-----------+          3+-+2 3| |          2          3+-+
+--R        3+-+3|   |          2           \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       6\|c \|- \|- 4a c + b   + b atan(-----------------------------------)
+--R                                                     +------------------+
+--R                                                     | +-----------+
+--R                                           3+-+2 +-+3| |          2
+--R                                           \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                               +--------------------+
+--R               +------------------+            |   +-----------+
+--R               | +-----------+          3+-+2 3|   |          2          3+-+
+--R          3+-+3| |          2           \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R       - 6\|c \|\|- 4a c + b   + b atan(-------------------------------------)
+--R                                                     +--------------------+
+--R                                                     |   +-----------+
+--R                                           3+-+2 +-+3|   |          2
+--R                                           \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R      3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R     3\|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 1311
+t0:=1/(a+b*x^3+c*x^6)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           6      3
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 427
+
+--S 428 of 1311
+r0:=1/3*2^(2/3)*c^(2/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))/_
+   ((b-sqrt(b^2-4*a*c))^(2/3)*sqrt(b^2-4*a*c))-1/3*c^(2/3)*log(2^(2/3)*_
+   c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-_
+   sqrt(b^2-4*a*c))^(2/3))/(2^(1/3)*(b-sqrt(b^2-4*a*c))^(2/3)*_
+   sqrt(b^2-4*a*c))-2^(2/3)*c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b-_
+   sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))/_
+   (sqrt(3)*(b-sqrt(b^2-4*a*c))^(2/3)*sqrt(b^2-4*a*c))-_
+   1/3*2^(2/3)*c^(2/3)*log(2^(1/3)*c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(2/3))+1/3*c^(2/3)*_
+   log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+_
+   (b+sqrt(b^2-4*a*c))^(2/3))/(2^(1/3)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-_
+   4*a*c))^(2/3))+2^(2/3)*c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b+_
+   sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))/_
+   (sqrt(3)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                    +--------------------+2
+--R                    |   +-----------+
+--R          +-+3+-+2 3|   |          2
+--R         \|3 \|c   \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R       -
+--R                        +--------------------+2
+--R                        |   +-----------+
+--R              +-+3+-+2 3|   |          2
+--R            2\|3 \|c   \|- \|- 4a c + b   + b
+--R         *
+--R                 +------------------+
+--R                 | +-----------+
+--R                3| |          2          3+-+3+-+
+--R            log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R       -
+--R                       +------------------+2
+--R                       | +-----------+
+--R             +-+3+-+2 3| |          2
+--R            \|3 \|c   \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +--------------------+2             +--------------------+
+--R                  |   +-----------+                   |   +-----------+
+--R                 3|   |          2           3+-+3+-+3|   |          2
+--R                 \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R               + 
+--R                  2 3+-+2 3+-+2
+--R                 x  \|2   \|c
+--R     + 
+--R                   +------------------+2     +--------------------+
+--R                   | +-----------+           |   +-----------+
+--R         +-+3+-+2 3| |          2           3|   |          2          3+-+3+-+
+--R       2\|3 \|c   \|\|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                  +------------------+
+--R               +--------------------+2            | +-----------+
+--R               |   +-----------+           3+-+2 3| |          2          3+-+
+--R        3+-+2 3|   |          2            \|2   \|\|- 4a c + b   + b - 4x\|c
+--R       6\|c   \|- \|- 4a c + b   + b  atan(-----------------------------------)
+--R                                                        +------------------+
+--R                                                        | +-----------+
+--R                                              3+-+2 +-+3| |          2
+--R                                              \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                                +--------------------+
+--R               +------------------+2            |   +-----------+
+--R               | +-----------+           3+-+2 3|   |          2          3+-+
+--R        3+-+2 3| |          2            \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R     - 6\|c   \|\|- 4a c + b   + b  atan(-------------------------------------)
+--R                                                      +--------------------+
+--R                                                      |   +-----------+
+--R                                            3+-+2 +-+3|   |          2
+--R                                            \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                             +--------------------+2  +------------------+2
+--R               +-----------+ |   +-----------+        | +-----------+
+--R      3+-+ +-+ |          2 3|   |          2        3| |          2
+--R     3\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 1311
+t0:=1/(x*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           7      4
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 430
+
+--S 431 of 1311
+r0:=log(x)/a-1/6*log(a+b*x^3+c*x^6)/a+1/3*b*atanh((b+2*c*x^3)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                   3                                             +-----------+
+--R               2c x  + b                6      3                 |          2
+--R   2b atanh(--------------) + (- log(c x  + b x  + a) + 6log(x))\|- 4a c + b
+--R             +-----------+
+--R             |          2
+--R            \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                    +-----------+
+--R                                    |          2
+--R                                 6a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 1311
+t0:=1/(x^2*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           8      5      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 433
+
+--S 434 of 1311
+r0:=(-1)/(a*x)+1/3*c^(1/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*_
+   (1+b/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b-sqrt(b^2-4*a*c))^(1/3))-_
+   1/6*c^(1/3)*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-_
+   sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(1+_
+   b/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b-sqrt(b^2-4*a*c))^(1/3))+c^(1/3)*_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(1+b/sqrt(b^2-4*a*c))/(2^(2/3)*_
+   a*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3))+1/3*c^(1/3)*log(2^(1/3)*c^(1/3)*x+_
+   (b+sqrt(b^2-4*a*c))^(1/3))*(1-b/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b+_
+   sqrt(b^2-4*a*c))^(1/3))-1/6*c^(1/3)*log(2^(2/3)*c^(2/3)*x^2-_
+   2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-_
+   4*a*c))^(2/3))*(1-b/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b+sqrt(b^2-_
+   4*a*c))^(1/3))+c^(1/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*_
+   (1-b/sqrt(b^2-4*a*c))/(2^(2/3)*a*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3))
+--R 
+--R
+--R   (2)
+--R                                               +--------------------+
+--R                  +-----------+                |   +-----------+
+--R              +-+ |          2        +-+ 3+-+3|   |          2
+--R         (- x\|3 \|- 4a c + b   + b x\|3 )\|c \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                               +--------------------+
+--R                 +-----------+                 |   +-----------+
+--R             +-+ |          2         +-+ 3+-+3|   |          2
+--R         (2x\|3 \|- 4a c + b   - 2b x\|3 )\|c \|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                               +------------------+
+--R                  +-----------+                | +-----------+
+--R              +-+ |          2        +-+ 3+-+3| |          2
+--R         (- x\|3 \|- 4a c + b   - b x\|3 )\|c \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                               +------------------+
+--R                 +-----------+                 | +-----------+
+--R             +-+ |          2         +-+ 3+-+3| |          2
+--R         (2x\|3 \|- 4a c + b   + 2b x\|3 )\|c \|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                       +--------------------+
+--R             +-----------+             |   +-----------+
+--R             |          2         3+-+3|   |          2
+--R         (6x\|- 4a c + b   - 6b x)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                       +------------------+
+--R             +-----------+             | +-----------+
+--R             |          2         3+-+3| |          2
+--R         (6x\|- 4a c + b   + 6b x)\|c \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R          3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R       - 6\|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+ +------------------+
+--R                    +-----------+ |   +-----------+      | +-----------+
+--R          3+-+2 +-+ |          2 3|   |          2      3| |          2
+--R     6a x \|2  \|3 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 1311
+t0:=1/(x^3*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           9      6      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 436
+
+--S 437 of 1311
+r0:=(-1/2)/(a*x^2)-1/3*c^(2/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-_
+   4*a*c))^(1/3))*(1+b/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b-sqrt(b^2-_
+   4*a*c))^(2/3))+1/6*c^(2/3)*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*_
+   c^(1/3)*x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*_
+   (1+b/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b-sqrt(b^2-4*a*c))^(2/3))+_
+   c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(1+b/sqrt(b^2-_
+   4*a*c))/(2^(1/3)*a*sqrt(3)*(b-sqrt(b^2-4*a*c))^(2/3))-_
+   1/3*c^(2/3)*log(2^(1/3)*c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*_
+   (1-b/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b+sqrt(b^2-4*a*c))^(2/3))+_
+   1/6*c^(2/3)*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*_
+   (b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*_
+   (1-b/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b+sqrt(b^2-4*a*c))^(2/3))+_
+   c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(1-b/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*a*sqrt(3)*(b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                                                 +--------------------+2
+--R                 +-----------+                   |   +-----------+
+--R           2 +-+ |          2       2 +-+ 3+-+2 3|   |          2
+--R         (x \|3 \|- 4a c + b   - b x \|3 )\|c   \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2             +------------------+
+--R               | +-----------+                   | +-----------+
+--R              3| |          2           3+-+3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - x\|2 \|c \|\|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                     +--------------------+2
+--R                    +-----------+                    |   +-----------+
+--R              2 +-+ |          2        2 +-+ 3+-+2 3|   |          2
+--R         (- 2x \|3 \|- 4a c + b   + 2b x \|3 )\|c   \|- \|- 4a c + b   + b
+--R      *
+--R              +------------------+
+--R              | +-----------+
+--R             3| |          2          3+-+3+-+
+--R         log(\|\|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                                 +------------------+2
+--R                 +-----------+                   | +-----------+
+--R           2 +-+ |          2       2 +-+ 3+-+2 3| |          2
+--R         (x \|3 \|- 4a c + b   + b x \|3 )\|c   \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2             +--------------------+
+--R               |   +-----------+                   |   +-----------+
+--R              3|   |          2           3+-+3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - x\|2 \|c \|- \|- 4a c + b   + b
+--R            + 
+--R               2 3+-+2 3+-+2
+--R              x  \|2   \|c
+--R     + 
+--R                                                     +------------------+2
+--R                    +-----------+                    | +-----------+
+--R              2 +-+ |          2        2 +-+ 3+-+2 3| |          2
+--R         (- 2x \|3 \|- 4a c + b   - 2b x \|3 )\|c   \|\|- 4a c + b   + b
+--R      *
+--R              +--------------------+
+--R              |   +-----------+
+--R             3|   |          2          3+-+3+-+
+--R         log(\|- \|- 4a c + b   + b  + x\|2 \|c )
+--R     + 
+--R                                           +--------------------+2
+--R              +-----------+                |   +-----------+
+--R            2 |          2        2 3+-+2 3|   |          2
+--R         (6x \|- 4a c + b   - 6b x )\|c   \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+
+--R                     | +-----------+
+--R              3+-+2 3| |          2          3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x\|c
+--R         atan(-----------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                                           +------------------+2
+--R              +-----------+                | +-----------+
+--R            2 |          2        2 3+-+2 3| |          2
+--R         (6x \|- 4a c + b   + 6b x )\|c   \|\|- 4a c + b   + b
+--R      *
+--R                     +--------------------+
+--R                     |   +-----------+
+--R              3+-+2 3|   |          2          3+-+
+--R              \|2   \|- \|- 4a c + b   + b - 4x\|c
+--R         atan(-------------------------------------)
+--R                           +--------------------+
+--R                           |   +-----------+
+--R                 3+-+2 +-+3|   |          2
+--R                 \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                 +--------------------+2  +------------------+2
+--R                   +-----------+ |   +-----------+        | +-----------+
+--R          3+-+ +-+ |          2 3|   |          2        3| |          2
+--R       - 3\|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R  /
+--R                                  +--------------------+2  +------------------+2
+--R                    +-----------+ |   +-----------+        | +-----------+
+--R         2 3+-+ +-+ |          2 3|   |          2        3| |          2
+--R     6a x  \|2 \|3 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 1311
+t0:=1/(x^4*(a+b*x^3+c*x^6))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R           10      7      4
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 439
+
+--S 440 of 1311
+r0:=(-1/3)/(a*x^3)-b*log(x)/a^2+1/6*b*log(a+b*x^3+c*x^6)/a^2-_
+   1/3*(b^2-2*a*c)*atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                  3
+--R                 2  3         2c x  + b
+--R       (4a c - 2b )x atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R           3       6      3            3             |          2
+--R       (b x log(c x  + b x  + a) - 6b x log(x) - 2a)\|- 4a c + b
+--R  /
+--R           +-----------+
+--R       2 3 |          2
+--R     6a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 1311
+t0:=x^m/(3+4*x^3+x^6)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 1311
+--r0:=1/2*x^(1+m)*hypergeometric(1,1/3*(1+m),1/3*(4+m),-x^3)/(1+m)-_
+--   1/6*x^(1+m)*hypergeometric(1,1/3*(1+m),1/3*(4+m),-1/3*x^3)/(1+m)
+--E 443
+
+--S 444 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 444
+
+)clear all
+
+--S 445 of 1311
+t0:=x^11/(3+4*x^3+x^6)
+--R 
+--R
+--R              11
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 445
+
+--S 446 of 1311
+r0:=-4/3*x^3+1/6*x^6-1/6*log(1+x^3)+9/2*log(3+x^3)
+--R 
+--R
+--R               3             3         6     3
+--R        27log(x  + 3) - log(x  + 1) + x  - 8x
+--R   (2)  --------------------------------------
+--R                           6
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 1311
+t0:=x^10/(3+4*x^3+x^6)
+--R 
+--R
+--R              10
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 448
+
+--S 449 of 1311
+r0:=-2*x^2+1/5*x^5-9/2*3^(1/6)*atan((3^(1/3)-2*x)/3^(5/6))+1/6*log(1+x)-_
+   3/2*3^(2/3)*log(3^(1/3)+x)-1/12*log(1-x+x^2)+3/4*3^(2/3)*_
+   log(3^(2/3)-3^(1/3)*x+x^2)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          +-+3+-+2    3+-+2    3+-+    2       +-+3+-+2    3+-+
+--R       45\|3 \|3  log(\|3   - x\|3  + x ) - 90\|3 \|3  log(\|3  + x)
+--R     + 
+--R           +-+     2               +-+
+--R       - 5\|3 log(x  - x + 1) + 10\|3 log(x + 1)
+--R     + 
+--R                          3+-+      6+-+                    +-+
+--R             +-+6+-+     (\|3  - 2x)\|3            (2x - 1)\|3
+--R       - 270\|3 \|3 atan(---------------) - 30atan(------------)
+--R                                3                        3
+--R     + 
+--R           5       2  +-+
+--R       (12x  - 120x )\|3
+--R  /
+--R        +-+
+--R     60\|3
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 1311
+t0:=x^9/(3+4*x^3+x^6)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 451
+
+--S 452 of 1311
+r0:=-4*x+1/4*x^4-3/2*3^(5/6)*atan((3^(1/3)-2*x)/3^(5/6))-1/6*log(1+x)+_
+   3/2*3^(1/3)*log(3^(1/3)+x)+1/12*log(1-x+x^2)-3/4*3^(1/3)*log(3^(2/3)-_
+   3^(1/3)*x+x^2)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           +-+3+-+    3+-+2    3+-+    2       +-+3+-+    3+-+
+--R       - 9\|3 \|3 log(\|3   - x\|3  + x ) + 18\|3 \|3 log(\|3  + x)
+--R     + 
+--R                                                                3+-+      6+-+
+--R        +-+     2              +-+                +-+6+-+5     (\|3  - 2x)\|3
+--R       \|3 log(x  - x + 1) - 2\|3 log(x + 1) - 18\|3 \|3  atan(---------------)
+--R                                                                      3
+--R     + 
+--R                        +-+
+--R               (2x - 1)\|3        4        +-+
+--R       - 6atan(------------) + (3x  - 48x)\|3
+--R                     3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 1311
+t0:=x^8/(3+4*x^3+x^6)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 454
+
+--S 455 of 1311
+r0:=1/3*x^3+1/6*log(1+x^3)-3/2*log(3+x^3)
+--R 
+--R
+--R                3             3          3
+--R        - 9log(x  + 3) + log(x  + 1) + 2x
+--R   (2)  ----------------------------------
+--R                         6
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 1311
+t0:=x^7/(3+4*x^3+x^6)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 457
+
+--S 458 of 1311
+r0:=1/2*x^2+3/2*3^(1/6)*atan((3^(1/3)-2*x)/3^(5/6))-1/6*log(1+x)+_
+   1/2*3^(2/3)*log(3^(1/3)+x)+1/12*log(1-x+x^2)-1/4*3^(2/3)*log(3^(2/3)-_
+   3^(1/3)*x+x^2)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           +-+3+-+2    3+-+2    3+-+    2      +-+3+-+2    3+-+
+--R       - 3\|3 \|3  log(\|3   - x\|3  + x ) + 6\|3 \|3  log(\|3  + x)
+--R     + 
+--R                                                               3+-+      6+-+
+--R        +-+     2              +-+                +-+6+-+     (\|3  - 2x)\|3
+--R       \|3 log(x  - x + 1) - 2\|3 log(x + 1) + 18\|3 \|3 atan(---------------)
+--R                                                                     3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3       2 +-+
+--R       6atan(------------) + 6x \|3
+--R                   3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 1311
+t0:=x^6/(3+4*x^3+x^6)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 460
+
+--S 461 of 1311
+r0:=x+1/2*3^(5/6)*atan((3^(1/3)-2*x)/3^(5/6))+1/6*log(1+x)-_
+   1/2*3^(1/3)*log(3^(1/3)+x)-1/12*log(1-x+x^2)+1/4*3^(1/3)*log(3^(2/3)-_
+   3^(1/3)*x+x^2)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         +-+3+-+    3+-+2    3+-+    2      +-+3+-+    3+-+
+--R       3\|3 \|3 log(\|3   - x\|3  + x ) - 6\|3 \|3 log(\|3  + x)
+--R     + 
+--R                                                                 3+-+      6+-+
+--R          +-+     2              +-+               +-+6+-+5     (\|3  - 2x)\|3
+--R       - \|3 log(x  - x + 1) + 2\|3 log(x + 1) + 6\|3 \|3  atan(---------------)
+--R                                                                       3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3         +-+
+--R       6atan(------------) + 12x\|3
+--R                   3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 1311
+t0:=x^5/(3+4*x^3+x^6)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 463
+
+--S 464 of 1311
+r0:=-1/6*log(1+x^3)+1/2*log(3+x^3)
+--R 
+--R
+--R              3             3
+--R        3log(x  + 3) - log(x  + 1)
+--R   (2)  --------------------------
+--R                     6
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 1311
+t0:=x^4/(3+4*x^3+x^6)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 466
+
+--S 467 of 1311
+r0:=-1/2*3^(1/6)*atan((3^(1/3)-2*x)/3^(5/6))+1/6*log(1+x)-_
+   1/2*log(3^(1/3)+x)/3^(1/3)-1/12*log(1-x+x^2)+1/4*log(3^(2/3)-3^(1/3)*x+_
+   x^2)/3^(1/3)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         +-+    3+-+2    3+-+    2      +-+    3+-+
+--R       3\|3 log(\|3   - x\|3  + x ) - 6\|3 log(\|3  + x)
+--R     + 
+--R          +-+3+-+     2              +-+3+-+
+--R       - \|3 \|3 log(x  - x + 1) + 2\|3 \|3 log(x + 1)
+--R     + 
+--R                            3+-+      6+-+                       +-+
+--R           +-+3+-+6+-+     (\|3  - 2x)\|3      3+-+     (2x - 1)\|3
+--R       - 6\|3 \|3 \|3 atan(---------------) - 6\|3 atan(------------)
+--R                                  3                           3
+--R  /
+--R        +-+3+-+
+--R     12\|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 1311
+t0:=x^3/(3+4*x^3+x^6)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 469
+
+--S 470 of 1311
+r0:=-1/2*atan((3^(1/3)-2*x)/3^(5/6))/3^(1/6)-1/6*log(1+x)+_
+   1/2*log(3^(1/3)+x)/3^(2/3)+1/12*log(1-x+x^2)-1/4*log(3^(2/3)-3^(1/3)*x+_
+   x^2)/3^(2/3)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           +-+6+-+    3+-+2    3+-+    2      +-+6+-+    3+-+
+--R       - 3\|3 \|3 log(\|3   - x\|3  + x ) + 6\|3 \|3 log(\|3  + x)
+--R     + 
+--R        +-+3+-+2 6+-+     2             +-+3+-+2 6+-+
+--R       \|3 \|3   \|3 log(x  - x + 1 - 2\|3 \|3   \|3 log(x + 1)
+--R     + 
+--R                         3+-+      6+-+                             +-+
+--R           +-+3+-+2     (\|3  - 2x)\|3      3+-+2 6+-+     (2x - 1)\|3
+--R       - 6\|3 \|3  atan(---------------) - 6\|3   \|3 atan(------------)
+--R                               3                                 3
+--R  /
+--R        +-+3+-+2 6+-+
+--R     12\|3 \|3   \|3
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 1311
+t0:=x^2/(3+4*x^3+x^6)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 472
+
+--S 473 of 1311
+r0:=-1/3*atanh(2+x^3),1/6*log(1+x^3)-1/6*log(3+x^3)
+--R 
+--R
+--R                  3             3             3
+--R           atanh(x  + 2) - log(x  + 3) + log(x  + 1)
+--R   (2)  [- -------------,---------------------------]
+--R                 3                    6
+--R                                             Type: Tuple(Expression(Integer))
+--E 473
+
+--S 474 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 1311
+t0:=x/(3+4*x^3+x^6)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 475
+
+--S 476 of 1311
+r0:=1/2*atan((3^(1/3)-2*x)/3^(5/6))/3^(5/6)-1/6*log(1+x)+_
+   1/6*log(3^(1/3)+x)/3^(1/3)+1/12*log(1-x+x^2)-1/12*log(3^(2/3)-3^(1/3)*x+_
+   x^2)/3^(1/3)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          +-+6+-+5    3+-+2    3+-+    2      +-+6+-+5    3+-+
+--R       - \|3 \|3  log(\|3   - x\|3  + x ) + 2\|3 \|3  log(\|3  + x)
+--R     + 
+--R        +-+3+-+6+-+5     2              +-+3+-+6+-+5
+--R       \|3 \|3 \|3  log(x  - x + 1) - 2\|3 \|3 \|3  log(x + 1)
+--R     + 
+--R                      3+-+      6+-+                            +-+
+--R         +-+3+-+     (\|3  - 2x)\|3      3+-+6+-+5     (2x - 1)\|3
+--R       6\|3 \|3 atan(---------------) + 6\|3 \|3  atan(------------)
+--R                            3                                3
+--R  /
+--R        +-+3+-+6+-+5
+--R     12\|3 \|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 1311
+t0:=1/(3+4*x^3+x^6)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         6     3
+--R        x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 478
+
+--S 479 of 1311
+r0:=1/6*atan((3^(1/3)-2*x)/3^(5/6))/3^(1/6)+1/6*log(1+x)-_
+   1/6*log(3^(1/3)+x)/3^(2/3)-1/12*log(1-x+x^2)+1/12*log(3^(2/3)-_
+   3^(1/3)*x+x^2)/3^(2/3)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R        +-+6+-+    3+-+2    3+-+    2      +-+6+-+    3+-+
+--R       \|3 \|3 log(\|3   - x\|3  + x ) - 2\|3 \|3 log(\|3  + x)
+--R     + 
+--R          +-+3+-+2 6+-+     2             +-+3+-+2 6+-+
+--R       - \|3 \|3   \|3 log(x  - x + 1 + 2\|3 \|3   \|3 log(x + 1)
+--R     + 
+--R                       3+-+      6+-+                             +-+
+--R         +-+3+-+2     (\|3  - 2x)\|3      3+-+2 6+-+     (2x - 1)\|3
+--R       2\|3 \|3  atan(---------------) + 6\|3   \|3 atan(------------)
+--R                             3                                 3
+--R  /
+--R        +-+3+-+2 6+-+
+--R     12\|3 \|3   \|3
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 1311
+t0:=1/(x*(3+4*x^3+x^6))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         7     4
+--R        x  + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 481
+
+--S 482 of 1311
+r0:=1/3*log(x)-1/6*log(1+x^3)+1/18*log(3+x^3)
+--R 
+--R
+--R             3              3
+--R        log(x  + 3) - 3log(x  + 1) + 6log(x)
+--R   (2)  ------------------------------------
+--R                         18
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+)clear all
+
+--S 484 of 1311
+t0:=1/(x^2*(3+4*x^3+x^6))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         8     5     2
+--R        x  + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 484
+
+--S 485 of 1311
+r0:=(-1/3)/x-1/6*atan((3^(1/3)-2*x)/3^(5/6))/3^(5/6)+1/6*log(1+x)-_
+   1/18*log(3^(1/3)+x)/3^(1/3)-1/12*log(1-x+x^2)+1/36*log(3^(2/3)-_
+   3^(1/3)*x+x^2)/3^(1/3)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         +-+6+-+5    3+-+2    3+-+    2       +-+6+-+5    3+-+
+--R       x\|3 \|3  log(\|3   - x\|3  + x ) - 2x\|3 \|3  log(\|3  + x)
+--R     + 
+--R            +-+3+-+6+-+5     2               +-+3+-+6+-+5
+--R       - 3x\|3 \|3 \|3  log(x  - x + 1) + 6x\|3 \|3 \|3  log(x + 1)
+--R     + 
+--R                         3+-+      6+-+                              +-+
+--R            +-+3+-+     (\|3  - 2x)\|3        3+-+6+-+5     (2x - 1)\|3
+--R       - 6x\|3 \|3 atan(---------------) - 18x\|3 \|3  atan(------------)
+--R                               3                                  3
+--R     + 
+--R            +-+3+-+6+-+5
+--R       - 12\|3 \|3 \|3
+--R  /
+--R         +-+3+-+6+-+5
+--R     36x\|3 \|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 1311
+t0:=1/(x^3*(3+4*x^3+x^6))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         9     6     3
+--R        x  + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 487
+
+--S 488 of 1311
+r0:=(-1/6)/x^2-1/18*atan((3^(1/3)-2*x)/3^(5/6))/3^(1/6)-1/6*log(1+x)+_
+   1/18*log(3^(1/3)+x)/3^(2/3)+1/12*log(1-x+x^2)-_
+   1/36*log(3^(2/3)-3^(1/3)*x+x^2)/3^(2/3)+1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          2 +-+6+-+    3+-+2    3+-+    2      2 +-+6+-+    3+-+
+--R       - x \|3 \|3 log(\|3   - x\|3  + x ) + 2x \|3 \|3 log(\|3  + x)
+--R     + 
+--R         2 +-+3+-+2 6+-+     2             2 +-+3+-+2 6+-+
+--R       3x \|3 \|3   \|3 log(x  - x + 1 - 6x \|3 \|3   \|3 log(x + 1)
+--R     + 
+--R                           3+-+      6+-+                                 +-+
+--R           2 +-+3+-+2     (\|3  - 2x)\|3        2 3+-+2 6+-+     (2x - 1)\|3
+--R       - 2x \|3 \|3  atan(---------------) - 18x  \|3   \|3 atan(------------)
+--R                                 3                                     3
+--R     + 
+--R           +-+3+-+2 6+-+
+--R       - 6\|3 \|3   \|3
+--R  /
+--R        2 +-+3+-+2 6+-+
+--R     36x \|3 \|3   \|3
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 1311
+t0:=1/(x^4*(3+4*x^3+x^6))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         10     7     4
+--R        x   + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 490
+
+--S 491 of 1311
+r0:=(-1/9)/x^3-4/9*log(x)+1/6*log(1+x^3)-1/54*log(3+x^3)
+--R 
+--R
+--R           3     3          3     3           3
+--R        - x log(x  + 3) + 9x log(x  + 1) - 24x log(x) - 6
+--R   (2)  -------------------------------------------------
+--R                                  3
+--R                               54x
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 1311
+t0:=1/(x^5*(3+4*x^3+x^6))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         11     8     5
+--R        x   + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 493
+
+--S 494 of 1311
+r0:=(-1/12)/x^4+4/9/x+1/18*atan((3^(1/3)-2*x)/3^(5/6))/3^(5/6)-_
+   1/6*log(1+x)+1/54*log(3^(1/3)+x)/3^(1/3)+1/12*log(1-x+x^2)-_
+   1/108*log(3^(2/3)-3^(1/3)*x+x^2)/3^(1/3)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          4 +-+6+-+5    3+-+2    3+-+    2      4 +-+6+-+5    3+-+
+--R       - x \|3 \|3  log(\|3   - x\|3  + x ) + 2x \|3 \|3  log(\|3  + x)
+--R     + 
+--R         4 +-+3+-+6+-+5     2               4 +-+3+-+6+-+5
+--R       9x \|3 \|3 \|3  log(x  - x + 1) - 18x \|3 \|3 \|3  log(x + 1)
+--R     + 
+--R                        3+-+      6+-+                                +-+
+--R         4 +-+3+-+     (\|3  - 2x)\|3        4 3+-+6+-+5     (2x - 1)\|3
+--R       6x \|3 \|3 atan(---------------) + 54x  \|3 \|3  atan(------------)
+--R                              3                                    3
+--R     + 
+--R           3      +-+3+-+6+-+5
+--R       (48x  - 9)\|3 \|3 \|3
+--R  /
+--R         4 +-+3+-+6+-+5
+--R     108x \|3 \|3 \|3
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 1311
+t0:=1/(x^6*(3+4*x^3+x^6))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         12     9     6
+--R        x   + 4x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 496
+
+--S 497 of 1311
+r0:=(-1/15)/x^5+2/9/x^2+1/54*atan((3^(1/3)-2*x)/3^(5/6))/3^(1/6)+_
+   1/6*log(1+x)-1/54*log(3^(1/3)+x)/3^(2/3)-1/12*log(1-x+x^2)+_
+   1/108*log(3^(2/3)-3^(1/3)*x+x^2)/3^(2/3)-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         5 +-+6+-+    3+-+2    3+-+    2       5 +-+6+-+    3+-+
+--R       5x \|3 \|3 log(\|3   - x\|3  + x ) - 10x \|3 \|3 log(\|3  + x)
+--R     + 
+--R            5 +-+3+-+2 6+-+     2              5 +-+3+-+2 6+-+
+--R       - 45x \|3 \|3   \|3 log(x  - x + 1 + 90x \|3 \|3   \|3 log(x + 1)
+--R     + 
+--R                          3+-+      6+-+                                  +-+
+--R          5 +-+3+-+2     (\|3  - 2x)\|3         5 3+-+2 6+-+     (2x - 1)\|3
+--R       10x \|3 \|3  atan(---------------) + 270x  \|3   \|3 atan(------------)
+--R                                3                                      3
+--R     + 
+--R            3       +-+3+-+2 6+-+
+--R       (120x  - 36)\|3 \|3   \|3
+--R  /
+--R         5 +-+3+-+2 6+-+
+--R     540x \|3 \|3   \|3
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 1311
+t0:=1/(x^7*(3+4*x^3+x^6))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R         13     10     7
+--R        x   + 4x   + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 499
+
+--S 500 of 1311
+r0:=(-1/18)/x^6+4/27/x^3+13/27*log(x)-1/6*log(1+x^3)+1/162*log(3+x^3)
+--R 
+--R
+--R         6     3           6     3           6            3
+--R        x log(x  + 3) - 27x log(x  + 1) + 78x log(x) + 24x  - 9
+--R   (2)  -------------------------------------------------------
+--R                                     6
+--R                                 162x
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 1311
+t0:=x^m/(1-x^3+x^6)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 1311
+--r0:=-2*x^(1+m)*hypergeometric(1,1/3*(1+m),1/3*(4+m),_
+--   2*x^3/(1+%i*sqrt(3)))/((1+m)*(%i-sqrt(3))*sqrt(3))+2*x^(1+m)*_
+--   hypergeometric(1,1/3*(1+m),1/3*(4+m),2*x^3/(1-%i*sqrt(3)))/_
+--   ((1+m)*sqrt(3)*(%i+sqrt(3)))
+--E 503
+
+--S 504 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 504
+
+)clear all
+
+--S 505 of 1311
+t0:=x^6/(1-x^3+x^6)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 505
+
+--S 506 of 1311
+r0:=x+1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))+_
+   1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1-%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*_
+   sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1-%i*sqrt(3))^(2/3))+1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*_
+   (3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))-1/3*atan((4*x+_
+   2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*_
+   sqrt(3)))*(%i+sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))
+--R 
+--R
+--R   (2)
+--R                        +------------+2
+--R               +-+     3|     +-+
+--R         (- %i\|3  - 3)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +------------+2     +----------+
+--R            +-+     3|     +-+          3|   +-+         3+-+
+--R       (2%i\|3  + 6)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                      +----------+2
+--R             +-+     3|   +-+
+--R         (%i\|3  - 3)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +----------+2     +------------+
+--R              +-+     3|   +-+          3|     +-+         3+-+
+--R       (- 2%i\|3  + 6)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                +------------+
+--R                       +----------+2     3+-+2 3|     +-+
+--R            +-+       3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (- 6\|3  + 6%i)\|%i\|3  + 1  atan(-------------------------)
+--R                                                    +------------+
+--R                                          3+-+2 +-+3|     +-+
+--R                                          \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                  +----------+
+--R                       +------------+2     3+-+2 3|   +-+
+--R            +-+       3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (- 6\|3  - 6%i)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                      +----------+
+--R                                            3+-+2 +-+3|   +-+
+--R                                            \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R               +------------+2  +----------+2
+--R          3+-+3|     +-+       3|   +-+
+--R       18x\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R  /
+--R            +------------+2  +----------+2
+--R       3+-+3|     +-+       3|   +-+
+--R     18\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 506
+
+--S 507 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                           Type: Expression(Complex(Integer))
+--E 507
+
+)clear all
+
+--S 508 of 1311
+t0:=x^5/(1-x^3+x^6)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 508
+
+--S 509 of 1311
+r0:=1/6*log(1-x^3+x^6)-1/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                        3      +-+
+--R         +-+     6    3              (2x  - 1)\|3
+--R        \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           6\|3
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 1311
+t0:=x^4/(1-x^3+x^6)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 511
+
+--S 512 of 1311
+r0:=-1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))+_
+   1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3))-1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*_
+   sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3))+1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))-1/18*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3+%i*_
+   sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))+1/3*atan((4*x+2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))*_
+   (%i+sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))
+--R 
+--R
+--R   (2)
+--R                      +------------+
+--R             +-+     3|     +-+
+--R         (%i\|3  - 3)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +------------+     +----------+
+--R              +-+     3|     +-+         3|   +-+         3+-+
+--R       (- 2%i\|3  + 6)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                        +----------+
+--R               +-+     3|   +-+
+--R         (- %i\|3  - 3)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+     +------------+
+--R            +-+     3|   +-+         3|     +-+         3+-+
+--R       (2%i\|3  + 6)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                             +------------+
+--R                     +----------+     3+-+2 3|     +-+
+--R          +-+       3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (6\|3  + 6%i)\|%i\|3  + 1 atan(-------------------------)
+--R                                                 +------------+
+--R                                       3+-+2 +-+3|     +-+
+--R                                       \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                               +----------+
+--R                     +------------+     3+-+2 3|   +-+
+--R          +-+       3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (6\|3  - 6%i)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                   +----------+
+--R                                         3+-+2 +-+3|   +-+
+--R                                         \|2  \|3 \|%i\|3  + 1
+--R  /
+--R              +------------+ +----------+
+--R       3+-+2 3|     +-+     3|   +-+
+--R     18\|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 512
+
+--S 513 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                           Type: Expression(Complex(Integer))
+--E 513
+
+)clear all
+
+--S 514 of 1311
+t0:=x^3/(1-x^3+x^6)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 514
+
+--S 515 of 1311
+r0:=1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))+_
+   1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*_
+   sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3))+1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3+%i*_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/3*atan((4*x+2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))*_
+   (%i+sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))
+--R 
+--R
+--R   (2)
+--R                      +------------+2
+--R             +-+     3|     +-+
+--R         (%i\|3  - 3)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                       +------------+2     +----------+
+--R              +-+     3|     +-+          3|   +-+         3+-+
+--R       (- 2%i\|3  + 6)\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                        +----------+2
+--R               +-+     3|   +-+
+--R         (- %i\|3  - 3)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                     +----------+2     +------------+
+--R            +-+     3|   +-+          3|     +-+         3+-+
+--R       (2%i\|3  + 6)\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                +------------+
+--R                       +----------+2     3+-+2 3|     +-+
+--R            +-+       3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (- 6\|3  - 6%i)\|%i\|3  + 1  atan(-------------------------)
+--R                                                    +------------+
+--R                                          3+-+2 +-+3|     +-+
+--R                                          \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                  +----------+
+--R                       +------------+2     3+-+2 3|   +-+
+--R            +-+       3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (- 6\|3  + 6%i)\|- %i\|3  + 1  atan(-----------------------)
+--R                                                      +----------+
+--R                                            3+-+2 +-+3|   +-+
+--R                                            \|2  \|3 \|%i\|3  + 1
+--R  /
+--R            +------------+2  +----------+2
+--R       3+-+3|     +-+       3|   +-+
+--R     18\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 515
+
+--S 516 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                           Type: Expression(Complex(Integer))
+--E 516
+
+)clear all
+
+--S 517 of 1311
+t0:=x^2/(1-x^3+x^6)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 517
+
+--S 518 of 1311
+r0:=-2/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                 3      +-+
+--R              (2x  - 1)\|3
+--R        2atan(-------------)
+--R                    3
+--R   (2)  --------------------
+--R                  +-+
+--R                3\|3
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 519
+
+)clear all
+
+--S 520 of 1311
+t0:=x/(1-x^3+x^6)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 520
+
+--S 521 of 1311
+r0:=1/3*%i*2^(1/3)*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3)*sqrt(3)))/(1-%i*sqrt(3))^(1/3)-1/3*%i*2^(1/3)*_
+   atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*_
+   sqrt(3)))/(1+%i*sqrt(3))^(1/3)+1/3*%i*2^(1/3)*log(-2^(1/3)*x+(1-%i*_
+   sqrt(3))^(1/3))/((1-%i*sqrt(3))^(1/3)*sqrt(3))-1/3*%i*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3)*sqrt(3))-1/3*%i*2^(1/3)*log(-2^(1/3)*x+_
+   (1+%i*sqrt(3))^(1/3))/((1+%i*sqrt(3))^(1/3)*sqrt(3))+1/3*%i*_
+   log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))/_
+   (2^(2/3)*(1+%i*sqrt(3))^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +------------+     +----------+2         +----------+
+--R       1   3|     +-+         3|   +-+          3+-+3|   +-+         2 3+-+2
+--R       - %i\|- %i\|3  + 1 log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R       3
+--R     + 
+--R              +------------+     +----------+
+--R         2   3|     +-+         3|   +-+         3+-+
+--R       - - %i\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R         3
+--R     + 
+--R              +----------+     +------------+2         +------------+
+--R         1   3|   +-+         3|     +-+          3+-+3|     +-+         2 3+-+2
+--R       - - %i\|%i\|3  + 1 log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R         3
+--R     + 
+--R            +----------+     +------------+
+--R       2   3|   +-+         3|     +-+         3+-+
+--R       - %i\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R       3
+--R     + 
+--R                                        +------------+
+--R                +----------+     3+-+2 3|     +-+
+--R       2    +-+3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       - %i\|3 \|%i\|3  + 1 atan(-------------------------)
+--R       3                                    +------------+
+--R                                  3+-+2 +-+3|     +-+
+--R                                  \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                            +----------+
+--R                  +------------+     3+-+2 3|   +-+
+--R         2    +-+3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       - - %i\|3 \|- %i\|3  + 1 atan(-----------------------)
+--R         3                                      +----------+
+--R                                      3+-+2 +-+3|   +-+
+--R                                      \|2  \|3 \|%i\|3  + 1
+--R  /
+--R               +------------+ +----------+
+--R     3+-+2 +-+3|     +-+     3|   +-+
+--R     \|2  \|3 \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 521
+
+--S 522 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 522
+
+)clear all
+
+--S 523 of 1311
+t0:=1/(1-x^3+x^6)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         6    3
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 523
+
+--S 524 of 1311
+r0:=-1/3*(-1)^(13/18)*atan((1+2*(-1)^(1/9)*x)/sqrt(3))+1/3*(-1)^(5/18)*_
+   atan((1-2*(-1)^(8/9)*x)/sqrt(3))-1/9*(-1)^(5/18)*(log(2)+_
+   3*log((-1)^(1/9)-x))/sqrt(3)+1/3*(-1)^(13/18)*log(-2^(1/3)*_
+   ((-1)^(8/9)+x))/sqrt(3)-1/6*(-1)^(13/18)*log(-2^(2/3)*((-1)^(7/9)+_
+   ((-1)^(8/9)-x)*x))/sqrt(3)+1/6*(-1)^(5/18)*log(2^(2/3)*((-1)^(2/9)+_
+   x*((-1)^(1/9)+x)))/sqrt(3),-1/3*%i*2^(2/3)*atan((4*x+2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))/_
+   (1-%i*sqrt(3))^(2/3)+1/3*%i*2^(2/3)*atan((4*x+2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*sqrt(3)))/(1+%i*_
+   sqrt(3))^(2/3)+1/3*%i*2^(2/3)*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))/_
+   ((1-%i*sqrt(3))^(2/3)*sqrt(3))-1/3*%i*log(2^(2/3)*x^2+2^(1/3)*x*_
+   (1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))/(2^(1/3)*(1-%i*_
+   sqrt(3))^(2/3)*sqrt(3))-1/3*%i*2^(2/3)*log(-2^(1/3)*x+(1+%i*_
+   sqrt(3))^(1/3))/((1+%i*sqrt(3))^(2/3)*sqrt(3))+1/3*%i*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R   [
+--R         1 18+---+5     9+---+2    9+---+    2 3+-+2
+--R         -  \|- 1  log((\|- 1   + x\|- 1  + x )\|2  )
+--R         6
+--R       + 
+--R           1 18+---+5    9+---+        1 18+---+13       9+---+8     3+-+
+--R         - -  \|- 1  log(\|- 1  - x) + -  \|- 1   log((- \|- 1   - x)\|2 )
+--R           3                           3
+--R       + 
+--R           1 18+---+13       9+---+7    2     3+-+2
+--R         - -  \|- 1   log((- \|- 1   + x  - x)\|2  )
+--R           6
+--R       + 
+--R           1 18+---+5 +-+      2   9+---+8   1  +-+
+--R         - -  \|- 1  \|3 atan((- x \|- 1   - -)\|3 )
+--R           3                   3             3
+--R       + 
+--R           1 18+---+13 +-+      2  9+---+   1  +-+    1       18+---+5
+--R         - -  \|- 1   \|3 atan((- x\|- 1  + -)\|3 ) - - log(2) \|- 1
+--R           3                    3           3         9
+--R    /
+--R        +-+
+--R       \|3
+--R     ,
+--R
+--R               +------------+2     +----------+2         +----------+
+--R         1    3|     +-+          3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         - %i \|- %i\|3  + 1  log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R         3
+--R       + 
+--R                 +------------+2     +----------+
+--R           2    3|     +-+          3|   +-+         3+-+
+--R         - - %i \|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R           3
+--R       + 
+--R         -
+--R                    +----------+2
+--R              1    3|   +-+
+--R              - %i \|%i\|3  + 1
+--R              3
+--R           *
+--R                   +------------+2         +------------+
+--R                  3|     +-+          3+-+3|     +-+         2 3+-+2
+--R              log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R       + 
+--R               +----------+2     +------------+
+--R         2    3|   +-+          3|     +-+         3+-+
+--R         - %i \|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R         3
+--R       + 
+--R                                             +------------+
+--R                    +----------+2     3+-+2 3|     +-+
+--R           2    +-+3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R         - - %i\|3 \|%i\|3  + 1  atan(-------------------------)
+--R           3                                     +------------+
+--R                                       3+-+2 +-+3|     +-+
+--R                                       \|2  \|3 \|- %i\|3  + 1
+--R       + 
+--R                                             +----------+
+--R                  +------------+2     3+-+2 3|   +-+
+--R         2    +-+3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R         - %i\|3 \|- %i\|3  + 1  atan(-----------------------)
+--R         3                                       +----------+
+--R                                       3+-+2 +-+3|   +-+
+--R                                       \|2  \|3 \|%i\|3  + 1
+--R    /
+--R                +------------+2  +----------+2
+--R       3+-+ +-+3|     +-+       3|   +-+
+--R       \|2 \|3 \|- %i\|3  + 1   \|%i\|3  + 1
+--R     ]
+--R                          Type: Tuple(Expression(Complex(Fraction(Integer))))
+--E 524
+
+--S 525 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                 12    11    10     9     8     6     5     3    2
+--R             (- x   + x   - x   - 6x  - 2x  + 7x  + 2x  - 8x  - x  - x + 1)
+--R          *
+--R             18+---+17
+--R              \|- 1
+--R         + 
+--R                  13    12    11     10     9     8     7      6     5     4
+--R               - x   - x   + x   - 6x   + 6x  - 2x  + 7x  - 11x  + 2x  - 8x
+--R             + 
+--R                  3    2
+--R               10x  - x  + x - 5
+--R          *
+--R             18+---+15
+--R              \|- 1
+--R         + 
+--R                  14    13    12     11     10     9    8     7     6     4    3
+--R               - x   - x   + x   + 2x   + 2x   - 2x  - x  - 7x  + 2x  + 6x  - x
+--R             + 
+--R                2
+--R               x  - 5x
+--R          *
+--R             18+---+13
+--R              \|- 1
+--R         + 
+--R                 14    13    12     11     9     8     6     5    4    3     2
+--R             (- x   + x   + x   + 2x   - 2x  - 7x  + 2x  + 6x  + x  - x  - 5x )
+--R          *
+--R             18+---+11
+--R              \|- 1
+--R         + 
+--R               13    12    11     10     9    8     7     6    5    4    3
+--R             (x   + x   + x   - 2x   - 2x  - x  + 2x  + 2x  + x  - x  - x )
+--R          *
+--R             18+---+9
+--R              \|- 1
+--R         + 
+--R               12    11    10    9     8     7    6     5     4     2
+--R             (x   - x   - x   - x  + 7x  - 5x  + x  - 7x  + 5x  + 6x  - 6x)
+--R          *
+--R             18+---+7
+--R              \|- 1
+--R         + 
+--R               11     9     8     6     5     3     2 18+---+5
+--R           (- x   + 5x  - 5x  - 5x  + 5x  + 5x  - 6x ) \|- 1
+--R         + 
+--R              10     9    8     7      6    5     4      3    2     18+---+3
+--R           (5x   - 7x  + x  - 5x  + 13x  - x  + 5x  - 13x  + x  + 6) \|- 1
+--R         + 
+--R             11    10    9     8     7    6     5     4    3     2     18+---+
+--R         (- x   - x   + x  + 8x  + 2x  - x  - 8x  - 2x  + x  + 7x  + x) \|- 1
+--R      *
+--R          +-+
+--R         \|3
+--R     + 
+--R           7      5      4       18+---+16
+--R       (18x  - 18x  + 18x  + 18x) \|- 1
+--R     + 
+--R           8      6      5      2 18+---+14         7      6      3 18+---+12
+--R       (18x  - 18x  + 18x  + 18x ) \|- 1    + (- 18x  + 18x  - 18x ) \|- 1
+--R     + 
+--R           5      4 18+---+10       6      5 18+---+8
+--R       (18x  - 36x ) \|- 1    + (18x  - 36x ) \|- 1
+--R     + 
+--R           7      6      3 18+---+6
+--R       (18x  - 18x  + 18x ) \|- 1
+--R     + 
+--R             8      7      4      2       18+---+4
+--R       (- 18x  + 18x  + 18x  - 18x  + 18x) \|- 1
+--R     + 
+--R             9      8      5      3      2 18+---+2      10      9      6      4
+--R       (- 18x  + 18x  + 18x  - 18x  + 18x ) \|- 1   - 18x   + 18x  - 18x  - 18x
+--R     + 
+--R          3
+--R       18x  - 18
+--R  /
+--R           13      11      8      7      5       18+---+16
+--R       (18x   - 18x   + 18x  + 18x  - 18x  + 18x) \|- 1
+--R     + 
+--R           14      12      9      8      6      2 18+---+14
+--R       (18x   - 18x   + 18x  + 18x  - 18x  + 18x ) \|- 1
+--R     + 
+--R             13      12      10      9      7      6      3 18+---+12
+--R       (- 18x   + 18x   + 18x   - 36x  - 18x  + 36x  - 18x ) \|- 1
+--R     + 
+--R           11      10      8      7      5      4 18+---+10
+--R       (18x   - 36x   - 18x  + 36x  + 18x  - 36x ) \|- 1
+--R     + 
+--R           12      11      9      8      6      5 18+---+8
+--R       (18x   - 36x   - 18x  + 36x  + 18x  - 36x ) \|- 1
+--R     + 
+--R           13      12      10      9      7      6      3 18+---+6
+--R       (18x   - 18x   - 18x   + 36x  + 18x  - 36x  + 18x ) \|- 1
+--R     + 
+--R             14      13      11      8      7      5      2       18+---+4
+--R       (- 18x   + 18x   + 18x   - 36x  + 18x  + 18x  - 18x  + 18x) \|- 1
+--R     + 
+--R             15      14      12      9      8      6      3      2 18+---+2
+--R       (- 18x   + 18x   + 18x   - 36x  + 18x  + 18x  - 18x  + 18x ) \|- 1
+--R     + 
+--R            16      15      13      12      10      9      7      6      4
+--R       - 18x   + 18x   + 18x   - 36x   - 36x   + 54x  + 18x  - 54x  - 18x
+--R     + 
+--R          3
+--R       36x  - 18
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 1311
+t0:=1/(x*(1-x^3+x^6))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         7    4
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 526
+
+--S 527 of 1311
+r0:=log(x)-1/6*log(1-x^3+x^6)-1/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                        3      +-+
+--R           +-+     6    3          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 6\|3 log(x) + 2atan(-------------)
+--R                                                           3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   6\|3
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 1311
+t0:=1/(x^2*(1-x^3+x^6))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         8    5    2
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 529
+
+--S 530 of 1311
+r0:=(-1)/x+1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))-_
+   1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*_
+   sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3+%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))-1/3*atan((4*x+2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*sqrt(3)))*_
+   (%i+sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))
+--R 
+--R
+--R   (2)
+--R                         +------------+
+--R               +-+      3|     +-+
+--R         (%i x\|3  + 3x)\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                          +------------+     +----------+
+--R                +-+      3|     +-+         3|   +-+         3+-+
+--R       (- 2%i x\|3  - 6x)\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                           +----------+
+--R                 +-+      3|   +-+
+--R         (- %i x\|3  + 3x)\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                        +----------+     +------------+
+--R              +-+      3|   +-+         3|     +-+         3+-+
+--R       (2%i x\|3  - 6x)\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                  +------------+
+--R                          +----------+     3+-+2 3|     +-+
+--R             +-+         3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (- 6x\|3  + 6%i x)\|%i\|3  + 1 atan(-------------------------)
+--R                                                      +------------+
+--R                                            3+-+2 +-+3|     +-+
+--R                                            \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                    +----------+
+--R                          +------------+     3+-+2 3|   +-+
+--R             +-+         3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (- 6x\|3  - 6%i x)\|- %i\|3  + 1 atan(-----------------------)
+--R                                                        +----------+
+--R                                              3+-+2 +-+3|   +-+
+--R                                              \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                  +------------+ +----------+
+--R           3+-+2 3|     +-+     3|   +-+
+--R       - 18\|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R  /
+--R                +------------+ +----------+
+--R         3+-+2 3|     +-+     3|   +-+
+--R     18x \|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 530
+
+--S 531 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                           Type: Expression(Complex(Integer))
+--E 531
+
+)clear all
+
+--S 532 of 1311
+t0:=1/(x^3*(1-x^3+x^6))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         9    6    3
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 532
+
+--S 533 of 1311
+r0:=(-1/2)/x^2-1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1-%i*_
+   sqrt(3))^(2/3))-1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*(3-%i*_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))+1/18*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3-%i*_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/9*log(-2^(1/3)*x+(1+%i*_
+   sqrt(3))^(1/3))*(3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))+_
+   1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*_
+   sqrt(3))^(2/3))*(3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))+_
+   1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i+sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))
+--R 
+--R
+--R   (2)
+--R                           +------------+2
+--R              2 +-+     2 3|     +-+
+--R         (%i x \|3  + 3x )\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                            +------------+2     +----------+
+--R               2 +-+     2 3|     +-+          3|   +-+         3+-+
+--R       (- 2%i x \|3  - 6x )\|- %i\|3  + 1  log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                             +----------+2
+--R                2 +-+     2 3|   +-+
+--R         (- %i x \|3  + 3x )\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                          +----------+2     +------------+
+--R             2 +-+     2 3|   +-+          3|     +-+         3+-+
+--R       (2%i x \|3  - 6x )\|%i\|3  + 1  log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                   +------------+
+--R                          +----------+2     3+-+2 3|     +-+
+--R          2 +-+        2 3|   +-+           \|2   \|- %i\|3  + 1 + 4x
+--R       (6x \|3  - 6%i x )\|%i\|3  + 1  atan(-------------------------)
+--R                                                       +------------+
+--R                                             3+-+2 +-+3|     +-+
+--R                                             \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                     +----------+
+--R                          +------------+2     3+-+2 3|   +-+
+--R          2 +-+        2 3|     +-+           \|2   \|%i\|3  + 1 + 4x
+--R       (6x \|3  + 6%i x )\|- %i\|3  + 1  atan(-----------------------)
+--R                                                         +----------+
+--R                                               3+-+2 +-+3|   +-+
+--R                                               \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R               +------------+2  +----------+2
+--R          3+-+3|     +-+       3|   +-+
+--R       - 9\|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R  /
+--R               +------------+2  +----------+2
+--R        2 3+-+3|     +-+       3|   +-+
+--R     18x  \|2 \|- %i\|3  + 1   \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 533
+
+--S 534 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                           Type: Expression(Complex(Integer))
+--E 534
+
+)clear all
+
+--S 535 of 1311
+t0:=1/(x^4*(1-x^3+x^6))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         10    7    4
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 535
+
+--S 536 of 1311
+r0:=(-1/3)/x^3+log(x)-1/6*log(1-x^3+x^6)+1/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                         3      +-+
+--R      3 +-+     6    3          3 +-+           3     (2x  - 1)\|3       +-+
+--R   - x \|3 log(x  - x  + 1) + 6x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                            3
+--R   -------------------------------------------------------------------------
+--R                                      3 +-+
+--R                                    6x \|3
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 537
+
+)clear all
+
+--S 538 of 1311
+t0:=1/(x^5*(1-x^3+x^6))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         11    8    5
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 538
+
+--S 539 of 1311
+r0:=(-1/4)/x^4+(-1)/x+1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+_
+   (1-%i*sqrt(3))^(1/3))*(3+%i*sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))+_
+   1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*_
+   sqrt(3))^(2/3))*(3+%i*sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))-_
+   1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i+sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))
+--R 
+--R
+--R   (2)
+--R                              +------------+
+--R                 4 +-+     4 3|     +-+
+--R         (- 2%i x \|3  + 6x )\|- %i\|3  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|3  + 1   + x\|2 \|%i\|3  + 1  + x  \|2 )
+--R     + 
+--R                           +------------+     +----------+
+--R             4 +-+      4 3|     +-+         3|   +-+         3+-+
+--R       (4%i x \|3  - 12x )\|- %i\|3  + 1 log(\|%i\|3  + 1  - x\|2 )
+--R     + 
+--R                            +----------+
+--R               4 +-+     4 3|   +-+
+--R         (2%i x \|3  + 6x )\|%i\|3  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|3  + 1   + x\|2 \|- %i\|3  + 1  + x  \|2 )
+--R     + 
+--R                             +----------+     +------------+
+--R               4 +-+      4 3|   +-+         3|     +-+         3+-+
+--R       (- 4%i x \|3  - 12x )\|%i\|3  + 1 log(\|- %i\|3  + 1  - x\|2 )
+--R     + 
+--R                                                      +------------+
+--R                              +----------+     3+-+2 3|     +-+
+--R             4 +-+         4 3|   +-+          \|2   \|- %i\|3  + 1 + 4x
+--R       (- 12x \|3  - 12%i x )\|%i\|3  + 1 atan(-------------------------)
+--R                                                          +------------+
+--R                                                3+-+2 +-+3|     +-+
+--R                                                \|2  \|3 \|- %i\|3  + 1
+--R     + 
+--R                                                        +----------+
+--R                              +------------+     3+-+2 3|   +-+
+--R             4 +-+         4 3|     +-+          \|2   \|%i\|3  + 1 + 4x
+--R       (- 12x \|3  + 12%i x )\|- %i\|3  + 1 atan(-----------------------)
+--R                                                            +----------+
+--R                                                  3+-+2 +-+3|   +-+
+--R                                                  \|2  \|3 \|%i\|3  + 1
+--R     + 
+--R                          +------------+ +----------+
+--R             3     3+-+2 3|     +-+     3|   +-+
+--R       (- 36x  - 9)\|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R  /
+--R                 +------------+ +----------+
+--R        4 3+-+2 3|     +-+     3|   +-+
+--R     36x  \|2   \|- %i\|3  + 1 \|%i\|3  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 539
+
+--S 540 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                           Type: Expression(Complex(Integer))
+--E 540
+
+)clear all
+
+--S 541 of 1311
+t0:=1/(2+x^3+x^6)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         6    3
+--R        x  + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 541
+
+--S 542 of 1311
+r0:=-1/3*%i*2^(2/3)*log(2^(1/3)*x+(1-%i*sqrt(7))^(1/3))/((1-%i*_
+   sqrt(7))^(2/3)*sqrt(7))+1/3*%i*log(2^(2/3)*x^2-2^(1/3)*x*(1-%i*_
+   sqrt(7))^(1/3)+(1-%i*sqrt(7))^(2/3))/(2^(1/3)*(1-%i*sqrt(7))^(2/3)*_
+   sqrt(7))+1/3*%i*2^(2/3)*log(2^(1/3)*x+(1+%i*sqrt(7))^(1/3))/((1+%i*_
+   sqrt(7))^(2/3)*sqrt(7))-1/3*%i*log(2^(2/3)*x^2-2^(1/3)*x*(1+%i*_
+   sqrt(7))^(1/3)+(1+%i*sqrt(7))^(2/3))/(2^(1/3)*(1+%i*sqrt(7))^(2/3)*_
+   sqrt(7))+%i*2^(2/3)*atan((-4*x+2^(2/3)*(1-%i*sqrt(7))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(1-%i*sqrt(7))^(1/3)))/((1-%i*sqrt(7))^(2/3)*sqrt(21))-_
+   %i*2^(2/3)*atan((-4*x+2^(2/3)*(1+%i*sqrt(7))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(1+%i*sqrt(7))^(1/3)))/((1+%i*sqrt(7))^(2/3)*sqrt(21))
+--R 
+--R
+--R   (2)
+--R       -
+--R                      +------------+2
+--R            1    +--+3|     +-+
+--R            - %i\|21 \|- %i\|7  + 1
+--R            3
+--R         *
+--R                 +----------+2         +----------+
+--R                3|   +-+          3+-+3|   +-+         2 3+-+2
+--R            log(\|%i\|7  + 1   - x\|2 \|%i\|7  + 1  + x  \|2 )
+--R     + 
+--R                 +------------+2     +----------+
+--R       2    +--+3|     +-+          3|   +-+         3+-+
+--R       - %i\|21 \|- %i\|7  + 1  log(\|%i\|7  + 1  + x\|2 )
+--R       3
+--R     + 
+--R                   +----------+2
+--R         1    +--+3|   +-+
+--R         - %i\|21 \|%i\|7  + 1
+--R         3
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|7  + 1   - x\|2 \|- %i\|7  + 1  + x  \|2 )
+--R     + 
+--R                   +----------+2     +------------+
+--R         2    +--+3|   +-+          3|     +-+         3+-+
+--R       - - %i\|21 \|%i\|7  + 1  log(\|- %i\|7  + 1  + x\|2 )
+--R         3
+--R     + 
+--R                                            +----------+
+--R                 +------------+2     3+-+2 3|   +-+
+--R             +-+3|     +-+           \|2   \|%i\|7  + 1 - 4x
+--R       - 2%i\|7 \|- %i\|7  + 1  atan(-----------------------)
+--R                                                +----------+
+--R                                      3+-+2 +-+3|   +-+
+--R                                      \|2  \|3 \|%i\|7  + 1
+--R     + 
+--R                                        +------------+
+--R               +----------+2     3+-+2 3|     +-+
+--R           +-+3|   +-+           \|2   \|- %i\|7  + 1 - 4x
+--R       2%i\|7 \|%i\|7  + 1  atan(-------------------------)
+--R                                            +------------+
+--R                                  3+-+2 +-+3|     +-+
+--R                                  \|2  \|3 \|- %i\|7  + 1
+--R  /
+--R                   +------------+2  +----------+2
+--R     3+-+ +-+ +--+3|     +-+       3|   +-+
+--R     \|2 \|7 \|21 \|- %i\|7  + 1   \|%i\|7  + 1
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 542
+
+--S 543 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                      +----------+2
+--R           1      3+-+2 +-+ +--+    1      3+-+2 +-+ 3|   +-+
+--R       (- -- %i x \|2  \|3 \|21  + -- %i x \|2  \|7 )\|%i\|7  + 1
+--R          42                       14
+--R     + 
+--R                                         +----------+
+--R         1     2 +-+ +--+   1     2 +-+ 3|   +-+
+--R       (-- %i x \|3 \|21  - - %i x \|7 )\|%i\|7  + 1
+--R        21                  7
+--R     + 
+--R                                                    +------------+2
+--R         1      3+-+2 +-+ +--+    1      3+-+2 +-+ 3|     +-+
+--R       (-- %i x \|2  \|3 \|21  - -- %i x \|2  \|7 )\|- %i\|7  + 1
+--R        42                       14
+--R     + 
+--R                                           +------------+
+--R           1     2 +-+ +--+   1     2 +-+ 3|     +-+         1 3+-+ +-+ +-+ +--+
+--R       (- -- %i x \|3 \|21  + - %i x \|7 )\|- %i\|7  + 1  - -- \|2 \|3 \|7 \|21
+--R          21                  7                             21
+--R     + 
+--R       3+-+
+--R       \|2
+--R  /
+--R               +------------+2          +------------+
+--R            2 3|     +-+         3 3+-+3|     +-+       1      3+-+2 +-+
+--R           x  \|- %i\|7  + 1  - x  \|2 \|- %i\|7  + 1 + - %i x \|2  \|7
+--R                                                        2
+--R         + 
+--R             1   3+-+2
+--R           - - x \|2
+--R             2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                    +------------+2            +------------+
+--R             3 3+-+3|     +-+         4 3+-+2 3|     +-+          2 +-+    2
+--R         (- x  \|2 \|- %i\|7  + 1  + x  \|2   \|- %i\|7  +  - %i x \|7  + x )
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                                        +------------+2
+--R          1      3+-+2 +-+   1   3+-+2 3|     +-+
+--R       (- - %i x \|2  \|7  - - x \|2  )\|- %i\|7  + 1
+--R          2                  2
+--R     + 
+--R                        +------------+
+--R            2 +-+    2 3|     +-+         3+-+
+--R       (%i x \|7  + x )\|- %i\|7  + 1  + 4\|2
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 543
+
+)clear all
+
+--S 544 of 1311
+t0:=x^2/(2+x^3+x^6)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 544
+
+--S 545 of 1311
+r0:=2/3*atan((1+2*x^3)/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                 3      +-+
+--R              (2x  + 1)\|7
+--R        2atan(-------------)
+--R                    7
+--R   (2)  --------------------
+--R                  +-+
+--R                3\|7
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 546
+
+)clear all
+
+--S 547 of 1311
+t0:=x^3/(2+x^3+x^6)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         6    3
+--R        x  + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 547
+
+--S 548 of 1311
+r0:=1/21*log(2^(1/3)*x+(1+%i*sqrt(7))^(1/3))*(7-%i*sqrt(7))/(2^(1/3)*_
+   (1+%i*sqrt(7))^(2/3))-1/42*log(2^(2/3)*x^2-2^(1/3)*x*(1+%i*_
+   sqrt(7))^(1/3)+(1+%i*sqrt(7))^(2/3))*(7-%i*sqrt(7))/(2^(1/3)*_
+   (1+%i*sqrt(7))^(2/3))+1/21*log(2^(1/3)*x+(1-%i*sqrt(7))^(1/3))*_
+   (7+%i*sqrt(7))/(2^(1/3)*(1-%i*sqrt(7))^(2/3))-1/42*log(2^(2/3)*_
+   x^2-2^(1/3)*x*(1-%i*sqrt(7))^(1/3)+(1-%i*sqrt(7))^(2/3))*(7+%i*_
+   sqrt(7))/(2^(1/3)*(1-%i*sqrt(7))^(2/3))-%i*atan((-4*x+2^(2/3)*_
+   (1-%i*sqrt(7))^(1/3))/(2^(2/3)*sqrt(3)*(1-%i*sqrt(7))^(1/3)))*_
+   (1-%i*sqrt(7))^(1/3)/(2^(1/3)*sqrt(21))+%i*atan((-4*x+2^(2/3)*_
+   (1+%i*sqrt(7))^(1/3))/(2^(2/3)*sqrt(3)*(1+%i*sqrt(7))^(1/3)))*_
+   (1+%i*sqrt(7))^(1/3)/(2^(1/3)*sqrt(21))
+--R 
+--R
+--R   (2)
+--R                           +------------+2
+--R             +-+      +--+3|     +-+
+--R         (%i\|7  - 7)\|21 \|- %i\|7  + 1
+--R      *
+--R              +----------+2         +----------+
+--R             3|   +-+          3+-+3|   +-+         2 3+-+2
+--R         log(\|%i\|7  + 1   - x\|2 \|%i\|7  + 1  + x  \|2 )
+--R     + 
+--R                             +------------+2     +----------+
+--R              +-+       +--+3|     +-+          3|   +-+         3+-+
+--R       (- 2%i\|7  + 14)\|21 \|- %i\|7  + 1  log(\|%i\|7  + 1  + x\|2 )
+--R     + 
+--R                             +----------+2
+--R               +-+      +--+3|   +-+
+--R         (- %i\|7  - 7)\|21 \|%i\|7  + 1
+--R      *
+--R              +------------+2         +------------+
+--R             3|     +-+          3+-+3|     +-+         2 3+-+2
+--R         log(\|- %i\|7  + 1   - x\|2 \|- %i\|7  + 1  + x  \|2 )
+--R     + 
+--R                           +----------+2     +------------+
+--R            +-+       +--+3|   +-+          3|     +-+         3+-+
+--R       (2%i\|7  + 14)\|21 \|%i\|7  + 1  log(\|- %i\|7  + 1  + x\|2 )
+--R     + 
+--R                                                    +----------+
+--R                         +------------+2     3+-+2 3|   +-+
+--R             +-+        3|     +-+           \|2   \|%i\|7  + 1 - 4x
+--R       (- 42\|7  + 42%i)\|- %i\|7  + 1  atan(-----------------------)
+--R                                                        +----------+
+--R                                              3+-+2 +-+3|   +-+
+--R                                              \|2  \|3 \|%i\|7  + 1
+--R     + 
+--R                                                  +------------+
+--R                         +----------+2     3+-+2 3|     +-+
+--R             +-+        3|   +-+           \|2   \|- %i\|7  + 1 - 4x
+--R       (- 42\|7  - 42%i)\|%i\|7  + 1  atan(-------------------------)
+--R                                                      +------------+
+--R                                            3+-+2 +-+3|     +-+
+--R                                            \|2  \|3 \|- %i\|7  + 1
+--R  /
+--R                 +------------+2  +----------+2
+--R       3+-+ +--+3|     +-+       3|   +-+
+--R     42\|2 \|21 \|- %i\|7  + 1   \|%i\|7  + 1
+--R                                           Type: Expression(Complex(Integer))
+--E 548
+
+--S 549 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R             3+-+2 +-+ +-+        3+-+2 +-+  +--+         3+-+2 +-+       3+-+2
+--R         ((x \|2  \|3 \|7  + %i x \|2  \|3 )\|21  - 3%i x \|2  \|7  - 21x \|2  )
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                                                               +----------+
+--R             2 +-+ +-+        2 +-+  +--+        2 +-+      2 3|   +-+
+--R       ((- 2x \|3 \|7  - 2%i x \|3 )\|21  + 6%i x \|7  + 42x )\|%i\|7  + 1
+--R     + 
+--R             3+-+2 +-+ +-+        3+-+2 +-+  +--+         3+-+2 +-+       3+-+2
+--R         ((x \|2  \|3 \|7  - %i x \|2  \|3 )\|21  + 3%i x \|2  \|7  - 21x \|2  )
+--R      *
+--R          +------------+2
+--R         3|     +-+
+--R         \|- %i\|7  + 1
+--R     + 
+--R                                                               +------------+
+--R             2 +-+ +-+        2 +-+  +--+        2 +-+      2 3|     +-+
+--R       ((- 2x \|3 \|7  + 2%i x \|3 )\|21  - 6%i x \|7  + 42x )\|- %i\|7  + 1
+--R  /
+--R                 +------------+2            +------------+
+--R              2 3|     +-+           3 3+-+3|     +-+              3+-+2 +-+
+--R           84x  \|- %i\|7  + 1  - 84x  \|2 \|- %i\|7  + 1 + 42%i x \|2  \|7
+--R         + 
+--R                 3+-+2
+--R           - 42x \|2
+--R      *
+--R          +----------+2
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                       +------------+2              +------------+
+--R                3 3+-+3|     +-+           4 3+-+2 3|     +-+            2 +-+
+--R           - 84x  \|2 \|- %i\|7  + 1  + 84x  \|2   \|- %i\|7  +  - 84%i x \|7
+--R         + 
+--R              2
+--R           84x
+--R      *
+--R          +----------+
+--R         3|   +-+
+--R         \|%i\|7  + 1
+--R     + 
+--R                                        +------------+2
+--R                 3+-+2 +-+       3+-+2 3|     +-+
+--R       (- 42%i x \|2  \|7  - 42x \|2  )\|- %i\|7  + 1
+--R     + 
+--R                            +------------+
+--R              2 +-+      2 3|     +-+           3+-+
+--R       (84%i x \|7  + 84x )\|- %i\|7  + 1  + 336\|2
+--R                                           Type: Expression(Complex(Integer))
+--E 549
+
+)clear all
+
+--S 550 of 1311
+t0:=x^m/(1+2*x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 1311
+--r0:=1/4*x^(1+m)/(1+x^4)+1/4*(3-m)*x^(1+m)*hypergeometric(1,1/4*(1+m),_
+--   1/4*(5+m),-x^4)/(1+m)
+--E 551
+
+--S 552 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 552
+
+)clear all
+
+--S 553 of 1311
+t0:=x^9/(1+2*x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 553
+
+--S 554 of 1311
+r0:=3/4*x^2-1/4*x^6/(1+x^4)-3/4*atan(x^2)
+--R 
+--R
+--R             4           2      6     2
+--R        (- 3x  - 3)atan(x ) + 2x  + 3x
+--R   (2)  -------------------------------
+--R                      4
+--R                    4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 1311
+t0:=x^7/(1+2*x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 556
+
+--S 557 of 1311
+r0:=1/4/(1+x^4)+1/4*log(1+x^4)
+--R 
+--R
+--R          4          4
+--R        (x  + 1)log(x  + 1) + 1
+--R   (2)  -----------------------
+--R                  4
+--R                4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 558
+
+)clear all
+
+--S 559 of 1311
+t0:=x^5/(1+2*x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 559
+
+--S 560 of 1311
+r0:=-1/4*x^2/(1+x^4)+1/4*atan(x^2)
+--R 
+--R
+--R          4           2     2
+--R        (x  + 1)atan(x ) - x
+--R   (2)  ---------------------
+--R                 4
+--R               4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 1311
+t0:=x^3/(1+2*x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 562
+
+--S 563 of 1311
+r0:=(-1/4)/(1+x^4)
+--R 
+--R
+--R             1
+--R             -
+--R             4
+--R   (2)  - ------
+--R           4
+--R          x  + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 563
+
+--S 564 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 1311
+t0:=x/(1+2*x^4+x^8)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 565
+
+--S 566 of 1311
+r0:=1/4*x^2/(1+x^4)+1/4*atan(x^2)
+--R 
+--R
+--R          4           2     2
+--R        (x  + 1)atan(x ) + x
+--R   (2)  ---------------------
+--R                 4
+--R               4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 567
+
+)clear all
+
+--S 568 of 1311
+t0:=1/(x*(1+2*x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         9     5
+--R        x  + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 568
+
+--S 569 of 1311
+r0:=1/4/(1+x^4)-1/2*atanh(1+2*x^4)
+--R 
+--R
+--R             4             4
+--R        (- 2x  - 2)atanh(2x  + 1) + 1
+--R   (2)  -----------------------------
+--R                     4
+--R                   4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 1311
+t0:=1/(x^3*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         11     7    3
+--R        x   + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 571
+
+--S 572 of 1311
+r0:=(-3/4)/x^2+1/4/(x^2*(1+x^4))-3/4*atan(x^2)
+--R 
+--R
+--R             6     2       2      4
+--R        (- 3x  - 3x )atan(x ) - 3x  - 2
+--R   (2)  -------------------------------
+--R                     6     2
+--R                   4x  + 4x
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+)clear all
+
+--S 574 of 1311
+t0:=1/(x^5*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         13     9    5
+--R        x   + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 574
+
+--S 575 of 1311
+r0:=(-1/2)/x^4+1/4/(x^4*(1+x^4))+atanh(1+2*x^4)
+--R 
+--R
+--R           8     4         4          4
+--R        (4x  + 4x )atanh(2x  + 1) - 2x  - 1
+--R   (2)  -----------------------------------
+--R                       8     4
+--R                     4x  + 4x
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 1311
+t0:=1/(x^7*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         15     11    7
+--R        x   + 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 577
+
+--S 578 of 1311
+r0:=(-5/12)/x^6+5/4/x^2+1/4/(x^6*(1+x^4))+5/4*atan(x^2)
+--R 
+--R
+--R            10      6       2       8      4
+--R        (15x   + 15x )atan(x ) + 15x  + 10x  - 2
+--R   (2)  ----------------------------------------
+--R                         10      6
+--R                      12x   + 12x
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 579
+
+)clear all
+
+--S 580 of 1311
+t0:=x^8/(1+2*x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 580
+
+--S 581 of 1311
+r0:=5/4*x-1/4*x^5/(1+x^4)+5/8*atan(1-x*sqrt(2))/sqrt(2)-5/8*atan(1+_
+   x*sqrt(2))/sqrt(2)+5/16*log(1+x^2-x*sqrt(2))/sqrt(2)-5/16*log(1+_
+   x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R            4           +-+    2           4             +-+    2
+--R       (- 5x  - 5)log(x\|2  + x  + 1) + (5x  + 5)log(- x\|2  + x  + 1)
+--R     + 
+--R             4             +-+              4             +-+
+--R       (- 10x  - 10)atan(x\|2  + 1) + (- 10x  - 10)atan(x\|2  - 1)
+--R     + 
+--R           5        +-+
+--R       (16x  + 20x)\|2
+--R  /
+--R         4       +-+
+--R     (16x  + 16)\|2
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 1311
+t0:=x^6/(1+2*x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 583
+
+--S 584 of 1311
+r0:=-1/4*x^3/(1+x^4)-3/8*atan(1-x*sqrt(2))/sqrt(2)+3/8*atan(1+x*sqrt(2))/_
+   sqrt(2)+3/16*log(1+x^2-x*sqrt(2))/sqrt(2)-3/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R            4           +-+    2           4             +-+    2
+--R       (- 3x  - 3)log(x\|2  + x  + 1) + (3x  + 3)log(- x\|2  + x  + 1)
+--R     + 
+--R          4            +-+           4            +-+          3 +-+
+--R       (6x  + 6)atan(x\|2  + 1) + (6x  + 6)atan(x\|2  - 1) - 4x \|2
+--R  /
+--R         4       +-+
+--R     (16x  + 16)\|2
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 1311
+t0:=x^4/(1+2*x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 586
+
+--S 587 of 1311
+r0:=-1/4*x/(1+x^4)-1/8*atan(1-x*sqrt(2))/sqrt(2)+1/8*atan(1+x*sqrt(2))/_
+   sqrt(2)-1/16*log(1+x^2-x*sqrt(2))/sqrt(2)+1/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R         4           +-+    2            4             +-+    2
+--R       (x  + 1)log(x\|2  + x  + 1) + (- x  - 1)log(- x\|2  + x  + 1)
+--R     + 
+--R          4            +-+           4            +-+           +-+
+--R       (2x  + 2)atan(x\|2  + 1) + (2x  + 2)atan(x\|2  - 1) - 4x\|2
+--R  /
+--R         4       +-+
+--R     (16x  + 16)\|2
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 588
+
+)clear all
+
+--S 589 of 1311
+t0:=x^2/(1+2*x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 589
+
+--S 590 of 1311
+r0:=1/4*x^3/(1+x^4)-1/8*atan(1-x*sqrt(2))/sqrt(2)+1/8*atan(1+x*sqrt(2))/_
+   sqrt(2)+1/16*log(1+x^2-x*sqrt(2))/sqrt(2)-1/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R           4           +-+    2          4             +-+    2
+--R       (- x  - 1)log(x\|2  + x  + 1) + (x  + 1)log(- x\|2  + x  + 1)
+--R     + 
+--R          4            +-+           4            +-+          3 +-+
+--R       (2x  + 2)atan(x\|2  + 1) + (2x  + 2)atan(x\|2  - 1) + 4x \|2
+--R  /
+--R         4       +-+
+--R     (16x  + 16)\|2
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 591
+
+)clear all
+
+--S 592 of 1311
+t0:=1/(1+2*x^4+x^8)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         8     4
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 592
+
+--S 593 of 1311
+r0:=1/4*x/(1+x^4)-3/8*atan(1-x*sqrt(2))/sqrt(2)+3/8*atan(1+x*sqrt(2))/_
+   sqrt(2)-3/16*log(1+x^2-x*sqrt(2))/sqrt(2)+3/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R          4           +-+    2             4             +-+    2
+--R       (3x  + 3)log(x\|2  + x  + 1) + (- 3x  - 3)log(- x\|2  + x  + 1)
+--R     + 
+--R          4            +-+           4            +-+           +-+
+--R       (6x  + 6)atan(x\|2  + 1) + (6x  + 6)atan(x\|2  - 1) + 4x\|2
+--R  /
+--R         4       +-+
+--R     (16x  + 16)\|2
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 594
+
+)clear all
+
+--S 595 of 1311
+t0:=1/(x^2*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         10     6    2
+--R        x   + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 595
+
+--S 596 of 1311
+r0:=(-5/4)/x+1/4/(x*(1+x^4))+5/8*atan(1-x*sqrt(2))/sqrt(2)-_
+   5/8*atan(1+x*sqrt(2))/sqrt(2)-5/16*log(1+x^2-x*sqrt(2))/sqrt(2)+_
+   5/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R          5            +-+    2             5              +-+    2
+--R       (5x  + 5x)log(x\|2  + x  + 1) + (- 5x  - 5x)log(- x\|2  + x  + 1)
+--R     + 
+--R             5              +-+              5              +-+
+--R       (- 10x  - 10x)atan(x\|2  + 1) + (- 10x  - 10x)atan(x\|2  - 1)
+--R     + 
+--R             4       +-+
+--R       (- 20x  - 16)\|2
+--R  /
+--R         5        +-+
+--R     (16x  + 16x)\|2
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 597
+
+)clear all
+
+--S 598 of 1311
+t0:=1/(x^4*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         12     8    4
+--R        x   + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 598
+
+--S 599 of 1311
+r0:=(-7/12)/x^3+1/4/(x^3*(1+x^4))+7/8*atan(1-x*sqrt(2))/sqrt(2)-_
+   7/8*atan(1+x*sqrt(2))/sqrt(2)+7/16*log(1+x^2-x*sqrt(2))/sqrt(2)-_
+   7/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R             7      3       +-+    2            7      3         +-+    2
+--R       (- 21x  - 21x )log(x\|2  + x  + 1) + (21x  + 21x )log(- x\|2  + x  + 1)
+--R     + 
+--R             7      3        +-+              7      3        +-+
+--R       (- 42x  - 42x )atan(x\|2  + 1) + (- 42x  - 42x )atan(x\|2  - 1)
+--R     + 
+--R             4       +-+
+--R       (- 28x  - 16)\|2
+--R  /
+--R         7      3  +-+
+--R     (48x  + 48x )\|2
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)clear all
+
+--S 601 of 1311
+t0:=1/(x^6*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         14     10    6
+--R        x   + 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 601
+
+--S 602 of 1311
+r0:=(-9/20)/x^5+9/4/x+1/4/(x^5*(1+x^4))-9/8*atan(1-x*sqrt(2))/sqrt(2)+_
+   9/8*atan(1+x*sqrt(2))/sqrt(2)+9/16*log(1+x^2-x*sqrt(2))/sqrt(2)-_
+   9/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R             9      5       +-+    2            9      5         +-+    2
+--R       (- 45x  - 45x )log(x\|2  + x  + 1) + (45x  + 45x )log(- x\|2  + x  + 1)
+--R     + 
+--R           9      5        +-+            9      5        +-+
+--R       (90x  + 90x )atan(x\|2  + 1) + (90x  + 90x )atan(x\|2  - 1)
+--R     + 
+--R            8       4       +-+
+--R       (180x  + 144x  - 16)\|2
+--R  /
+--R         9      5  +-+
+--R     (80x  + 80x )\|2
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 603
+
+)clear all
+
+--S 604 of 1311
+t0:=1/(x^8*(1+2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         16     12    8
+--R        x   + 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 604
+
+--S 605 of 1311
+r0:=(-11/28)/x^7+11/12/x^3+1/4/(x^7*(1+x^4))-11/8*atan(1-x*sqrt(2))/_
+   sqrt(2)+11/8*atan(1+x*sqrt(2))/sqrt(2)-11/16*log(1+x^2-x*sqrt(2))/_
+   sqrt(2)+11/16*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R            11       7       +-+    2
+--R       (231x   + 231x )log(x\|2  + x  + 1)
+--R     + 
+--R              11       7         +-+    2             11       7        +-+
+--R       (- 231x   - 231x )log(- x\|2  + x  + 1) + (462x   + 462x )atan(x\|2  + 1)
+--R     + 
+--R            11       7        +-+             8       4       +-+
+--R       (462x   + 462x )atan(x\|2  - 1) + (308x  + 176x  - 48)\|2
+--R  /
+--R          11       7  +-+
+--R     (336x   + 336x )\|2
+--R                                                    Type: Expression(Integer)
+--E 605
+
+--S 606 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 606
+
+)clear all
+
+--S 607 of 1311
+t0:=x^m/(1-2*x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 1311
+--r0:=1/4*x^(1+m)/(1-x^4)+1/4*(3-m)*x^(1+m)*hypergeometric(1,1/4*(1+m),_
+--   1/4*(5+m),x^4)/(1+m)
+--E 608
+
+--S 609 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 609
+
+)clear all
+
+--S 610 of 1311
+t0:=x^9/(1-2*x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 610
+
+--S 611 of 1311
+r0:=3/4*x^2+1/4*x^6/(1-x^4)-3/4*atanh(x^2)
+--R 
+--R
+--R             4            2      6     2
+--R        (- 3x  + 3)atanh(x ) + 2x  - 3x
+--R   (2)  --------------------------------
+--R                       4
+--R                     4x  - 4
+--R                                                    Type: Expression(Integer)
+--E 611
+
+--S 612 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 612
+
+)clear all
+
+--S 613 of 1311
+t0:=x^7/(1-2*x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 613
+
+--S 614 of 1311
+r0:=1/4/(1-x^4)+1/4*log(1-x^4)
+--R 
+--R
+--R          4            4
+--R        (x  - 1)log(- x  + 1) - 1
+--R   (2)  -------------------------
+--R                   4
+--R                 4x  - 4
+--R                                                    Type: Expression(Integer)
+--E 614
+
+--S 615 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 615
+
+)clear all
+
+--S 616 of 1311
+t0:=x^5/(1-2*x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 616
+
+--S 617 of 1311
+r0:=1/4*x^2/(1-x^4)-1/4*atanh(x^2)
+--R 
+--R
+--R            4            2     2
+--R        (- x  + 1)atanh(x ) - x
+--R   (2)  ------------------------
+--R                   4
+--R                 4x  - 4
+--R                                                    Type: Expression(Integer)
+--E 617
+
+--S 618 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 618
+
+)clear all
+
+--S 619 of 1311
+t0:=x^3/(1-2*x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 619
+
+--S 620 of 1311
+r0:=1/4/(1-x^4)
+--R 
+--R
+--R             1
+--R             -
+--R             4
+--R   (2)  - ------
+--R           4
+--R          x  - 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 620
+
+--S 621 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 621
+
+)clear all
+
+--S 622 of 1311
+t0:=x/(1-2*x^4+x^8)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 622
+
+--S 623 of 1311
+r0:=1/4*x^2/(1-x^4)+1/4*atanh(x^2)
+--R 
+--R
+--R          4            2     2
+--R        (x  - 1)atanh(x ) - x
+--R   (2)  ----------------------
+--R                  4
+--R                4x  - 4
+--R                                                    Type: Expression(Integer)
+--E 623
+
+--S 624 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 624
+
+)clear all
+
+--S 625 of 1311
+t0:=1/(x*(1-2*x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         9     5
+--R        x  - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 625
+
+--S 626 of 1311
+r0:=1/4/(1-x^4)-1/2*atanh(1-2*x^4)
+--R 
+--R
+--R           4             4
+--R        (2x  - 2)atanh(2x  - 1) - 1
+--R   (2)  ---------------------------
+--R                    4
+--R                  4x  - 4
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 627
+
+)clear all
+
+--S 628 of 1311
+t0:=1/(x^3*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         11     7    3
+--R        x   - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 628
+
+--S 629 of 1311
+r0:=(-3/4)/x^2+1/4/(x^2*(1-x^4))+3/4*atanh(x^2)
+--R 
+--R
+--R           6     2        2      4
+--R        (3x  - 3x )atanh(x ) - 3x  + 2
+--R   (2)  ------------------------------
+--R                     6     2
+--R                   4x  - 4x
+--R                                                    Type: Expression(Integer)
+--E 629
+
+--S 630 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 630
+
+)clear all
+
+--S 631 of 1311
+t0:=1/(x^5*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         13     9    5
+--R        x   - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 631
+
+--S 632 of 1311
+r0:=(-1/2)/x^4+1/4/(x^4*(1-x^4))-atanh(1-2*x^4)
+--R 
+--R
+--R           8     4         4          4
+--R        (4x  - 4x )atanh(2x  - 1) - 2x  + 1
+--R   (2)  -----------------------------------
+--R                       8     4
+--R                     4x  - 4x
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 633
+
+)clear all
+
+--S 634 of 1311
+t0:=1/(x^7*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         15     11    7
+--R        x   - 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 634
+
+--S 635 of 1311
+r0:=(-5/12)/x^6+(-5/4)/x^2+1/4/(x^6*(1-x^4))+5/4*atanh(x^2)
+--R 
+--R
+--R            10      6        2       8      4
+--R        (15x   - 15x )atanh(x ) - 15x  + 10x  + 2
+--R   (2)  -----------------------------------------
+--R                          10      6
+--R                       12x   - 12x
+--R                                                    Type: Expression(Integer)
+--E 635
+
+--S 636 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 636
+
+)clear all
+
+--S 637 of 1311
+t0:=x^8/(1-2*x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 637
+
+--S 638 of 1311
+r0:=5/4*x+1/4*x^5/(1-x^4)-5/8*atan(x)-5/8*atanh(x)
+--R 
+--R
+--R             4                     4                 5
+--R        (- 5x  + 5)atanh(x) + (- 5x  + 5)atan(x) + 8x  - 10x
+--R   (2)  ----------------------------------------------------
+--R                                 4
+--R                               8x  - 8
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 639
+
+)clear all
+
+--S 640 of 1311
+t0:=x^6/(1-2*x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 640
+
+--S 641 of 1311
+r0:=1/4*x^3/(1-x^4)+3/8*atan(x)-3/8*atanh(x)
+--R 
+--R
+--R             4                   4                 3
+--R        (- 3x  + 3)atanh(x) + (3x  - 3)atan(x) - 2x
+--R   (2)  --------------------------------------------
+--R                             4
+--R                           8x  - 8
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 642
+
+)clear all
+
+--S 643 of 1311
+t0:=x^4/(1-2*x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 643
+
+--S 644 of 1311
+r0:=1/4*x/(1-x^4)-1/8*atan(x)-1/8*atanh(x)
+--R 
+--R
+--R            4                    4
+--R        (- x  + 1)atanh(x) + (- x  + 1)atan(x) - 2x
+--R   (2)  -------------------------------------------
+--R                            4
+--R                          8x  - 8
+--R                                                    Type: Expression(Integer)
+--E 644
+
+--S 645 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 645
+
+)clear all
+
+--S 646 of 1311
+t0:=x^2/(1-2*x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 646
+
+--S 647 of 1311
+r0:=1/4*x^3/(1-x^4)-1/8*atan(x)+1/8*atanh(x)
+--R 
+--R
+--R          4                    4                 3
+--R        (x  - 1)atanh(x) + (- x  + 1)atan(x) - 2x
+--R   (2)  ------------------------------------------
+--R                            4
+--R                          8x  - 8
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 648
+
+)clear all
+
+--S 649 of 1311
+t0:=1/(1-2*x^4+x^8)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         8     4
+--R        x  - 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 649
+
+--S 650 of 1311
+r0:=1/4*x/(1-x^4)+3/8*atan(x)+3/8*atanh(x)
+--R 
+--R
+--R           4                   4
+--R        (3x  - 3)atanh(x) + (3x  - 3)atan(x) - 2x
+--R   (2)  -----------------------------------------
+--R                           4
+--R                         8x  - 8
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 651
+
+)clear all
+
+--S 652 of 1311
+t0:=1/(x^2*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         10     6    2
+--R        x   - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 652
+
+--S 653 of 1311
+r0:=(-5/4)/x+1/4/(x*(1-x^4))-5/8*atan(x)+5/8*atanh(x)
+--R 
+--R
+--R           5                      5                   4
+--R        (5x  - 5x)atanh(x) + (- 5x  + 5x)atan(x) - 10x  + 8
+--R   (2)  ---------------------------------------------------
+--R                                5
+--R                              8x  - 8x
+--R                                                    Type: Expression(Integer)
+--E 653
+
+--S 654 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 654
+
+)clear all
+
+--S 655 of 1311
+t0:=1/(x^4*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         12     8    4
+--R        x   - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 655
+
+--S 656 of 1311
+r0:=(-7/12)/x^3+1/4/(x^3*(1-x^4))+7/8*atan(x)+7/8*atanh(x)
+--R 
+--R
+--R            7      3                7      3              4
+--R        (21x  - 21x )atanh(x) + (21x  - 21x )atan(x) - 14x  + 8
+--R   (2)  -------------------------------------------------------
+--R                                 7      3
+--R                              24x  - 24x
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 657
+
+)clear all
+
+--S 658 of 1311
+t0:=1/(x^6*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         14     10    6
+--R        x   - 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 658
+
+--S 659 of 1311
+r0:=(-9/20)/x^5+(-9/4)/x+1/4/(x^5*(1-x^4))-9/8*atan(x)+9/8*atanh(x)
+--R 
+--R
+--R            9      5                  9      5              8      4
+--R        (45x  - 45x )atanh(x) + (- 45x  + 45x )atan(x) - 90x  + 72x  + 8
+--R   (2)  ----------------------------------------------------------------
+--R                                      9      5
+--R                                   40x  - 40x
+--R                                                    Type: Expression(Integer)
+--E 659
+
+--S 660 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 660
+
+)clear all
+
+--S 661 of 1311
+t0:=1/(x^8*(1-2*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         16     12    8
+--R        x   - 2x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 661
+
+--S 662 of 1311
+r0:=(-11/28)/x^7+(-11/12)/x^3+1/4/(x^7*(1-x^4))+11/8*atan(x)+11/8*atanh(x)
+--R 
+--R
+--R             11       7                 11       7               8      4
+--R        (231x   - 231x )atanh(x) + (231x   - 231x )atan(x) - 154x  + 88x  + 24
+--R   (2)  ----------------------------------------------------------------------
+--R                                        11       7
+--R                                    168x   - 168x
+--R                                                    Type: Expression(Integer)
+--E 662
+
+--S 663 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 663
+
+)clear all
+
+--S 664 of 1311
+t0:=x^m/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 664
+
+--S 665 of 1311
+--r0:=2*c*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),-2*c*x^4/(b-_
+--   sqrt(b^2-4*a*c)))/((1+m)*(b-sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))-_
+--   2*c*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),_
+--   -2*c*x^4/(b+sqrt(b^2-4*a*c)))/((1+m)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))
+--E 665
+
+--S 666 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 666
+
+)clear all
+
+--S 667 of 1311
+t0:=x^11/(a+b*x^4+c*x^8)
+--R 
+--R
+--R               11
+--R              x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 667
+
+--S 668 of 1311
+r0:=1/4*x^4/c-1/8*b*log(a+b*x^4+c*x^8)/c^2-_
+   1/4*(b^2-2*a*c)*atanh((b+2*c*x^4)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                4
+--R                 2          2c x  + b
+--R       (4a c - 2b )atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                          +-----------+
+--R                   8      4            4  |          2
+--R       (- b log(c x  + b x  + a) + 2c x )\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     8c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 668
+
+--S 669 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 669
+
+)clear all
+
+--S 670 of 1311
+t0:=x^9/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                9
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 670
+
+--S 671 of 1311
+r0:=1/2*x^2/c-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R              +-----------+              | +-----------+
+--R              |          2            2  | |          2
+--R         (- b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   + b
+--R      *
+--R                      2 +-+ +-+
+--R                     x \|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R              +-----------+              |   +-----------+
+--R              |          2            2  |   |          2
+--R         (- b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   + b
+--R      *
+--R                     2 +-+ +-+
+--R                    x \|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R        2 +-+ |          2  +-+ |   |          2       | |          2
+--R       x \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 672
+
+)clear all
+
+--S 673 of 1311
+t0:=x^7/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                7
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 673
+
+--S 674 of 1311
+r0:=1/8*log(a+b*x^4+c*x^8)/c+1/4*b*atanh((b+2*c*x^4)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                        4                               +-----------+
+--R                    2c x  + b             8      4      |          2
+--R        2b atanh(--------------) + log(c x  + b x  + a)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  -------------------------------------------------------------
+--R                                  +-----------+
+--R                                  |          2
+--R                               8c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+)clear all
+
+--S 676 of 1311
+t0:=x^5/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                5
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 676
+
+--S 677 of 1311
+r0:=-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(b-sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+_
+   1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   sqrt(b+sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +--------------------+
+--R          |   +-----------+                  2 +-+ +-+
+--R          |   |          2                  x \|2 \|c
+--R       - \|- \|- 4a c + b   + b atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                      |   |          2
+--R                                     \|- \|- 4a c + b   + b
+--R     + 
+--R        +------------------+
+--R        | +-----------+                 2 +-+ +-+
+--R        | |          2                 x \|2 \|c
+--R       \|\|- 4a c + b   + b atan(---------------------)
+--R                                  +------------------+
+--R                                  | +-----------+
+--R                                  | |          2
+--R                                 \|\|- 4a c + b   + b
+--R  /
+--R           +-----------+
+--R       +-+ |          2  +-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 678
+
+)clear all
+
+--S 679 of 1311
+t0:=x^3/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 679
+
+--S 680 of 1311
+r0:=-1/2*atanh((b+2*c*x^4)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                       4
+--R                   2c x  + b
+--R          atanh(--------------)
+--R                 +-----------+
+--R                 |          2
+--R                \|- 4a c + b
+--R   (2)  - ---------------------
+--R               +-----------+
+--R               |          2
+--R             2\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 681
+
+)clear all
+
+--S 682 of 1311
+t0:=x/(a+b*x^4+c*x^8)
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 682
+
+--S 683 of 1311
+r0:=atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)/_
+   (sqrt(2)*sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x^2*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)/(sqrt(2)*sqrt(b^2-4*a*c)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R            +------------------+
+--R            | +-----------+                  2 +-+ +-+
+--R        +-+ | |          2                  x \|2 \|c
+--R       \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                      |   |          2
+--R                                     \|- \|- 4a c + b   + b
+--R     + 
+--R              +--------------------+
+--R              |   +-----------+                 2 +-+ +-+
+--R          +-+ |   |          2                 x \|2 \|c
+--R       - \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                          +------------------+
+--R                                          | +-----------+
+--R                                          | |          2
+--R                                         \|\|- 4a c + b   + b
+--R  /
+--R                        +--------------------+ +------------------+
+--R          +-----------+ |   +-----------+      | +-----------+
+--R      +-+ |          2  |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 683
+
+--S 684 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 684
+
+)clear all
+
+--S 685 of 1311
+t0:=1/(x*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           9      5
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 685
+
+--S 686 of 1311
+r0:=log(x)/a-1/8*log(a+b*x^4+c*x^8)/a+1/4*b*atanh((b+2*c*x^4)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                   4                                             +-----------+
+--R               2c x  + b                8      4                 |          2
+--R   2b atanh(--------------) + (- log(c x  + b x  + a) + 8log(x))\|- 4a c + b
+--R             +-----------+
+--R             |          2
+--R            \|- 4a c + b
+--R   ---------------------------------------------------------------------------
+--R                                    +-----------+
+--R                                    |          2
+--R                                 8a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 687
+
+)clear all
+
+--S 688 of 1311
+t0:=1/(x^3*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R           11      7      3
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 688
+
+--S 689 of 1311
+r0:=(-1/2)/(a*x^2)-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(1+b/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (1-b/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R               +-----------+             | +-----------+
+--R             2 |          2       2  +-+ | |          2
+--R         (- x \|- 4a c + b   - b x )\|c \|\|- 4a c + b   + b
+--R      *
+--R                      2 +-+ +-+
+--R                     x \|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +--------------------+
+--R               +-----------+             |   +-----------+
+--R             2 |          2       2  +-+ |   |          2
+--R         (- x \|- 4a c + b   + b x )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                     2 +-+ +-+
+--R                    x \|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R       - \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R         2 +-+ |          2  |   |          2       | |          2
+--R     2a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 690
+
+)clear all
+
+--S 691 of 1311
+t0:=1/(x^5*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R           13      9      5
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 691
+
+--S 692 of 1311
+r0:=(-1/4)/(a*x^4)-b*log(x)/a^2+1/8*b*log(a+b*x^4+c*x^8)/a^2-_
+   1/4*(b^2-2*a*c)*atanh((b+2*c*x^4)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                  4
+--R                 2  4         2c x  + b
+--R       (4a c - 2b )x atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R           4       8      4            4             |          2
+--R       (b x log(c x  + b x  + a) - 8b x log(x) - 2a)\|- 4a c + b
+--R  /
+--R           +-----------+
+--R       2 4 |          2
+--R     8a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 693
+
+)clear all
+
+--S 694 of 1311
+t0:=x^10/(a+b*x^4+c*x^8)
+--R 
+--R
+--R               10
+--R              x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 694
+
+--S 695 of 1311
+r0:=1/3*x^3/c-1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(7/4)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-1/2*atan(2^(1/4)*c^(1/4)*x/(-b+_
+   sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   c^(7/4)*(-b+sqrt(b^2-4*a*c))^(1/4))+1/2*atanh(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   c^(7/4)*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                         +------------------+
+--R             +-----------+               | +-----------+
+--R             |          2             2 4| |          2
+--R         (3b\|- 4a c + b   - 6a c + 3b )\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                         +--------------------+
+--R             +-----------+               |   +-----------+
+--R             |          2             2 4|   |          2
+--R         (3b\|- 4a c + b   + 6a c - 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                           +------------------+
+--R               +-----------+               | +-----------+
+--R               |          2             2 4| |          2
+--R         (- 3b\|- 4a c + b   + 6a c - 3b )\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+
+--R               +-----------+               |   +-----------+
+--R               |          2             2 4|   |          2
+--R         (- 3b\|- 4a c + b   - 6a c + 3b )\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                                     +--------------------+ +------------------+
+--R                 +-----------+       |   +-----------+      | +-----------+
+--R         3 4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R       2x  \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                                  +--------------------+ +------------------+
+--R              +-----------+       |   +-----------+      | +-----------+
+--R        4+-+3 |          2 4+-+3 4|   |          2      4| |          2
+--R     6c \|2  \|- 4a c + b  \|c   \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 696
+
+)clear all
+
+--S 697 of 1311
+t0:=x^8/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                8
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 697
+
+--S 698 of 1311
+r0:=x/c+1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b-sqrt(b^2-_
+   4*a*c))^(3/4))+1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b-sqrt(b^2-_
+   4*a*c))^(3/4))+1/2*atan(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b+sqrt(b^2-_
+   4*a*c))^(3/4))+1/2*atanh(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                       +------------------+3
+--R            +-----------+              | +-----------+
+--R            |          2            2 4| |          2
+--R         (b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                       +--------------------+3
+--R            +-----------+              |   +-----------+
+--R            |          2            2 4|   |          2
+--R         (b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                       +------------------+3
+--R            +-----------+              | +-----------+
+--R            |          2            2 4| |          2
+--R         (b\|- 4a c + b   - 2a c + b )\|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                       +--------------------+3
+--R            +-----------+              |   +-----------+
+--R            |          2            2 4|   |          2
+--R         (b\|- 4a c + b   + 2a c - b )\|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                                +--------------------+3  +------------------+3
+--R              +-----------+     |   +-----------+        | +-----------+
+--R         4+-+ |          2 4+-+4|   |          2        4| |          2
+--R       2x\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+3  +------------------+3
+--R            +-----------+     |   +-----------+        | +-----------+
+--R       4+-+ |          2 4+-+4|   |          2        4| |          2
+--R     2c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 698
+
+--S 699 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 699
+
+)clear all
+
+--S 700 of 1311
+t0:=x^6/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                6
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 700
+
+--S 701 of 1311
+r0:=-1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (-b-sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))+_
+   1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (-b-sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))+_
+   1/2*atan(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (-b+sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))-_
+   1/2*atanh(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (-b+sqrt(b^2-4*a*c))^(3/4)/(2^(3/4)*c^(3/4)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +--------------------+3
+--R        |   +-----------+                    4+-+4+-+
+--R       4|   |          2                    x\|2 \|c
+--R       \|- \|- 4a c + b   - b  atanh(-----------------------)
+--R                                      +--------------------+
+--R                                      |   +-----------+
+--R                                     4|   |          2
+--R                                     \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+3
+--R          | +-----------+                   4+-+4+-+
+--R         4| |          2                   x\|2 \|c
+--R       - \|\|- 4a c + b   - b  atanh(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R          +--------------------+3
+--R          |   +-----------+                   4+-+4+-+
+--R         4|   |          2                   x\|2 \|c
+--R       - \|- \|- 4a c + b   - b  atan(-----------------------)
+--R                                       +--------------------+
+--R                                       |   +-----------+
+--R                                      4|   |          2
+--R                                      \|- \|- 4a c + b   - b
+--R     + 
+--R        +------------------+3
+--R        | +-----------+                  4+-+4+-+
+--R       4| |          2                  x\|2 \|c
+--R       \|\|- 4a c + b   - b  atan(---------------------)
+--R                                   +------------------+
+--R                                   | +-----------+
+--R                                  4| |          2
+--R                                  \|\|- 4a c + b   - b
+--R  /
+--R            +-----------+
+--R      4+-+3 |          2 4+-+3
+--R     2\|2  \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 702
+
+)clear all
+
+--S 703 of 1311
+t0:=x^4/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 703
+
+--S 704 of 1311
+r0:=1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (-b-sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))+_
+   1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (-b-sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))-_
+   1/2*atan(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (-b+sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))-_
+   1/2*atanh(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*_
+   (-b+sqrt(b^2-4*a*c))^(1/4)/(2^(1/4)*c^(1/4)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R        +--------------------+
+--R        |   +-----------+                   4+-+4+-+
+--R       4|   |          2                   x\|2 \|c
+--R       \|- \|- 4a c + b   - b atanh(-----------------------)
+--R                                     +--------------------+
+--R                                     |   +-----------+
+--R                                    4|   |          2
+--R                                    \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                  4+-+4+-+
+--R         4| |          2                  x\|2 \|c
+--R       - \|\|- 4a c + b   - b atanh(---------------------)
+--R                                     +------------------+
+--R                                     | +-----------+
+--R                                    4| |          2
+--R                                    \|\|- 4a c + b   - b
+--R     + 
+--R        +--------------------+
+--R        |   +-----------+                  4+-+4+-+
+--R       4|   |          2                  x\|2 \|c
+--R       \|- \|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R          +------------------+
+--R          | +-----------+                 4+-+4+-+
+--R         4| |          2                 x\|2 \|c
+--R       - \|\|- 4a c + b   - b atan(---------------------)
+--R                                    +------------------+
+--R                                    | +-----------+
+--R                                   4| |          2
+--R                                   \|\|- 4a c + b   - b
+--R  /
+--R           +-----------+
+--R      4+-+ |          2 4+-+
+--R     2\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 705
+
+)clear all
+
+--S 706 of 1311
+t0:=x^2/(a+b*x^4+c*x^8)
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 706
+
+--S 707 of 1311
+r0:=-c^(1/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))/(2^(3/4)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4)*sqrt(b^2-4*a*c))+c^(1/4)*_
+   atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))/(2^(3/4)*_
+   (-b-sqrt(b^2-4*a*c))^(1/4)*sqrt(b^2-4*a*c))+c^(1/4)*atan(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))/(2^(3/4)*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(1/4))-c^(1/4)*atanh(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))/(2^(3/4)*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R            +------------------+
+--R            | +-----------+                   4+-+4+-+
+--R       4+-+4| |          2                   x\|2 \|c
+--R       \|c \|\|- 4a c + b   - b atanh(-----------------------)
+--R                                       +--------------------+
+--R                                       |   +-----------+
+--R                                      4|   |          2
+--R                                      \|- \|- 4a c + b   - b
+--R     + 
+--R              +--------------------+
+--R              |   +-----------+                  4+-+4+-+
+--R         4+-+4|   |          2                  x\|2 \|c
+--R       - \|c \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                           +------------------+
+--R                                           | +-----------+
+--R                                          4| |          2
+--R                                          \|\|- 4a c + b   - b
+--R     + 
+--R              +------------------+
+--R              | +-----------+                  4+-+4+-+
+--R         4+-+4| |          2                  x\|2 \|c
+--R       - \|c \|\|- 4a c + b   - b atan(-----------------------)
+--R                                        +--------------------+
+--R                                        |   +-----------+
+--R                                       4|   |          2
+--R                                       \|- \|- 4a c + b   - b
+--R     + 
+--R            +--------------------+
+--R            |   +-----------+                 4+-+4+-+
+--R       4+-+4|   |          2                 x\|2 \|c
+--R       \|c \|- \|- 4a c + b   - b atan(---------------------)
+--R                                        +------------------+
+--R                                        | +-----------+
+--R                                       4| |          2
+--R                                       \|\|- 4a c + b   - b
+--R  /
+--R                         +--------------------+ +------------------+
+--R           +-----------+ |   +-----------+      | +-----------+
+--R     4+-+3 |          2 4|   |          2      4| |          2
+--R     \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 708
+
+)clear all
+
+--S 709 of 1311
+t0:=1/(a+b*x^4+c*x^8)
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           8      4
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 709
+
+--S 710 of 1311
+r0:=c^(3/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))/(2^(1/4)*_
+   (-b-sqrt(b^2-4*a*c))^(3/4)*sqrt(b^2-4*a*c))+c^(3/4)*atanh(2^(1/4)*_
+   c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))/(2^(1/4)*(-b-sqrt(b^2-_
+   4*a*c))^(3/4)*sqrt(b^2-4*a*c))-c^(3/4)*atan(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))/(2^(1/4)*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(3/4))-c^(3/4)*atanh(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))/(2^(1/4)*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R              +------------------+3
+--R              | +-----------+                    4+-+4+-+
+--R       4+-+3 4| |          2                    x\|2 \|c
+--R       \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                          +--------------------+
+--R                                          |   +-----------+
+--R                                         4|   |          2
+--R                                         \|- \|- 4a c + b   - b
+--R     + 
+--R                +--------------------+3
+--R                |   +-----------+                   4+-+4+-+
+--R         4+-+3 4|   |          2                   x\|2 \|c
+--R       - \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                              +------------------+
+--R                                              | +-----------+
+--R                                             4| |          2
+--R                                             \|\|- 4a c + b   - b
+--R     + 
+--R              +------------------+3
+--R              | +-----------+                   4+-+4+-+
+--R       4+-+3 4| |          2                   x\|2 \|c
+--R       \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                         +--------------------+
+--R                                         |   +-----------+
+--R                                        4|   |          2
+--R                                        \|- \|- 4a c + b   - b
+--R     + 
+--R                +--------------------+3
+--R                |   +-----------+                  4+-+4+-+
+--R         4+-+3 4|   |          2                  x\|2 \|c
+--R       - \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                             +------------------+
+--R                                             | +-----------+
+--R                                            4| |          2
+--R                                            \|\|- 4a c + b   - b
+--R  /
+--R                        +--------------------+3  +------------------+3
+--R          +-----------+ |   +-----------+        | +-----------+
+--R     4+-+ |          2 4|   |          2        4| |          2
+--R     \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 711
+
+)clear all
+
+--S 712 of 1311
+t0:=1/(x^2*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R           10      6      2
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 712
+
+--S 713 of 1311
+r0:=(-1)/(a*x)-1/2*c^(1/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+1/2*c^(1/4)*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(3/4)*a*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-1/2*c^(1/4)*atan(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(1/4))+1/2*c^(1/4)*atanh(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(1/4))
+--R 
+--R
+--R   (2)
+--R                                     +------------------+
+--R            +-----------+            | +-----------+
+--R            |          2        4+-+4| |          2
+--R         (x\|- 4a c + b   - b x)\|c \|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                     +--------------------+
+--R            +-----------+            |   +-----------+
+--R            |          2        4+-+4|   |          2
+--R         (x\|- 4a c + b   + b x)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                       +------------------+
+--R              +-----------+            | +-----------+
+--R              |          2        4+-+4| |          2
+--R         (- x\|- 4a c + b   + b x)\|c \|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                       +--------------------+
+--R              +-----------+            |   +-----------+
+--R              |          2        4+-+4|   |          2
+--R         (- x\|- 4a c + b   - b x)\|c \|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R       - 2\|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+ +------------------+
+--R                +-----------+ |   +-----------+      | +-----------+
+--R          4+-+3 |          2 4|   |          2      4| |          2
+--R     2a x \|2  \|- 4a c + b  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 714
+
+)clear all
+
+--S 715 of 1311
+t0:=1/(x^4*(a+b*x^4+c*x^8))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R           12      8      4
+--R        c x   + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 715
+
+--S 716 of 1311
+r0:=(-1/3)/(a*x^3)+1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b-sqrt(b^2-_
+   4*a*c))^(3/4))+1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(1-b/sqrt(b^2-4*a*c))/(2^(1/4)*a*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))+1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(3/4))+1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(1+b/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                           +------------------+3
+--R              +-----------+                | +-----------+
+--R            3 |          2        3 4+-+3 4| |          2
+--R         (3x \|- 4a c + b   - 3b x )\|c   \|\|- 4a c + b   - b
+--R      *
+--R                       4+-+4+-+
+--R                      x\|2 \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+3
+--R              +-----------+                |   +-----------+
+--R            3 |          2        3 4+-+3 4|   |          2
+--R         (3x \|- 4a c + b   + 3b x )\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atanh(---------------------)
+--R                +------------------+
+--R                | +-----------+
+--R               4| |          2
+--R               \|\|- 4a c + b   - b
+--R     + 
+--R                                           +------------------+3
+--R              +-----------+                | +-----------+
+--R            3 |          2        3 4+-+3 4| |          2
+--R         (3x \|- 4a c + b   - 3b x )\|c   \|\|- 4a c + b   - b
+--R      *
+--R                      4+-+4+-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R              4|   |          2
+--R              \|- \|- 4a c + b   - b
+--R     + 
+--R                                           +--------------------+3
+--R              +-----------+                |   +-----------+
+--R            3 |          2        3 4+-+3 4|   |          2
+--R         (3x \|- 4a c + b   + 3b x )\|c   \|- \|- 4a c + b   - b
+--R      *
+--R                     4+-+4+-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R              4| |          2
+--R              \|\|- 4a c + b   - b
+--R     + 
+--R                             +--------------------+3  +------------------+3
+--R               +-----------+ |   +-----------+        | +-----------+
+--R          4+-+ |          2 4|   |          2        4| |          2
+--R       - 2\|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R  /
+--R                              +--------------------+3  +------------------+3
+--R                +-----------+ |   +-----------+        | +-----------+
+--R         3 4+-+ |          2 4|   |          2        4| |          2
+--R     6a x  \|2 \|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 717
+
+)clear all
+
+--S 718 of 1311
+t0:=x^m/(1+x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 1311
+--r0:=-2*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),_
+--   -2*x^4/(1+%i*sqrt(3)))/((1+m)*(%i-sqrt(3))*sqrt(3))+2*x^(1+m)*_
+--   hypergeometric(1,1/4*(1+m),1/4*(5+m),-2*x^4/(1-%i*sqrt(3)))/_
+--   ((1+m)*sqrt(3)*(%i+sqrt(3)))
+--E 719
+
+--S 720 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 720
+
+)clear all
+
+--S 721 of 1311
+t0:=x^11/(1+x^4+x^8)
+--R 
+--R
+--R             11
+--R            x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 721
+
+--S 722 of 1311
+r0:=1/4*x^4-1/8*log(1+x^4+x^8)-1/4*atan((1+2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                          4      +-+
+--R           +-+     8    4              (2x  + 1)\|3       4 +-+
+--R        - \|3 log(x  + x  + 1) - 2atan(-------------) + 2x \|3
+--R                                             3
+--R   (2)  -------------------------------------------------------
+--R                                   +-+
+--R                                 8\|3
+--R                                                    Type: Expression(Integer)
+--E 722
+
+--S 723 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 723
+
+)clear all
+
+--S 724 of 1311
+t0:=x^9/(1+x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 724
+
+--S 725 of 1311
+r0:=1/2*x^2+1/2*atan((1-2*x^2)/sqrt(3))/sqrt(3)-_
+   1/2*atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                  2      +-+            2      +-+
+--R               (2x  + 1)\|3          (2x  - 1)\|3      2 +-+
+--R        - atan(-------------) - atan(-------------) + x \|3
+--R                     3                     3
+--R   (2)  ----------------------------------------------------
+--R                                  +-+
+--R                                2\|3
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 726
+
+)clear all
+
+--S 727 of 1311
+t0:=x^7/(1+x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 727
+
+--S 728 of 1311
+r0:=1/8*log(1+x^4+x^8)-1/4*atan((1+2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                        4      +-+
+--R         +-+     8    4              (2x  + 1)\|3
+--R        \|3 log(x  + x  + 1) - 2atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           8\|3
+--R                                                    Type: Expression(Integer)
+--E 728
+
+--S 729 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 729
+
+)clear all
+
+--S 730 of 1311
+t0:=x^5/(1+x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 730
+
+--S 731 of 1311
+r0:=1/8*log(1-x^2+x^4)-1/8*log(1+x^2+x^4)-_
+   1/4*atan((1-2*x^2)/sqrt(3))/sqrt(3)+1/4*atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                2      +-+
+--R          +-+     4    2         +-+     4    2              (2x  + 1)\|3
+--R       - \|3 log(x  + x  + 1) + \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                                                   3
+--R     + 
+--R                2      +-+
+--R             (2x  - 1)\|3
+--R       2atan(-------------)
+--R                   3
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 732
+
+)clear all
+
+--S 733 of 1311
+t0:=x^3/(1+x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 733
+
+--S 734 of 1311
+r0:=1/2*atan((1+2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                4      +-+
+--R             (2x  + 1)\|3
+--R        atan(-------------)
+--R                   3
+--R   (2)  -------------------
+--R                 +-+
+--R               2\|3
+--R                                                    Type: Expression(Integer)
+--E 734
+
+--S 735 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 735
+
+)clear all
+
+--S 736 of 1311
+t0:=x/(1+x^4+x^8)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 736
+
+--S 737 of 1311
+r0:=-1/8*log(1-x^2+x^4)+1/8*log(1+x^2+x^4)-_
+   1/4*atan((1-2*x^2)/sqrt(3))/sqrt(3)+1/4*atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                              2      +-+
+--R        +-+     4    2         +-+     4    2              (2x  + 1)\|3
+--R       \|3 log(x  + x  + 1) - \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                                                 3
+--R     + 
+--R                2      +-+
+--R             (2x  - 1)\|3
+--R       2atan(-------------)
+--R                   3
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 738
+
+)clear all
+
+--S 739 of 1311
+t0:=1/(x*(1+x^4+x^8))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         9    5
+--R        x  + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 739
+
+--S 740 of 1311
+r0:=log(x)-1/8*log(1+x^4+x^8)-1/4*atan((1+2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                        4      +-+
+--R           +-+     8    4          +-+               (2x  + 1)\|3
+--R        - \|3 log(x  + x  + 1) + 8\|3 log(x) - 2atan(-------------)
+--R                                                           3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   8\|3
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 741
+
+)clear all
+
+--S 742 of 1311
+t0:=1/(x^3*(1+x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         11    7    3
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 742
+
+--S 743 of 1311
+r0:=(-1/2)/x^2+1/2*atan((1-2*x^2)/sqrt(3))/sqrt(3)-_
+   1/2*atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                    2      +-+              2      +-+
+--R           2     (2x  + 1)\|3      2     (2x  - 1)\|3      +-+
+--R        - x atan(-------------) - x atan(-------------) - \|3
+--R                       3                       3
+--R   (2)  ------------------------------------------------------
+--R                                  2 +-+
+--R                                2x \|3
+--R                                                    Type: Expression(Integer)
+--E 743
+
+--S 744 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 744
+
+)clear all
+
+--S 745 of 1311
+t0:=1/(x^5*(1+x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         13    9    5
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 745
+
+--S 746 of 1311
+r0:=(-1/4)/x^4-log(x)+1/8*log(1+x^4+x^8)-1/4*atan((1+2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                       4      +-+
+--R    4 +-+     8    4          4 +-+           4     (2x  + 1)\|3       +-+
+--R   x \|3 log(x  + x  + 1) - 8x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                          3
+--R   -----------------------------------------------------------------------
+--R                                     4 +-+
+--R                                   8x \|3
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 747
+
+)clear all
+
+--S 748 of 1311
+t0:=1/(x^7*(1+x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         15    11    7
+--R        x   + x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 748
+
+--S 749 of 1311
+r0:=(-1/6)/x^6+1/2/x^2+1/8*log(1-x^2+x^4)-1/8*log(1+x^2+x^4)-_
+   1/4*atan((1-2*x^2)/sqrt(3))/sqrt(3)+1/4*atan((1+2*x^2)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           6 +-+     4    2          6 +-+     4    2
+--R       - 3x \|3 log(x  + x  + 1) + 3x \|3 log(x  - x  + 1)
+--R     + 
+--R                  2      +-+               2      +-+
+--R         6     (2x  + 1)\|3       6     (2x  - 1)\|3         4      +-+
+--R       6x atan(-------------) + 6x atan(-------------) + (12x  - 4)\|3
+--R                     3                        3
+--R  /
+--R        6 +-+
+--R     24x \|3
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 750
+
+)clear all
+
+--S 751 of 1311
+t0:=x^8/(1+x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 751
+
+--S 752 of 1311
+r0:=x+1/4*atan(-2*x+sqrt(3))-1/4*atan(2*x+sqrt(3))+1/8*log(1-x+x^2)-_
+   1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)+1/8*log(1+x^2-x*sqrt(3))/sqrt(3)-_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R               +-+    2         +-+     2             +-+     2
+--R       - log(x\|3  + x  + 1) - \|3 log(x  + x + 1) + \|3 log(x  - x + 1)
+--R     + 
+--R                                              +-+                   +-+
+--R               +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       log(- x\|3  + x  + 1) - 2atan(------------) - 2atan(------------)
+--R                                           3                     3
+--R     + 
+--R           +-+      +-+           +-+      +-+            +-+
+--R       - 2\|3 atan(\|3  + 2x) + 2\|3 atan(\|3  - 2x) + 8x\|3
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 753
+
+)clear all
+
+--S 754 of 1311
+t0:=x^6/(1+x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 754
+
+--S 755 of 1311
+r0:=-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)+1/2*atan((1+2*x)/sqrt(3))/sqrt(3)+_
+   1/4*log(1+x^2-x*sqrt(3))/sqrt(3)-1/4*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                      +-+
+--R               +-+    2                +-+    2              (2x + 1)\|3
+--R       - log(x\|3  + x  + 1) + log(- x\|3  + x  + 1) + 2atan(------------)
+--R                                                                   3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3
+--R       2atan(------------)
+--R                   3
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 755
+
+--S 756 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 756
+
+)clear all
+
+--S 757 of 1311
+t0:=x^4/(1+x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 757
+
+--S 758 of 1311
+r0:=-1/4*atan(-2*x+sqrt(3))+1/4*atan(2*x+sqrt(3))-1/8*log(1-x+x^2)+_
+   1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)+1/8*log(1+x^2-x*sqrt(3))/sqrt(3)-_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R               +-+    2         +-+     2             +-+     2
+--R       - log(x\|3  + x  + 1) + \|3 log(x  + x + 1) - \|3 log(x  - x + 1)
+--R     + 
+--R                                              +-+                   +-+
+--R               +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       log(- x\|3  + x  + 1) - 2atan(------------) - 2atan(------------)
+--R                                           3                     3
+--R     + 
+--R         +-+      +-+           +-+      +-+
+--R       2\|3 atan(\|3  + 2x) - 2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 758
+
+--S 759 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 759
+
+)clear all
+
+--S 760 of 1311
+t0:=x^2/(1+x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 760
+
+--S 761 of 1311
+r0:=-1/4*atan(-2*x+sqrt(3))+1/4*atan(2*x+sqrt(3))+1/8*log(1-x+x^2)-_
+   1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)-1/8*log(1+x^2-x*sqrt(3))/sqrt(3)+_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R             +-+    2         +-+     2             +-+     2
+--R       log(x\|3  + x  + 1) - \|3 log(x  + x + 1) + \|3 log(x  - x + 1)
+--R     + 
+--R                                                +-+                   +-+
+--R                 +-+    2              (2x + 1)\|3           (2x - 1)\|3
+--R       - log(- x\|3  + x  + 1) - 2atan(------------) - 2atan(------------)
+--R                                             3                     3
+--R     + 
+--R         +-+      +-+           +-+      +-+
+--R       2\|3 atan(\|3  + 2x) - 2\|3 atan(\|3  - 2x)
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 762
+
+)clear all
+
+--S 763 of 1311
+t0:=1/(1+x^4+x^8)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         8    4
+--R        x  + x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 763
+
+--S 764 of 1311
+r0:=-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)+1/2*atan((1+2*x)/sqrt(3))/sqrt(3)-_
+   1/4*log(1+x^2-x*sqrt(3))/sqrt(3)+1/4*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                    +-+
+--R             +-+    2                +-+    2              (2x + 1)\|3
+--R       log(x\|3  + x  + 1) - log(- x\|3  + x  + 1) + 2atan(------------)
+--R                                                                 3
+--R     + 
+--R                      +-+
+--R             (2x - 1)\|3
+--R       2atan(------------)
+--R                   3
+--R  /
+--R       +-+
+--R     4\|3
+--R                                                    Type: Expression(Integer)
+--E 764
+
+--S 765 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 765
+
+)clear all
+
+--S 766 of 1311
+t0:=1/(x^2*(1+x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         10    6    2
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 766
+
+--S 767 of 1311
+r0:=(-1)/x+1/4*atan(-2*x+sqrt(3))-1/4*atan(2*x+sqrt(3))-1/8*log(1-x+x^2)+_
+   1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)-1/8*log(1+x^2-x*sqrt(3))/sqrt(3)+_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R               +-+    2          +-+     2              +-+     2
+--R       x log(x\|3  + x  + 1) + x\|3 log(x  + x + 1) - x\|3 log(x  - x + 1)
+--R     + 
+--R                                                    +-+                     +-+
+--R                   +-+    2                (2x + 1)\|3             (2x - 1)\|3
+--R       - x log(- x\|3  + x  + 1) - 2x atan(------------) - 2x atan(------------)
+--R                                                 3                       3
+--R     + 
+--R            +-+      +-+            +-+      +-+           +-+
+--R       - 2x\|3 atan(\|3  + 2x) + 2x\|3 atan(\|3  - 2x) - 8\|3
+--R  /
+--R        +-+
+--R     8x\|3
+--R                                                    Type: Expression(Integer)
+--E 767
+
+--S 768 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 768
+
+)clear all
+
+--S 769 of 1311
+t0:=1/(x^4*(1+x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         12    8    4
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 769
+
+--S 770 of 1311
+r0:=(-1/3)/x^3+1/4*atan(-2*x+sqrt(3))-1/4*atan(2*x+sqrt(3))+_
+   1/8*log(1-x+x^2)-1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)+1/8*log(1+x^2-x*sqrt(3))/sqrt(3)-_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           3      +-+    2          3 +-+     2
+--R       - 3x log(x\|3  + x  + 1) - 3x \|3 log(x  + x + 1)
+--R     + 
+--R                                                                            +-+
+--R         3 +-+     2              3        +-+    2          3     (2x + 1)\|3
+--R       3x \|3 log(x  - x + 1) + 3x log(- x\|3  + x  + 1) - 6x atan(------------)
+--R                                                                         3
+--R     + 
+--R                          +-+
+--R           3     (2x - 1)\|3       3 +-+      +-+           3 +-+      +-+
+--R       - 6x atan(------------) - 6x \|3 atan(\|3  + 2x) + 6x \|3 atan(\|3  - 2x)
+--R                       3
+--R     + 
+--R           +-+
+--R       - 8\|3
+--R  /
+--R        3 +-+
+--R     24x \|3
+--R                                                    Type: Expression(Integer)
+--E 770
+
+--S 771 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 771
+
+)clear all
+
+--S 772 of 1311
+t0:=1/(x^6*(1+x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         14    10    6
+--R        x   + x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 772
+
+--S 773 of 1311
+r0:=(-1/5)/x^5+1/x-1/2*atan((1-2*x)/sqrt(3))/sqrt(3)+_
+   1/2*atan((1+2*x)/sqrt(3))/sqrt(3)+1/4*log(1+x^2-x*sqrt(3))/sqrt(3)-_
+   1/4*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           5      +-+    2          5        +-+    2
+--R       - 5x log(x\|3  + x  + 1) + 5x log(- x\|3  + x  + 1)
+--R     + 
+--R                         +-+                      +-+
+--R          5     (2x + 1)\|3        5     (2x - 1)\|3         4      +-+
+--R       10x atan(------------) + 10x atan(------------) + (20x  - 4)\|3
+--R                      3                        3
+--R  /
+--R        5 +-+
+--R     20x \|3
+--R                                                    Type: Expression(Integer)
+--E 773
+
+--S 774 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 774
+
+)clear all
+
+--S 775 of 1311
+t0:=1/(x^8*(1+x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         16    12    8
+--R        x   + x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 775
+
+--S 776 of 1311
+r0:=(-1/7)/x^7+1/3/x^3-1/4*atan(-2*x+sqrt(3))+1/4*atan(2*x+sqrt(3))-_
+   1/8*log(1-x+x^2)+1/8*log(1+x+x^2)+1/4*atan((1-2*x)/sqrt(3))/sqrt(3)-_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3)+1/8*log(1+x^2-x*sqrt(3))/sqrt(3)-_
+   1/8*log(1+x^2+x*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R            7      +-+    2           7 +-+     2
+--R       - 21x log(x\|3  + x  + 1) + 21x \|3 log(x  + x + 1)
+--R     + 
+--R            7 +-+     2               7        +-+    2
+--R       - 21x \|3 log(x  - x + 1) + 21x log(- x\|3  + x  + 1)
+--R     + 
+--R                           +-+                      +-+
+--R            7     (2x + 1)\|3        7     (2x - 1)\|3
+--R       - 42x atan(------------) - 42x atan(------------)
+--R                        3                        3
+--R     + 
+--R          7 +-+      +-+            7 +-+      +-+             4       +-+
+--R       42x \|3 atan(\|3  + 2x) - 42x \|3 atan(\|3  - 2x) + (56x  - 24)\|3
+--R  /
+--R         7 +-+
+--R     168x \|3
+--R                                                    Type: Expression(Integer)
+--E 776
+
+--S 777 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 777
+
+)clear all
+
+--S 778 of 1311
+t0:=x^m/(1-x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 778
+
+--S 779 of 1311
+--r0:=-2*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),_
+--   2*x^4/(1+%i*sqrt(3)))/((1+m)*(%i-sqrt(3))*sqrt(3))+2*x^(1+m)*_
+--   hypergeometric(1,1/4*(1+m),1/4*(5+m),2*x^4/(1-%i*sqrt(3)))/_
+--   ((1+m)*sqrt(3)*(%i+sqrt(3)))
+--E 779
+
+--S 780 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 780
+
+)clear all
+
+--S 781 of 1311
+t0:=x^11/(1-x^4+x^8)
+--R 
+--R
+--R             11
+--R            x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 781
+
+--S 782 of 1311
+r0:=1/4*x^4+1/8*log(1-x^4+x^8)+1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                        4      +-+
+--R         +-+     8    4              (2x  - 1)\|3       4 +-+
+--R        \|3 log(x  - x  + 1) - 2atan(-------------) + 2x \|3
+--R                                           3
+--R   (2)  -----------------------------------------------------
+--R                                  +-+
+--R                                8\|3
+--R                                                    Type: Expression(Integer)
+--E 782
+
+--S 783 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 783
+
+)clear all
+
+--S 784 of 1311
+t0:=x^9/(1-x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 784
+
+--S 785 of 1311
+r0:=1/2*x^2+1/4*log(1+x^4-x^2*sqrt(3))/sqrt(3)-_
+   1/4*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R               2 +-+    4               2 +-+    4          2 +-+
+--R        - log(x \|3  + x  + 1) + log(- x \|3  + x  + 1) + 2x \|3
+--R   (2)  ---------------------------------------------------------
+--R                                    +-+
+--R                                  4\|3
+--R                                                    Type: Expression(Integer)
+--E 785
+
+--S 786 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 786
+
+)clear all
+
+--S 787 of 1311
+t0:=x^7/(1-x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 787
+
+--S 788 of 1311
+r0:=1/8*log(1-x^4+x^8)-1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                        4      +-+
+--R         +-+     8    4              (2x  - 1)\|3
+--R        \|3 log(x  - x  + 1) + 2atan(-------------)
+--R                                           3
+--R   (2)  -------------------------------------------
+--R                             +-+
+--R                           8\|3
+--R                                                    Type: Expression(Integer)
+--E 788
+
+--S 789 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 789
+
+)clear all
+
+--S 790 of 1311
+t0:=x^5/(1-x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 790
+
+--S 791 of 1311
+r0:=-1/4*atan(-2*x^2+sqrt(3))+1/4*atan(2*x^2+sqrt(3))+_
+   1/8*log(1+x^4-x^2*sqrt(3))/sqrt(3)-1/8*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R              2 +-+    4               2 +-+    4          +-+      +-+     2
+--R       - log(x \|3  + x  + 1) + log(- x \|3  + x  + 1) + 2\|3 atan(\|3  + 2x )
+--R     + 
+--R           +-+      +-+     2
+--R       - 2\|3 atan(\|3  - 2x )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 791
+
+--S 792 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 792
+
+)clear all
+
+--S 793 of 1311
+t0:=x^3/(1-x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 793
+
+--S 794 of 1311
+r0:=-1/2*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                4      +-+
+--R             (2x  - 1)\|3
+--R        atan(-------------)
+--R                   3
+--R   (2)  -------------------
+--R                 +-+
+--R               2\|3
+--R                                                    Type: Expression(Integer)
+--E 794
+
+--S 795 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 795
+
+)clear all
+
+--S 796 of 1311
+t0:=x/(1-x^4+x^8)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 796
+
+--S 797 of 1311
+r0:=-1/4*atan(-2*x^2+sqrt(3))+1/4*atan(2*x^2+sqrt(3))-_
+   1/8*log(1+x^4-x^2*sqrt(3))/sqrt(3)+1/8*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R            2 +-+    4               2 +-+    4          +-+      +-+     2
+--R       log(x \|3  + x  + 1) - log(- x \|3  + x  + 1) + 2\|3 atan(\|3  + 2x )
+--R     + 
+--R           +-+      +-+     2
+--R       - 2\|3 atan(\|3  - 2x )
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 797
+
+--S 798 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 798
+
+)clear all
+
+--S 799 of 1311
+t0:=1/(x*(1-x^4+x^8))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         9    5
+--R        x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 799
+
+--S 800 of 1311
+r0:=log(x)-1/8*log(1-x^4+x^8)-1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                        4      +-+
+--R           +-+     8    4          +-+               (2x  - 1)\|3
+--R        - \|3 log(x  - x  + 1) + 8\|3 log(x) + 2atan(-------------)
+--R                                                           3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   8\|3
+--R                                                    Type: Expression(Integer)
+--E 800
+
+--S 801 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 801
+
+)clear all
+
+--S 802 of 1311
+t0:=1/(x^3*(1-x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         11    7    3
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 802
+
+--S 803 of 1311
+r0:=(-1/2)/x^2-1/4*log(1+x^4-x^2*sqrt(3))/sqrt(3)+_
+   1/4*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R         2     2 +-+    4         2       2 +-+    4          +-+
+--R        x log(x \|3  + x  + 1) - x log(- x \|3  + x  + 1) - 2\|3
+--R   (2)  ---------------------------------------------------------
+--R                                   2 +-+
+--R                                 4x \|3
+--R                                                    Type: Expression(Integer)
+--E 803
+
+--S 804 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 804
+
+)clear all
+
+--S 805 of 1311
+t0:=1/(x^5*(1-x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         13    9    5
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 805
+
+--S 806 of 1311
+r0:=(-1/4)/x^4+log(x)-1/8*log(1-x^4+x^8)+1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                         4      +-+
+--R      4 +-+     8    4          4 +-+           4     (2x  - 1)\|3       +-+
+--R   - x \|3 log(x  - x  + 1) + 8x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                            3
+--R   -------------------------------------------------------------------------
+--R                                      4 +-+
+--R                                    8x \|3
+--R                                                    Type: Expression(Integer)
+--E 806
+
+--S 807 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 807
+
+)clear all
+
+--S 808 of 1311
+t0:=1/(x^7*(1-x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         15    11    7
+--R        x   - x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 808
+
+--S 809 of 1311
+r0:=(-1/6)/x^6+(-1/2)/x^2+1/4*atan(-2*x^2+sqrt(3))-1/4*atan(2*x^2+sqrt(3))-_
+   1/8*log(1+x^4-x^2*sqrt(3))/sqrt(3)+1/8*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         6     2 +-+    4          6       2 +-+    4
+--R       3x log(x \|3  + x  + 1) - 3x log(- x \|3  + x  + 1)
+--R     + 
+--R           6 +-+      +-+     2      6 +-+      +-+     2          4      +-+
+--R       - 6x \|3 atan(\|3  + 2x ) + 6x \|3 atan(\|3  - 2x ) + (- 12x  - 4)\|3
+--R  /
+--R        6 +-+
+--R     24x \|3
+--R                                                    Type: Expression(Integer)
+--E 809
+
+--S 810 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 810
+
+)clear all
+
+--S 811 of 1311
+t0:=x^8/(1-x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 811
+
+--S 812 of 1311
+r0:=x-1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*sqrt(1/3*(2-_
+   sqrt(3)))+1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))-1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))+1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))+1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*_
+   sqrt(1/3*(2+sqrt(3)))-1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+_
+   sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+1/8*log(1+x^2-x*sqrt(2+sqrt(3)))*_
+   sqrt(1/3*(2+sqrt(3)))-1/8*log(1+x^2+x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R          +--------+      +--------+
+--R          | +-+           | +-+         2
+--R       - \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R        +----------+      +----------+
+--R        |   +-+           |   +-+         2
+--R       \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +----------+        +----------+
+--R          |   +-+             |   +-+         2
+--R       - \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +--------+        +--------+
+--R        | +-+             | +-+         2
+--R       \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R           +----------+
+--R           |   +-+
+--R         2\|- \|3  + 2
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R              +----------+
+--R              |   +-+
+--R            2\|- \|3  + 2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R         +--------+                 +----------+                +--------+
+--R         | +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R           +--------+                 +----------+                +--------+
+--R           | +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R          +-+
+--R       8x\|3
+--R  /
+--R       +-+
+--R     8\|3
+--R                                                    Type: Expression(Integer)
+--E 812
+
+--S 813 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 813
+
+)clear all
+
+--S 814 of 1311
+t0:=x^6/(1-x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 814
+
+--S 815 of 1311
+r0:=-1/2*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)-_
+   1/2*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)+_
+   1/4*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(6)-1/4*log(1+x^2+x*_
+   sqrt(2-sqrt(3)))/sqrt(6)+1/4*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(6)-_
+   1/4*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R               +--------+                   +----------+
+--R               | +-+         2              |   +-+         2
+--R       - log(x\|\|3  + 2  + x  + 1) - log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R               +----------+                     +--------+
+--R               |   +-+         2                | +-+         2
+--R       log(- x\|- \|3  + 2  + x  + 1) + log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R                        +----------+ +--------+                 +----------+
+--R               +-+      |   +-+      | +-+            +-+       |   +-+
+--R       2atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R                           +----------+                +--------+
+--R                  +-+      |   +-+           +-+       | +-+
+--R       - 2atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                         +----------+                +--------+
+--R                +-+      |   +-+           +-+       | +-+
+--R       2atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+
+--R     4\|6
+--R                                                    Type: Expression(Integer)
+--E 815
+
+--S 816 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                              +--------+                            +----------+
+--R         2 +-+    6    2  +-+ | +-+            2 +-+    6    2  +-+ |   +-+
+--R       (x \|3  - x  - x )\|6 \|\|3  + 2  + (- x \|3  - x  - x )\|6 \|- \|3  + 2
+--R     + 
+--R         6
+--R       6x
+--R  /
+--R       8     4
+--R     6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 816
+
+)clear all
+
+--S 817 of 1311
+t0:=x^4/(1-x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 817
+
+--S 818 of 1311
+r0:=-1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))-_
+   1/8*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/8*log(1+x^2+x*sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))-_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))+_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))-_
+   1/8*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R          +-----------+      +--------+
+--R          |    +-+           | +-+         2
+--R       - \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R        +---------+      +----------+
+--R        |  +-+           |   +-+         2
+--R       \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +---------+        +----------+
+--R          |  +-+             |   +-+         2
+--R       - \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +-----------+        +--------+
+--R        |    +-+             | +-+         2
+--R       \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R           +---------+
+--R           |  +-+
+--R         2\|3\|3  + 6
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R              +---------+
+--R              |  +-+
+--R            2\|3\|3  + 6
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R         +-----------+                 +----------+                +--------+
+--R         |    +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R         +-----------+                 +----------+                +--------+
+--R         |    +-+             +-+      |   +-+           +-+       | +-+
+--R     - 2\|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-----------+ +---------+
+--R       |    +-+      |  +-+
+--R     8\|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 818
+
+--S 819 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                   +--------+ +---------+
+--R             4      +-+     4      | +-+      |  +-+
+--R       ((- 3x  - 1)\|3  + 5x  + 2)\|\|3  + 2 \|3\|3  + 6
+--R     + 
+--R                                   +-----------+ +----------+
+--R             4      +-+     4      |    +-+      |   +-+          4
+--R       ((- 3x  - 1)\|3  - 5x  - 2)\|- 3\|3  + 6 \|- \|3  + 2  + 6x
+--R  /
+--R       8     4
+--R     6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 819
+
+)clear all
+
+--S 820 of 1311
+t0:=x^2/(1-x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 820
+
+--S 821 of 1311
+r0:=-1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/8*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))-_
+   1/8*log(1+x^2+x*sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+_
+   1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))-_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))-_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))+_
+   1/8*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R        +-----------+      +--------+
+--R        |    +-+           | +-+         2
+--R       \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R          +---------+      +----------+
+--R          |  +-+           |   +-+         2
+--R       - \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R        +---------+        +----------+
+--R        |  +-+             |   +-+         2
+--R       \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R          +-----------+        +--------+
+--R          |    +-+             | +-+         2
+--R       - \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R           +---------+
+--R           |  +-+
+--R         2\|3\|3  + 6
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R              +---------+
+--R              |  +-+
+--R            2\|3\|3  + 6
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R         +-----------+                 +----------+                +--------+
+--R         |    +-+             +-+      |   +-+           +-+       | +-+
+--R       2\|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R         +-----------+                 +----------+                +--------+
+--R         |    +-+             +-+      |   +-+           +-+       | +-+
+--R     - 2\|- 3\|3  + 6 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-----------+ +---------+
+--R       |    +-+      |  +-+
+--R     8\|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 821
+
+--S 822 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                      +--------+ +---------+
+--R            6     2  +-+     6     2  | +-+      |  +-+
+--R       ((- x  - 3x )\|3  + 2x  + 5x )\|\|3  + 2 \|3\|3  + 6
+--R     + 
+--R                                      +-----------+ +----------+
+--R            6     2  +-+     6     2  |    +-+      |   +-+          2
+--R       ((- x  - 3x )\|3  - 2x  - 5x )\|- 3\|3  + 6 \|- \|3  + 2  + 6x
+--R  /
+--R       8     4
+--R     6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 822
+
+)clear all
+
+--S 823 of 1311
+t0:=1/(1-x^4+x^8)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         8    4
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 823
+
+--S 824 of 1311
+r0:=-1/2*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)-_
+   1/2*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/4*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(6)+1/4*log(1+x^2+x*_
+   sqrt(2-sqrt(3)))/sqrt(6)-1/4*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/4*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R             +--------+                   +----------+
+--R             | +-+         2              |   +-+         2
+--R       log(x\|\|3  + 2  + x  + 1) + log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                 +----------+                     +--------+
+--R                 |   +-+         2                | +-+         2
+--R       - log(- x\|- \|3  + 2  + x  + 1) - log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R                        +----------+ +--------+                 +----------+
+--R               +-+      |   +-+      | +-+            +-+       |   +-+
+--R       2atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R            2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R                           +----------+                +--------+
+--R                  +-+      |   +-+           +-+       | +-+
+--R       - 2atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                         +----------+                +--------+
+--R                +-+      |   +-+           +-+       | +-+
+--R       2atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R  /
+--R       +-+
+--R     4\|6
+--R                                                    Type: Expression(Integer)
+--E 824
+
+--S 825 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                         +--------+                           +----------+
+--R     4 +-+    4      +-+ | +-+            4 +-+    4      +-+ |   +-+
+--R   (x \|3  - x  - 1)\|6 \|\|3  + 2  + (- x \|3  - x  - 1)\|6 \|- \|3  + 2  + 6
+--R   ---------------------------------------------------------------------------
+--R                                    8     4
+--R                                  6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 825
+
+)clear all
+
+--S 826 of 1311
+t0:=1/(x^2*(1-x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         10    6    2
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 826
+
+--S 827 of 1311
+r0:=(-1)/x-1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))+1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-_
+   sqrt(3)))*sqrt(1/3*(2-sqrt(3)))+1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))-1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*sqrt(1/3*_
+   (2-sqrt(3)))+1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*_
+   sqrt(1/3*(2+sqrt(3)))-1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+_
+   sqrt(3)))*sqrt(1/3*(2+sqrt(3)))-1/8*log(1+x^2-x*sqrt(2+sqrt(3)))*_
+   sqrt(1/3*(2+sqrt(3)))+1/8*log(1+x^2+x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R         +--------+      +--------+
+--R         | +-+           | +-+         2
+--R       x\|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R           +----------+      +----------+
+--R           |   +-+           |   +-+         2
+--R       - x\|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R         +----------+        +----------+
+--R         |   +-+             |   +-+         2
+--R       x\|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R           +--------+        +--------+
+--R           | +-+             | +-+         2
+--R       - x\|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R            +----------+
+--R            |   +-+
+--R         2x\|- \|3  + 2
+--R      *
+--R                         +----------+ +--------+                 +----------+
+--R                +-+      |   +-+      | +-+            +-+       |   +-+
+--R         atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R               +----------+
+--R               |   +-+
+--R            2x\|- \|3  + 2
+--R         *
+--R            atan
+--R                          +----------+ +--------+                   +----------+
+--R                 +-+      |   +-+      | +-+              +-+       |   +-+
+--R               (\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2
+--R     + 
+--R          +--------+                 +----------+                +--------+
+--R          | +-+             +-+      |   +-+           +-+       | +-+
+--R       2x\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R            +--------+                 +----------+                +--------+
+--R            | +-+             +-+      |   +-+           +-+       | +-+
+--R       - 2x\|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R           +-+
+--R       - 8\|3
+--R  /
+--R        +-+
+--R     8x\|3
+--R                                                    Type: Expression(Integer)
+--E 827
+
+--S 828 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 828
+
+)clear all
+
+--S 829 of 1311
+t0:=1/(x^4*(1-x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         12    8    4
+--R        x   - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 829
+
+--S 830 of 1311
+r0:=(-1/3)/x^3+1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))-1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))+1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))-1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*_
+   sqrt(1/3*(2-sqrt(3)))-1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+_
+   sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+1/4*atan((2*x+sqrt(2-sqrt(3)))/_
+   sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))-1/8*log(1+x^2-x*sqrt(2+_
+   sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+1/8*log(1+x^2+x*sqrt(2+sqrt(3)))*_
+   sqrt(1/3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R           +--------+      +--------+
+--R         3 | +-+           | +-+         2
+--R       3x \|\|3  + 2 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R             +----------+      +----------+
+--R           3 |   +-+           |   +-+         2
+--R       - 3x \|- \|3  + 2 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R           +----------+        +----------+
+--R         3 |   +-+             |   +-+         2
+--R       3x \|- \|3  + 2 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R             +--------+        +--------+
+--R           3 | +-+             | +-+         2
+--R       - 3x \|\|3  + 2 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R                +----------+
+--R              3 |   +-+
+--R            6x \|- \|3  + 2
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R             +----------+
+--R           3 |   +-+
+--R         6x \|- \|3  + 2
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R             +--------+                 +----------+                +--------+
+--R           3 | +-+             +-+      |   +-+           +-+       | +-+
+--R       - 6x \|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R           +--------+                 +----------+                +--------+
+--R         3 | +-+             +-+      |   +-+           +-+       | +-+
+--R       6x \|\|3  + 2 atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R           +-+
+--R       - 8\|3
+--R  /
+--R        3 +-+
+--R     24x \|3
+--R                                                    Type: Expression(Integer)
+--E 830
+
+--S 831 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 831
+
+)clear all
+
+--S 832 of 1311
+t0:=1/(x^6*(1-x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         14    10    6
+--R        x   - x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 832
+
+--S 833 of 1311
+r0:=(-1/5)/x^5+(-1)/x+1/2*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/_
+   sqrt(6)-1/2*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/2*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/2*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/4*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(6)+1/4*log(1+x^2+x*_
+   sqrt(2-sqrt(3)))/sqrt(6)-1/4*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/4*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R                +--------+                      +----------+
+--R         5      | +-+         2          5      |   +-+         2
+--R       5x log(x\|\|3  + 2  + x  + 1) + 5x log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R                    +----------+                        +--------+
+--R           5        |   +-+         2          5        | +-+         2
+--R       - 5x log(- x\|- \|3  + 2  + x  + 1) - 5x log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R               5
+--R            10x
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R            5
+--R         10x
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R                            +----------+                +--------+
+--R          5        +-+      |   +-+           +-+       | +-+
+--R       10x atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R                              +----------+                +--------+
+--R            5        +-+      |   +-+           +-+       | +-+
+--R       - 10x atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R             4      +-+
+--R       (- 20x  - 4)\|6
+--R  /
+--R        5 +-+
+--R     20x \|6
+--R                                                    Type: Expression(Integer)
+--E 833
+
+--S 834 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                +--------+                          +----------+
+--R           2 +-+    6    2  +-+ | +-+          2 +-+    6    2  +-+ |   +-+
+--R       (- x \|3  + x  + x )\|6 \|\|3  + 2  + (x \|3  + x  + x )\|6 \|- \|3  + 2
+--R     + 
+--R           6
+--R       - 6x
+--R  /
+--R       8     4
+--R     6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 834
+
+)clear all
+
+--S 835 of 1311
+t0:=1/(x^8*(1-x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         16    12    8
+--R        x   - x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 835
+
+--S 836 of 1311
+r0:=(-1/7)/x^7+(-1/3)/x^3+1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-_
+   sqrt(3)))/sqrt(3*(2-sqrt(3)))-1/4*atan((2*x+sqrt(2+sqrt(3)))/_
+   sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))+1/8*log(1+x^2-x*sqrt(2-_
+   sqrt(3)))/sqrt(3*(2-sqrt(3)))-1/8*log(1+x^2+x*sqrt(2-sqrt(3)))/_
+   sqrt(3*(2-sqrt(3)))-1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/_
+   sqrt(3*(2+sqrt(3)))+1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/_
+   sqrt(3*(2+sqrt(3)))-1/8*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(3*(2+_
+   sqrt(3)))+1/8*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))
+--R 
+--R
+--R   (2)
+--R            +-----------+      +--------+
+--R          7 |    +-+           | +-+         2
+--R       21x \|- 3\|3  + 6 log(x\|\|3  + 2  + x  + 1)
+--R     + 
+--R              +---------+      +----------+
+--R            7 |  +-+           |   +-+         2
+--R       - 21x \|3\|3  + 6 log(x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R            +---------+        +----------+
+--R          7 |  +-+             |   +-+         2
+--R       21x \|3\|3  + 6 log(- x\|- \|3  + 2  + x  + 1)
+--R     + 
+--R              +-----------+        +--------+
+--R            7 |    +-+             | +-+         2
+--R       - 21x \|- 3\|3  + 6 log(- x\|\|3  + 2  + x  + 1)
+--R     + 
+--R       -
+--R                 +---------+
+--R               7 |  +-+
+--R            42x \|3\|3  + 6
+--R         *
+--R                          +----------+ +--------+                 +----------+
+--R                 +-+      |   +-+      | +-+            +-+       |   +-+
+--R          atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (2x\|3  + 4x)\|- \|3  + 2 )
+--R     + 
+--R              +---------+
+--R            7 |  +-+
+--R         42x \|3\|3  + 6
+--R      *
+--R                       +----------+ +--------+                   +----------+
+--R              +-+      |   +-+      | +-+              +-+       |   +-+
+--R       atan((\|3  + 2)\|- \|3  + 2 \|\|3  + 2  + (- 2x\|3  - 4x)\|- \|3  + 2 )
+--R     + 
+--R       -
+--R                 +-----------+
+--R               7 |    +-+
+--R            42x \|- 3\|3  + 6
+--R         *
+--R                             +----------+                +--------+
+--R                    +-+      |   +-+           +-+       | +-+
+--R            atan(((\|3  - 2)\|- \|3  + 2  + 2x\|3  - 4x)\|\|3  + 2 )
+--R     + 
+--R              +-----------+
+--R            7 |    +-+
+--R         42x \|- 3\|3  + 6
+--R      *
+--R                          +----------+                +--------+
+--R                 +-+      |   +-+           +-+       | +-+
+--R         atan(((\|3  - 2)\|- \|3  + 2  - 2x\|3  + 4x)\|\|3  + 2 )
+--R     + 
+--R                     +-----------+ +---------+
+--R             4       |    +-+      |  +-+
+--R       (- 56x  - 24)\|- 3\|3  + 6 \|3\|3  + 6
+--R  /
+--R           +-----------+ +---------+
+--R         7 |    +-+      |  +-+
+--R     168x \|- 3\|3  + 6 \|3\|3  + 6
+--R                                                    Type: Expression(Integer)
+--E 836
+
+--S 837 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                 +--------+ +---------+
+--R           4      +-+     4      | +-+      |  +-+
+--R       ((3x  + 1)\|3  - 5x  - 2)\|\|3  + 2 \|3\|3  + 6
+--R     + 
+--R                                 +-----------+ +----------+
+--R           4      +-+     4      |    +-+      |   +-+          4
+--R       ((3x  + 1)\|3  + 5x  + 2)\|- 3\|3  + 6 \|- \|3  + 2  - 6x
+--R  /
+--R       8     4
+--R     6x  - 6x  + 6
+--R                                                    Type: Expression(Integer)
+--E 837
+
+)clear all
+
+--S 838 of 1311
+t0:=x^m/(1+3*x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                                    Type: Expression(Integer)
+--E 838
+
+--S 839 of 1311
+--r0:=2*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),-2*x^4/(3-sqrt(5)))/_
+--   ((1+m)*(3-sqrt(5))*sqrt(5))-2*x^(1+m)*hypergeometric(1,1/4*(1+m),_
+--   1/4*(5+m),-2*x^4/(3+sqrt(5)))/((1+m)*sqrt(5)*(3+sqrt(5)))
+--E 839
+
+--S 840 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 840
+
+)clear all
+
+--S 841 of 1311
+t0:=x^11/(1+3*x^4+x^8)
+--R 
+--R
+--R              11
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 841
+
+--S 842 of 1311
+r0:=1/4*x^4-1/40*log(3+2*x^4-sqrt(5))*(15-7*sqrt(5))-_
+   1/40*log(3+2*x^4+sqrt(5))*(15+7*sqrt(5))
+--R 
+--R
+--R   (2)
+--R        +-+           +-+     4           +-+             +-+     4           4
+--R   (- 7\|5  - 15)log(\|5  + 2x  + 3) + (7\|5  - 15)log(- \|5  + 2x  + 3) + 10x
+--R   ----------------------------------------------------------------------------
+--R                                        40
+--R                                                    Type: Expression(Integer)
+--E 842
+
+--S 843 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 843
+
+)clear all
+
+--S 844 of 1311
+t0:=x^9/(1+3*x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 844
+
+--S 845 of 1311
+r0:=1/2*x^2+1/2*atan(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/5*(9-4*sqrt(5)))-_
+   1/2*atan(x^2*sqrt(2/(3+sqrt(5))))*sqrt(1/5*(9+4*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                             +--------+                        +----------+
+--R        +-----------+      2 | +-+          +---------+      2 |   +-+
+--R        |    +-+          x \|\|5  + 3      |  +-+          x \|- \|5  + 3
+--R       \|- 4\|5  + 9 atan(-------------) - \|4\|5  + 9 atan(---------------)
+--R                                +-+                                +-+
+--R                               \|2                                \|2
+--R     + 
+--R        2 +-+
+--R       x \|5
+--R  /
+--R       +-+
+--R     2\|5
+--R                                                    Type: Expression(Integer)
+--E 845
+
+--S 846 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                      +----------+ +---------+
+--R           5       +-+ +-+     5 +-+  |   +-+      |  +-+
+--R       ((3x  + 2x)\|2 \|5  + 5x \|2 )\|- \|5  + 3 \|4\|5  + 9
+--R     + 
+--R                                        +-----------+ +--------+
+--R             5       +-+ +-+     5 +-+  |    +-+      | +-+           5
+--R       ((- 3x  - 2x)\|2 \|5  + 5x \|2 )\|- 4\|5  + 9 \|\|5  + 3  - 60x  - 20x
+--R  /
+--R        8      4
+--R     20x  + 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 846
+
+)clear all
+
+--S 847 of 1311
+t0:=x^7/(1+3*x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 847
+
+--S 848 of 1311
+r0:=1/40*log(3+2*x^4-sqrt(5))*(5-3*sqrt(5))+1/40*log(3+2*x^4+sqrt(5))*_
+   (5+3*sqrt(5))
+--R 
+--R
+--R           +-+          +-+     4             +-+            +-+     4
+--R        (3\|5  + 5)log(\|5  + 2x  + 3) + (- 3\|5  + 5)log(- \|5  + 2x  + 3)
+--R   (2)  -------------------------------------------------------------------
+--R                                         40
+--R                                                    Type: Expression(Integer)
+--E 848
+
+--S 849 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 849
+
+)clear all
+
+--S 850 of 1311
+t0:=x^5/(1+3*x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 850
+
+--S 851 of 1311
+r0:=-1/2*atan(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/10*(3-sqrt(5)))+_
+   1/2*atan(x^2*sqrt(2/(3+sqrt(5))))*sqrt(1/10*(3+sqrt(5)))
+--R 
+--R
+--R                               +--------+                       +----------+
+--R           +----------+      2 | +-+          +--------+      2 |   +-+
+--R           |   +-+          x \|\|5  + 3      | +-+          x \|- \|5  + 3
+--R        - \|- \|5  + 3 atan(-------------) + \|\|5  + 3 atan(---------------)
+--R                                  +-+                               +-+
+--R                                 \|2                               \|2
+--R   (2)  ---------------------------------------------------------------------
+--R                                          +--+
+--R                                        2\|10
+--R                                                    Type: Expression(Integer)
+--E 851
+
+--S 852 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                          +----------+ +--------+
+--R           5 +-+ +-+ +--+ |   +-+      | +-+           5
+--R        - x \|2 \|5 \|10 \|- \|5  + 3 \|\|5  + 3  + 20x
+--R   (3)  ------------------------------------------------
+--R                           8      4
+--R                        20x  + 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 852
+
+)clear all
+
+--S 853 of 1311
+t0:=x^3/(1+3*x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 853
+
+--S 854 of 1311
+r0:=-1/2*atanh((3+2*x^4)/sqrt(5))/sqrt(5)
+--R 
+--R
+--R                   4      +-+
+--R                (2x  + 3)\|5
+--R          atanh(-------------)
+--R                      5
+--R   (2)  - --------------------
+--R                    +-+
+--R                  2\|5
+--R                                                    Type: Expression(Integer)
+--E 854
+
+--S 855 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 855
+
+)clear all
+
+--S 856 of 1311
+t0:=x/(1+3*x^4+x^8)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 856
+
+--S 857 of 1311
+r0:=1/2*atan(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/10*(3+sqrt(5)))-_
+   atan(x^2*sqrt(2/(3+sqrt(5))))/sqrt(10*(3+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                    +--------+                  +----------+
+--R    +--------+ +-----------+      2 | +-+                     2 |   +-+
+--R    | +-+      |   +-+           x \|\|5  + 3       +--+     x \|- \|5  + 3
+--R   \|\|5  + 3 \|10\|5  + 30 atan(-------------) - 2\|10 atan(---------------)
+--R                                       +-+                          +-+
+--R                                      \|2                          \|2
+--R   --------------------------------------------------------------------------
+--R                                     +-----------+
+--R                                +--+ |   +-+
+--R                              2\|10 \|10\|5  + 30
+--R                                                    Type: Expression(Integer)
+--E 857
+
+--S 858 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                     +----------+ +-----------+
+--R         5 +-+ +-+      5       +-+  |   +-+      |   +-+
+--R       (x \|2 \|5  + (3x  + 2x)\|2 )\|- \|5  + 3 \|10\|5  + 30
+--R     + 
+--R             5       +-+ +-+        5        +-+  +--+       +-+
+--R       ((- 2x  - 6x)\|2 \|5  + (- 6x  - 14x)\|2 )\|10  + 20x\|5  + 60x
+--R  /
+--R         8      4       +-+      8       4
+--R     (20x  + 60x  + 20)\|5  + 60x  + 180x  + 60
+--R                                                    Type: Expression(Integer)
+--E 858
+
+)clear all
+
+--S 859 of 1311
+t0:=1/(x*(1+3*x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         9     5
+--R        x  + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 859
+
+--S 860 of 1311
+r0:=log(x)-1/40*log(3+2*x^4+sqrt(5))*(5-3*sqrt(5))-_
+   1/40*log(3+2*x^4-sqrt(5))*(5+3*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          +-+          +-+     4
+--R       (3\|5  - 5)log(\|5  + 2x  + 3) + 40log(x)
+--R     + 
+--R            +-+            +-+     4
+--R       (- 3\|5  - 5)log(- \|5  + 2x  + 3)
+--R  /
+--R     40
+--R                                                    Type: Expression(Integer)
+--E 860
+
+--S 861 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 861
+
+)clear all
+
+--S 862 of 1311
+t0:=1/(x^3*(1+3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         11     7    3
+--R        x   + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 862
+
+--S 863 of 1311
+r0:=(-1/2)/x^2-1/4*atan(x^2*sqrt(1/2*(3+sqrt(5))))*(3+sqrt(5))^(3/2)/_
+   sqrt(10)+1/2*atan(x^2*sqrt(2/(3+sqrt(5))))*sqrt(1/5*(9-4*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                           +--------+
+--R                         +--------+      2 | +-+
+--R            2 +-+     2  | +-+          x \|\|5  + 3
+--R       (- 3x \|5  - 5x )\|\|5  + 3 atan(-------------)
+--R                                              +-+
+--R                                             \|2
+--R     + 
+--R                                     +----------+
+--R                +-----------+      2 |   +-+
+--R         2 +--+ |    +-+          x \|- \|5  + 3       +-+ +--+
+--R       2x \|10 \|- 4\|5  + 9 atan(---------------) - 2\|5 \|10
+--R                                         +-+
+--R                                        \|2
+--R  /
+--R       2 +-+ +--+
+--R     4x \|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 863
+
+--S 864 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                        +-----------+ +----------+
+--R             5       +-+ +-+     5 +-+  |    +-+      |   +-+
+--R       ((- 3x  - 2x)\|2 \|5  - 5x \|2 )\|- 4\|5  + 9 \|- \|5  + 3
+--R     + 
+--R          5       +-+ +-+      5       +-+  +--+      5
+--R       ((x  + 3x)\|2 \|5  + (3x  + 7x)\|2 )\|10  - 20x  - 60x
+--R  /
+--R        8      4
+--R     20x  + 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 864
+
+)clear all
+
+--S 865 of 1311
+t0:=1/(x^5*(1+3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         13     9    5
+--R        x   + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 865
+
+--S 866 of 1311
+r0:=(-1/4)/x^4-3*log(x)+1/40*log(3+2*x^4+sqrt(5))*(15-7*sqrt(5))+_
+   1/40*log(3+2*x^4-sqrt(5))*(15+7*sqrt(5))
+--R 
+--R
+--R   (2)
+--R            4 +-+      4      +-+     4            4
+--R       (- 7x \|5  + 15x )log(\|5  + 2x  + 3) - 120x log(x)
+--R     + 
+--R          4 +-+      4        +-+     4
+--R       (7x \|5  + 15x )log(- \|5  + 2x  + 3) - 10
+--R  /
+--R        4
+--R     40x
+--R                                                    Type: Expression(Integer)
+--E 866
+
+--S 867 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 867
+
+)clear all
+
+--S 868 of 1311
+t0:=1/(x^7*(1+3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         15     11    7
+--R        x   + 3x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 868
+
+--S 869 of 1311
+r0:=(-1/6)/x^6+3/2/x^2-1/2*atan(x^2*sqrt(2/(3+sqrt(5))))*_
+   sqrt(1/10*(123-55*sqrt(5)))+1/2*atan(x^2*sqrt(1/2*(3+sqrt(5))))*_
+   sqrt(1/10*(123+55*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                 +--------+
+--R           +------------+      2 | +-+
+--R         6 |   +-+            x \|\|5  + 3
+--R       3x \|55\|5  + 123 atan(-------------)
+--R                                    +-+
+--R                                   \|2
+--R     + 
+--R                                     +----------+
+--R             +--------------+      2 |   +-+
+--R           6 |     +-+            x \|- \|5  + 3        4      +--+
+--R       - 3x \|- 55\|5  + 123 atan(---------------) + (9x  - 1)\|10
+--R                                         +-+
+--R                                        \|2
+--R  /
+--R       6 +--+
+--R     6x \|10
+--R                                                    Type: Expression(Integer)
+--E 869
+
+--S 870 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                            +--------+ +------------+
+--R         5 +-+ +-+        5       +-+  +--+ | +-+      |   +-+
+--R       (x \|2 \|5  + (- 3x  - 2x)\|2 )\|10 \|\|5  + 3 \|55\|5  + 123
+--R     + 
+--R                                          +--------------+ +----------+
+--R         5 +-+ +-+      5       +-+  +--+ |     +-+        |   +-+            5
+--R       (x \|2 \|5  + (3x  + 2x)\|2 )\|10 \|- 55\|5  + 123 \|- \|5  + 3  + 120x
+--R     + 
+--R       320x
+--R  /
+--R        8       4
+--R     40x  + 120x  + 40
+--R                                                    Type: Expression(Integer)
+--E 870
+
+)clear all
+
+--S 871 of 1311
+t0:=x^8/(1+3*x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 871
+
+--S 872 of 1311
+r0:=x-1/2*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))*(123-55*sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))+1/2*atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))*_
+   (123-55*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-1/4*log(2*x^2-2*2^(1/4)*_
+   x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*(123-55*sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))+1/4*log(2*x^2+2*2^(1/4)*x*(3-sqrt(5))^(1/4)+_
+   sqrt(2*(3-sqrt(5))))*(123-55*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+_
+   1/2*atan(1-2^(3/4)*x/(3+sqrt(5))^(1/4))*(123+55*sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))-1/2*atan(1+2^(3/4)*x/(3+sqrt(5))^(1/4))*_
+   (123+55*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+1/4*log(2*x^2-2*2^(1/4)*_
+   x*(3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*(123+55*sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))-1/4*log(2*x^2+2*2^(1/4)*x*(3+sqrt(5))^(1/4)+_
+   sqrt(2*(3+sqrt(5))))*(123+55*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          +------------+     +---------+          +--------+
+--R         4|   +-+            |  +-+          4+-+4| +-+          2
+--R       - \|55\|5  + 123 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +------------+     +---------+          +--------+
+--R       4|   +-+            |  +-+          4+-+4| +-+          2
+--R       \|55\|5  + 123 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +--------------+           +----------+    +-----------+
+--R       4|     +-+             4+-+4|   +-+         |    +-+          2
+--R       \|- 55\|5  + 123 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R          +--------------+             +----------+    +-----------+
+--R         4|     +-+               4+-+4|   +-+         |    +-+          2
+--R       - \|- 55\|5  + 123 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                     +--------+3
+--R         +------------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       2\|55\|5  + 123 atan(----------------------------------------)
+--R                                                4
+--R     + 
+--R                                                     +--------+3
+--R         +------------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       2\|55\|5  + 123 atan(----------------------------------------)
+--R                                                4
+--R     + 
+--R                                                       +----------+3
+--R         +--------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|     +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       2\|- 55\|5  + 123 atan(------------------------------------------)
+--R                                                   4
+--R     + 
+--R                                                       +----------+3
+--R         +--------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4|     +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       2\|- 55\|5  + 123 atan(------------------------------------------)
+--R                                                   4
+--R     + 
+--R          4+-+3 +-+
+--R       4x \|2  \|5
+--R  /
+--R      4+-+3 +-+
+--R     4\|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 872
+
+--S 873 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                            +----------+2
+--R                       8     4  +-+      4 4|   +-+
+--R                   ((4x  + 6x )\|5  - 10x )\|- \|5  + 3
+--R                 + 
+--R                                                       +-----------+
+--R                         8     4 4+-+2 +-+     4 4+-+2 |    +-+
+--R                   ((- 2x  - 3x )\|2  \|5  + 5x  \|2 )\|- 2\|5  + 6
+--R                 + 
+--R                        10     6     2 4+-+2 +-+       6      2 4+-+2
+--R                   (- 2x   - 6x  - 7x )\|2  \|5  + (10x  + 15x )\|2
+--R              *
+--R                  +--------+3
+--R                 4| +-+
+--R                 \|\|5  + 3
+--R             + 
+--R                                                              +----------+2
+--R                       10      6     2 4+-+2 +-+      6 4+-+24|   +-+
+--R                   ((6x   + 12x  + 2x )\|2  \|5  - 10x  \|2 )\|- \|5  + 3
+--R                 + 
+--R                                                      +-----------+
+--R                         10      6     2  +-+      6  |    +-+
+--R                   ((- 6x   - 12x  - 2x )\|5  + 10x )\|- 2\|5  + 6
+--R                 + 
+--R                        12      8      4      +-+      8      4
+--R                   (- 6x   - 21x  - 25x  - 3)\|5  + 25x  + 45x  + 5
+--R              *
+--R                  +--------+
+--R                 4| +-+
+--R                 \|\|5  + 3
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|5  + 6
+--R         + 
+--R                                           +----------+2
+--R                     10     2  +-+      6 4|   +-+
+--R               ((- 4x   + 4x )\|5  + 20x )\|- \|5  + 3
+--R             + 
+--R                                                   +-----------+
+--R                   10     2 4+-+2 +-+      6 4+-+2 |    +-+
+--R               ((2x   - 2x )\|2  \|5  - 10x  \|2 )\|- 2\|5  + 6
+--R             + 
+--R                  12     8     4     4+-+2 +-+         8      4     4+-+2
+--R               (2x   + 3x  + 3x  - 3)\|2  \|5  + (- 15x  - 15x  + 5)\|2
+--R          *
+--R              +--------+3
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                                     +----------+2
+--R                      8     4 4+-+2 +-+      8 4+-+24|   +-+
+--R               ((- 12x  - 8x )\|2  \|5  - 20x  \|2 )\|- \|5  + 3
+--R             + 
+--R                                         +-----------+
+--R                    8     4  +-+      8  |    +-+
+--R               ((12x  + 8x )\|5  + 20x )\|- 2\|5  + 6
+--R             + 
+--R                   10      6      2  +-+      10      2
+--R               (12x   + 16x  + 12x )\|5  + 20x   - 20x
+--R          *
+--R              +--------+
+--R             4| +-+
+--R             \|\|5  + 3
+--R      *
+--R          +------------+
+--R         4|   +-+
+--R         \|55\|5  + 123
+--R     + 
+--R                                                 +--------------+ +-----------+
+--R                   8     4 4+-+2 +-+     4 4+-+24|     +-+        |    +-+
+--R               ((2x  + 3x )\|2  \|5  + 5x  \|2 )\|- 55\|5  + 123 \|- 2\|5  + 6
+--R             + 
+--R                                                     +--------------+
+--R                     10     2 4+-+2 +-+      6 4+-+24|     +-+
+--R               ((- 2x   + 2x )\|2  \|5  - 10x  \|2 )\|- 55\|5  + 123
+--R          *
+--R              +----------+3
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                            +----------+2
+--R                  8      4 4|   +-+
+--R           (- 240x  - 80x )\|- \|5  + 3
+--R         + 
+--R                                                +--------------+ +-----------+
+--R                   10      6     2  +-+      6 4|     +-+        |    +-+
+--R               ((6x   + 12x  + 2x )\|5  + 10x )\|- 55\|5  + 123 \|- 2\|5  + 6
+--R             + 
+--R                                           +--------------+
+--R                      8     4  +-+      8 4|     +-+
+--R               ((- 12x  - 8x )\|5  + 20x )\|- 55\|5  + 123
+--R          *
+--R              +----------+
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                               +-----------+
+--R                8      4 4+-+2 |    +-+              6      2 4+-+2 +-+
+--R           (120x  + 40x )\|2  \|- 2\|5  + 6  + (- 60x  - 20x )\|2  \|5
+--R         + 
+--R                10       6      2 4+-+2
+--R           (120x   + 220x  + 60x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                          +--------------+ +-----------+
+--R                     8     4  +-+      4 4|     +-+        |    +-+
+--R               ((- 4x  - 6x )\|5  - 10x )\|- 55\|5  + 123 \|- 2\|5  + 6
+--R             + 
+--R                                         +--------------+
+--R                   10     2  +-+      6 4|     +-+
+--R               ((4x   - 4x )\|5  + 20x )\|- 55\|5  + 123
+--R          *
+--R              +----------+3
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                +----------+2
+--R                8      4 4+-+2 4|   +-+
+--R           (240x  + 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                                              +--------------+
+--R                       10      6     2 4+-+2 +-+      6 4+-+24|     +-+
+--R                 ((- 6x   - 12x  - 2x )\|2  \|5  - 10x  \|2 )\|- 55\|5  + 123
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                                                   +--------------+
+--R                    8     4 4+-+2 +-+      8 4+-+24|     +-+
+--R               ((12x  + 8x )\|2  \|5  - 20x  \|2 )\|- 55\|5  + 123
+--R          *
+--R              +----------+
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                            +-----------+
+--R                  8      4  |    +-+             6      2  +-+       10       6
+--R           (- 240x  - 80x )\|- 2\|5  + 6  + (120x  + 40x )\|5  - 240x   - 440x
+--R         + 
+--R                 2
+--R           - 120x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                                +--------------+
+--R                 10     6     2 4+-+2 +-+       6      2 4+-+2 4|     +-+
+--R             ((2x   + 6x  + 7x )\|2  \|5  + (10x  + 15x )\|2  )\|- 55\|5  + 123
+--R          *
+--R              +-----------+
+--R              |    +-+
+--R             \|- 2\|5  + 6
+--R         + 
+--R                   12     8     4     4+-+2 +-+         8      4     4+-+2
+--R             ((- 2x   - 3x  - 3x  + 3)\|2  \|5  + (- 15x  - 15x  + 5)\|2  )
+--R          *
+--R              +--------------+
+--R             4|     +-+
+--R             \|- 55\|5  + 123
+--R      *
+--R          +----------+3
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                                                       +----------+2
+--R               6      2  +-+       10       6       2 4|   +-+
+--R       ((- 120x  - 40x )\|5  - 240x   - 440x  - 120x )\|- \|5  + 3
+--R     + 
+--R                                                              +--------------+
+--R                 12      8      4      +-+      8      4     4|     +-+
+--R             ((6x   + 21x  + 25x  + 3)\|5  + 25x  + 45x  + 5)\|- 55\|5  + 123
+--R          *
+--R              +-----------+
+--R              |    +-+
+--R             \|- 2\|5  + 6
+--R         + 
+--R                                                        +--------------+
+--R                  10      6      2  +-+      10      2 4|     +-+
+--R           ((- 12x   - 16x  - 12x )\|5  + 20x   - 20x )\|- 55\|5  + 123
+--R      *
+--R          +----------+
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                                                               +-----------+
+--R            6      2 4+-+2 +-+        10       6      2 4+-+2  |    +-+
+--R       ((60x  + 20x )\|2  \|5  + (120x   + 220x  + 60x )\|2  )\|- 2\|5  + 6
+--R     + 
+--R            12       8       4      4+-+2
+--R       (120x   + 400x  + 240x  + 40)\|2
+--R  /
+--R                                  +----------+2
+--R               12       8      4 4|   +-+
+--R           (80x   + 240x  + 80x )\|- \|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                 12       8      4 4+-+2 |    +-+
+--R           (- 40x   - 120x  - 40x )\|2  \|- 2\|5  + 6
+--R         + 
+--R             10      6      2 4+-+2 +-+         14       10       6      2 4+-+2
+--R         (20x   + 60x  + 20x )\|2  \|5  + (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                          +----------+2
+--R                 12       8      4 4+-+2 4|   +-+
+--R           (- 80x   - 240x  - 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                  +-----------+
+--R               12       8      4  |    +-+              10       6      2  +-+
+--R           (80x   + 240x  + 80x )\|- 2\|5  + 6  + (- 40x   - 120x  - 40x )\|5
+--R         + 
+--R              14       10       6       2
+--R           80x   + 360x   + 440x  + 120x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R              10       6      2  +-+      14       10       6       2
+--R         ((40x   + 120x  + 40x )\|5  + 80x   + 360x   + 440x  + 120x )
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                 10      6      2 4+-+2 +-+
+--R           (- 20x   - 60x  - 20x )\|2  \|5
+--R         + 
+--R                 14       10       6      2 4+-+2
+--R           (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R             16       12       8       4      4+-+2
+--R       (- 40x   - 240x   - 440x  - 240x  - 40)\|2
+--R                                                    Type: Expression(Integer)
+--E 873
+
+)clear all
+
+--S 874 of 1311
+t0:=x^6/(1+3*x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 874
+
+--S 875 of 1311
+r0:=1/4*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))*(3-sqrt(5))^(3/4)/(2^(1/4)*_
+   sqrt(5))-1/4*atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))*(3-sqrt(5))^(3/4)/_
+   (2^(1/4)*sqrt(5))-1/8*log(2*x^2-2*2^(1/4)*x*(3-sqrt(5))^(1/4)+_
+   sqrt(2*(3-sqrt(5))))*(3-sqrt(5))^(3/4)/(2^(1/4)*sqrt(5))+_
+   1/8*log(2*x^2+2*2^(1/4)*x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*_
+   (3-sqrt(5))^(3/4)/(2^(1/4)*sqrt(5))-1/4*atan(1-2^(3/4)*_
+   x/(3+sqrt(5))^(1/4))*(3+sqrt(5))^(3/4)/(2^(1/4)*sqrt(5))+_
+   1/4*atan(1+2^(3/4)*x/(3+sqrt(5))^(1/4))*(3+sqrt(5))^(3/4)/(2^(1/4)*_
+   sqrt(5))+1/8*log(2*x^2-2*2^(1/4)*x*(3+sqrt(5))^(1/4)+sqrt(2*(3+_
+   sqrt(5))))*(3+sqrt(5))^(3/4)/(2^(1/4)*sqrt(5))-1/8*log(2*x^2+_
+   2*2^(1/4)*x*(3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*(3+_
+   sqrt(5))^(3/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          +--------+3     +---------+          +--------+
+--R         4| +-+           |  +-+          4+-+4| +-+          2
+--R       - \|\|5  + 3  log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +--------+3     +---------+          +--------+
+--R       4| +-+           |  +-+          4+-+4| +-+          2
+--R       \|\|5  + 3  log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +----------+3           +----------+    +-----------+
+--R       4|   +-+            4+-+4|   +-+         |    +-+          2
+--R       \|- \|5  + 3  log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R          +----------+3             +----------+    +-----------+
+--R         4|   +-+              4+-+4|   +-+         |    +-+          2
+--R       - \|- \|5  + 3  log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                    +--------+3
+--R           +--------+3        4+-+3 +-+      4+-+3 4| +-+
+--R          4| +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 2\|\|5  + 3  atan(----------------------------------------)
+--R                                               4
+--R     + 
+--R                                                    +--------+3
+--R           +--------+3        4+-+3 +-+      4+-+3 4| +-+
+--R          4| +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 2\|\|5  + 3  atan(----------------------------------------)
+--R                                               4
+--R     + 
+--R                                                      +----------+3
+--R           +----------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R          4|   +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 2\|- \|5  + 3  atan(------------------------------------------)
+--R                                                  4
+--R     + 
+--R                                                      +----------+3
+--R           +----------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R          4|   +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 2\|- \|5  + 3  atan(------------------------------------------)
+--R                                                  4
+--R  /
+--R      4+-+ +-+
+--R     8\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 875
+
+--S 876 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                    +----------+2
+--R                     8     4 4+-+2 +-+      8 4+-+24|   +-+
+--R               ((- 6x  - 4x )\|2  \|5  - 10x  \|2 )\|- \|5  + 3
+--R             + 
+--R                                        +-----------+
+--R                   8     4  +-+      8  |    +-+           10     6     2  +-+
+--R               ((6x  + 4x )\|5  + 10x )\|- 2\|5  + 6  + (6x   + 8x  + 6x )\|5
+--R             + 
+--R                  10      2
+--R               10x   - 10x
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                    8     4  +-+      8  |    +-+           10      6      2
+--R             (((- 6x  - 4x )\|5  + 10x )\|- 2\|5  + 6  + 60x   + 60x  + 20x )
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                        +-----------+
+--R                 10      6      2 4+-+2 |    +-+
+--R           (- 30x   - 30x  - 10x )\|2  \|- 2\|5  + 6
+--R         + 
+--R                12     8     4     4+-+2 +-+         12      8      4 4+-+2
+--R           (- 9x   + 9x  - 3x  - 2)\|2  \|5  + (- 15x   - 75x  - 15x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                                  +-----------+
+--R                   8     4 4+-+2 +-+      8 4+-+2 |    +-+
+--R               ((6x  + 4x )\|2  \|5  - 10x  \|2 )\|- 2\|5  + 6
+--R             + 
+--R                     10      6      2 4+-+2
+--R               (- 60x   - 60x  - 20x )\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                 +-----------+
+--R               10      6      2  |    +-+            12      8     4      +-+
+--R           (60x   + 60x  + 20x )\|- 2\|5  + 6  + (18x   - 18x  + 6x  + 4)\|5
+--R         + 
+--R              12       8      4
+--R           30x   + 150x  + 30x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                     +-----------+
+--R                 10     6     2  +-+      10      2  |    +-+
+--R           ((- 6x   - 8x  - 6x )\|5  + 10x   - 10x )\|- 2\|5  + 6
+--R         + 
+--R                 12      8     4      +-+      12       8      4
+--R           (- 18x   + 18x  - 6x  - 4)\|5  + 30x   + 150x  + 30x
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R             12     8     4     4+-+2 +-+         12      8      4 4+-+2
+--R         ((9x   - 9x  + 3x  + 2)\|2  \|5  + (- 15x   - 75x  - 15x )\|2  )
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R              10      6 4+-+2
+--R       (- 120x   - 80x )\|2
+--R  /
+--R                                  +----------+2
+--R               12       8      4 4|   +-+
+--R           (80x   + 240x  + 80x )\|- \|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                 12       8      4 4+-+2 |    +-+
+--R           (- 40x   - 120x  - 40x )\|2  \|- 2\|5  + 6
+--R         + 
+--R             10      6      2 4+-+2 +-+         14       10       6      2 4+-+2
+--R         (20x   + 60x  + 20x )\|2  \|5  + (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                          +----------+2
+--R                 12       8      4 4+-+2 4|   +-+
+--R           (- 80x   - 240x  - 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                  +-----------+
+--R               12       8      4  |    +-+              10       6      2  +-+
+--R           (80x   + 240x  + 80x )\|- 2\|5  + 6  + (- 40x   - 120x  - 40x )\|5
+--R         + 
+--R              14       10       6       2
+--R           80x   + 360x   + 440x  + 120x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R              10       6      2  +-+      14       10       6       2
+--R         ((40x   + 120x  + 40x )\|5  + 80x   + 360x   + 440x  + 120x )
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                 10      6      2 4+-+2 +-+
+--R           (- 20x   - 60x  - 20x )\|2  \|5
+--R         + 
+--R                 14       10       6      2 4+-+2
+--R           (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R             16       12       8       4      4+-+2
+--R       (- 40x   - 240x   - 440x  - 240x  - 40)\|2
+--R                                                    Type: Expression(Integer)
+--E 876
+
+)clear all
+
+--S 877 of 1311
+t0:=x^4/(1+3*x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 877
+
+--S 878 of 1311
+r0:=1/2*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))*(3-sqrt(5))^(1/4)/(2^(3/4)*_
+   sqrt(5))-1/2*atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))*_
+   (3-sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+1/4*log(2*x^2-2*2^(1/4)*_
+   x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*(3-sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))-1/4*log(2*x^2+2*2^(1/4)*x*(3-sqrt(5))^(1/4)+_
+   sqrt(2*(3-sqrt(5))))*(3-sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-_
+   1/2*atan(1-2^(3/4)*x/(3+sqrt(5))^(1/4))*(3+sqrt(5))^(1/4)/(2^(3/4)*_
+   sqrt(5))+1/2*atan(1+2^(3/4)*x/(3+sqrt(5))^(1/4))*(3+_
+   sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-1/4*log(2*x^2-2*2^(1/4)*x*_
+   (3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*(3+sqrt(5))^(1/4)/(2^(3/4)*_
+   sqrt(5))+1/4*log(2*x^2+2*2^(1/4)*x*(3+sqrt(5))^(1/4)+sqrt(2*_
+   (3+sqrt(5))))*(3+sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R        +--------+     +---------+          +--------+
+--R       4| +-+          |  +-+          4+-+4| +-+          2
+--R       \|\|5  + 3 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +--------+     +---------+          +--------+
+--R         4| +-+          |  +-+          4+-+4| +-+          2
+--R       - \|\|5  + 3 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +----------+           +----------+    +-----------+
+--R         4|   +-+           4+-+4|   +-+         |    +-+          2
+--R       - \|- \|5  + 3 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R        +----------+             +----------+    +-----------+
+--R       4|   +-+             4+-+4|   +-+         |    +-+          2
+--R       \|- \|5  + 3 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                   +--------+3
+--R           +--------+        4+-+3 +-+      4+-+3 4| +-+
+--R          4| +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 2\|\|5  + 3 atan(----------------------------------------)
+--R                                              4
+--R     + 
+--R                                                   +--------+3
+--R           +--------+        4+-+3 +-+      4+-+3 4| +-+
+--R          4| +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 2\|\|5  + 3 atan(----------------------------------------)
+--R                                              4
+--R     + 
+--R                                                     +----------+3
+--R           +----------+        4+-+3 +-+      4+-+3 4|   +-+
+--R          4|   +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 2\|- \|5  + 3 atan(------------------------------------------)
+--R                                                 4
+--R     + 
+--R                                                     +----------+3
+--R           +----------+        4+-+3 +-+      4+-+3 4|   +-+
+--R          4|   +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 2\|- \|5  + 3 atan(------------------------------------------)
+--R                                                 4
+--R  /
+--R      4+-+3 +-+
+--R     4\|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 878
+
+--S 879 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                            +----------+2
+--R                     10      6     2 4+-+2 +-+      6 4+-+24|   +-+
+--R               ((- 6x   - 12x  - 2x )\|2  \|5  + 10x  \|2 )\|- \|5  + 3
+--R             + 
+--R                                                +-----------+
+--R                   10      6     2  +-+      6  |    +-+
+--R               ((6x   + 12x  + 2x )\|5  - 10x )\|- 2\|5  + 6
+--R             + 
+--R                  12      8      4      +-+      8      4
+--R               (6x   + 21x  + 25x  + 3)\|5  - 25x  - 45x  - 5
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                                 +-----------+
+--R                    10      6     2  +-+      6  |    +-+           8
+--R             (((- 6x   - 12x  - 2x )\|5  - 10x )\|- 2\|5  + 6  + 40x )
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                        +-----------+
+--R                8 4+-+2 |    +-+           10      6 4+-+2 +-+
+--R           - 20x  \|2  \|- 2\|5  + 6 + (12x   + 18x )\|2  \|5
+--R         + 
+--R                 10      6 4+-+2
+--R           (- 40x   - 30x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                                          +-----------+
+--R                   10      6     2 4+-+2 +-+      6 4+-+2 |    +-+
+--R               ((6x   + 12x  + 2x )\|2  \|5  + 10x  \|2 )\|- 2\|5  + 6
+--R             + 
+--R                    8 4+-+2
+--R               - 40x  \|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                +-----------+
+--R              8 |    +-+              10      6  +-+      10      6
+--R           40x \|- 2\|5  + 6  + (- 24x   - 36x )\|5  + 80x   + 60x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                              +-----------+
+--R                 12      8      4      +-+      8      4      |    +-+
+--R           ((- 6x   - 21x  - 25x  - 3)\|5  - 25x  - 45x  - 5)\|- 2\|5  + 6
+--R         + 
+--R               10      6  +-+      10      6
+--R           (24x   + 36x )\|5  + 80x   + 60x
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                                                           +-----------+
+--R              10      6 4+-+2 +-+         10      6 4+-+2  |    +-+
+--R       ((- 12x   - 18x )\|2  \|5  + (- 40x   - 30x )\|2  )\|- 2\|5  + 6
+--R     + 
+--R             12      8      4 4+-+2
+--R       (- 60x   - 60x  + 20x )\|2
+--R  /
+--R                                  +----------+2
+--R               12       8      4 4|   +-+
+--R           (80x   + 240x  + 80x )\|- \|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                 12       8      4 4+-+2 |    +-+
+--R           (- 40x   - 120x  - 40x )\|2  \|- 2\|5  + 6
+--R         + 
+--R             10      6      2 4+-+2 +-+         14       10       6      2 4+-+2
+--R         (20x   + 60x  + 20x )\|2  \|5  + (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                          +----------+2
+--R                 12       8      4 4+-+2 4|   +-+
+--R           (- 80x   - 240x  - 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                  +-----------+
+--R               12       8      4  |    +-+              10       6      2  +-+
+--R           (80x   + 240x  + 80x )\|- 2\|5  + 6  + (- 40x   - 120x  - 40x )\|5
+--R         + 
+--R              14       10       6       2
+--R           80x   + 360x   + 440x  + 120x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R              10       6      2  +-+      14       10       6       2
+--R         ((40x   + 120x  + 40x )\|5  + 80x   + 360x   + 440x  + 120x )
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                 10      6      2 4+-+2 +-+
+--R           (- 20x   - 60x  - 20x )\|2  \|5
+--R         + 
+--R                 14       10       6      2 4+-+2
+--R           (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R             16       12       8       4      4+-+2
+--R       (- 40x   - 240x   - 440x  - 240x  - 40)\|2
+--R                                                    Type: Expression(Integer)
+--E 879
+
+)clear all
+
+--S 880 of 1311
+t0:=x^2/(1+3*x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 880
+
+--S 881 of 1311
+r0:=-1/2*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))/(2^(1/4)*(3-sqrt(5))^(1/4)*_
+   sqrt(5))+1/2*atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))/(2^(1/4)*_
+   (3-sqrt(5))^(1/4)*sqrt(5))+1/4*log(2*x^2-2*2^(1/4)*x*(3-sqrt(5))^(1/4)+_
+   sqrt(2*(3-sqrt(5))))/(2^(1/4)*(3-sqrt(5))^(1/4)*sqrt(5))-_
+   1/4*log(2*x^2+2*2^(1/4)*x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))/_
+   (2^(1/4)*(3-sqrt(5))^(1/4)*sqrt(5))+1/2*atan(1-2^(3/4)*_
+   x/(3+sqrt(5))^(1/4))/(2^(1/4)*sqrt(5)*(3+sqrt(5))^(1/4))-_
+   1/2*atan(1+2^(3/4)*x/(3+sqrt(5))^(1/4))/(2^(1/4)*sqrt(5)*_
+   (3+sqrt(5))^(1/4))-1/4*log(2*x^2-2*2^(1/4)*x*(3+sqrt(5))^(1/4)+_
+   sqrt(2*(3+sqrt(5))))/(2^(1/4)*sqrt(5)*(3+sqrt(5))^(1/4))+_
+   1/4*log(2*x^2+2*2^(1/4)*x*(3+sqrt(5))^(1/4)+_
+   sqrt(2*(3+sqrt(5))))/(2^(1/4)*sqrt(5)*(3+sqrt(5))^(1/4))
+--R 
+--R
+--R   (2)
+--R        +----------+     +---------+          +--------+
+--R       4|   +-+          |  +-+          4+-+4| +-+          2
+--R       \|- \|5  + 3 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +----------+     +---------+          +--------+
+--R         4|   +-+          |  +-+          4+-+4| +-+          2
+--R       - \|- \|5  + 3 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R          +--------+           +----------+    +-----------+
+--R         4| +-+           4+-+4|   +-+         |    +-+          2
+--R       - \|\|5  + 3 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R        +--------+             +----------+    +-----------+
+--R       4| +-+             4+-+4|   +-+         |    +-+          2
+--R       \|\|5  + 3 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                   +--------+3
+--R         +----------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       2\|- \|5  + 3 atan(----------------------------------------)
+--R                                              4
+--R     + 
+--R                                                   +--------+3
+--R         +----------+        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+          (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       2\|- \|5  + 3 atan(----------------------------------------)
+--R                                              4
+--R     + 
+--R                                                 +----------+3
+--R         +--------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4| +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       2\|\|5  + 3 atan(------------------------------------------)
+--R                                             4
+--R     + 
+--R                                                 +----------+3
+--R         +--------+        4+-+3 +-+      4+-+3 4|   +-+
+--R        4| +-+          (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       2\|\|5  + 3 atan(------------------------------------------)
+--R                                             4
+--R  /
+--R               +----------+ +--------+
+--R      4+-+ +-+4|   +-+     4| +-+
+--R     4\|2 \|5 \|- \|5  + 3 \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 881
+
+--S 882 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                              +-----------+
+--R                      6 4+-+2 |    +-+            12     8      4     4+-+2 +-+
+--R                   20x  \|2  \|- 2\|5  + 6 + (- 6x   - 9x  - 17x  - 3)\|2  \|5
+--R                 + 
+--R                      8      4     4+-+2
+--R                   (5x  + 45x  + 5)\|2
+--R              *
+--R                  +----------+2
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                           +-----------+
+--R                      8     4  +-+      8  |    +-+           6 +-+       6
+--R               ((- 12x  - 8x )\|5  + 20x )\|- 2\|5  + 6  + 40x \|5  - 120x
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                    8     4  +-+      8  |    +-+
+--R               ((12x  + 8x )\|5  + 20x )\|- 2\|5  + 6
+--R             + 
+--R                   10      6      2  +-+      10      2
+--R               (12x   + 16x  + 12x )\|5  + 20x   - 20x
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                 8      4 4+-+2 +-+      4 4+-+2
+--R           (- 16x  - 24x )\|2  \|5  + 40x  \|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                     12     8      4     4+-+2 +-+      8      4     4+-+2
+--R                 ((6x   + 9x  + 17x  + 3)\|2  \|5  + (5x  + 45x  + 5)\|2  )
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                     10      2 4+-+2
+--R               (- 40x   + 40x )\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                                        +-----------+
+--R                  10      6      2  +-+      10      2  |    +-+
+--R           ((- 12x   - 16x  - 12x )\|5  + 20x   - 20x )\|- 2\|5  + 6
+--R         + 
+--R                 12      8      4      +-+      12      8       4
+--R           (- 36x   - 44x  - 12x  - 8)\|5  + 60x   + 60x  - 100x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                +-----------+
+--R                 6 +-+       6  |    +-+            12      8      4      +-+
+--R           (- 40x \|5  - 120x )\|- 2\|5  + 6  + (36x   + 44x  + 12x  + 8)\|5
+--R         + 
+--R              12      8       4
+--R           60x   + 60x  - 100x
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                                            +-----------+
+--R            8      4 4+-+2 +-+      4 4+-+2 |    +-+            6 4+-+2
+--R       ((16x  + 24x )\|2  \|5  + 40x  \|2 )\|- 2\|5  + 6  + 160x  \|2
+--R  /
+--R                                           +-----------+
+--R                   12       8      4 4+-+2 |    +-+
+--R               (40x   + 120x  + 40x )\|2  \|- 2\|5  + 6
+--R             + 
+--R                     10      6      2 4+-+2 +-+
+--R               (- 20x   - 60x  - 20x )\|2  \|5
+--R             + 
+--R                   14       10       6      2 4+-+2
+--R               (40x   + 180x   + 220x  + 60x )\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R               12       8      4  +-+       12       8       4
+--R           (80x   + 240x  + 80x )\|5  - 240x   - 720x  - 240x
+--R      *
+--R          +--------+2 +---------+
+--R         4| +-+       |  +-+
+--R         \|\|5  + 3  \|2\|5  + 6
+--R     + 
+--R                       10      6      2 4+-+2 +-+
+--R                   (20x   + 60x  + 20x )\|2  \|5
+--R                 + 
+--R                       14       10       6      2 4+-+2
+--R                   (40x   + 180x   + 220x  + 60x )\|2
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                   16       12       8       4      4+-+2
+--R               (40x   + 240x   + 440x  + 240x  + 40)\|2
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R               14       10      6  +-+       14       10       6       2
+--R           (80x   + 240x   + 80x )\|5  - 240x   - 880x   - 720x  - 160x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                                   +-----------+
+--R                  12       8      4  +-+       12       8       4  |    +-+
+--R           ((- 80x   - 240x  - 80x )\|5  - 240x   - 720x  - 240x )\|- 2\|5  + 6
+--R         + 
+--R                 14       10      6  +-+       14       10       6       2
+--R           (- 80x   - 240x   - 80x )\|5  - 240x   - 880x   - 720x  - 160x
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R            12       8       4 4+-+2
+--R       (320x   + 960x  + 320x )\|2
+--R                                                    Type: Expression(Integer)
+--E 882
+
+)clear all
+
+--S 883 of 1311
+t0:=1/(1+3*x^4+x^8)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 883
+
+--S 884 of 1311
+r0a:=1/20*atan(1-x*sqrt(-1+sqrt(5)))*sqrt(-20+10*sqrt(5))-_
+   1/20*atan(1+x*sqrt(-1+sqrt(5)))*sqrt(-20+10*sqrt(5))+_
+   1/40*log(1+2*x^2+sqrt(5)-2*x*sqrt(1+sqrt(5)))*sqrt(-20+10*sqrt(5))-_
+   1/40*log(1+2*x^2+sqrt(5)+2*x*sqrt(1+sqrt(5)))*sqrt(-20+10*sqrt(5))-_
+   1/20*atan(1-x*sqrt(1+sqrt(5)))*sqrt(20+10*sqrt(5))+_
+   1/20*atan(1+x*sqrt(1+sqrt(5)))*sqrt(20+10*sqrt(5))-_
+   1/40*log(-1+2*x^2+sqrt(5)-2*x*sqrt(-1+sqrt(5)))*sqrt(20+10*sqrt(5))+_
+   1/40*log(-1+2*x^2+sqrt(5)+2*x*sqrt(-1+sqrt(5)))*sqrt(20+10*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          +-----------+       +--------+
+--R          |   +-+             | +-+         +-+     2
+--R       - \|10\|5  - 20 log(2x\|\|5  + 1  + \|5  + 2x  + 1)
+--R     + 
+--R        +-----------+       +--------+
+--R        |   +-+             | +-+         +-+     2
+--R       \|10\|5  + 20 log(2x\|\|5  - 1  + \|5  + 2x  - 1)
+--R     + 
+--R          +-----------+         +--------+
+--R          |   +-+               | +-+         +-+     2
+--R       - \|10\|5  + 20 log(- 2x\|\|5  - 1  + \|5  + 2x  - 1)
+--R     + 
+--R        +-----------+         +--------+
+--R        |   +-+               | +-+         +-+     2
+--R       \|10\|5  - 20 log(- 2x\|\|5  + 1  + \|5  + 2x  + 1)
+--R     + 
+--R         +-----------+       +--------+
+--R         |   +-+             | +-+
+--R       2\|10\|5  + 20 atan(x\|\|5  + 1  + 1)
+--R     + 
+--R         +-----------+       +--------+
+--R         |   +-+             | +-+
+--R       2\|10\|5  + 20 atan(x\|\|5  + 1  - 1)
+--R     + 
+--R           +-----------+       +--------+
+--R           |   +-+             | +-+
+--R       - 2\|10\|5  - 20 atan(x\|\|5  - 1  + 1)
+--R     + 
+--R           +-----------+       +--------+
+--R           |   +-+             | +-+
+--R       - 2\|10\|5  - 20 atan(x\|\|5  - 1  - 1)
+--R  /
+--R     40
+--R                                                    Type: Expression(Integer)
+--E 884
+
+--S 885 of 1311
+r0b:=-atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))/(2^(3/4)*(3-sqrt(5))^(3/4)*_
+   sqrt(5))+atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))/(2^(3/4)*_
+   (3-sqrt(5))^(3/4)*sqrt(5))-1/2*log(2*x^2-2*2^(1/4)*x*_
+   (3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))/(2^(3/4)*(3-sqrt(5))^(3/4)*_
+   sqrt(5))+1/2*log(2*x^2+2*2^(1/4)*x*(3-sqrt(5))^(1/4)+_
+   sqrt(2*(3-sqrt(5))))/(2^(3/4)*(3-sqrt(5))^(3/4)*sqrt(5))+_
+   atan(1-2^(3/4)*x/(3+sqrt(5))^(1/4))/(2^(3/4)*sqrt(5)*_
+   (3+sqrt(5))^(3/4))-atan(1+2^(3/4)*x/(3+sqrt(5))^(1/4))/(2^(3/4)*_
+   sqrt(5)*(3+sqrt(5))^(3/4))+1/2*log(2*x^2-2*2^(1/4)*x*(3+_
+   sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))/(2^(3/4)*sqrt(5)*_
+   (3+sqrt(5))^(3/4))-1/2*log(2*x^2+2*2^(1/4)*x*(3+sqrt(5))^(1/4)+_
+   sqrt(2*(3+sqrt(5))))/(2^(3/4)*sqrt(5)*(3+sqrt(5))^(3/4))
+--R 
+--R
+--R   (3)
+--R          +----------+3     +---------+          +--------+
+--R         4|   +-+           |  +-+          4+-+4| +-+          2
+--R       - \|- \|5  + 3  log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +----------+3     +---------+          +--------+
+--R       4|   +-+           |  +-+          4+-+4| +-+          2
+--R       \|- \|5  + 3  log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R        +--------+3           +----------+    +-----------+
+--R       4| +-+            4+-+4|   +-+         |    +-+          2
+--R       \|\|5  + 3  log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R          +--------+3             +----------+    +-----------+
+--R         4| +-+              4+-+4|   +-+         |    +-+          2
+--R       - \|\|5  + 3  log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                    +--------+3
+--R         +----------+3        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       2\|- \|5  + 3  atan(----------------------------------------)
+--R                                               4
+--R     + 
+--R                                                    +--------+3
+--R         +----------+3        4+-+3 +-+      4+-+3 4| +-+
+--R        4|   +-+           (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       2\|- \|5  + 3  atan(----------------------------------------)
+--R                                               4
+--R     + 
+--R                                                  +----------+3
+--R         +--------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R        4| +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       2\|\|5  + 3  atan(------------------------------------------)
+--R                                              4
+--R     + 
+--R                                                  +----------+3
+--R         +--------+3        4+-+3 +-+      4+-+3 4|   +-+
+--R        4| +-+           (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       2\|\|5  + 3  atan(------------------------------------------)
+--R                                              4
+--R  /
+--R                +----------+3  +--------+3
+--R      4+-+3 +-+4|   +-+       4| +-+
+--R     2\|2  \|5 \|- \|5  + 3   \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 885
+
+--S 886 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              1
+--R   (4)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                                    Type: Expression(Integer)
+--E 886
+
+--S 887 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              1
+--R   (5)  ------------
+--R         8     4
+--R        x  + 3x  + 1
+--R                                                    Type: Expression(Integer)
+--E 887
+
+)clear all
+
+--S 888 of 1311
+t0:=1/(x^2*(1+3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         10     6    2
+--R        x   + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 888
+
+--S 889 of 1311
+r0:=(-1)/x-1/4*atan(1-2^(3/4)*x/(3+sqrt(5))^(1/4))*_
+   (246-110*sqrt(5))^(1/4)/sqrt(5)+1/4*atan(1+2^(3/4)*_
+   x/(3+sqrt(5))^(1/4))*(246-110*sqrt(5))^(1/4)/sqrt(5)+_
+   1/8*log(2*x^2-2*2^(1/4)*x*(3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*_
+   (246-110*sqrt(5))^(1/4)/sqrt(5)-1/8*log(2*x^2+2*2^(1/4)*x*_
+   (3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*(246-110*sqrt(5))^(1/4)/sqrt(5)+_
+   1/4*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))*(246+110*sqrt(5))^(1/4)/sqrt(5)-_
+   1/4*atan(1+2^(3/4)*x/(3-sqrt(5))^(1/4))*(246+110*sqrt(5))^(1/4)/sqrt(5)-_
+   1/8*log(2*x^2-2*2^(1/4)*x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*_
+   (246+110*sqrt(5))^(1/4)/sqrt(5)+1/8*log(2*x^2+2*2^(1/4)*x*_
+   (3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*(246+110*sqrt(5))^(1/4)/sqrt(5)
+--R 
+--R
+--R   (2)
+--R           +---------------+     +---------+          +--------+
+--R          4|      +-+            |  +-+          4+-+4| +-+          2
+--R       - x\|- 110\|5  + 246 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R         +---------------+     +---------+          +--------+
+--R        4|      +-+            |  +-+          4+-+4| +-+          2
+--R       x\|- 110\|5  + 246 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R         +-------------+           +----------+    +-----------+
+--R        4|    +-+             4+-+4|   +-+         |    +-+          2
+--R       x\|110\|5  + 246 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R           +-------------+             +----------+    +-----------+
+--R          4|    +-+               4+-+4|   +-+         |    +-+          2
+--R       - x\|110\|5  + 246 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                           +--------+3
+--R            +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R           4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 2x\|- 110\|5  + 246 atan(----------------------------------------)
+--R                                                      4
+--R     + 
+--R                                                           +--------+3
+--R            +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R           4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 2x\|- 110\|5  + 246 atan(----------------------------------------)
+--R                                                      4
+--R     + 
+--R                                                         +----------+3
+--R            +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R           4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 2x\|110\|5  + 246 atan(------------------------------------------)
+--R                                                     4
+--R     + 
+--R                                                         +----------+3
+--R            +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R           4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 2x\|110\|5  + 246 atan(------------------------------------------)
+--R                                                     4
+--R     + 
+--R           +-+
+--R       - 8\|5
+--R  /
+--R        +-+
+--R     8x\|5
+--R                                                    Type: Expression(Integer)
+--E 889
+
+--S 890 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                       +-----------+
+--R                         8     4 4+-+3 +-+     4 4+-+3 |    +-+
+--R                   ((- 2x  - 3x )\|2  \|5  - 5x  \|2 )\|- 2\|5  + 6
+--R                 + 
+--R                      10     2 4+-+3 +-+      6 4+-+3
+--R                   (2x   - 2x )\|2  \|5  + 10x  \|2
+--R              *
+--R                  +----------+3
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                       +-----------+
+--R                         10     2 4+-+ +-+      6 4+-+ |    +-+
+--R                   ((- 2x   + 2x )\|2 \|5  - 10x  \|2)\|- 2\|5  + 6
+--R                 + 
+--R                        12      8 4+-+ +-+      8 4+-+
+--R                   (- 8x   - 12x )\|2 \|5  - 20x  \|2
+--R              *
+--R                  +----------+
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|5  + 6
+--R         + 
+--R                                                    +-----------+
+--R                       8     4 4+-+ +-+      4 4+-+ |    +-+
+--R                   ((4x  + 6x )\|2 \|5  + 10x  \|2)\|- 2\|5  + 6
+--R                 + 
+--R                        10     2 4+-+ +-+      6 4+-+
+--R                   (- 4x   + 4x )\|2 \|5  - 20x  \|2
+--R              *
+--R                  +----------+3
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                       +-----------+
+--R                       10     2 4+-+3 +-+      6 4+-+3 |    +-+
+--R                   ((2x   - 2x )\|2  \|5  + 10x  \|2 )\|- 2\|5  + 6
+--R                 + 
+--R                      12      8 4+-+3 +-+      8 4+-+3
+--R                   (8x   + 12x )\|2  \|5  + 20x  \|2
+--R              *
+--R                  +----------+
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                       10     6     2 4+-+3 +-+         6      2 4+-+3
+--R                 ((- 2x   - 6x  - 7x )\|2  \|5  + (- 10x  - 15x )\|2  )
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                  12     8     4     4+-+3 +-+       8      4     4+-+3
+--R               (2x   + 3x  + 3x  - 3)\|2  \|5  + (15x  + 15x  - 5)\|2
+--R          *
+--R              +----------+3
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                       12     8     4     4+-+ +-+         8      4     4+-+
+--R                 ((- 2x   - 3x  - 3x  + 3)\|2 \|5  + (- 15x  - 15x  + 5)\|2 )
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                    14      10      6 4+-+ +-+         10      6 4+-+
+--R               (- 8x   - 24x   - 28x )\|2 \|5  + (- 40x   - 60x )\|2
+--R          *
+--R              +----------+
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R      *
+--R          +-------------+
+--R         4|    +-+
+--R         \|110\|5  + 246
+--R     + 
+--R                                                    +---------------+
+--R                       8     4 4+-+ +-+      4 4+-+4|      +-+
+--R                 ((- 4x  - 6x )\|2 \|5  + 10x  \|2)\|- 110\|5  + 246
+--R              *
+--R                  +----------+2
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                 +---------------+ +-----------+
+--R                   8     4 4+-+3 +-+     4 4+-+34|      +-+        |    +-+
+--R               ((2x  + 3x )\|2  \|5  - 5x  \|2 )\|- 110\|5  + 246 \|- 2\|5  + 6
+--R             + 
+--R                     10     6     2 4+-+3 +-+         6      2 4+-+3
+--R                 ((2x   + 6x  + 7x )\|2  \|5  + (- 10x  - 15x )\|2  )
+--R              *
+--R                  +---------------+
+--R                 4|      +-+
+--R                 \|- 110\|5  + 246
+--R          *
+--R              +--------+3
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                                       +---------------+
+--R                       10     2 4+-+3 +-+      6 4+-+34|      +-+
+--R                 ((- 2x   + 2x )\|2  \|5  + 10x  \|2 )\|- 110\|5  + 246
+--R              *
+--R                  +----------+2
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                 +---------------+ +-----------+
+--R                   10     2 4+-+ +-+      6 4+-+4|      +-+        |    +-+
+--R               ((2x   - 2x )\|2 \|5  - 10x  \|2)\|- 110\|5  + 246 \|- 2\|5  + 6
+--R             + 
+--R                     12     8     4     4+-+ +-+         8      4     4+-+
+--R                 ((2x   + 3x  + 3x  - 3)\|2 \|5  + (- 15x  - 15x  + 5)\|2 )
+--R              *
+--R                  +---------------+
+--R                 4|      +-+
+--R                 \|- 110\|5  + 246
+--R          *
+--R              +--------+
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                   +----------+2                  +-----------+
+--R                 10       6 4+-+2 4|   +-+            10       6  |    +-+
+--R           (- 80x   - 240x )\|2   \|- \|5  + 3  + (80x   + 240x )\|- 2\|5  + 6
+--R         + 
+--R                 8       4  +-+      12       8       4
+--R           (- 40x  - 120x )\|5  + 80x   + 360x  + 360x
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                             +---------------+ +----------+2
+--R               10     2 4+-+ +-+      6 4+-+4|      +-+       4|   +-+
+--R           ((4x   - 4x )\|2 \|5  - 20x  \|2)\|- 110\|5  + 246 \|- \|5  + 3
+--R         + 
+--R                                                 +---------------+ +-----------+
+--R                 10     2 4+-+3 +-+      6 4+-+34|      +-+        |    +-+
+--R           ((- 2x   + 2x )\|2  \|5  + 10x  \|2 )\|- 110\|5  + 246 \|- 2\|5  + 6
+--R         + 
+--R                   12     8     4     4+-+3 +-+       8      4     4+-+3
+--R             ((- 2x   - 3x  - 3x  + 3)\|2  \|5  + (15x  + 15x  - 5)\|2  )
+--R          *
+--R              +---------------+
+--R             4|      +-+
+--R             \|- 110\|5  + 246
+--R      *
+--R          +--------+3
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                            +----------+2                          +-----------+
+--R                10       6 4|   +-+               10       6 4+-+2 |    +-+
+--R           (160x   + 480x )\|- \|5  + 3   + (- 80x   - 240x )\|2  \|- 2\|5  + 6
+--R         + 
+--R               8       4 4+-+2 +-+         12       8       4 4+-+2
+--R           (40x  + 120x )\|2  \|5  + (- 80x   - 360x  - 360x )\|2
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                    +---------------+
+--R                   12      8 4+-+3 +-+      8 4+-+34|      +-+
+--R             ((- 8x   - 12x )\|2  \|5  + 20x  \|2 )\|- 110\|5  + 246
+--R          *
+--R              +----------+2
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                              +---------------+ +-----------+
+--R               12      8 4+-+ +-+      8 4+-+4|      +-+        |    +-+
+--R           ((8x   + 12x )\|2 \|5  - 20x  \|2)\|- 110\|5  + 246 \|- 2\|5  + 6
+--R         + 
+--R                 14      10      6 4+-+ +-+         10      6 4+-+
+--R             ((8x   + 24x   + 28x )\|2 \|5  + (- 40x   - 60x )\|2 )
+--R          *
+--R              +---------------+
+--R             4|      +-+
+--R             \|- 110\|5  + 246
+--R      *
+--R          +--------+
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                8       4 4+-+2 +-+         12       8       4 4+-+2
+--R         ((- 40x  - 120x )\|2  \|5  + (- 80x   - 360x  - 360x )\|2  )
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                                                    +-----------+
+--R            8       4  +-+      12       8       4  |    +-+           14
+--R       ((40x  + 120x )\|5  + 80x   + 360x  + 360x )\|- 2\|5  + 6  + 80x
+--R     + 
+--R           10       6       2
+--R       480x   + 800x  + 240x
+--R  /
+--R                                        +----------+2
+--R               12       8      4 4+-+2 4|   +-+
+--R           (80x   + 240x  + 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                    +-----------+
+--R                 12       8      4  |    +-+            10       6      2  +-+
+--R           (- 80x   - 240x  - 80x )\|- 2\|5  + 6  + (40x   + 120x  + 40x )\|5
+--R         + 
+--R                14       10       6       2
+--R           - 80x   - 360x   - 440x  - 120x
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                      +----------+2
+--R                  12       8       4 4|   +-+
+--R           (- 160x   - 480x  - 160x )\|- \|5  + 3
+--R         + 
+--R                                       +-----------+
+--R               12       8      4 4+-+2 |    +-+
+--R           (80x   + 240x  + 80x )\|2  \|- 2\|5  + 6
+--R         + 
+--R                 10       6      2 4+-+2 +-+
+--R           (- 40x   - 120x  - 40x )\|2  \|5
+--R         + 
+--R               14       10       6       2 4+-+2
+--R           (80x   + 360x   + 440x  + 120x )\|2
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                 10       6      2 4+-+2 +-+
+--R             (40x   + 120x  + 40x )\|2  \|5
+--R           + 
+--R                 14       10       6       2 4+-+2
+--R             (80x   + 360x   + 440x  + 120x )\|2
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                10       6      2  +-+      14       10       6       2
+--R         ((- 40x   - 120x  - 40x )\|5  - 80x   - 360x   - 440x  - 120x )
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R            16       12       8       4
+--R       - 80x   - 480x   - 880x  - 480x  - 80
+--R                                                    Type: Expression(Integer)
+--E 890
+
+)clear all
+
+--S 891 of 1311
+t0:=1/(x^4*(1+3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         12     8    4
+--R        x   + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 891
+
+--S 892 of 1311
+r0:=(-1/3)/x^3-1/2*atan(1-2^(3/4)*x/(3+sqrt(5))^(1/4))*_
+   (843-377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+1/2*atan(1+2^(3/4)*_
+   x/(3+sqrt(5))^(1/4))*(843-377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-_
+   1/4*log(2*x^2-2*2^(1/4)*x*(3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*_
+   (843-377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+1/4*log(2*x^2+2*2^(1/4)*x*_
+   (3+sqrt(5))^(1/4)+sqrt(2*(3+sqrt(5))))*(843-377*sqrt(5))^(1/4)/_
+   (2^(3/4)*sqrt(5))+1/2*atan(1-2^(3/4)*x/(3-sqrt(5))^(1/4))*_
+   (843+377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-1/2*atan(1+2^(3/4)*_
+   x/(3-sqrt(5))^(1/4))*(843+377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))+_
+   1/4*log(2*x^2-2*2^(1/4)*x*(3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*_
+   (843+377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))-1/4*log(2*x^2+2*2^(1/4)*x*_
+   (3-sqrt(5))^(1/4)+sqrt(2*(3-sqrt(5))))*_
+   (843+377*sqrt(5))^(1/4)/(2^(3/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R            +---------------+     +---------+          +--------+
+--R         3 4|      +-+            |  +-+          4+-+4| +-+          2
+--R       3x  \|- 377\|5  + 843 log(\|2\|5  + 6  + 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R              +---------------+     +---------+          +--------+
+--R           3 4|      +-+            |  +-+          4+-+4| +-+          2
+--R       - 3x  \|- 377\|5  + 843 log(\|2\|5  + 6  - 2x\|2 \|\|5  + 3  + 2x )
+--R     + 
+--R              +-------------+           +----------+    +-----------+
+--R           3 4|    +-+             4+-+4|   +-+         |    +-+          2
+--R       - 3x  \|377\|5  + 843 log(2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R            +-------------+             +----------+    +-----------+
+--R         3 4|    +-+               4+-+4|   +-+         |    +-+          2
+--R       3x  \|377\|5  + 843 log(- 2x\|2 \|- \|5  + 3  + \|- 2\|5  + 6  + 2x )
+--R     + 
+--R                                                             +--------+3
+--R              +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R           3 4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   + 4
+--R       - 6x  \|- 377\|5  + 843 atan(----------------------------------------)
+--R                                                        4
+--R     + 
+--R                                                             +--------+3
+--R              +---------------+        4+-+3 +-+      4+-+3 4| +-+
+--R           3 4|      +-+            (x \|2  \|5  - 3x \|2  )\|\|5  + 3   - 4
+--R       - 6x  \|- 377\|5  + 843 atan(----------------------------------------)
+--R                                                        4
+--R     + 
+--R                                                           +----------+3
+--R              +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R           3 4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   + 4
+--R       - 6x  \|377\|5  + 843 atan(------------------------------------------)
+--R                                                       4
+--R     + 
+--R                                                           +----------+3
+--R              +-------------+        4+-+3 +-+      4+-+3 4|   +-+
+--R           3 4|    +-+            (x \|2  \|5  + 3x \|2  )\|- \|5  + 3   - 4
+--R       - 6x  \|377\|5  + 843 atan(------------------------------------------)
+--R                                                       4
+--R     + 
+--R          4+-+3 +-+
+--R       - 4\|2  \|5
+--R  /
+--R        3 4+-+3 +-+
+--R     12x  \|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 892
+
+--S 893 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                       +-----------+
+--R                         8     4 4+-+2 +-+     4 4+-+2 |    +-+
+--R                   ((- 2x  - 3x )\|2  \|5  - 5x  \|2 )\|- 2\|5  + 6
+--R                 + 
+--R                      10     2 4+-+2 +-+      6 4+-+2
+--R                   (2x   - 2x )\|2  \|5  + 10x  \|2
+--R              *
+--R                  +----------+3
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                      +-----------+
+--R                         10      6     2  +-+      6  |    +-+
+--R                   ((- 6x   - 12x  - 2x )\|5  - 10x )\|- 2\|5  + 6
+--R                 + 
+--R                       8     4  +-+      8
+--R                   (12x  + 8x )\|5  - 20x
+--R              *
+--R                  +----------+
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R          *
+--R              +---------+
+--R              |  +-+
+--R             \|2\|5  + 6
+--R         + 
+--R                                            +-----------+
+--R                       8     4  +-+      4  |    +-+             10     2  +-+
+--R                   ((4x  + 6x )\|5  + 10x )\|- 2\|5  + 6  + (- 4x   + 4x )\|5
+--R                 + 
+--R                        6
+--R                   - 20x
+--R              *
+--R                  +----------+3
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                              +-----------+
+--R                       10      6     2 4+-+2 +-+      6 4+-+2 |    +-+
+--R                   ((6x   + 12x  + 2x )\|2  \|5  + 10x  \|2 )\|- 2\|5  + 6
+--R                 + 
+--R                         8     4 4+-+2 +-+      8 4+-+2
+--R                   (- 12x  - 8x )\|2  \|5  + 20x  \|2
+--R              *
+--R                  +----------+
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R          *
+--R              +--------+2
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                       10     6     2 4+-+2 +-+         6      2 4+-+2
+--R                 ((- 2x   - 6x  - 7x )\|2  \|5  + (- 10x  - 15x )\|2  )
+--R              *
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- 2\|5  + 6
+--R             + 
+--R                  12     8     4     4+-+2 +-+       8      4     4+-+2
+--R               (2x   + 3x  + 3x  - 3)\|2  \|5  + (15x  + 15x  - 5)\|2
+--R          *
+--R              +----------+3
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R         + 
+--R                                                                  +-----------+
+--R                     12      8      4      +-+      8      4      |    +-+
+--R               ((- 6x   - 21x  - 25x  - 3)\|5  - 25x  - 45x  - 5)\|- 2\|5  + 6
+--R             + 
+--R                   10      6      2  +-+      10      2
+--R               (12x   + 16x  + 12x )\|5  - 20x   + 20x
+--R          *
+--R              +----------+
+--R             4|   +-+
+--R             \|- \|5  + 3
+--R      *
+--R          +-------------+
+--R         4|    +-+
+--R         \|377\|5  + 843
+--R     + 
+--R                                          +---------------+ +----------+2
+--R                     8     4  +-+      4 4|      +-+       4|   +-+
+--R               ((- 4x  - 6x )\|5  + 10x )\|- 377\|5  + 843 \|- \|5  + 3
+--R             + 
+--R                                                 +---------------+ +-----------+
+--R                   8     4 4+-+2 +-+     4 4+-+24|      +-+        |    +-+
+--R               ((2x  + 3x )\|2  \|5  - 5x  \|2 )\|- 377\|5  + 843 \|- 2\|5  + 6
+--R             + 
+--R                     10     6     2 4+-+2 +-+         6      2 4+-+2
+--R                 ((2x   + 6x  + 7x )\|2  \|5  + (- 10x  - 15x )\|2  )
+--R              *
+--R                  +---------------+
+--R                 4|      +-+
+--R                 \|- 377\|5  + 843
+--R          *
+--R              +--------+3
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                                                              +---------------+
+--R                       10      6     2 4+-+2 +-+      6 4+-+24|      +-+
+--R                 ((- 6x   - 12x  - 2x )\|2  \|5  + 10x  \|2 )\|- 377\|5  + 843
+--R              *
+--R                  +----------+2
+--R                 4|   +-+
+--R                 \|- \|5  + 3
+--R             + 
+--R                                                +---------------+ +-----------+
+--R                   10      6     2  +-+      6 4|      +-+        |    +-+
+--R               ((6x   + 12x  + 2x )\|5  - 10x )\|- 377\|5  + 843 \|- 2\|5  + 6
+--R             + 
+--R                                                              +---------------+
+--R                 12      8      4      +-+      8      4     4|      +-+
+--R             ((6x   + 21x  + 25x  + 3)\|5  - 25x  - 45x  - 5)\|- 377\|5  + 843
+--R          *
+--R              +--------+
+--R             4| +-+
+--R             \|\|5  + 3
+--R         + 
+--R                            +----------+2                       +-----------+
+--R                 8       4 4|   +-+             8       4 4+-+2 |    +-+
+--R           (- 80x  - 240x )\|- \|5  + 3   + (40x  + 120x )\|2  \|- 2\|5  + 6
+--R         + 
+--R                 6      2 4+-+2 +-+       10       6       2 4+-+2
+--R           (- 20x  - 60x )\|2  \|5  + (40x   + 180x  + 180x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                     +---------------+ +----------+2
+--R               10     2  +-+      6 4|      +-+       4|   +-+
+--R           ((4x   - 4x )\|5  - 20x )\|- 377\|5  + 843 \|- \|5  + 3
+--R         + 
+--R                                                 +---------------+ +-----------+
+--R                 10     2 4+-+2 +-+      6 4+-+24|      +-+        |    +-+
+--R           ((- 2x   + 2x )\|2  \|5  + 10x  \|2 )\|- 377\|5  + 843 \|- 2\|5  + 6
+--R         + 
+--R                   12     8     4     4+-+2 +-+       8      4     4+-+2
+--R             ((- 2x   - 3x  - 3x  + 3)\|2  \|5  + (15x  + 15x  - 5)\|2  )
+--R          *
+--R              +---------------+
+--R             4|      +-+
+--R             \|- 377\|5  + 843
+--R      *
+--R          +--------+3
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                +----------+2                   +-----------+
+--R               8       4 4+-+2 4|   +-+              8       4  |    +-+
+--R           (80x  + 240x )\|2   \|- \|5  + 3  + (- 80x  - 240x )\|- 2\|5  + 6
+--R         + 
+--R               6       2  +-+      10       6       2
+--R           (40x  + 120x )\|5  - 80x   - 360x  - 360x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                               +---------------+ +----------+2
+--R                8     4 4+-+2 +-+      8 4+-+24|      +-+       4|   +-+
+--R           ((12x  + 8x )\|2  \|5  + 20x  \|2 )\|- 377\|5  + 843 \|- \|5  + 3
+--R         + 
+--R                                       +---------------+ +-----------+
+--R                  8     4  +-+      8 4|      +-+        |    +-+
+--R           ((- 12x  - 8x )\|5  - 20x )\|- 377\|5  + 843 \|- 2\|5  + 6
+--R         + 
+--R                                                        +---------------+
+--R                  10      6      2  +-+      10      2 4|      +-+
+--R           ((- 12x   - 16x  - 12x )\|5  - 20x   + 20x )\|- 377\|5  + 843
+--R      *
+--R          +--------+
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R                                                      +----------+2
+--R              6       2  +-+      10       6       2 4|   +-+
+--R       ((- 40x  - 120x )\|5  - 80x   - 360x  - 360x )\|- \|5  + 3
+--R     + 
+--R                                                               +-----------+
+--R            6      2 4+-+2 +-+       10       6       2 4+-+2  |    +-+
+--R       ((20x  + 60x )\|2  \|5  + (40x   + 180x  + 180x )\|2  )\|- 2\|5  + 6
+--R     + 
+--R           12       8       4       4+-+2
+--R       (40x   + 240x  + 400x  + 120)\|2
+--R  /
+--R                                  +----------+2
+--R               12       8      4 4|   +-+
+--R           (80x   + 240x  + 80x )\|- \|5  + 3
+--R         + 
+--R                                         +-----------+
+--R                 12       8      4 4+-+2 |    +-+
+--R           (- 40x   - 120x  - 40x )\|2  \|- 2\|5  + 6
+--R         + 
+--R             10      6      2 4+-+2 +-+         14       10       6      2 4+-+2
+--R         (20x   + 60x  + 20x )\|2  \|5  + (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +---------+
+--R          |  +-+
+--R         \|2\|5  + 6
+--R     + 
+--R                                          +----------+2
+--R                 12       8      4 4+-+2 4|   +-+
+--R           (- 80x   - 240x  - 80x )\|2   \|- \|5  + 3
+--R         + 
+--R                                  +-----------+
+--R               12       8      4  |    +-+              10       6      2  +-+
+--R           (80x   + 240x  + 80x )\|- 2\|5  + 6  + (- 40x   - 120x  - 40x )\|5
+--R         + 
+--R              14       10       6       2
+--R           80x   + 360x   + 440x  + 120x
+--R      *
+--R          +--------+2
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R              10       6      2  +-+      14       10       6       2
+--R         ((40x   + 120x  + 40x )\|5  + 80x   + 360x   + 440x  + 120x )
+--R      *
+--R          +----------+2
+--R         4|   +-+
+--R         \|- \|5  + 3
+--R     + 
+--R                 10      6      2 4+-+2 +-+
+--R           (- 20x   - 60x  - 20x )\|2  \|5
+--R         + 
+--R                 14       10       6      2 4+-+2
+--R           (- 40x   - 180x   - 220x  - 60x )\|2
+--R      *
+--R          +-----------+
+--R          |    +-+
+--R         \|- 2\|5  + 6
+--R     + 
+--R             16       12       8       4      4+-+2
+--R       (- 40x   - 240x   - 440x  - 240x  - 40)\|2
+--R                                                    Type: Expression(Integer)
+--E 893
+
+)clear all
+
+--S 894 of 1311
+t0:=x^m/(1-3*x^4+x^8)
+--R 
+--R
+--R              m
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                                    Type: Expression(Integer)
+--E 894
+
+--S 895 of 1311
+--r0:=2*x^(1+m)*hypergeometric(1,1/4*(1+m),1/4*(5+m),2*x^4/(3-sqrt(5)))/_
+--   ((1+m)*(3-sqrt(5))*sqrt(5))-2*x^(1+m)*hypergeometric(1,1/4*(1+m),_
+--   1/4*(5+m),2*x^4/(3+sqrt(5)))/((1+m)*sqrt(5)*(3+sqrt(5)))
+--E 895
+
+--S 896 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 896
+
+)clear all
+
+--S 897 of 1311
+t0:=x^11/(1-3*x^4+x^8)
+--R 
+--R
+--R              11
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 897
+
+--S 898 of 1311
+r0:=1/4*x^4+1/40*log(3-2*x^4-sqrt(5))*(15-7*sqrt(5))+_
+   1/40*log(3-2*x^4+sqrt(5))*(15+7*sqrt(5))
+--R 
+--R
+--R   (2)
+--R      +-+           +-+     4             +-+             +-+     4           4
+--R   (7\|5  + 15)log(\|5  - 2x  + 3) + (- 7\|5  + 15)log(- \|5  - 2x  + 3) + 10x
+--R   ----------------------------------------------------------------------------
+--R                                        40
+--R                                                    Type: Expression(Integer)
+--E 898
+
+--S 899 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 899
+
+)clear all
+
+--S 900 of 1311
+t0:=x^9/(1-3*x^4+x^8)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 900
+
+--S 901 of 1311
+r0:=1/2*x^2+1/2*atanh(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/5*(9-4*sqrt(5)))-_
+   1/2*atanh(x^2*sqrt(2/(3+sqrt(5))))*sqrt(1/5*(9+4*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                              +--------+                         +----------+
+--R        +-----------+       2 | +-+          +---------+       2 |   +-+
+--R        |    +-+           x \|\|5  + 3      |  +-+           x \|- \|5  + 3
+--R       \|- 4\|5  + 9 atanh(-------------) - \|4\|5  + 9 atanh(---------------)
+--R                                 +-+                                 +-+
+--R                                \|2                                 \|2
+--R     + 
+--R        2 +-+
+--R       x \|5
+--R  /
+--R       +-+
+--R     2\|5
+--R                                                    Type: Expression(Integer)
+--E 901
+
+--S 902 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                        +----------+ +---------+
+--R             5       +-+ +-+     5 +-+  |   +-+      |  +-+
+--R       ((- 3x  + 2x)\|2 \|5  - 5x \|2 )\|- \|5  + 3 \|4\|5  + 9
+--R     + 
+--R                                      +-----------+ +--------+
+--R           5       +-+ +-+     5 +-+  |    +-+      | +-+           5
+--R       ((3x  - 2x)\|2 \|5  - 5x \|2 )\|- 4\|5  + 9 \|\|5  + 3  + 60x  - 20x
+--R  /
+--R        8      4
+--R     20x  - 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 902
+
+)clear all
+
+--S 903 of 1311
+t0:=x^7/(1-3*x^4+x^8)
+--R 
+--R
+--R              7
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 903
+
+--S 904 of 1311
+r0:=1/40*log(3-2*x^4-sqrt(5))*(5-3*sqrt(5))+_
+   1/40*log(3-2*x^4+sqrt(5))*(5+3*sqrt(5))
+--R 
+--R
+--R           +-+          +-+     4             +-+            +-+     4
+--R        (3\|5  + 5)log(\|5  - 2x  + 3) + (- 3\|5  + 5)log(- \|5  - 2x  + 3)
+--R   (2)  -------------------------------------------------------------------
+--R                                         40
+--R                                                    Type: Expression(Integer)
+--E 904
+
+--S 905 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 905
+
+)clear all
+
+--S 906 of 1311
+t0:=x^5/(1-3*x^4+x^8)
+--R 
+--R
+--R              5
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 906
+
+--S 907 of 1311
+r0:=1/2*atanh(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/10*(3-sqrt(5)))-_
+   1/2*atanh(x^2*sqrt(2/(3+sqrt(5))))*sqrt(1/10*(3+sqrt(5)))
+--R 
+--R
+--R                              +--------+                        +----------+
+--R         +----------+       2 | +-+          +--------+       2 |   +-+
+--R         |   +-+           x \|\|5  + 3      | +-+           x \|- \|5  + 3
+--R        \|- \|5  + 3 atanh(-------------) - \|\|5  + 3 atanh(---------------)
+--R                                 +-+                                +-+
+--R                                \|2                                \|2
+--R   (2)  ---------------------------------------------------------------------
+--R                                          +--+
+--R                                        2\|10
+--R                                                    Type: Expression(Integer)
+--E 907
+
+--S 908 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                          +----------+ +--------+
+--R           5 +-+ +-+ +--+ |   +-+      | +-+           5
+--R        - x \|2 \|5 \|10 \|- \|5  + 3 \|\|5  + 3  + 20x
+--R   (3)  ------------------------------------------------
+--R                           8      4
+--R                        20x  - 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 908
+
+)clear all
+
+--S 909 of 1311
+t0:=x^3/(1-3*x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 909
+
+--S 910 of 1311
+r0:=1/2*atanh((3-2*x^4)/sqrt(5))/sqrt(5)
+--R 
+--R
+--R                   4      +-+
+--R                (2x  - 3)\|5
+--R          atanh(-------------)
+--R                      5
+--R   (2)  - --------------------
+--R                    +-+
+--R                  2\|5
+--R                                                    Type: Expression(Integer)
+--E 910
+
+--S 911 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 911
+
+)clear all
+
+--S 912 of 1311
+t0:=x/(1-3*x^4+x^8)
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 912
+
+--S 913 of 1311
+r0:=1/2*atanh(x^2*sqrt(1/2*(3+sqrt(5))))*sqrt(1/10*(3+sqrt(5)))-_
+   atanh(x^2*sqrt(2/(3+sqrt(5))))/sqrt(10*(3+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                     +--------+                   +----------+
+--R    +--------+ +-----------+       2 | +-+                      2 |   +-+
+--R    | +-+      |   +-+            x \|\|5  + 3       +--+      x \|- \|5  + 3
+--R   \|\|5  + 3 \|10\|5  + 30 atanh(-------------) - 2\|10 atanh(---------------)
+--R                                        +-+                           +-+
+--R                                       \|2                           \|2
+--R   ----------------------------------------------------------------------------
+--R                                      +-----------+
+--R                                 +--+ |   +-+
+--R                               2\|10 \|10\|5  + 30
+--R                                                    Type: Expression(Integer)
+--E 913
+
+--S 914 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                         +----------+ +-----------+
+--R           5 +-+ +-+        5       +-+  |   +-+      |   +-+
+--R       (- x \|2 \|5  + (- 3x  + 2x)\|2 )\|- \|5  + 3 \|10\|5  + 30
+--R     + 
+--R           5       +-+ +-+      5        +-+  +--+       +-+
+--R       ((2x  - 6x)\|2 \|5  + (6x  - 14x)\|2 )\|10  + 20x\|5  + 60x
+--R  /
+--R         8      4       +-+      8       4
+--R     (20x  - 60x  + 20)\|5  + 60x  - 180x  + 60
+--R                                                    Type: Expression(Integer)
+--E 914
+
+)clear all
+
+--S 915 of 1311
+t0:=1/(x*(1-3*x^4+x^8))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         9     5
+--R        x  - 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 915
+
+--S 916 of 1311
+r0:=log(x)-1/40*log(3-2*x^4+sqrt(5))*(5-3*sqrt(5))-_
+   1/40*log(3-2*x^4-sqrt(5))*(5+3*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          +-+          +-+     4
+--R       (3\|5  - 5)log(\|5  - 2x  + 3) + 40log(x)
+--R     + 
+--R            +-+            +-+     4
+--R       (- 3\|5  - 5)log(- \|5  - 2x  + 3)
+--R  /
+--R     40
+--R                                                    Type: Expression(Integer)
+--E 916
+
+--S 917 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 917
+
+)clear all
+
+--S 918 of 1311
+t0:=1/(x^3*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         11     7    3
+--R        x   - 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 918
+
+--S 919 of 1311
+r0:=(-1/2)/x^2+1/4*atanh(x^2*sqrt(1/2*(3+sqrt(5))))*_
+   (3+sqrt(5))^(3/2)/sqrt(10)-1/2*atanh(x^2*sqrt(2/(3+sqrt(5))))*_
+   sqrt(1/5*(9-4*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                          +--------+
+--R                       +--------+       2 | +-+
+--R          2 +-+     2  | +-+           x \|\|5  + 3
+--R       (3x \|5  + 5x )\|\|5  + 3 atanh(-------------)
+--R                                             +-+
+--R                                            \|2
+--R     + 
+--R                                        +----------+
+--R                  +-----------+       2 |   +-+
+--R           2 +--+ |    +-+           x \|- \|5  + 3       +-+ +--+
+--R       - 2x \|10 \|- 4\|5  + 9 atanh(---------------) - 2\|5 \|10
+--R                                            +-+
+--R                                           \|2
+--R  /
+--R       2 +-+ +--+
+--R     4x \|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 919
+
+--S 920 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                        +-----------+ +----------+
+--R             5       +-+ +-+     5 +-+  |    +-+      |   +-+
+--R       ((- 3x  + 2x)\|2 \|5  - 5x \|2 )\|- 4\|5  + 9 \|- \|5  + 3
+--R     + 
+--R          5       +-+ +-+      5       +-+  +--+      5
+--R       ((x  - 3x)\|2 \|5  + (3x  - 7x)\|2 )\|10  - 20x  + 60x
+--R  /
+--R        8      4
+--R     20x  - 60x  + 20
+--R                                                    Type: Expression(Integer)
+--E 920
+
+)clear all
+
+--S 921 of 1311
+t0:=1/(x^5*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         13     9    5
+--R        x   - 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 921
+
+--S 922 of 1311
+r0:=(-1/4)/x^4+3*log(x)-1/40*log(3-2*x^4+sqrt(5))*(15-7*sqrt(5))-_
+   1/40*log(3-2*x^4-sqrt(5))*(15+7*sqrt(5))
+--R 
+--R
+--R   (2)
+--R          4 +-+      4      +-+     4            4
+--R       (7x \|5  - 15x )log(\|5  - 2x  + 3) + 120x log(x)
+--R     + 
+--R            4 +-+      4        +-+     4
+--R       (- 7x \|5  - 15x )log(- \|5  - 2x  + 3) - 10
+--R  /
+--R        4
+--R     40x
+--R                                                    Type: Expression(Integer)
+--E 922
+
+--S 923 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 923
+
+)clear all
+
+--S 924 of 1311
+t0:=1/(x^7*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         15     11    7
+--R        x   - 3x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 924
+
+--S 925 of 1311
+r0:=(-1/6)/x^6+(-3/2)/x^2-1/2*atanh(x^2*sqrt(2/(3+sqrt(5))))*_
+   sqrt(1/10*(123-55*sqrt(5)))+1/2*atanh(x^2*sqrt(1/2*(3+sqrt(5))))*_
+   sqrt(1/10*(123+55*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                  +--------+
+--R           +------------+       2 | +-+
+--R         6 |   +-+             x \|\|5  + 3
+--R       3x \|55\|5  + 123 atanh(-------------)
+--R                                     +-+
+--R                                    \|2
+--R     + 
+--R                                      +----------+
+--R             +--------------+       2 |   +-+
+--R           6 |     +-+             x \|- \|5  + 3          4      +--+
+--R       - 3x \|- 55\|5  + 123 atanh(---------------) + (- 9x  - 1)\|10
+--R                                          +-+
+--R                                         \|2
+--R  /
+--R       6 +--+
+--R     6x \|10
+--R                                                    Type: Expression(Integer)
+--E 925
+
+--S 926 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                            +--------+ +------------+
+--R           5 +-+ +-+      5       +-+  +--+ | +-+      |   +-+
+--R       (- x \|2 \|5  + (3x  - 2x)\|2 )\|10 \|\|5  + 3 \|55\|5  + 123
+--R     + 
+--R                                              +--------------+ +----------+
+--R           5 +-+ +-+        5       +-+  +--+ |     +-+        |   +-+
+--R       (- x \|2 \|5  + (- 3x  + 2x)\|2 )\|10 \|- 55\|5  + 123 \|- \|5  + 3
+--R     + 
+--R             5
+--R       - 120x  + 320x
+--R  /
+--R        8       4
+--R     40x  - 120x  + 40
+--R                                                    Type: Expression(Integer)
+--E 926
+
+)clear all
+
+--S 927 of 1311
+t0:=x^8/(1-3*x^4+x^8)
+--R 
+--R
+--R              8
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 927
+
+--S 928 of 1311
+r0:=x+1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(123-55*sqrt(5))^(1/4)/_
+   (2^(1/4)*sqrt(5))+1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (123-55*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))-1/2*atan(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(123+55*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))-_
+   1/2*atanh(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*(123+55*sqrt(5))^(1/4)/_
+   (2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                       +--------+
+--R        +--------------+        4+-+3 4| +-+
+--R       4|     +-+             x \|2   \|\|5  + 3
+--R       \|- 55\|5  + 123 atanh(------------------)
+--R                                       2
+--R     + 
+--R                                    +----------+
+--R          +------------+       4+-+4|   +-+
+--R         4|   +-+             x\|2 \|- \|5  + 3
+--R       - \|55\|5  + 123 atanh(------------------)
+--R                                      +-+
+--R                                     \|2
+--R     + 
+--R                                      +--------+
+--R        +--------------+       4+-+3 4| +-+
+--R       4|     +-+            x \|2   \|\|5  + 3
+--R       \|- 55\|5  + 123 atan(------------------)
+--R                                      2
+--R     + 
+--R                                   +----------+
+--R          +------------+      4+-+4|   +-+
+--R         4|   +-+            x\|2 \|- \|5  + 3       4+-+ +-+
+--R       - \|55\|5  + 123 atan(------------------) + 2x\|2 \|5
+--R                                     +-+
+--R                                    \|2
+--R  /
+--R      4+-+ +-+
+--R     2\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 928
+
+--S 929 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                               +----------+ +------------+
+--R             4      +-+     4 4|   +-+     4|   +-+
+--R       ((- 3x  + 2)\|5  - 5x )\|- \|5  + 3 \|55\|5  + 123
+--R     + 
+--R                             +--------------+ +--------+
+--R           4      +-+     4 4|     +-+       4| +-+            4      4+-+2
+--R       ((3x  - 2)\|5  - 5x )\|- 55\|5  + 123 \|\|5  + 3  + (30x  - 10)\|2
+--R  /
+--R         8      4      4+-+2
+--R     (10x  - 30x  + 10)\|2
+--R                                                    Type: Expression(Integer)
+--E 929
+
+)clear all
+
+--S 930 of 1311
+t0:=x^6/(1-3*x^4+x^8)
+--R 
+--R
+--R              6
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 930
+
+--S 931 of 1311
+r0:=-1/4*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(144-64*sqrt(5))^(1/4)/sqrt(5)+_
+   1/4*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*(144-64*sqrt(5))^(1/4)/sqrt(5)+_
+   1/2*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*(3+sqrt(5))^(3/4)/_
+   (2^(3/4)*sqrt(5))-1/2*atanh(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (3+sqrt(5))^(3/4)/(2^(3/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                             +--------+
+--R              +--------------+        4+-+3 4| +-+
+--R       4+-+3 4|     +-+             x \|2   \|\|5  + 3
+--R       \|2   \|- 64\|5  + 144 atanh(------------------)
+--R                                             2
+--R     + 
+--R                                  +----------+
+--R           +--------+3       4+-+4|   +-+
+--R          4| +-+            x\|2 \|- \|5  + 3
+--R       - 2\|\|5  + 3  atanh(------------------)
+--R                                    +-+
+--R                                   \|2
+--R     + 
+--R                                              +--------+
+--R                +--------------+       4+-+3 4| +-+
+--R         4+-+3 4|     +-+            x \|2   \|\|5  + 3
+--R       - \|2   \|- 64\|5  + 144 atan(------------------)
+--R                                              2
+--R     + 
+--R                               +----------+
+--R         +--------+3      4+-+4|   +-+
+--R        4| +-+           x\|2 \|- \|5  + 3
+--R       2\|\|5  + 3  atan(------------------)
+--R                                 +-+
+--R                                \|2
+--R  /
+--R      4+-+3 +-+
+--R     4\|2  \|5
+--R                                                    Type: Expression(Integer)
+--E 931
+
+--S 932 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                               +----------+3
+--R                 6     2 4+-+2 +-+     6 4+-+24|   +-+
+--R           ((- 3x  + 2x )\|2  \|5  - 5x  \|2 )\|- \|5  + 3
+--R         + 
+--R                                           +--------------+
+--R               6     2 4+-+ +-+     6 4+-+4|     +-+
+--R           ((3x  - 2x )\|2 \|5  - 5x  \|2)\|- 64\|5  + 144
+--R      *
+--R          +--------+3
+--R         4| +-+
+--R         \|\|5  + 3
+--R     + 
+--R          6
+--R       40x
+--R  /
+--R        8       4
+--R     40x  - 120x  + 40
+--R                                                    Type: Expression(Integer)
+--E 932
+
+)clear all
+
+--S 933 of 1311
+t0:=x^4/(1-3*x^4+x^8)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 933
+
+--S 934 of 1311
+r0:=1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(3-sqrt(5))^(1/4)/(2^(1/4)*_
+   sqrt(5))+1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*(3-sqrt(5))^(1/4)/_
+   (2^(1/4)*sqrt(5))-1/2*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))-1/2*atanh(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                   +--------+
+--R        +----------+        4+-+3 4| +-+
+--R       4|   +-+           x \|2   \|\|5  + 3
+--R       \|- \|5  + 3 atanh(------------------)
+--R                                   2
+--R     + 
+--R                                +----------+
+--R          +--------+       4+-+4|   +-+
+--R         4| +-+           x\|2 \|- \|5  + 3
+--R       - \|\|5  + 3 atanh(------------------)
+--R                                  +-+
+--R                                 \|2
+--R     + 
+--R                                +--------+                         +----------+
+--R      +----------+       4+-+3 4| +-+         +--------+      4+-+4|   +-+
+--R     4|   +-+          x \|2   \|\|5  + 3    4| +-+          x\|2 \|- \|5  + 3
+--R     \|- \|5  + 3 atan(------------------) - \|\|5  + 3 atan(------------------)
+--R                                2                                    +-+
+--R                                                                    \|2
+--R  /
+--R      4+-+ +-+
+--R     2\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 934
+
+--S 935 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              +----------+ +--------+
+--R           4 4|   +-+     4| +-+        4 4+-+2
+--R        - x  \|- \|5  + 3 \|\|5  + 3 + x  \|2
+--R   (3)  --------------------------------------
+--R                    8     4     4+-+2
+--R                  (x  - 3x  + 1)\|2
+--R                                                    Type: Expression(Integer)
+--E 935
+
+)clear all
+
+--S 936 of 1311
+t0:=x^2/(1-3*x^4+x^8)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 936
+
+--S 937 of 1311
+--r0a:=1/20*atan(1/2*x*sqrt(-2+2*sqrt(5)))*sqrt(-10+10*sqrt(5))-
+--  1/20*atanh(1/2*x*sqrt(-2+2*sqrt(5)))*sqrt(-10+10*sqrt(5))-
+--  1/20*atan(1/2*x*sqrt(2+2*sqrt(5)))*sqrt(10+10*sqrt(5))+
+--  1/20*atanh(1/2*x*sqrt(2+2*sqrt(5)))*sqrt(10+10*sqrt(5))
+--E 937
+
+--S 938 of 1311
+r0b:=atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))/(2^(3/4)*sqrt(5)*_
+   (3+sqrt(5))^(1/4))-atanh(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))/(2^(3/4)*_
+   sqrt(5)*(3+sqrt(5))^(1/4))-1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))+_
+   1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*(3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                        +--------+               +----------+
+--R              +--------+2        4+-+3 4| +-+               4+-+4|   +-+
+--R       4+-+2 4| +-+            x \|2   \|\|5  + 3          x\|2 \|- \|5  + 3
+--R       \|2   \|\|5  + 3  atanh(------------------ - 2atanh(------------------)
+--R                                        2                          +-+
+--R                                                                  \|2
+--R     + 
+--R                                         +--------+              +----------+
+--R                +--------+2       4+-+3 4| +-+              4+-+4|   +-+
+--R         4+-+2 4| +-+           x \|2   \|\|5  + 3         x\|2 \|- \|5  + 3
+--R       - \|2   \|\|5  + 3  atan(------------------ + 2atan(------------------)
+--R                                         2                         +-+
+--R                                                                  \|2
+--R  /
+--R                +--------+
+--R      4+-+3 +-+4| +-+
+--R     2\|2  \|5 \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 938
+
+--S 939 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              2
+--R             x
+--R   (3)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                                    Type: Expression(Integer)
+--E 939
+
+)clear all
+
+--S 940 of 1311
+t0:=1/(1-3*x^4+x^8)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         8     4
+--R        x  - 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 940
+
+--S 941 of 1311
+r0:=-atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))/(2^(1/4)*sqrt(5)*_
+   (3+sqrt(5))^(3/4))-atanh(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))/(2^(1/4)*_
+   sqrt(5)*(3+sqrt(5))^(3/4))+1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (9+4*sqrt(5))^(1/4)/sqrt(5)+1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (9+4*sqrt(5))^(1/4)/sqrt(5)
+--R 
+--R
+--R   (2)
+--R                                                   +--------+
+--R            +--------+3  +---------+        4+-+3 4| +-+
+--R       4+-+4| +-+       4|  +-+           x \|2   \|\|5  + 3
+--R       \|2 \|\|5  + 3   \|4\|5  + 9 atanh(------------------)
+--R                                                   2
+--R     + 
+--R                      +----------+
+--R                 4+-+4|   +-+
+--R                x\|2 \|- \|5  + 3
+--R       - 2atanh(------------------)
+--R                        +-+
+--R                       \|2
+--R     + 
+--R                                                  +--------+
+--R            +--------+3  +---------+       4+-+3 4| +-+
+--R       4+-+4| +-+       4|  +-+          x \|2   \|\|5  + 3
+--R       \|2 \|\|5  + 3   \|4\|5  + 9 atan(------------------)
+--R                                                  2
+--R     + 
+--R                     +----------+
+--R                4+-+4|   +-+
+--R               x\|2 \|- \|5  + 3
+--R       - 2atan(------------------)
+--R                       +-+
+--R                      \|2
+--R  /
+--R               +--------+3
+--R      4+-+ +-+4| +-+
+--R     2\|2 \|5 \|\|5  + 3
+--R                                                    Type: Expression(Integer)
+--E 941
+
+--S 942 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                            +--------+ +---------+
+--R           4      +-+      4| +-+     4|  +-+
+--R       ((4x  - 6)\|5  - 10)\|\|5  + 3 \|4\|5  + 9
+--R     + 
+--R                                         +----------+ +--------+
+--R             4     4+-+3 +-+     4 4+-+34|   +-+     4| +-+          4+-+ +-+
+--R       ((- 3x  + 2)\|2  \|5  - 5x  \|2 )\|- \|5  + 3 \|\|5  + 3  + 10\|2 \|5
+--R     + 
+--R         4+-+
+--R       30\|2
+--R  /
+--R         8      4      4+-+ +-+       8      4      4+-+
+--R     (10x  - 30x  + 10)\|2 \|5  + (30x  - 90x  + 30)\|2
+--R                                                    Type: Expression(Integer)
+--E 942
+
+)clear all
+
+--S 943 of 1311
+t0:=1/(x^2*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         10     6    2
+--R        x   - 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 943
+
+--S 944 of 1311
+r0:=(-1)/x+1/4*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (984-440*sqrt(5))^(1/4)/sqrt(5)-1/4*atanh(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(984-440*sqrt(5))^(1/4)/sqrt(5)-_
+   1/4*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(3+sqrt(5))^(5/4)/(2^(1/4)*_
+   sqrt(5))+1/4*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*(3+sqrt(5))^(5/4)/_
+   (2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                             +--------+
+--R                    +--------+        4+-+3 4| +-+
+--R          +-+      4| +-+           x \|2   \|\|5  + 3
+--R       (x\|5  + 3x)\|\|5  + 3 atanh(------------------)
+--R                                             2
+--R     + 
+--R                                            +----------+
+--R               +---------------+       4+-+4|   +-+
+--R          4+-+4|      +-+             x\|2 \|- \|5  + 3
+--R       - x\|2 \|- 440\|5  + 984 atanh(------------------)
+--R                                              +-+
+--R                                             \|2
+--R     + 
+--R                                              +--------+
+--R                      +--------+       4+-+3 4| +-+
+--R            +-+      4| +-+          x \|2   \|\|5  + 3
+--R       (- x\|5  - 3x)\|\|5  + 3 atan(------------------)
+--R                                              2
+--R     + 
+--R                                         +----------+
+--R             +---------------+      4+-+4|   +-+
+--R        4+-+4|      +-+            x\|2 \|- \|5  + 3      4+-+ +-+
+--R       x\|2 \|- 440\|5  + 984 atan(------------------) - 4\|2 \|5
+--R                                           +-+
+--R                                          \|2
+--R  /
+--R       4+-+ +-+
+--R     4x\|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 944
+
+--S 945 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                         +---------------+ +----------+3
+--R             6     2 4+-+ +-+     6 4+-+4|      +-+       4|   +-+
+--R       ((- 3x  + 2x )\|2 \|5  - 5x  \|2)\|- 440\|5  + 984 \|- \|5  + 3
+--R     + 
+--R           6      2  +-+      6      2
+--R       (12x  - 28x )\|5  - 20x  + 60x
+--R  /
+--R        8       4
+--R     40x  - 120x  + 40
+--R                                                    Type: Expression(Integer)
+--E 945
+
+)clear all
+
+--S 946 of 1311
+t0:=1/(x^4*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         12     8    4
+--R        x   - 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 946
+
+--S 947 of 1311
+r0:=(-1/3)/x^3-1/2*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (843-377*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))-1/2*atanh(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(843-377*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))+_
+   1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(843+377*sqrt(5))^(1/4)/_
+   (2^(1/4)*sqrt(5))+1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (843+377*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                          +--------+
+--R            +-------------+        4+-+3 4| +-+
+--R         3 4|    +-+             x \|2   \|\|5  + 3
+--R       3x  \|377\|5  + 843 atanh(------------------)
+--R                                          2
+--R     + 
+--R                                           +----------+
+--R              +---------------+       4+-+4|   +-+
+--R           3 4|      +-+             x\|2 \|- \|5  + 3
+--R       - 3x  \|- 377\|5  + 843 atanh(------------------)
+--R                                             +-+
+--R                                            \|2
+--R     + 
+--R                                         +--------+
+--R            +-------------+       4+-+3 4| +-+
+--R         3 4|    +-+            x \|2   \|\|5  + 3
+--R       3x  \|377\|5  + 843 atan(------------------)
+--R                                         2
+--R     + 
+--R                                          +----------+
+--R              +---------------+      4+-+4|   +-+
+--R           3 4|      +-+            x\|2 \|- \|5  + 3     4+-+ +-+
+--R       - 3x  \|- 377\|5  + 843 atan(------------------ - 2\|2 \|5
+--R                                            +-+
+--R                                           \|2
+--R  /
+--R       3 4+-+ +-+
+--R     6x  \|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 947
+
+--S 948 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                             +--------+ +-------------+
+--R           4      +-+     4 4| +-+     4|    +-+
+--R       ((3x  - 2)\|5  - 5x )\|\|5  + 3 \|377\|5  + 843
+--R     + 
+--R                             +---------------+ +----------+
+--R           4      +-+     4 4|      +-+       4|   +-+              4      4+-+2
+--R     ((- 3x  + 2)\|5  - 5x )\|- 377\|5  + 843 \|- \|5  + 3  + (- 10x  + 30)\|2
+--R  /
+--R         8      4      4+-+2
+--R     (10x  - 30x  + 10)\|2
+--R                                                    Type: Expression(Integer)
+--E 948
+
+)clear all
+
+--S 949 of 1311
+t0:=1/(x^6*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         14     10    6
+--R        x   - 3x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 949
+
+--S 950 of 1311
+r0:=(-1/5)/x^5+(-3)/x+1/4*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (46224-20672*sqrt(5))^(1/4)/sqrt(5)-1/4*atanh(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(46224-20672*sqrt(5))^(1/4)/sqrt(5)-_
+   1/4*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*(46224+20672*sqrt(5))^(1/4)/_
+   sqrt(5)+1/4*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (46224+20672*sqrt(5))^(1/4)/sqrt(5)
+--R 
+--R
+--R   (2)
+--R                                              +--------+
+--R            +-----------------+        4+-+3 4| +-+
+--R         5 4|      +-+               x \|2   \|\|5  + 3
+--R       5x  \|20672\|5  + 46224 atanh(------------------)
+--R                                              2
+--R     + 
+--R                                               +----------+
+--R              +-------------------+       4+-+4|   +-+
+--R           5 4|        +-+               x\|2 \|- \|5  + 3
+--R       - 5x  \|- 20672\|5  + 46224 atanh(------------------)
+--R                                                 +-+
+--R                                                \|2
+--R     + 
+--R                                               +--------+
+--R              +-----------------+       4+-+3 4| +-+
+--R           5 4|      +-+              x \|2   \|\|5  + 3
+--R       - 5x  \|20672\|5  + 46224 atan(------------------)
+--R                                               2
+--R     + 
+--R                                            +----------+
+--R            +-------------------+      4+-+4|   +-+
+--R         5 4|        +-+              x\|2 \|- \|5  + 3          4      +-+
+--R       5x  \|- 20672\|5  + 46224 atan(------------------ + (- 60x  - 4)\|5
+--R                                              +-+
+--R                                             \|2
+--R  /
+--R        5 +-+
+--R     20x \|5
+--R                                                    Type: Expression(Integer)
+--E 950
+
+--S 951 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                       +--------+3  +-----------------+
+--R           6     2 4+-+ +-+     6 4+-+4| +-+       4|      +-+
+--R       ((3x  - 2x )\|2 \|5  - 5x  \|2)\|\|5  + 3   \|20672\|5  + 46224
+--R     + 
+--R                                         +-------------------+ +----------+3
+--R             6     2 4+-+ +-+     6 4+-+4|        +-+         4|   +-+
+--R       ((- 3x  + 2x )\|2 \|5  - 5x  \|2)\|- 20672\|5  + 46224 \|- \|5  + 3
+--R     + 
+--R             6       2
+--R       - 120x  + 320x
+--R  /
+--R        8       4
+--R     40x  - 120x  + 40
+--R                                                    Type: Expression(Integer)
+--E 951
+
+)clear all
+
+--S 952 of 1311
+t0:=1/(x^8*(1-3*x^4+x^8))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         16     12    8
+--R        x   - 3x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 952
+
+--S 953 of 1311
+r0:=(-1/7)/x^7+(-1)/x^3-1/2*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*_
+   (39603-17711*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))-1/2*atanh(2^(1/4)*x*_
+   (1/(3+sqrt(5)))^(1/4))*(39603-17711*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))+_
+   1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (39603+17711*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))+_
+   1/2*atanh(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (39603+17711*sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))
+--R 
+--R
+--R   (2)
+--R                                              +--------+
+--R            +-----------------+        4+-+3 4| +-+
+--R         7 4|      +-+               x \|2   \|\|5  + 3
+--R       7x  \|17711\|5  + 39603 atanh(------------------)
+--R                                              2
+--R     + 
+--R                                               +----------+
+--R              +-------------------+       4+-+4|   +-+
+--R           7 4|        +-+               x\|2 \|- \|5  + 3
+--R       - 7x  \|- 17711\|5  + 39603 atanh(------------------)
+--R                                                 +-+
+--R                                                \|2
+--R     + 
+--R                                             +--------+
+--R            +-----------------+       4+-+3 4| +-+
+--R         7 4|      +-+              x \|2   \|\|5  + 3
+--R       7x  \|17711\|5  + 39603 atan(------------------)
+--R                                             2
+--R     + 
+--R                                            +----------+
+--R            +-------------------+      4+-+4|   +-+
+--R         7 4|        +-+              x\|2 \|- \|5  + 3          4     4+-+ +-+
+--R     - 7x  \|- 17711\|5  + 39603 atan(------------------ + (- 14x  - 2)\|2 \|5
+--R                                              +-+
+--R                                             \|2
+--R  /
+--R        7 4+-+ +-+
+--R     14x  \|2 \|5
+--R                                                    Type: Expression(Integer)
+--E 953
+
+--S 954 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                             +--------+ +-----------------+
+--R           4      +-+     4 4| +-+     4|      +-+
+--R       ((3x  - 2)\|5  - 5x )\|\|5  + 3 \|17711\|5  + 39603
+--R     + 
+--R                               +-------------------+ +----------+
+--R             4      +-+     4 4|        +-+         4|   +-+
+--R       ((- 3x  + 2)\|5  - 5x )\|- 17711\|5  + 39603 \|- \|5  + 3
+--R     + 
+--R             4      4+-+2
+--R       (- 30x  + 80)\|2
+--R  /
+--R         8      4      4+-+2
+--R     (10x  - 30x  + 10)\|2
+--R                                                    Type: Expression(Integer)
+--E 954
+
+)clear all
+
+--S 955 of 1311
+t0:=x^3/(2+3*x^4+x^8)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 955
+
+--S 956 of 1311
+r0:=-1/2*atanh(3+2*x^4)
+--R 
+--R
+--R                  4
+--R          atanh(2x  + 3)
+--R   (2)  - --------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 956
+
+--S 957 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 957
+
+)clear all
+
+--S 958 of 1311
+t0:=x^11/(2+3*x^4+x^8)
+--R 
+--R
+--R              11
+--R             x
+--R   (1)  ------------
+--R         8     4
+--R        x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 958
+
+--S 959 of 1311
+r0:=1/4*x^4+1/4*log(1+x^4)-log(2+x^4)
+--R 
+--R
+--R                4             4         4
+--R        - 4log(x  + 2) + log(x  + 1) + x
+--R   (2)  ---------------------------------
+--R                        4
+--R                                                    Type: Expression(Integer)
+--E 959
+
+--S 960 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 960
+
+)clear all
+
+--S 961 of 1311
+t0:=x^9/(2+x^5+x^10)
+--R 
+--R
+--R              9
+--R             x
+--R   (1)  ------------
+--R         10    5
+--R        x   + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 961
+
+--S 962 of 1311
+r0:=1/10*log(2+x^5+x^10)-1/5*atan((1+2*x^5)/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                                         5      +-+
+--R         +-+     10    5              (2x  + 1)\|7
+--R        \|7 log(x   + x  + 2) - 2atan(-------------)
+--R                                            7
+--R   (2)  --------------------------------------------
+--R                              +-+
+--R                           10\|7
+--R                                                    Type: Expression(Integer)
+--E 962
+
+--S 963 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 963
+
+)clear all
+
+--S 964 of 1311
+t0:=x^4/(2+x^5+x^10)
+--R 
+--R
+--R              4
+--R             x
+--R   (1)  ------------
+--R         10    5
+--R        x   + x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 964
+
+--S 965 of 1311
+r0:=2/5*atan((1+2*x^5)/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                 5      +-+
+--R              (2x  + 1)\|7
+--R        2atan(-------------)
+--R                    7
+--R   (2)  --------------------
+--R                  +-+
+--R                5\|7
+--R                                                    Type: Expression(Integer)
+--E 965
+
+--S 966 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 966
+
+)clear all
+
+--S 967 of 1311
+t0:=1/(x*(1+x^5+x^10))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         11    6
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 967
+
+--S 968 of 1311
+r0:=log(x)-1/10*log(1+x^5+x^10)-1/5*atan((1+2*x^5)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                          5      +-+
+--R           +-+     10    5           +-+               (2x  + 1)\|3
+--R        - \|3 log(x   + x  + 1) + 10\|3 log(x) - 2atan(-------------)
+--R                                                             3
+--R   (2)  -------------------------------------------------------------
+--R                                       +-+
+--R                                    10\|3
+--R                                                    Type: Expression(Integer)
+--E 968
+
+--S 969 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 969
+
+)clear all
+
+--S 970 of 1311
+t0:=1/(x^6*(1+x^5+x^10))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         16    11    6
+--R        x   + x   + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 970
+
+--S 971 of 1311
+r0:=(-1/5)/x^5-log(x)+1/10*log(1+x^5+x^10)-1/5*atan((1+2*x^5)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                         5      +-+
+--R    5 +-+     10    5           5 +-+           5     (2x  + 1)\|3       +-+
+--R   x \|3 log(x   + x  + 1) - 10x \|3 log(x) - 2x atan(-------------) - 2\|3
+--R                                                            3
+--R   -------------------------------------------------------------------------
+--R                                       5 +-+
+--R                                    10x \|3
+--R                                                    Type: Expression(Integer)
+--E 971
+
+--S 972 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 972
+
+)clear all
+
+--S 973 of 1311
+t0:=1/(x+x^6+x^11)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         11    6
+--R        x   + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 973
+
+--S 974 of 1311
+r0:=log(x)-1/10*log(1+x^5+x^10)-1/5*atan((1+2*x^5)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                          5      +-+
+--R           +-+     10    5           +-+               (2x  + 1)\|3
+--R        - \|3 log(x   + x  + 1) + 10\|3 log(x) - 2atan(-------------)
+--R                                                             3
+--R   (2)  -------------------------------------------------------------
+--R                                       +-+
+--R                                    10\|3
+--R                                                    Type: Expression(Integer)
+--E 974
+
+--S 975 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 975
+
+)clear all
+
+--S 976 of 1311
+t0:=x^(-1+4*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            4n - 1
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 976
+
+--S 977 of 1311
+r0:=-b*x^n/(c^2*n)+1/2*x^(2*n)/(c*n)+b^2*log(b+c*x^n)/(c^3*n)
+--R 
+--R
+--R          2       n         2 2n         n
+--R        2b log(c x  + b) + c x   - 2b c x
+--R   (2)  ----------------------------------
+--R                         3
+--R                       2c n
+--R                                                    Type: Expression(Integer)
+--E 977
+
+--S 978 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 978
+
+)clear all
+
+--S 979 of 1311
+t0:=x^(-1+3*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            3n - 1
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 979
+
+--S 980 of 1311
+r0:=x^n/(c*n)-b*log(b+c*x^n)/(c^2*n)
+--R 
+--R
+--R                   n           n
+--R        - b log(c x  + b) + c x
+--R   (2)  ------------------------
+--R                    2
+--R                   c n
+--R                                                    Type: Expression(Integer)
+--E 980
+
+--S 981 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 981
+
+)clear all
+
+--S 982 of 1311
+t0:=x^(-1+2*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            2n - 1
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 982
+
+--S 983 of 1311
+r0:=log(b+c*x^n)/(c*n)
+--R 
+--R
+--R               n
+--R        log(c x  + b)
+--R   (2)  -------------
+--R             c n
+--R                                                    Type: Expression(Integer)
+--E 983
+
+--S 984 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 984
+
+)clear all
+
+--S 985 of 1311
+t0:=x^(-1+n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 1
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 985
+
+--S 986 of 1311
+r0:=log(x)/b-log(b+c*x^n)/(b*n)
+--R 
+--R
+--R                 n
+--R        - log(c x  + b) + n log(x)
+--R   (2)  --------------------------
+--R                    b n
+--R                                                    Type: Expression(Integer)
+--E 986
+
+--S 987 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 987
+
+)clear all
+
+--S 988 of 1311
+t0:=x^(-1-n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - n - 1
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 988
+
+--S 989 of 1311
+r0:=(-1/2)/(b*n*x^(2*n))+c/(b^2*n*x^n)+c^2*log(x)/b^3-c^2*log(b+c*x^n)/(b^3*n)
+--R 
+--R
+--R            2 n 2n       n           2         n         2n    2 n
+--R        - 2c x x  log(c x  + b) + (2c n log(x)x  + 2b c)x   - b x
+--R   (2)  ----------------------------------------------------------
+--R                                  3   n 2n
+--R                                2b n x x
+--R                                                    Type: Expression(Integer)
+--E 989
+
+--S 990 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 990
+
+)clear all
+
+--S 991 of 1311
+t0:=x^(-1-2*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - 2n - 1
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 991
+
+--S 992 of 1311
+r0:=(-1/3)/(b*n*x^(3*n))+1/2*c/(b^2*n*x^(2*n))-c^2/(b^3*n*x^n)-_
+   c^3*log(x)/b^4+c^3*log(b+c*x^n)/(b^4*n)
+--R 
+--R
+--R   (2)
+--R         3 n 2n 3n       n              3         n       2  2n     2   n  3n
+--R       6c x x  x  log(c x  + b) + ((- 6c n log(x)x  - 6b c )x   + 3b c x )x
+--R     + 
+--R           3 n 2n
+--R       - 2b x x
+--R  /
+--R       4   n 2n 3n
+--R     6b n x x  x
+--R                                                    Type: Expression(Integer)
+--E 992
+
+--S 993 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 993
+
+)clear all
+
+--S 994 of 1311
+t0:=x^(-1-3*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - 3n - 1
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 994
+
+--S 995 of 1311
+r0:=(-1/4)/(b*n*x^(4*n))+1/3*c/(b^2*n*x^(3*n))-1/2*c^2/(b^3*n*x^(2*n))+_
+   c^3/(b^4*n*x^n)+c^4*log(x)/b^5-c^4*log(b+c*x^n)/(b^5*n)
+--R 
+--R
+--R   (2)
+--R            4 n 2n 3n 4n       n
+--R       - 12c x x  x  x  log(c x  + b)
+--R     + 
+--R           4         n        3  2n     2 2 n  3n     3   n 2n  4n     4 n 2n 3n
+--R     (((12c n log(x)x  + 12b c )x   - 6b c x )x   + 4b c x x  )x   - 3b x x  x
+--R  /
+--R        5   n 2n 3n 4n
+--R     12b n x x  x  x
+--R                                                    Type: Expression(Integer)
+--E 995
+
+--S 996 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 996
+
+)clear all
+
+--S 997 of 1311
+t0:=x^(-1+1/4*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 4
+--R            -----
+--R              4
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 997
+
+--S 998 of 1311
+r0:=(-4/3)/(b*n*x^(3/4*n))+c^(3/4)*log(-b^(1/4)*c^(1/4)*x^(1/4*n)*sqrt(2)+_
+   sqrt(b)+x^(1/2*n)*sqrt(c))/(b^(7/4)*n*sqrt(2))-c^(3/4)*_
+   log(b^(1/4)*c^(1/4)*x^(1/4*n)*sqrt(2)+sqrt(b)+x^(1/2*n)*_
+   sqrt(c))/(b^(7/4)*n*sqrt(2))+c^(3/4)*atan(1-c^(1/4)*x^(1/4*n)*_
+   sqrt(2)/b^(1/4))*sqrt(2)/(b^(7/4)*n)-c^(3/4)*atan(1+c^(1/4)*_
+   x^(1/4*n)*sqrt(2)/b^(1/4))*sqrt(2)/(b^(7/4)*n)
+--R 
+--R
+--R   (2)
+--R           3n               n            n
+--R           --               -            -
+--R            4 4+-+3     +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       - 3x   \|c  log(\|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R         3n                 n            n
+--R         --                 -            -
+--R          4 4+-+3       +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       3x   \|c  log(- \|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R                             n                                  n
+--R           3n                -                3n                -
+--R           --            +-+ 4 4+-+  4+-+     --            +-+ 4 4+-+  4+-+
+--R            4 4+-+3     \|2 x  \|c + \|b       4 4+-+3     \|2 x  \|c - \|b
+--R       - 6x   \|c  atan(----------------- - 6x   \|c  atan(-----------------)
+--R                               4+-+                               4+-+
+--R                               \|b                                \|b
+--R     + 
+--R           +-+4+-+3
+--R       - 4\|2 \|b
+--R  /
+--R              3n
+--R              --
+--R          +-+  4 4+-+3
+--R     3b n\|2 x   \|b
+--R                                                    Type: Expression(Integer)
+--E 998
+
+--S 999 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 999
+
+)clear all
+
+--S 1000 of 1311
+t0:=x^(-1+1/3*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 3
+--R            -----
+--R              3
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1000
+
+--S 1001 of 1311
+r0:=(-3/2)/(b*n*x^(2/3*n))-c^(2/3)*log(b^(1/3)+c^(1/3)*x^(1/3*n))/_
+   (b^(5/3)*n)+1/2*c^(2/3)*log(b^(2/3)-b^(1/3)*c^(1/3)*x^(1/3*n)+_
+   c^(2/3)*x^(2/3*n))/(b^(5/3)*n)+c^(2/3)*atan((b^(1/3)-_
+   2*c^(1/3)*x^(1/3*n))/(b^(1/3)*sqrt(3)))*sqrt(3)/(b^(5/3)*n)
+--R 
+--R
+--R   (2)
+--R        2n           2n         n                     2n           n
+--R        --           --         -                     --           -
+--R         3 3+-+2      3 3+-+2   3 3+-+3+-+  3+-+2      3 3+-+2     3 3+-+  3+-+
+--R       x   \|c  log(x   \|c  - x  \|b \|c + \|b   - 2x   \|c  log(x  \|c + \|b )
+--R     + 
+--R                              n
+--R               2n             -
+--R               --             3 3+-+  3+-+
+--R           +-+  3 3+-+2     2x  \|c - \|b     3+-+2
+--R       - 2\|3 x   \|c  atan(-------------- - 3\|b
+--R                                +-+3+-+
+--R                               \|3 \|b
+--R  /
+--R           2n
+--R           --
+--R            3 3+-+2
+--R     2b n x   \|b
+--R                                                    Type: Expression(Integer)
+--E 1001
+
+--S 1002 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1002
+
+)clear all
+
+--S 1003 of 1311
+t0:=x^(-1+1/2*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R            n - 2
+--R            -----
+--R              2
+--R           x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1003
+
+--S 1004 of 1311
+r0:=(-2)/(b*n*x^(1/2*n))-2*atan(x^(1/2*n)*sqrt(c)/sqrt(b))*sqrt(c)/(b^(3/2)*n)
+--R 
+--R
+--R                       n
+--R            n          -
+--R            -          2 +-+
+--R            2 +-+     x \|c       +-+
+--R        - 2x \|c atan(------) - 2\|b
+--R                        +-+
+--R                       \|b
+--R   (2)  -----------------------------
+--R                       n
+--R                       -
+--R                       2 +-+
+--R                  b n x \|b
+--R                                                    Type: Expression(Integer)
+--E 1004
+
+--S 1005 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1005
+
+)clear all
+
+--S 1006 of 1311
+t0:=x^(-1-1/2*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - n - 2
+--R           -------
+--R              2
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1006
+
+--S 1007 of 1311
+r0:=(-2/3)/(b*n*x^(3/2*n))+2*c/(b^2*n*x^(1/2*n))+2*c^(3/2)*atan(x^(1/2*n)*_
+   sqrt(c)/sqrt(b))/(b^(5/2)*n)
+--R 
+--R
+--R                          n
+--R            n 3n          -             3n       n
+--R            - --          2 +-+         --       -
+--R            2  2 +-+     x \|c           2       2  +-+
+--R        6c x x  \|c atan(------) + (6c x   - 2b x )\|b
+--R                           +-+
+--R                          \|b
+--R   (2)  -----------------------------------------------
+--R                               n 3n
+--R                               - --
+--R                           2   2  2 +-+
+--R                         3b n x x  \|b
+--R                                                    Type: Expression(Integer)
+--E 1007
+
+--S 1008 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1008
+
+)clear all
+
+--S 1009 of 1311
+t0:=x^(-1-1/3*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - n - 3
+--R           -------
+--R              3
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1009
+
+--S 1010 of 1311
+r0:=(-3/4)/(b*n*x^(4/3*n))+3*c/(b^2*n*x^(1/3*n))-c^(4/3)*log(b^(1/3)+_
+   c^(1/3)*x^(1/3*n))/(b^(7/3)*n)+1/2*c^(4/3)*log(b^(2/3)-b^(1/3)*_
+   c^(1/3)*x^(1/3*n)+c^(2/3)*x^(2/3*n))/(b^(7/3)*n)-c^(4/3)*_
+   atan((b^(1/3)-2*c^(1/3)*x^(1/3*n))/(b^(1/3)*sqrt(3)))*sqrt(3)/(b^(7/3)*n)
+--R 
+--R
+--R   (2)
+--R           n 4n          2n         n
+--R           - --          --         -
+--R           3  3 3+-+      3 3+-+2   3 3+-+3+-+  3+-+2
+--R       2c x x   \|c log(x   \|c  - x  \|b \|c + \|b  )
+--R     + 
+--R                                                                 n
+--R             n 4n          n                     n 4n            -
+--R             - --          -                     - --            3 3+-+  3+-+
+--R             3  3 3+-+     3 3+-+  3+-+      +-+ 3  3 3+-+     2x  \|c - \|b
+--R       - 4c x x   \|c log(x  \|c + \|b  + 4c\|3 x x   \|c atan(--------------)
+--R                                                                   +-+3+-+
+--R                                                                  \|3 \|b
+--R     + 
+--R             4n       n
+--R             --       -
+--R              3       3 3+-+
+--R       (12c x   - 3b x )\|b
+--R  /
+--R           n 4n
+--R           - --
+--R       2   3  3 3+-+
+--R     4b n x x   \|b
+--R                                                    Type: Expression(Integer)
+--E 1010
+
+--S 1011 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1011
+
+)clear all
+
+--S 1012 of 1311
+t0:=x^(-1-1/4*n)/(b*x^n+c*x^(2*n))
+--R 
+--R
+--R           - n - 4
+--R           -------
+--R              4
+--R          x
+--R   (1)  ------------
+--R           2n      n
+--R        c x   + b x
+--R                                                    Type: Expression(Integer)
+--E 1012
+
+--S 1013 of 1311
+r0:=(-4/5)/(b*n*x^(5/4*n))+4*c/(b^2*n*x^(1/4*n))+c^(5/4)*log(-b^(1/4)*_
+   c^(1/4)*x^(1/4*n)*sqrt(2)+sqrt(b)+x^(1/2*n)*sqrt(c))/(b^(9/4)*n*_
+   sqrt(2))-c^(5/4)*log(b^(1/4)*c^(1/4)*x^(1/4*n)*sqrt(2)+sqrt(b)+_
+   x^(1/2*n)*sqrt(c))/(b^(9/4)*n*sqrt(2))-c^(5/4)*atan(1-c^(1/4)*_
+   x^(1/4*n)*sqrt(2)/b^(1/4))*sqrt(2)/(b^(9/4)*n)+c^(5/4)*_
+   atan(1+c^(1/4)*x^(1/4*n)*sqrt(2)/b^(1/4))*sqrt(2)/(b^(9/4)*n)
+--R 
+--R
+--R   (2)
+--R             n 5n              n            n
+--R             - --              -            -
+--R             4  4 4+-+     +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       - 5c x x   \|c log(\|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R           n 5n                n            n
+--R           - --                -            -
+--R           4  4 4+-+       +-+ 4 4+-+4+-+   2 +-+    +-+
+--R       5c x x   \|c log(- \|2 x  \|b \|c + x \|c  + \|b )
+--R     + 
+--R                               n
+--R            n 5n               -
+--R            - --           +-+ 4 4+-+  4+-+
+--R            4  4 4+-+     \|2 x  \|c + \|b
+--R       10c x x   \|c atan(-----------------)
+--R                                 4+-+
+--R                                 \|b
+--R     + 
+--R                               n
+--R            n 5n               -                       5n          n
+--R            - --           +-+ 4 4+-+  4+-+            --          -
+--R            4  4 4+-+     \|2 x  \|c - \|b         +-+  4      +-+ 4 4+-+
+--R       10c x x   \|c atan(----------------- + (20c\|2 x   - 4b\|2 x )\|b
+--R                                 4+-+
+--R                                 \|b
+--R  /
+--R              n 5n
+--R              - --
+--R       2  +-+ 4  4 4+-+
+--R     5b n\|2 x x   \|b
+--R                                                    Type: Expression(Integer)
+--E 1013
+
+--S 1014 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1014
+
+)clear all
+
+--S 1015 of 1311
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^2
+--R 
+--R
+--R         2  2 3+-+2      3+-+    2 p
+--R   (1)  x (b  \|x  + 2a b\|x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1015
+
+--S 1016 of 1311
+r0:=15120*a^8*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/_
+   (b^9*(2+p)*(3+p)*(4+p)*(5+2*p)*(7+2*p)*(9+2*p)*(3+8*p+4*p^2))-_
+   7560*a^7*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(1+p)/(b^9*(1+p)*(2+p)*_
+   (3+p)*(4+p)*(3+2*p)*(5+2*p)*(7+2*p)*(9+2*p))+7560*a^6*(a+b*x^(1/3))*_
+   (a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(2/3)/(b^7*(2+p)*(3+p)*(4+p)*_
+   (3+2*p)*(5+2*p)*(7+2*p)*(9+2*p))-2520*a^5*(a+b*x^(1/3))*(a^2+_
+   2*a*b*x^(1/3)+b^2*x^(2/3))^p*x/(b^6*(2+p)*(3+p)*(4+p)*(5+2*p)*_
+   (7+2*p)*(9+2*p))+1260*a^4*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+_
+   b^2*x^(2/3))^p*x^(4/3)/(b^5*(3+p)*(4+p)*(5+2*p)*(7+2*p)*(9+2*p))-_
+   252*a^3*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(5/3)/_
+   (b^4*(3+p)*(4+p)*(7+2*p)*(9+2*p))+84*a^2*(a+b*x^(1/3))*(a^2+_
+   2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^2/(b^3*(4+p)*(7+2*p)*(9+2*p))-_
+   12*a*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(7/3)/_
+   (b^2*(4+p)*(9+2*p))+3*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*_
+   x^(8/3)/(b*(9+2*p))
+--R 
+--R
+--R   (2)
+--R                7         7   2 3+-+2      3+-+    2 p + 1
+--R       (- 15120a p - 7560a )(b  \|x  + 2a b\|x  + a )
+--R     + 
+--R                        8 8         8 7          8 6           8 5           8 4
+--R                   48a b p  + 672a b p  + 3864a b p  + 11760a b p  + 20307a b p
+--R                 + 
+--R                           8 3          8 2          8
+--R                   19698a b p  + 9801a b p  + 1890a b p
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                          4 5 5         4 5 4         4 5 3         4 5 2
+--R                   - 2016a b p  - 10080a b p  - 17640a b p  - 12600a b p
+--R                 + 
+--R                          4 5
+--R                   - 3024a b p
+--R              *
+--R                 x
+--R             + 
+--R                     7 2 2         7 2         7 2
+--R               15120a b p  + 22680a b p + 7560a b
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                         2 7 7        2 7 6        2 7 5         2 7 4
+--R                   - 192a b p  - 2016a b p  - 8400a b p  - 17640a b p
+--R                 + 
+--R                           2 7 3         2 7 2        2 7
+--R                   - 19488a b p  - 10584a b p  - 2160a b p
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                     5 4 4         5 4 3         5 4 2        5 4
+--R               (5040a b p  + 15120a b p  + 13860a b p  + 3780a b p)x
+--R             + 
+--R                     8            8
+--R               15120a b p + 15120a b
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R                  9 8       9 7        9 6         9 5         9 4          9 3
+--R               48b p  + 864b p  + 6552b p  + 27216b p  + 67347b p  + 100926b p
+--R             + 
+--R                     9 2         9         9
+--R               88593b p  + 41094b p + 7560b
+--R          *
+--R              3
+--R             x
+--R         + 
+--R                   3 6 6        3 6 5         3 6 4         3 6 3         3 6 2
+--R               672a b p  + 5040a b p  + 14280a b p  + 18900a b p  + 11508a b p
+--R             + 
+--R                    3 6
+--R               2520a b p
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                    6 3 3         6 3 2        6 3            9          9
+--R           (- 10080a b p  - 15120a b p  - 5040a b p)x + 15120a p + 15120a
+--R      *
+--R           2 3+-+2      3+-+    2 p
+--R         (b  \|x  + 2a b\|x  + a )
+--R  /
+--R          9 9       9 8        9 7         9 6          9 5          9 4
+--R       32b p  + 720b p  + 6960b p  + 37800b p  + 126546b p  + 269325b p
+--R     + 
+--R              9 3          9 2          9          9
+--R       361840b p  + 293175b p  + 128322b p + 22680b
+--R                                                    Type: Expression(Integer)
+--E 1016
+
+--S 1017 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1017
+
+)clear all
+
+--S 1018 of 1311
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x
+--R 
+--R
+--R            2 3+-+2      3+-+    2 p
+--R   (1)  x (b  \|x  + 2a b\|x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1018
+
+--S 1019 of 1311
+r0:=-90*a^5*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(b^6*(2+p)*_
+   (3+p)*(5+2*p)*(3+8*p+4*p^2))+45*a^4*(a^2+2*a*b*x^(1/3)+b^2*_
+   x^(2/3))^(1+p)/(b^6*(1+p)*(2+p)*(3+p)*(3+2*p)*(5+2*p))-_
+   45*a^3*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(2/3)/_
+   (b^4*(2+p)*(3+p)*(3+2*p)*(5+2*p))+15*a^2*(a+b*x^(1/3))*(a^2+_
+   2*a*b*x^(1/3)+b^2*x^(2/3))^p*x/(b^3*(2+p)*(3+p)*(5+2*p))-_
+   15/2*a*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(4/3)/_
+   (b^2*(3+p)*(5+2*p))+3/2*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*_
+   x^(2/3))^p*x^(5/3)/(b*(3+p))
+--R 
+--R
+--R   (2)
+--R            4       4   2 3+-+2      3+-+    2 p + 1
+--R       (180a p + 90a )(b  \|x  + 2a b\|x  + a )
+--R     + 
+--R                     5 5         5 4         5 3         5 2        5
+--R               (24a b p  + 120a b p  + 210a b p  + 150a b p  + 36a b p)x
+--R             + 
+--R                     4 2 2       4 2       4 2
+--R               - 180a b p  - 270a b p - 90a b
+--R          *
+--R             3+-+2
+--R             \|x
+--R         + 
+--R                       2 4 4       2 4 3       2 4 2      2 4          5
+--R                 (- 60a b p  - 180a b p  - 165a b p  - 45a b p)x - 180a b p
+--R               + 
+--R                       5
+--R                 - 180a b
+--R          *
+--R             3+-+
+--R             \|x
+--R         + 
+--R               6 5       6 4       6 3       6 2       6       6  2
+--R           (24b p  + 180b p  + 510b p  + 675b p  + 411b p + 90b )x
+--R         + 
+--R                3 3 3       3 3 2      3 3          6        6
+--R           (120a b p  + 180a b p  + 60a b p)x - 180a p - 180a
+--R      *
+--R           2 3+-+2      3+-+    2 p
+--R         (b  \|x  + 2a b\|x  + a )
+--R  /
+--R        6 6       6 5       6 4        6 3        6 2       6        6
+--R     16b p  + 168b p  + 700b p  + 1470b p  + 1624b p  + 882b p + 180b
+--R                                                    Type: Expression(Integer)
+--E 1019
+
+--S 1020 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1020
+
+)clear all
+
+--S 1021 of 1311
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p
+--R 
+--R
+--R          2 3+-+2      3+-+    2 p
+--R   (1)  (b  \|x  + 2a b\|x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1021
+
+--S 1022 of 1311
+r0:=6*a^2*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(b^3*(3+8*p+_
+   4*p^2))-3*a*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(1+p)/(b^3*(1+p)*(3+2*p))+_
+   3*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*x^(2/3)/(b*(3+2*p))
+--R 
+--R
+--R   (2)
+--R                      2 3+-+2      3+-+    2 p + 1
+--R       (- 6a p - 3a)(b  \|x  + 2a b\|x  + a )
+--R     + 
+--R                2 2       2        2 3+-+2      2        2  3+-+
+--R           (6a b p  + 9a b p + 3a b )\|x   + (6a b p + 6a b)\|x
+--R         + 
+--R              3 2     3      3       3      3
+--R           (6b p  + 9b p + 3b )x + 6a p + 6a
+--R      *
+--R           2 3+-+2      3+-+    2 p
+--R         (b  \|x  + 2a b\|x  + a )
+--R  /
+--R       3 3      3 2      3      3
+--R     4b p  + 12b p  + 11b p + 3b
+--R                                                    Type: Expression(Integer)
+--E 1022
+
+--S 1023 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1023
+
+)clear all
+
+--S 1024 of 1311
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/x
+--R 
+--R
+--R          2 3+-+2      3+-+    2 p
+--R        (b  \|x  + 2a b\|x  + a )
+--R   (1)  --------------------------
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 1024
+
+--S 1025 of 1311
+--r0:=3/2*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*hypergeometric(-2*p,-2*p,1-2*p,_
+--   -a/(b*x^(1/3)))/(p*((a+b*x^(1/3))/(b*x^(1/3)))^(2*p))
+--E 1025
+
+--S 1026 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 1026
+
+)clear all
+
+--S 1027 of 1311
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/x^2
+--R 
+--R
+--R          2 3+-+2      3+-+    2 p
+--R        (b  \|x  + 2a b\|x  + a )
+--R   (1)  --------------------------
+--R                     2
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 1027
+
+--S 1028 of 1311
+--r0:=-(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(a*x)+b*(1-p)*_
+--   (a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(a^2*x^(2/3))-_
+--   b^2*(1-2*p)*(1-p)*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/_
+--   (a^3*x^(1/3))+b^3*(1-2*p)*(1-p)*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p*_
+--   hypergeometric(-2*p,-2*p,1-2*p,-a/(b*x^(1/3)))/(a^3*((a+b*x^(1/3))/_
+--   (b*x^(1/3)))^(2*p))
+--E 1028
+
+--S 1029 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 1029
+
+)clear all
+
+--S 1030 of 1311
+t0:=(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/x^2-2/3*b^3*(1-2*p)*(1-p)*p*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(a^3*x)
+--R 
+--R
+--R              3 3     3 2     3        3   2 3+-+2      3+-+    2 p
+--R        ((- 4b p  + 6b p  - 2b p)x + 3a )(b  \|x  + 2a b\|x  + a )
+--R   (1)  -----------------------------------------------------------
+--R                                     3 2
+--R                                   3a x
+--R                                                    Type: Expression(Integer)
+--E 1030
+
+--S 1031 of 1311
+r0:=-(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(a*x)+b*(1-p)*_
+   (a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/(a^2*x^(2/3))-_
+   b^2*(1-2*p)*(1-p)*(a+b*x^(1/3))*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^p/_
+   (a^3*x^(1/3))
+--R 
+--R
+--R   (2)
+--R                 3 2     3     3      3 3+-+2          2 2       2   3+-+
+--R           ((- 2b p  + 3b p - b )x - a )\|x   + (- 2a b p  + 2a b p)x\|x
+--R         + 
+--R              2
+--R           - a b p x
+--R    *
+--R         2 3+-+2      3+-+    2 p
+--R       (b  \|x  + 2a b\|x  + a )
+--R  /
+--R      3  3+-+2
+--R     a x \|x
+--R                                                    Type: Expression(Integer)
+--E 1031
+
+--S 1032 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1032
+
+)clear all
+
+--S 1033 of 1311
+t0:=(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(7/2)
+--R 
+--R
+--R   (1)
+--R           5         2 4 3+-+2       4 2        5 3+-+    6 2      3 3     6
+--R       ((6a b x + 15a b )\|x   + (15a b x + 6a b )\|x  + a x  + 20a b x + b )
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R        |a  \|x  + 2a b\|x  + b
+--R        |-----------------------
+--R        |         3+-+2
+--R       \|         \|x
+--R  /
+--R      2
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 1033
+
+--S 1034 of 1311
+r0:=-35*a*b^3*(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)-105/4*b^3*(a+b/x^(1/3))*_
+   (a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)+21*b^2*(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3))^(5/2)*x^(1/3)+7/2*b*(a+b/x^(1/3))*(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3))^(5/2)*x^(2/3)+(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(7/2)*x-_
+   105*a^3*b^3*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))-105/2*a^2*b^3*_
+   (a+b/x^(1/3))*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))-105*a^4*b^3*_
+   log(1/x^(1/3))*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/(a+b/x^(1/3))
+--R 
+--R
+--R   (2)
+--R               4 3 2      1         6   2       3 4      7 3+-+2
+--R         - 420a b x log(----) + (42a b x  - 420a b x - 3b )\|x
+--R                        3+-+
+--R                        \|x
+--R       + 
+--R              5 2 2       2 5  3+-+     7 3       4 3 2        6
+--R         (252a b x  - 126a b x)\|x  + 4a x  - 105a b x  - 28a b x
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R        |a  \|x  + 2a b\|x  + b
+--R        |-----------------------
+--R        |         3+-+2
+--R       \|         \|x
+--R  /
+--R          3+-+2       2
+--R     4b x \|x   + 4a x
+--R                                                    Type: Expression(Integer)
+--E 1034
+
+--S 1035 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1035
+
+)clear all
+
+--S 1036 of 1311
+t0:=(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(5/2)
+--R 
+--R
+--R   (1)
+--R                                                  +-----------------------+
+--R                                                  | 2 3+-+2      3+-+    2
+--R      2 2 3+-+2    4        3 3+-+     3       4  |a  \|x  + 2a b\|x  + b
+--R   (6a b  \|x  + (a x + 4a b )\|x  + 4a b x + b ) |-----------------------
+--R                                                  |         3+-+2
+--R                                                 \|         \|x
+--R   ------------------------------------------------------------------------
+--R                                      3+-+
+--R                                     x\|x
+--R                                                    Type: Expression(Integer)
+--E 1036
+
+--S 1037 of 1311
+r0:=10*b^2*(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)*x^(1/3)+_
+   5/2*b*(a+b/x^(1/3))*(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)*x^(2/3)+_
+   (a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(5/2)*x-30*a*b^3*sqrt(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3))-15*b^3*(a+b/x^(1/3))*sqrt(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3))-30*a^2*b^3*log(1/x^(1/3))*sqrt(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3))/(a+b/x^(1/3))
+--R 
+--R
+--R   (2)
+--R              2 3 3+-+2      1       5       2 3 3+-+2       4           4 3+-+
+--R         - 60a b  \|x  log(---- + (2a x + 20a b )\|x   + (15a b x - 30a b )\|x
+--R                           3+-+
+--R                           \|x
+--R       + 
+--R            3 2      5
+--R         60a b x - 3b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R        |a  \|x  + 2a b\|x  + b
+--R        |-----------------------
+--R        |         3+-+2
+--R       \|         \|x
+--R  /
+--R        3+-+2     3+-+
+--R     2a \|x   + 2b\|x
+--R                                                    Type: Expression(Integer)
+--E 1037
+
+--S 1038 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1038
+
+)clear all
+
+--S 1039 of 1311
+t0:=(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)
+--R 
+--R
+--R                                  +-----------------------+
+--R                                  | 2 3+-+2      3+-+    2
+--R          2 3+-+2      3+-+    2  |a  \|x  + 2a b\|x  + b
+--R        (a  \|x  + 2a b\|x  + b ) |-----------------------
+--R                                  |         3+-+2
+--R                                 \|         \|x
+--R   (1)  ---------------------------------------------------
+--R                               3+-+2
+--R                               \|x
+--R                                                    Type: Expression(Integer)
+--E 1039
+
+--S 1040 of 1311
+r0:=9*a*b^3*x^(1/3)*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/(a*b+b^2/x^(1/3))+_
+   9/2*a^2*b^2*x^(2/3)*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/(a*b+_
+   b^2/x^(1/3))+a^3*x*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/(a+b/x^(1/3))+_
+   b^4*log(x)*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/(a*b+b^2/x^(1/3))
+--R 
+--R
+--R   (2)
+--R                                                   +-----------------------+
+--R                                                   | 2 3+-+2      3+-+    2
+--R         2 3+-+2     3           3  3+-+     2     |a  \|x  + 2a b\|x  + b
+--R   (18a b  \|x  + (2b log(x) + 2a x)\|x  + 9a b x) |-----------------------
+--R                                                   |         3+-+2
+--R                                                  \|         \|x
+--R   -------------------------------------------------------------------------
+--R                                    3+-+
+--R                                  2a\|x  + 2b
+--R                                                    Type: Expression(Integer)
+--E 1040
+
+--S 1041 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1041
+
+)clear all
+
+--S 1042 of 1311
+t0:=(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(1/2)
+--R 
+--R
+--R         +-----------------------+
+--R         | 2 3+-+2      3+-+    2
+--R         |a  \|x  + 2a b\|x  + b
+--R   (1)   |-----------------------
+--R         |         3+-+2
+--R        \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1042
+
+--S 1043 of 1311
+r0:=-1/2*(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(3/2)*x/a^2+3/2*(a+b/x^(1/3))*x*_
+   sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))/a
+--R 
+--R
+--R                                       +-----------------------+
+--R                                       | 2 3+-+2      3+-+    2
+--R           2  3+-+2        3+-+    2   |a  \|x  + 2a b\|x  + b
+--R        (2a x \|x   + a b x\|x  - b x) |-----------------------
+--R                                       |         3+-+2
+--R                                      \|         \|x
+--R   (2)  --------------------------------------------------------
+--R                                  2 3+-+2
+--R                                2a  \|x
+--R                                                    Type: Expression(Integer)
+--E 1043
+
+--S 1044 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1044
+
+)clear all
+
+--S 1045 of 1311
+t0:=1/(a^2+b^2/x^(2/3)+2*a*b/x^(1/3))^(1/2)
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R         +-----------------------+
+--R         | 2 3+-+2      3+-+    2
+--R         |a  \|x  + 2a b\|x  + b
+--R         |-----------------------
+--R         |         3+-+2
+--R        \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1045
+
+--S 1046 of 1311
+r0:=-3/2*b*(a+b/x^(1/3))*x^(2/3)/(a^2*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3)))+_
+   (a+b/x^(1/3))*x/(a*sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3)))-_
+   3*b^3*(a+b/x^(1/3))*log(a+b/x^(1/3))/(a^4*sqrt(a^2+b^2/x^(2/3)+_
+   2*a*b/x^(1/3)))+3*b^3*(a+b/x^(1/3))*log(1/x^(1/3))/(a^4*_
+   sqrt(a^2+b^2/x^(2/3)+2*a*b/x^(1/3)))+3*b^2*x^(1/3)*sqrt(a^2+_
+   b^2/x^(2/3)+2*a*b/x^(1/3))/a^4
+--R 
+--R
+--R   (2)
+--R                               3+-+
+--R              3 3+-+    4     a\|x  + b         3 3+-+    4       1
+--R       (- 6a b  \|x - 6b )log(---------) + (6a b  \|x + 6b )log(----)
+--R                                 3+-+                           3+-+
+--R                                 \|x                            \|x
+--R     + 
+--R         2 2 3+-+2     4         3 3+-+    3        4
+--R       3a b  \|x  + (2a x + 12a b )\|x  - a b x + 6b
+--R  /
+--R              +-----------------------+
+--R              | 2 3+-+2      3+-+    2
+--R       4 3+-+ |a  \|x  + 2a b\|x  + b
+--R     2a  \|x  |-----------------------
+--R              |         3+-+2
+--R             \|         \|x
+--R                                                    Type: Expression(Integer)
+--E 1046
+
+--S 1047 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1047
+
+)clear all
+
+--S 1048 of 1311
+t0:=1/(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(3/2)
+--R 
+--R
+--R                                 1
+--R   (1)  ---------------------------------------------------
+--R                                  +-----------------------+
+--R          2 3+-+2      3+-+    2  | 2 3+-+2      3+-+    2
+--R        (b  \|x  + 2a b\|x  + a )\|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1048
+
+--S 1049 of 1311
+r0:=-3/2*(a+b*x^(1/3))*x^(2/3)/(b*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(3/2))-_
+   3*x^(1/3)/(b^2*sqrt(a^2+2*a*b*x^(1/3)+b^2*x^(2/3)))+3*(a+b*x^(1/3))*_
+   log(a+b*x^(1/3))/(b^3*sqrt(a^2+2*a*b*x^(1/3)+b^2*x^(2/3)))
+--R 
+--R
+--R   (2)
+--R             2 3+-+2     2 3+-+     3      3      3+-+             2 3+-+2
+--R       (18a b  \|x  + 18a b\|x  + 6b x + 6a )log(b\|x  + a) - 15a b  \|x
+--R     + 
+--R           2 3+-+     3
+--R       - 6a b\|x  - 9b x
+--R  /
+--R                                    +-----------------------+
+--R        5 3+-+2      4 3+-+    2 3  | 2 3+-+2      3+-+    2
+--R     (2b  \|x  + 4a b  \|x + 2a b )\|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1049
+
+--S 1050 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1050
+
+)clear all
+
+--S 1051 of 1311
+t0:=1/(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(5/2)
+--R 
+--R
+--R   (1)
+--R                                      1
+--R   -----------------------------------------------------------------------
+--R                                                 +-----------------------+
+--R      2 2 3+-+2    4      3  3+-+       3     4  | 2 3+-+2      3+-+    2
+--R   (6a b  \|x  + (b x + 4a b)\|x  + 4a b x + a )\|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1051
+
+--S 1052 of 1311
+r0:=3/4*(a+b*x^(1/3))*x/(a*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(5/2))+_
+   1/4*x/(a^2*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(3/2))
+--R 
+--R
+--R   (2)
+--R        2 2  3+-+2     4 2      3    3+-+       3 2     4
+--R     15a b x \|x   + (b x  + 13a b x)\|x  + 7a b x  + 4a x
+--R  /
+--R               3 5       6 2 3+-+2       4 4       7  3+-+     2 6 2      5 3
+--R           (24a b x + 60a b )\|x   + (60a b x + 24a b)\|x  + 4a b x  + 80a b x
+--R         + 
+--R             8
+--R           4a
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1052
+
+--S 1053 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1053
+
+)clear all
+
+--S 1054 of 1311
+t0:=1/(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(7/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R             5       4 2 3+-+2       2 4      5  3+-+    6 2      3 3     6
+--R       ((6a b x + 15a b )\|x   + (15a b x + 6a b)\|x  + b x  + 20a b x + a )
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1054
+
+--S 1055 of 1311
+r0:=1/20*(-a-b*x^(1/3))/(b^3*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(5/2))-_
+   1/5*x^(1/3)/(b^2*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(5/2))-_
+   1/2*(a+b*x^(1/3))*x^(2/3)/(b*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(7/2))
+--R 
+--R
+--R   (2)
+--R              2 5       5 2 3+-+2         7 2       3 4       6  3+-+        6 2
+--R       (- 181a b x - 55a b )\|x   + (- 15b x  - 215a b x - 11a b)\|x  - 81a b x
+--R     + 
+--R             4 3     7
+--R       - 145a b x - a
+--R  /
+--R              2 11 2        5 8        8 5 3+-+2
+--R         (900a b  x  + 5040a b x + 900a b )\|x
+--R       + 
+--R             13 3        3 10 2        6 7        9 4 3+-+         12 3
+--R         (20b  x  + 2400a b  x  + 4200a b x + 200a b )\|x  + 200a b  x
+--R       + 
+--R              4 9 2        7 6       10 3
+--R         4200a b x  + 2400a b x + 20a  b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1055
+
+--S 1056 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1056
+
+)clear all
+
+--S 1057 of 1311
+t0:=1/(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(9/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R           8 2      3 5       6 2 3+-+2        7 2      4 4      7  3+-+
+--R         (b x  + 56a b x + 28a b )\|x   + (8a b x  + 70a b x + 8a b)\|x
+--R       + 
+--R            2 6 2      5 3     8
+--R         28a b x  + 56a b x + a
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1057
+
+--S 1058 of 1311
+r0:=1/56*(-a-b*x^(1/3))/(b^3*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(7/2))-_
+   3/28*x^(1/3)/(b^2*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(7/2))-_
+   3/8*(a+b*x^(1/3))*x^(2/3)/(b*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(9/2))
+--R 
+--R
+--R   (2)
+--R                8 2        4 5        7 2 3+-+2
+--R       (- 204a b x  - 1281a b x - 105a b )\|x
+--R     + 
+--R            2 7 2       5 4       8  3+-+      9 3        3 6 2       6 3     9
+--R     (- 645a b x  - 903a b x - 15a b)\|x  - 28b x  - 1155a b x  - 399a b x - a
+--R  /
+--R             17 4         3 14 3          6 11 2          9 8         12 5 3+-+2
+--R         (56b  x  + 20384a b  x  + 168168a b  x  + 112112a b x + 5096a  b )\|x
+--R       + 
+--R                  16 4         4 13 3          7 10 2         10 7        13 4
+--R           (784a b  x  + 56056a b  x  + 192192a b  x  + 56056a  b x + 784a  b )
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R              2 15 4          5 12 3          8 9 2         11 6       14 3
+--R         5096a b  x  + 112112a b  x  + 168168a b x  + 20384a  b x + 56a  b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1058
+
+--S 1059 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1059
+
+)clear all
+
+--S 1060 of 1311
+t0:=1/(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(11/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R             2 8 2       5 5       8 2 3+-+2
+--R         (45a b x  + 252a b x + 45a b )\|x
+--R       + 
+--R           10 3       3 7 2       6 4       9  3+-+        9 3       4 6 2
+--R         (b  x  + 120a b x  + 210a b x + 10a b)\|x  + 10a b x  + 210a b x
+--R       + 
+--R             7 3     10
+--R         120a b x + a
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1060
+
+--S 1061 of 1311
+r0:=1/120*(-a-b*x^(1/3))/(b^3*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(9/2))-_
+   1/15*x^(1/3)/(b^2*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(9/2))-_
+   3/10*(a+b*x^(1/3))*x^(2/3)/(b*(a^2+2*a*b*x^(1/3)+b^2*x^(2/3))^(11/2))
+--R 
+--R
+--R   (2)
+--R             11 3        3 8 2        6 5        9 2 3+-+2
+--R       (- 45b  x  - 4149a b x  - 5166a b x - 171a b )\|x
+--R     + 
+--R                10 3        4 7 2        7 4       10  3+-+        2 9 3
+--R       (- 415a b  x  - 6546a b x  - 2586a b x - 19a  b)\|x  - 1711a b x
+--R     + 
+--R              5 6 2       8 3     11
+--R       - 7014a b x  - 849a b x - a
+--R  /
+--R                    20 5          4 17 4           7 14 3           10 11 2
+--R             2160a b  x  + 367200a b  x  + 3818880a b  x  + 5250960a  b  x
+--R           + 
+--R                     13 8          16 5
+--R             1028160a  b x + 18360a  b
+--R        *
+--R           3+-+2
+--R           \|x
+--R       + 
+--R                   2 19 5           5 16 4           8 13 3           11 10 2
+--R             18360a b  x  + 1028160a b  x  + 5250960a b  x  + 3818880a  b  x
+--R           + 
+--R                    14 7         17 4
+--R             367200a  b x + 2160a  b
+--R        *
+--R           3+-+
+--R           \|x
+--R       + 
+--R             21 6         3 18 5           6 15 4           9 12 3
+--R         120b  x  + 97920a b  x  + 2227680a b  x  + 5834400a b  x
+--R       + 
+--R                 12 9 2         15 6        18 3
+--R         2227680a  b x  + 97920a  b x + 120a  b
+--R    *
+--R        +-----------------------+
+--R        | 2 3+-+2      3+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1061
+
+--S 1062 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1062
+
+)clear all
+
+--S 1063 of 1311
+t0:=(a^2+b^2/x^(2/5)+2*a*b/x^(1/5))^(5/2)
+--R 
+--R
+--R   (1)
+--R         4 5+-+4    3  5+-+3     2 2 5+-+2      3 5+-+   4
+--R       (a  \|x  + 4a b \|x   + 6a b  \|x  + 4a b  \|x + b )
+--R    *
+--R        +-----------------------+
+--R        | 2 5+-+2      5+-+    2
+--R        |a  \|x  + 2a b\|x  + b
+--R        |-----------------------
+--R        |         5+-+2
+--R       \|         \|x
+--R  /
+--R     5+-+4
+--R     \|x
+--R                                                    Type: Expression(Integer)
+--E 1063
+
+--S 1064 of 1311
+r0:=25*a*b^5*x^(1/5)*sqrt(a^2+b^2/x^(2/5)+2*a*b/x^(1/5))/(a*b+b^2/x^(1/5))+_
+   25*a^2*b^4*x^(2/5)*sqrt(a^2+b^2/x^(2/5)+2*a*b/x^(1/5))/(a*b+b^2/x^(1/5))+_
+   50/3*a^3*b^3*x^(3/5)*sqrt(a^2+b^2/x^(2/5)+2*a*b/x^(1/5))/_
+   (a*b+b^2/x^(1/5))+25/4*a^4*b^2*x^(4/5)*sqrt(a^2+b^2/x^(2/5)+_
+   2*a*b/x^(1/5))/(a*b+b^2/x^(1/5))+a^5*x*sqrt(a^2+b^2/x^(2/5)+_
+   2*a*b/x^(1/5))/(a+b/x^(1/5))+b^6*log(x)*sqrt(a^2+b^2/x^(2/5)+_
+   2*a*b/x^(1/5))/(a*b+b^2/x^(1/5))
+--R 
+--R
+--R   (2)
+--R             3 2 5+-+4      2 3 5+-+3        4 5+-+2      5            5  5+-+
+--R         200a b  \|x  + 300a b  \|x  + 300a b  \|x  + (12b log(x) + 12a x)\|x
+--R       + 
+--R            4
+--R         75a b x
+--R    *
+--R        +-----------------------+
+--R        | 2 5+-+2      5+-+    2
+--R        |a  \|x  + 2a b\|x  + b
+--R        |-----------------------
+--R        |         5+-+2
+--R       \|         \|x
+--R  /
+--R        5+-+
+--R     12a\|x  + 12b
+--R                                                    Type: Expression(Integer)
+--E 1064
+
+--S 1065 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1065
+
+)clear all
+
+--S 1066 of 1311
+t0:=(a^2+b^2/x^2+2*a*b/x)^(1/2)
+--R 
+--R
+--R         +------------------+
+--R         | 2 2             2
+--R         |a x  + 2a b x + b
+--R   (1)   |------------------
+--R         |         2
+--R        \|        x
+--R                                                    Type: Expression(Integer)
+--E 1066
+
+--S 1067 of 1311
+r0:=a*x*sqrt(a^2+b^2/x^2+2*a*b/x)/(a+b/x)+b*log(x)*_
+   sqrt(a^2+b^2/x^2+2*a*b/x)/(a+b/x)
+--R 
+--R
+--R                            +------------------+
+--R                            | 2 2             2
+--R                         2  |a x  + 2a b x + b
+--R        (b x log(x) + a x ) |------------------
+--R                            |         2
+--R                           \|        x
+--R   (2)  ----------------------------------------
+--R                         a x + b
+--R                                                    Type: Expression(Integer)
+--E 1067
+
+--S 1068 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1068
+
+)clear all
+
+--S 1069 of 1311
+t0:=1/(a^2+2*a*b*x+b^2*x^2)^(1/2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         +------------------+
+--R         | 2 2             2
+--R        \|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 1069
+
+--S 1070 of 1311
+r0:=(a+b*x)*log(a+b*x)/(b*sqrt(a^2+2*a*b*x+b^2*x^2))
+--R 
+--R
+--R         (b x + a)log(b x + a)
+--R   (2)  ----------------------
+--R          +------------------+
+--R          | 2 2             2
+--R        b\|b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 1070
+
+--S 1071 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1071
+
+)clear all
+
+--S 1072 of 1311
+t0:=1/(a^2+2*a*b*x^(1/5)+b^2*x^(2/5))^(5/2)
+--R 
+--R
+--R   (1)
+--R                                         1
+--R   -----------------------------------------------------------------------------
+--R                                                       +-----------------------+
+--R     4 5+-+4      3 5+-+3    2 2 5+-+2    3 5+-+    4  | 2 5+-+2      5+-+    2
+--R   (b  \|x  + 4a b  \|x  + 6a b  \|x  + 4a b\|x  + a )\|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1072
+
+--S 1073 of 1311
+r0:=-5/2*(a+b*x^(1/5))*x^(2/5)/(b^3*(a^2+2*a*b*x^(1/5)+b^2*x^(2/5))^(3/2))-_
+   5/3*x^(3/5)/(b^2*(a^2+2*a*b*x^(1/5)+b^2*x^(2/5))^(3/2))-_
+   5/4*(a+b*x^(1/5))*x^(4/5)/(b*(a^2+2*a*b*x^(1/5)+b^2*x^(2/5))^(5/2))-_
+   5*x^(1/5)/(b^4*sqrt(a^2+2*a*b*x^(1/5)+b^2*x^(2/5)))+_
+   5*(a+b*x^(1/5))*log(a+b*x^(1/5))/(b^5*sqrt(a^2+2*a*b*x^(1/5)+b^2*x^(2/5)))
+--R 
+--R
+--R   (2)
+--R                   4 5+-+4      2 3 5+-+3      3 2 5+-+2      4 5+-+      5
+--R             300a b  \|x  + 600a b  \|x  + 600a b  \|x  + 300a b\|x  + 60b x
+--R           + 
+--R                5
+--R             60a
+--R      *
+--R              5+-+
+--R         log(b\|x  + a)
+--R     + 
+--R               4 5+-+4      2 3 5+-+3      3 2 5+-+2     4 5+-+       5
+--R       - 385a b  \|x  - 470a b  \|x  - 270a b  \|x  - 60a b\|x  - 125b x
+--R  /
+--R           9 5+-+4       8 5+-+3     2 7 5+-+2     3 6 5+-+     4 5
+--R       (12b  \|x  + 48a b  \|x  + 72a b  \|x  + 48a b  \|x + 12a b )
+--R    *
+--R        +-----------------------+
+--R        | 2 5+-+2      5+-+    2
+--R       \|b  \|x  + 2a b\|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1073
+
+--S 1074 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1074
+
+)clear all
+
+--S 1075 of 1311
+t0:=(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))^(7/2)
+--R 
+--R
+--R   (1)
+--R            4 2 3+-+2    2 4 3+-+   6     6 6+-+3
+--R         (3a b  \|x  + 3a b  \|x + a x + b )\|x
+--R       + 
+--R             3 3 3+-+2      5 3+-+    5    6+-+2       2 4 3+-+2     4 2  6+-+
+--R         (12a b  \|x  + 6a b  \|x + 6a b x)\|x   + (12a b  \|x  + 12a b x)\|x
+--R       + 
+--R           3 3
+--R         8a b x
+--R    *
+--R        +----------------------------+
+--R        |  2 3+-+   2 6+-+       3+-+
+--R        |(a  \|x + b )\|x  + 2a b\|x
+--R        |----------------------------
+--R        |          3+-+6+-+
+--R       \|          \|x \|x
+--R  /
+--R       6+-+3
+--R     x \|x
+--R                                                    Type: Expression(Integer)
+--E 1075
+
+--S 1076 of 1311
+r0:=-6*b^8*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/((a*b+b^2/x^(1/6))*x^(1/6))+_
+   126*a^2*b^6*x^(1/6)*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/_
+   (a*b+b^2/x^(1/6))+105*a^3*b^5*x^(1/3)*sqrt(a^2+b^2/x^(1/3)+_
+   2*a*b/x^(1/6))/(a*b+b^2/x^(1/6))+63/2*a^5*b^3*x^(2/3)*_
+   sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/(a*b+b^2/x^(1/6))+_
+   42/5*a^6*b^2*x^(5/6)*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/_
+   (a*b+b^2/x^(1/6))+a^7*x*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/_
+   (a+b/x^(1/6))+7*a*b^7*log(x)*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))/_
+   (a*b+b^2/x^(1/6))+70*a^4*b^4*sqrt(a^2+b^2/x^(1/3)+2*a*b/x^(1/6))*_
+   sqrt(x)/(a*b+b^2/x^(1/6))
+--R 
+--R
+--R   (2)
+--R              2 5 6+-+2
+--R         1260a b  \|x
+--R       + 
+--R              5 2 3+-+2       3 4 3+-+      4 3 +-+        6            7  6+-+
+--R         (315a b  \|x  + 1050a b  \|x + 700a b \|x  + 70a b log(x) + 10a x)\|x
+--R       + 
+--R            6         7
+--R         84a b x - 60b
+--R    *
+--R        +----------------------------+
+--R        |  2 3+-+   2 6+-+       3+-+
+--R        |(a  \|x + b )\|x  + 2a b\|x
+--R        |----------------------------
+--R        |          3+-+6+-+
+--R       \|          \|x \|x
+--R  /
+--R        6+-+
+--R     10a\|x  + 10b
+--R                                                    Type: Expression(Integer)
+--E 1076
+
+--S 1077 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1077
+
+)clear all
+
+--S 1078 of 1311
+t0:=(a^2+b^2/x^(1/2)+2*a*b/x^(1/4))^(5/2)
+--R 
+--R
+--R   (1)
+--R           2 2 +-+    4     4 4+-+2        3 +-+     3    4+-+     2 2
+--R       ((2a b \|x  + a x + b )\|x   + (4a b \|x  + 4a b x)\|x  + 4a b x)
+--R    *
+--R        +----------------------------+
+--R        |  2 +-+    2 4+-+        +-+
+--R        |(a \|x  + b )\|x  + 2a b\|x
+--R        |----------------------------
+--R        |           +-+4+-+
+--R       \|          \|x \|x
+--R  /
+--R       4+-+2
+--R     x \|x
+--R                                                    Type: Expression(Integer)
+--E 1078
+
+--S 1079 of 1311
+r0:=-4*b^6*sqrt(a^2+2*a*b/x^(1/4)+b^2/sqrt(x))/((a*b+b^2/x^(1/4))*x^(1/4))+_
+   40*a^2*b^4*x^(1/4)*sqrt(a^2+2*a*b/x^(1/4)+b^2/sqrt(x))/(a*b+b^2/x^(1/4))+_
+   20/3*a^4*b^2*x^(3/4)*sqrt(a^2+2*a*b/x^(1/4)+b^2/sqrt(x))/_
+   (a*b+b^2/x^(1/4))+a^5*x*sqrt(a^2+2*a*b/x^(1/4)+b^2/sqrt(x))/_
+   (a+b/x^(1/4))+5*a*b^5*log(x)*sqrt(a^2+2*a*b/x^(1/4)+b^2/sqrt(x))/_
+   (a*b+b^2/x^(1/4))+20*a^3*b^3*sqrt(x)*sqrt(a^2+2*a*b/x^(1/4)+_
+   b^2/sqrt(x))/(a*b+b^2/x^(1/4))
+--R 
+--R
+--R   (2)
+--R            2 3 4+-+2      3 2 +-+        4           5  4+-+      4         5
+--R       (120a b  \|x  + (60a b \|x  + 15a b log(x) + 3a x)\|x  + 20a b x - 12b )
+--R    *
+--R        +----------------------------+
+--R        |  2 +-+    2 4+-+        +-+
+--R        |(a \|x  + b )\|x  + 2a b\|x
+--R        |----------------------------
+--R        |           +-+4+-+
+--R       \|          \|x \|x
+--R  /
+--R       4+-+
+--R     3a\|x  + 3b
+--R                                                    Type: Expression(Integer)
+--E 1079
+
+--S 1080 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1080
+
+)clear all
+
+--S 1081 of 1311
+t0:=(a^2+b^2/x+2*a*b/x^(1/2))^(3/2)
+--R 
+--R
+--R                                  +-----------------------+
+--R                                  |  2     2  +-+
+--R           2     2  +-+           |(a x + b )\|x  + 2a b x
+--R        ((a x + b )\|x  + 2a b x) |-----------------------
+--R                                  |           +-+
+--R                                 \|         x\|x
+--R   (1)  ---------------------------------------------------
+--R                                 +-+
+--R                               x\|x
+--R                                                    Type: Expression(Integer)
+--E 1081
+
+--S 1082 of 1311
+r0:=a^3*x*sqrt(a^2+b^2/x+2*a*b/sqrt(x))/(a+b/sqrt(x))+3*a*b^3*log(x)*_
+   sqrt(a^2+b^2/x+2*a*b/sqrt(x))/(a*b+b^2/sqrt(x))-2*b^4*sqrt(a^2+b^2/x+_
+   2*a*b/sqrt(x))/((a*b+b^2/sqrt(x))*sqrt(x))+6*a^2*b^2*sqrt(x)*_
+   sqrt(a^2+b^2/x+2*a*b/sqrt(x))/(a*b+b^2/sqrt(x))
+--R 
+--R
+--R                                                 +-----------------------+
+--R                                                 |  2     2  +-+
+--R              2          3   +-+     2        3  |(a x + b )\|x  + 2a b x
+--R        ((3a b log(x) + a x)\|x  + 6a b x - 2b ) |-----------------------
+--R                                                 |           +-+
+--R                                                \|         x\|x
+--R   (2)  ------------------------------------------------------------------
+--R                                       +-+
+--R                                     a\|x  + b
+--R                                                    Type: Expression(Integer)
+--E 1082
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 1083 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1083
+
+)clear all
+
+--S 1084 of 1311
+t0:=1/(a^2+2*a*b*x^(1/2)+b^2*x)^(1/2)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         +-------------------+
+--R         |     +-+    2     2
+--R        \|2a b\|x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 1084
+
+--S 1085 of 1311
+r0:=-2*a*log(a+b*sqrt(x))*(a+b*sqrt(x))/(b^2*sqrt(a^2+b^2*x+2*a*b*sqrt(x)))+_
+   2*sqrt(a^2+b^2*x+2*a*b*sqrt(x))/b^2
+--R 
+--R
+--R                +-+     2       +-+             +-+     2      2
+--R        (- 2a b\|x  - 2a )log(b\|x  + a) + 4a b\|x  + 2b x + 2a
+--R   (2)  --------------------------------------------------------
+--R                           +-------------------+
+--R                         2 |     +-+    2     2
+--R                        b \|2a b\|x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 1085
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 1086 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1086
+
+)clear all
+
+--S 1087 of 1311
+t0:=1/(a^2+2*a*b*x^(1/4)+b^2*x^(1/2))^(3/2)
+--R 
+--R
+--R                                1
+--R   (1)  -------------------------------------------------
+--R                                 +----------------------+
+--R             4+-+    2 +-+    2  |    4+-+    2 +-+    2
+--R        (2a b\|x  + b \|x  + a )\|2a b\|x  + b \|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1087
+
+--S 1088 of 1311
+r0:=-2*(a+b*x^(1/4))*x^(3/4)/(b*(a^2+2*a*b*x^(1/4)+b^2*sqrt(x))^(3/2))-_
+   12*a*(a+b*x^(1/4))*log(a+b*x^(1/4))/(b^4*sqrt(a^2+2*a*b*x^(1/4)+_
+   b^2*sqrt(x)))-6*sqrt(x)/(b^2*sqrt(a^2+2*a*b*x^(1/4)+b^2*sqrt(x)))+_
+   12*sqrt(a^2+2*a*b*x^(1/4)+b^2*sqrt(x))/b^4
+--R 
+--R
+--R   (2)
+--R               2 2 4+-+2          3 +-+      3  4+-+      2 2 +-+      4
+--R         (- 24a b  \|x  + (- 12a b \|x  - 36a b)\|x  - 12a b \|x  - 12a )
+--R      *
+--R              4+-+
+--R         log(b\|x  + a)
+--R     + 
+--R             3 4+-+3     2 2 4+-+2        3 +-+      3  4+-+      2 2 +-+     4
+--R       - 2a b  \|x  + 48a b  \|x  + (36a b \|x  + 48a b)\|x  + 18a b \|x  + 4b x
+--R     + 
+--R          4
+--R       12a
+--R  /
+--R                                 +----------------------+
+--R          5 4+-+   6 +-+    2 4  |    4+-+    2 +-+    2
+--R     (2a b  \|x + b \|x  + a b )\|2a b\|x  + b \|x  + a
+--R                                                    Type: Expression(Integer)
+--E 1088
+
+--S 1089 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1089
+
+)clear all
+
+--S 1090 of 1311
+t0:=1/(a^2+2*a*b*x^(1/6)+b^2*x^(1/3))^(5/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          2 2 6+-+2       3 3+-+    3  6+-+    4 3+-+2    2 2 3+-+   4
+--R       (4a b  \|x  + (4a b  \|x + 4a b)\|x  + b  \|x  + 2a b  \|x + a )
+--R    *
+--R        +----------------------+
+--R        |    6+-+    2 3+-+   2
+--R       \|2a b\|x  + b  \|x + a
+--R                                                    Type: Expression(Integer)
+--E 1090
+
+--S 1091 of 1311
+r0:=-5/2*x^(2/3)/(b^2*(a^2+2*a*b*x^(1/6)+b^2*x^(1/3))^(3/2))-_
+   3/2*(a+b*x^(1/6))*x^(5/6)/(b*(a^2+2*a*b*x^(1/6)+b^2*x^(1/3))^(5/2))-_
+   15*x^(1/3)/(b^4*sqrt(a^2+2*a*b*x^(1/6)+b^2*x^(1/3)))-_
+   30*a*(a+b*x^(1/6))*log(a+b*x^(1/6))/(b^6*sqrt(a^2+2*a*b*x^(1/6)+_
+   b^2*x^(1/3)))+30*sqrt(a^2+2*a*b*x^(1/6)+b^2*x^(1/3))/b^6-_
+   5*(a+b*x^(1/6))*sqrt(x)/(b^3*(a^2+2*a*b*x^(1/6)+b^2*x^(1/3))^(3/2))
+--R 
+--R
+--R   (2)
+--R                 3 3 6+-+3         2 4 3+-+      4 2 6+-+2
+--R           - 240a b  \|x  + (- 240a b  \|x - 480a b )\|x
+--R         + 
+--R                   5 3+-+2      3 3 3+-+      5  6+-+      2 4 3+-+2
+--R           (- 60a b  \|x  - 360a b  \|x - 300a b)\|x  - 60a b  \|x
+--R         + 
+--R                 4 2 3+-+     6
+--R           - 120a b  \|x - 60a
+--R      *
+--R              6+-+
+--R         log(b\|x  + a)
+--R     + 
+--R             5 6+-+5      3 3 6+-+3       2 4 3+-+       5 +-+       4 2 6+-+2
+--R       - 3a b  \|x  + 480a b  \|x  + (600a b  \|x - 20a b \|x  + 720a b )\|x
+--R     + 
+--R              5 3+-+2        6 +-+       3 3 3+-+      2 4 +-+       5  6+-+
+--R       (230a b  \|x  + (- 10b \|x  + 600a b )\|x  - 30a b \|x  + 360a b)\|x
+--R     + 
+--R           2 4 3+-+2          5 +-+       4 2 3+-+      3 3 +-+      6       6
+--R       115a b  \|x  + (- 10a b \|x  + 150a b )\|x  - 10a b \|x  + 22b x + 60a
+--R  /
+--R          2 8 6+-+2       9 3+-+    3 7 6+-+     10 3+-+2    2 8 3+-+    4 6
+--R       (8a b  \|x  + (8a b  \|x + 8a b )\|x  + 2b   \|x  + 4a b  \|x + 2a b )
+--R    *
+--R        +----------------------+
+--R        |    6+-+    2 3+-+   2
+--R       \|2a b\|x  + b  \|x + a
+--R                                                    Type: Expression(Integer)
+--E 1091
+
+--S 1092 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1092
+
+)clear all
+
+--S 1093 of 1311
+t0:=(a^2+b^2/x^(2/(1+2*p))+2*a*b/x^(1/(1+2*p)))^p
+--R 
+--R
+--R                1              2           1   p
+--R             ------         ------      ------
+--R           2 2p + 1         2p + 1    2 2p + 1
+--R         (a x       + 2a b)x       + b x
+--R   (1)  (-------------------------------------)
+--R                         1      2
+--R                      ------ ------
+--R                      2p + 1 2p + 1
+--R                     x      x
+--R                                                    Type: Expression(Integer)
+--E 1093
+
+--S 1094 of 1311
+r0:=x*(a+b*x^(1/(-1-2*p)))*(a^2+2*a*b*x^(1/(-1-2*p))+b^2/x^(2/(1+2*p)))^p/a
+--R 
+--R
+--R                                          1            2        p
+--R                   1                 - ------       ------
+--R              - ------                 2p + 1    2  2p + 1    2
+--R                2p + 1        (2a b x         + a )x       + b
+--R        (b x x         + a x)(---------------------------------)
+--R                                               2
+--R                                            ------
+--R                                            2p + 1
+--R                                           x
+--R   (2)  ---------------------------------------------------------
+--R                                    a
+--R                                                    Type: Expression(Integer)
+--E 1094
+
+--S 1095 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1095
+
+)clear all
+
+--S 1096 of 1311
+t0:=1/(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2*(1+n)/n)
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                              n + 1
+--R                              -----
+--R          2 2n         n    2   2n
+--R        (b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1096
+
+--S 1097 of 1311
+r0:=x*(a+b*x^n)/(a*(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2*(1+n)/n))
+--R 
+--R
+--R                      n
+--R                 b x x  + a x
+--R   (2)  -----------------------------
+--R                                n + 1
+--R                                -----
+--R            2 2n         n    2   2n
+--R        a (b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1097
+
+--S 1098 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1098
+
+)clear all
+
+--S 1099 of 1311
+t0:=(a^2+b^2/x^(1/(1+p))+2*a*b/x^(1/2/(1+p)))^p
+--R 
+--R
+--R                1             1           1   p
+--R             ------         -----      ------
+--R           2 2p + 2         p + 1    2 2p + 2
+--R         (a x       + 2a b)x      + b x
+--R   (1)  (------------------------------------)
+--R                         1     1
+--R                      ------ -----
+--R                      2p + 2 p + 1
+--R                     x      x
+--R                                                    Type: Expression(Integer)
+--E 1099
+
+--S 1100 of 1311
+r0:=2*(1+p)*x*(a+b/x^(1/2/(1+p)))*(a^2+b^2/x^(1/(1+p))+_
+   2*a*b/x^(1/2/(1+p)))^p/(a*(1+2*p))-x*(a^2+b^2/x^(1/(1+p))+_
+   2*a*b/x^(1/2/(1+p)))^(1+p)/(a^2*(1+2*p))
+--R 
+--R
+--R   (2)
+--R                          1             1           1   p + 1
+--R               1       ------         -----      ------
+--R            ------   2 2p + 2         p + 1    2 2p + 2
+--R            2p + 2 (a x       + 2a b)x      + b x
+--R       - x x      (------------------------------------)
+--R                                   1     1
+--R                                ------ -----
+--R                                2p + 2 p + 1
+--R                               x      x
+--R     + 
+--R                            1
+--R                         ------
+--R             2      2    2p + 2
+--R         ((2a p + 2a )x x       + (2a b p + 2a b)x)
+--R      *
+--R                 1             1           1   p
+--R              ------         -----      ------
+--R            2 2p + 2         p + 1    2 2p + 2
+--R          (a x       + 2a b)x      + b x
+--R         (------------------------------------)
+--R                          1     1
+--R                       ------ -----
+--R                       2p + 2 p + 1
+--R                      x      x
+--R  /
+--R                    1
+--R                 ------
+--R        2     2  2p + 2
+--R     (2a p + a )x
+--R                                                    Type: Expression(Integer)
+--E 1100
+
+--S 1101 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1101
+
+)clear all
+
+--S 1102 of 1311
+t0:=1/(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2*(1+2*n)/n)
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R                              2n + 1
+--R                              ------
+--R          2 2n         n    2   2n
+--R        (b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1102
+
+--S 1103 of 1311
+r0:=x*(a+b*x^n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2*(-2+(-1)/n))/(a*(1+n))+_
+   n*x/(a^2*(1+n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2/n))
+--R 
+--R
+--R   (2)
+--R                                         - 2n - 1                       1
+--R                                         --------                      --
+--R           n    2    2 2n         n    2    2n     2 2n         n    2 2n
+--R   (a b x x  + a x)(b x   + 2a b x  + a )        (b x   + 2a b x  + a )   + n x
+--R   ----------------------------------------------------------------------------
+--R                                                         1
+--R                                                        --
+--R                          2     2   2 2n         n    2 2n
+--R                        (a n + a )(b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1103
+
+--S 1104 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1104
+
+)clear all
+
+--S 1105 of 1311
+t0:=x^(-1+2*n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^p
+--R 
+--R
+--R         2n - 1  2 2n         n    2 p
+--R   (1)  x      (b x   + 2a b x  + a )
+--R                                                    Type: Expression(Integer)
+--E 1105
+
+--S 1106 of 1311
+r0:=-a*(a+b*x^n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^p/(b^2*n*(1+2*p))+_
+   1/2*(a^2+2*a*b*x^n+b^2*x^(2*n))^(1+p)/(b^2*n*(1+p))
+--R 
+--R
+--R   (2)
+--R                 2 2n         n    2 p + 1
+--R       (2p + 1)(b x   + 2a b x  + a )
+--R     + 
+--R                          n     2      2   2 2n         n    2 p
+--R       ((- 2a b p - 2a b)x  - 2a p - 2a )(b x   + 2a b x  + a )
+--R  /
+--R       2   2     2        2
+--R     4b n p  + 6b n p + 2b n
+--R                                                    Type: Expression(Integer)
+--E 1106
+
+--S 1107 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1107
+
+)clear all
+
+--S 1108 of 1311
+t0:=x^(-1+2*n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2)
+--R 
+--R
+--R   (1)
+--R        4 2n - 1  2n 2        3 n     2 2  2n - 1 2n
+--R       b x      (x  )  + (4a b x  + 2a b )x      x
+--R     + 
+--R          2 2  n 2     3   n    4  2n - 1
+--R       (4a b (x )  + 4a b x  + a )x
+--R  *
+--R      +--------------------+
+--R      | 2 2n         n    2
+--R     \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1108
+
+--S 1109 of 1311
+r0:=-1/6*a*(a+b*x^n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2)/(b^2*n)+_
+   1/7*(a^2+2*a*b*x^n+b^2*x^(2*n))^(7/2)/(b^2*n)
+--R 
+--R
+--R   (2)
+--R           6  2n 3         5 n      2 4   2n 2
+--R         6b (x  )  + (29a b x  + 11a b )(x  )
+--R       + 
+--R             2 4  n 2      3 3 n     4 2  2n      3 3  n 3      4 2  n 2
+--R         (44a b (x )  + 30a b x  + 4a b )x   + 20a b (x )  + 16a b (x )
+--R       + 
+--R          5   n    6
+--R         a b x  - a
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R  /
+--R        2
+--R     42b n
+--R                                                    Type: Expression(Integer)
+--E 1109
+
+--S 1110 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1110
+
+)clear all
+
+--S 1111 of 1311
+t0:=x^(-1+2*n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(3/2)
+--R 
+--R
+--R                                               +--------------------+
+--R          2 2n - 1 2n          n    2  2n - 1  | 2 2n         n    2
+--R   (1)  (b x      x   + (2a b x  + a )x      )\|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1111
+
+--S 1112 of 1311
+r0:=-1/4*a*(a+b*x^n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(3/2)/(b^2*n)+_
+   1/5*(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2)/(b^2*n)
+--R 
+--R
+--R   (2)
+--R          4  2n 2         3 n     2 2  2n     2 2  n 2    3   n    4
+--R       (4b (x  )  + (11a b x  + 3a b )x   + 6a b (x )  + a b x  - a )
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R  /
+--R        2
+--R     20b n
+--R                                                    Type: Expression(Integer)
+--E 1112
+
+--S 1113 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1113
+
+)clear all
+
+--S 1114 of 1311
+t0:=x^(-1+2*n)*(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2)
+--R 
+--R
+--R                +--------------------+
+--R         2n - 1 | 2 2n         n    2
+--R   (1)  x      \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1114
+
+--S 1115 of 1311
+r0:=1/3*x^(2*n)*sqrt(a^2+2*a*b*x^n+b^2*x^(2*n))/n+1/6*a*x^(2*n)*_
+   sqrt(a^2+2*a*b*x^n+b^2*x^(2*n))/(n*(a+b*x^n))
+--R 
+--R
+--R                        +--------------------+
+--R             n       2n | 2 2n         n    2
+--R        (2b x  + 3a)x  \|b x   + 2a b x  + a
+--R   (2)  --------------------------------------
+--R                          n
+--R                    6b n x  + 6a n
+--R                                                    Type: Expression(Integer)
+--E 1115
+
+--S 1116 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1116
+
+)clear all
+
+--S 1117 of 1311
+t0:=x^(-1+2*n)/(a^2+2*a*b*x^n+b^2*x^(2*n))^(1/2)
+--R 
+--R
+--R                 2n - 1
+--R                x
+--R   (1)  -----------------------
+--R         +--------------------+
+--R         | 2 2n         n    2
+--R        \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1117
+
+--S 1118 of 1311
+r0:=-a*(a+b*x^n)*log(a+b*x^n)/(b^2*n*sqrt(a^2+2*a*b*x^n+b^2*x^(2*n)))+_
+   sqrt(a^2+2*a*b*x^n+b^2*x^(2*n))/(b^2*n)
+--R 
+--R
+--R                n    2        n         2 2n         n    2
+--R        (- a b x  - a )log(b x  + a) + b x   + 2a b x  + a
+--R   (2)  ---------------------------------------------------
+--R                         +--------------------+
+--R                      2  | 2 2n         n    2
+--R                     b n\|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1118
+
+--S 1119 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1119
+
+)clear all
+
+--S 1120 of 1311
+t0:=x^(-1+2*n)/(a^2+2*a*b*x^n+b^2*x^(2*n))^(3/2)
+--R 
+--R
+--R                            2n - 1
+--R                           x
+--R   (1)  ---------------------------------------------
+--R                               +--------------------+
+--R          2 2n         n    2  | 2 2n         n    2
+--R        (b x   + 2a b x  + a )\|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1120
+
+--S 1121 of 1311
+r0:=1/2*x^(2*n)*(a+b*x^n)/(a*n*(a^2+2*a*b*x^n+b^2*x^(2*n))^(3/2))
+--R 
+--R
+--R                                 n      2n
+--R                             (b x  + a)x
+--R   (2)  ------------------------------------------------------
+--R                                        +--------------------+
+--R             2   2n     2     n     3   | 2 2n         n    2
+--R        (2a b n x   + 4a b n x  + 2a n)\|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1121
+
+--S 1122 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1122
+
+)clear all
+
+--S 1123 of 1311
+t0:=x^(-1+2*n)/(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2)
+--R 
+--R
+--R   (1)
+--R      2n - 1
+--R     x
+--R  /
+--R         4  2n 2        3 n     2 2  2n     2 2  n 2     3   n    4
+--R       (b (x  )  + (4a b x  + 2a b )x   + 4a b (x )  + 4a b x  + a )
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1123
+
+--S 1124 of 1311
+r0:=1/4*a*(a+b*x^n)/(b^2*n*(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2))+(-1/3)/_
+   (b^2*n*(a^2+2*a*b*x^n+b^2*x^(2*n))^(3/2))
+--R 
+--R
+--R   (2)
+--R         2 2n         n    2
+--R     - 4b x   - 5a b x  - a
+--R  /
+--R            6    2n 2         5   n      2 4   2n      2 4    n 2      3 3   n
+--R         12b n (x  )  + (48a b n x  + 24a b n)x   + 48a b n (x )  + 48a b n x
+--R       + 
+--R            4 2
+--R         12a b n
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1124
+
+--S 1125 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1125
+
+)clear all
+
+--S 1126 of 1311
+t0:=x^(-1+2*n)/(a^2+2*a*b*x^n+b^2*x^(2*n))^(7/2)
+--R 
+--R
+--R   (1)
+--R      2n - 1
+--R     x
+--R  /
+--R          6  2n 3        5 n     2 4   2n 2
+--R         b (x  )  + (6a b x  + 3a b )(x  )
+--R       + 
+--R             2 4  n 2      3 3 n     4 2  2n     3 3  n 3      4 2  n 2
+--R         (12a b (x )  + 12a b x  + 3a b )x   + 8a b (x )  + 12a b (x )
+--R       + 
+--R           5   n    6
+--R         6a b x  + a
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1126
+
+--S 1127 of 1311
+r0:=1/6*a*(a+b*x^n)/(b^2*n*(a^2+2*a*b*x^n+b^2*x^(2*n))^(7/2))+_
+   (-1/5)/(b^2*n*(a^2+2*a*b*x^n+b^2*x^(2*n))^(5/2))
+--R 
+--R
+--R   (2)
+--R         2 2n         n    2
+--R     - 6b x   - 7a b x  - a
+--R  /
+--R            8    2n 3          7   n      2 6    2n 2
+--R         30b n (x  )  + (180a b n x  + 90a b n)(x  )
+--R       + 
+--R              2 6    n 2       3 5   n      4 4   2n       3 5    n 3
+--R         (360a b n (x )  + 360a b n x  + 90a b n)x   + 240a b n (x )
+--R       + 
+--R             4 4    n 2       5 3   n      6 2
+--R         360a b n (x )  + 180a b n x  + 30a b n
+--R    *
+--R        +--------------------+
+--R        | 2 2n         n    2
+--R       \|b x   + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1127
+
+--S 1128 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1128
+
+)clear all
+
+--S 1129 of 1311
+t0:=x^(-1+4*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              4n - 1
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1129
+
+--S 1130 of 1311
+r0:=-b*x^n/(c^2*n)+1/2*x^(2*n)/(c*n)+1/2*(b^2-a*c)*log(a+b*x^n+c*x^(2*n))/_
+   (c^3*n)+b*(b^2-3*a*c)*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/_
+   (c^3*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                    +-----------+
+--R                 2  |          2        2n      n
+--R       (- a c + b )\|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R                                    n                            +-----------+
+--R                     3          2c x  + b        2 2n         n  |          2
+--R       (- 6a b c + 2b )atanh(--------------) + (c x   - 2b c x )\|- 4a c + b
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R  /
+--R          +-----------+
+--R       3  |          2
+--R     2c n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1130
+
+--S 1131 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1131
+
+)clear all
+
+--S 1132 of 1311
+t0:=x^(-1+3*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              3n - 1
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1132
+
+--S 1133 of 1311
+r0:=x^n/(c*n)-1/2*b*log(a+b*x^n+c*x^(2*n))/(c^2*n)-(b^2-2*a*c)*_
+   atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/(c^2*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R           +-----------+
+--R           |          2        2n      n
+--R       - b\|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R                                n                +-----------+
+--R                 2          2c x  + b          n |          2
+--R       (4a c - 2b )atanh(--------------) + 2c x \|- 4a c + b
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R  /
+--R          +-----------+
+--R       2  |          2
+--R     2c n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1133
+
+--S 1134 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1134
+
+)clear all
+
+--S 1135 of 1311
+t0:=x^(-1+2*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              2n - 1
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1135
+
+--S 1136 of 1311
+r0:=1/2*log(a+b*x^n+c*x^(2*n))/(c*n)+b*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/_
+   (c*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R         +-----------+                                        n
+--R         |          2        2n      n                    2c x  + b
+--R        \|- 4a c + b  log(c x   + b x  + a) + 2b atanh(--------------)
+--R                                                        +-----------+
+--R                                                        |          2
+--R                                                       \|- 4a c + b
+--R   (2)  --------------------------------------------------------------
+--R                                   +-----------+
+--R                                   |          2
+--R                              2c n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1136
+
+--S 1137 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1137
+
+)clear all
+
+--S 1138 of 1311
+t0:=x^(-1+n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              n - 1
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1138
+
+--S 1139 of 1311
+r0:=-2*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/(n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                        n
+--R                    2c x  + b
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  - ----------------------
+--R                +-----------+
+--R                |          2
+--R              n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1139
+
+--S 1140 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1140
+
+)clear all
+
+--S 1141 of 1311
+t0:=x^(-1-n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - n - 1
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1141
+
+--S 1142 of 1311
+r0:=(-1)/(a*n*x^n)-b*log(x)/a^2+1/2*b*log(a+b*x^n+c*x^(2*n))/(a^2*n)-_
+   (b^2-2*a*c)*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/(a^2*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R            +-----------+
+--R          n |          2        2n      n
+--R       b x \|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R                                n                                 +-----------+
+--R               2  n         2c x  + b                     n       |          2
+--R     (4a c - 2b )x atanh(--------------) + (- 2b n log(x)x  - 2a)\|- 4a c + b
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R  /
+--R             +-----------+
+--R       2   n |          2
+--R     2a n x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1142
+
+--S 1143 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1143
+
+)clear all
+
+--S 1144 of 1311
+t0:=x^(-1-2*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - 2n - 1
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1144
+
+--S 1145 of 1311
+r0:=(-1/2)/(a*n*x^(2*n))+b/(a^2*n*x^n)+(b^2-a*c)*log(x)/a^3-1/2*(b^2-a*c)*_
+   log(a+b*x^n+c*x^(2*n))/(a^3*n)+b*(b^2-3*a*c)*atanh((b+2*c*x^n)/_
+   sqrt(b^2-4*a*c))/(a^3*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                       +-----------+
+--R               2  n 2n |          2        2n      n
+--R       (a c - b )x x  \|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R                                         n
+--R                     3  n 2n         2c x  + b
+--R       (- 6a b c + 2b )x x  atanh(--------------)
+--R                                   +-----------+
+--R                                   |          2
+--R                                  \|- 4a c + b
+--R     + 
+--R                                                     +-----------+
+--R                     2          n         2n    2 n  |          2
+--R       (((- 2a c + 2b )n log(x)x  + 2a b)x   - a x )\|- 4a c + b
+--R  /
+--R                +-----------+
+--R       3   n 2n |          2
+--R     2a n x x  \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1145
+
+--S 1146 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1146
+
+)clear all
+
+--S 1147 of 1311
+t0:=x^(-1-3*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - 3n - 1
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1147
+
+--S 1148 of 1311
+r0:=(-1/3)/(a*n*x^(3*n))+1/2*b/(a^2*n*x^(2*n))+(-b^2+a*c)/(a^3*n*x^n)-_
+   b*(b^2-2*a*c)*log(x)/a^4+1/2*b*(b^2-2*a*c)*log(a+b*x^n+c*x^(2*n))/_
+   (a^4*n)-(b^4-4*a*b^2*c+2*a^2*c^2)*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/_
+   (a^4*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                +-----------+
+--R                     3  n 2n 3n |          2        2n      n
+--R       (- 6a b c + 3b )x x  x  \|- 4a c + b  log(c x   + b x  + a)
+--R     + 
+--R                                                      n
+--R             2 2        2      4  n 2n 3n         2c x  + b
+--R       (- 12a c  + 24a b c - 6b )x x  x  atanh(--------------)
+--R                                                +-----------+
+--R                                                |          2
+--R                                               \|- 4a c + b
+--R     + 
+--R                            3          n     2        2  2n     2   n  3n
+--R             (((12a b c - 6b )n log(x)x  + 6a c - 6a b )x   + 3a b x )x
+--R           + 
+--R                 3 n 2n
+--R             - 2a x x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                   +-----------+
+--R       4   n 2n 3n |          2
+--R     6a n x x  x  \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1148
+
+--S 1149 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1149
+
+)clear all
+
+--S 1150 of 1311
+t0:=x^(-1+1/4*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              n - 4
+--R              -----
+--R                4
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1150
+
+--S 1151 of 1311
+r0:=2*2^(3/4)*c^(3/4)*atan(2^(1/4)*c^(1/4)*x^(1/4*n)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))/(n*(-b-sqrt(b^2-4*a*c))^(3/4)*sqrt(b^2-4*a*c))+_
+   2*2^(3/4)*c^(3/4)*atanh(2^(1/4)*c^(1/4)*x^(1/4*n)/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))/(n*(-b-sqrt(b^2-4*a*c))^(3/4)*sqrt(b^2-4*a*c))-_
+   2*2^(3/4)*c^(3/4)*atan(2^(1/4)*c^(1/4)*x^(1/4*n)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))/(n*sqrt(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))-_
+   2*2^(3/4)*c^(3/4)*atanh(2^(1/4)*c^(1/4)*x^(1/4*n)/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))/(n*sqrt(b^2-4*a*c)*(-b+sqrt(b^2-4*a*c))^(3/4))
+--R 
+--R
+--R   (2)
+--R                                                            n
+--R                     +------------------+3                  -
+--R                     | +-----------+                   4+-+ 4 4+-+
+--R        4+-+3 4+-+3 4| |          2                    \|2 x  \|c
+--R       2\|2   \|c   \|\|- 4a c + b   - b  atanh(-----------------------)
+--R                                                 +--------------------+
+--R                                                 |   +-----------+
+--R                                                4|   |          2
+--R                                                \|- \|- 4a c + b   - b
+--R     + 
+--R                                                               n
+--R                       +--------------------+3                 -
+--R                       |   +-----------+                  4+-+ 4 4+-+
+--R          4+-+3 4+-+3 4|   |          2                   \|2 x  \|c
+--R       - 2\|2   \|c   \|- \|- 4a c + b   - b  atanh(---------------------)
+--R                                                     +------------------+
+--R                                                     | +-----------+
+--R                                                    4| |          2
+--R                                                    \|\|- 4a c + b   - b
+--R     + 
+--R                                                           n
+--R                     +------------------+3                 -
+--R                     | +-----------+                  4+-+ 4 4+-+
+--R        4+-+3 4+-+3 4| |          2                   \|2 x  \|c
+--R       2\|2   \|c   \|\|- 4a c + b   - b  atan(-----------------------)
+--R                                                +--------------------+
+--R                                                |   +-----------+
+--R                                               4|   |          2
+--R                                               \|- \|- 4a c + b   - b
+--R     + 
+--R                                                              n
+--R                       +--------------------+3                -
+--R                       |   +-----------+                 4+-+ 4 4+-+
+--R          4+-+3 4+-+3 4|   |          2                  \|2 x  \|c
+--R       - 2\|2   \|c   \|- \|- 4a c + b   - b  atan(---------------------)
+--R                                                    +------------------+
+--R                                                    | +-----------+
+--R                                                   4| |          2
+--R                                                   \|\|- 4a c + b   - b
+--R  /
+--R                     +--------------------+3  +------------------+3
+--R       +-----------+ |   +-----------+        | +-----------+
+--R       |          2 4|   |          2        4| |          2
+--R     n\|- 4a c + b  \|- \|- 4a c + b   - b   \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1151
+
+--S 1152 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1152
+
+)clear all
+
+--S 1153 of 1311
+t0:=x^(-1+1/3*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              n - 3
+--R              -----
+--R                3
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1153
+
+--S 1154 of 1311
+r0:=2^(2/3)*c^(2/3)*log(2^(1/3)*c^(1/3)*x^(1/3*n)+(b-sqrt(b^2-_
+   4*a*c))^(1/3))/(n*(b-sqrt(b^2-4*a*c))^(2/3)*sqrt(b^2-4*a*c))-_
+   c^(2/3)*log(2^(2/3)*c^(2/3)*x^(2/3*n)-2^(1/3)*c^(1/3)*x^(1/3*n)*_
+   (b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))/(2^(1/3)*_
+   n*(b-sqrt(b^2-4*a*c))^(2/3)*sqrt(b^2-4*a*c))-2^(2/3)*c^(2/3)*_
+   atan((-4*c^(1/3)*x^(1/3*n)+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*sqrt(3)/(n*_
+   (b-sqrt(b^2-4*a*c))^(2/3)*sqrt(b^2-4*a*c))-2^(2/3)*c^(2/3)*_
+   log(2^(1/3)*c^(1/3)*x^(1/3*n)+(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (n*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(2/3))+c^(2/3)*log(2^(2/3)*_
+   c^(2/3)*x^(2/3*n)-2^(1/3)*c^(1/3)*x^(1/3*n)*(b+sqrt(b^2-_
+   4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))/(2^(1/3)*n*sqrt(b^2-4*a*c)*_
+   (b+sqrt(b^2-4*a*c))^(2/3))+2^(2/3)*c^(2/3)*atan((-4*c^(1/3)*_
+   x^(1/3*n)+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*_
+   (b+sqrt(b^2-4*a*c))^(1/3)))*sqrt(3)/(n*sqrt(b^2-4*a*c)*_
+   (b+sqrt(b^2-4*a*c))^(2/3))
+--R 
+--R
+--R   (2)
+--R                +--------------------+2
+--R                |   +-----------+
+--R         3+-+2 3|   |          2
+--R         \|c   \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2        n      +------------------+
+--R               | +-----------+              -      | +-----------+
+--R              3| |          2          3+-+ 3 3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - \|2 x  \|c \|\|- 4a c + b   + b
+--R            + 
+--R                    2n
+--R                    --
+--R              3+-+2  3 3+-+2
+--R              \|2  x   \|c
+--R     + 
+--R                 +--------------------+2     +------------------+        n
+--R                 |   +-----------+           | +-----------+             -
+--R          3+-+2 3|   |          2           3| |          2         3+-+ 3 3+-+
+--R       - 2\|c   \|- \|- 4a c + b   + b  log(\|\|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R       -
+--R                   +------------------+2
+--R                   | +-----------+
+--R            3+-+2 3| |          2
+--R            \|c   \|\|- 4a c + b   + b
+--R         *
+--R            log
+--R                  +--------------------+2        n      +--------------------+
+--R                  |   +-----------+              -      |   +-----------+
+--R                 3|   |          2          3+-+ 3 3+-+3|   |          2
+--R                 \|- \|- 4a c + b   + b   - \|2 x  \|c \|- \|- 4a c + b   + b
+--R               + 
+--R                       2n
+--R                       --
+--R                 3+-+2  3 3+-+2
+--R                 \|2  x   \|c
+--R     + 
+--R               +------------------+2     +--------------------+        n
+--R               | +-----------+           |   +-----------+             -
+--R        3+-+2 3| |          2           3|   |          2         3+-+ 3 3+-+
+--R       2\|c   \|\|- 4a c + b   + b  log(\|- \|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R                     +--------------------+2
+--R                     |   +-----------+
+--R           +-+3+-+2 3|   |          2
+--R         2\|3 \|c   \|- \|- 4a c + b   + b
+--R      *
+--R                     +------------------+    n
+--R                     | +-----------+         -
+--R              3+-+2 3| |          2          3 3+-+
+--R              \|2   \|\|- 4a c + b   + b - 4x  \|c
+--R         atan(------------------------------------)
+--R                           +------------------+
+--R                           | +-----------+
+--R                 3+-+2 +-+3| |          2
+--R                 \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                        +------------------+2
+--R                        | +-----------+
+--R              +-+3+-+2 3| |          2
+--R            2\|3 \|c   \|\|- 4a c + b   + b
+--R         *
+--R                        +--------------------+    n
+--R                        |   +-----------+         -
+--R                 3+-+2 3|   |          2          3 3+-+
+--R                 \|2   \|- \|- 4a c + b   + b - 4x  \|c
+--R            atan(--------------------------------------)
+--R                              +--------------------+
+--R                              |   +-----------+
+--R                    3+-+2 +-+3|   |          2
+--R                    \|2  \|3 \|- \|- 4a c + b   + b
+--R  /
+--R                         +--------------------+2  +------------------+2
+--R           +-----------+ |   +-----------+        | +-----------+
+--R      3+-+ |          2 3|   |          2        3| |          2
+--R     n\|2 \|- 4a c + b  \|- \|- 4a c + b   + b   \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1154
+
+--S 1155 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1155
+
+)clear all
+
+--S 1156 of 1311
+t0:=x^(-1+1/2*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R              n - 2
+--R              -----
+--R                2
+--R             x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1156
+
+--S 1157 of 1311
+r0:=2*atan(x^(1/2*n)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*_
+   sqrt(c)/(n*sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-2*atan(x^(1/2*n)*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/_
+   (n*sqrt(b^2-4*a*c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                      n
+--R                 +------------------+                 -
+--R                 | +-----------+                  +-+ 2 +-+
+--R         +-+ +-+ | |          2                  \|2 x \|c
+--R       2\|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                           +--------------------+
+--R                                           |   +-----------+
+--R                                           |   |          2
+--R                                          \|- \|- 4a c + b   + b
+--R     + 
+--R                                                         n
+--R                   +--------------------+                -
+--R                   |   +-----------+                 +-+ 2 +-+
+--R           +-+ +-+ |   |          2                 \|2 x \|c
+--R       - 2\|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                               +------------------+
+--R                                               | +-----------+
+--R                                               | |          2
+--R                                              \|\|- 4a c + b   + b
+--R  /
+--R                     +--------------------+ +------------------+
+--R       +-----------+ |   +-----------+      | +-----------+
+--R       |          2  |   |          2       | |          2
+--R     n\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1157
+
+--S 1158 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1158
+
+)clear all
+
+--S 1159 of 1311
+t0:=x^(-1-1/2*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - n - 2
+--R             -------
+--R                2
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1159
+
+--S 1160 of 1311
+r0:=-4*c^(3/2)*atan(x^(1/2*n)*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(2)/(n*(b-sqrt(b^2-4*a*c))^(3/2)*sqrt(b^2-4*a*c))+4*c^(3/2)*_
+   atan(x^(1/2*n)*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)/_
+   (n*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c))^(3/2))+4*c/(n*x^(1/2*n)*_
+   (b^2-4*a*c-b*sqrt(b^2-4*a*c)))+4*c/(n*x^(1/2*n)*(b^2-4*a*c+_
+   b*sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                n                                   n      +------------------+
+--R                - +-----------+                     -      | +-----------+
+--R            +-+ 2 |          2               2  +-+ 2  +-+ | |          2
+--R         (b\|2 x \|- 4a c + b   + (- 4a c + b )\|2 x )\|c \|\|- 4a c + b   + b
+--R      *
+--R                          n
+--R                          -
+--R                      +-+ 2 +-+
+--R                     \|2 x \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                  n                                   n
+--R                  - +-----------+                     -
+--R              +-+ 2 |          2               2  +-+ 2  +-+
+--R         (- b\|2 x \|- 4a c + b   + (- 4a c + b )\|2 x )\|c
+--R      *
+--R                                                n
+--R          +--------------------+                -
+--R          |   +-----------+                 +-+ 2 +-+
+--R          |   |          2                 \|2 x \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                      +--------------------+ +------------------+
+--R                      |   +-----------+      | +-----------+
+--R                   2  |   |          2       | |          2
+--R       (- 8a c + 2b )\|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                     n +--------------------+ +------------------+
+--R                     - |   +-----------+      | +-----------+
+--R        2       2    2 |   |          2       | |          2
+--R     (4a c - a b )n x \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1160
+
+--S 1161 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1161
+
+)clear all
+
+--S 1162 of 1311
+t0:=x^(-1-1/3*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - n - 3
+--R             -------
+--R                3
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1162
+
+--S 1163 of 1311
+r0:=2*2^(1/3)*c^(4/3)*log(2^(1/3)*c^(1/3)*x^(1/3*n)+(b-_
+   sqrt(b^2-4*a*c))^(1/3))/(n*(b-sqrt(b^2-4*a*c))^(4/3)*_
+   sqrt(b^2-4*a*c))-2^(1/3)*c^(4/3)*log(2^(2/3)*c^(2/3)*x^(2/3*n)-_
+   2^(1/3)*c^(1/3)*x^(1/3*n)*(b-sqrt(b^2-4*a*c))^(1/3)+_
+   (b-sqrt(b^2-4*a*c))^(2/3))/(n*(b-sqrt(b^2-4*a*c))^(4/3)*_
+   sqrt(b^2-4*a*c))+2*2^(1/3)*c^(4/3)*atan((-4*c^(1/3)*x^(1/3*n)+_
+   2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3)))*sqrt(3)/(n*(b-sqrt(b^2-4*a*c))^(4/3)*_
+   sqrt(b^2-4*a*c))-2*2^(1/3)*c^(4/3)*log(2^(1/3)*c^(1/3)*x^(1/3*n)+_
+   (b+sqrt(b^2-4*a*c))^(1/3))/(n*sqrt(b^2-4*a*c)*(b+sqrt(b^2-_
+   4*a*c))^(4/3))+2^(1/3)*c^(4/3)*log(2^(2/3)*c^(2/3)*x^(2/3*n)-_
+   2^(1/3)*c^(1/3)*x^(1/3*n)*(b+sqrt(b^2-4*a*c))^(1/3)+(b+_
+   sqrt(b^2-4*a*c))^(2/3))/(n*sqrt(b^2-4*a*c)*(b+sqrt(b^2-_
+   4*a*c))^(4/3))-2*2^(1/3)*c^(4/3)*atan((-4*c^(1/3)*x^(1/3*n)+_
+   2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+_
+   sqrt(b^2-4*a*c))^(1/3)))*sqrt(3)/(n*sqrt(b^2-4*a*c)*(b+_
+   sqrt(b^2-4*a*c))^(4/3))+6*c/(n*x^(1/3*n)*(b^2-4*a*c-b*_
+   sqrt(b^2-4*a*c)))+6*c/(n*x^(1/3*n)*(b^2-4*a*c+b*sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                  n      +--------------------+
+--R                  -      |   +-----------+
+--R             3+-+ 3 3+-+3|   |          2
+--R         2a c\|2 x  \|c \|- \|- 4a c + b   + b
+--R      *
+--R         log
+--R               +------------------+2        n      +------------------+
+--R               | +-----------+              -      | +-----------+
+--R              3| |          2          3+-+ 3 3+-+3| |          2
+--R              \|\|- 4a c + b   + b   - \|2 x  \|c \|\|- 4a c + b   + b
+--R            + 
+--R                    2n
+--R                    --
+--R              3+-+2  3 3+-+2
+--R              \|2  x   \|c
+--R     + 
+--R       -
+--R                     n      +--------------------+
+--R                     -      |   +-----------+
+--R                3+-+ 3 3+-+3|   |          2
+--R            4a c\|2 x  \|c \|- \|- 4a c + b   + b
+--R         *
+--R                 +------------------+        n
+--R                 | +-----------+             -
+--R                3| |          2         3+-+ 3 3+-+
+--R            log(\|\|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R                  n                                 n      +------------------+
+--R                  - +-----------+                   -      | +-----------+
+--R             3+-+ 3 |          2             2 3+-+ 3 3+-+3| |          2
+--R         (- b\|2 x \|- 4a c + b   + (2a c - b )\|2 x )\|c \|\|- 4a c + b   + b
+--R      *
+--R         log
+--R               +--------------------+2        n      +--------------------+
+--R               |   +-----------+              -      |   +-----------+
+--R              3|   |          2          3+-+ 3 3+-+3|   |          2
+--R              \|- \|- 4a c + b   + b   - \|2 x  \|c \|- \|- 4a c + b   + b
+--R            + 
+--R                    2n
+--R                    --
+--R              3+-+2  3 3+-+2
+--R              \|2  x   \|c
+--R     + 
+--R                 n                                    n
+--R                 - +-----------+                      -
+--R            3+-+ 3 |          2                2 3+-+ 3 3+-+
+--R         (2b\|2 x \|- 4a c + b   + (- 4a c + 2b )\|2 x )\|c
+--R      *
+--R          +------------------+     +--------------------+        n
+--R          | +-----------+          |   +-----------+             -
+--R         3| |          2          3|   |          2         3+-+ 3 3+-+
+--R         \|\|- 4a c + b   + b log(\|- \|- 4a c + b   + b  + \|2 x  \|c)
+--R     + 
+--R       -
+--R                         n      +--------------------+
+--R                         -      |   +-----------+
+--R                3+-+ +-+ 3 3+-+3|   |          2
+--R            4a c\|2 \|3 x  \|c \|- \|- 4a c + b   + b
+--R         *
+--R                        +------------------+    n
+--R                        | +-----------+         -
+--R                 3+-+2 3| |          2          3 3+-+
+--R                 \|2   \|\|- 4a c + b   + b - 4x  \|c
+--R            atan(------------------------------------)
+--R                              +------------------+
+--R                              | +-----------+
+--R                    3+-+2 +-+3| |          2
+--R                    \|2  \|3 \|\|- 4a c + b   + b
+--R     + 
+--R                     n                                        n
+--R                     - +-----------+                          -
+--R            3+-+ +-+ 3 |          2                2 3+-+ +-+ 3 3+-+
+--R         (2b\|2 \|3 x \|- 4a c + b   + (- 4a c + 2b )\|2 \|3 x )\|c
+--R      *
+--R                                          +--------------------+    n
+--R          +------------------+            |   +-----------+         -
+--R          | +-----------+          3+-+2 3|   |          2          3 3+-+
+--R         3| |          2           \|2   \|- \|- 4a c + b   + b - 4x  \|c
+--R         \|\|- 4a c + b   + b atan(--------------------------------------)
+--R                                                +--------------------+
+--R                                                |   +-----------+
+--R                                      3+-+2 +-+3|   |          2
+--R                                      \|2  \|3 \|- \|- 4a c + b   + b
+--R     + 
+--R                                            +--------------------+
+--R               +-----------+                |   +-----------+
+--R               |          2              2 3|   |          2
+--R         (- 6b\|- 4a c + b   + 24a c - 6b )\|- \|- 4a c + b   + b
+--R      *
+--R          +------------------+
+--R          | +-----------+
+--R         3| |          2
+--R         \|\|- 4a c + b   + b
+--R  /
+--R                n                                    n  +--------------------+
+--R                - +-----------+                      -  |   +-----------+
+--R                3 |          2         2        2    3 3|   |          2
+--R       (2a b n x \|- 4a c + b   + (- 8a c + 2a b )n x )\|- \|- 4a c + b   + b
+--R    *
+--R        +------------------+
+--R        | +-----------+
+--R       3| |          2
+--R       \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 1163
+
+--S 1164 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1164
+
+)clear all
+
+--S 1165 of 1311
+t0:=x^(-1-1/4*n)/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R             - n - 4
+--R             -------
+--R                4
+--R            x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1165
+
+--S 1166 of 1311
+r0:=-4*2^(1/4)*c^(5/4)*atan(2^(1/4)*c^(1/4)*x^(1/4*n)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))/(n*(-b-sqrt(b^2-4*a*c))^(5/4)*_
+   sqrt(b^2-4*a*c))+4*2^(1/4)*c^(5/4)*atanh(2^(1/4)*c^(1/4)*x^(1/4*n)/_
+   (-b-sqrt(b^2-4*a*c))^(1/4))/(n*(-b-sqrt(b^2-4*a*c))^(5/4)*_
+   sqrt(b^2-4*a*c))+4*2^(1/4)*c^(5/4)*atan(2^(1/4)*c^(1/4)*x^(1/4*n)/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))/(n*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(5/4))-4*2^(1/4)*c^(5/4)*atanh(2^(1/4)*_
+   c^(1/4)*x^(1/4*n)/(-b+sqrt(b^2-4*a*c))^(1/4))/(n*sqrt(b^2-4*a*c)*_
+   (-b+sqrt(b^2-4*a*c))^(5/4))+8*c/(n*x^(1/4*n)*(b^2-4*a*c-_
+   b*sqrt(b^2-4*a*c)))+8*c/(n*x^(1/4*n)*(b^2-4*a*c+b*sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                n                                 n      +------------------+
+--R                - +-----------+                   -      | +-----------+
+--R           4+-+ 4 |          2             2 4+-+ 4 4+-+4| |          2
+--R         (b\|2 x \|- 4a c + b   + (4a c - b )\|2 x )\|c \|\|- 4a c + b   - b
+--R      *
+--R                           n
+--R                           -
+--R                      4+-+ 4 4+-+
+--R                      \|2 x  \|c
+--R         atanh(-----------------------)
+--R                +--------------------+
+--R                |   +-----------+
+--R               4|   |          2
+--R               \|- \|- 4a c + b   - b
+--R     + 
+--R                  n                                 n
+--R                  - +-----------+                   -
+--R             4+-+ 4 |          2             2 4+-+ 4 4+-+
+--R         (- b\|2 x \|- 4a c + b   + (4a c - b )\|2 x )\|c
+--R      *
+--R                                                 n
+--R          +--------------------+                 -
+--R          |   +-----------+                 4+-+ 4 4+-+
+--R         4|   |          2                  \|2 x  \|c
+--R         \|- \|- 4a c + b   - b atanh(---------------------)
+--R                                       +------------------+
+--R                                       | +-----------+
+--R                                      4| |          2
+--R                                      \|\|- 4a c + b   - b
+--R     + 
+--R                  n                                   n
+--R                  - +-----------+                     -
+--R             4+-+ 4 |          2               2 4+-+ 4 4+-+
+--R         (- b\|2 x \|- 4a c + b   + (- 4a c + b )\|2 x )\|c
+--R      *
+--R                                               n
+--R          +------------------+                 -
+--R          | +-----------+                 4+-+ 4 4+-+
+--R         4| |          2                  \|2 x  \|c
+--R         \|\|- 4a c + b   - b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                   4|   |          2
+--R                                   \|- \|- 4a c + b   - b
+--R     + 
+--R                n                                   n
+--R                - +-----------+                     -
+--R           4+-+ 4 |          2               2 4+-+ 4 4+-+
+--R         (b\|2 x \|- 4a c + b   + (- 4a c + b )\|2 x )\|c
+--R      *
+--R                                                n
+--R          +--------------------+                -
+--R          |   +-----------+                4+-+ 4 4+-+
+--R         4|   |          2                 \|2 x  \|c
+--R         \|- \|- 4a c + b   - b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                     4| |          2
+--R                                     \|\|- 4a c + b   - b
+--R     + 
+--R                       +--------------------+ +------------------+
+--R                       |   +-----------+      | +-----------+
+--R                    2 4|   |          2      4| |          2
+--R       (- 16a c + 4b )\|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R  /
+--R                     n  +--------------------+ +------------------+
+--R                     -  |   +-----------+      | +-----------+
+--R        2       2    4 4|   |          2      4| |          2
+--R     (4a c - a b )n x  \|- \|- 4a c + b   - b \|\|- 4a c + b   - b
+--R                                                    Type: Expression(Integer)
+--E 1166
+
+--S 1167 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1167
+
+)clear all
+
+--S 1168 of 1311
+t0:=x^3/(c+a/x^2+b/x)
+--R 
+--R
+--R               5
+--R              x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1168
+
+--S 1169 of 1311
+r0:=-b*(b^2-2*a*c)*x/c^4+1/2*(b^2-a*c)*x^2/c^3-1/3*b*x^3/c^2+1/4*x^4/c+_
+   1/2*(b^4-3*a*b^2*c+a^2*c^2)*log(a+b*x+c*x^2)/c^5+b*(b^4-_
+   5*a*b^2*c+5*a^2*c^2)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^5*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R           2   2        3       5          2c x + b
+--R       (60a b c  - 60a b c + 12b )atanh(--------------)
+--R                                         +-----------+
+--R                                         |          2
+--R                                        \|- 4a c + b
+--R     + 
+--R              2 2        2      4        2                4 4       3 3
+--R           (6a c  - 18a b c + 6b )log(c x  + b x + a) + 3c x  - 4b c x
+--R         + 
+--R                  3     2 2  2           2      3
+--R           (- 6a c  + 6b c )x  + (24a b c  - 12b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R          +-----------+
+--R        5 |          2
+--R     12c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1169
+
+--S 1170 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1170
+
+)clear all
+
+--S 1171 of 1311
+t0:=x^2/(c+a/x^2+b/x)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1171
+
+--S 1172 of 1311
+r0:=(b^2-a*c)*x/c^3-1/2*b*x^2/c^2+1/3*x^3/c-1/2*b*(b^2-2*a*c)*_
+   log(a+b*x+c*x^2)/c^4-(b^4-4*a*b^2*c+2*a^2*c^2)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(c^4*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R             2 2        2      4          2c x + b
+--R       (- 12a c  + 24a b c - 6b )atanh(--------------)
+--R                                        +-----------+
+--R                                        |          2
+--R                                       \|- 4a c + b
+--R     + 
+--R                         3        2                3 3       2 2
+--R             (6a b c - 3b )log(c x  + b x + a) + 2c x  - 3b c x
+--R           + 
+--R                    2     2
+--R             (- 6a c  + 6b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R         +-----------+
+--R       4 |          2
+--R     6c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1172
+
+--S 1173 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1173
+
+)clear all
+
+--S 1174 of 1311
+t0:=x/(c+a/x^2+b/x)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1174
+
+--S 1175 of 1311
+r0:=-b*x/c^2+1/2*x^2/c+1/2*(b^2-a*c)*log(a+b*x+c*x^2)/c^3+b*(b^2-3*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                     3          2c x + b
+--R       (- 6a b c + 2b )atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R     + 
+--R                                                         +-----------+
+--R                  2        2               2 2           |          2
+--R       ((- a c + b )log(c x  + b x + a) + c x  - 2b c x)\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       3 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1175
+
+--S 1176 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1176
+
+)clear all
+
+--S 1177 of 1311
+t0:=1/(c+a/x^2+b/x)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1177
+
+--S 1178 of 1311
+r0:=x/c-1/2*b*log(a+b*x+c*x^2)/c^2-(b^2-2*a*c)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                 2          2c x + b
+--R       (4a c - 2b )atanh(--------------)
+--R                          +-----------+
+--R                          |          2
+--R                         \|- 4a c + b
+--R     + 
+--R                                        +-----------+
+--R                   2                    |          2
+--R       (- b log(c x  + b x + a) + 2c x)\|- 4a c + b
+--R  /
+--R         +-----------+
+--R       2 |          2
+--R     2c \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1178
+
+--S 1179 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1179
+
+)clear all
+
+--S 1180 of 1311
+t0:=1/((c+a/x^2+b/x)*x)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1180
+
+--S 1181 of 1311
+r0:=1/2*log(a+b*x+c*x^2)/c+b*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--R 
+--R
+--R                                                       +-----------+
+--R                    2c x + b              2            |          2
+--R        2b atanh(--------------) + log(c x  + b x + a)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R   (2)  ------------------------------------------------------------
+--R                                 +-----------+
+--R                                 |          2
+--R                              2c\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1181
+
+--S 1182 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1182
+
+)clear all
+
+--S 1183 of 1311
+t0:=1/((c+a/x^2+b/x)*x^2)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R           2
+--R        c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1183
+
+--S 1184 of 1311
+r0:=2*atanh((b+2*a/x)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--R 
+--R
+--R                   b x + 2a
+--R        2atanh(---------------)
+--R                 +-----------+
+--R                 |          2
+--R               x\|- 4a c + b
+--R   (2)  -----------------------
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1184
+
+--S 1185 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1185
+
+)clear all
+
+--S 1186 of 1311
+t0:=1/((c+a/x^2+b/x)*x^3)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           3      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1186
+
+--S 1187 of 1311
+r0:=log(x)/a-1/2*log(a+b*x+c*x^2)/a+b*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (a*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                                                                +-----------+
+--R               2c x + b                 2                       |          2
+--R   2b atanh(--------------) + (- log(c x  + b x + a) + 2log(x))\|- 4a c + b
+--R             +-----------+
+--R             |          2
+--R            \|- 4a c + b
+--R   --------------------------------------------------------------------------
+--R                                   +-----------+
+--R                                   |          2
+--R                                2a\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1187
+
+--S 1188 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1188
+
+)clear all
+
+--S 1189 of 1311
+t0:=1/((c+a/x^2+b/x)*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           4      3      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1189
+
+--S 1190 of 1311
+r0:=(-1)/(a*x)-b*log(x)/a^2+1/2*b*log(a+b*x+c*x^2)/a^2-(b^2-2*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                 2            2c x + b
+--R       (4a c - 2b )x atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R     + 
+--R                                                    +-----------+
+--R                   2                                |          2
+--R       (b x log(c x  + b x + a) - 2b x log(x) - 2a)\|- 4a c + b
+--R  /
+--R          +-----------+
+--R       2  |          2
+--R     2a x\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1190
+
+--S 1191 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1191
+
+)clear all
+
+--S 1192 of 1311
+t0:=1/((c+a/x^2+b/x)*x^5)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           5      4      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1192
+
+--S 1193 of 1311
+r0:=(-1/2)/(a*x^2)+b/(a^2*x)+(b^2-a*c)*log(x)/a^3-1/2*(b^2-a*c)*_
+   log(a+b*x+c*x^2)/a^3+b*(b^2-3*a*c)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(a^3*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R                     3  2         2c x + b
+--R       (- 6a b c + 2b )x atanh(--------------)
+--R                                +-----------+
+--R                                |          2
+--R                               \|- 4a c + b
+--R     + 
+--R                     2  2       2                          2  2
+--R             (a c - b )x log(c x  + b x + a) + (- 2a c + 2b )x log(x) + 2a b x
+--R           + 
+--R                2
+--R             - a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       3 2 |          2
+--R     2a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1193
+
+--S 1194 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1194
+
+)clear all
+
+--S 1195 of 1311
+t0:=1/((c+a/x^2+b/x)*x^6)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R           6      5      4
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1195
+
+--S 1196 of 1311
+r0:=(-1/3)/(a*x^3)+1/2*b/(a^2*x^2)+(-b^2+a*c)/(a^3*x)-b*(b^2-2*a*c)*_
+   log(x)/a^4+1/2*b*(b^2-2*a*c)*log(a+b*x+c*x^2)/a^4-(b^4-4*a*b^2*c+_
+   2*a^2*c^2)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^4*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R             2 2        2      4  3         2c x + b
+--R       (- 12a c  + 24a b c - 6b )x atanh(--------------)
+--R                                          +-----------+
+--R                                          |          2
+--R                                         \|- 4a c + b
+--R     + 
+--R                         3  3       2                           3  3
+--R           (- 6a b c + 3b )x log(c x  + b x + a) + (12a b c - 6b )x log(x)
+--R         + 
+--R              2        2  2     2        3
+--R           (6a c - 6a b )x  + 3a b x - 2a
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R           +-----------+
+--R       4 3 |          2
+--R     6a x \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1196
+
+--S 1197 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1197
+
+)clear all
+
+--S 1198 of 1311
+t0:=x/(c+a/x^2+b/x)^2
+--R 
+--R
+--R                              5
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1198
+
+--S 1199 of 1311
+r0:=-b*(3*b^2-11*a*c)*x/(c^3*(b^2-4*a*c))+1/2*(3*b^2-8*a*c)*x^2/(c^2*_
+   (b^2-4*a*c))-b*x^3/(c*(b^2-4*a*c))+x^4*(2*a+b*x)/((b^2-4*a*c)*_
+   (a+b*x+c*x^2))+b*(3*b^4-20*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(c^4*(b^2-4*a*c)^(3/2))+1/2*(3*b^2-2*a*c)*_
+   log(a+b*x+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R                 2   3        3 2     5   2         2 2 2        4      6
+--R           (- 60a b c  + 40a b c  - 6b c)x  + (- 60a b c  + 40a b c - 6b )x
+--R         + 
+--R                3   2      2 3        5
+--R           - 60a b c  + 40a b c - 6a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                    2 3        2 2     4   2        2   2        3      5
+--R               (- 8a c  + 14a b c  - 3b c)x  + (- 8a b c  + 14a b c - 3b )x
+--R             + 
+--R                   3 2      2 2        4
+--R               - 8a c  + 14a b c - 3a b
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                4    2 3  4             3     3 2  3
+--R           (4a c  - b c )x  + (- 12a b c  + 3b c )x
+--R         + 
+--R              2 3        2 2     4   2         2   2       3
+--R           (8a c  - 25a b c  + 6b c)x  + (- 22a b c  + 6a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                +-----------+
+--R           6     2 5  2          5     3 4       2 5       2 4  |          2
+--R     ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1199
+
+--S 1200 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1200
+
+)clear all
+
+--S 1201 of 1311
+t0:=1/(c+a/x^2+b/x)^2
+--R 
+--R
+--R                              4
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1201
+
+--S 1202 of 1311
+r0:=2*(b^2-3*a*c)*x/(c^2*(b^2-4*a*c))-(b^2-2*a*c+a*b/x)*x/(c*(b^2-4*a*c)*_
+   (c+a/x^2+b/x))+2*(b^4-6*a*b^2*c+6*a^2*c^2)*atanh((b+2*a/x)/_
+   sqrt(b^2-4*a*c))/(c^3*(b^2-4*a*c)^(3/2))-b*log(c+a/x^2+b/x)/c^3-_
+   2*b*log(x)/c^3
+--R 
+--R
+--R   (2)
+--R                 2 3        2 2     4   2         2   2        3      5
+--R           (- 12a c  + 12a b c  - 2b c)x  + (- 12a b c  + 12a b c - 2b )x
+--R         + 
+--R                3 2      2 2        4
+--R           - 12a c  + 12a b c - 2a b
+--R      *
+--R                   b x + 2a
+--R         atanh(---------------)
+--R                 +-----------+
+--R                 |          2
+--R               x\|- 4a c + b
+--R     + 
+--R                     2     3   2          2      4       2          3
+--R           ((- 8a b c  + 2b c)x  + (- 8a b c + 2b )x - 8a b c + 2a b )log(x)
+--R         + 
+--R                       2    3   2          2     4       2         3
+--R             ((- 4a b c  + b c)x  + (- 4a b c + b )x - 4a b c + a b )
+--R          *
+--R                    2
+--R                 c x  + b x + a
+--R             log(--------------)
+--R                        2
+--R                       x
+--R         + 
+--R                3    2 2  3          2     3   2      2 2       2
+--R           (4a c  - b c )x  + (7a b c  - 2b c)x  + (6a c  - 2a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                             +-----------+
+--R           5    2 4  2          4    3 3       2 4      2 3  |          2
+--R     ((4a c  - b c )x  + (4a b c  - b c )x + 4a c  - a b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1202
+
+--S 1203 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1203
+
+)clear all
+
+--S 1204 of 1311
+t0:=1/((c+a/x^2+b/x)^2*x)
+--R 
+--R
+--R                              3
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1204
+
+--S 1205 of 1311
+r0:=-b*x/(c*(b^2-4*a*c))+x^2*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))+_
+   b*(b^2-6*a*c)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^2*(b^2-_
+   4*a*c)^(3/2))+1/2*log(a+b*x+c*x^2)/c^2
+--R 
+--R
+--R   (2)
+--R                  2     3   2         2      4        2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x + 12a b c - 2a b )
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                 2    2   2              3       2       2        2
+--R           ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )log(c x  + b x + a)
+--R         + 
+--R                  2     2   2
+--R           (- 4a c  + 2b c)x  + 2a b c x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                +-----------+
+--R           4     2 3  2          3     3 2       2 3       2 2  |          2
+--R     ((8a c  - 2b c )x  + (8a b c  - 2b c )x + 8a c  - 2a b c )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1205
+
+--S 1206 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1206
+
+)clear all
+
+--S 1207 of 1311
+t0:=1/((c+a/x^2+b/x)^2*x^2)
+--R 
+--R
+--R                              2
+--R                             x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1207
+
+--S 1208 of 1311
+r0:=(b+2*a/x)/((b^2-4*a*c)*(c+a/x^2+b/x))-4*a*atanh((b+2*a/x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R              2              2           b x + 2a
+--R       (4a c x  + 4a b x + 4a )atanh(---------------)
+--R                                       +-----------+
+--R                                       |          2
+--R                                     x\|- 4a c + b
+--R     + 
+--R                       +-----------+
+--R             2         |          2
+--R       (- b x  - 2a x)\|- 4a c + b
+--R  /
+--R                                                      +-----------+
+--R           2    2   2              3       2       2  |          2
+--R     ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1208
+
+--S 1209 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1209
+
+)clear all
+
+--S 1210 of 1311
+t0:=1/((c+a/x^2+b/x)^2*x^3)
+--R 
+--R
+--R                              x
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1210
+
+--S 1211 of 1311
+r0:=(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))-2*b*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                                               +-----------+
+--R          2     2                  2c x + b                    |          2
+--R   (2b c x  + 2b x + 2a b)atanh(--------------) + (- b x - 2a)\|- 4a c + b
+--R                                 +-----------+
+--R                                 |          2
+--R                                \|- 4a c + b
+--R   -------------------------------------------------------------------------
+--R                                                          +-----------+
+--R               2    2   2              3       2       2  |          2
+--R         ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1211
+
+--S 1212 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1212
+
+)clear all
+
+--S 1213 of 1311
+t0:=1/((c+a/x^2+b/x)^2*x^4)
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1213
+
+--S 1214 of 1311
+r0:=(-b-2*c*x)/((b^2-4*a*c)*(a+b*x+c*x^2))+4*c*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--R 
+--R
+--R   (2)
+--R                                                               +-----------+
+--R        2 2                          2c x + b                  |          2
+--R   (- 4c x  - 4b c x - 4a c)atanh(--------------) + (2c x + b)\|- 4a c + b
+--R                                   +-----------+
+--R                                   |          2
+--R                                  \|- 4a c + b
+--R   -------------------------------------------------------------------------
+--R                                                          +-----------+
+--R               2    2   2              3       2       2  |          2
+--R         ((4a c  - b c)x  + (4a b c - b )x + 4a c - a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1214
+
+--S 1215 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1215
+
+)clear all
+
+--S 1216 of 1311
+t0:=1/((c+a/x^2+b/x)^2*x^5)
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R         2 5         4            2  3         2    2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1216
+
+--S 1217 of 1311
+r0:=(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*(a+b*x+c*x^2))+b*(b^2-6*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^(3/2))+_
+   log(x)/a^2-1/2*log(a+b*x+c*x^2)/a^2
+--R 
+--R
+--R   (2)
+--R                  2     3   2         2      4        2          3
+--R         ((12a b c  - 2b c)x  + (12a b c - 2b )x + 12a b c - 2a b )
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    2   2                3       2       2
+--R             ((- 4a c  + b c)x  + (- 4a b c + b )x - 4a c + a b )
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                 2     2   2               3       2        2
+--R           ((8a c  - 2b c)x  + (8a b c - 2b )x + 8a c - 2a b )log(x) - 2a b c x
+--R         + 
+--R             2        2
+--R           4a c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                             +-----------+
+--R         3 2     2 2   2      3        2 3       4      3 2  |          2
+--R     ((8a c  - 2a b c)x  + (8a b c - 2a b )x + 8a c - 2a b )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1217
+
+--S 1218 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1218
+
+)clear all
+
+--S 1219 of 1311
+t0:=1/((c+a/x^2+b/x)^2*x^6)
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R         2 6         5            2  4         3    2 2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1219
+
+--S 1220 of 1311
+r0:=-2*(b^2-3*a*c)/(a^2*(b^2-4*a*c)*x)+(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*_
+   x*(a+b*x+c*x^2))-2*(b^4-6*a*b^2*c+6*a^2*c^2)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(3/2))-2*b*log(x)/a^3+_
+   b*log(a+b*x+c*x^2)/a^3
+--R 
+--R
+--R   (2)
+--R               2 3        2 2     4   3       2   2        3      5  2
+--R           (12a c  - 12a b c  + 2b c)x  + (12a b c  - 12a b c + 2b )x
+--R         + 
+--R               3 2      2 2        4
+--R           (12a c  - 12a b c + 2a b )x
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2    3   3        2     4  2      2         3
+--R             ((4a b c  - b c)x  + (4a b c - b )x  + (4a b c - a b )x)
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                       2     3   3          2      4  2        2          3
+--R             ((- 8a b c  + 2b c)x  + (- 8a b c + 2b )x  + (- 8a b c + 2a b )x)
+--R          *
+--R             log(x)
+--R         + 
+--R                2 2       2   2        2          3       3     2 2
+--R           (- 6a c  + 2a b c)x  + (- 7a b c + 2a b )x - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                              +-----------+
+--R         4 2    3 2   3      4       3 3  2      5     4 2    |          2
+--R     ((4a c  - a b c)x  + (4a b c - a b )x  + (4a c - a b )x)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1220
+
+--S 1221 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1221
+
+)clear all
+
+--S 1222 of 1311
+t0:=1/((c+a/x^2+b/x)^2*x^7)
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R         2 7         6            2  5         4    2 3
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1222
+
+--S 1223 of 1311
+r0:=1/2*(-3*b^2+8*a*c)/(a^2*(b^2-4*a*c)*x^2)+b*(3*b^2-11*a*c)/_
+   (a^3*(b^2-4*a*c)*x)+(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^2*_
+   (a+b*x+c*x^2))+b*(3*b^4-20*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(3/2))+(3*b^2-2*a*c)*_
+   log(x)/a^4-1/2*(3*b^2-2*a*c)*log(a+b*x+c*x^2)/a^4
+--R 
+--R
+--R   (2)
+--R                 2   3        3 2     5   4         2 2 2        4      6  3
+--R           (- 60a b c  + 40a b c  - 6b c)x  + (- 60a b c  + 40a b c - 6b )x
+--R         + 
+--R                 3   2      2 3        5  2
+--R           (- 60a b c  + 40a b c - 6a b )x
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                  2 3        2 2     4   4      2   2        3      5  3
+--R               (8a c  - 14a b c  + 3b c)x  + (8a b c  - 14a b c + 3b )x
+--R             + 
+--R                  3 2      2 2        4  2
+--R               (8a c  - 14a b c + 3a b )x
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                     2 3        2 2     4   4         2   2        3      5  3
+--R               (- 16a c  + 28a b c  - 6b c)x  + (- 16a b c  + 28a b c - 6b )x
+--R             + 
+--R                     3 2      2 2        4  2
+--R               (- 16a c  + 28a b c - 6a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R               2   2       3   3        3 2      2 2        4  2
+--R           (22a b c  - 6a b c)x  + (- 8a c  + 25a b c - 6a b )x
+--R         + 
+--R               3        2 3       4     3 2
+--R           (12a b c - 3a b )x - 4a c + a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R                                                                  +-----------+
+--R         5 2     4 2   4      5        4 3  3      6      5 2  2  |          2
+--R     ((8a c  - 2a b c)x  + (8a b c - 2a b )x  + (8a c - 2a b )x )\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1223
+
+--S 1224 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1224
+
+)clear all
+
+--S 1225 of 1311
+t0:=1/(c+a/x^2+b/x)^3
+--R 
+--R
+--R   (1)
+--R      6
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1225
+
+--S 1226 of 1311
+r0:=3*(b^4-7*a*b^2*c+10*a^2*c^2)*x/(c^3*(b^2-4*a*c)^2)-_
+   1/2*(b^2-2*a*c+a*b/x)*x/(c*(b^2-4*a*c)*(c+a/x^2+b/x)^2)-_
+   1/2*(3*b^4-20*a*b^2*c+20*a^2*c^2+3*a*b*(b^2-6*a*c)/x)*x/_
+   (c^2*(b^2-4*a*c)^2*(c+a/x^2+b/x))+3*(b^6-10*a*b^4*c+30*a^2*_
+   b^2*c^2-20*a^3*c^3)*atanh((b+2*a/x)/sqrt(b^2-4*a*c))/(c^4*_
+   (b^2-4*a*c)^(5/2))-3/2*b*log(c+a/x^2+b/x)/c^4-3*b*log(x)/c^4
+--R 
+--R
+--R   (2)
+--R                  3 5       2 2 4        4 3     6 2  4
+--R           (- 120a c  + 180a b c  - 60a b c  + 6b c )x
+--R         + 
+--R                  3   4       2 3 3         5 2      7   3
+--R           (- 240a b c  + 360a b c  - 120a b c  + 12b c)x
+--R         + 
+--R                  4 4       3 2 3      2 4 2        6      8  2
+--R           (- 240a c  + 240a b c  + 60a b c  - 48a b c + 6b )x
+--R         + 
+--R                  4   3       3 3 2       2 5         7         5 3       4 2 2
+--R           (- 240a b c  + 360a b c  - 120a b c + 12a b )x - 120a c  + 180a b c
+--R         + 
+--R                3 4      2 6
+--R           - 60a b c + 6a b
+--R      *
+--R                   b x + 2a
+--R         atanh(---------------)
+--R                 +-----------+
+--R                 |          2
+--R               x\|- 4a c + b
+--R     + 
+--R                     2   4        3 3     5 2  4
+--R               (- 96a b c  + 48a b c  - 6b c )x
+--R             + 
+--R                      2 2 3        4 2      6   3
+--R               (- 192a b c  + 96a b c  - 12b c)x
+--R             + 
+--R                      3   3        5      7  2
+--R               (- 192a b c  + 36a b c - 6b )x
+--R             + 
+--R                      3 2 2      2 4         6        4   2      3 3      2 5
+--R               (- 192a b c  + 96a b c - 12a b )x - 96a b c  + 48a b c - 6a b
+--R          *
+--R             log(x)
+--R         + 
+--R                     2   4        3 3     5 2  4
+--R               (- 48a b c  + 24a b c  - 3b c )x
+--R             + 
+--R                     2 2 3        4 2     6   3         3   3        5      7  2
+--R               (- 96a b c  + 48a b c  - 6b c)x  + (- 96a b c  + 18a b c - 3b )x
+--R             + 
+--R                     3 2 2      2 4        6        4   2      3 3      2 5
+--R               (- 96a b c  + 48a b c - 6a b )x - 48a b c  + 24a b c - 3a b
+--R          *
+--R                    2
+--R                 c x  + b x + a
+--R             log(--------------)
+--R                        2
+--R                       x
+--R         + 
+--R               2 5        2 4     4 3  5        2   4        3 3     5 2  4
+--R           (32a c  - 16a b c  + 2b c )x  + (122a b c  - 68a b c  + 9b c )x
+--R         + 
+--R                3 4      2 2 3        4 2     6   3
+--R           (100a c  + 14a b c  - 36a b c  + 6b c)x
+--R         + 
+--R                3   3      2 3 2        5   2       4 3      3 2 2     2 4
+--R           (138a b c  - 87a b c  + 12a b c)x  + (60a c  - 42a b c  + 6a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 8        2 7     4 6  4       2   7        3 6     5 5  3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R       + 
+--R             3 7        4 5     6 4  2       3   6      2 3 5       5 4
+--R         (64a c  - 12a b c  + 2b c )x  + (64a b c  - 32a b c  + 4a b c )x
+--R       + 
+--R            4 6      3 2 5     2 4 4
+--R         32a c  - 16a b c  + 2a b c
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1226
+
+--S 1227 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1227
+
+)clear all
+
+--S 1228 of 1311
+t0:=1/((c+a/x^2+b/x)^3*x)
+--R 
+--R
+--R   (1)
+--R      5
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1228
+
+--S 1229 of 1311
+r0:=-b*(b^2-7*a*c)*x/(c^2*(b^2-4*a*c)^2)+1/2*(b^2-16*a*c)*x^2/_
+   (c*(b^2-4*a*c)^2)+1/2*x^4*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2)^2)+_
+   1/2*x^3*(6*a*b-(b^2-16*a*c)*x)/((b^2-4*a*c)^2*(a+b*x+c*x^2))+_
+   b*(b^4-10*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (c^3*(b^2-4*a*c)^(5/2))+1/2*log(a+b*x+c*x^2)/c^3
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  4        2 2 3        4 2     6   3
+--R           (60a b c  - 20a b c  + 2b c )x  + (120a b c  - 40a b c  + 4b c)x
+--R         + 
+--R                3   3      2 3 2        5      7  2
+--R           (120a b c  + 20a b c  - 16a b c + 2b )x
+--R         + 
+--R                3 2 2      2 4        6        4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )x + 60a b c  - 20a b c + 2a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2 4       2 3    4 2  4       2   3        3 2     5   3
+--R               (16a c  - 8a b c  + b c )x  + (32a b c  - 16a b c  + 2b c)x
+--R             + 
+--R                   3 3       4     6  2       3   2      2 3        5        4 2
+--R               (32a c  - 6a b c + b )x  + (32a b c  - 16a b c + 2a b )x + 16a c
+--R             + 
+--R                   3 2     2 4
+--R               - 8a b c + a b
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                 2 4        2 3     4 2  4      2   3        3 2     5   3
+--R           (- 24a c  + 21a b c  - 3b c )x  + (2a b c  + 12a b c  - 2b c)x
+--R         + 
+--R                 3 3      2 2 2       4   2       3   2     2 3
+--R           (- 16a c  + 29a b c  - 4a b c)x  + (14a b c  - 2a b c)x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 7        2 6     4 5  4       2   6        3 5     5 4  3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c )x
+--R       + 
+--R             3 6        4 4     6 3  2       3   5      2 3 4       5 3
+--R         (64a c  - 12a b c  + 2b c )x  + (64a b c  - 32a b c  + 4a b c )x
+--R       + 
+--R            4 5      3 2 4     2 4 3
+--R         32a c  - 16a b c  + 2a b c
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1229
+
+--S 1230 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1230
+
+)clear all
+
+--S 1231 of 1311
+t0:=1/((c+a/x^2+b/x)^3*x^2)
+--R 
+--R
+--R   (1)
+--R      4
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1231
+
+--S 1232 of 1311
+r0:=1/2*(b+2*a/x)/((b^2-4*a*c)*(c+a/x^2+b/x)^2)-_
+   3*a*(b+2*a/x)/((b^2-4*a*c)^2*(c+a/x^2+b/x))+_
+   12*a^2*atanh((b+2*a/x)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R             2 2 4      2     3       3       2 2  2      3         4
+--R         (24a c x  + 48a b c x  + (48a c + 24a b )x  + 48a b x + 24a )
+--R      *
+--R                   b x + 2a
+--R         atanh(---------------)
+--R                 +-----------+
+--R                 |          2
+--R               x\|- 4a c + b
+--R     + 
+--R                                                                   +-----------+
+--R                    3  4         2        2  3      2   2      3   |          2
+--R     ((- 10a b c + b )x  + (- 20a c - 4a b )x  - 18a b x  - 12a x)\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1232
+
+--S 1233 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1233
+
+)clear all
+
+--S 1234 of 1311
+t0:=1/((c+a/x^2+b/x)^3*x^3)
+--R 
+--R
+--R   (1)
+--R      3
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1234
+
+--S 1235 of 1311
+r0:=-1/2*x^3*(b+2*c*x)/((b^2-4*a*c)*(a+b*x+c*x^2)^2)+3/2*b*x*(2*a+b*x)/_
+   ((b^2-4*a*c)^2*(a+b*x+c*x^2))+6*a*b*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                 2 4        2   3       2           3  2      2 2       3
+--R         (12a b c x  + 24a b c x  + (24a b c + 12a b )x  + 24a b x + 12a b)
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                                +-----------+
+--R             2    2   4                3  3       2 2     2     |          2
+--R       ((8a c  + b c)x  + (10a b c + 2b )x  + 9a b x  + 6a b x)\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1235
+
+--S 1236 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1236
+
+)clear all
+
+--S 1237 of 1311
+t0:=1/((c+a/x^2+b/x)^3*x^4)
+--R 
+--R
+--R   (1)
+--R      2
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1237
+
+--S 1238 of 1311
+r0:=1/2*x^3*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*(a+b*x+c*x^2)^2)-_
+   1/2*(b^2+2*a*c)*x*(2*a+b*x)/(a*(b^2-4*a*c)^2*(a+b*x+c*x^2))-_
+   2*(b^2+2*a*c)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R                  3     2 2  4             2     3   3
+--R           (- 8a c  - 4b c )x  + (- 16a b c  - 8b c)x
+--R         + 
+--R                 2 2        2      4  2         2          3       3      2 2
+--R           (- 16a c  - 16a b c - 4b )x  + (- 16a b c - 8a b )x - 8a c - 4a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2 4        2      2   3                 3  2
+--R             - 6b c x  + (4a c  - 10b c)x  + (- 6a b c - 3b )x
+--R           + 
+--R                  2        2
+--R             (- 4a c - 2a b )x
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1238
+
+--S 1239 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1239
+
+)clear all
+
+--S 1240 of 1311
+t0:=1/((c+a/x^2+b/x)^3*x^5)
+--R 
+--R
+--R   (1)
+--R     x
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1240
+
+--S 1241 of 1311
+r0:=1/2*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2)^2)-3/2*b*(b+2*c*x)/_
+   ((b^2-4*a*c)^2*(a+b*x+c*x^2))+6*b*c*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R               3 4      2 2 3           2      3   2        2         2
+--R         (12b c x  + 24b c x  + (24a b c  + 12b c)x  + 24a b c x + 12a b c)
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                                +-----------+
+--R              2 3     2   2                  3       2       2  |          2
+--R       (- 6b c x  - 9b c x  + (- 10a b c - 2b )x - 8a c - a b )\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1241
+
+--S 1242 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1242
+
+)clear all
+
+--S 1243 of 1311
+t0:=1/((c+a/x^2+b/x)^3*x^6)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1243
+
+--S 1244 of 1311
+r0:=1/2*(-b-2*c*x)/((b^2-4*a*c)*(a+b*x+c*x^2)^2)+3*c*(b+2*c*x)/_
+   ((b^2-4*a*c)^2*(a+b*x+c*x^2))-12*c^2*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(5/2)
+--R 
+--R
+--R   (2)
+--R               4 4        3 3           3      2 2  2          2       2 2
+--R         (- 24c x  - 48b c x  + (- 48a c  - 24b c )x  - 48a b c x - 24a c )
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                                                             +-----------+
+--R           3 3        2 2         2     2                 3  |          2
+--R       (12c x  + 18b c x  + (20a c  + 4b c)x + 10a b c - b )\|- 4a c + b
+--R  /
+--R             2 4        2 3     4 2  4       2   3        3 2     5   3
+--R         (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R       + 
+--R             3 3        4      6  2       3   2      2 3        5        4 2
+--R         (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              3 2      2 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1244
+
+--S 1245 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1245
+
+)clear all
+
+--S 1246 of 1311
+t0:=1/((c+a/x^2+b/x)^3*x^7)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 7       2 6        2     2   5              3  4      2        2  3
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   2    3
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1246
+
+--S 1247 of 1311
+r0:=1/2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*(a+b*x+c*x^2)^2)+_
+   1/2*(2*b^4-15*a*b^2*c+16*a^2*c^2+2*b*c*(b^2-7*a*c)*x)/_
+   (a^2*(b^2-4*a*c)^2*(a+b*x+c*x^2))+b*(b^4-10*a*b^2*c+30*a^2*c^2)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(5/2))+_
+   log(x)/a^3-1/2*log(a+b*x+c*x^2)/a^3
+--R 
+--R
+--R   (2)
+--R               2   4        3 3     5 2  4        2 2 3        4 2     6   3
+--R           (60a b c  - 20a b c  + 2b c )x  + (120a b c  - 40a b c  + 4b c)x
+--R         + 
+--R                3   3      2 3 2        5      7  2
+--R           (120a b c  + 20a b c  - 16a b c + 2b )x
+--R         + 
+--R                3 2 2      2 4        6        4   2      3 3      2 5
+--R           (120a b c  - 40a b c + 4a b )x + 60a b c  - 20a b c + 2a b
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                     2 4       2 3    4 2  4         2   3        3 2     5   3
+--R               (- 16a c  + 8a b c  - b c )x  + (- 32a b c  + 16a b c  - 2b c)x
+--R             + 
+--R                     3 3       4     6  2         3   2      2 3        5
+--R               (- 32a c  + 6a b c - b )x  + (- 32a b c  + 16a b c - 2a b )x
+--R             + 
+--R                    4 2     3 2     2 4
+--R               - 16a c  + 8a b c - a b
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                   2 4        2 3     4 2  4       2   3        3 2     5   3
+--R               (32a c  - 16a b c  + 2b c )x  + (64a b c  - 32a b c  + 4b c)x
+--R             + 
+--R                   3 3        4      6  2       3   2      2 3        5
+--R               (64a c  - 12a b c + 2b )x  + (64a b c  - 32a b c + 4a b )x
+--R             + 
+--R                  4 2      3 2      2 4
+--R               32a c  - 16a b c + 2a b
+--R          *
+--R             log(x)
+--R         + 
+--R                 2   3       3 2  3       3 3      2 2 2       4   2
+--R           (- 14a b c  + 2a b c )x  + (16a c  - 29a b c  + 4a b c)x
+--R         + 
+--R                3   2      2 3        5        4 2      3 2      2 4
+--R           (- 2a b c  - 12a b c + 2a b )x + 24a c  - 21a b c + 3a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             5 4      4 2 3     3 4 2  4       5   3      4 3 2     3 5   3
+--R         (32a c  - 16a b c  + 2a b c )x  + (64a b c  - 32a b c  + 4a b c)x
+--R       + 
+--R             6 3      4 4      3 6  2       6   2      5 3      4 5        7 2
+--R         (64a c  - 12a b c + 2a b )x  + (64a b c  - 32a b c + 4a b )x + 32a c
+--R       + 
+--R              6 2      5 4
+--R         - 16a b c + 2a b
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1247
+
+--S 1248 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1248
+
+)clear all
+
+--S 1249 of 1311
+t0:=1/((c+a/x^2+b/x)^3*x^8)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 8       2 7        2     2   6              3  5      2        2  4
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2   3    3 2
+--R       3a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1249
+
+--S 1250 of 1311
+r0:=-3*(b^4-7*a*b^2*c+10*a^2*c^2)/(a^3*(b^2-4*a*c)^2*x)+_
+   1/2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x*(a+b*x+c*x^2)^2)+_
+   1/2*(3*b^4-20*a*b^2*c+20*a^2*c^2+3*b*c*(b^2-6*a*c)*x)/(a^2*_
+   (b^2-4*a*c)^2*x*(a+b*x+c*x^2))-3*(b^6-10*a*b^4*c+30*a^2*b^2*c^2-_
+   20*a^3*c^3)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(5/2))-_
+   3*b*log(x)/a^4+3/2*b*log(a+b*x+c*x^2)/a^4
+--R 
+--R
+--R   (2)
+--R                3 5       2 2 4        4 3     6 2  5
+--R           (120a c  - 180a b c  + 60a b c  - 6b c )x
+--R         + 
+--R                3   4       2 3 3         5 2      7   4
+--R           (240a b c  - 360a b c  + 120a b c  - 12b c)x
+--R         + 
+--R                4 4       3 2 3      2 4 2        6      8  3
+--R           (240a c  - 240a b c  - 60a b c  + 48a b c - 6b )x
+--R         + 
+--R                4   3       3 3 2       2 5         7  2
+--R           (240a b c  - 360a b c  + 120a b c - 12a b )x
+--R         + 
+--R                5 3       4 2 2      3 4      2 6
+--R           (120a c  - 180a b c  + 60a b c - 6a b )x
+--R      *
+--R                  2c x + b
+--R         atanh(--------------)
+--R                +-----------+
+--R                |          2
+--R               \|- 4a c + b
+--R     + 
+--R                   2   4        3 3     5 2  5       2 2 3        4 2     6   4
+--R               (48a b c  - 24a b c  + 3b c )x  + (96a b c  - 48a b c  + 6b c)x
+--R             + 
+--R                   3   3        5      7  3       3 2 2      2 4        6  2
+--R               (96a b c  - 18a b c + 3b )x  + (96a b c  - 48a b c + 6a b )x
+--R             + 
+--R                   4   2      3 3      2 5
+--R               (48a b c  - 24a b c + 3a b )x
+--R          *
+--R                    2
+--R             log(c x  + b x + a)
+--R         + 
+--R                     2   4        3 3     5 2  5
+--R               (- 96a b c  + 48a b c  - 6b c )x
+--R             + 
+--R                      2 2 3        4 2      6   4
+--R               (- 192a b c  + 96a b c  - 12b c)x
+--R             + 
+--R                      3   3        5      7  3
+--R               (- 192a b c  + 36a b c - 6b )x
+--R             + 
+--R                      3 2 2      2 4         6  2
+--R               (- 192a b c  + 96a b c - 12a b )x
+--R             + 
+--R                     4   2      3 3      2 5
+--R               (- 96a b c  + 48a b c - 6a b )x
+--R          *
+--R             log(x)
+--R         + 
+--R                 3 4      2 2 3       4 2  4
+--R           (- 60a c  + 42a b c  - 6a b c )x
+--R         + 
+--R                  3   3      2 3 2        5   3
+--R           (- 138a b c  + 87a b c  - 12a b c)x
+--R         + 
+--R                  4 3      3 2 2      2 4        6  2
+--R           (- 100a c  - 14a b c  + 36a b c - 6a b )x
+--R         + 
+--R                  4   2      3 3      2 5        5 2      4 2      3 4
+--R           (- 122a b c  + 68a b c - 9a b )x - 32a c  + 16a b c - 2a b
+--R      *
+--R          +-----------+
+--R          |          2
+--R         \|- 4a c + b
+--R  /
+--R             6 4      5 2 3     4 4 2  5       6   3      5 3 2     4 5   4
+--R         (32a c  - 16a b c  + 2a b c )x  + (64a b c  - 32a b c  + 4a b c)x
+--R       + 
+--R             7 3      5 4      4 6  3       7   2      6 3      5 5  2
+--R         (64a c  - 12a b c + 2a b )x  + (64a b c  - 32a b c + 4a b )x
+--R       + 
+--R             8 2      7 2      6 4
+--R         (32a c  - 16a b c + 2a b )x
+--R    *
+--R        +-----------+
+--R        |          2
+--R       \|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1250
+
+--S 1251 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1251
+
+)clear all
+
+--S 1252 of 1311
+t0:=x^2/(15+2/x^2+13/x)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1252
+
+--S 1253 of 1311
+r0:=139/3375*x-13/450*x^2+1/45*x^3-16/567*log(2+3*x)+1/4375*log(1+5*x)
+--R 
+--R
+--R                                                  3         2
+--R        162log(5x + 1) - 20000log(3x + 2) + 15750x  - 20475x  + 29190x
+--R   (2)  --------------------------------------------------------------
+--R                                    708750
+--R                                                    Type: Expression(Integer)
+--E 1253
+
+--S 1254 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1254
+
+)clear all
+
+--S 1255 of 1311
+t0:=x/(15+2/x^2+13/x)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1255
+
+--S 1256 of 1311
+r0:=-13/225*x+1/30*x^2+8/189*log(2+3*x)-1/875*log(1+5*x)
+--R 
+--R
+--R                                                 2
+--R        - 54log(5x + 1) + 2000log(3x + 2) + 1575x  - 2730x
+--R   (2)  --------------------------------------------------
+--R                               47250
+--R                                                    Type: Expression(Integer)
+--E 1256
+
+--S 1257 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1257
+
+)clear all
+
+--S 1258 of 1311
+t0:=1/(15+2/x^2+13/x)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1258
+
+--S 1259 of 1311
+r0:=1/15*x-4/63*log(2+3*x)+1/175*log(1+5*x)
+--R 
+--R
+--R        9log(5x + 1) - 100log(3x + 2) + 105x
+--R   (2)  ------------------------------------
+--R                        1575
+--R                                                    Type: Expression(Integer)
+--E 1259
+
+--S 1260 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1260
+
+)clear all
+
+--S 1261 of 1311
+t0:=1/((15+2/x^2+13/x)*x)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1261
+
+--S 1262 of 1311
+r0:=2/21*log(2+3*x)-1/35*log(1+5*x)
+--R 
+--R
+--R        - 3log(5x + 1) + 10log(3x + 2)
+--R   (2)  ------------------------------
+--R                      105
+--R                                                    Type: Expression(Integer)
+--E 1262
+
+--S 1263 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1263
+
+)clear all
+
+--S 1264 of 1311
+t0:=1/((15+2/x^2+13/x)*x^2)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1264
+
+--S 1265 of 1311
+r0:=1/7*log(5+1/x)-1/7*log(3+2/x)
+--R 
+--R
+--R            5x + 1        3x + 2
+--R        log(------) - log(------)
+--R               x             x
+--R   (2)  -------------------------
+--R                    7
+--R                                                    Type: Expression(Integer)
+--E 1265
+
+--S 1266 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1266
+
+)clear all
+
+--S 1267 of 1311
+t0:=1/((15+2/x^2+13/x)*x^3)
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           3      2
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1267
+
+--S 1268 of 1311
+r0:=1/2*log(x)+3/14*log(2+3*x)-5/7*log(1+5*x)
+--R 
+--R
+--R        - 10log(5x + 1) + 3log(3x + 2) + 7log(x)
+--R   (2)  ----------------------------------------
+--R                           14
+--R                                                    Type: Expression(Integer)
+--E 1268
+
+--S 1269 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1269
+
+)clear all
+
+--S 1270 of 1311
+t0:=1/((15+2/x^2+13/x)*x^4)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           4      3     2
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1270
+
+--S 1271 of 1311
+r0:=(-1/2)/x-13/4*log(x)-9/28*log(2+3*x)+25/7*log(1+5*x)
+--R 
+--R
+--R        100x log(5x + 1) - 9x log(3x + 2) - 91x log(x) - 14
+--R   (2)  ---------------------------------------------------
+--R                                28x
+--R                                                    Type: Expression(Integer)
+--E 1271
+
+--S 1272 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1272
+
+)clear all
+
+--S 1273 of 1311
+t0:=1/((15+2/x^2+13/x)*x^5)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           5      4     3
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1273
+
+--S 1274 of 1311
+r0:=(-1/4)/x^2+13/4/x+139/8*log(x)+27/56*log(2+3*x)-125/7*log(1+5*x)
+--R 
+--R
+--R               2                 2                  2
+--R        - 1000x log(5x + 1) + 27x log(3x + 2) + 973x log(x) + 182x - 14
+--R   (2)  ---------------------------------------------------------------
+--R                                         2
+--R                                      56x
+--R                                                    Type: Expression(Integer)
+--E 1274
+
+--S 1275 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1275
+
+)clear all
+
+--S 1276 of 1311
+t0:=1/((15+2/x^2+13/x)*x^6)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           6      5     4
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1276
+
+--S 1277 of 1311
+r0:=(-1/6)/x^3+13/8/x^2+(-139/8)/x-1417/16*log(x)-81/112*log(2+3*x)+_
+   625/7*log(1+5*x)
+--R 
+--R
+--R   (2)
+--R         3                  3                    3              2
+--R   30000x log(5x + 1) - 243x log(3x + 2) - 29757x log(x) - 5838x  + 546x - 56
+--R   --------------------------------------------------------------------------
+--R                                          3
+--R                                      336x
+--R                                                    Type: Expression(Integer)
+--E 1277
+
+--S 1278 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1278
+
+)clear all
+
+--S 1279 of 1311
+t0:=x^m/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R                m
+--R               x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1279
+
+--S 1280 of 1311
+--r0:=2*c*x^(1+m)*hypergeometric(1,(1+m)/n,(1+m+n)/n,_
+--   -2*c*x^n/(b-sqrt(b^2-4*a*c)))/((1+m)*(b-sqrt(b^2-4*a*c))*_
+--   sqrt(b^2-4*a*c))-2*c*x^(1+m)*hypergeometric(1,(1+m)/n,(1+m+n)/n,_
+--   -2*c*x^n/(b+sqrt(b^2-4*a*c)))/((1+m)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))
+--E 1280
+
+--S 1281 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 1281
+
+)clear all
+
+--S 1282 of 1311
+t0:=x^2/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1282
+
+--S 1283 of 1311
+--r0:=-2/3*c*x^3*hypergeometric(1,3/n,(3+n)/n,-2*c*x^n/(b-sqrt(b^2-_
+--   4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-4*a*c))-2/3*c*x^3*_
+--   hypergeometric(1,3/n,(3+n)/n,-2*c*x^n/(b+sqrt(b^2-4*a*c)))/_
+--   (b^2-4*a*c+b*sqrt(b^2-4*a*c))
+--E 1283
+
+--S 1284 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 1284
+
+)clear all
+
+--S 1285 of 1311
+t0:=x/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R                x
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1285
+
+--S 1286 of 1311
+--r0:=-c*x^2*hypergeometric(1,2/n,(2+n)/n,-2*c*x^n/(b-sqrt(b^2-4*a*c)))/_
+--   (b^2-4*a*c-b*sqrt(b^2-4*a*c))-c*x^2*hypergeometric(1,2/n,(2+n)/n,_
+--   -2*c*x^n/(b+sqrt(b^2-4*a*c)))/(b^2-4*a*c+b*sqrt(b^2-4*a*c))
+--E 1286
+
+--S 1287 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 1287
+
+)clear all
+
+--S 1288 of 1311
+t0:=1/(a+b*x^n+c*x^(2*n))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           2n      n
+--R        c x   + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 1288
+
+--S 1289 of 1311
+--r0:=x*AppellF1(1/n,1,1,1+1/n,-2*c*x^n/(b+sqrt(b^2-4*a*c)),_
+--   -2*c*x^n/(b-sqrt(b^2-4*a*c)))*(1+2*c*x^n/(b-sqrt(b^2-4*a*c)))*_
+--   (1+2*c*x^n/(b+sqrt(b^2-4*a*c)))/(a+b*x^n+c*x^(2*n))
+--E 1289
+
+--S 1290 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 1290
+
+)clear all
+
+--S 1291 of 1311
+t0:=1/(x*(a+b*x^n+c*x^(2*n)))
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R             2n        n
+--R        c x x   + b x x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1291
+
+--S 1292 of 1311
+r0:=log(x)/a-1/2*log(a+b*x^n+c*x^(2*n))/(a*n)+_
+   b*atanh((b+2*c*x^n)/sqrt(b^2-4*a*c))/(a*n*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +-----------+                                        n
+--R          |          2        2n      n                    2c x  + b
+--R       - \|- 4a c + b  log(c x   + b x  + a) + 2b atanh(--------------)
+--R                                                         +-----------+
+--R                                                         |          2
+--R                                                        \|- 4a c + b
+--R     + 
+--R                 +-----------+
+--R                 |          2
+--R       2n log(x)\|- 4a c + b
+--R  /
+--R          +-----------+
+--R          |          2
+--R     2a n\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 1292
+
+--S 1293 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1293
+
+)clear all
+
+--S 1294 of 1311
+t0:=1/(x^2*(a+b*x^n+c*x^(2*n)))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R           2 2n      2 n      2
+--R        c x x   + b x x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1294
+
+--S 1295 of 1311
+--r0:=2*c*hypergeometric(1,(-1)/n,(-1+n)/n,-2*c*x^n/(b-sqrt(b^2-4*a*c)))/_
+--   (x*(b^2-4*a*c-b*sqrt(b^2-4*a*c)))+2*c*hypergeometric(1,(-1)/n,_
+--   (-1+n)/n,-2*c*x^n/(b+sqrt(b^2-4*a*c)))/(x*(b^2-4*a*c+b*sqrt(b^2-4*a*c)))
+--E 1295
+
+--S 1296 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 1296
+
+)clear all
+
+--S 1297 of 1311
+t0:=1/(x^3*(a+b*x^n+c*x^(2*n)))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R           3 2n      3 n      3
+--R        c x x   + b x x  + a x
+--R                                                    Type: Expression(Integer)
+--E 1297
+
+--S 1298 of 1311
+--r0:=c*hypergeometric(1,(-2)/n,(-2+n)/n,-2*c*x^n/(b-sqrt(b^2-4*a*c)))/_
+--   (x^2*(b^2-4*a*c-b*sqrt(b^2-4*a*c)))+c*hypergeometric(1,(-2)/n,_
+--   (-2+n)/n,-2*c*x^n/(b+sqrt(b^2-4*a*c)))/(x^2*(b^2-4*a*c+b*sqrt(b^2-4*a*c)))
+--E 1298
+
+--S 1299 of 1311
+--d0:=normalize(t0-D(r0,x))
+--E 1299
+
+)clear all
+
+--S 1300 of 1311
+t0:=(c^(1/3)-2*d^(1/3)*x^(1/3))/(c*d^(1/3)*x^(2/3)-c^(2/3)*d^(2/3)*x+c^(1/3)*d*x^(4/3))
+--R 
+--R
+--R                      3+-+3+-+   3+-+
+--R                   - 2\|d \|x  + \|c
+--R   (1)  ---------------------------------------
+--R         3+-+3+-+2      3+-+3+-+     3+-+2 3+-+2
+--R        c\|d \|x   + d x\|c \|x  - x \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 1300
+
+--S 1301 of 1311
+r0:=-3*log(c^(2/3)-c^(1/3)*d^(1/3)*x^(1/3)+d^(2/3)*x^(2/3))/(c^(1/3)*d^(2/3))
+--R 
+--R
+--R               3+-+2 3+-+2  3+-+3+-+3+-+   3+-+2
+--R          3log(\|d   \|x  - \|c \|d \|x  + \|c  )
+--R   (2)  - ---------------------------------------
+--R                         3+-+3+-+2
+--R                         \|c \|d
+--R                                                    Type: Expression(Integer)
+--E 1301
+
+--S 1302 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1302
+
+)clear all
+
+--S 1303 of 1311
+t0:=(1/4*b^2/c+c*x+b*sqrt(x))^2
+--R 
+--R
+--R              3      3   +-+      4 2      2 2     4
+--R        (32b c x + 8b c)\|x  + 16c x  + 24b c x + b
+--R   (1)  --------------------------------------------
+--R                               2
+--R                            16c
+--R                                                    Type: Expression(Integer)
+--E 1303
+
+--S 1304 of 1311
+r0:=-1/160*b*(b+2*c*sqrt(x))^5/c^4+1/192*(b+2*c*sqrt(x))^6/c^4
+--R 
+--R
+--R               5 2       3 3   +-+       6 3       2 4 2      4 2     6
+--R        (768b c x  + 320b c x)\|x  + 320c x  + 720b c x  + 60b c x - b
+--R   (2)  ---------------------------------------------------------------
+--R                                         4
+--R                                     960c
+--R                                                    Type: Expression(Integer)
+--E 1304
+
+--S 1305 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1305
+
+)clear all
+
+--S 1306 of 1311
+t0:=(2+3*x)^6*(1+(2+3*x)^7+(2+3*x)^14)
+--R 
+--R
+--R   (1)
+--R                20               19                18                 17
+--R     3486784401x   + 46490458680x   + 294439571640x   + 1177758286560x
+--R   + 
+--R                   16                 15                  14                  13
+--R     3336981811920x   + 7118894532096x   + 11864824220160x   + 15819767221203x
+--R   + 
+--R                    12                  11                  10                 9
+--R     17138093246586x   + 15233903651304x   + 11171623917168x   + 6770824454160x
+--R   + 
+--R                   8                 7                6                5
+--R     3385569848544x  + 1389081063168x  + 463107083481x  + 123532587108x
+--R   + 
+--R                 4              3             2
+--R     25748932860x  + 4042307808x  + 449706096x  + 31617600x + 1056832
+--R                                                    Type: Polynomial(Integer)
+--E 1306
+
+--S 1307 of 1311
+r0:=1/21*(2+3*x)^7+1/42*(2+3*x)^14+1/63*(2+3*x)^21
+--R 
+--R
+--R   (2)
+--R     1162261467  21              20               19               18
+--R     ---------- x   + 2324522934x   + 15496819560x   + 65431015920x
+--R          7
+--R   + 
+--R                  17                16                15   15819767221203  14
+--R     196293047760x   + 444930908256x   + 790988281344x   + -------------- x
+--R                                                                 14
+--R   + 
+--R                   13                 12                 11                10
+--R     1318314865122x   + 1269491970942x   + 1015602174288x   + 677082445416x
+--R   + 
+--R                  9                8               7               6
+--R     376174427616x  + 173635132896x  + 66158154783x  + 20588764518x
+--R   + 
+--R              5              4             3            2              2122112
+--R   5149786572x  + 1010576952x  + 149902032x  + 15808800x  + 1056832x + -------
+--R                                                                          63
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1307
+
+--S 1308 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1308
+
+)clear all
+
+--S 1309 of 1311
+t0:=(2+3*x)^6*(1+(2+3*x)^7+(2+3*x)^14)^2
+--R 
+--R
+--R   (1)
+--R                       34                      33                       32
+--R     16677181699666569x   + 378016118525775564x   + 4158177303783531204x
+--R   + 
+--R                          31                         30
+--R     29569260826905110784x   + 152774514272343072384x
+--R   + 
+--R                           29                          28
+--R     611098057089372289536x   + 1969093739510199599616x
+--R   + 
+--R                            27                           26
+--R     5250916653945060568950x   + 11814562711582707057228x
+--R   + 
+--R                             25                           24
+--R     22753974480193166244840x   + 37923300052713558858960x
+--R   + 
+--R                             23                           22
+--R     55161197358098322404160x   + 70483846759795477607040x
+--R   + 
+--R                             21                           20
+--R     79520450781314886393600x   + 79520847116576754110643x
+--R   + 
+--R                             19                           18
+--R     70685813958589477281960x   + 55960416183860517516840x
+--R   + 
+--R                             17                           16
+--R     39502388988265540321440x   + 24872768546728823564400x
+--R   + 
+--R                             15                          14
+--R     13964412385079287976448x   + 6982756365625215229440x
+--R   + 
+--R                            13                          12
+--R     3103796605675782721446x   + 1222900430946085012212x
+--R   + 
+--R                           11                         10
+--R     425448833766864577488x   + 130036362517827878112x
+--R   + 
+--R                          9                       8                       7
+--R     34689917186099544096x  + 8009483060433484224x  + 1583178214811622912x
+--R   + 
+--R                        6                     5                    4
+--R     264090004030265049x  + 36466108367328612x  + 4057390785756924x
+--R   + 
+--R                     3                  2
+--R     349626718314720x  + 21898634455152x  + 887139656256x + 17451466816
+--R                                                    Type: Polynomial(Integer)
+--E 1309
+
+--S 1310 of 1311
+r0:=1/21*(2+3*x)^7+1/21*(2+3*x)^14+1/21*(2+3*x)^21+1/42*(2+3*x)^28+_
+   1/105*(2+3*x)^35
+--R 
+--R
+--R   (2)
+--R     16677181699666569  35                     34                      33
+--R     ----------------- x   + 11118121133111046x   + 126005372841925188x
+--R             35
+--R   + 
+--R                        32                       31   101849676181562048256  30
+--R     924039400840784712x   + 4928210137817518464x   + --------------------- x
+--R                                                                5
+--R   + 
+--R                          29   2625458326972530284475  28
+--R     67899784121041365504x   + ---------------------- x
+--R                                         14
+--R   + 
+--R                           27                         26
+--R     437576396725285446564x   + 875152864622814086340x
+--R   + 
+--R     7584660010542711771792  25                          24
+--R     ---------------------- x   + 2298383223254096766840x
+--R                5
+--R   + 
+--R                            23                          22
+--R     3064515076512846852480x   + 3614565944605222108800x
+--R   + 
+--R     26506949038858918036881  21                          20
+--R     ----------------------- x   + 3534290697929473864098x
+--R                7
+--R   + 
+--R                            19                          18
+--R     2945285062308448290360x   + 2194577166014752240080x
+--R   + 
+--R                            17                         16
+--R     1463104032160519033200x   + 872775774067455498528x
+--R   + 
+--R                           15                         14
+--R     465517091041681015296x   + 221699757548270194389x
+--R   + 
+--R                          13                        12                        11
+--R     94069263918929616324x   + 35454069480572048124x   + 11821487501620716192x
+--R   + 
+--R     17344958593049772048  10                      9                      8
+--R     -------------------- x   + 889942562270387136x  + 197897276851452864x
+--R               5
+--R   + 
+--R                       7                    6   4057390785756924  5
+--R     37727143432895007x  + 6077684727888102x  + ---------------- x
+--R                                                        5
+--R   + 
+--R                    4                 3                2
+--R     87406679578680x  + 7299544818384x  + 443569828128x  + 17451466816x
+--R   + 
+--R     35041395328
+--R     -----------
+--R         105
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 1310
+
+--S 1311 of 1311
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 1311
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder17.input.pamphlet b/src/input/richder17.input.pamphlet
new file mode 100644
index 0000000..df2c8bd
--- /dev/null
+++ b/src/input/richder17.input.pamphlet
@@ -0,0 +1,2269 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder17.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (d+e x^n)^q (a+b x^n+c x^(2n))^p|
+
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder17.output
+)spool richder17.output
+)set message test on
+)set message auto off
+)clear all
+ 
+--S 1 of 381
+t0:=x^4*(d+e*x^3)/(a+b*x^3+c*x^6)
+--E 1
+
+--S 2 of 381
+r0:=1/2*e*x^2/c-1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*_
+   (c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3))+1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*_
+   c^(1/3)*x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*_
+   (c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3))-atan((-4*c^(1/3)*x+2^(2/3)*(b-_
+   sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*_
+   (c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3))-1/3*log(2^(1/3)*c^(1/3)*x+_
+   (b+sqrt(b^2-4*a*c))^(1/3))*(c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/_
+   sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*(b+sqrt(b^2-4*a*c))^(1/3))+_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-_
+   4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*(c*d-b*e+(b*c*d-b^2*e+_
+   2*a*c*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))-atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*_
+   (c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(5/3)*_
+   sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3))
+--E 2
+
+--S 3 of 381
+d0:=t0-normalize(D(r0,x))
+--E 3
+
+)clear all
+
+--S 4 of 381
+t0:=x^3*(d+e*x^3)/(a+b*x^3+c*x^6)
+--E 4
+
+--S 5 of 381
+r0:=e*x/c+1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(c*d-b*e+_
+   (-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b-_
+   sqrt(b^2-4*a*c))^(2/3))-1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*_
+   x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(c*d-b*e+_
+   (-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*_
+   (b-sqrt(b^2-4*a*c))^(2/3))-atan((-4*c^(1/3)*x+2^(2/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b-sqrt(b^2-_
+   4*a*c))^(1/3)))*(c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*c^(4/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(2/3))+1/3*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/_
+   sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b+sqrt(b^2-4*a*c))^(2/3))-_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-_
+   4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*(c*d-b*e+(b*c*d-b^2*e+_
+   2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*(b+sqrt(b^2-_
+   4*a*c))^(2/3))-atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*_
+   (c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(4/3)*_
+   sqrt(3)*(b+sqrt(b^2-4*a*c))^(2/3))
+--E 5
+
+--S 6 of 381
+d0:=t0-normalize(D(r0,x))
+--E 6
+
+)clear all
+
+--S 7 of 381
+t0:=x^2*(d+e*x^3)/(a+b*x^3+c*x^6)
+--E 7
+
+--S 8 of 381
+r0:=1/6*e*log(a+b*x^3+c*x^6)/c-1/3*(2*c*d-b*e)*atanh((b+2*c*x^3)/_
+   sqrt(b^2-4*a*c))/(c*sqrt(b^2-4*a*c))
+--E 8
+
+--S 9 of 381
+d0:=t0-normalize(D(r0,x))
+--E 9
+
+)clear all
+
+--S 10 of 381
+t0:=x*(d+e*x^3)/(a+b*x^3+c*x^6)
+--E 10
+
+--S 11 of 381
+r0:=-1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(e+(2*c*d-b*e)/_
+   sqrt(b^2-4*a*c))/(2^(2/3)*c^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))+_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-_
+   4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(e+(2*c*d-b*e)/sqrt(b^2-_
+   4*a*c))/(2^(2/3)*c^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))-atan((-4*_
+   c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3)))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/(2^(2/3)*_
+   c^(2/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3))-1/3*log(2^(1/3)*c^(1/3)*_
+   x+(b+sqrt(b^2-4*a*c))^(1/3))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(2/3)*_
+   c^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))+1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*_
+   c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(2/3)*c^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))-atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/_
+   (2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(e+(-2*c*d+b*e)/_
+   sqrt(b^2-4*a*c))/(2^(2/3)*c^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3))
+--E 11
+
+--S 12 of 381
+d0:=t0-normalize(D(r0,x))
+--E 12
+
+)clear all
+
+--S 13 of 381
+t0:=(d+e*x^3)/(a+b*x^3+c*x^6)
+--E 13
+
+--S 14 of 381
+r0:=1/3*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*(e+(2*c*d-b*e)/_
+   sqrt(b^2-4*a*c))/(2^(1/3)*c^(1/3)*(b-sqrt(b^2-4*a*c))^(2/3))-_
+   1/6*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-_
+   4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(e+(2*c*d-b*e)/sqrt(b^2-_
+   4*a*c))/(2^(1/3)*c^(1/3)*(b-sqrt(b^2-4*a*c))^(2/3))-_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*c^(1/3)*sqrt(3)*(b-sqrt(b^2-4*a*c))^(2/3))+1/3*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*c^(1/3)*(b+sqrt(b^2-4*a*c))^(2/3))-1/6*log(2^(2/3)*c^(2/3)*_
+   x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-_
+   4*a*c))^(2/3))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(1/3)*_
+   (b+sqrt(b^2-4*a*c))^(2/3))-atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(1/3)*c^(1/3)*sqrt(3)*_
+   (b+sqrt(b^2-4*a*c))^(2/3))
+--E 14
+
+--S 15 of 381
+d0:=t0-normalize(D(r0,x))
+--E 15
+
+)clear all
+
+--S 16 of 381
+t0:=(d+e*x^3)/(x*(a+b*x^3+c*x^6))
+--E 16
+
+--S 17 of 381
+r0:=d*log(x)/a-1/6*d*log(a+b*x^3+c*x^6)/a+1/3*(b*d-2*a*e)*_
+   atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--E 17
+
+--S 18 of 381
+d0:=t0-normalize(D(r0,x))
+--E 18
+
+--S 19 of 381
+m0b:=a0.2-r0
+--E 19
+
+--S 20 of 381
+d0b:=D(m0b,x)
+--E 20
+
+)clear all
+
+--S 21 of 381
+t0:=(d+e*x^3)/(x^2*(a+b*x^3+c*x^6))
+--E 21
+
+--S 22 of 381
+r0:=-d/(a*x)+1/3*c^(1/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-4*a*c))^(1/3))*_
+   (d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b-sqrt(b^2-4*a*c))^(1/3))-_
+   1/6*c^(1/3)*log(2^(2/3)*c^(2/3)*x^2-2^(1/3)*c^(1/3)*x*(b-_
+   sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-4*a*c))^(2/3))*(d+(b*d-2*a*e)/_
+   sqrt(b^2-4*a*c))/(2^(2/3)*a*(b-sqrt(b^2-4*a*c))^(1/3))+c^(1/3)*_
+   atan((-4*c^(1/3)*x+2^(2/3)*(b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3)))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/_
+   (2^(2/3)*a*sqrt(3)*(b-sqrt(b^2-4*a*c))^(1/3))+1/3*c^(1/3)*log(2^(1/3)*_
+   c^(1/3)*x+(b+sqrt(b^2-4*a*c))^(1/3))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/_
+   (2^(2/3)*a*(b+sqrt(b^2-4*a*c))^(1/3))-1/6*c^(1/3)*log(2^(2/3)*c^(2/3)*_
+   x^2-2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-_
+   4*a*c))^(2/3))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(2/3)*a*(b+_
+   sqrt(b^2-4*a*c))^(1/3))+c^(1/3)*atan((-4*c^(1/3)*x+2^(2/3)*_
+   (b+sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b+sqrt(b^2-_
+   4*a*c))^(1/3)))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(2/3)*a*_
+   sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3))
+--E 22
+
+--S 23 of 381
+d0:=t0-normalize(D(r0,x))
+--E 23
+
+)clear all
+
+--S 24 of 381
+t0:=(d+e*x^3)/(x^3*(a+b*x^3+c*x^6))
+--E 24
+
+--S 25 of 381
+r0:=-1/2*d/(a*x^2)-1/3*c^(2/3)*log(2^(1/3)*c^(1/3)*x+(b-sqrt(b^2-_
+   4*a*c))^(1/3))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(1/3)*a*_
+   (b-sqrt(b^2-4*a*c))^(2/3))+1/6*c^(2/3)*log(2^(2/3)*c^(2/3)*x^2-_
+   2^(1/3)*c^(1/3)*x*(b-sqrt(b^2-4*a*c))^(1/3)+(b-sqrt(b^2-_
+   4*a*c))^(2/3))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b-_
+   sqrt(b^2-4*a*c))^(2/3))+c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*_
+   (b-sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*sqrt(3)*(b-sqrt(b^2-_
+   4*a*c))^(1/3)))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(1/3)*a*sqrt(3)*_
+   (b-sqrt(b^2-4*a*c))^(2/3))-1/3*c^(2/3)*log(2^(1/3)*c^(1/3)*x+_
+   (b+sqrt(b^2-4*a*c))^(1/3))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(1/3)*_
+   a*(b+sqrt(b^2-4*a*c))^(2/3))+1/6*c^(2/3)*log(2^(2/3)*c^(2/3)*x^2-_
+   2^(1/3)*c^(1/3)*x*(b+sqrt(b^2-4*a*c))^(1/3)+(b+sqrt(b^2-4*a*c))^(2/3))*_
+   (d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(1/3)*a*(b+sqrt(b^2-4*a*c))^(2/3))+_
+   c^(2/3)*atan((-4*c^(1/3)*x+2^(2/3)*(b+sqrt(b^2-4*a*c))^(1/3))/(2^(2/3)*_
+   sqrt(3)*(b+sqrt(b^2-4*a*c))^(1/3)))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/3)*a*sqrt(3)*(b+sqrt(b^2-4*a*c))^(2/3))
+--E 25
+
+--S 26 of 381
+d0:=t0-normalize(D(r0,x))
+--E 26
+
+)clear all
+
+--S 27 of 381
+t0:=(d+e*x^3)/(x^4*(a+b*x^3+c*x^6))
+--E 27
+
+--S 28 of 381
+r0:=-1/3*d/(a*x^3)-(b*d-a*e)*log(x)/a^2+1/6*(b*d-a*e)*log(a+b*x^3+c*x^6)/a^2-_
+   1/3*(b^2*d-2*a*c*d-a*b*e)*atanh((b+2*c*x^3)/sqrt(b^2-4*a*c))/(a^2*_
+   sqrt(b^2-4*a*c))
+--E 28
+
+--S 29 of 381
+d0:=t0-normalize(D(r0,x))
+--E 29
+
+)clear all
+
+--S 30 of 381
+t0:=x^6*(1-x^3)/(1-x^3+x^6)
+--E 30
+
+--S 31 of 381
+r0:=-1/4*x^4+1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1+%i*_
+   sqrt(3))^(2/3))+1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*_
+   sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*x^2+2^(1/3)*_
+   x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3))+1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/18*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3+%i*sqrt(3))/_
+   (2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/3*atan((4*x+2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))*(%i+_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))
+--E 31
+
+--S 32 of 381
+d0:=t0-normalize(D(r0,x))
+--E 32
+
+)clear all
+
+--S 33 of 381
+t0:=x^5*(1-x^3)/(1-x^3+x^6)
+--E 33
+
+--S 34 of 381
+r0:=-1/3*x^3-2/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--E 34
+
+--S 35 of 381
+d0:=t0-normalize(D(r0,x))
+--E 35
+
+)clear all
+
+--S 36 of 381
+t0:=x^4*(1-x^3)/(1-x^3+x^6)
+--E 36
+
+--S 37 of 381
+r0:=-1/2*x^2+1/3*%i*2^(1/3)*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/_
+   (2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))/(1-%i*sqrt(3))^(1/3)-_
+   1/3*%i*2^(1/3)*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3)*sqrt(3)))/(1+%i*sqrt(3))^(1/3)+1/3*%i*2^(1/3)*_
+   log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))/((1-%i*sqrt(3))^(1/3)*sqrt(3))-_
+   1/3*%i*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*_
+   sqrt(3))^(2/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3))-1/3*%i*2^(1/3)*_
+   log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))/((1+%i*sqrt(3))^(1/3)*sqrt(3))+_
+   1/3*%i*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*_
+   sqrt(3))^(2/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*sqrt(3))
+--E 37
+
+--S 38 of 381
+d0:=t0-normalize(D(r0,x))
+--E 38
+
+)clear all
+
+--S 39 of 381
+t0:=x^3*(1-x^3)/(1-x^3+x^6)
+--E 39
+
+--S 40 of 381
+r0:=-x-1/3*%i*2^(2/3)*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3)*sqrt(3)))/(1-%i*sqrt(3))^(2/3)+1/3*%i*2^(2/3)*_
+   atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3)*_
+   sqrt(3)))/(1+%i*sqrt(3))^(2/3)+1/3*%i*2^(2/3)*log(-2^(1/3)*x+(1-%i*_
+   sqrt(3))^(1/3))/((1-%i*sqrt(3))^(2/3)*sqrt(3))-1/3*%i*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))/(2^(1/3)*_
+   (1-%i*sqrt(3))^(2/3)*sqrt(3))-1/3*%i*2^(2/3)*log(-2^(1/3)*x+(1+%i*_
+   sqrt(3))^(1/3))/((1+%i*sqrt(3))^(2/3)*sqrt(3))+1/3*%i*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3)*sqrt(3))
+--E 40
+
+--S 41 of 381
+d0:=t0-normalize(D(r0,x))
+--E 41
+
+)clear all
+
+--S 42 of 381
+t0:=x^2*(1-x^3)/(1-x^3+x^6)
+--E 42
+
+--S 43 of 381
+r0:=-1/6*log(1-x^3+x^6)-1/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--E 43
+
+--S 44 of 381
+d0:=t0-normalize(D(r0,x))
+--E 44
+
+)clear all
+
+--S 45 of 381
+t0:=x*(1-x^3)/(1-x^3+x^6)
+--E 45
+
+--S 46 of 381
+r0:=1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))-_
+   1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*_
+   sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(2/3)*(1-_
+   %i*sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3+%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*x^2+2^(1/3)*_
+   x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3+%i*sqrt(3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3))-1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/_
+   (2^(2/3)*(1+%i*sqrt(3))^(1/3)*sqrt(3)))*(%i+sqrt(3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3))
+--E 46
+
+--S 47 of 381
+d0:=t0-normalize(D(r0,x))
+--E 47
+
+)clear all
+
+--S 48 of 381
+t0:=(1-x^3)/(1-x^3+x^6)
+--E 48
+
+--S 49 of 381
+r0:=-1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-_
+   %i*sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1-%i*_
+   sqrt(3))^(2/3))-1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*(3-%i*_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))+1/18*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/_
+   (2^(1/3)*(1-%i*sqrt(3))^(2/3))-1/9*log(-2^(1/3)*x+(1+%i*_
+   sqrt(3))^(1/3))*(3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))+_
+   1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*_
+   sqrt(3))^(2/3))*(3+%i*sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))+_
+   1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i+sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))
+--E 49
+
+--S 50 of 381
+d0:=t0-normalize(D(r0,x))
+--E 50
+
+)clear all
+
+--S 51 of 381
+t0:=(1-x^3)/(x*(1-x^3+x^6))
+--E 51
+
+--S 52 of 381
+r0:=log(x)-1/6*log(1-x^3+x^6)+1/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--E 52
+
+--S 53 of 381
+d0:=t0-normalize(D(r0,x))
+--E 53
+
+)clear all
+
+--S 54 of 381
+t0:=(1-x^3)/(x^2*(1-x^3+x^6))
+--E 54
+
+--S 55 of 381
+r0:=(-1)/x+1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*_
+   (1+%i*sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))+1/18*log(2^(2/3)*x^2+_
+   2^(1/3)*x*(1+%i*sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*_
+   sqrt(3))/(2^(2/3)*(1+%i*sqrt(3))^(1/3))-1/9*log(-2^(1/3)*x+(1-%i*_
+   sqrt(3))^(1/3))*(3+%i*sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))+_
+   1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*_
+   sqrt(3))^(2/3))*(3+%i*sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))-_
+   1/3*atan((4*x+2^(2/3)*(1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i+sqrt(3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3))
+--E 55
+
+--S 56 of 381
+d0:=t0-normalize(D(r0,x))
+--E 56
+
+)clear all
+
+--S 57 of 381
+t0:=(1-x^3)/(x^3*(1-x^3+x^6))
+--E 57
+
+--S 58 of 381
+r0:=(-1/2)/x^2-1/3*atan((4*x+2^(2/3)*(1+%i*sqrt(3))^(1/3))/(2^(2/3)*(1+%i*_
+   sqrt(3))^(1/3)*sqrt(3)))*(%i-sqrt(3))/(2^(1/3)*(1+%i*sqrt(3))^(2/3))-_
+   1/9*log(-2^(1/3)*x+(1+%i*sqrt(3))^(1/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3))+1/18*log(2^(2/3)*x^2+2^(1/3)*x*(1+%i*_
+   sqrt(3))^(1/3)+(1+%i*sqrt(3))^(2/3))*(3-%i*sqrt(3))/(2^(1/3)*_
+   (1+%i*sqrt(3))^(2/3))-1/9*log(-2^(1/3)*x+(1-%i*sqrt(3))^(1/3))*_
+   (3+%i*sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))+1/18*log(2^(2/3)*_
+   x^2+2^(1/3)*x*(1-%i*sqrt(3))^(1/3)+(1-%i*sqrt(3))^(2/3))*(3+%i*_
+   sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))+1/3*atan((4*x+2^(2/3)*_
+   (1-%i*sqrt(3))^(1/3))/(2^(2/3)*(1-%i*sqrt(3))^(1/3)*sqrt(3)))*_
+   (%i+sqrt(3))/(2^(1/3)*(1-%i*sqrt(3))^(2/3))
+--E 58
+
+--S 59 of 381
+d0:=t0-normalize(D(r0,x))
+--E 59
+
+)clear all
+
+--S 60 of 381
+t0:=(1-x^3)/(x^4*(1-x^3+x^6))
+--E 60
+
+--S 61 of 381
+r0:=(-1/3)/x^3+2/3*atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--E 61
+
+--S 62 of 381
+d0:=t0-normalize(D(r0,x))
+--E 62
+
+)clear all
+
+--S 63 of 381
+t0:=x^2*(-2+x^3)/(1-x^3+x^6)
+--E 63
+
+--S 64 of 381
+r0:=1/6*log(1-x^3+x^6)+atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--E 64
+
+--S 65 of 381
+d0:=t0-normalize(D(r0,x))
+--E 65
+
+)clear all
+
+--S 66 of 381
+t0:=(1+x^3)/(x*(1-x^3+x^6))
+--E 66
+
+--S 67 of 381
+r0:=log(x)-1/6*log(1-x^3+x^6)-atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--E 67
+
+--S 68 of 381
+d0:=t0-normalize(D(r0,x))
+--E 68
+
+)clear all
+
+--S 69 of 381
+t0:=(d+e*x^3)^5*(a+b*x^3+c*x^6)
+--E 69
+
+--S 70 of 381
+r0:=a*d^5*x+1/4*d^4*(b*d+5*a*e)*x^4+1/7*d^3*(c*d^2+5*e*(b*d+2*a*e))*x^7+_
+   1/2*d^2*e*(c*d^2+2*e*(b*d+a*e))*x^10+5/13*d*e^2*(2*c*d^2+e*_
+   (2*b*d+a*e))*x^13+1/16*e^3*(10*c*d^2+e*(5*b*d+a*e))*x^16+_
+   1/19*e^4*(5*c*d+b*e)*x^19+1/22*c*e^5*x^22
+--E 70
+
+--S 71 of 381
+d0:=t0-normalize(D(r0,x))
+--E 71
+
+)clear all
+
+--S 72 of 381
+t0:=(d+e*x^3)^4*(a+b*x^3+c*x^6)
+--E 72
+
+--S 73 of 381
+r0:=a*d^4*x+1/4*d^3*(b*d+4*a*e)*x^4+1/7*d^2*(c*d^2+4*b*d*e+6*a*e^2)*x^7+_
+   1/5*d*e*(2*c*d^2+e*(3*b*d+2*a*e))*x^10+1/13*e^2*(6*c*d^2+_
+   e*(4*b*d+a*e))*x^13+1/16*e^3*(4*c*d+b*e)*x^16+1/19*c*e^4*x^19
+--E 73
+
+--S 74 of 381
+d0:=t0-normalize(D(r0,x))
+--E 74
+
+)clear all
+
+--S 75 of 381
+t0:=(d+e*x^3)^3*(a+b*x^3+c*x^6)
+--E 75
+
+--S 76 of 381
+r0:=a*d^3*x+1/4*d^2*(b*d+3*a*e)*x^4+1/7*d*(c*d^2+3*e*(b*d+a*e))*x^7+_
+   1/10*e*(3*c*d^2+e*(3*b*d+a*e))*x^10+1/13*e^2*(3*c*d+b*e)*x^13+_
+   1/16*c*e^3*x^16
+--E 76
+
+--S 77 of 381
+d0:=t0-normalize(D(r0,x))
+--E 77
+
+)clear all
+
+--S 78 of 381
+t0:=(d+e*x^3)^2*(a+b*x^3+c*x^6)
+--E 78
+
+--S 79 of 381
+r0:=a*d^2*x+1/4*d*(b*d+2*a*e)*x^4+1/7*(c*d^2+e*(2*b*d+a*e))*x^7+_
+   1/10*e*(2*c*d+b*e)*x^10+1/13*c*e^2*x^13
+--E 79
+
+--S 80 of 381
+d0:=t0-normalize(D(r0,x))
+--E 80
+
+)clear all
+
+--S 81 of 381
+t0:=(d+e*x^3)*(a+b*x^3+c*x^6)
+--E 81
+
+--S 82 of 381
+r0:=a*d*x+1/4*(b*d+a*e)*x^4+1/7*(c*d+b*e)*x^7+1/10*c*e*x^10
+--E 82
+
+--S 83 of 381
+d0:=t0-normalize(D(r0,x))
+--E 83
+
+)clear all
+
+--S 84 of 381
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)
+--E 84
+
+--S 85 of 381
+r0:=-(c*d-b*e)*x/e^2+1/4*c*x^4/e+1/3*(c*d^2-b*d*e+a*e^2)*log(d^(1/3)+_
+   e^(1/3)*x)/(d^(2/3)*e^(7/3))-1/6*(c*d^2-b*d*e+a*e^2)*log(d^(2/3)-_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(2/3)*e^(7/3))-(c*d^2-b*d*e+a*e^2)*_
+   atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(7/3)*sqrt(3))
+--E 85
+
+--S 86 of 381
+d0:=t0-normalize(D(r0,x))
+--E 86
+
+)clear all
+
+--S 87 of 381
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^2
+--E 87
+
+--S 88 of 381
+r0:=c*x/e^2+1/3*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3))-1/9*(4*c*d^2-_
+   e*(b*d+2*a*e))*log(d^(1/3)+e^(1/3)*x)/(d^(5/3)*e^(7/3))+1/18*(4*c*d^2-_
+   e*(b*d+2*a*e))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(5/3)*_
+   e^(7/3))+1/3*(4*c*d^2-e*(b*d+2*a*e))*atan((d^(1/3)-2*e^(1/3)*x)/_
+   (d^(1/3)*sqrt(3)))/(d^(5/3)*e^(7/3)*sqrt(3))
+--E 88
+
+--S 89 of 381
+d0:=t0-normalize(D(r0,x))
+--E 89
+
+)clear all
+
+--S 90 of 381
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^3
+--E 90
+
+--S 91 of 381
+r0:=1/6*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3)^2)-1/18*(7*c*d^2-_
+   e*(b*d+5*a*e))*x/(d^2*e^2*(d+e*x^3))+1/27*(2*c*d^2+e*(b*d+5*a*e))*_
+   log(d^(1/3)+e^(1/3)*x)/(d^(8/3)*e^(7/3))-1/54*(2*c*d^2+e*(b*d+5*a*e))*_
+   log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(8/3)*e^(7/3))-_
+   1/9*(2*c*d^2+e*(b*d+5*a*e))*atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*_
+   sqrt(3)))/(d^(8/3)*e^(7/3)*sqrt(3))
+--E 91
+
+--S 92 of 381
+d0:=t0-normalize(D(r0,x))
+--E 92
+
+)clear all
+
+--S 93 of 381
+t0:=(d+e*x^3)^(3/2)*(a+b*x^3+c*x^6)
+--E 93
+
+--S 94 of 381
+--r0:=2/4301*(16*c*d^2-46*b*d*e+391*a*e^2)*x*(d+e*x^3)^(3/2)/e^2-_
+--  2/15*(c*d^2-b*d*e+a*e^2)*x*(d+e*x^3)^(5/2)/(d*e^2)+2/5865*(16*c*d^2-_
+--  46*b*d*e+391*a*e^2)*x*(d+e*x^3)^(5/2)/(d*e^2)+2/23*c*x*_
+--  (d+e*x^3)^(7/2)/e^2+18/21505*d*(16*c*d^2-46*b*d*e+391*a*e^2)*x*_
+--  sqrt(d+e*x^3)/e^2+27/21505*d^(13/6)*(16*c*d^2-23*e*(2*b*d-17*a*e))*_
+--  elliptic_f(asin(e^(1/6)*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3)))/(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)*sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*_
+--  sqrt((2*e^(2/3)*x+d^(1/3)*(-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*_
+--  (-3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*_
+--  (e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))/(e^(5/2)*sqrt(d+e*x^3))
+--E 94
+
+--S 95 of 381
+--d0:=t0-normalize(D(r0,x))
+--E 95
+
+)clear all
+
+--S 96 of 381
+t0:=(d+e*x^3)^(1/2)*(a+b*x^3+c*x^6)
+--E 96
+
+--S 97 of 381
+--r0:=-2/9*(c*d^2-b*d*e+a*e^2)*x*(d+e*x^3)^(3/2)/(d*e^2)+2/1683*_
+--  (16*c*d^2-34*b*d*e+187*a*e^2)*x*(d+e*x^3)^(3/2)/(d*e^2)+2/17*c*x*_
+--  (d+e*x^3)^(5/2)/e^2+2/935*(16*c*d^2-34*b*d*e+187*a*e^2)*x*_
+--  sqrt(d+e*x^3)/e^2+3/935*d^(7/6)*(16*c*d^2-17*e*(2*b*d-11*a*e))*_
+--  elliptic_f(asin(e^(1/6)*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3)))/(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)*sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*_
+--  sqrt((2*e^(2/3)*x+d^(1/3)*(-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*_
+--  (-3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*_
+--  (e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))/(e^(5/2)*sqrt(d+e*x^3))
+--E 97
+
+--S 98 of 381
+--d0:=t0-normalize(D(r0,x))
+--E 98
+
+)clear all
+
+--S 99 of 381
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(1/2)
+--E 99
+
+--S 100 of 381
+--r0:=2/11*c*x*(d+e*x^3)^(3/2)/e^2-2/3*(c*d^2-b*d*e+a*e^2)*x*_
+--  sqrt(d+e*x^3)/(d*e^2)+2/165*(16*c*d^2-22*b*d*e+55*a*e^2)*x*_
+--  sqrt(d+e*x^3)/(d*e^2)+1/55*d^(1/6)*(16*c*d^2-11*e*(2*b*d-5*a*e))*_
+--  elliptic_f(asin(e^(1/6)*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3)))/(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)*sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*_
+--  sqrt((2*e^(2/3)*x+d^(1/3)*(-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*_
+--  (-3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*_
+--  (e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))/(e^(5/2)*sqrt(d+e*x^3))
+--E 100
+
+--S 101 of 381
+--d0:=t0-normalize(D(r0,x))
+--E 101
+
+)clear all
+
+--S 102 of 381
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(3/2)
+--E 102
+
+--S 103 of 381
+--r0:=2/3*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*sqrt(d+e*x^3))+2/5*c*x*_
+--  sqrt(d+e*x^3)/e^2-1/15*(16*c*d^2-5*e*(2*b*d+a*e))*_
+--  elliptic_f(asin(e^(1/6)*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3)))/(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)*sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*_
+--  sqrt((2*e^(2/3)*x+d^(1/3)*(-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*_
+--  (-3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*_
+--  (e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))/(d^(5/6)*e^(5/2)*sqrt(d+e*x^3))
+--E 103
+
+--S 104 of 381
+--d0:=t0-normalize(D(r0,x))
+--E 104
+
+)clear all
+
+--S 105 of 381
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(5/2)
+--E 105
+
+--S 106 of 381
+--r0:=2/9*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3)^(3/2))-_
+--  2/27*(11*c*d^2-2*b*d*e-7*a*e^2)*x/(d^2*e^2*sqrt(d+e*x^3))+_
+--  1/27*(16*c*d^2+e*(2*b*d+7*a*e))*elliptic_f(asin(e^(1/6)*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*sqrt(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))/(3*e^(1/3)+_
+--  sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*sqrt((2*e^(2/3)*x+d^(1/3)*_
+--  (-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(-3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*(e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))/_
+--  (d^(11/6)*e^(5/2)*sqrt(d+e*x^3))
+--E 106
+
+--S 107 of 381
+--d0:=t0-normalize(D(r0,x))
+--E 107
+
+)clear all
+
+--S 108 of 381
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(7/2)
+--E 108
+
+--S 109 of 381
+--r0:=2/15*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3)^(5/2))-_
+--  2/135*(17*c*d^2-2*b*d*e-13*a*e^2)*x/(d^2*e^2*(d+e*x^3)^(3/2))+_
+--  2/405*(16*c*d^2+14*b*d*e+91*a*e^2)*x/(d^3*e^2*sqrt(d+e*x^3))+_
+--  1/405*(16*c*d^2+7*e*(2*b*d+13*a*e))*elliptic_f(asin(e^(1/6)*sqrt(2)*_
+--  sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*sqrt(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))/(3*e^(1/3)+_
+--  sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*sqrt((2*e^(2/3)*x+d^(1/3)*_
+--  (-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(-3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*(e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))/_
+--  (d^(17/6)*e^(5/2)*sqrt(d+e*x^3))
+--E 109
+
+--S 110 of 381
+--d0:=t0-normalize(D(r0,x))
+--E 110
+
+)clear all
+
+--S 111 of 381
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(9/2)
+--E 111
+
+--S 112 of 381
+--r0:=2/21*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3)^(7/2))-_
+--  2/315*(23*c*d^2-2*b*d*e-19*a*e^2)*x/(d^2*e^2*(d+e*x^3)^(5/2))+_
+--  2/2835*(16*c*d^2+26*b*d*e+247*a*e^2)*x/(d^3*e^2*(d+e*x^3)^(3/2))+_
+--  2/1215*(16*c*d^2+26*b*d*e+247*a*e^2)*x/(d^4*e^2*sqrt(d+e*x^3))+_
+--  1/1215*(16*c*d^2+13*e*(2*b*d+19*a*e))*elliptic_f(asin(e^(1/6)*_
+--  sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*sqrt(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))/(3*e^(1/3)+_
+--  sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*sqrt((2*e^(2/3)*x+d^(1/3)*_
+--  (-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(-3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*(e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))/_
+--  (d^(23/6)*e^(5/2)*sqrt(d+e*x^3))
+--E 112
+
+--S 113 of 381
+--d0:=t0-normalize(D(r0,x))
+--E 113
+
+)clear all
+
+--S 114 of 381
+t0:=(a+b*x^3+c*x^6)/(d+e*x^3)^(11/2)
+--E 114
+
+--S 115 of 381
+--r0:=2/27*(c*d^2-b*d*e+a*e^2)*x/(d*e^2*(d+e*x^3)^(9/2))-_
+--  2/567*(29*c*d^2-2*b*d*e-25*a*e^2)*x/(d^2*e^2*(d+e*x^3)^(7/2))+_
+--  2/8505*(16*c*d^2+38*b*d*e+475*a*e^2)*x/(d^3*e^2*(d+e*x^3)^(5/2))+_
+--  26/76545*(16*c*d^2+38*b*d*e+475*a*e^2)*x/(d^4*e^2*(d+e*x^3)^(3/2))+_
+--  26/32805*(16*c*d^2+38*b*d*e+475*a*e^2)*x/(d^5*e^2*sqrt(d+e*x^3))+_
+--  13/32805*(16*c*d^2+19*e*(2*b*d+25*a*e))*elliptic_f(asin(e^(1/6)*_
+--  sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)/(d^(1/6)*sqrt(3*e^(1/3)-sqrt(3)*_
+--  sqrt(-e^(2/3))))),(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))/(3*e^(1/3)+_
+--  sqrt(3)*sqrt(-e^(2/3))))*sqrt(2)*sqrt(d^(1/3)+e^(1/3)*x)*_
+--  sqrt(3*e^(1/3)-sqrt(3)*sqrt(-e^(2/3)))*sqrt((2*e^(2/3)*x+d^(1/3)*_
+--  (-e^(1/3)+sqrt(3)*sqrt(-e^(2/3))))/(d^(1/3)*(-3*e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3)))))*sqrt((-2*e^(2/3)*x+d^(1/3)*(e^(1/3)+sqrt(3)*_
+--  sqrt(-e^(2/3))))/(d^(1/3)*(3*e^(1/3)+sqrt(3)*sqrt(-e^(2/3)))))/_
+--  (d^(29/6)*e^(5/2)*sqrt(d+e*x^3))
+--E 115
+
+--S 116 of 381
+--d0:=t0-normalize(D(r0,x))
+--E 116
+
+)clear all
+
+--S 117 of 381
+t0:=x^4*(d+e*x^4)/(a+b*x^4+c*x^8)
+--E 117
+
+--S 118 of 381
+r0:=e*x/c-1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(c*d-b*e+(b*c*d-b^2*e+2*a*c*e)/sqrt(b^2-_
+   4*a*c))/(2^(1/4)*c^(5/4)*(-b-sqrt(b^2-4*a*c))^(3/4))-_
+   1/2*atan(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(c*d-b*e+_
+   (-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(5/4)*(-b+_
+   sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*c^(1/4)*x/(-b+sqrt(b^2-_
+   4*a*c))^(1/4))*(c*d-b*e+(-b*c*d+b^2*e-2*a*c*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(5/4)*(-b+sqrt(b^2-4*a*c))^(3/4))
+--E 118
+
+--S 119 of 381
+d0:=t0-normalize(D(r0,x))
+--E 119
+
+)clear all
+
+--S 120 of 381
+t0:=x^3*(d+e*x^4)/(a+b*x^4+c*x^8)
+--E 120
+
+--S 121 of 381
+r0:=1/8*e*log(a+b*x^4+c*x^8)/c-1/4*(2*c*d-b*e)*atanh((b+2*c*x^4)/_
+   sqrt(b^2-4*a*c))/(c*sqrt(b^2-4*a*c))
+--E 121
+
+--S 122 of 381
+d0:=t0-normalize(D(r0,x))
+--E 122
+
+)clear all
+
+--S 123 of 381
+t0:=x^2*(d+e*x^4)/(a+b*x^4+c*x^8)
+--E 123
+
+--S 124 of 381
+r0:=1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(3/4)*c^(3/4)*(-b-_
+   sqrt(b^2-4*a*c))^(1/4))-1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(3/4)*_
+   c^(3/4)*(-b-sqrt(b^2-4*a*c))^(1/4))+1/2*atan(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*c^(3/4)*(-b+sqrt(b^2-4*a*c))^(1/4))-1/2*atanh(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-_
+   4*a*c))/(2^(3/4)*c^(3/4)*(-b+sqrt(b^2-4*a*c))^(1/4))
+--E 124
+
+--S 125 of 381
+d0:=t0-normalize(D(r0,x))
+--E 125
+
+)clear all
+
+--S 126 of 381
+t0:=x*(d+e*x^4)/(a+b*x^4+c*x^8)
+--E 126
+
+--S 127 of 381
+r0:=1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(e+(2*c*d-b*e)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--E 127
+
+--S 128 of 381
+d0:=t0-normalize(D(r0,x))
+--E 128
+
+)clear all
+
+--S 129 of 381
+t0:=(d+e*x^4)/(a+b*x^4+c*x^8)
+--E 129
+
+--S 130 of 381
+r0:=-1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   c^(1/4)*(-b-sqrt(b^2-4*a*c))^(3/4))-1/2*atan(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(1/4)*(-b+sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-_
+   4*a*c))/(2^(1/4)*c^(1/4)*(-b+sqrt(b^2-4*a*c))^(3/4))
+--E 130
+
+--S 131 of 381
+d0:=t0-normalize(D(r0,x))
+--E 131
+
+)clear all
+
+--S 132 of 381
+t0:=(d+e*x^4)/(x*(a+b*x^4+c*x^8))
+--E 132
+
+--S 133 of 381
+r0:=d*log(x)/a-1/8*d*log(a+b*x^4+c*x^8)/a+1/4*(b*d-2*a*e)*_
+   atanh((b+2*c*x^4)/sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--E 133
+
+--S 134 of 381
+d0:=t0-normalize(D(r0,x))
+--E 134
+
+)clear all
+
+--S 135 of 381
+t0:=(d+e*x^4)/(x^2*(a+b*x^4+c*x^8))
+--E 135
+
+--S 136 of 381
+r0:=-d/(a*x)-1/2*c^(1/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b-sqrt(b^2-_
+   4*a*c))^(1/4))+1/2*c^(1/4)*atanh(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(3/4)*a*_
+   (-b-sqrt(b^2-4*a*c))^(1/4))-1/2*c^(1/4)*atan(2^(1/4)*c^(1/4)*_
+   x/(-b+sqrt(b^2-4*a*c))^(1/4))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/_
+   (2^(3/4)*a*(-b+sqrt(b^2-4*a*c))^(1/4))+1/2*c^(1/4)*atanh(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(d+(b*d-2*a*e)/_
+   sqrt(b^2-4*a*c))/(2^(3/4)*a*(-b+sqrt(b^2-4*a*c))^(1/4))
+--E 136
+
+--S 137 of 381
+d0:=t0-normalize(D(r0,x))
+--E 137
+
+)clear all
+
+--S 138 of 381
+t0:=(d+e*x^4)/(x^3*(a+b*x^4+c*x^8))
+--E 138
+
+--S 139 of 381
+r0:=-1/2*d/(a*x^2)-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-1/2*atan(x^2*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*sqrt(c)*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(a*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--E 139
+
+--S 140 of 381
+d0:=t0-normalize(D(r0,x))
+--E 140
+
+)clear all
+
+--S 141 of 381
+t0:=(d+e*x^4)/(x^4*(a+b*x^4+c*x^8))
+--E 141
+
+--S 142 of 381
+r0:=-1/3*d/(a*x^3)+1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-_
+   4*a*c))^(1/4))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(1/4)*a*(-b-_
+   sqrt(b^2-4*a*c))^(3/4))+1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*x/(-b-_
+   sqrt(b^2-4*a*c))^(1/4))*(d+(-b*d+2*a*e)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(-b-sqrt(b^2-4*a*c))^(3/4))+1/2*c^(3/4)*atan(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(3/4))+1/2*c^(3/4)*atanh(2^(1/4)*c^(1/4)*x/_
+   (-b+sqrt(b^2-4*a*c))^(1/4))*(d+(b*d-2*a*e)/sqrt(b^2-4*a*c))/(2^(1/4)*_
+   a*(-b+sqrt(b^2-4*a*c))^(3/4))
+--E 142
+
+--S 143 of 381
+d0:=t0-normalize(D(r0,x))
+--E 143
+
+)clear all
+
+--S 144 of 381
+t0:=x^4*(1-x^4)/(1-x^4+x^8)
+--E 144
+
+--S 145 of 381
+r0:=-x-1/2*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)-_
+   1/2*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)+_
+   1/2*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/4*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(6)+1/4*log(1+x^2+_
+   x*sqrt(2-sqrt(3)))/sqrt(6)-1/4*log(1+x^2-x*sqrt(2+sqrt(3)))/_
+   sqrt(6)+1/4*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(6)
+--E 145
+
+--S 146 of 381
+d0:=t0-normalize(D(r0,x))
+--E 146
+
+)clear all
+
+--S 147 of 381
+t0:=x^3*(1-x^4)/(1-x^4+x^8)
+--E 147
+
+--S 148 of 381
+r0:=-1/8*log(1-x^4+x^8)-1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--E 148
+
+--S 149 of 381
+d0:=t0-normalize(D(r0,x))
+--E 149
+
+)clear all
+
+--S 150 of 381
+t0:=x^2*(1-x^4)/(1-x^4+x^8)
+--E 150
+
+--S 151 of 381
+r0:=-1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))+_
+   1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))+_
+   1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))-_
+   1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))+_
+   1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))-_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))-_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+_
+   1/8*log(1+x^2+x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))
+--E 151
+
+--S 152 of 381
+d0:=t0-normalize(D(r0,x))
+--E 152
+
+)clear all
+
+--S 153 of 381
+t0:=x*(1-x^4)/(1-x^4+x^8)
+--E 153
+
+--S 154 of 381
+r0:=-1/4*log(1+x^4-x^2*sqrt(3))/sqrt(3)+1/4*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--E 154
+
+--S 155 of 381
+d0:=t0-normalize(D(r0,x))
+--E 155
+
+)clear all
+
+--S 156 of 381
+t0:=(1-x^4)/(1-x^4+x^8)
+--E 156
+
+--S 157 of 381
+r0:=1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))-_
+   1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))+_
+   1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))-_
+   1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*sqrt(1/3*(2-sqrt(3)))-_
+   1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))-_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))+_
+   1/8*log(1+x^2+x*sqrt(2+sqrt(3)))*sqrt(1/3*(2+sqrt(3)))
+--E 157
+
+--S 158 of 381
+d0:=t0-normalize(D(r0,x))
+--E 158
+
+)clear all
+
+--S 159 of 381
+t0:=(1-x^4)/(x*(1-x^4+x^8))
+--E 159
+
+--S 160 of 381
+r0:=log(x)-1/8*log(1-x^4+x^8)+1/4*atan((1-2*x^4)/sqrt(3))/sqrt(3)
+--E 160
+
+--S 161 of 381
+d0:=t0-normalize(D(r0,x))
+--E 161
+
+)clear all
+
+--S 162 of 381
+t0:=(1-x^4)/(x^2*(1-x^4+x^8))
+--E 162
+
+--S 163 of 381
+r0:=(-1)/x+1/2*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)-_
+   1/2*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(6)+_
+   1/2*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/2*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/sqrt(6)-_
+   1/4*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(6)+1/4*log(1+x^2+_
+   x*sqrt(2-sqrt(3)))/sqrt(6)-1/4*log(1+x^2-x*sqrt(2+sqrt(3)))/_
+   sqrt(6)+1/4*log(1+x^2+x*sqrt(2+sqrt(3)))/sqrt(6)
+--E 163
+
+--S 164 of 381
+d0:=t0-normalize(D(r0,x))
+--E 164
+
+)clear all
+
+--S 165 of 381
+t0:=(1-x^4)/(x^3*(1-x^4+x^8))
+--E 165
+
+--S 166 of 381
+r0:=(-1/2)/x^2+1/4*atan(-2*x^2+sqrt(3))-1/4*atan(2*x^2+sqrt(3))-_
+   1/8*log(1+x^4-x^2*sqrt(3))/sqrt(3)+1/8*log(1+x^4+x^2*sqrt(3))/sqrt(3)
+--E 166
+
+--S 167 of 381
+d0:=t0-normalize(D(r0,x))
+--E 167
+
+)clear all
+
+--S 168 of 381
+t0:=(1-x^4)/(x^4*(1-x^4+x^8))
+--E 168
+
+--S 169 of 381
+r0:=(-1/3)/x^3+1/4*atan((-2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/_
+   sqrt(3*(2-sqrt(3)))-1/4*atan((2*x+sqrt(2+sqrt(3)))/sqrt(2-sqrt(3)))/_
+   sqrt(3*(2-sqrt(3)))+1/8*log(1+x^2-x*sqrt(2-sqrt(3)))/sqrt(3*(2-_
+   sqrt(3)))-1/8*log(1+x^2+x*sqrt(2-sqrt(3)))/sqrt(3*(2-sqrt(3)))-_
+   1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))+_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))-_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))+1/8*log(1+x^2+_
+   x*sqrt(2+sqrt(3)))/sqrt(3*(2+sqrt(3)))
+--E 169
+
+--S 170 of 381
+d0:=t0-normalize(D(r0,x))
+--E 170
+
+)clear all
+
+--S 171 of 381
+t0:=(1+x^4)/(1+x^4+x^8)
+--E 171
+
+--S 172 of 381
+r0:=-1/4*atan(-2*x+sqrt(3))+1/4*atan(2*x+sqrt(3))-1/8*log(1-x+x^2)+_
+   1/8*log(1+x+x^2)-1/4*atan((1-2*x)/sqrt(3))/sqrt(3)+1/4*atan((1+2*x)/_
+   sqrt(3))/sqrt(3)-1/8*log(1+x^2-x*sqrt(3))/sqrt(3)+1/8*log(1+x^2+_
+   x*sqrt(3))/sqrt(3)
+--E 172
+
+--S 173 of 381
+d0:=t0-normalize(D(r0,x))
+--E 173
+
+)clear all
+
+--S 174 of 381
+t0:=(1-x^4)/(1+x^4+x^8)
+--E 174
+
+--S 175 of 381
+r0:=1/4*atan(-2*x+sqrt(3))-1/4*atan(2*x+sqrt(3))+1/8*log(1-x+x^2)-_
+   1/8*log(1+x+x^2)-1/4*atan((1-2*x)/sqrt(3))*sqrt(3)+1/4*atan((1+2*x)/_
+   sqrt(3))*sqrt(3)-1/8*log(1+x^2-x*sqrt(3))*sqrt(3)+1/8*log(1+x^2+_
+   x*sqrt(3))*sqrt(3)
+--E 175
+
+--S 176 of 381
+d0:=t0-normalize(D(r0,x))
+--E 176
+
+)clear all
+
+--S 177 of 381
+t0:=(1+x^4)/(1-x^4+x^8)
+--E 177
+
+--S 178 of 381
+r0:=-1/4*atan((-2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(2-sqrt(3))+_
+   1/4*atan((2*x+sqrt(2-sqrt(3)))/sqrt(2+sqrt(3)))*sqrt(2-sqrt(3))-_
+   1/8*log(1+x^2-x*sqrt(2+sqrt(3)))*sqrt(2-sqrt(3))+1/8*log(1+x^2+_
+   x*sqrt(2+sqrt(3)))*sqrt(2-sqrt(3))-1/4*atan((-2*x+sqrt(2+sqrt(3)))/_
+   sqrt(2-sqrt(3)))*sqrt(2+sqrt(3))+1/4*atan((2*x+sqrt(2+sqrt(3)))/_
+   sqrt(2-sqrt(3)))*sqrt(2+sqrt(3))-1/8*log(1+x^2-x*sqrt(2-sqrt(3)))*_
+   sqrt(2+sqrt(3))+1/8*log(1+x^2+x*sqrt(2-sqrt(3)))*sqrt(2+sqrt(3))
+--E 178
+
+--S 179 of 381
+d0:=t0-normalize(D(r0,x))
+--E 179
+
+)clear all
+
+--S 180 of 381
+t0:=(1-x^4)/(1-3*x^4+x^8)
+--E 180
+
+--S 181 of 381
+r0:=1/2*atan(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*(3-sqrt(5))^(1/4)/(2^(1/4)*_
+   sqrt(5))+1/2*atanh(2^(1/4)*x*(1/(3+sqrt(5)))^(1/4))*(3-sqrt(5))^(1/4)/_
+   (2^(1/4)*sqrt(5))+1/2*atan(x*(3+sqrt(5))^(1/4)/2^(1/4))*_
+   (3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))+1/2*atanh(x*(3+sqrt(5))^(1/4)/_
+   2^(1/4))*(3+sqrt(5))^(1/4)/(2^(1/4)*sqrt(5))
+--E 181
+
+--S 182 of 381
+d0:=t0-normalize(D(r0,x))
+--E 182
+
+)clear all
+
+--S 183 of 381
+t0:=(-1+2*x^4+sqrt(3))/(1-x^4+x^8)
+--E 183
+
+--S 184 of 381
+r0:=-atan((-2*x*(3-sqrt(3))+sqrt(6))/sqrt(6*(7-4*sqrt(3))))/sqrt(2)+_
+   atan((2*x*(3-sqrt(3))+sqrt(6))/sqrt(6*(7-4*sqrt(3))))/sqrt(2)+_
+   1/2*log(3+x^2*(3-sqrt(3))-sqrt(3)-x*sqrt(6*(7-4*sqrt(3))))/sqrt(2)-_
+   1/2*log(3+x^2*(3-sqrt(3))-sqrt(3)+x*sqrt(6*(7-4*sqrt(3))))/sqrt(2)
+--E 184
+
+--S 185 of 381
+d0:=t0-normalize(D(r0,x))
+--E 185
+
+)clear all
+
+--S 186 of 381
+t0:=(1+x^4*(1+sqrt(3)))/(1-x^4+x^8)
+--E 186
+
+--S 187 of 381
+r0:=-1/2*atan((-2*x*sqrt(3)+sqrt(3*(2+sqrt(3))))/sqrt(3*(2-sqrt(3))))*_
+   sqrt(2+sqrt(3))+1/2*atan((2*x*sqrt(3)+sqrt(3*(2+sqrt(3))))/sqrt(3*_
+   (2-sqrt(3))))*sqrt(2+sqrt(3))-1/4*log(sqrt(3)+x^2*sqrt(3)-x*sqrt(3*_
+   (2-sqrt(3))))*sqrt(2+sqrt(3))+1/4*log(sqrt(3)+x^2*sqrt(3)+_
+   x*sqrt(3*(2-sqrt(3))))*sqrt(2+sqrt(3))
+--E 187
+
+--gcd not gcd in QF cancelGcd (numerator)
+--S 188 of 381
+d0:=t0-normalize(D(r0,x))
+--E 188
+
+)clear all
+
+--S 189 of 381
+t0:=(3+x^4*(-3+sqrt(3))-2*sqrt(3))/(1-x^4+x^8)
+--E 189
+
+--S 190 of 381
+r0:=1/2*atan((-2*x*(2-sqrt(3))+sqrt(2-sqrt(3)))/sqrt(26-15*sqrt(3)))*_
+   sqrt(3*(2-sqrt(3)))-1/2*atan((2*x*(2-sqrt(3))+sqrt(2-sqrt(3)))/_
+   sqrt(26-15*sqrt(3)))*sqrt(3*(2-sqrt(3)))+1/4*log(-3-x^2*(3-_
+   2*sqrt(3))+2*sqrt(3)-x*sqrt(3*(26-15*sqrt(3))))*sqrt(3*(2-sqrt(3)))-_
+   1/4*log(-3-x^2*(3-2*sqrt(3))+2*sqrt(3)+x*sqrt(3*(26-15*sqrt(3))))*_
+   sqrt(3*(2-sqrt(3)))
+--E 190
+
+--S 191 of 381
+d0:=t0-normalize(D(r0,x))
+--E 191
+
+)clear all
+
+--S 192 of 381
+t0:=(d+e*x^n)/(a+c*x^(2*n))
+--E 192
+
+--S 193 of 381
+--r0:=1/2*x*hypergeometric(1,1/n,1+1/n,-x^n*sqrt(c)/sqrt(-a))*_
+--  (d-e*sqrt(-a)/sqrt(c))/a+1/2*x*hypergeometric(1,1/n,1+1/n,x^n*_
+--  sqrt(c)/sqrt(-a))*(d+e*sqrt(-a)/sqrt(c))/a
+--E 193
+
+--S 194 of 381
+--d0:=t0-normalize(D(r0,x))
+--E 194
+
+)clear all
+
+--S 195 of 381
+t0:=(d+e*x)/(a+c*x^2)
+--E 195
+
+--S 196 of 381
+r0:=1/2*e*log(a+c*x^2)/c+d*atan(x*sqrt(c)/sqrt(a))/(sqrt(a)*sqrt(c))
+--E 196
+
+--S 197 of 381
+d0:=t0-normalize(D(r0,x))
+--E 197
+
+)clear all
+
+--S 198 of 381
+t0:=(d+e*x^2)/(a+c*x^4)
+--E 198
+
+--S 199 of 381
+r0:=-1/4*log(-a^(1/4)*c^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(c))*(-e*sqrt(a)+_
+   d*sqrt(c))/(a^(3/4)*c^(3/4)*sqrt(2))+1/4*log(a^(1/4)*c^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(c))*(-e*sqrt(a)+d*sqrt(c))/(a^(3/4)*c^(3/4)*sqrt(2))-_
+   1/2*atan(1-c^(1/4)*x*sqrt(2)/a^(1/4))*(e*sqrt(a)+d*sqrt(c))/(a^(3/4)*_
+   c^(3/4)*sqrt(2))+1/2*atan(1+c^(1/4)*x*sqrt(2)/a^(1/4))*(e*sqrt(a)+_
+   d*sqrt(c))/(a^(3/4)*c^(3/4)*sqrt(2))
+--E 199
+
+--S 200 of 381
+d0:=t0-normalize(D(r0,x))
+--E 200
+
+)clear all
+
+--S 201 of 381
+t0:=(d+e*x^3)/(a+c*x^6)
+--E 201
+
+--S 202 of 381
+r0:=-1/6*log((-a)^(1/6)+c^(1/6)*x)*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*_
+   c^(2/3))+1/12*log((-a)^(1/3)-(-a)^(1/6)*c^(1/6)*x+c^(1/3)*x^2)*_
+   (-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))+1/2*atan(((-a)^(1/6)-_
+   2*c^(1/6)*x)/((-a)^(1/6)*sqrt(3)))*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*_
+   c^(2/3)*sqrt(3))+1/6*log((-a)^(1/6)-c^(1/6)*x)*(e*sqrt(-a)+d*sqrt(c))/_
+   ((-a)^(5/6)*c^(2/3))-1/12*log((-a)^(1/3)+(-a)^(1/6)*c^(1/6)*x+_
+   c^(1/3)*x^2)*(e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))-_
+   1/2*atan(((-a)^(1/6)+2*c^(1/6)*x)/((-a)^(1/6)*sqrt(3)))*(e*_
+   sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3)*sqrt(3)),-1/6*log((-a)^(1/6)+_
+   c^(1/6)*x)*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))-1/6*(-1)^(2/3)*_
+   log((-a)^(1/6)-(-1)^(1/3)*c^(1/6)*x)*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*_
+   c^(2/3))+1/6*(-1)^(1/3)*log((-a)^(1/6)+(-1)^(2/3)*c^(1/6)*x)*_
+   (-e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))+1/6*log((-a)^(1/6)-_
+   c^(1/6)*x)*(e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))+1/6*(-1)^(2/3)*_
+   log((-a)^(1/6)+(-1)^(1/3)*c^(1/6)*x)*(e*sqrt(-a)+d*sqrt(c))/_
+   ((-a)^(5/6)*c^(2/3))-1/6*(-1)^(1/3)*log((-a)^(1/6)-(-1)^(2/3)*_
+   c^(1/6)*x)*(e*sqrt(-a)+d*sqrt(c))/((-a)^(5/6)*c^(2/3))
+--E 202
+
+--S 203 of 381
+d0:=t0-normalize(D(r0,x))
+--E 203
+
+)clear all
+
+--S 204 of 381
+t0:=(d+e*x^4)/(a+c*x^8)
+--E 204
+
+--S 205 of 381
+r0a:=-1/4*atan(2^(1/4)*c^(1/8)*x/sqrt(-a^(1/4)+sqrt(-sqrt(a))))*_
+   (-e*sqrt(a)+d*sqrt(c)+a^(1/4)*(e*sqrt(a)+d*sqrt(c))/sqrt(-sqrt(a)))/_
+   (2^(1/4)*a^(3/4)*c^(5/8)*sqrt(-a^(1/4)+sqrt(-sqrt(a))))-_
+   1/4*atanh(2^(1/4)*c^(1/8)*x/sqrt(-a^(1/4)+sqrt(-sqrt(a))))*_
+   (-e*sqrt(a)+d*sqrt(c)+a^(1/4)*(e*sqrt(a)+d*sqrt(c))/sqrt(-sqrt(a)))/_
+   (2^(1/4)*a^(3/4)*c^(5/8)*sqrt(-a^(1/4)+sqrt(-sqrt(a))))+_
+   1/4*atan(2^(1/4)*c^(1/8)*x/sqrt(a^(1/4)+sqrt(-sqrt(a))))*_
+   (-e*sqrt(a)+d*sqrt(c)-a^(1/4)*(e*sqrt(a)+d*sqrt(c))/sqrt(-sqrt(a)))/_
+   (2^(1/4)*a^(3/4)*c^(5/8)*sqrt(a^(1/4)+sqrt(-sqrt(a))))+_
+   1/4*atanh(2^(1/4)*c^(1/8)*x/sqrt(a^(1/4)+sqrt(-sqrt(a))))*_
+   (-e*sqrt(a)+d*sqrt(c)-a^(1/4)*(e*sqrt(a)+d*sqrt(c))/sqrt(-sqrt(a)))/_
+   (2^(1/4)*a^(3/4)*c^(5/8)*sqrt(a^(1/4)+sqrt(-sqrt(a))))
+--E 205
+
+--S 206 of 381
+r0b:=-1/8*(-1)^(3/4)*log((-a)^(1/8)-(-1)^(1/4)*c^(1/8)*x)*(-e*sqrt(-a)+_
+   d*sqrt(c))/((-a)^(7/8)*c^(5/8))+1/8*(-1)^(3/4)*log((-a)^(1/8)+_
+   (-1)^(1/4)*c^(1/8)*x)*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(7/8)*c^(5/8))-_
+   1/8*(-1)^(1/4)*log((-a)^(1/8)-(-1)^(3/4)*c^(1/8)*x)*(-e*sqrt(-a)+_
+   d*sqrt(c))/((-a)^(7/8)*c^(5/8))+1/8*(-1)^(1/4)*log((-a)^(1/8)+_
+   (-1)^(3/4)*c^(1/8)*x)*(-e*sqrt(-a)+d*sqrt(c))/((-a)^(7/8)*c^(5/8))+_
+   1/8*log((-a)^(1/8)-c^(1/8)*x)*(e*sqrt(-a)+d*sqrt(c))/((-a)^(7/8)*_
+   c^(5/8))-1/8*%i*log((-a)^(1/8)-%i*c^(1/8)*x)*(e*sqrt(-a)+d*sqrt(c))/_
+   ((-a)^(7/8)*c^(5/8))+1/8*%i*log((-a)^(1/8)+%i*c^(1/8)*x)*(e*sqrt(-a)+_
+   d*sqrt(c))/((-a)^(7/8)*c^(5/8))-1/8*log((-a)^(1/8)+c^(1/8)*x)*_
+   (e*sqrt(-a)+d*sqrt(c))/((-a)^(7/8)*c^(5/8))
+--E 206
+
+--S 207 of 381
+d0:=t0-normalize(D(r0,x))
+--E 207
+
+)clear all
+
+--S 208 of 381
+t0:=(d+e*x^n)/(a-c*x^(2*n))
+--E 208
+
+--S 209 of 381
+--r0:=1/2*x*hypergeometric(1,1/n,1+1/n,-x^n*sqrt(c)/sqrt(a))*_
+--  (d-e*sqrt(a)/sqrt(c))/a+1/2*x*hypergeometric(1,1/n,1+1/n,x^n*_
+--  sqrt(c)/sqrt(a))*(d+e*sqrt(a)/sqrt(c))/a
+--E 209
+
+--S 210 of 381
+--d0:=t0-normalize(D(r0,x))
+--E 210
+
+)clear all
+
+--S 211 of 381
+t0:=(d+e*x)/(a-c*x^2)
+--E 211
+
+--S 212 of 381
+r0:=-1/2*e*log(a-c*x^2)/c+d*atanh(x*sqrt(c)/sqrt(a))/(sqrt(a)*sqrt(c))
+--E 212
+
+--S 213 of 381
+d0:=t0-normalize(D(r0,x))
+--E 213
+
+)clear all
+
+--S 214 of 381
+t0:=(d+e*x^2)/(a-c*x^4)
+--E 214
+
+--S 215 of 381
+r0:=1/2*atan(c^(1/4)*x/a^(1/4))*(-e*sqrt(a)+d*sqrt(c))/(a^(3/4)*c^(3/4))+_
+   1/2*atanh(c^(1/4)*x/a^(1/4))*(e*sqrt(a)+d*sqrt(c))/(a^(3/4)*c^(3/4))
+--E 215
+
+--S 216 of 381
+d0:=t0-normalize(D(r0,x))
+--E 216
+
+)clear all
+
+--S 217 of 381
+t0:=(d+e*x^3)/(a-c*x^6)
+--E 217
+
+--S 218 of 381
+r0:=1/6*log(a^(1/6)+c^(1/6)*x)*(d-e*sqrt(a)/sqrt(c))/(a^(5/6)*c^(1/6))+_
+   1/6*(-1)^(2/3)*log(a^(1/6)-(-1)^(1/3)*c^(1/6)*x)*(d-e*sqrt(a)/sqrt(c))/_
+   (a^(5/6)*c^(1/6))-1/6*(-1)^(1/3)*log(a^(1/6)+(-1)^(2/3)*c^(1/6)*x)*_
+   (d-e*sqrt(a)/sqrt(c))/(a^(5/6)*c^(1/6))-1/6*log(a^(1/6)-c^(1/6)*x)*_
+   (e*sqrt(a)+d*sqrt(c))/(a^(5/6)*c^(2/3))-1/6*(-1)^(2/3)*log(a^(1/6)+_
+   (-1)^(1/3)*c^(1/6)*x)*(e*sqrt(a)+d*sqrt(c))/(a^(5/6)*c^(2/3))+_
+   1/6*(-1)^(1/3)*log(a^(1/6)-(-1)^(2/3)*c^(1/6)*x)*(e*sqrt(a)+d*_
+   sqrt(c))/(a^(5/6)*c^(2/3))
+--E 218
+
+--S 219 of 381
+d0:=t0-normalize(D(r0,x))
+--E 219
+
+)clear all
+
+--S 220 of 381
+t0:=(d+e*x^4)/(a-c*x^8)
+--E 220
+
+--S 221 of 381
+r0:=1/8*(-1)^(3/4)*log(a^(1/8)-(-1)^(1/4)*c^(1/8)*x)*(d-e*sqrt(a)/sqrt(c))/_
+   (a^(7/8)*c^(1/8))-1/8*(-1)^(3/4)*log(a^(1/8)+(-1)^(1/4)*c^(1/8)*x)*_
+   (d-e*sqrt(a)/sqrt(c))/(a^(7/8)*c^(1/8))+1/8*(-1)^(1/4)*log(a^(1/8)-_
+   (-1)^(3/4)*c^(1/8)*x)*(d-e*sqrt(a)/sqrt(c))/(a^(7/8)*c^(1/8))-_
+   1/8*(-1)^(1/4)*log(a^(1/8)+(-1)^(3/4)*c^(1/8)*x)*(d-e*sqrt(a)/_
+   sqrt(c))/(a^(7/8)*c^(1/8))-1/8*log(a^(1/8)-c^(1/8)*x)*(e*sqrt(a)+_
+   d*sqrt(c))/(a^(7/8)*c^(5/8))+1/8*%i*log(a^(1/8)-%i*c^(1/8)*x)*(e*_
+   sqrt(a)+d*sqrt(c))/(a^(7/8)*c^(5/8))-1/8*%i*log(a^(1/8)+%i*c^(1/8)*x)*_
+   (e*sqrt(a)+d*sqrt(c))/(a^(7/8)*c^(5/8))+1/8*log(a^(1/8)+c^(1/8)*x)*_
+   (e*sqrt(a)+d*sqrt(c))/(a^(7/8)*c^(5/8))
+--E 221
+
+--S 222 of 381
+d0:=t0-normalize(D(r0,x))
+--E 222
+
+)clear all
+
+--S 223 of 381
+t0:=(b+2*c*x)*(a+b*x+c*x^2)^13
+--E 223
+
+--S 224 of 381
+r0:=1/14*(a+b*x+c*x^2)^14
+--E 224
+
+--S 225 of 381
+d0:=t0-normalize(D(r0,x))
+--E 225
+
+)clear all
+
+--S 226 of 381
+t0:=x*(b+2*c*x^2)*(a+b*x^2+c*x^4)^13
+--E 226
+
+--S 227 of 381
+r0:=1/28*(a+b*x^2+c*x^4)^14
+--E 227
+
+--S 228 of 381
+d0:=t0-normalize(D(r0,x))
+--E 228
+
+)clear all
+
+--S 229 of 381
+t0:=x^2*(b+2*c*x^3)*(a+b*x^3+c*x^6)^13
+--E 229
+
+--S 230 of 381
+r0:=1/42*(a+b*x^3+c*x^6)^14
+--E 230
+
+--S 231 of 381
+d0:=t0-normalize(D(r0,x))
+--E 231
+
+)clear all
+
+--S 232 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)*(a+b*x^n+c*x^(2*n))^13
+--E 232
+
+--S 233 of 381
+r0:=1/14*(a+b*x^n+c*x^(2*n))^14/n
+--E 233
+
+--S 234 of 381
+d0:=t0-normalize(D(r0,x))
+--E 234
+
+)clear all
+
+--S 235 of 381
+t0:=(b+2*c*x)*(-a+b*x+c*x^2)^13
+--E 235
+
+--S 236 of 381
+r0:=1/14*(a-b*x-c*x^2)^14
+--E 236
+
+--S 237 of 381
+d0:=t0-normalize(D(r0,x))
+--E 237
+
+)clear all
+
+--S 238 of 381
+t0:=x*(b+2*c*x^2)*(-a+b*x^2+c*x^4)^13
+--E 238
+
+--S 239 of 381
+r0:=1/28*(a-b*x^2-c*x^4)^14
+--E 239
+
+--S 240 of 381
+d0:=t0-normalize(D(r0,x))
+--E 240
+
+)clear all
+
+--S 241 of 381
+t0:=x^2*(b+2*c*x^3)*(-a+b*x^3+c*x^6)^13
+--E 241
+
+--S 242 of 381
+r0:=1/42*(a-b*x^3-c*x^6)^14
+--E 242
+
+--S 243 of 381
+d0:=t0-normalize(D(r0,x))
+--E 243
+
+)clear all
+
+--S 244 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)*(-a+b*x^n+c*x^(2*n))^13
+--E 244
+
+--S 245 of 381
+r0:=1/14*(a-b*x^n-c*x^(2*n))^14/n
+--E 245
+
+--S 246 of 381
+d0:=t0-normalize(D(r0,x))
+--E 246
+
+)clear all
+
+--S 247 of 381
+t0:=(b+2*c*x)*(b*x+c*x^2)^13
+--E 247
+
+--S 248 of 381
+r0:=1/14*x^14*(b+c*x)^14
+--E 248
+
+--S 249 of 381
+d0:=t0-normalize(D(r0,x))
+--E 249
+
+)clear all
+
+--S 250 of 381
+t0:=x*(b+2*c*x^2)*(b*x^2+c*x^4)^13
+--E 250
+
+--S 251 of 381
+r0:=1/28*x^28*(b+c*x^2)^14
+--E 251
+
+--S 252 of 381
+d0:=t0-normalize(D(r0,x))
+--E 252
+
+)clear all
+
+--S 253 of 381
+t0:=x^2*(b+2*c*x^3)*(b*x^3+c*x^6)^13
+--E 253
+
+--S 254 of 381
+r0:=1/42*x^42*(b+c*x^3)^14
+--E 254
+
+--S 255 of 381
+d0:=t0-normalize(D(r0,x))
+--E 255
+
+)clear all
+
+--S 256 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)*(b*x^n+c*x^(2*n))^13
+--E 256
+
+--S 257 of 381
+r0:=1/14*x^(14*n)*(b+c*x^n)^14/n
+--E 257
+
+--S 258 of 381
+d0:=t0-normalize(D(r0,x))
+--E 258
+
+)clear all
+
+--S 259 of 381
+t0:=(b+2*c*x)/(a+b*x+c*x^2)
+--E 259
+
+--S 260 of 381
+r0:=log(a+b*x+c*x^2)
+--E 260
+
+--S 261 of 381
+d0:=t0-normalize(D(r0,x))
+--E 261
+
+)clear all
+
+--S 262 of 381
+t0:=x*(b+2*c*x^2)/(a+b*x^2+c*x^4)
+--E 262
+
+--S 263 of 381
+r0:=1/2*log(a+b*x^2+c*x^4)
+--E 263
+
+--S 264 of 381
+d0:=t0-normalize(D(r0,x))
+--E 264
+
+)clear all
+
+--S 265 of 381
+t0:=x^2*(b+2*c*x^3)/(a+b*x^3+c*x^6)
+--E 265
+
+--S 266 of 381
+r0:=1/3*log(a+b*x^3+c*x^6)
+--E 266
+
+--S 267 of 381
+d0:=t0-normalize(D(r0,x))
+--E 267
+
+)clear all
+
+--S 268 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)/(a+b*x^n+c*x^(2*n))
+--E 268
+
+--S 269 of 381
+r0:=log(a+b*x^n+c*x^(2*n))/n
+--E 269
+
+--S 270 of 381
+d0:=t0-normalize(D(r0,x))
+--E 270
+
+)clear all
+
+--S 271 of 381
+t0:=(b+2*c*x)/(a+b*x+c*x^2)^8
+--E 271
+
+--S 272 of 381
+r0:=(-1/7)/(a+b*x+c*x^2)^7
+--E 272
+
+--S 273 of 381
+d0:=t0-normalize(D(r0,x))
+--E 273
+
+)clear all
+
+--S 274 of 381
+t0:=x*(b+2*c*x^2)/(a+b*x^2+c*x^4)^8
+--E 274
+
+--S 275 of 381
+r0:=(-1/14)/(a+b*x^2+c*x^4)^7
+--E 275
+
+--S 276 of 381
+d0:=t0-normalize(D(r0,x))
+--E 276
+
+)clear all
+
+--S 277 of 381
+t0:=x^2*(b+2*c*x^3)/(a+b*x^3+c*x^6)^8
+--E 277
+
+--S 278 of 381
+r0:=(-1/21)/(a+b*x^3+c*x^6)^7
+--E 278
+
+--S 279 of 381
+d0:=t0-normalize(D(r0,x))
+--E 279
+
+)clear all
+
+--S 280 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)/(a+b*x^n+c*x^(2*n))^8
+--E 280
+
+--S 281 of 381
+r0:=(-1/7)/(n*(a+b*x^n+c*x^(2*n))^7)
+--E 281
+
+--S 282 of 381
+d0:=t0-normalize(D(r0,x))
+--E 282
+
+)clear all
+
+--S 283 of 381
+t0:=(b+2*c*x)/(-a+b*x+c*x^2)
+--E 283
+
+--S 284 of 381
+r0:=log(a-b*x-c*x^2)
+--E 284
+
+--S 285 of 381
+d0:=t0-normalize(D(r0,x))
+--E 285
+
+)clear all
+
+--S 286 of 381
+t0:=x*(b+2*c*x^2)/(-a+b*x^2+c*x^4)
+--E 286
+
+--S 287 of 381
+r0:=1/2*log(a-b*x^2-c*x^4)
+--E 287
+
+--S 288 of 381
+d0:=t0-normalize(D(r0,x))
+--E 288
+
+)clear all
+
+--S 289 of 381
+t0:=x^2*(b+2*c*x^3)/(-a+b*x^3+c*x^6)
+--E 289
+
+--S 290 of 381
+r0:=1/3*log(a-b*x^3-c*x^6)
+--E 290
+
+--S 291 of 381
+d0:=t0-normalize(D(r0,x))
+--E 291
+
+)clear all
+
+--S 292 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)/(-a+b*x^n+c*x^(2*n))
+--E 292
+
+--S 293 of 381
+r0:=log(a-b*x^n-c*x^(2*n))/n
+--E 293
+
+--S 294 of 381
+d0:=t0-normalize(D(r0,x))
+--E 294
+
+)clear all
+
+--S 295 of 381
+t0:=(b+2*c*x)/(-a+b*x+c*x^2)^8
+--E 295
+
+--S 296 of 381
+r0:=1/7/(a-b*x-c*x^2)^7
+--E 296
+
+--S 297 of 381
+d0:=t0-normalize(D(r0,x))
+--E 297
+
+)clear all
+
+--S 298 of 381
+t0:=x*(b+2*c*x^2)/(-a+b*x^2+c*x^4)^8
+--E 298
+
+--S 299 of 381
+r0:=1/14/(a-b*x^2-c*x^4)^7
+--E 299
+
+--S 300 of 381
+d0:=t0-normalize(D(r0,x))
+--E 300
+
+)clear all
+
+--S 301 of 381
+t0:=x^2*(b+2*c*x^3)/(-a+b*x^3+c*x^6)^8
+--E 301
+
+--S 302 of 381
+r0:=1/21/(a-b*x^3-c*x^6)^7
+--E 302
+
+--S 303 of 381
+d0:=t0-normalize(D(r0,x))
+--E 303
+
+)clear all
+
+--S 304 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)/(-a+b*x^n+c*x^(2*n))^8
+--E 304
+
+--S 305 of 381
+r0:=1/7/(n*(a-b*x^n-c*x^(2*n))^7)
+--E 305
+
+--S 306 of 381
+d0:=t0-normalize(D(r0,x))
+--E 306
+
+)clear all
+
+--S 307 of 381
+t0:=(b+2*c*x)/(b*x+c*x^2)
+--E 307
+
+--S 308 of 381
+r0:=log(x*(b+c*x)),log(x)+log(b+c*x)
+--E 308
+
+--S 309 of 381
+d0:=t0-normalize(D(r0,x))
+--E 309
+
+)clear all
+
+--S 310 of 381
+t0:=x*(b+2*c*x^2)/(b*x^2+c*x^4)
+--E 310
+
+--S 311 of 381
+r0:=log(x)+1/2*log(b+c*x^2)
+--E 311
+
+--S 312 of 381
+d0:=t0-normalize(D(r0,x))
+--E 312
+
+)clear all
+
+--S 313 of 381
+t0:=x^2*(b+2*c*x^3)/(b*x^3+c*x^6)
+--E 313
+
+--S 314 of 381
+r0:=log(x)+1/3*log(b+c*x^3)
+--E 314
+
+--S 315 of 381
+d0:=t0-normalize(D(r0,x))
+--E 315
+
+)clear all
+
+--S 316 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)/(b*x^n+c*x^(2*n))
+--E 316
+
+--S 317 of 381
+r0:=log(x)+log(b+c*x^n)/n
+--E 317
+
+--S 318 of 381
+d0:=t0-normalize(D(r0,x))
+--E 318
+
+)clear all
+
+--S 319 of 381
+t0:=(b+2*c*x)/(b*x+c*x^2)^8
+--E 319
+
+--S 320 of 381
+r0:=(-1/7)/(x^7*(b+c*x)^7)
+--E 320
+
+--S 321 of 381
+d0:=t0-normalize(D(r0,x))
+--E 321
+
+)clear all
+
+--S 322 of 381
+t0:=x*(b+2*c*x^2)/(b*x^2+c*x^4)^8
+--E 322
+
+--S 323 of 381
+r0:=(-1/14)/(x^14*(b+c*x^2)^7)
+--E 323
+
+--S 324 of 381
+d0:=t0-normalize(D(r0,x))
+--E 324
+
+)clear all
+
+--S 325 of 381
+t0:=x^2*(b+2*c*x^3)/(b*x^3+c*x^6)^8
+--E 325
+
+--S 326 of 381
+r0:=(-1/21)/(x^21*(b+c*x^3)^7)
+--E 326
+
+--S 327 of 381
+d0:=t0-normalize(D(r0,x))
+--E 327
+
+)clear all
+
+--S 328 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)/(b*x^n+c*x^(2*n))^8
+--E 328
+
+--S 329 of 381
+r0:=(-1/7)/(n*x^(7*n)*(b+c*x^n)^7)
+--E 329
+
+--S 330 of 381
+d0:=t0-normalize(D(r0,x))
+--E 330
+
+)clear all
+
+--S 331 of 381
+t0:=(b+2*c*x)*(a+b*x+c*x^2)^p
+--E 331
+
+--S 332 of 381
+r0:=(a+b*x+c*x^2)^(1+p)/(1+p)
+--E 332
+
+--S 333 of 381
+d0:=t0-normalize(D(r0,x))
+--E 333
+
+)clear all
+
+--S 334 of 381
+t0:=x*(b+2*c*x^2)*(a+b*x^2+c*x^4)^p
+--E 334
+
+--S 335 of 381
+r0:=1/2*(a+b*x^2+c*x^4)^(1+p)/(1+p)
+--E 335
+
+--S 336 of 381
+d0:=t0-normalize(D(r0,x))
+--E 336
+
+)clear all
+
+--S 337 of 381
+t0:=x^2*(b+2*c*x^3)*(a+b*x^3+c*x^6)^p
+--E 337
+
+--S 338 of 381
+r0:=1/3*(a+b*x^3+c*x^6)^(1+p)/(1+p)
+--E 338
+
+--S 339 of 381
+d0:=t0-normalize(D(r0,x))
+--E 339
+
+)clear all
+
+--S 340 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)*(a+b*x^n+c*x^(2*n))^p
+--E 340
+
+--S 341 of 381
+r0:=(a+b*x^n+c*x^(2*n))^(1+p)/(n*(1+p))
+--E 341
+
+--S 342 of 381
+d0:=t0-normalize(D(r0,x))
+--E 342
+
+)clear all
+
+--S 343 of 381
+t0:=(b+2*c*x)*(-a+b*x+c*x^2)^p
+--E 343
+
+--S 344 of 381
+r0:=(-a+b*x+c*x^2)^(1+p)/(1+p)
+--E 344
+
+--S 345 of 381
+d0:=t0-normalize(D(r0,x))
+--E 345
+
+)clear all
+
+--S 346 of 381
+t0:=x*(b+2*c*x^2)*(-a+b*x^2+c*x^4)^p
+--E 346
+
+--S 347 of 381
+r0:=1/2*(-a+b*x^2+c*x^4)^(1+p)/(1+p)
+--E 347
+
+--S 348 of 381
+d0:=t0-normalize(D(r0,x))
+--E 348
+
+)clear all
+
+--S 349 of 381
+t0:=x^2*(b+2*c*x^3)*(-a+b*x^3+c*x^6)^p
+--E 349
+
+--S 350 of 381
+r0:=1/3*(-a+b*x^3+c*x^6)^(1+p)/(1+p)
+--E 350
+
+--S 351 of 381
+d0:=t0-normalize(D(r0,x))
+--E 351
+
+)clear all
+
+--S 352 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)*(-a+b*x^n+c*x^(2*n))^p
+--E 352
+
+--S 353 of 381
+r0:=(-a+b*x^n+c*x^(2*n))^(1+p)/(n*(1+p))
+--E 353
+
+--S 354 of 381
+d0:=t0-normalize(D(r0,x))
+--E 354
+
+)clear all
+
+--S 355 of 381
+t0:=(b+2*c*x)*(b*x+c*x^2)^p
+--E 355
+
+--S 356 of 381
+r0:=(b*x+c*x^2)^(1+p)/(1+p)
+--E 356
+
+--S 357 of 381
+d0:=t0-normalize(D(r0,x))
+--E 357
+
+)clear all
+
+--S 358 of 381
+t0:=x*(b+2*c*x^2)*(b*x^2+c*x^4)^p
+--E 358
+
+--S 359 of 381
+r0:=1/2*(b*x^2+c*x^4)^(1+p)/(1+p)
+--E 359
+
+--S 360 of 381
+d0:=t0-normalize(D(r0,x))
+--E 360
+
+)clear all
+
+--S 361 of 381
+t0:=x^2*(b+2*c*x^3)*(b*x^3+c*x^6)^p
+--E 361
+
+--S 362 of 381
+r0:=1/3*(b*x^3+c*x^6)^(1+p)/(1+p)
+--E 362
+
+--S 363 of 381
+d0:=t0-normalize(D(r0,x))
+--E 363
+
+)clear all
+
+--S 364 of 381
+t0:=x^(-1+n)*(b+2*c*x^n)*(b*x^n+c*x^(2*n))^p
+--E 364
+
+--S 365 of 381
+r0:=(b*x^n+c*x^(2*n))^(1+p)/(n*(1+p))
+--E 365
+
+--S 366 of 381
+d0:=t0-normalize(D(r0,x))
+--E 366
+
+)clear all
+
+--S 367 of 381
+t0:=(d+e*x^n)/(a+b*x^n+c*x^(2*n))
+--E 367
+
+--S 368 of 381
+--r0:=x*hypergeometric(1,1/n,1+1/n,-2*c*x^n/(b-sqrt(b^2-4*a*c)))*_
+--  (e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c))+x*_
+--  hypergeometric(1,1/n,1+1/n,-2*c*x^n/(b+sqrt(b^2-4*a*c)))*_
+--  (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c))
+--E 368
+
+--S 369 of 381
+d0:=t0-normalize(D(r0,x))
+--E 369
+
+)clear all
+
+--S 370 of 381
+t0:=(d+e*x)/(a+b*x+c*x^2)
+--E 370
+
+--S 371 of 381
+r0:=1/2*e*log(a+b*x+c*x^2)/c-(2*c*d-b*e)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(c*sqrt(b^2-4*a*c))
+--E 371
+
+--S 372 of 381
+d0:=t0-normalize(D(r0,x))
+--E 372
+
+)clear all
+
+--S 373 of 381
+t0:=(d+e*x^2)/(a+b*x^2+c*x^4)
+--E 373
+
+--S 374 of 381
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(e+(2*c*d-b*e)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(e+(-2*c*d+b*e)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--E 374
+
+--S 375 of 381
+d0:=t0-normalize(D(r0,x))
+--E 375
+
+)clear all
+
+--S 376 of 381
+t0:=(d+e*x^4)/(a+b*x^4+c*x^8)
+--E 376
+
+--S 377 of 381
+r0:=-1/2*atan(2^(1/4)*c^(1/4)*x/(-b-sqrt(b^2-4*a*c))^(1/4))*_
+   (e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/(2^(1/4)*c^(1/4)*_
+   (-b-sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*c^(1/4)*_
+   x/(-b-sqrt(b^2-4*a*c))^(1/4))*(e+(-2*c*d+b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(1/4)*(-b-sqrt(b^2-4*a*c))^(3/4))-1/2*atan(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(1/4)*(-b+sqrt(b^2-4*a*c))^(3/4))-1/2*atanh(2^(1/4)*_
+   c^(1/4)*x/(-b+sqrt(b^2-4*a*c))^(1/4))*(e+(2*c*d-b*e)/sqrt(b^2-4*a*c))/_
+   (2^(1/4)*c^(1/4)*(-b+sqrt(b^2-4*a*c))^(3/4))
+--E 377
+
+--S 378 of 381
+d0:=t0-normalize(D(r0,x))
+--E 378
+
+)clear all
+
+--S 379 of 381
+t0:=(1+x^3)/(x-x^4+x^7)
+--E 379
+
+--S 380 of 381
+r0:=log(x)-1/6*log(1-x^3+x^6)-atan((1-2*x^3)/sqrt(3))/sqrt(3)
+--E 380
+
+--S 381 of 381
+d0:=t0-normalize(D(r0,x))
+--E 381
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder18.input.pamphlet b/src/input/richder18.input.pamphlet
new file mode 100644
index 0000000..a2553c3
--- /dev/null
+++ b/src/input/richder18.input.pamphlet
@@ -0,0 +1,6754 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder18.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a x^q+b x^n+c x^(2 n-q))^p|
+
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder18.output
+)spool richder18.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1125
+t0:=(A+B*x)*(d+e*x)^m*(b*x+c*x^2)
+--E 1
+
+--S 2 of 1125
+r0:=-d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^(1+m)/(e^4*(1+m))+(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^(2+m)/(e^4*(2+m))-(3*B*c*d-b*B*e-A*c*e)*_
+     (d+e*x)^(3+m)/(e^4*(3+m))+B*c*(d+e*x)^(4+m)/(e^4*(4+m))
+--E 2
+
+--S 3 of 1125
+d0:=normalize(D(m0,x))
+--E 3
+
+)clear all
+
+--S 4 of 1125
+t0:=(A+B*x)*(d+e*x)^5*(b*x+c*x^2)
+--E 4
+
+--S 5 of 1125
+r0:=-1/6*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^6/e^4+1/7*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^7/e^4-1/8*(3*B*c*d-b*B*e-A*c*e)*(d+e*x)^8/e^4+_
+     1/9*B*c*(d+e*x)^9/e^4
+--E 5
+
+--S 6 of 1125
+d0:=D(m0,x)
+--E 6
+
+)clear all
+
+--S 7 of 1125
+t0:=(A+B*x)*(d+e*x)^4*(b*x+c*x^2)
+--E 7
+
+--S 8 of 1125
+r0:=-1/5*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^5/e^4+1/6*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^6/e^4-1/7*(3*B*c*d-b*B*e-A*c*e)*(d+e*x)^7/e^4+_
+     1/8*B*c*(d+e*x)^8/e^4
+--E 8
+
+--S 9 of 1125
+d0:=D(m0,x)
+--E 9
+
+)clear all
+
+--S 10 of 1125
+t0:=(A+B*x)*(d+e*x)^3*(b*x+c*x^2)
+--E 10
+
+--S 11 of 1125
+r0:=-1/4*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^4/e^4+1/5*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^5/e^4-1/6*(3*B*c*d-b*B*e-A*c*e)*(d+e*x)^6/e^4+_
+     1/7*B*c*(d+e*x)^7/e^4
+--E 11
+
+--S 12 of 1125
+d0:=D(m0,x)
+--E 12
+
+)clear all
+
+--S 13 of 1125
+t0:=(A+B*x)*(d+e*x)^2*(b*x+c*x^2)
+--E 13
+
+--S 14 of 1125
+r0:=1/2*A*b*d^2*x^2+1/3*d*(b*B*d+A*c*d+2*A*b*e)*x^3+1/4*(A*e*(2*c*d+b*e)+_
+     B*d*(c*d+2*b*e))*x^4+1/5*e*(2*B*c*d+b*B*e+A*c*e)*x^5+1/6*B*c*e^2*x^6
+--E 14
+
+--S 15 of 1125
+d0:=D(m0,x)
+--E 15
+
+)clear all
+
+--S 16 of 1125
+t0:=(A+B*x)*(d+e*x)*(b*x+c*x^2)
+--E 16
+
+--S 17 of 1125
+r0:=1/2*A*b*d*x^2+1/3*(b*B*d+A*c*d+A*b*e)*x^3+1/4*(B*c*d+b*B*e+A*c*e)*x^4+_
+     1/5*B*c*e*x^5
+--E 17
+
+--S 18 of 1125
+d0:=D(m0,x)
+--E 18
+
+)clear all
+
+--S 19 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)
+--E 19
+
+--S 20 of 1125
+r0:=1/2*A*b*x^2+1/3*(b*B+A*c)*x^3+1/4*B*c*x^4
+--E 20
+
+--S 21 of 1125
+d0:=D(m0,x)
+--E 21
+
+)clear all
+
+--S 22 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)
+--E 22
+
+--S 23 of 1125
+r0:=(B*d-A*e)*(c*d-b*e)*x/e^3-1/2*(B*c*d-b*B*e-A*c*e)*x^2/e^2+_
+     1/3*B*c*x^3/e-d*(B*d-A*e)*(c*d-b*e)*log(d+e*x)/e^4
+--E 23
+
+--S 24 of 1125
+d0:=D(m0,x)
+--E 24
+
+)clear all
+
+--S 25 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^2
+--E 25
+
+--S 26 of 1125
+r0:=-(2*B*c*d-b*B*e-A*c*e)*x/e^3+1/2*B*c*x^2/e^2+d*(B*d-A*e)*_
+     (c*d-b*e)/(e^4*(d+e*x))+(B*d*(3*c*d-2*b*e)-A*e*(2*c*d-b*e))*log(d+e*x)/e^4
+--E 26
+
+--S 27 of 1125
+d0:=D(m0,x)
+--E 27
+
+)clear all
+
+--S 28 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^3
+--E 28
+
+--S 29 of 1125
+r0:=B*c*x/e^3+1/2*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^2)+(-B*d*(3*c*d-_
+     2*b*e)+A*e*(2*c*d-b*e))/(e^4*(d+e*x))-(3*B*c*d-b*B*e-A*c*e)*log(d+_
+     e*x)/e^4
+--E 29
+
+--S 30 of 1125
+d0:=D(m0,x)
+--E 30
+
+)clear all
+
+--S 31 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^4
+--E 31
+
+--S 32 of 1125
+r0:=1/3*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^3)+1/2*(-B*d*(3*c*d-2*b*e)+_
+     A*e*(2*c*d-b*e))/(e^4*(d+e*x)^2)+(3*B*c*d-b*B*e-A*c*e)/(e^4*(d+e*x))+_
+     B*c*log(d+e*x)/e^4
+--E 32
+
+--S 33 of 1125
+d0:=D(m0,x)
+--E 33
+
+)clear all
+
+--S 34 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^5
+--E 34
+
+--S 35 of 1125
+r0:=1/4*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^4)+1/3*(-B*d*(3*c*d-2*b*e)+_
+     A*e*(2*c*d-b*e))/(e^4*(d+e*x)^3)+1/2*(3*B*c*d-b*B*e-A*c*e)/(e^4*_
+     (d+e*x)^2)-B*c/(e^4*(d+e*x))
+--E 35
+
+--S 36 of 1125
+d0:=D(m0,x)
+--E 36
+
+)clear all
+
+--S 37 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^6
+--E 37
+
+--S 38 of 1125
+r0:=1/5*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^5)+1/4*(-B*d*(3*c*d-2*b*e)+_
+     A*e*(2*c*d-b*e))/(e^4*(d+e*x)^4)+1/3*(3*B*c*d-b*B*e-A*c*e)/(e^4*_
+     (d+e*x)^3)-1/2*B*c/(e^4*(d+e*x)^2)
+--E 38
+
+--S 39 of 1125
+d0:=D(m0,x)
+--E 39
+
+)clear all
+
+--S 40 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^7
+--E 40
+
+--S 41 of 1125
+r0:=1/6*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^6)+1/5*(-B*d*(3*c*d-2*b*e)+_
+     A*e*(2*c*d-b*e))/(e^4*(d+e*x)^5)+1/4*(3*B*c*d-b*B*e-A*c*e)/(e^4*_
+     (d+e*x)^4)-1/3*B*c/(e^4*(d+e*x)^3)
+--E 41
+
+--S 42 of 1125
+d0:=D(m0,x)
+--E 42
+
+)clear all
+
+--S 43 of 1125
+t0:=(A+B*x)*(d+e*x)^m*(b*x+c*x^2)^2
+--E 43
+
+--S 44 of 1125
+r0:=-d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^(1+m)/(e^6*(1+m))+d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(2+m)/(e^6*(2+m))+_
+     (A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*(d+e*x)^(3+m)/(e^6*(3+m))-(2*A*c*e*(2*c*d-b*e)-_
+     B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*(d+e*x)^(4+m)/(e^6*(4+m))-_
+     c*(5*B*c*d-2*b*B*e-A*c*e)*(d+e*x)^(5+m)/(e^6*(5+m))+B*c^2*_
+     (d+e*x)^(6+m)/(e^6*(6+m))
+--E 44
+
+--S 45 of 1125
+d0:=normalize(D(m0,x))
+--E 45
+
+)clear all
+
+--S 46 of 1125
+t0:=(A+B*x)*(d+e*x)^4*(b*x+c*x^2)^2
+--E 46
+
+--S 47 of 1125
+r0:=-1/5*d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^5/e^6+1/6*d*(c*d-b*e)*(B*d*_
+     (5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^6/e^6+1/7*(A*e*(6*c^2*d^2-_
+     6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*_
+     (d+e*x)^7/e^6-1/8*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-8*b*c*d*e+_
+     b^2*e^2))*(d+e*x)^8/e^6-1/9*c*(5*B*c*d-2*b*B*e-A*c*e)*_
+     (d+e*x)^9/e^6+1/10*B*c^2*(d+e*x)^10/e^6
+--E 47
+
+--S 48 of 1125
+d0:=D(m0,x)
+--E 48
+
+)clear all
+
+--S 49 of 1125
+t0:=(A+B*x)*(d+e*x)^3*(b*x+c*x^2)^2
+--E 49
+
+--S 50 of 1125
+r0:=1/3*A*b^2*d^3*x^3+1/4*b*d^2*(b*B*d+2*A*c*d+3*A*b*e)*x^4+1/5*d*(A*c^2*_
+     d^2+3*b^2*e*(B*d+A*e)+2*b*c*d*(B*d+3*A*e))*x^5+1/6*(A*e*(3*c^2*d^2+_
+     6*b*c*d*e+b^2*e^2)+B*d*(c^2*d^2+6*b*c*d*e+3*b^2*e^2))*x^6+1/7*e*_
+     (A*c*e*(3*c*d+2*b*e)+B*(3*c^2*d^2+6*b*c*d*e+b^2*e^2))*x^7+_
+     1/8*c*e^2*(3*B*c*d+2*b*B*e+A*c*e)*x^8+1/9*B*c^2*e^3*x^9
+--E 50
+
+--S 51 of 1125
+d0:=D(m0,x)
+--E 51
+
+)clear all
+
+--S 52 of 1125
+t0:=(A+B*x)*(d+e*x)^2*(b*x+c*x^2)^2
+--E 52
+
+--S 53 of 1125
+r0:=1/3*A*b^2*d^2*x^3+1/4*b*d*(b*B*d+2*A*c*d+2*A*b*e)*x^4+1/5*(A*c^2*d^2+_
+     b^2*e*(2*B*d+A*e)+2*b*c*d*(B*d+2*A*e))*x^5+1/6*(2*A*c*e*(c*d+b*e)+_
+     B*(c^2*d^2+4*b*c*d*e+b^2*e^2))*x^6+1/7*c*e*(A*c*e+2*B*(c*d+b*e))*_
+     x^7+1/8*B*c^2*e^2*x^8
+--E 53
+
+--S 54 of 1125
+d0:=D(m0,x)
+--E 54
+
+)clear all
+
+--S 55 of 1125
+t0:=(A+B*x)*(d+e*x)*(b*x+c*x^2)^2
+--E 55
+
+--S 56 of 1125
+r0:=1/3*A*b^2*d*x^3+1/4*b*(b*B*d+2*A*c*d+A*b*e)*x^4+1/5*(A*c^2*d+b^2*B*e+_
+     2*b*c*(B*d+A*e))*x^5+1/6*c*(B*c*d+2*b*B*e+A*c*e)*x^6+1/7*B*c^2*e*x^7
+--E 56
+
+--S 57 of 1125
+d0:=D(m0,x)
+--E 57
+
+)clear all
+
+--S 58 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^2
+--E 58
+
+--S 59 of 1125
+r0:=1/3*A*b^2*x^3+1/4*b*(b*B+2*A*c)*x^4+1/5*c*(2*b*B+A*c)*x^5+1/6*B*c^2*x^6
+--E 59
+
+--S 60 of 1125
+d0:=D(m0,x)
+--E 60
+
+)clear all
+
+--S 61 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)
+--E 61
+
+--S 62 of 1125
+r0:=d*(B*d-A*e)*(c*d-b*e)^2*x/e^5-1/2*(B*d-A*e)*(c*d-b*e)^2*x^2/e^4-_
+     1/3*(A*c*e*(c*d-2*b*e)-B*(c*d-b*e)^2)*x^3/e^3-1/4*c*(B*c*d-2*b*B*e-_
+     A*c*e)*x^4/e^2+1/5*B*c^2*x^5/e-d^2*(B*d-A*e)*(c*d-b*e)^2*log(d+e*x)/e^6
+--E 62
+
+--S 63 of 1125
+d0:=D(m0,x)
+--E 63
+
+)clear all
+
+--S 64 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^2
+--E 64
+
+--S 65 of 1125
+r0:=-(c*d-b*e)*(2*B*d*(2*c*d-b*e)-A*e*(3*c*d-b*e))*x/e^5+1/2*(c*d-b*e)*_
+     (3*B*c*d-b*B*e-2*A*c*e)*x^2/e^4-1/3*c*(2*B*c*d-2*b*B*e-A*c*e)*x^3/e^3+_
+     1/4*B*c^2*x^4/e^2+d^2*(B*d-A*e)*(c*d-b*e)^2/(e^6*(d+e*x))+d*_
+     (c*d-b*e)*(B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*log(d+e*x)/e^6
+--E 65
+
+--S 66 of 1125
+d0:=D(m0,x)
+--E 66
+
+)clear all
+
+--S 67 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^3
+--E 67
+
+--S 68 of 1125
+r0:=-(A*c*e*(3*c*d-2*b*e)-B*(6*c^2*d^2-6*b*c*d*e+b^2*e^2))*x/e^5-1/2*c*_
+     (3*B*c*d-2*b*B*e-A*c*e)*x^2/e^4+1/3*B*c^2*x^3/e^3+1/2*d^2*(B*d-A*e)*_
+     (c*d-b*e)^2/(e^6*(d+e*x)^2)-d*(c*d-b*e)*(B*d*(5*c*d-3*b*e)-2*A*e*_
+     (2*c*d-b*e))/(e^6*(d+e*x))+(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-_
+     B*d*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*log(d+e*x)/e^6
+--E 68
+
+--S 69 of 1125
+d0:=D(m0,x)
+--E 69
+
+)clear all
+
+--S 70 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^4
+--E 70
+
+--S 71 of 1125
+r0:=-c*(4*B*c*d-2*b*B*e-A*c*e)*x/e^5+1/2*B*c^2*x^2/e^4+1/3*d^2*(B*d-A*e)*_
+     (c*d-b*e)^2/(e^6*(d+e*x)^3)-1/2*d*(c*d-b*e)*(B*d*(5*c*d-3*b*e)-_
+     2*A*e*(2*c*d-b*e))/(e^6*(d+e*x)^2)+(-A*e*(6*c^2*d^2-6*b*c*d*e+_
+     b^2*e^2)+B*d*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))/(e^6*(d+e*x))-_
+     (2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*log(d+e*x)/e^6
+--E 71
+
+--S 72 of 1125
+d0:=D(m0,x)
+--E 72
+
+)clear all
+
+--S 73 of 1125
+t0:=(A+B*x)*(d+e*x)^m*(b*x+c*x^2)^3
+--E 73
+
+--S 74 of 1125
+r0:=-d^3*(B*d-A*e)*(c*d-b*e)^3*(d+e*x)^(1+m)/(e^8*(1+m))+d^2*(c*d-b*e)^2*_
+     (B*d*(7*c*d-4*b*e)-3*A*e*(2*c*d-b*e))*(d+e*x)^(2+m)/(e^8*(2+m))+_
+     3*d*(c*d-b*e)*(A*e*(5*c^2*d^2-5*b*c*d*e+b^2*e^2)-B*d*(7*c^2*d^2-_
+     8*b*c*d*e+2*b^2*e^2))*(d+e*x)^(3+m)/(e^8*(3+m))+(B*d*(35*c^3*d^3-_
+     60*b*c^2*d^2*e+30*b^2*c*d*e^2-4*b^3*e^3)-A*e*(20*c^3*d^3-30*b*c^2*_
+     d^2*e+12*b^2*c*d*e^2-b^3*e^3))*(d+e*x)^(4+m)/(e^8*(4+m))+(3*A*c*e*_
+     (5*c^2*d^2-5*b*c*d*e+b^2*e^2)-B*(35*c^3*d^3-45*b*c^2*d^2*e+15*b^2*_
+     c*d*e^2-b^3*e^3))*(d+e*x)^(5+m)/(e^8*(5+m))-3*c*(A*c*e*(2*c*d-b*e)-_
+     B*(7*c^2*d^2-6*b*c*d*e+b^2*e^2))*(d+e*x)^(6+m)/(e^8*(6+m))-c^2*_
+     (7*B*c*d-3*b*B*e-A*c*e)*(d+e*x)^(7+m)/(e^8*(7+m))+B*c^3*_
+     (d+e*x)^(8+m)/(e^8*(8+m))
+--E 74
+
+--S 75 of 1125
+d0:=normalize(D(m0,x))
+--E 75
+
+)clear all
+
+--S 76 of 1125
+t0:=(A+B*x)*(d+e*x)^4*(b*x+c*x^2)^3
+--E 76
+
+--S 77 of 1125
+r0:=1/4*A*b^3*d^4*x^4+1/5*b^2*d^3*(b*B*d+3*A*c*d+4*A*b*e)*x^5+1/6*b*d^2*_
+     (3*A*c^2*d^2+2*b^2*e*(2*B*d+3*A*e)+3*b*c*d*(B*d+4*A*e))*x^6+1/7*d*_
+     (A*c^3*d^3+2*b^3*e^2*(3*B*d+2*A*e)+6*b^2*c*d*e*(2*B*d+3*A*e)+3*b*_
+     c^2*d^2*(B*d+4*A*e))*x^7+1/8*(A*e*(4*c^3*d^3+18*b*c^2*d^2*e+12*_
+     b^2*c*d*e^2+b^3*e^3)+B*d*(c^3*d^3+12*b*c^2*d^2*e+18*b^2*c*d*e^2+4*_
+     b^3*e^3))*x^8+1/9*e*(3*A*c*e*(2*c^2*d^2+4*b*c*d*e+b^2*e^2)+B*_
+     (4*c^3*d^3+18*b*c^2*d^2*e+12*b^2*c*d*e^2+b^3*e^3))*x^9+1/10*c*e^2*_
+     (A*c*e*(4*c*d+3*b*e)+3*B*(2*c^2*d^2+4*b*c*d*e+b^2*e^2))*x^10+1/11*_
+     c^2*e^3*(4*B*c*d+3*b*B*e+A*c*e)*x^11+1/12*B*c^3*e^4*x^12
+--E 77
+
+--S 78 of 1125
+d0:=D(m0,x)
+--E 78
+
+)clear all
+
+--S 79 of 1125
+t0:=(A+B*x)*(d+e*x)^3*(b*x+c*x^2)^3
+--E 79
+
+--S 80 of 1125
+r0:=1/4*A*b^3*d^3*x^4+1/5*b^2*d^2*(b*B*d+3*A*c*d+3*A*b*e)*x^5+1/2*b*d*_
+     (A*c^2*d^2+b^2*e*(B*d+A*e)+b*c*d*(B*d+3*A*e))*x^6+1/7*(A*c^3*d^3+_
+     9*b^2*c*d*e*(B*d+A*e)+b^3*e^2*(3*B*d+A*e)+3*b*c^2*d^2*(B*d+3*A*e))*_
+     x^7+1/8*(3*A*c*e*(c^2*d^2+3*b*c*d*e+b^2*e^2)+B*(c^3*d^3+9*b*c^2*d^2*e+_
+     9*b^2*c*d*e^2+b^3*e^3))*x^8+1/3*c*e*(A*c*e*(c*d+b*e)+B*(c^2*d^2+_
+     3*b*c*d*e+b^2*e^2))*x^9+1/10*c^2*e^2*(A*c*e+3*B*(c*d+b*e))*x^10+_
+     1/11*B*c^3*e^3*x^11
+--E 80
+
+--S 81 of 1125
+d0:=D(m0,x)
+--E 81
+
+)clear all
+
+--S 82 of 1125
+t0:=(A+B*x)*(d+e*x)^2*(b*x+c*x^2)^3
+--E 82
+
+--S 83 of 1125
+r0:=1/4*A*b^3*d^2*x^4+1/5*b^2*d*(b*B*d+3*A*c*d+2*A*b*e)*x^5+1/6*b*_
+     (3*A*c^2*d^2+b^2*e*(2*B*d+A*e)+3*b*c*d*(B*d+2*A*e))*x^6+1/7*_
+     (A*c^3*d^2+b^3*B*e^2+3*b^2*c*e*(2*B*d+A*e)+3*b*c^2*d*(B*d+2*A*e))*x^7+_
+     1/8*c*(A*c*e*(2*c*d+3*b*e)+B*(c^2*d^2+6*b*c*d*e+3*b^2*e^2))*x^8+_
+     1/9*c^2*e*(2*B*c*d+3*b*B*e+A*c*e)*x^9+1/10*B*c^3*e^2*x^10
+--E 83
+
+--S 84 of 1125
+d0:=D(m0,x)
+--E 84
+
+)clear all
+
+--S 85 of 1125
+t0:=(A+B*x)*(d+e*x)*(b*x+c*x^2)^3
+--E 85
+
+--S 86 of 1125
+r0:=1/4*A*b^3*d*x^4+1/5*b^2*(b*B*d+3*A*c*d+A*b*e)*x^5+1/6*b*(3*A*c^2*d+_
+     b^2*B*e+3*b*c*(B*d+A*e))*x^6+1/7*c*(A*c^2*d+3*b^2*B*e+3*b*c*(B*d+_
+     A*e))*x^7+1/8*c^2*(B*c*d+3*b*B*e+A*c*e)*x^8+1/9*B*c^3*e*x^9
+--E 86
+
+--S 87 of 1125
+d0:=D(m0,x)
+--E 87
+
+)clear all
+
+--S 88 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^3
+--E 88
+
+--S 89 of 1125
+r0:=1/4*A*b^3*x^4+1/5*b^2*(b*B+3*A*c)*x^5+1/2*b*c*(b*B+A*c)*x^6+_
+     1/7*c^2*(3*b*B+A*c)*x^7+1/8*B*c^3*x^8
+--E 89
+
+--S 90 of 1125
+d0:=D(m0,x)
+--E 90
+
+)clear all
+
+--S 91 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^3/(d+e*x)
+--E 91
+
+--S 92 of 1125
+r0:=d^2*(B*d-A*e)*(c*d-b*e)^3*x/e^7-1/2*d*(B*d-A*e)*(c*d-b*e)^3*x^2/e^6+_
+     1/3*(B*d-A*e)*(c*d-b*e)^3*x^3/e^5-1/4*(B*(c*d-b*e)^3-A*c*e*(c^2*d^2-_
+     3*b*c*d*e+3*b^2*e^2))*x^4/e^4-1/5*c*(A*c*e*(c*d-3*b*e)-B*(c^2*d^2-_
+     3*b*c*d*e+3*b^2*e^2))*x^5/e^3-1/6*c^2*(B*c*d-3*b*B*e-A*c*e)*x^6/e^2+_
+     1/7*B*c^3*x^7/e-d^3*(B*d-A*e)*(c*d-b*e)^3*log(d+e*x)/e^8
+--E 92
+
+--S 93 of 1125
+d0:=D(m0,x)
+--E 93
+
+)clear all
+
+--S 94 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^3/(d+e*x)^2
+--E 94
+
+--S 95 of 1125
+r0:=d*(c*d-b*e)^2*(A*e*(5*c*d-2*b*e)-3*B*d*(2*c*d-b*e))*x/e^7+_
+     1/2*(c*d-b*e)^2*(B*d*(5*c*d-2*b*e)-A*e*(4*c*d-b*e))*x^2/e^6-_
+     1/3*(c*d-b*e)^2*(4*B*c*d-b*B*e-3*A*c*e)*x^3/e^5-1/4*c*(A*c*e*_
+     (2*c*d-3*b*e)-3*B*(c*d-b*e)^2)*x^4/e^4-1/5*c^2*(2*B*c*d-3*b*B*e-_
+     A*c*e)*x^5/e^3+1/6*B*c^3*x^6/e^2+d^3*(B*d-A*e)*(c*d-b*e)^3/(e^8*_
+     (d+e*x))+d^2*(c*d-b*e)^2*(B*d*(7*c*d-4*b*e)-3*A*e*(2*c*d-b*e))*_
+     log(d+e*x)/e^8
+--E 95
+
+--S 96 of 1125
+d0:=D(m0,x)
+--E 96
+
+)clear all
+
+--S 97 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^3/(d+e*x)^3
+--E 97
+
+--S 98 of 1125
+r0:=-(c*d-b*e)*(A*e*(10*c^2*d^2-8*b*c*d*e+b^2*e^2)-3*B*d*(5*c^2*d^2-_
+     5*b*c*d*e+b^2*e^2))*x/e^7+1/2*(c*d-b*e)*(3*A*c*e*(2*c*d-b*e)-_
+     B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*x^2/e^6+c*(c*d-b*e)*(2*B*c*d-b*B*e-_
+     A*c*e)*x^3/e^5-1/4*c^2*(3*B*c*d-3*b*B*e-A*c*e)*x^4/e^4+1/5*B*c^3*_
+     x^5/e^3+1/2*d^3*(B*d-A*e)*(c*d-b*e)^3/(e^8*(d+e*x)^2)-d^2*_
+     (c*d-b*e)^2*(B*d*(7*c*d-4*b*e)-3*A*e*(2*c*d-b*e))/(e^8*(d+e*x))+_
+     3*d*(c*d-b*e)*(A*e*(5*c^2*d^2-5*b*c*d*e+b^2*e^2)-B*d*(7*c^2*d^2-_
+     8*b*c*d*e+2*b^2*e^2))*log(d+e*x)/e^8
+--E 98
+
+--S 99 of 1125
+d0:=D(m0,x)
+--E 99
+
+)clear all
+
+--S 100 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^3/(d+e*x)^4
+--E 100
+
+--S 101 of 1125
+r0:=(A*c*e*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2)-B*(20*c^3*d^3-30*b*c^2*d^2*e+_
+     12*b^2*c*d*e^2-b^3*e^3))*x/e^7-1/2*c*(A*c*e*(4*c*d-3*b*e)-_
+     B*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*x^2/e^6-1/3*c^2*(4*B*c*d-_
+     3*b*B*e-A*c*e)*x^3/e^5+1/4*B*c^3*x^4/e^4+1/3*d^3*(B*d-A*e)*_
+     (c*d-b*e)^3/(e^8*(d+e*x)^3)-1/2*d^2*(c*d-b*e)^2*(B*d*(7*c*d-4*b*e)-_
+     3*A*e*(2*c*d-b*e))/(e^8*(d+e*x)^2)-3*d*(c*d-b*e)*(A*e*(5*c^2*d^2-_
+     5*b*c*d*e+b^2*e^2)-B*d*(7*c^2*d^2-8*b*c*d*e+2*b^2*e^2))/(e^8*_
+     (d+e*x))+(B*d*(35*c^3*d^3-60*b*c^2*d^2*e+30*b^2*c*d*e^2-4*b^3*e^3)-_
+     A*e*(20*c^3*d^3-30*b*c^2*d^2*e+12*b^2*c*d*e^2-b^3*e^3))*log(d+e*x)/e^8
+--E 101
+
+--S 102 of 1125
+d0:=D(m0,x)
+--E 102
+
+)clear all
+
+--S 103 of 1125
+t0:=(A+B*x)*(d+e*x)^4/(b*x+c*x^2)
+--E 103
+
+--S 104 of 1125
+r0:=e*(A*c*e*(6*c^2*d^2-4*b*c*d*e+b^2*e^2)+B*(4*c^3*d^3-6*b*c^2*d^2*e+_
+     4*b^2*c*d*e^2-b^3*e^3))*x/c^4+1/2*e^2*(A*c*e*(4*c*d-b*e)+B*_
+     (6*c^2*d^2-4*b*c*d*e+b^2*e^2))*x^2/c^3+1/3*e^3*(4*B*c*d-b*B*e+_
+     A*c*e)*x^3/c^2+1/4*B*e^4*x^4/c+A*d^4*log(x)/b+(b*B-A*c)*_
+     (c*d-b*e)^4*log(b+c*x)/(b*c^5)
+--E 104
+
+--S 105 of 1125
+d0:=D(m0,x)
+--E 105
+
+)clear all
+
+--S 106 of 1125
+t0:=(A+B*x)*(d+e*x)^3/(b*x+c*x^2)
+--E 106
+
+--S 107 of 1125
+r0:=e*(A*c*e*(3*c*d-b*e)+B*(3*c^2*d^2-3*b*c*d*e+b^2*e^2))*x/c^3+_
+     1/2*e^2*(3*B*c*d-b*B*e+A*c*e)*x^2/c^2+1/3*B*e^3*x^3/c+A*d^3*_
+     log(x)/b+(b*B-A*c)*(c*d-b*e)^3*log(b+c*x)/(b*c^4)
+--E 107
+
+--S 108 of 1125
+d0:=D(m0,x)
+--E 108
+
+)clear all
+
+--S 109 of 1125
+t0:=(A+B*x)*(d+e*x)^2/(b*x+c*x^2)
+--E 109
+
+--S 110 of 1125
+r0:=e*(2*B*c*d-b*B*e+A*c*e)*x/c^2+1/2*B*e^2*x^2/c+A*d^2*log(x)/b+_
+     (b*B-A*c)*(c*d-b*e)^2*log(b+c*x)/(b*c^3)
+--E 110
+
+--S 111 of 1125
+d0:=D(m0,x)
+--E 111
+
+)clear all
+
+--S 112 of 1125
+t0:=(A+B*x)*(d+e*x)/(b*x+c*x^2)
+--E 112
+
+--S 113 of 1125
+r0:=B*e*x/c+A*d*log(x)/b+(b*B-A*c)*(c*d-b*e)*log(b+c*x)/(b*c^2)
+--E 113
+
+--S 114 of 1125
+d0:=D(m0,x)
+--E 114
+
+)clear all
+
+--S 115 of 1125
+t0:=(A+B*x)/(b*x+c*x^2)
+--E 115
+
+--S 116 of 1125
+r0:=A*log(x)/b+(b*B-A*c)*log(b+c*x)/(b*c)
+--E 116
+
+--S 117 of 1125
+d0:=D(m0,x)
+--E 117
+
+)clear all
+
+--S 118 of 1125
+t0:=(A+B*x)/((d+e*x)*(b*x+c*x^2))
+--E 118
+
+--S 119 of 1125
+r0:=A*log(x)/(b*d)+(b*B-A*c)*log(b+c*x)/(b*(c*d-b*e))-_
+     (B*d-A*e)*log(d+e*x)/(d*(c*d-b*e))
+--E 119
+
+--S 120 of 1125
+d0:=D(m0,x)
+--E 120
+
+)clear all
+
+--S 121 of 1125
+t0:=(A+B*x)/((d+e*x)^2*(b*x+c*x^2))
+--E 121
+
+--S 122 of 1125
+r0:=(B*d-A*e)/(d*(c*d-b*e)*(d+e*x))+A*log(x)/(b*d^2)+c*(b*B-A*c)*_
+     log(b+c*x)/(b*(c*d-b*e)^2)-(B*c*d^2-A*e*(2*c*d-b*e))*log(d+e*x)/_
+     (d^2*(c*d-b*e)^2)
+--E 122
+
+--S 123 of 1125
+d0:=D(m0,x)
+--E 123
+
+)clear all
+
+--S 124 of 1125
+t0:=(A+B*x)/((d+e*x)^3*(b*x+c*x^2))
+--E 124
+
+--S 125 of 1125
+r0:=1/2*(B*d-A*e)/(d*(c*d-b*e)*(d+e*x)^2)+(B*c*d^2-A*e*(2*c*d-b*e))/_
+     (d^2*(c*d-b*e)^2*(d+e*x))+A*log(x)/(b*d^3)+c^2*(b*B-A*c)*_
+     log(b+c*x)/(b*(c*d-b*e)^3)-(B*c^2*d^3-A*e*(3*c^2*d^2-3*b*c*d*e+_
+     b^2*e^2))*log(d+e*x)/(d^3*(c*d-b*e)^3)
+--E 125
+
+--S 126 of 1125
+d0:=D(m0,x)
+--E 126
+
+)clear all
+
+--S 127 of 1125
+t0:=(A+B*x)/((d+e*x)^4*(b*x+c*x^2))
+--E 127
+
+--S 128 of 1125
+r0:=1/3*(B*d-A*e)/(d*(c*d-b*e)*(d+e*x)^3)+1/2*(B*c*d^2-A*e*(2*c*d-b*e))/_
+     (d^2*(c*d-b*e)^2*(d+e*x)^2)+(B*c^2*d^3-A*e*(3*c^2*d^2-3*b*c*d*e+_
+     b^2*e^2))/(d^3*(c*d-b*e)^3*(d+e*x))+A*log(x)/(b*d^4)+c^3*(b*B-A*c)*_
+     log(b+c*x)/(b*(c*d-b*e)^4)-(B*c^3*d^4-A*e*(4*c^3*d^3-_
+     6*b*c^2*d^2*e+4*b^2*c*d*e^2-b^3*e^3))*log(d+e*x)/(d^4*(c*d-b*e)^4)
+--E 128
+
+--S 129 of 1125
+d0:=D(m0,x)
+--E 129
+
+)clear all
+
+--S 130 of 1125
+t0:=(A+B*x)*(d+e*x)^4/(b*x+c*x^2)^2
+--E 130
+
+--S 131 of 1125
+r0:=-A*d^4/(b^2*x)+e^3*(4*B*c*d-2*b*B*e+A*c*e)*x/c^3+1/2*B*e^4*x^2/c^2+_
+     (b*B-A*c)*(c*d-b*e)^4/(b^2*c^4*(b+c*x))+d^3*(b*B*d-2*A*c*d+_
+     4*A*b*e)*log(x)/b^3+(c*d-b*e)^3*(2*A*c^2*d-3*b^2*B*e-b*c*(B*d-_
+     2*A*e))*log(b+c*x)/(b^3*c^4)
+--E 131
+
+--S 132 of 1125
+d0:=D(m0,x)
+--E 132
+
+)clear all
+
+--S 133 of 1125
+t0:=(A+B*x)*(d+e*x)^3/(b*x+c*x^2)^2
+--E 133
+
+--S 134 of 1125
+r0:=-A*d^3/(b^2*x)+B*e^3*x/c^2+(b*B-A*c)*(c*d-b*e)^3/(b^2*c^3*(b+c*x))+_
+     d^2*(b*B*d-2*A*c*d+3*A*b*e)*log(x)/b^3-(c*d-b*e)^2*(b*B*c*d-_
+     2*A*c^2*d+2*b^2*B*e-A*b*c*e)*log(b+c*x)/(b^3*c^3)
+--E 134
+
+--S 135 of 1125
+d0:=D(m0,x)
+--E 135
+
+)clear all
+
+--S 136 of 1125
+t0:=(A+B*x)*(d+e*x)^2/(b*x+c*x^2)^2
+--E 136
+
+--S 137 of 1125
+r0:=-A*d^2/(b^2*x)+(b*B-A*c)*(c*d-b*e)^2/(b^2*c^2*(b+c*x))+d*_
+     (b*B*d-2*A*c*d+2*A*b*e)*log(x)/b^3-(c*d-b*e)*(b*B*c*d-2*A*c^2*d+_
+     b^2*B*e)*log(b+c*x)/(b^3*c^2)
+--E 137
+
+--S 138 of 1125
+d0:=D(m0,x)
+--E 138
+
+)clear all
+
+--S 139 of 1125
+t0:=(A+B*x)*(d+e*x)/(b*x+c*x^2)^2
+--E 139
+
+--S 140 of 1125
+r0:=-A*d/(b^2*x)+(b*B-A*c)*(c*d-b*e)/(b^2*c*(b+c*x))+(b*B*d-2*A*c*d+A*b*e)*_
+     log(x)/b^3-(b*B*d-2*A*c*d+A*b*e)*log(b+c*x)/b^3
+--E 140
+
+--S 141 of 1125
+d0:=D(m0,x)
+--E 141
+
+)clear all
+
+--S 142 of 1125
+t0:=(A+B*x)/(b*x+c*x^2)^2
+--E 142
+
+--S 143 of 1125
+r0:=-A/(b^2*x)+(b*B-A*c)/(b^2*(b+c*x))+(b*B-2*A*c)*log(x)/b^3-(b*B-2*A*c)*_
+     log(b+c*x)/b^3
+--E 143
+
+--S 144 of 1125
+d0:=D(m0,x)
+--E 144
+
+)clear all
+
+--S 145 of 1125
+t0:=(A+B*x)/((d+e*x)*(b*x+c*x^2)^2)
+--E 145
+
+--S 146 of 1125
+r0:=-A/(b^2*d*x)+c*(b*B-A*c)/(b^2*(c*d-b*e)*(b+c*x))+(b*B*d-2*A*c*d-A*b*e)*_
+     log(x)/(b^3*d^2)+c*(2*A*c^2*d+2*b^2*B*e-b*c*(B*d+3*A*e))*log(b+c*x)/_
+     (b^3*(c*d-b*e)^2)-e^2*(B*d-A*e)*log(d+e*x)/(d^2*(c*d-b*e)^2)
+--E 146
+
+--S 147 of 1125
+d0:=D(m0,x)
+--E 147
+
+)clear all
+
+--S 148 of 1125
+t0:=(A+B*x)/((d+e*x)^2*(b*x+c*x^2)^2)
+--E 148
+
+--S 149 of 1125
+r0:=-A/(b^2*d^2*x)+c^2*(b*B-A*c)/(b^2*(c*d-b*e)^2*(b+c*x))+e^2*(B*d-A*e)/_
+     (d^2*(c*d-b*e)^2*(d+e*x))+(b*B*d-2*A*c*d-2*A*b*e)*log(x)/(b^3*d^3)+_
+     c^2*(2*A*c^2*d+3*b^2*B*e-b*c*(B*d+4*A*e))*log(b+c*x)/(b^3*_
+     (c*d-b*e)^3)+e^2*(2*A*e*(2*c*d-b*e)-B*d*(3*c*d-b*e))*log(d+e*x)/_
+     (d^3*(c*d-b*e)^3)
+--E 149
+
+--S 150 of 1125
+d0:=D(m0,x)
+--E 150
+
+)clear all
+
+--S 151 of 1125
+t0:=(A+B*x)/((d+e*x)^3*(b*x+c*x^2)^2)
+--E 151
+
+--S 152 of 1125
+r0:=-A/(b^2*d^3*x)+c^3*(b*B-A*c)/(b^2*(c*d-b*e)^3*(b+c*x))+1/2*e^2*_
+     (B*d-A*e)/(d^2*(c*d-b*e)^2*(d+e*x)^2)-e^2*(2*A*e*(2*c*d-b*e)-B*d*_
+     (3*c*d-b*e))/(d^3*(c*d-b*e)^3*(d+e*x))+(b*B*d-2*A*c*d-3*A*b*e)*_
+     log(x)/(b^3*d^4)+c^3*(2*A*c^2*d+4*b^2*B*e-b*c*(B*d+5*A*e))*log(b+_
+     c*x)/(b^3*(c*d-b*e)^4)-e^2*(B*d*(6*c^2*d^2-4*b*c*d*e+b^2*e^2)-_
+     A*e*(10*c^2*d^2-10*b*c*d*e+3*b^2*e^2))*log(d+e*x)/(d^4*(c*d-b*e)^4)
+--E 152
+
+--S 153 of 1125
+d0:=D(m0,x)
+--E 153
+
+)clear all
+
+--S 154 of 1125
+t0:=(A+B*x)*(d+e*x)^5/(b*x+c*x^2)^3
+--E 154
+
+--S 155 of 1125
+r0:=-1/2*A*d^5/(b^3*x^2)-d^4*(b*B*d-3*A*c*d+5*A*b*e)/(b^4*x)+B*e^5*x/c^3-_
+     1/2*(b*B-A*c)*(c*d-b*e)^5/(b^3*c^4*(b+c*x)^2)-(c*d-b*e)^4*(2*b*B*c*d-_
+     3*A*c^2*d+3*b^2*B*e-2*A*b*c*e)/(b^4*c^4*(b+c*x))+d^3*(6*A*c^2*d^2+_
+     5*b^2*e*(B*d+2*A*e)-3*b*c*d*(B*d+5*A*e))*log(x)/b^5-(c*d-b*e)^3*_
+     (6*A*c^3*d^2-3*b^3*B*e^2-3*b*c^2*d*(B*d-A*e)-b^2*c*e*(4*B*d-A*e))*_
+     log(b+c*x)/(b^5*c^4)
+--E 155
+
+--S 156 of 1125
+d0:=D(m0,x)
+--E 156
+
+)clear all
+
+--S 157 of 1125
+t0:=(A+B*x)*(d+e*x)^4/(b*x+c*x^2)^3
+--E 157
+
+--S 158 of 1125
+r0:=-1/2*A*d^4/(b^3*x^2)-d^3*(b*B*d-3*A*c*d+4*A*b*e)/(b^4*x)-1/2*(b*B-_
+     A*c)*(c*d-b*e)^4/(b^3*c^3*(b+c*x)^2)+(c*d-b*e)^3*(3*A*c^2*d-2*b^2*_
+     B*e-b*c*(2*B*d-A*e))/(b^4*c^3*(b+c*x))+d^2*(6*A*c^2*d^2+2*b^2*e*_
+     (2*B*d+3*A*e)-3*b*c*d*(B*d+4*A*e))*log(x)/b^5+(c*d-b*e)^2*(3*b*B*_
+     c^2*d^2-6*A*c^3*d^2+2*b^2*B*c*d*e+b^3*B*e^2)*log(b+c*x)/(b^5*c^3)
+--E 158
+
+--S 159 of 1125
+d0:=D(m0,x)
+--E 159
+
+)clear all
+
+--S 160 of 1125
+t0:=(A+B*x)*(d+e*x)^3/(b*x+c*x^2)^3
+--E 160
+
+--S 161 of 1125
+r0:=-1/2*A*d^3/(b^3*x^2)-d^2*(b*B*d-3*A*c*d+3*A*b*e)/(b^4*x)-1/2*(b*B-A*c)*_
+     (c*d-b*e)^3/(b^3*c^2*(b+c*x)^2)-(c*d-b*e)^2*(2*b*B*c*d-3*A*c^2*d+_
+     b^2*B*e)/(b^4*c^2*(b+c*x))-3*d*(c*d-b*e)*(b*B*d-2*A*c*d+A*b*e)*_
+     log(x)/b^5+3*d*(c*d-b*e)*(b*B*d-2*A*c*d+A*b*e)*log(b+c*x)/b^5
+--E 161
+
+--S 162 of 1125
+d0:=D(m0,x)
+--E 162
+
+)clear all
+
+--S 163 of 1125
+t0:=(A+B*x)*(d+e*x)^2/(b*x+c*x^2)^3
+--E 163
+
+--S 164 of 1125
+r0:=-1/2*A*d^2/(b^3*x^2)-d*(b*B*d-3*A*c*d+2*A*b*e)/(b^4*x)-1/2*(b*B-A*c)*_
+     (c*d-b*e)^2/(b^3*c*(b+c*x)^2)-(c*d-b*e)*(2*b*B*d-3*A*c*d+A*b*e)/_
+     (b^4*(b+c*x))+(6*A*c^2*d^2+b^2*e*(2*B*d+A*e)-3*b*c*d*(B*d+2*A*e))*_
+     log(x)/b^5-(6*A*c^2*d^2+b^2*e*(2*B*d+A*e)-3*b*c*d*(B*d+2*A*e))*_
+     log(b+c*x)/b^5
+--E 164
+
+--S 165 of 1125
+d0:=D(m0,x)
+--E 165
+
+)clear all
+
+--S 166 of 1125
+t0:=(A+B*x)*(d+e*x)/(b*x+c*x^2)^3
+--E 166
+
+--S 167 of 1125
+r0:=-1/2*A*d/(b^3*x^2)+(-b*B*d+3*A*c*d-A*b*e)/(b^4*x)-1/2*(b*B-A*c)*_
+     (c*d-b*e)/(b^3*(b+c*x)^2)+(3*A*c^2*d+b^2*B*e-2*b*c*(B*d+A*e))/_
+     (b^4*(b+c*x))+(6*A*c^2*d+b^2*B*e-3*b*c*(B*d+A*e))*log(x)/b^5-_
+     (6*A*c^2*d+b^2*B*e-3*b*c*(B*d+A*e))*log(b+c*x)/b^5
+--E 167
+
+--S 168 of 1125
+d0:=D(m0,x)
+--E 168
+
+)clear all
+
+--S 169 of 1125
+t0:=(A+B*x)/(b*x+c*x^2)^3
+--E 169
+
+--S 170 of 1125
+r0:=-1/2*A/(b^3*x^2)+(-b*B+3*A*c)/(b^4*x)-1/2*c*(b*B-A*c)/(b^3*(b+c*x)^2)-_
+     c*(2*b*B-3*A*c)/(b^4*(b+c*x))-3*c*(b*B-2*A*c)*log(x)/b^5+3*c*(b*B-_
+     2*A*c)*log(b+c*x)/b^5
+--E 170
+
+--S 171 of 1125
+d0:=D(m0,x)
+--E 171
+
+)clear all
+
+--S 172 of 1125
+t0:=(A+B*x)/((d+e*x)*(b*x+c*x^2)^3)
+--E 172
+
+--S 173 of 1125
+r0:=-1/2*A/(b^3*d*x^2)+(-b*B*d+3*A*c*d+A*b*e)/(b^4*d^2*x)-1/2*c^2*(b*B-_
+     A*c)/(b^3*(c*d-b*e)*(b+c*x)^2)+c^2*(3*A*c^2*d+3*b^2*B*e-2*b*c*(B*d+_
+     2*A*e))/(b^4*(c*d-b*e)^2*(b+c*x))+(6*A*c^2*d^2-3*b*c*d*(B*d-A*e)-_
+     b^2*e*(B*d-A*e))*log(x)/(b^5*d^3)-c^2*(6*A*c^3*d^2-6*b^3*B*e^2-_
+     3*b*c^2*d*(B*d+5*A*e)+2*b^2*c*e*(4*B*d+5*A*e))*log(b+c*x)/(b^5*(c*d-_
+     b*e)^3)-e^4*(B*d-A*e)*log(d+e*x)/(d^3*(c*d-b*e)^3)
+--E 173
+
+--S 174 of 1125
+d0:=D(m0,x)
+--E 174
+
+)clear all
+
+--S 175 of 1125
+t0:=(A+B*x)/((d+e*x)^2*(b*x+c*x^2)^3)
+--E 175
+
+--S 176 of 1125
+r0:=-1/2*A/(b^3*d^2*x^2)+(-b*B*d+3*A*c*d+2*A*b*e)/(b^4*d^3*x)-1/2*c^3*(b*B-_
+     A*c)/(b^3*(c*d-b*e)^2*(b+c*x)^2)-c^3*(2*b*B*c*d-3*A*c^2*d-4*b^2*B*e+_
+     5*A*b*c*e)/(b^4*(c*d-b*e)^3*(b+c*x))+e^4*(B*d-A*e)/(d^3*(c*d-b*e)^3*_
+     (d+e*x))+(6*A*c^2*d^2-b^2*e*(2*B*d-3*A*e)-3*b*c*d*(B*d-2*A*e))*_
+     log(x)/(b^5*d^4)-c^3*(6*A*c^3*d^2-10*b^3*B*e^2+5*b^2*c*e*(2*B*d+_
+     3*A*e)-3*b*c^2*d*(B*d+6*A*e))*log(b+c*x)/(b^5*(c*d-b*e)^4)-e^4*_
+     (B*d*(5*c*d-2*b*e)-3*A*e*(2*c*d-b*e))*log(d+e*x)/(d^4*(c*d-b*e)^4)
+--E 176
+
+--S 177 of 1125
+d0:=D(m0,x)
+--E 177
+
+)clear all
+
+--S 178 of 1125
+t0:=(A+B*x)*(d+e*x)^3*sqrt(b*x+c*x^2)
+--E 178
+
+--S 179 of 1125
+r0:=1/960*(4*A*c*e*(132*c^2*d^2-132*b*c*d*e+35*b^2*e^2)+B*(64*c^3*d^3-_
+     360*b*c^2*d^2*e+366*b^2*c*d*e^2-105*b^3*e^3))*(b*x+c*x^2)^(3/2)/c^4+_
+     1/20*(2*B*c*d-3*b*B*e+4*A*c*e)*(d+e*x)^2*(b*x+c*x^2)^(3/2)/c^2+_
+     1/6*B*(d+e*x)^3*(b*x+c*x^2)^(3/2)/c-1/160*e*(d*(16*b*B*c*d-40*A*c^2*d-_
+     9*b^2*B*e+12*A*b*c*e)-(28*A*c*e*(2*c*d-b*e)+B*(8*c^2*d^2-36*b*c*d*e+_
+     21*b^2*e^2))*x)*(b*x+c*x^2)^(3/2)/c^3-1/512*b^2*(128*A*c^4*d^3+_
+     21*b^4*B*e^3+120*b^2*c^2*d*e*(B*d+A*e)-28*b^3*c*e^2*(3*B*d+A*e)-_
+     64*b*c^3*d^2*(B*d+3*A*e))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(11/2)+_
+     1/512*b*(128*A*c^4*d^3+21*b^4*B*e^3+120*b^2*c^2*d*e*(B*d+A*e)-_
+     28*b^3*c*e^2*(3*B*d+A*e)-64*b*c^3*d^2*(B*d+3*A*e))*sqrt(b*x+c*x^2)/c^5+_
+     1/256*(128*A*c^4*d^3+21*b^4*B*e^3+120*b^2*c^2*d*e*(B*d+A*e)-_
+     28*b^3*c*e^2*(3*B*d+A*e)-64*b*c^3*d^2*(B*d+3*A*e))*x*sqrt(b*x+c*x^2)/c^4
+--E 179
+
+--S 180 of 1125
+d0:=D(m0,x)
+--E 180
+
+)clear all
+
+--S 181 of 1125
+t0:=(A+B*x)*(d+e*x)^2*sqrt(b*x+c*x^2)
+--E 181
+
+--S 182 of 1125
+r0:=1/240*(50*A*c*e*(2*c*d-b*e)+B*(32*c^2*d^2-82*b*c*d*e+35*b^2*e^2))*_
+     (b*x+c*x^2)^(3/2)/c^3+1/5*B*(d+e*x)^2*(b*x+c*x^2)^(3/2)/c-1/40*e*_
+     ((3*b*B-10*A*c)*d-(4*B*c*d-7*b*B*e+10*A*c*e)*x)*(b*x+c*x^2)^(3/2)/c^2-_
+     1/128*b^2*(32*A*c^3*d^2-7*b^3*B*e^2+10*b^2*c*e*(2*B*d+A*e)-_
+     16*b*c^2*d*(B*d+2*A*e))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(9/2)+_
+     1/128*b*(32*A*c^3*d^2-7*b^3*B*e^2+10*b^2*c*e*(2*B*d+A*e)-16*b*c^2*_
+     d*(B*d+2*A*e))*sqrt(b*x+c*x^2)/c^4+1/64*(32*A*c^3*d^2-7*b^3*B*e^2+_
+     10*b^2*c*e*(2*B*d+A*e)-16*b*c^2*d*(B*d+2*A*e))*x*sqrt(b*x+c*x^2)/c^3
+--E 182
+
+--S 183 of 1125
+d0:=D(m0,x)
+--E 183
+
+)clear all
+
+--S 184 of 1125
+t0:=(A+B*x)*(d+e*x)*sqrt(b*x+c*x^2)
+--E 184
+
+--S 185 of 1125
+r0:=1/24*(2*B*c*d-5*b*B*e+8*A*c*e)*(b*x+c*x^2)^(3/2)/c^2+1/4*B*(d+e*x)*_
+     (b*x+c*x^2)^(3/2)/c-1/64*b^2*(16*A*c^2*d+5*b^2*B*e-8*b*c*(B*d+A*e))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(7/2)+1/64*b*(16*A*c^2*d+5*b^2*B*e-_
+     8*b*c*(B*d+A*e))*sqrt(b*x+c*x^2)/c^3+1/32*(16*A*c^2*d+5*b^2*B*e-_
+     8*b*c*(B*d+A*e))*x*sqrt(b*x+c*x^2)/c^2
+--E 185
+
+--S 186 of 1125
+d0:=D(m0,x)
+--E 186
+
+)clear all
+
+--S 187 of 1125
+t0:=(A+B*x)*sqrt(b*x+c*x^2)
+--E 187
+
+--S 188 of 1125
+r0:=1/3*B*(b*x+c*x^2)^(3/2)/c+1/8*b^2*(b*B-2*A*c)*atanh(x*sqrt(c)/_
+     sqrt(b*x+c*x^2))/c^(5/2)-1/8*b*(b*B-2*A*c)*sqrt(b*x+c*x^2)/c^2-_
+     1/4*(b*B-2*A*c)*x*sqrt(b*x+c*x^2)/c
+--E 188
+
+--S 189 of 1125
+d0:=D(m0,x)
+--E 189
+
+)clear all
+
+--S 190 of 1125
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)
+--E 190
+
+--S 191 of 1125
+r0:=-1/4*(4*A*c*e*(2*c*d-b*e)-B*(8*c^2*d^2-4*b*c*d*e-b^2*e^2))*atanh(x*_
+     sqrt(c)/sqrt(b*x+c*x^2))/(c^(3/2)*e^3)-(B*d-A*e)*atanh(1/2*(b*d+_
+     (2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))*sqrt(d)*_
+     sqrt(c*d-b*e)/e^3-1/4*(4*B*c*d-b*B*e-4*A*c*e-2*B*c*e*x)*sqrt(b*x+_
+     c*x^2)/(c*e^2)
+--E 191
+
+--S 192 of 1125
+d0:=D(m0,x)
+--E 192
+
+)clear all
+
+--S 193 of 1125
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^2
+--E 193
+
+--S 194 of 1125
+r0:=-(4*B*c*d-b*B*e-2*A*c*e)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(e^3*sqrt(c))+_
+     1/2*(B*d*(4*c*d-3*b*e)-A*e*(2*c*d-b*e))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(e^3*sqrt(d)*sqrt(c*d-b*e))+_
+     (2*B*d-A*e+B*e*x)*sqrt(b*x+c*x^2)/(e^2*(d+e*x))
+--E 194
+
+--S 195 of 1125
+d0:=D(m0,x)
+--E 195
+
+)clear all
+
+--S 196 of 1125
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^3
+--E 196
+
+--S 197 of 1125
+r0:=1/2*(B*d-A*e)*(b*x+c*x^2)^(3/2)/(d*(c*d-b*e)*(d+e*x)^2)-1/8*(A*b^2*e^3+_
+     B*d*(8*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(3/2)*e^3*(c*d-b*e)^(3/2))+_
+     2*B*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))*sqrt(c)/e^3+1/4*(A*b*e^2-B*d*_
+     (4*c*d-3*b*e)-2*c*e*(B*d-A*e)*x)*sqrt(b*x+c*x^2)/(d*e^2*(c*d-b*e)*(d+e*x))
+--E 197
+
+--S 198 of 1125
+d0:=D(m0,x)
+--E 198
+
+)clear all
+
+--S 199 of 1125
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^4
+--E 199
+
+--S 200 of 1125
+r0:=1/16*b^2*(b*B*d-2*A*c*d+A*b*e)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(5/2)*(c*d-b*e)^(5/2))+1/12*(B*_
+     d*(4*c*d-5*b*e)+A*e*(2*c*d-b*e))*sqrt(b*x+c*x^2)/(d*e^2*(c*d-b*e)*_
+     (d+e*x)^2)+1/24*(B*d*(8*c^2*d^2-14*b*c*d*e+3*b^2*e^2)+A*e*(4*c^2*_
+     d^2-4*b*c*d*e+3*b^2*e^2))*sqrt(b*x+c*x^2)/(d^2*e^2*(c*d-b*e)^2*_
+     (d+e*x))-1/3*(2*B*d+A*e+3*B*e*x)*sqrt(b*x+c*x^2)/(e^2*(d+e*x)^3)
+--E 200
+
+--S 201 of 1125
+d0:=D(m0,x)
+--E 201
+
+)clear all
+
+--S 202 of 1125
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^5
+--E 202
+
+--S 203 of 1125
+r0:=-1/128*b^2*(16*A*c^2*d^2-8*b*c*d*(B*d+2*A*e)+b^2*e*(3*B*d+5*A*e))*_
+     atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+_
+     c*x^2)))/(d^(7/2)*(c*d-b*e)^(7/2))+1/24*(B*d*(2*c*d-3*b*e)+A*e*(2*c*d-_
+     b*e))*sqrt(b*x+c*x^2)/(d*e^2*(c*d-b*e)*(d+e*x)^3)+1/96*(B*d*_
+     (8*c^2*d^2-16*b*c*d*e+3*b^2*e^2)+A*e*(8*c^2*d^2-8*b*c*d*e+_
+     5*b^2*e^2))*sqrt(b*x+c*x^2)/(d^2*e^2*(c*d-b*e)^2*(d+e*x)^2)+_
+     1/192*(A*e*(16*c^3*d^3-24*b*c^2*d^2*e+38*b^2*c*d*e^2-15*b^3*e^3)+_
+     B*d*(16*c^3*d^3-40*b*c^2*d^2*e+18*b^2*c*d*e^2-9*b^3*e^3))*_
+     sqrt(b*x+c*x^2)/(d^3*e^2*(c*d-b*e)^3*(d+e*x))-1/4*(B*d+A*e+_
+     2*B*e*x)*sqrt(b*x+c*x^2)/(e^2*(d+e*x)^4)
+--E 203
+
+--S 204 of 1125
+d0:=D(m0,x)
+--E 204
+
+)clear all
+
+--S 205 of 1125
+t0:=(A+B*x)*(d+e*x)^2*(b*x+c*x^2)^(3/2)
+--E 205
+
+--S 206 of 1125
+r0:=1/192*(48*A*c^3*d^2-9*b^3*B*e^2+14*b^2*c*e*(2*B*d+A*e)-24*b*c^2*d*(B*d+_
+     2*A*e))*x*(b*x+c*x^2)^(3/2)/c^3+1/840*(98*A*c*e*(2*c*d-b*e)+B*(48*_
+     c^2*d^2-146*b*c*d*e+63*b^2*e^2))*(b*x+c*x^2)^(5/2)/c^3+1/7*B*_
+     (d+e*x)^2*(b*x+c*x^2)^(5/2)/c-1/84*e*((5*b*B-14*A*c)*d-(4*B*c*d-_
+     9*b*B*e+14*A*c*e)*x)*(b*x+c*x^2)^(5/2)/c^2+1/1024*b^4*(48*A*c^3*d^2-_
+     9*b^3*B*e^2+14*b^2*c*e*(2*B*d+A*e)-24*b*c^2*d*(B*d+2*A*e))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(11/2)-1/1024*b^3*(48*A*c^3*d^2-_
+     9*b^3*B*e^2+14*b^2*c*e*(2*B*d+A*e)-24*b*c^2*d*(B*d+2*A*e))*sqrt(b*x+_
+     c*x^2)/c^5+1/1536*b^2*(48*A*c^3*d^2-9*b^3*B*e^2+14*b^2*c*e*(2*B*d+_
+     A*e)-24*b*c^2*d*(B*d+2*A*e))*x*sqrt(b*x+c*x^2)/c^4+1/384*b*_
+     (48*A*c^3*d^2-9*b^3*B*e^2+14*b^2*c*e*(2*B*d+A*e)-24*b*c^2*d*(B*d+_
+     2*A*e))*x^2*sqrt(b*x+c*x^2)/c^3
+--E 206
+
+--S 207 of 1125
+d0:=D(m0,x)
+--E 207
+
+)clear all
+
+--S 208 of 1125
+t0:=(A+B*x)*(d+e*x)*(b*x+c*x^2)^(3/2)
+--E 208
+
+--S 209 of 1125
+r0:=1/96*(24*A*c^2*d+7*b^2*B*e-12*b*c*(B*d+A*e))*x*(b*x+c*x^2)^(3/2)/c^2+_
+     1/60*(2*B*c*d-7*b*B*e+12*A*c*e)*(b*x+c*x^2)^(5/2)/c^2+1/6*B*(d+e*x)*_
+     (b*x+c*x^2)^(5/2)/c+1/512*b^4*(24*A*c^2*d+7*b^2*B*e-12*b*c*(B*d+_
+     A*e))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(9/2)-1/512*b^3*_
+     (24*A*c^2*d+7*b^2*B*e-12*b*c*(B*d+A*e))*sqrt(b*x+c*x^2)/c^4+_
+     1/768*b^2*(24*A*c^2*d+7*b^2*B*e-12*b*c*(B*d+A*e))*x*sqrt(b*x+_
+     c*x^2)/c^3+1/192*b*(24*A*c^2*d+7*b^2*B*e-12*b*c*(B*d+A*e))*x^2*_
+     sqrt(b*x+c*x^2)/c^2
+--E 209
+
+--S 210 of 1125
+d0:=D(m0,x)
+--E 210
+
+)clear all
+
+--S 211 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)
+--E 211
+
+--S 212 of 1125
+r0:=-1/8*(b*B-2*A*c)*x*(b*x+c*x^2)^(3/2)/c+1/5*B*(b*x+c*x^2)^(5/2)/c-_
+     3/128*b^4*(b*B-2*A*c)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(7/2)+_
+     3/128*b^3*(b*B-2*A*c)*sqrt(b*x+c*x^2)/c^3-1/64*b^2*(b*B-2*A*c)*x*_
+     sqrt(b*x+c*x^2)/c^2-1/16*b*(b*B-2*A*c)*x^2*sqrt(b*x+c*x^2)/c
+--E 212
+
+--S 213 of 1125
+d0:=D(m0,x)
+--E 213
+
+)clear all
+
+--S 214 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)
+--E 214
+
+--S 215 of 1125
+r0:=-1/24*(8*B*c*d-3*b*B*e-8*A*c*e-6*B*c*e*x)*(b*x+c*x^2)^(3/2)/(c*e^2)-_
+     1/64*(8*A*c*e*(16*c^3*d^3-24*b*c^2*d^2*e+6*b^2*c*d*e^2+b^3*e^3)-_
+     B*(128*c^4*d^4-192*b*c^3*d^3*e+48*b^2*c^2*d^2*e^2+8*b^3*c*d*e^3+_
+     3*b^4*e^4))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(c^(5/2)*e^5)-d^(3/2)*_
+     (B*d-A*e)*(c*d-b*e)^(3/2)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/e^5+1/64*(8*A*c*e*(8*c^2*d^2-_
+     10*b*c*d*e+b^2*e^2)-B*(64*c^3*d^3-80*b*c^2*d^2*e+8*b^2*c*d*e^2+_
+     3*b^3*e^3)-2*c*e*(8*A*c*e*(2*c*d-b*e)-B*(16*c^2*d^2-8*b*c*d*e-_
+     3*b^2*e^2))*x)*sqrt(b*x+c*x^2)/(c^2*e^4)
+--E 215
+
+--S 216 of 1125
+d0:=D(m0,x)
+--E 216
+
+)clear all
+
+--S 217 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^2
+--E 217
+
+--S 218 of 1125
+r0:=1/3*(4*B*d-3*A*e+B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*(d+e*x))+1/8*(4*b*c*e*_
+     (4*B*d-3*A*e)*(2*c*d-b*e)-(8*B*c*d-b*B*e-6*A*c*e)*(8*c^2*d^2-_
+     4*b*c*d*e-b^2*e^2))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(c^(3/2)*e^5)+_
+     1/2*(B*d*(8*c*d-5*b*e)-3*A*e*(2*c*d-b*e))*atanh(1/2*(b*d+(2*c*d-_
+     b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))*sqrt(d)*sqrt(c*d-_
+     b*e)/e^5-1/8*(6*A*c*e*(4*c*d-3*b*e)-B*(32*c^2*d^2-28*b*c*d*e+_
+     b^2*e^2)+2*c*e*(8*B*c*d-b*B*e-6*A*c*e)*x)*sqrt(b*x+c*x^2)/(c*e^4)
+--E 218
+
+--S 219 of 1125
+d0:=D(m0,x)
+--E 219
+
+)clear all
+
+--S 220 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^3
+--E 220
+
+--S 221 of 1125
+r0:=1/2*(2*B*d-A*e+B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*(d+e*x)^2)-3/4*(4*A*c*e*_
+     (2*c*d-b*e)-B*(16*c^2*d^2-12*b*c*d*e+b^2*e^2))*atanh(x*sqrt(c)/_
+     sqrt(b*x+c*x^2))/(e^5*sqrt(c))+3/8*(A*e*(8*c^2*d^2-8*b*c*d*e+_
+     b^2*e^2)-B*d*(16*c^2*d^2-20*b*c*d*e+5*b^2*e^2))*atanh(1/2*(b*d+_
+     (2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(e^5*_
+     sqrt(d)*sqrt(c*d-b*e))-3/4*(4*B*d*(2*c*d-b*e)-A*e*(4*c*d-b*e)+_
+     e*(4*B*c*d-b*B*e-2*A*c*e)*x)*sqrt(b*x+c*x^2)/(e^4*(d+e*x))
+--E 221
+
+--S 222 of 1125
+d0:=D(m0,x)
+--E 222
+
+)clear all
+
+--S 223 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^4
+--E 223
+
+--S 224 of 1125
+r0:=-1/4*(B*d*(8*c*d-7*b*e)-A*e*(2*c*d-b*e))*(b*x+c*x^2)^(3/2)/(d*e^2*_
+     (c*d-b*e)*(d+e*x)^2)+1/3*(4*B*d-A*e+3*B*e*x)*(b*x+c*x^2)^(3/2)/_
+     (e^2*(d+e*x)^3)+1/16*(B*d*(64*c^3*d^3-120*b*c^2*d^2*e+60*b^2*c*d*e^2-_
+     5*b^3*e^3)-A*e*(16*c^3*d^3-24*b*c^2*d^2*e+6*b^2*c*d*e^2+b^3*e^3))*_
+     atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+_
+     c*x^2)))/(d^(3/2)*e^5*(c*d-b*e)^(3/2))-(8*B*c*d-3*b*B*e-2*A*c*e)*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))*sqrt(c)/e^5-1/8*(A*e*(8*c^2*d^2-_
+     6*b*c*d*e-b^2*e^2)-B*d*(32*c^2*d^2-36*b*c*d*e+5*b^2*e^2)-_
+     2*c*e*(B*d*(8*c*d-7*b*e)-A*e*(2*c*d-b*e))*x)*sqrt(b*x+c*x^2)/_
+     (d*e^4*(c*d-b*e)*(d+e*x))
+--E 224
+
+--S 225 of 1125
+d0:=D(m0,x)
+--E 225
+
+)clear all
+
+--S 226 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^5
+--E 226
+
+--S 227 of 1125
+r0:=1/32*(3*A*b^2*e^3+B*d*(16*c^2*d^2-24*b*c*d*e+5*b^2*e^2))*_
+     (b*x+c*x^2)^(3/2)/(d^2*e^2*(c*d-b*e)^2*(d+e*x)^2)+1/24*(3*A*b*e^2-_
+     B*d*(8*c*d-5*b*e)-6*c*e*(B*d-A*e)*x)*(b*x+c*x^2)^(3/2)/(d*e^2*_
+     (c*d-b*e)*(d+e*x)^3)+1/4*(B*d-A*e)*(b*x+c*x^2)^(5/2)/(d*(c*d-b*e)*_
+     (d+e*x)^4)+2*B*c^(3/2)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/e^5+_
+     1/128*(3*A*b^4*e^5-B*d*(128*c^4*d^4-320*b*c^3*d^3*e+240*b^2*c^2*_
+     d^2*e^2-40*b^3*c*d*e^3-5*b^4*e^4))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(5/2)*e^5*_
+     (c*d-b*e)^(5/2))-1/64*(3*A*b^3*e^4+B*d*(64*c^3*d^3-112*b*c^2*_
+     d^2*e+40*b^2*c*d*e^2+5*b^3*e^3)+2*c*e*(3*A*b^2*e^3+B*d*(16*c^2*_
+     d^2-24*b*c*d*e+5*b^2*e^2))*x)*sqrt(b*x+c*x^2)/(d^2*e^4*_
+     (c*d-b*e)^2*(d+e*x))
+--E 227
+
+--S 228 of 1125
+d0:=D(m0,x)
+--E 228
+
+)clear all
+
+--S 229 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^6
+--E 229
+
+--S 230 of 1125
+r0:=-1/5*(4*B*d+A*e+5*B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*(d+e*x)^5)-_
+     3/256*b^4*(b*B*d-2*A*c*d+A*b*e)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(7/2)*(c*d-b*e)^(7/2))+_
+     1/80*(A*e*(4*c^2*d^2-4*b*c*d*e-b^2*e^2)+B*d*(16*c^2*d^2-26*b*c*d*e+_
+     11*b^2*e^2))*sqrt(b*x+c*x^2)/(d*e^4*(c*d-b*e)*(d+e*x)^3)+1/320*_
+     (A*e*(16*c^3*d^3-24*b*c^2*d^2*e-2*b^2*c*d*e^2+5*b^3*e^3)+B*d*_
+     (64*c^3*d^3-136*b*c^2*d^2*e+72*b^2*c*d*e^2+5*b^3*e^3))*_
+     sqrt(b*x+c*x^2)/(d^2*e^4*(c*d-b*e)^2*(d+e*x)^2)+1/640*(B*d*_
+     (128*c^4*d^4-336*b*c^3*d^3*e+248*b^2*c^2*d^2*e^2-10*b^3*c*d*e^3-_
+     15*b^4*e^4)+A*e*(32*c^4*d^4-64*b*c^3*d^3*e+12*b^2*c^2*d^2*e^2+_
+     20*b^3*c*d*e^3-15*b^4*e^4))*sqrt(b*x+c*x^2)/(d^3*e^4*(c*d-b*e)^3*_
+     (d+e*x))-3/40*(B*d*(8*c*d-b*e)+A*e*(2*c*d+b*e)+2*e*(8*B*c*d-_
+     5*b*B*e+2*A*c*e)*x)*sqrt(b*x+c*x^2)/(e^4*(d+e*x)^4)
+--E 230
+
+--S 231 of 1125
+d0:=D(m0,x)
+--E 231
+
+)clear all
+
+--S 232 of 1125
+t0:=(A+B*x)*(d+e*x)^2*(b*x+c*x^2)^(5/2)
+--E 232
+
+--S 233 of 1125
+r0:=1/768*b*(64*A*c^3*d^2-11*b^3*B*e^2+18*b^2*c*e*(2*B*d+A*e)-32*b*c^2*d*_
+     (B*d+2*A*e))*x^2*(b*x+c*x^2)^(3/2)/c^3+1/384*(64*A*c^3*d^2-11*b^3*_
+     B*e^2+18*b^2*c*e*(2*B*d+A*e)-32*b*c^2*d*(B*d+2*A*e))*x*(b*x+_
+     c*x^2)^(5/2)/c^3+1/2016*(162*A*c*e*(2*c*d-b*e)+B*(64*c^2*d^2-_
+     226*b*c*d*e+99*b^2*e^2))*(b*x+c*x^2)^(7/2)/c^3+1/9*B*(d+e*x)^2*_
+     (b*x+c*x^2)^(7/2)/c-1/144*e*((7*b*B-18*A*c)*d-(4*B*c*d-11*b*B*e+_
+     18*A*c*e)*x)*(b*x+c*x^2)^(7/2)/c^2-5/32768*b^6*(64*A*c^3*d^2-_
+     11*b^3*B*e^2+18*b^2*c*e*(2*B*d+A*e)-32*b*c^2*d*(B*d+2*A*e))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(13/2)+5/32768*b^5*(64*A*c^3*_
+     d^2-11*b^3*B*e^2+18*b^2*c*e*(2*B*d+A*e)-32*b*c^2*d*(B*d+2*A*e))*_
+     sqrt(b*x+c*x^2)/c^6-5/49152*b^4*(64*A*c^3*d^2-11*b^3*B*e^2+18*b^2*_
+     c*e*(2*B*d+A*e)-32*b*c^2*d*(B*d+2*A*e))*x*sqrt(b*x+c*x^2)/c^5+_
+     1/12288*b^3*(64*A*c^3*d^2-11*b^3*B*e^2+18*b^2*c*e*(2*B*d+A*e)-_
+     32*b*c^2*d*(B*d+2*A*e))*x^2*sqrt(b*x+c*x^2)/c^4+1/2048*b^2*_
+     (64*A*c^3*d^2-11*b^3*B*e^2+18*b^2*c*e*(2*B*d+A*e)-32*b*c^2*d*_
+     (B*d+2*A*e))*x^3*sqrt(b*x+c*x^2)/c^3
+--E 233
+
+--S 234 of 1125
+d0:=D(m0,x)
+--E 234
+
+)clear all
+
+--S 235 of 1125
+t0:=(A+B*x)*(d+e*x)*(b*x+c*x^2)^(5/2)
+--E 235
+
+--S 236 of 1125
+r0:=1/384*b*(32*A*c^2*d+9*b^2*B*e-16*b*c*(B*d+A*e))*x^2*_
+     (b*x+c*x^2)^(3/2)/c^2+1/192*(32*A*c^2*d+9*b^2*B*e-16*b*c*(B*d+A*e))*_
+     x*(b*x+c*x^2)^(5/2)/c^2+1/112*(2*B*c*d-9*b*B*e+16*A*c*e)*_
+     (b*x+c*x^2)^(7/2)/c^2+1/8*B*(d+e*x)*(b*x+c*x^2)^(7/2)/c-_
+     5/16384*b^6*(32*A*c^2*d+9*b^2*B*e-16*b*c*(B*d+A*e))*atanh(x*_
+     sqrt(c)/sqrt(b*x+c*x^2))/c^(11/2)+5/16384*b^5*(32*A*c^2*d+9*b^2*B*e-_
+     16*b*c*(B*d+A*e))*sqrt(b*x+c*x^2)/c^5-5/24576*b^4*(32*A*c^2*d+_
+     9*b^2*B*e-16*b*c*(B*d+A*e))*x*sqrt(b*x+c*x^2)/c^4+1/6144*b^3*_
+     (32*A*c^2*d+9*b^2*B*e-16*b*c*(B*d+A*e))*x^2*sqrt(b*x+c*x^2)/c^3+_
+     1/1024*b^2*(32*A*c^2*d+9*b^2*B*e-16*b*c*(B*d+A*e))*x^3*_
+     sqrt(b*x+c*x^2)/c^2
+--E 236
+
+--S 237 of 1125
+d0:=D(m0,x)
+--E 237
+
+)clear all
+
+--S 238 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)
+--E 238
+
+--S 239 of 1125
+r0:=-1/24*b*(b*B-2*A*c)*x^2*(b*x+c*x^2)^(3/2)/c-1/12*(b*B-2*A*c)*x*_
+     (b*x+c*x^2)^(5/2)/c+1/7*B*(b*x+c*x^2)^(7/2)/c+5/1024*b^6*(b*B-_
+     2*A*c)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(9/2)-5/1024*b^5*(b*B-_
+     2*A*c)*sqrt(b*x+c*x^2)/c^4+5/1536*b^4*(b*B-2*A*c)*x*sqrt(b*x+_
+     c*x^2)/c^3-1/384*b^3*(b*B-2*A*c)*x^2*sqrt(b*x+c*x^2)/c^2-1/64*b^2*_
+     (b*B-2*A*c)*x^3*sqrt(b*x+c*x^2)/c
+--E 239
+
+--S 240 of 1125
+d0:=D(m0,x)
+--E 240
+
+)clear all
+
+--S 241 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)/(d+e*x)
+--E 241
+
+--S 242 of 1125
+r0:=1/192*(4*A*c*e*(16*c^2*d^2-22*b*c*d*e+3*b^2*e^2)-B*(64*c^3*d^3-_
+     88*b*c^2*d^2*e+12*b^2*c*d*e^2+5*b^3*e^3)-2*c*e*(12*A*c*e*(2*c*d-_
+     b*e)-B*(24*c^2*d^2-12*b*c*d*e-5*b^2*e^2))*x)*(b*x+c*x^2)^(3/2)/_
+     (c^2*e^4)-1/60*(12*B*c*d-5*b*B*e-12*A*c*e-10*B*c*e*x)*(b*x+_
+     c*x^2)^(5/2)/(c*e^2)-1/512*(4*A*c*e*(256*c^5*d^5-640*b*c^4*d^4*e+_
+     480*b^2*c^3*d^3*e^2-80*b^3*c^2*d^2*e^3-10*b^4*c*d*e^4-3*b^5*e^5)-_
+     B*(1024*c^6*d^6-2560*b*c^5*d^5*e+1920*b^2*c^4*d^4*e^2-320*b^3*_
+     c^3*d^3*e^3-40*b^4*c^2*d^2*e^4-12*b^5*c*d*e^5-5*b^6*e^6))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(c^(7/2)*e^7)-d^(5/2)*(B*d-A*e)*_
+     (c*d-b*e)^(5/2)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/e^7+1/1536*(3*(4*A*c*e*(128*c^4*d^4-_
+     288*b*c^3*d^3*e+176*b^2*c^2*d^2*e^2-10*b^3*c*d*e^3-3*b^4*e^4)-_
+     B*(512*c^5*d^5-1152*b*c^4*d^4*e+704*b^2*c^3*d^3*e^2-40*b^3*c^2*_
+     d^2*e^3-12*b^4*c*d*e^4-5*b^5*e^5))-2*c*e*(8*b*c*d*e*(2*c*d-b*e)*_
+     (12*B*c*d-5*b*B*e-12*A*c*e)+(16*c^2*d^2-8*b*c*d*e-3*b^2*e^2)*_
+     (12*A*c*e*(2*c*d-b*e)-B*(24*c^2*d^2-12*b*c*d*e-5*b^2*e^2)))*x)*_
+     sqrt(b*x+c*x^2)/(c^3*e^6)
+--E 242
+
+--S 243 of 1125
+d0:=D(m0,x)
+--E 243
+
+)clear all
+
+--S 244 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)/(d+e*x)^2
+--E 244
+
+--S 245 of 1125
+r0:=-1/48*(10*A*c*e*(8*c*d-7*b*e)-B*(96*c^2*d^2-92*b*c*d*e+3*b^2*e^2)+_
+     6*c*e*(12*B*c*d-b*B*e-10*A*c*e)*x)*(b*x+c*x^2)^(3/2)/(c*e^4)+_
+     1/5*(6*B*d-5*A*e+B*e*x)*(b*x+c*x^2)^(5/2)/(e^2*(d+e*x))+_
+     1/128*(10*A*c*e*(128*c^4*d^4-256*b*c^3*d^3*e+144*b^2*c^2*d^2*e^2-_
+     16*b^3*c*d*e^3-b^4*e^4)-B*(1536*c^5*d^5-3200*b*c^4*d^4*e+_
+     1920*b^2*c^3*d^3*e^2-240*b^3*c^2*d^2*e^3-20*b^4*c*d*e^4-3*b^5*e^5))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(c^(5/2)*e^7)+1/2*d^(3/2)*_
+     (c*d-b*e)^(3/2)*(B*d*(12*c*d-7*b*e)-5*A*e*(2*c*d-b*e))*atanh(1/2*_
+     (b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/e^7-_
+     1/128*(10*A*c*e*(64*c^3*d^3-112*b*c^2*d^2*e+48*b^2*c*d*e^2-b^3*e^3)-_
+     B*(768*c^4*d^4-1408*b*c^3*d^3*e+656*b^2*c^2*d^2*e^2-20*b^3*c*d*e^3-_
+     3*b^4*e^4)-2*c*e*(8*b*c*e*(6*B*d-5*A*e)*(2*c*d-b*e)-(12*B*c*d-b*B*e-_
+     10*A*c*e)*(16*c^2*d^2-8*b*c*d*e-3*b^2*e^2))*x)*sqrt(b*x+c*x^2)/(c^2*e^6)
+--E 245
+
+--S 246 of 1125
+d0:=D(m0,x)
+--E 246
+
+)clear all
+
+--S 247 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)/(d+e*x)^3
+--E 247
+
+--S 248 of 1125
+r0:=-5/24*(B*d*(24*c*d-13*b*e)-2*A*e*(8*c*d-3*b*e)+e*(6*B*c*d-b*B*e-_
+     4*A*c*e)*x)*(b*x+c*x^2)^(3/2)/(e^4*(d+e*x))+1/4*(3*B*d-2*A*e+B*e*x)*_
+     (b*x+c*x^2)^(5/2)/(e^2*(d+e*x)^2)-5/64*(8*A*c*e*(32*c^3*d^3-48*b*c^2*_
+     d^2*e+18*b^2*c*d*e^2-b^3*e^3)-B*(384*c^4*d^4-640*b*c^3*d^3*e+288*b^2*_
+     c^2*d^2*e^2-24*b^3*c*d*e^3-b^4*e^4))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/_
+     (c^(3/2)*e^7)+5/8*(A*e*(16*c^2*d^2-16*b*c*d*e+3*b^2*e^2)-B*d*(24*c^2*_
+     d^2-28*b*c*d*e+7*b^2*e^2))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))*sqrt(d)*sqrt(c*d-b*e)/e^7+5/64*_
+     (8*A*c*e*(16*c^2*d^2-20*b*c*d*e+5*b^2*e^2)-B*(192*c^3*d^3-272*b*c^2*_
+     d^2*e+88*b^2*c*d*e^2-b^3*e^3)-2*c*e*(16*A*c*e*(2*c*d-b*e)-B*(48*c^2*_
+     d^2-32*b*c*d*e+b^2*e^2))*x)*sqrt(b*x+c*x^2)/(c*e^6)
+--E 248
+
+--S 249 of 1125
+d0:=D(m0,x)
+--E 249
+
+)clear all
+
+--S 250 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)/(d+e*x)^4
+--E 250
+
+--S 251 of 1125
+r0:=-5/12*(4*B*d*(2*c*d-b*e)-A*e*(4*c*d-b*e)+e*(4*B*c*d-b*B*e-2*A*c*e)*x)*_
+     (b*x+c*x^2)^(3/2)/(e^4*(d+e*x)^2)+1/3*(2*B*d-A*e+B*e*x)*_
+     (b*x+c*x^2)^(5/2)/(e^2*(d+e*x)^3)+5/8*(2*A*c*e*(16*c^2*d^2-_
+     16*b*c*d*e+3*b^2*e^2)-B*(64*c^3*d^3-80*b*c^2*d^2*e+24*b^2*c*d*e^2-_
+     b^3*e^3))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(e^7*sqrt(c))+5/16*(B*d*_
+     (64*c^3*d^3-112*b*c^2*d^2*e+56*b^2*c*d*e^2-7*b^3*e^3)-A*e*(32*c^3*d^3-_
+     48*b*c^2*d^2*e+18*b^2*c*d*e^2-b^3*e^3))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(e^7*sqrt(d)*sqrt(c*d-b*e))-_
+     5/8*(A*e*(16*c^2*d^2-12*b*c*d*e+b^2*e^2)-2*B*d*(16*c^2*d^2-_
+     16*b*c*d*e+3*b^2*e^2)+e*(4*A*c*e*(2*c*d-b*e)-B*(16*c^2*d^2-12*b*c*d*e+_
+     b^2*e^2))*x)*sqrt(b*x+c*x^2)/(e^6*(d+e*x))
+--E 251
+
+--S 252 of 1125
+d0:=D(m0,x)
+--E 252
+
+)clear all
+
+--S 253 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(5/2)/(d+e*x)^5
+--E 253
+
+--S 254 of 1125
+r0:=-5/32*(A*e*(16*c^2*d^2-16*b*c*d*e+b^2*e^2)-B*d*(48*c^2*d^2-64*b*c*d*e+_
+     17*b^2*e^2))*(b*x+c*x^2)^(3/2)/(d*e^4*(c*d-b*e)*(d+e*x)^2)-5/24*_
+     (B*d*(24*c*d-11*b*e)-A*e*(8*c*d-b*e)+6*e*(3*B*c*d-b*B*e-A*c*e)*x)*_
+     (b*x+c*x^2)^(3/2)/(e^4*(d+e*x)^3)+1/4*(3*B*d-A*e+2*B*e*x)*(b*x+_
+     c*x^2)^(5/2)/(e^2*(d+e*x)^4)+5/128*(A*e*(128*c^4*d^4-256*b*c^3*d^3*e+_
+     144*b^2*c^2*d^2*e^2-16*b^3*c*d*e^3-b^4*e^4)-B*d*(384*c^4*d^4-_
+     896*b*c^3*d^3*e+672*b^2*c^2*d^2*e^2-168*b^3*c*d*e^3+7*b^4*e^4))*_
+     atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+_
+     c*x^2)))/(d^(3/2)*e^7*(c*d-b*e)^(3/2))-5/4*(4*A*c*e*(2*c*d-b*e)-_
+     B*(24*c^2*d^2-20*b*c*d*e+3*b^2*e^2))*atanh(x*sqrt(c)/sqrt(b*x+_
+     c*x^2))*sqrt(c)/e^7-5/64*(B*d*(192*c^3*d^3-304*b*c^2*d^2*e+120*_
+     b^2*c*d*e^2-7*b^3*e^3)-A*e*(64*c^3*d^3-80*b*c^2*d^2*e+16*b^2*c*d*_
+     e^2+b^3*e^3)-2*c*e*(A*e*(16*c^2*d^2-16*b*c*d*e+b^2*e^2)-B*d*(48*c^2*_
+     d^2-64*b*c*d*e+17*b^2*e^2))*x)*sqrt(b*x+c*x^2)/(d*e^6*(c*d-b*e)*(d+e*x))
+--E 254
+
+--S 255 of 1125
+d0:=D(m0,x)
+--E 255
+
+)clear all
+
+--S 256 of 1125
+t0:=(A+B*x)*(d+e*x)^3/sqrt(b*x+c*x^2)
+--E 256
+
+--S 257 of 1125
+r0:=1/64*(128*A*c^4*d^3+35*b^4*B*e^3+144*b^2*c^2*d*e*(B*d+A*e)-40*b^3*_
+     c*e^2*(3*B*d+A*e)-64*b*c^3*d^2*(B*d+3*A*e))*atanh(x*sqrt(c)/_
+     sqrt(b*x+c*x^2))/c^(9/2)+1/192*(8*A*c*e*(52*c^2*d^2-52*b*c*d*e+_
+     15*b^2*e^2)+B*(96*c^3*d^3-352*b*c^2*d^2*e+346*b^2*c*d*e^2-105*_
+     b^3*e^3))*sqrt(b*x+c*x^2)/c^4+1/24*(6*B*c*d-7*b*B*e+8*A*c*e)*_
+     (d+e*x)^2*sqrt(b*x+c*x^2)/c^2+1/4*B*(d+e*x)^3*sqrt(b*x+c*x^2)/c-_
+     1/96*e*(d*(12*b*B*c*d-48*A*c^2*d-7*b^2*B*e+8*A*b*c*e)-(40*A*c*e*_
+     (2*c*d-b*e)+B*(24*c^2*d^2-64*b*c*d*e+35*b^2*e^2))*x)*sqrt(b*x+c*x^2)/c^3
+--E 257
+
+--S 258 of 1125
+d0:=D(m0,x)
+--E 258
+
+)clear all
+
+--S 259 of 1125
+t0:=(A+B*x)*(d+e*x)^2/sqrt(b*x+c*x^2)
+--E 259
+
+--S 260 of 1125
+r0:=1/8*(16*A*c^3*d^2-5*b^3*B*e^2+6*b^2*c*e*(2*B*d+A*e)-8*b*c^2*d*_
+     (B*d+2*A*e))*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(7/2)+1/24*(18*A*c*_
+     e*(2*c*d-b*e)+B*(16*c^2*d^2-34*b*c*d*e+15*b^2*e^2))*sqrt(b*x+_
+     c*x^2)/c^3+1/3*B*(d+e*x)^2*sqrt(b*x+c*x^2)/c-1/12*e*((b*B-6*A*c)*_
+     d-(4*B*c*d-5*b*B*e+6*A*c*e)*x)*sqrt(b*x+c*x^2)/c^2
+--E 260
+
+--S 261 of 1125
+d0:=D(m0,x)
+--E 261
+
+)clear all
+
+--S 262 of 1125
+t0:=(A+B*x)*(d+e*x)/sqrt(b*x+c*x^2)
+--E 262
+
+--S 263 of 1125
+r0:=1/4*(8*A*c^2*d+3*b^2*B*e-4*b*c*(B*d+A*e))*atanh(x*sqrt(c)/sqrt(b*x+_
+     c*x^2))/c^(5/2)+1/4*(2*B*c*d-3*b*B*e+4*A*c*e)*sqrt(b*x+c*x^2)/c^2+_
+     1/2*B*(d+e*x)*sqrt(b*x+c*x^2)/c
+--E 263
+
+--S 264 of 1125
+d0:=D(m0,x)
+--E 264
+
+)clear all
+
+--S 265 of 1125
+t0:=(A+B*x)/sqrt(b*x+c*x^2)
+--E 265
+
+--S 266 of 1125
+r0:=-(b*B-2*A*c)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(3/2)+B*sqrt(b*x+c*x^2)/c
+--E 266
+
+--S 267 of 1125
+d0:=D(m0,x)
+--E 267
+
+)clear all
+
+--S 268 of 1125
+t0:=(A+B*x)/((d+e*x)*sqrt(b*x+c*x^2))
+--E 268
+
+--S 269 of 1125
+r0:=2*B*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/(e*sqrt(c))-(B*d-A*e)*atanh(1/2*_
+     (b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/_
+     (e*sqrt(d)*sqrt(c*d-b*e))
+--E 269
+
+--S 270 of 1125
+d0:=D(m0,x)
+--E 270
+
+)clear all
+
+--S 271 of 1125
+t0:=(A+B*x)/((d+e*x)^2*sqrt(b*x+c*x^2))
+--E 271
+
+--S 272 of 1125
+r0:=-1/2*(b*B*d-2*A*c*d+A*b*e)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(3/2)*(c*d-b*e)^(3/2))+(B*d-A*e)*_
+     sqrt(b*x+c*x^2)/(d*(c*d-b*e)*(d+e*x))
+--E 272
+
+--S 273 of 1125
+d0:=D(m0,x)
+--E 273
+
+)clear all
+
+--S 274 of 1125
+t0:=(A+B*x)/((d+e*x)^3*sqrt(b*x+c*x^2))
+--E 274
+
+--S 275 of 1125
+r0:=1/8*(8*A*c^2*d^2-4*b*c*d*(B*d+2*A*e)+b^2*e*(B*d+3*A*e))*atanh(1/2*(b*d+_
+     (2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(5/2)*_
+     (c*d-b*e)^(5/2))+1/2*(B*d-A*e)*sqrt(b*x+c*x^2)/(d*(c*d-b*e)*_
+     (d+e*x)^2)-1/4*(3*A*e*(2*c*d-b*e)-B*d*(2*c*d+b*e))*sqrt(b*x+c*x^2)/_
+     (d^2*(c*d-b*e)^2*(d+e*x))
+--E 275
+
+--S 276 of 1125
+d0:=D(m0,x)
+--E 276
+
+)clear all
+
+--S 277 of 1125
+t0:=(A+B*x)/((d+e*x)^4*sqrt(b*x+c*x^2))
+--E 277
+
+--S 278 of 1125
+r0:=1/16*(16*A*c^3*d^3-8*b*c^2*d^2*(B*d+3*A*e)-b^3*e^2*(B*d+5*A*e)+_
+     2*b^2*c*d*e*(2*B*d+9*A*e))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*_
+     sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(7/2)*(c*d-b*e)^(7/2))+_
+     1/3*(B*d-A*e)*sqrt(b*x+c*x^2)/(d*(c*d-b*e)*(d+e*x)^3)-_
+     1/12*(5*A*e*(2*c*d-b*e)-B*d*(4*c*d+b*e))*sqrt(b*x+c*x^2)/(d^2*_
+     (c*d-b*e)^2*(d+e*x)^2)+1/24*(B*d*(8*c^2*d^2+10*b*c*d*e-3*b^2*e^2)-_
+     A*e*(44*c^2*d^2-44*b*c*d*e+15*b^2*e^2))*sqrt(b*x+c*x^2)/(d^3*_
+     (c*d-b*e)^3*(d+e*x))
+--E 278
+
+--S 279 of 1125
+d0:=D(m0,x)
+--E 279
+
+)clear all
+
+--S 280 of 1125
+t0:=(A+B*x)*(d+e*x)^3/(b*x+c*x^2)^(3/2)
+--E 280
+
+--S 281 of 1125
+r0:=3/4*e*(4*A*c*e*(2*c*d-b*e)+B*(8*c^2*d^2-12*b*c*d*e+5*b^2*e^2))*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(7/2)-2*(A*b-(b*B-2*A*c)*x)*_
+     (d+e*x)^3/(b^2*sqrt(b*x+c*x^2))+1/4*e*(32*A*c^3*d^2-15*b^3*B*e^2-_
+     16*b*c^2*d*(B*d+2*A*e)+2*b^2*c*e*(17*B*d+6*A*e))*sqrt(b*x+c*x^2)/_
+     (b^2*c^3)-2*(b*B-2*A*c)*e*(d+e*x)^2*sqrt(b*x+c*x^2)/(b^2*c)+_
+     1/2*e^2*(b*(b*B+4*A*c)*d+(8*A*c^2*d+5*b^2*B*e-4*b*c*(B*d+A*e))*x)*_
+     sqrt(b*x+c*x^2)/(b^2*c^2)
+--E 281
+
+--S 282 of 1125
+d0:=D(m0,x)
+--E 282
+
+)clear all
+
+--S 283 of 1125
+t0:=(A+B*x)*(d+e*x)^2/(b*x+c*x^2)^(3/2)
+--E 283
+
+--S 284 of 1125
+r0:=e*(4*B*c*d-3*b*B*e+2*A*c*e)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(5/2)-_
+     2*(A*b-(b*B-2*A*c)*x)*(d+e*x)^2/(b^2*sqrt(b*x+c*x^2))+e*(8*A*c^2*d+_
+     3*b^2*B*e-4*b*c*(B*d+A*e))*sqrt(b*x+c*x^2)/(b^2*c^2)+2*e^2*(A*b-_
+     (b*B-2*A*c)*x)*sqrt(b*x+c*x^2)/(b^2*c)
+--E 284
+
+--S 285 of 1125
+d0:=D(m0,x)
+--E 285
+
+)clear all
+
+--S 286 of 1125
+t0:=(A+B*x)*(d+e*x)/(b*x+c*x^2)^(3/2)
+--E 286
+
+--S 287 of 1125
+r0:=2*B*e*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(3/2)-2*(A*b-(b*B-2*A*c)*x)*_
+     (d+e*x)/(b^2*sqrt(b*x+c*x^2))-2*(b*B-2*A*c)*e*sqrt(b*x+c*x^2)/(b^2*c)
+--E 287
+
+--S 288 of 1125
+d0:=D(m0,x)
+--E 288
+
+)clear all
+
+--S 289 of 1125
+t0:=(A+B*x)/(b*x+c*x^2)^(3/2)
+--E 289
+
+--S 290 of 1125
+r0:=-2*(A*b-(b*B-2*A*c)*x)/(b^2*sqrt(b*x+c*x^2))
+--E 290
+
+--S 291 of 1125
+d0:=D(m0,x)
+--E 291
+
+)clear all
+
+--S 292 of 1125
+t0:=(A+B*x)/((d+e*x)*(b*x+c*x^2)^(3/2))
+--E 292
+
+--S 293 of 1125
+r0:=-e*(B*d-A*e)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*_
+     sqrt(b*x+c*x^2)))/(d^(3/2)*(c*d-b*e)^(3/2))-2*(A*b*(c*d-b*e)+_
+     c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*sqrt(b*x+c*x^2))
+--E 293
+
+--S 294 of 1125
+d0:=D(m0,x)
+--E 294
+
+)clear all
+
+--S 295 of 1125
+t0:=(A+B*x)/((d+e*x)^2*(b*x+c*x^2)^(3/2))
+--E 295
+
+--S 296 of 1125
+r0:=1/2*e*(3*A*e*(2*c*d-b*e)-B*d*(4*c*d-b*e))*atanh(1/2*(b*d+(2*c*d-_
+     b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(5/2)*(c*d-_
+     b*e)^(5/2))-2*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*_
+     (c*d-b*e)*(d+e*x)*sqrt(b*x+c*x^2))-e*(4*A*c^2*d^2-b^2*e*(B*d-_
+     3*A*e)-2*b*c*d*(B*d+2*A*e))*sqrt(b*x+c*x^2)/(b^2*d^2*(c*d-b*e)^2*(d+e*x))
+--E 296
+
+--S 297 of 1125
+d0:=D(m0,x)
+--E 297
+
+)clear all
+
+--S 298 of 1125
+t0:=(A+B*x)/((d+e*x)^3*(b*x+c*x^2)^(3/2))
+--E 298
+
+--S 299 of 1125
+r0:=-3/8*e*(B*d*(8*c^2*d^2-4*b*c*d*e+b^2*e^2)-A*e*(16*c^2*d^2-16*b*c*d*e+_
+     5*b^2*e^2))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*_
+     sqrt(b*x+c*x^2)))/(d^(7/2)*(c*d-b*e)^(7/2))-2*(A*b*(c*d-b*e)+_
+     c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*(d+e*x)^2*sqrt(b*x+_
+     c*x^2))-1/2*e*(8*A*c^2*d^2-b^2*e*(B*d-5*A*e)-4*b*c*d*(B*d+2*A*e))*_
+     sqrt(b*x+c*x^2)/(b^2*d^2*(c*d-b*e)^2*(d+e*x)^2)-1/4*e*(16*A*c^3*d^3-_
+     2*b^2*c*d*e*(5*B*d-19*A*e)+3*b^3*e^2*(B*d-5*A*e)-8*b*c^2*d^2*_
+     (B*d+3*A*e))*sqrt(b*x+c*x^2)/(b^2*d^3*(c*d-b*e)^3*(d+e*x))
+--E 299
+
+--S 300 of 1125
+d0:=D(m0,x)
+--E 300
+
+)clear all
+
+--S 301 of 1125
+t0:=(A+B*x)*(d+e*x)^4/(b*x+c*x^2)^(5/2)
+--E 301
+
+--S 302 of 1125
+r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^4/(b^2*(b*x+c*x^2)^(3/2))+e^3*(8*B*c*d-_
+     5*b*B*e+2*A*c*e)*atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(7/2)-8/3*_
+     (d+e*x)^3*(b*(b*B*d-2*A*c*d+2*A*b*e)-(4*A*c^2*d-b^2*B*e-2*b*c*(B*d+_
+     A*e))*x)/(b^4*sqrt(b*x+c*x^2))-1/3*e*(64*A*c^4*d^3-15*b^4*B*e^3-_
+     32*b*c^3*d^2*(B*d+3*A*e)+2*b^3*c*e^2*(11*B*d+3*A*e)+4*b^2*c^2*d*_
+     e*(4*B*d+5*A*e))*sqrt(b*x+c*x^2)/(b^4*c^3)-8/3*e*(4*A*c^2*d-b^2*B*e-_
+     2*b*c*(B*d+A*e))*(d+e*x)^2*sqrt(b*x+c*x^2)/(b^4*c)+2/3*e^2*(b*d*_
+     (4*b*B*c*d-8*A*c^2*d-b^2*B*e+10*A*b*c*e)-(16*A*c^3*d^2+5*b^3*B*e^2-_
+     2*A*b^2*c*e^2-8*b*c^2*d*(B*d+2*A*e))*x)*sqrt(b*x+c*x^2)/(b^4*c^2)
+--E 302
+
+--S 303 of 1125
+d0:=D(m0,x)
+--E 303
+
+)clear all
+
+--S 304 of 1125
+t0:=(A+B*x)*(d+e*x)^3/(b*x+c*x^2)^(5/2)
+--E 304
+
+--S 305 of 1125
+r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^3/(b^2*(b*x+c*x^2)^(3/2))+2*B*e^3*_
+     atanh(x*sqrt(c)/sqrt(b*x+c*x^2))/c^(5/2)-4/3*(d+e*x)^2*(b*(2*b*B*d-_
+     4*A*c*d+3*A*b*e)-(8*A*c^2*d-b^2*B*e-4*b*c*(B*d+A*e))*x)/(b^4*_
+     sqrt(b*x+c*x^2))-2/3*e*(32*A*c^3*d^2+3*b^3*B*e^2-16*b*c^2*d*(B*d+_
+     2*A*e)+2*b^2*c*e*(2*B*d+3*A*e))*sqrt(b*x+c*x^2)/(b^4*c^2)+4/3*e^2*_
+     (b*(2*b*B*d-4*A*c*d+3*A*b*e)-(8*A*c^2*d-b^2*B*e-4*b*c*(B*d+A*e))*x)*_
+     sqrt(b*x+c*x^2)/(b^4*c)
+--E 305
+
+--S 306 of 1125
+d0:=D(m0,x)
+--E 306
+
+)clear all
+
+--S 307 of 1125
+t0:=(A+B*x)*(d+e*x)^2/(b*x+c*x^2)^(5/2)
+--E 307
+
+--S 308 of 1125
+r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^2/(b^2*(b*x+c*x^2)^(3/2))-_
+     8/3*(b*B*d-2*A*c*d+A*b*e)*(b*d+(2*c*d-b*e)*x)/(b^4*sqrt(b*x+c*x^2))
+--E 308
+
+--S 309 of 1125
+d0:=D(m0,x)
+--E 309
+
+)clear all
+
+--S 310 of 1125
+t0:=(A+B*x)*(d+e*x)/(b*x+c*x^2)^(5/2)
+--E 310
+
+--S 311 of 1125
+r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)/(b^2*(b*x+c*x^2)^(3/2))-_
+     4/3*(b*(2*b*B*d-4*A*c*d+A*b*e)-(8*A*c^2*d+b^2*B*e-_
+     4*b*c*(B*d+A*e))*x)/(b^4*sqrt(b*x+c*x^2))
+--E 311
+
+--S 312 of 1125
+d0:=D(m0,x)
+--E 312
+
+)clear all
+
+--S 313 of 1125
+t0:=(A+B*x)/(b*x+c*x^2)^(5/2)
+--E 313
+
+--S 314 of 1125
+r0:=-2/3*(A*b-(b*B-2*A*c)*x)/(b^2*(b*x+c*x^2)^(3/2))+8/3*(b*B-2*A*c)/_
+     (b^3*sqrt(b*x+c*x^2))-16/3*(b*B-2*A*c)*sqrt(b*x+c*x^2)/(b^4*x)
+--E 314
+
+--S 315 of 1125
+d0:=D(m0,x)
+--E 315
+
+)clear all
+
+--S 316 of 1125
+t0:=(A+B*x)/((d+e*x)*(b*x+c*x^2)^(5/2))
+--E 316
+
+--S 317 of 1125
+r0:=-2/3*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*_
+     (b*x+c*x^2)^(3/2))-e^3*(B*d-A*e)*atanh(1/2*(b*d+(2*c*d-b*e)*x)/_
+     (sqrt(d)*sqrt(c*d-b*e)*sqrt(b*x+c*x^2)))/(d^(5/2)*(c*d-b*e)^(5/2))+_
+     2/3*(b*(c*d-b*e)*(8*A*c^2*d^2+3*b^2*e*(B*d-A*e)-4*b*c*d*(B*d+A*e))+_
+     c*(16*A*c^3*d^3-3*b^3*e^2*(B*d-A*e)+2*b^2*c*d*e*(7*B*d+A*e)-_
+     8*b*c^2*d^2*(B*d+3*A*e))*x)/(b^4*d^2*(c*d-b*e)^2*sqrt(b*x+c*x^2))
+--E 317
+
+--S 318 of 1125
+d0:=D(m0,x)
+--E 318
+
+)clear all
+
+--S 319 of 1125
+t0:=(A+B*x)/((d+e*x)^2*(b*x+c*x^2)^(5/2))
+--E 319
+
+--S 320 of 1125
+r0:=-2/3*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*_
+     (d+e*x)*(b*x+c*x^2)^(3/2))-1/2*e^3*(B*d*(8*c*d-3*b*e)-5*A*e*_
+     (2*c*d-b*e))*atanh(1/2*(b*d+(2*c*d-b*e)*x)/(sqrt(d)*sqrt(c*d-b*e)*_
+     sqrt(b*x+c*x^2)))/(d^(7/2)*(c*d-b*e)^(7/2))+2/3*(b*(c*d-b*e)*_
+     (8*A*c^2*d^2+b^2*e*(3*B*d-5*A*e)-2*b*c*d*(2*B*d+A*e))+c*(16*A*c^3*d^3-_
+     b^3*e^2*(3*B*d-5*A*e)+2*b^2*c*d*e*(8*B*d-A*e)-8*b*c^2*d^2*(B*d+_
+     3*A*e))*x)/(b^4*d^2*(c*d-b*e)^2*(d+e*x)*sqrt(b*x+c*x^2))+1/3*e*_
+     (32*A*c^4*d^4-2*b^3*c*d*e^2*(9*B*d-10*A*e)+3*b^4*e^3*(3*B*d-5*A*e)+_
+     4*b^2*c^2*d^2*e*(10*B*d+3*A*e)-16*b*c^3*d^3*(B*d+4*A*e))*sqrt(b*x+_
+     c*x^2)/(b^4*d^3*(c*d-b*e)^3*(d+e*x))
+--E 320
+
+--S 321 of 1125
+d0:=D(m0,x)
+--E 321
+
+)clear all
+
+--S 322 of 1125
+t0:=(A+B*x)*(d+e*x)^(7/2)*(b*x+c*x^2)
+--E 322
+
+--S 323 of 1125
+r0:=-2/9*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^(9/2)/e^4+2/11*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^(11/2)/e^4-2/13*(3*B*c*d-b*B*e-A*c*e)*_
+     (d+e*x)^(13/2)/e^4+2/15*B*c*(d+e*x)^(15/2)/e^4
+--E 323
+
+--S 324 of 1125
+d0:=D(m0,x)
+--E 324
+
+)clear all
+
+--S 325 of 1125
+t0:=(A+B*x)*(d+e*x)^(5/2)*(b*x+c*x^2)
+--E 325
+
+--S 326 of 1125
+r0:=-2/7*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^(7/2)/e^4+2/9*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^(9/2)/e^4-2/11*(3*B*c*d-b*B*e-A*c*e)*_
+     (d+e*x)^(11/2)/e^4+2/13*B*c*(d+e*x)^(13/2)/e^4
+--E 326
+
+--S 327 of 1125
+d0:=D(m0,x)
+--E 327
+
+)clear all
+
+--S 328 of 1125
+t0:=(A+B*x)*(d+e*x)^(3/2)*(b*x+c*x^2)
+--E 328
+
+--S 329 of 1125
+r0:=-2/5*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^(5/2)/e^4+2/7*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^(7/2)/e^4-2/9*(3*B*c*d-b*B*e-A*c*e)*_
+     (d+e*x)^(9/2)/e^4+2/11*B*c*(d+e*x)^(11/2)/e^4
+--E 329
+
+--S 330 of 1125
+d0:=D(m0,x)
+--E 330
+
+)clear all
+
+--S 331 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)*sqrt(d+e*x)
+--E 331
+
+--S 332 of 1125
+r0:=-2/3*d*(B*d-A*e)*(c*d-b*e)*(d+e*x)^(3/2)/e^4+2/5*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*(d+e*x)^(5/2)/e^4-2/7*(3*B*c*d-b*B*e-A*c*e)*_
+     (d+e*x)^(7/2)/e^4+2/9*B*c*(d+e*x)^(9/2)/e^4
+--E 332
+
+--S 333 of 1125
+d0:=D(m0,x)
+--E 333
+
+)clear all
+
+--S 334 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/sqrt(d+e*x)
+--E 334
+
+--S 335 of 1125
+r0:=2/3*(B*d*(3*c*d-2*b*e)-A*e*(2*c*d-b*e))*(d+e*x)^(3/2)/e^4-2/5*(3*B*c*d-_
+     b*B*e-A*c*e)*(d+e*x)^(5/2)/e^4+2/7*B*c*(d+e*x)^(7/2)/e^4-2*d*_
+     (B*d-A*e)*(c*d-b*e)*sqrt(d+e*x)/e^4
+--E 335
+
+--S 336 of 1125
+d0:=D(m0,x)
+--E 336
+
+)clear all
+
+--S 337 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^(3/2)
+--E 337
+
+--S 338 of 1125
+r0:=-2/3*(3*B*c*d-b*B*e-A*c*e)*(d+e*x)^(3/2)/e^4+2/5*B*c*(d+e*x)^(5/2)/e^4+_
+     2*d*(B*d-A*e)*(c*d-b*e)/(e^4*sqrt(d+e*x))+2*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))*sqrt(d+e*x)/e^4
+--E 338
+
+--S 339 of 1125
+d0:=D(m0,x)
+--E 339
+
+)clear all
+
+--S 340 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^(5/2)
+--E 340
+
+--S 341 of 1125
+r0:=2/3*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^(3/2))+2/3*B*c*(d+e*x)^(3/2)/e^4-_
+     2*(B*d*(3*c*d-2*b*e)-A*e*(2*c*d-b*e))/(e^4*sqrt(d+e*x))-_
+     2*(3*B*c*d-b*B*e-A*c*e)*sqrt(d+e*x)/e^4
+--E 341
+
+--S 342 of 1125
+d0:=D(m0,x)
+--E 342
+
+)clear all
+
+--S 343 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)/(d+e*x)^(7/2)
+--E 343
+
+--S 344 of 1125
+r0:=2/5*d*(B*d-A*e)*(c*d-b*e)/(e^4*(d+e*x)^(5/2))-2/3*(B*d*(3*c*d-2*b*e)-_
+     A*e*(2*c*d-b*e))/(e^4*(d+e*x)^(3/2))+2*(3*B*c*d-b*B*e-A*c*e)/_
+     (e^4*sqrt(d+e*x))+2*B*c*sqrt(d+e*x)/e^4
+--E 344
+
+--S 345 of 1125
+d0:=D(m0,x)
+--E 345
+
+)clear all
+
+--S 346 of 1125
+t0:=(A+B*x)*(d+e*x)^(7/2)*(b*x+c*x^2)^2
+--E 346
+
+--S 347 of 1125
+r0:=-2/9*d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^(9/2)/e^6+2/11*d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(11/2)/e^6+_
+     2/13*(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*(d+e*x)^(13/2)/e^6-2/15*(2*A*c*e*(2*c*d-b*e)-_
+     B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*(d+e*x)^(15/2)/e^6-2/17*c*_
+     (5*B*c*d-2*b*B*e-A*c*e)*(d+e*x)^(17/2)/e^6+2/19*B*c^2*(d+e*x)^(19/2)/e^6
+--E 347
+
+--S 348 of 1125
+d0:=D(m0,x)
+--E 348
+
+)clear all
+
+--S 349 of 1125
+t0:=(A+B*x)*(d+e*x)^(5/2)*(b*x+c*x^2)^2
+--E 349
+
+--S 350 of 1125
+r0:=-2/7*d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^(7/2)/e^6+2/9*d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(9/2)/e^6+2/11*_
+     (A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*(d+e*x)^(11/2)/e^6-2/13*(2*A*c*e*(2*c*d-b*e)-_
+     B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*(d+e*x)^(13/2)/e^6-2/15*c*_
+     (5*B*c*d-2*b*B*e-A*c*e)*(d+e*x)^(15/2)/e^6+2/17*B*c^2*(d+e*x)^(17/2)/e^6
+--E 350
+
+--S 351 of 1125
+d0:=D(m0,x)
+--E 351
+
+)clear all
+
+--S 352 of 1125
+t0:=(A+B*x)*(d+e*x)^(3/2)*(b*x+c*x^2)^2
+--E 352
+
+--S 353 of 1125
+r0:=-2/5*d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^(5/2)/e^6+2/7*d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(7/2)/e^6+2/9*(A*e*_
+     (6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*_
+     (d+e*x)^(9/2)/e^6-2/11*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-8*b*c*d*e+_
+     b^2*e^2))*(d+e*x)^(11/2)/e^6-2/13*c*(5*B*c*d-2*b*B*e-A*c*e)*_
+     (d+e*x)^(13/2)/e^6+2/15*B*c^2*(d+e*x)^(15/2)/e^6
+--E 353
+
+--S 354 of 1125
+d0:=D(m0,x)
+--E 354
+
+)clear all
+
+--S 355 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^2*sqrt(d+e*x)
+--E 355
+
+--S 356 of 1125
+r0:=-2/3*d^2*(B*d-A*e)*(c*d-b*e)^2*(d+e*x)^(3/2)/e^6+2/5*d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(5/2)/e^6+2/7*(A*e*_
+     (6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+3*b^2*e^2))*_
+     (d+e*x)^(7/2)/e^6-2/9*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-_
+     8*b*c*d*e+b^2*e^2))*(d+e*x)^(9/2)/e^6-2/11*c*(5*B*c*d-2*b*B*e-A*c*e)*_
+     (d+e*x)^(11/2)/e^6+2/13*B*c^2*(d+e*x)^(13/2)/e^6
+--E 356
+
+--S 357 of 1125
+d0:=D(m0,x)
+--E 357
+
+)clear all
+
+--S 358 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^2/sqrt(d+e*x)
+--E 358
+
+--S 359 of 1125
+r0:=2/3*d*(c*d-b*e)*(B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))*(d+e*x)^(3/2)/e^6+_
+     2/5*(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*(d+e*x)^(5/2)/e^6-2/7*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-_
+     8*b*c*d*e+b^2*e^2))*(d+e*x)^(7/2)/e^6-2/9*c*(5*B*c*d-2*b*B*e-A*c*e)*_
+     (d+e*x)^(9/2)/e^6+2/11*B*c^2*(d+e*x)^(11/2)/e^6-2*d^2*(B*d-A*e)*_
+     (c*d-b*e)^2*sqrt(d+e*x)/e^6
+--E 359
+
+--S 360 of 1125
+d0:=D(m0,x)
+--E 360
+
+)clear all
+
+--S 361 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^(3/2)
+--E 361
+
+--S 362 of 1125
+r0:=2/3*(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*(d+e*x)^(3/2)/e^6-2/5*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-_
+     8*b*c*d*e+b^2*e^2))*(d+e*x)^(5/2)/e^6-2/7*c*(5*B*c*d-2*b*B*e-A*c*e)*_
+     (d+e*x)^(7/2)/e^6+2/9*B*c^2*(d+e*x)^(9/2)/e^6+2*d^2*(B*d-A*e)*_
+     (c*d-b*e)^2/(e^6*sqrt(d+e*x))+2*d*(c*d-b*e)*(B*d*(5*c*d-3*b*e)-_
+     2*A*e*(2*c*d-b*e))*sqrt(d+e*x)/e^6
+--E 362
+
+--S 363 of 1125
+d0:=D(m0,x)
+--E 363
+
+)clear all
+
+--S 364 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^(5/2)
+--E 364
+
+--S 365 of 1125
+r0:=2/3*d^2*(B*d-A*e)*(c*d-b*e)^2/(e^6*(d+e*x)^(3/2))-2/3*(2*A*c*e*(2*c*d-_
+     b*e)-B*(10*c^2*d^2-8*b*c*d*e+b^2*e^2))*(d+e*x)^(3/2)/e^6-2/5*c*_
+     (5*B*c*d-2*b*B*e-A*c*e)*(d+e*x)^(5/2)/e^6+2/7*B*c^2*(d+e*x)^(7/2)/e^6-_
+     2*d*(c*d-b*e)*(B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))/(e^6*sqrt(d+e*x))+_
+     2*(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))*sqrt(d+e*x)/e^6
+--E 365
+
+--S 366 of 1125
+d0:=D(m0,x)
+--E 366
+
+)clear all
+
+--S 367 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^2/(d+e*x)^(7/2)
+--E 367
+
+--S 368 of 1125
+r0:=2/5*d^2*(B*d-A*e)*(c*d-b*e)^2/(e^6*(d+e*x)^(5/2))-2/3*d*(c*d-b*e)*_
+     (B*d*(5*c*d-3*b*e)-2*A*e*(2*c*d-b*e))/(e^6*(d+e*x)^(3/2))-2/3*c*_
+     (5*B*c*d-2*b*B*e-A*c*e)*(d+e*x)^(3/2)/e^6+2/5*B*c^2*(d+e*x)^(5/2)/e^6-_
+     2*(A*e*(6*c^2*d^2-6*b*c*d*e+b^2*e^2)-B*d*(10*c^2*d^2-12*b*c*d*e+_
+     3*b^2*e^2))/(e^6*sqrt(d+e*x))-2*(2*A*c*e*(2*c*d-b*e)-B*(10*c^2*d^2-_
+     8*b*c*d*e+b^2*e^2))*sqrt(d+e*x)/e^6
+--E 368
+
+--S 369 of 1125
+d0:=D(m0,x)
+--E 369
+
+)clear all
+
+--S 370 of 1125
+t0:=(A+B*x)*(d+e*x)^(7/2)/(b*x+c*x^2)
+--E 370
+
+--S 371 of 1125
+r0:=2/3*(B*(c*d-b*e)^2+A*c*e*(2*c*d-b*e))*(d+e*x)^(3/2)/c^3+2/5*_
+     (B*c*d-b*B*e+A*c*e)*(d+e*x)^(5/2)/c^2+2/7*B*(d+e*x)^(7/2)/c-_
+     2*A*d^(7/2)*atanh(sqrt(d+e*x)/sqrt(d))/b-2*(b*B-A*c)*(c*d-b*e)^(7/2)*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b*c^(9/2))+2*(B*(c*d-b*e)^3+_
+     A*c*e*(3*c^2*d^2-3*b*c*d*e+b^2*e^2))*sqrt(d+e*x)/c^4
+--E 371
+
+--S 372 of 1125
+d0:=D(m0,x)
+--E 372
+
+)clear all
+
+--S 373 of 1125
+t0:=(A+B*x)*(d+e*x)^(5/2)/(b*x+c*x^2)
+--E 373
+
+--S 374 of 1125
+r0:=2/3*(B*c*d-b*B*e+A*c*e)*(d+e*x)^(3/2)/c^2+2/5*B*(d+e*x)^(5/2)/c-_
+     2*A*d^(5/2)*atanh(sqrt(d+e*x)/sqrt(d))/b-2*(b*B-A*c)*(c*d-b*e)^(5/2)*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b*c^(7/2))+2*(B*(c*d-b*e)^2+_
+     A*c*e*(2*c*d-b*e))*sqrt(d+e*x)/c^3
+--E 374
+
+--S 375 of 1125
+d0:=D(m0,x)
+--E 375
+
+)clear all
+
+--S 376 of 1125
+t0:=(A+B*x)*(d+e*x)^(3/2)/(b*x+c*x^2)
+--E 376
+
+--S 377 of 1125
+r0:=2/3*B*(d+e*x)^(3/2)/c-2*A*d^(3/2)*atanh(sqrt(d+e*x)/sqrt(d))/b-_
+     2*(b*B-A*c)*(c*d-b*e)^(3/2)*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))/(b*c^(5/2))+2*(B*c*d-b*B*e+A*c*e)*sqrt(d+e*x)/c^2
+--E 377
+
+--S 378 of 1125
+d0:=D(m0,x)
+--E 378
+
+)clear all
+
+--S 379 of 1125
+t0:=(A+B*x)*sqrt(d+e*x)/(b*x+c*x^2)
+--E 379
+
+--S 380 of 1125
+r0:=-2*A*atanh(sqrt(d+e*x)/sqrt(d))*sqrt(d)/b-2*(b*B-A*c)*atanh(sqrt(c)*_
+     sqrt(d+e*x)/sqrt(c*d-b*e))*sqrt(c*d-b*e)/(b*c^(3/2))+2*B*sqrt(d+e*x)/c
+--E 380
+
+--S 381 of 1125
+d0:=D(m0,x)
+--E 381
+
+)clear all
+
+--S 382 of 1125
+t0:=(A+B*x)/((b*x+c*x^2)*sqrt(d+e*x))
+--E 382
+
+--S 383 of 1125
+r0:=-2*A*atanh(sqrt(d+e*x)/sqrt(d))/(b*sqrt(d))-2*(b*B-A*c)*atanh(sqrt(c)*_
+     sqrt(d+e*x)/sqrt(c*d-b*e))/(b*sqrt(c)*sqrt(c*d-b*e))
+--E 383
+
+--S 384 of 1125
+d0:=D(m0,x)
+--E 384
+
+)clear all
+
+--S 385 of 1125
+t0:=(A+B*x)/((d+e*x)^(3/2)*(b*x+c*x^2))
+--E 385
+
+--S 386 of 1125
+r0:=-2*A*atanh(sqrt(d+e*x)/sqrt(d))/(b*d^(3/2))-2*(b*B-A*c)*atanh(sqrt(c)*_
+     sqrt(d+e*x)/sqrt(c*d-b*e))*sqrt(c)/(b*(c*d-b*e)^(3/2))+_
+     2*(B*d-A*e)/(d*(c*d-b*e)*sqrt(d+e*x))
+--E 386
+
+--S 387 of 1125
+d0:=D(m0,x)
+--E 387
+
+)clear all
+
+--S 388 of 1125
+t0:=(A+B*x)/((d+e*x)^(5/2)*(b*x+c*x^2))
+--E 388
+
+--S 389 of 1125
+r0:=2/3*(B*d-A*e)/(d*(c*d-b*e)*(d+e*x)^(3/2))-2*A*atanh(sqrt(d+e*x)/_
+     sqrt(d))/(b*d^(5/2))-2*c^(3/2)*(b*B-A*c)*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))/(b*(c*d-b*e)^(5/2))+2*(B*c*d^2-A*e*(2*c*d-b*e))/(d^2*_
+     (c*d-b*e)^2*sqrt(d+e*x))
+--E 389
+
+--S 390 of 1125
+d0:=D(m0,x)
+--E 390
+
+)clear all
+
+--S 391 of 1125
+t0:=(A+B*x)/((d+e*x)^(7/2)*(b*x+c*x^2))
+--E 391
+
+--S 392 of 1125
+r0:=2/5*(B*d-A*e)/(d*(c*d-b*e)*(d+e*x)^(5/2))+2/3*(B*c*d^2-A*e*(2*c*d-_
+     b*e))/(d^2*(c*d-b*e)^2*(d+e*x)^(3/2))-2*A*atanh(sqrt(d+e*x)/_
+     sqrt(d))/(b*d^(7/2))-2*c^(5/2)*(b*B-A*c)*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))/(b*(c*d-b*e)^(7/2))+2*(B*c^2*d^3-A*e*(3*c^2*d^2-_
+     3*b*c*d*e+b^2*e^2))/(d^3*(c*d-b*e)^3*sqrt(d+e*x))
+--E 392
+
+--S 393 of 1125
+d0:=D(m0,x)
+--E 393
+
+)clear all
+
+--S 394 of 1125
+t0:=(A+B*x)/((d+e*x)^(9/2)*(b*x+c*x^2))
+--E 394
+
+--S 395 of 1125
+r0:=2/7*(B*d-A*e)/(d*(c*d-b*e)*(d+e*x)^(7/2))+2/5*(B*c*d^2-A*e*(2*c*d-b*e))/_
+     (d^2*(c*d-b*e)^2*(d+e*x)^(5/2))+2/3*(B*c^2*d^3-A*e*(3*c^2*d^2-_
+     3*b*c*d*e+b^2*e^2))/(d^3*(c*d-b*e)^3*(d+e*x)^(3/2))-_
+     2*A*atanh(sqrt(d+e*x)/sqrt(d))/(b*d^(9/2))-2*c^(7/2)*(b*B-A*c)*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b*(c*d-b*e)^(9/2))+_
+     2*(B*c^3*d^4-A*e*(4*c^3*d^3-6*b*c^2*d^2*e+4*b^2*c*d*e^2-b^3*e^3))/_
+     (d^4*(c*d-b*e)^4*sqrt(d+e*x))
+--E 395
+
+--S 396 of 1125
+d0:=D(m0,x)
+--E 396
+
+)clear all
+
+--S 397 of 1125
+t0:=(A+B*x)*(d+e*x)^(9/2)/(b*x+c*x^2)^2
+--E 397
+
+--S 398 of 1125
+r0:=1/3*e*(6*A*c^3*d^2-7*b^3*B*e^2-3*b*c^2*d*(B*d+2*A*e)+b^2*c*e*_
+     (12*B*d+5*A*e))*(d+e*x)^(3/2)/(b^2*c^3)+1/5*e*(10*A*c^2*d+7*b^2*B*e-_
+     5*b*c*(B*d+A*e))*(d+e*x)^(5/2)/(b^2*c^2)+(b*B-2*A*c)*(c*d-b*e)*_
+     (d+e*x)^(7/2)/(b^2*c*(b+c*x))-A*(d+e*x)^(9/2)/(b*x*(b+c*x))-_
+     d^(7/2)*(2*b*B*d-4*A*c*d+9*A*b*e)*atanh(sqrt(d+e*x)/sqrt(d))/b^3-_
+     (c*d-b*e)^(7/2)*(4*A*c^2*d-7*b^2*B*e-b*c*(2*B*d-5*A*e))*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^3*c^(9/2))+_
+     e*(2*A*c^4*d^3+7*b^4*B*e^3-b*c^3*d^2*(B*d+3*A*e)-b^3*c*e^2*_
+     (19*B*d+5*A*e)+b^2*c^2*d*e*(15*B*d+11*A*e))*sqrt(d+e*x)/(b^2*c^4)
+--E 398
+
+--S 399 of 1125
+d0:=D(m0,x)
+--E 399
+
+)clear all
+
+--S 400 of 1125
+t0:=(A+B*x)*(d+e*x)^(7/2)/(b*x+c*x^2)^2
+--E 400
+
+--S 401 of 1125
+r0:=1/3*e*(6*A*c^2*d+5*b^2*B*e-3*b*c*(B*d+A*e))*(d+e*x)^(3/2)/(b^2*c^2)+_
+     (b*B-2*A*c)*(c*d-b*e)*(d+e*x)^(5/2)/(b^2*c*(b+c*x))-A*(d+e*x)^(7/2)/_
+     (b*x*(b+c*x))-d^(5/2)*(2*b*B*d-4*A*c*d+7*A*b*e)*atanh(sqrt(d+e*x)/_
+     sqrt(d))/b^3+(c*d-b*e)^(5/2)*(2*b*B*c*d-4*A*c^2*d+5*b^2*B*e-_
+     3*A*b*c*e)*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^3*c^(7/2))+_
+     e*(2*A*c^3*d^2-5*b^3*B*e^2-b*c^2*d*(B*d+2*A*e)+b^2*c*e*(8*B*d+_
+     3*A*e))*sqrt(d+e*x)/(b^2*c^3)
+--E 401
+
+--S 402 of 1125
+d0:=D(m0,x)
+--E 402
+
+)clear all
+
+--S 403 of 1125
+t0:=(A+B*x)*(d+e*x)^(5/2)/(b*x+c*x^2)^2
+--E 403
+
+--S 404 of 1125
+r0:=(b*B-2*A*c)*(c*d-b*e)*(d+e*x)^(3/2)/(b^2*c*(b+c*x))-A*(d+e*x)^(5/2)/_
+     (b*x*(b+c*x))-d^(3/2)*(2*b*B*d-4*A*c*d+5*A*b*e)*atanh(sqrt(d+e*x)/_
+     sqrt(d))/b^3-(c*d-b*e)^(3/2)*(4*A*c^2*d-3*b^2*B*e-b*c*(2*B*d-A*e))*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^3*c^(5/2))+e*(2*A*c^2*d+_
+     3*b^2*B*e-b*c*(B*d+A*e))*sqrt(d+e*x)/(b^2*c^2)
+--E 404
+
+--S 405 of 1125
+d0:=D(m0,x)
+--E 405
+
+)clear all
+
+--S 406 of 1125
+t0:=(A+B*x)*(d+e*x)^(3/2)/(b*x+c*x^2)^2
+--E 406
+
+--S 407 of 1125
+r0:=-A*(d+e*x)^(3/2)/(b*x*(b+c*x))-(2*b*B*d-4*A*c*d+3*A*b*e)*_
+     atanh(sqrt(d+e*x)/sqrt(d))*sqrt(d)/b^3-(4*A*c^2*d-b^2*B*e-_
+     b*c*(2*B*d+A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))*_
+     sqrt(c*d-b*e)/(b^3*c^(3/2))+(b*B-2*A*c)*(c*d-b*e)*sqrt(d+e*x)/_
+     (b^2*c*(b+c*x))
+--E 407
+
+--S 408 of 1125
+d0:=D(m0,x)
+--E 408
+
+)clear all
+
+--S 409 of 1125
+t0:=(A+B*x)*sqrt(d+e*x)/(b*x+c*x^2)^2
+--E 409
+
+--S 410 of 1125
+r0:=-(2*b*B*d-4*A*c*d+A*b*e)*atanh(sqrt(d+e*x)/sqrt(d))/(b^3*sqrt(d))+_
+     (2*b*B*c*d-4*A*c^2*d-b^2*B*e+3*A*b*c*e)*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))/(b^3*sqrt(c)*sqrt(c*d-b*e))+(b*B-2*A*c)*sqrt(d+e*x)/_
+     (b^2*(b+c*x))-A*sqrt(d+e*x)/(b*x*(b+c*x))
+--E 410
+
+--S 411 of 1125
+d0:=D(m0,x)
+--E 411
+
+)clear all
+
+--S 412 of 1125
+t0:=(A+B*x)/((b*x+c*x^2)^2*sqrt(d+e*x))
+--E 412
+
+--S 413 of 1125
+r0:=-(2*b*B*d-4*A*c*d-A*b*e)*atanh(sqrt(d+e*x)/sqrt(d))/(b^3*d^(3/2))+_
+     (2*b*B*c*d-4*A*c^2*d-3*b^2*B*e+5*A*b*c*e)*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))*sqrt(c)/(b^3*(c*d-b*e)^(3/2))+c*(b*B*d-2*A*c*d+A*b*e)*_
+     sqrt(d+e*x)/(b^2*d*(c*d-b*e)*(b+c*x))-A*sqrt(d+e*x)/(b*d*x*(b+c*x))
+--E 413
+
+--S 414 of 1125
+d0:=D(m0,x)
+--E 414
+
+)clear all
+
+--S 415 of 1125
+t0:=(A+B*x)/((d+e*x)^(3/2)*(b*x+c*x^2)^2)
+--E 415
+
+--S 416 of 1125
+r0:=-(2*b*B*d-4*A*c*d-3*A*b*e)*atanh(sqrt(d+e*x)/sqrt(d))/(b^3*d^(5/2))-_
+     c^(3/2)*(4*A*c^2*d+5*b^2*B*e-b*c*(2*B*d+7*A*e))*atanh(sqrt(c)*_
+     sqrt(d+e*x)/sqrt(c*d-b*e))/(b^3*(c*d-b*e)^(5/2))-e*(2*A*c^2*d^2-_
+     b^2*e*(2*B*d-3*A*e)-b*c*d*(B*d+2*A*e))/(b^2*d^2*(c*d-b*e)^2*_
+     sqrt(d+e*x))+c*(b*B*d-2*A*c*d+A*b*e)/(b^2*d*(c*d-b*e)*(b+c*x)*_
+     sqrt(d+e*x))-A/(b*d*x*(b+c*x)*sqrt(d+e*x))
+--E 416
+
+--S 417 of 1125
+d0:=D(m0,x)
+--E 417
+
+)clear all
+
+--S 418 of 1125
+t0:=(A+B*x)/((d+e*x)^(5/2)*(b*x+c*x^2)^2)
+--E 418
+
+--S 419 of 1125
+r0:=-1/3*e*(6*A*c^2*d^2-b^2*e*(2*B*d-5*A*e)-3*b*c*d*(B*d+2*A*e))/_
+     (b^2*d^2*(c*d-b*e)^2*(d+e*x)^(3/2))+c*(b*B*d-2*A*c*d+A*b*e)/_
+     (b^2*d*(c*d-b*e)*(b+c*x)*(d+e*x)^(3/2))-A/(b*d*x*(b+c*x)*_
+     (d+e*x)^(3/2))-(2*b*B*d-4*A*c*d-5*A*b*e)*atanh(sqrt(d+e*x)/sqrt(d))/_
+     (b^3*d^(7/2))+c^(5/2)*(2*b*B*c*d-4*A*c^2*d-7*b^2*B*e+9*A*b*c*e)*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^3*(c*d-b*e)^(7/2))-_
+     e*(2*A*c^3*d^3-b^2*c*d*e*(6*B*d-11*A*e)+b^3*e^2*(2*B*d-5*A*e)-_
+     b*c^2*d^2*(B*d+3*A*e))/(b^2*d^3*(c*d-b*e)^3*sqrt(d+e*x))
+--E 419
+
+--S 420 of 1125
+d0:=D(m0,x)
+--E 420
+
+)clear all
+
+--S 421 of 1125
+t0:=(A+B*x)/((d+e*x)^(7/2)*(b*x+c*x^2)^2)
+--E 421
+
+--S 422 of 1125
+r0:=-1/5*e*(10*A*c^2*d^2-b^2*e*(2*B*d-7*A*e)-5*b*c*d*(B*d+2*A*e))/_
+     (b^2*d^2*(c*d-b*e)^2*(d+e*x)^(5/2))+c*(b*B*d-2*A*c*d+A*b*e)/_
+     (b^2*d*(c*d-b*e)*(b+c*x)*(d+e*x)^(5/2))-A/(b*d*x*(b+c*x)*_
+     (d+e*x)^(5/2))-1/3*e*(6*A*c^3*d^3-b^2*c*d*e*(6*B*d-17*A*e)+_
+     b^3*e^2*(2*B*d-7*A*e)-3*b*c^2*d^2*(B*d+3*A*e))/(b^2*d^3*_
+     (c*d-b*e)^3*(d+e*x)^(3/2))-(2*b*B*d-4*A*c*d-7*A*b*e)*_
+     atanh(sqrt(d+e*x)/sqrt(d))/(b^3*d^(9/2))-c^(7/2)*(4*A*c^2*d+9*b^2*B*e-_
+     b*c*(2*B*d+11*A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/_
+     (b^3*(c*d-b*e)^(9/2))-e*(2*A*c^4*d^4-2*b^2*c^2*d^2*e*(6*B*d-13*A*e)-_
+     b^4*e^3*(2*B*d-7*A*e)+8*b^3*c*d*e^2*(B*d-3*A*e)-b*c^3*d^3*_
+     (B*d+4*A*e))/(b^2*d^4*(c*d-b*e)^4*sqrt(d+e*x))
+--E 422
+
+--S 423 of 1125
+d0:=D(m0,x)
+--E 423
+
+)clear all
+
+--S 424 of 1125
+t0:=(A+B*x)*(d+e*x)^(9/2)/(b*x+c*x^2)^3
+--E 424
+
+--S 425 of 1125
+r0:=1/4*(c*d-b*e)*(24*A*c^3*d^2+5*b^3*B*e^2+b^2*c*e*(3*B*d-A*e)-_
+     12*b*c^2*d*(B*d+2*A*e))*(d+e*x)^(3/2)/(b^4*c^2*(b+c*x))-_
+     1/4*(c*d-b*e)*(6*b*B*c*d-12*A*c^2*d-2*b^2*B*e+13*A*b*c*e)*_
+     (d+e*x)^(5/2)/(b^3*c*(b+c*x)^2)-1/4*(4*b*B*d-8*A*c*d+9*A*b*e)*_
+     (d+e*x)^(7/2)/(b^2*x*(b+c*x)^2)-1/2*A*(d+e*x)^(9/2)/(b*x^2*_
+     (b+c*x)^2)-3/4*d^(5/2)*(16*A*c^2*d^2+3*b^2*e*(4*B*d+7*A*e)-_
+     4*b*c*d*(2*B*d+9*A*e))*atanh(sqrt(d+e*x)/sqrt(d))/b^5+_
+     3/4*(c*d-b*e)^(5/2)*(16*A*c^3*d^2-5*b^3*B*e^2-4*b*c^2*d*_
+     (2*B*d-A*e)-b^2*c*e*(8*B*d-A*e))*atanh(sqrt(c)*sqrt(d+e*x)/_
+     sqrt(c*d-b*e))/(b^5*c^(7/2))-3/4*e*(8*A*c^4*d^3-5*b^4*B*e^3+_
+     b^3*c*e^2*(2*B*d+A*e)+b^2*c^2*d*e*(3*B*d+2*A*e)-4*b*c^3*d^2*_
+     (B*d+3*A*e))*sqrt(d+e*x)/(b^4*c^3)
+--E 425
+
+--S 426 of 1125
+d0:=D(m0,x)
+--E 426
+
+)clear all
+
+--S 427 of 1125
+t0:=(A+B*x)*(d+e*x)^(7/2)/(b*x+c*x^2)^3
+--E 427
+
+--S 428 of 1125
+r0:=-1/4*(c*d-b*e)*(6*b*B*c*d-12*A*c^2*d-2*b^2*B*e+11*A*b*c*e)*_
+     (d+e*x)^(3/2)/(b^3*c*(b+c*x)^2)-1/4*(4*b*B*d-8*A*c*d+7*A*b*e)*_
+     (d+e*x)^(5/2)/(b^2*x*(b+c*x)^2)-1/2*A*(d+e*x)^(7/2)/(b*x^2*_
+     (b+c*x)^2)-1/4*d^(3/2)*(48*A*c^2*d^2+7*b^2*e*(4*B*d+5*A*e)-_
+     12*b*c*d*(2*B*d+7*A*e))*atanh(sqrt(d+e*x)/sqrt(d))/b^5+1/4*_
+     (c*d-b*e)^(3/2)*(48*A*c^3*d^2-3*b^3*B*e^2-12*b*c^2*d*(2*B*d+A*e)-_
+     b^2*c*e*(8*B*d+A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/_
+     (b^5*c^(5/2))+1/4*(c*d-b*e)*(24*A*c^3*d^2+3*b^3*B*e^2+b^2*c*e*_
+     (5*B*d+A*e)-12*b*c^2*d*(B*d+2*A*e))*sqrt(d+e*x)/(b^4*c^2*(b+c*x))
+--E 428
+
+--S 429 of 1125
+d0:=D(m0,x)
+--E 429
+
+)clear all
+
+--S 430 of 1125
+t0:=(A+B*x)*(d+e*x)^(5/2)/(b*x+c*x^2)^3
+--E 430
+
+--S 431 of 1125
+r0:=-1/4*(4*b*B*d-8*A*c*d+5*A*b*e)*(d+e*x)^(3/2)/(b^2*x*(b+c*x)^2)-_
+     1/2*A*(d+e*x)^(5/2)/(b*x^2*(b+c*x)^2)-1/4*(48*A*c^2*d^2+5*b^2*e*_
+     (4*B*d+3*A*e)-12*b*c*d*(2*B*d+5*A*e))*atanh(sqrt(d+e*x)/sqrt(d))*_
+     sqrt(d)/b^5+1/4*(48*A*c^3*d^2+b^3*B*e^2-12*b*c^2*d*(2*B*d+3*A*e)+_
+     b^2*c*e*(8*B*d+3*A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))*_
+     sqrt(c*d-b*e)/(b^5*c^(3/2))-1/4*(c*d-b*e)*(6*b*B*c*d-12*A*c^2*d-_
+     2*b^2*B*e+9*A*b*c*e)*sqrt(d+e*x)/(b^3*c*(b+c*x)^2)+1/4*_
+     (24*A*c^3*d^2+b^3*B*e^2-12*b*c^2*d*(B*d+2*A*e)+b^2*c*e*_
+     (7*B*d+3*A*e))*sqrt(d+e*x)/(b^4*c*(b+c*x))
+--E 431
+
+--S 432 of 1125
+d0:=D(m0,x)
+--E 432
+
+)clear all
+
+--S 433 of 1125
+t0:=(A+B*x)*(d+e*x)^(3/2)/(b*x+c*x^2)^3
+--E 433
+
+--S 434 of 1125
+r0:=-1/2*A*(d+e*x)^(3/2)/(b*x^2*(b+c*x)^2)-3/4*(16*A*c^2*d^2+b^2*e*_
+     (4*B*d+A*e)-4*b*c*d*(2*B*d+3*A*e))*atanh(sqrt(d+e*x)/sqrt(d))/_
+     (b^5*sqrt(d))+3/4*(16*A*c^3*d^2-b^3*B*e^2-4*b*c^2*d*(2*B*d+5*A*e)+_
+     b^2*c*e*(8*B*d+5*A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/_
+     (b^5*sqrt(c)*sqrt(c*d-b*e))-1/4*(6*b*B*c*d-12*A*c^2*d-2*b^2*B*e+_
+     7*A*b*c*e)*sqrt(d+e*x)/(b^3*(b+c*x)^2)-1/4*(4*b*B*d-8*A*c*d+3*A*b*e)*_
+     sqrt(d+e*x)/(b^2*x*(b+c*x)^2)+3/4*(8*A*c^2*d+b^2*B*e-4*b*c*(B*d+A*e))*_
+     sqrt(d+e*x)/(b^4*(b+c*x))
+--E 434
+
+--S 435 of 1125
+d0:=D(m0,x)
+--E 435
+
+)clear all
+
+--S 436 of 1125
+t0:=(A+B*x)*sqrt(d+e*x)/(b*x+c*x^2)^3
+--E 436
+
+--S 437 of 1125
+r0:=-1/4*(48*A*c^2*d^2+b^2*e*(4*B*d-A*e)-12*b*c*d*(2*B*d+A*e))*_
+     atanh(sqrt(d+e*x)/sqrt(d))/(b^5*d^(3/2))+1/4*(48*A*c^3*d^2-_
+     15*b^3*B*e^2-12*b*c^2*d*(2*B*d+7*A*e)+5*b^2*c*e*(8*B*d+7*A*e))*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))*sqrt(c)/(b^5*_
+     (c*d-b*e)^(3/2))-1/4*c*(6*b*B*d-12*A*c*d+A*b*e)*sqrt(d+e*x)/_
+     (b^3*d*(b+c*x)^2)-1/2*A*sqrt(d+e*x)/(b*x^2*(b+c*x)^2)-_
+     1/4*(4*b*B*d-8*A*c*d+A*b*e)*sqrt(d+e*x)/(b^2*d*x*(b+c*x)^2)+_
+     1/4*c*(24*A*c^2*d^2+b^2*e*(11*B*d+A*e)-12*b*c*d*(B*d+2*A*e))*_
+     sqrt(d+e*x)/(b^4*d*(c*d-b*e)*(b+c*x))
+--E 437
+
+--S 438 of 1125
+d0:=D(m0,x)
+--E 438
+
+)clear all
+
+--S 439 of 1125
+t0:=(A+B*x)/((b*x+c*x^2)^3*sqrt(d+e*x))
+--E 439
+
+--S 440 of 1125
+r0:=-1/4*(48*A*c^2*d^2-b^2*e*(4*B*d-3*A*e)-12*b*c*d*(2*B*d-A*e))*_
+     atanh(sqrt(d+e*x)/sqrt(d))/(b^5*d^(5/2))+1/4*c^(3/2)*_
+     (48*A*c^3*d^2-35*b^3*B*e^2-12*b*c^2*d*(2*B*d+9*A*e)+7*b^2*c*e*_
+     (8*B*d+9*A*e))*atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^5*_
+     (c*d-b*e)^(5/2))+1/4*c*(12*A*c^2*d^2+b^2*e*(4*B*d-3*A*e)-b*c*d*_
+     (6*B*d+7*A*e))*sqrt(d+e*x)/(b^3*d^2*(c*d-b*e)*(b+c*x)^2)-1/2*A*_
+     sqrt(d+e*x)/(b*d*x^2*(b+c*x)^2)-1/4*(4*b*B*d-8*A*c*d-3*A*b*e)*_
+     sqrt(d+e*x)/(b^2*d^2*x*(b+c*x)^2)+1/4*c*(24*A*c^3*d^3-b^3*e^2*_
+     (4*B*d-3*A*e)-12*b*c^2*d^2*(B*d+3*A*e)+b^2*c*d*e*(19*B*d+6*A*e))*_
+     sqrt(d+e*x)/(b^4*d^2*(c*d-b*e)^2*(b+c*x))
+--E 440
+
+--S 441 of 1125
+d0:=D(m0,x)
+--E 441
+
+)clear all
+
+--S 442 of 1125
+t0:=(A+B*x)/((d+e*x)^(3/2)*(b*x+c*x^2)^3)
+--E 442
+
+--S 443 of 1125
+r0:=-3/4*(16*A*c^2*d^2-b^2*e*(4*B*d-5*A*e)-4*b*c*d*(2*B*d-3*A*e))*_
+     atanh(sqrt(d+e*x)/sqrt(d))/(b^5*d^(7/2))+3/4*c^(5/2)*(16*A*c^3*d^2-_
+     21*b^3*B*e^2-4*b*c^2*d*(2*B*d+11*A*e)+3*b^2*c*e*(8*B*d+11*A*e))*_
+     atanh(sqrt(c)*sqrt(d+e*x)/sqrt(c*d-b*e))/(b^5*(c*d-b*e)^(7/2))+_
+     3/4*e*(8*A*c^4*d^4+b^4*e^3*(4*B*d-5*A*e)-b^3*c*d*e^2*(4*B*d-3*A*e)-_
+     4*b*c^3*d^3*(B*d+4*A*e)+b^2*c^2*d^2*e*(9*B*d+5*A*e))/(b^4*d^3*_
+     (c*d-b*e)^3*sqrt(d+e*x))+1/4*c*(12*A*c^2*d^2+b^2*e*(4*B*d-5*A*e)-_
+     b*c*d*(6*B*d+5*A*e))/(b^3*d^2*(c*d-b*e)*(b+c*x)^2*sqrt(d+e*x))-_
+     1/2*A/(b*d*x^2*(b+c*x)^2*sqrt(d+e*x))+1/4*(-4*b*B*d+8*A*c*d+_
+     5*A*b*e)/(b^2*d^2*x*(b+c*x)^2*sqrt(d+e*x))+1/4*c*(24*A*c^3*d^3-_
+     b^3*e^2*(4*B*d-5*A*e)+b^2*c*d*e*(21*B*d+2*A*e)-12*b*c^2*d^2*(B*d+_
+     3*A*e))/(b^4*d^2*(c*d-b*e)^2*(b+c*x)*sqrt(d+e*x))
+--E 443
+
+--S 444 of 1125
+d0:=D(m0,x)
+--E 444
+
+)clear all
+
+--S 445 of 1125
+t0:=(A+B*x)/((d+e*x)^(5/2)*(b*x+c*x^2)^3)
+--E 445
+
+--S 446 of 1125
+r0:=1/12*e*(72*A*c^4*d^4+5*b^4*e^3*(4*B*d-7*A*e)-9*b^3*c*d*e^2*(4*B*d-_
+   5*A*e)-36*b*c^3*d^3*(B*d+4*A*e)+3*b^2*c^2*d^2*e*(29*B*d+9*A*e))/(b^4*_
+   d^3*(c*d-b*e)^3*(d+e*x)^(3/2))+1/4*c*(12*A*c^2*d^2+b^2*e*(4*B*d-7*A*e)-_
+   3*b*c*d*(2*B*d+A*e))/(b^3*d^2*(c*d-b*e)*(b+c*x)^2*(d+e*x)^(3/2))-_
+   1/2*A/(b*d*x^2*(b+c*x)^2*(d+e*x)^(3/2))+1/4*(-4*b*B*d+8*A*c*d+7*A*b*e)/_
+   (b^2*d^2*x*(b+c*x)^2*(d+e*x)^(3/2))+1/4*c*(24*A*c^3*d^3-b^3*e^2*_
+   (4*B*d-7*A*e)+b^2*c*d*e*(23*B*d-2*A*e)-12*b*c^2*d^2*(B*d+3*A*e))/_
+   (b^4*d^2*(c*d-b*e)^2*(b+c*x)*(d+e*x)^(3/2))-1/4*(48*A*c^2*d^2-_
+   5*b^2*e*(4*B*d-7*A*e)-12*b*c*d*(2*B*d-5*A*e))*atanh(sqrt(d+e*x)/_
+   sqrt(d))/(b^5*d^(9/2))+1/4*c^(7/2)*(48*A*c^3*d^2-99*b^3*B*e^2-_
+   12*b*c^2*d*(2*B*d+13*A*e)+11*b^2*c*e*(8*B*d+13*A*e))*atanh(sqrt(c)*_
+   sqrt(d+e*x)/sqrt(c*d-b*e))/(b^5*(c*d-b*e)^(9/2))+1/4*e*(24*A*c^5*d^5+_
+   8*b^4*c*d*e^3*(7*B*d-10*A*e)-5*b^5*e^4*(4*B*d-7*A*e)-6*b^3*_
+   c^2*d^2*e^2*(4*B*d-3*A*e)+7*b^2*c^3*d^3*e*(5*B*d+4*A*e)-12*b*c^4*d^4*_
+   (B*d+5*A*e))/(b^4*d^4*(c*d-b*e)^4*sqrt(d+e*x))
+--E 446
+
+--S 447 of 1125
+d0:=D(m0,x)
+--E 447
+
+)clear all
+
+--S 448 of 1125
+t0:=(A+B*x)*(d+e*x)^(1/2)*sqrt(b*x+c*x^2)
+--E 448
+
+--S 449 of 1125
+--r0:=2/7*B*(b*x+c*x^2)^(3/2)*sqrt(d+e*x)/c-2/105*(14*A*c*e*(c^2*d^2-_
+--     b*c*d*e+b^2*e^2)-B*(8*c^3*d^3-5*b*c^2*d^2*e-5*b^2*c*d*e^2+8*_
+--     b^3*e^3))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c^3*e^(5/2)*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/105*(-b)^(3/2)*_
+--     (c*d-b*e)*(7*A*c*e*(c*d-2*b*e)-B*(4*c^2*d^2+b*c*d*e-8*b^2*e^2))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(7/2)*e^2*sqrt(d+e*x)*sqrt(b*x+_
+--     c*x^2))+2/105*(7*A*c*e*(c*d+b*e)-B*(4*c^2*d^2-2*b*c*d*e+4*b^2*e^2)+_
+--     3*c*e*(B*c*d-4*b*B*e+7*A*c*e)*x)*sqrt(d+e*x)*sqrt(b*x+c*x^2)/(c^2*e^2)
+--E 449
+
+--S 450 of 1125
+d0:=D(m0,x)
+--E 450
+
+)clear all
+
+--S 451 of 1125
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^(1/2)
+--E 451
+
+--S 452 of 1125
+--r0:=-2/15*(5*A*c*e*(2*c*d-b*e)-B*(8*c^2*d^2-3*b*c*d*e-2*b^2*e^2))*_
+--     (b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*_
+--     sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c^2*e^(5/2)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/15*(-b)^(3/2)*(c*d-b*e)*(4*B*c*d+_
+--     2*b*B*e-5*A*c*e)*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),_
+--     b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(5/2)*e^2*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/15*(4*B*c*d-b*B*e-5*A*c*e-3*B*c*e*x)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2)/(c*e^2)
+--E 452
+
+--S 453 of 1125
+d0:=D(m0,x)
+--E 453
+
+)clear all
+
+--S 454 of 1125
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^(3/2)
+--E 454
+
+--S 455 of 1125
+--r0:=-2/3*(8*B*c*d-b*B*e-6*A*c*e)*(b+c*x)*elliptic_e(asin(sqrt(e)*_
+--     sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/_
+--     (c*e^(5/2)*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2/3*(-b)^(3/2)*(4*B*c*d-b*B*e-3*A*c*e)*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+_
+--     e*x)/d)/(c^(3/2)*e^2*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*(4*B*d-_
+--     3*A*e+B*e*x)*sqrt(b*x+c*x^2)/(e^2*sqrt(d+e*x))
+--E 455
+
+--S 456 of 1125
+d0:=D(m0,x)
+--E 456
+
+)clear all
+
+--S 457 of 1125
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^(5/2)
+--E 457
+
+--S 458 of 1125
+--r0:=-2/3*(B*d*(8*c*d-7*b*e)-A*e*(2*c*d-b*e))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(x)*_
+--     sqrt((d+e*x)/d)/(e^(5/2)*(c*d-b*e)*sqrt(-d)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*(-b)^(3/2)*(4*B*d-A*e)*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d*e^2*sqrt(c)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/3*(4*B*d-A*e+3*B*e*x)*sqrt(b*x+c*x^2)/(e^2*_
+--     (d+e*x)^(3/2))-2/3*(B*d*(8*c*d-7*b*e)-A*e*(2*c*d-b*e))*_
+--     sqrt(b*x+c*x^2)/(d*e^2*(c*d-b*e)*sqrt(d+e*x))
+--E 458
+
+--S 459 of 1125
+d0:=D(m0,x)
+--E 459
+
+)clear all
+
+--S 460 of 1125
+t0:=(A+B*x)*sqrt(b*x+c*x^2)/(d+e*x)^(7/2)
+--E 460
+
+--S 461 of 1125
+--r0:=-2/15*(2*A*e*(c^2*d^2-b*c*d*e+b^2*e^2)+B*d*(8*c^2*d^2-13*b*c*d*e+_
+--     3*b^2*e^2))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(x)*sqrt((d+e*x)/d)/((-d)^(3/2)*e^(5/2)*(c*d-b*e)^2*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/15*(-b)^(3/2)*(B*d*_
+--     (4*c*d-3*b*e)+A*e*(c*d-2*b*e))*elliptic_f(asin(sqrt(c)*sqrt(x)/_
+--     sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d^2*_
+--     e^2*(c*d-b*e)*sqrt(c)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/15*(B*d*(8*c*d-_
+--     9*b*e)+A*e*(2*c*d-b*e))*sqrt(b*x+c*x^2)/(d*e^2*(c*d-b*e)*(d+_
+--     e*x)^(3/2))-2/5*(4*B*d+A*e+5*B*e*x)*sqrt(b*x+c*x^2)/(e^2*(d+_
+--     e*x)^(5/2))+2/15*(2*A*e*(c^2*d^2-b*c*d*e+b^2*e^2)+B*d*(8*c^2*d^2-_
+--     13*b*c*d*e+3*b^2*e^2))*sqrt(b*x+c*x^2)/(d^2*e^2*(c*d-b*e)^2*sqrt(d+e*x))
+--E 461
+
+--S 462 of 1125
+d0:=D(m0,x)
+--E 462
+
+)clear all
+
+--S 463 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^(1/2)
+--E 463
+
+--S 464 of 1125
+--r0:=-2/63*(8*B*c*d-3*b*B*e-9*A*c*e-7*B*c*e*x)*(b*x+c*x^2)^(3/2)*_
+--     sqrt(d+e*x)/(c*e^2)-2/315*(18*A*c*e*(8*c^3*d^3-12*b*c^2*d^2*e+_
+--     2*b^2*c*d*e^2+b^3*e^3)-B*(128*c^4*d^4-184*b*c^3*d^3*e+27*_
+--     b^2*c^2*d^2*e^2+11*b^3*c*d*e^3+8*b^4*e^4))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*_
+--     sqrt(x)*sqrt((d+e*x)/d)/(c^3*e^(9/2)*sqrt((b+c*x)/b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2/315*(-b)^(3/2)*(c*d-b*e)*(9*A*c*e*(8*c^2*d^2-_
+--     5*b*c*d*e-2*b^2*e^2)-B*(64*c^3*d^3-36*b*c^2*d^2*e-15*b^2*c*d*e^2-_
+--     8*b^3*e^3))*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(7/2)*e^4*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/315*(9*A*c*e*(8*c^2*d^2-11*b*c*d*e+b^2*e^2)-_
+--     2*B*(32*c^3*d^3-42*b*c^2*d^2*e+3*b^2*c*d*e^2+2*b^3*e^3)-3*c*e*_
+--     (9*A*c*e*(2*c*d-b*e)-B*(16*c^2*d^2-7*b*c*d*e-4*b^2*e^2))*x)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2)/(c^2*e^4)
+--E 464
+
+--S 465 of 1125
+d0:=D(m0,x)
+--E 465
+
+)clear all
+
+--S 466 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^(3/2)
+--E 466
+
+--S 467 of 1125
+--r0:=2/7*(8*B*d-7*A*e+B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*sqrt(d+e*x))+2/35*_
+--     (5*b*c*e*(8*B*d-7*A*e)*(2*c*d-b*e)-(16*B*c*d-b*B*e-14*A*c*e)*_
+--     (8*c^2*d^2-3*b*c*d*e-2*b^2*e^2))*(b+c*x)*elliptic_e(asin(sqrt(e)*_
+--     sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/_
+--     (c^2*e^(9/2)*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/35*_
+--     (-b)^(3/2)*(c*d-b*e)*(7*A*c*e*(8*c*d-b*e)-2*B*(32*c^2*d^2-6*b*c*d*e-_
+--     b^2*e^2))*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(5/2)*e^4*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2/35*(7*A*c*e*(8*c*d-7*b*e)-B*(64*c^2*d^2-60*b*c*_
+--     d*e+b^2*e^2)+3*c*e*(16*B*c*d-b*B*e-14*A*c*e)*x)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2)/(c*e^4)
+--E 467
+
+--S 468 of 1125
+d0:=D(m0,x)
+--E 468
+
+)clear all
+
+--S 469 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^(5/2)
+--E 469
+
+--S 470 of 1125
+--r0:=2/15*(8*B*d-5*A*e+3*B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*(d+e*x)^(3/2))-_
+--     2/15*(40*A*c*e*(2*c*d-b*e)-B*(128*c^2*d^2-88*b*c*d*e+3*b^2*e^2))*_
+--     (b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*_
+--     sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c*e^(9/2)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/15*(-b)^(3/2)*(5*A*c*e*(8*c*d-5*b*e)-_
+--     B*(64*c^2*d^2-52*b*c*d*e+3*b^2*e^2))*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/(c^(3/2)*e^4*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2/15*(4*B*d*(16*c*d-9*b*e)-5*A*e*(8*c*d-3*b*e)+e*(16*B*c*d-_
+--     3*b*B*e-10*A*c*e)*x)*sqrt(b*x+c*x^2)/(e^4*sqrt(d+e*x))
+--E 470
+
+--S 471 of 1125
+d0:=D(m0,x)
+--E 471
+
+)clear all
+
+--S 472 of 1125
+t0:=(A+B*x)*(b*x+c*x^2)^(3/2)/(d+e*x)^(7/2)
+--E 472
+
+--S 473 of 1125
+--r0:=2/15*(8*B*d-3*A*e+5*B*e*x)*(b*x+c*x^2)^(3/2)/(e^2*(d+e*x)^(5/2))-_
+--     2/15*(3*A*e*(16*c^2*d^2-16*b*c*d*e+b^2*e^2)-B*d*(128*c^2*d^2-_
+--     168*b*c*d*e+43*b^2*e^2))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/_
+--     sqrt(-d)),c*d/(b*e))*sqrt(x)*sqrt((d+e*x)/d)/(e^(9/2)*(c*d-b*e)*_
+--     sqrt(-d)*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2/15*(-b)^(3/2)*(4*B*d*(16*c*d-7*b*e)-3*A*e*(8*c*d-b*e))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d*e^4*sqrt(c)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2/15*(4*B*d*(16*c*d-7*b*e)-3*A*e*(8*c*d-b*e)+_
+--     3*e*(16*B*c*d-5*b*B*e-6*A*c*e)*x)*sqrt(b*x+c*x^2)/(e^4*_
+--     (d+e*x)^(3/2))-2/15*(3*A*e*(16*c^2*d^2-16*b*c*d*e+b^2*e^2)-B*d*_
+--     (128*c^2*d^2-168*b*c*d*e+43*b^2*e^2))*sqrt(b*x+c*x^2)/(d*e^4*_
+--     (c*d-b*e)*sqrt(d+e*x))
+--E 473
+
+--S 474 of 1125
+d0:=D(m0,x)
+--E 474
+
+)clear all
+
+--S 475 of 1125
+t0:=(A+B*x)*(d+e*x)^(5/2)/sqrt(b*x+c*x^2)
+--E 475
+
+--S 476 of 1125
+--r0:=2/105*(7*A*c*e*(23*c^2*d^2-23*b*c*d*e+8*b^2*e^2)+B*(15*c^3*d^3-_
+--     103*b*c^2*d^2*e+128*b^2*c*d*e^2-48*b^3*e^3))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*_
+--     sqrt(x)*sqrt((d+e*x)/d)/(c^4*sqrt(e)*sqrt((b+c*x)/b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/105*(c*d-b*e)*(105*A*c^3*d^2-48*b^3*B*e^2+_
+--     8*b^2*c*e*(13*B*d+7*A*e)-b*c^2*d*(60*B*d+133*A*e))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(-b)*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(9/2)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/35*(5*B*c*d-6*b*B*e+7*A*c*e)*(d+e*x)^(3/2)*_
+--     sqrt(b*x+c*x^2)/c^2+2/7*B*(d+e*x)^(5/2)*sqrt(b*x+c*x^2)/c+2/105*_
+--     (28*A*c*e*(2*c*d-b*e)+B*(15*c^2*d^2-43*b*c*d*e+24*b^2*e^2))*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2)/c^3
+--E 476
+
+--S 477 of 1125
+d0:=D(m0,x)
+--E 477
+
+)clear all
+
+--S 478 of 1125
+t0:=(A+B*x)*(d+e*x)^(3/2)/sqrt(b*x+c*x^2)
+--E 478
+
+--S 479 of 1125
+--r0:=2/15*(10*A*c*e*(2*c*d-b*e)+B*(3*c^2*d^2-13*b*c*d*e+8*b^2*e^2))*_
+--     (b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*_
+--     sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c^3*sqrt(e)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/15*(c*d-b*e)*(9*b*B*c*d-15*A*c^2*d-_
+--     8*b^2*B*e+10*A*b*c*e)*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),_
+--     b*e/(c*d))*sqrt(-b)*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/_
+--     (c^(7/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/5*B*(d+e*x)^(3/2)*_
+--     sqrt(b*x+c*x^2)/c+2/15*(3*B*c*d-4*b*B*e+5*A*c*e)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2)/c^2
+--E 479
+
+--S 480 of 1125
+d0:=D(m0,x)
+--E 480
+
+)clear all
+
+--S 481 of 1125
+t0:=(A+B*x)*sqrt(d+e*x)/sqrt(b*x+c*x^2)
+--E 481
+
+--S 482 of 1125
+--r0:=2/3*(B*c*d-2*b*B*e+3*A*c*e)*(b+c*x)*elliptic_e(asin(sqrt(e)*_
+--     sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c^2*_
+--     sqrt(e)*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*(2*b*B-_
+--     3*A*c)*(c*d-b*e)*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),_
+--     b*e/(c*d))*sqrt(-b)*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/_
+--     (c^(5/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*B*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2)/c
+--E 482
+
+--S 483 of 1125
+d0:=D(m0,x)
+--E 483
+
+)clear all
+
+--S 484 of 1125
+t0:=(A+B*x)/(sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 484
+
+--S 485 of 1125
+--r0:=2*B*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*_
+--     sqrt(-d)*sqrt(x)*sqrt((d+e*x)/d)/(c*sqrt(e)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2*(b*B-A*c)*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(-b)*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/(c^(3/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 485
+
+--S 486 of 1125
+d0:=D(m0,x)
+--E 486
+
+)clear all
+
+--S 487 of 1125
+t0:=(A+B*x)/((d+e*x)^(3/2)*sqrt(b*x+c*x^2))
+--E 487
+
+--S 488 of 1125
+--r0:=2*(B*d-A*e)*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(x)*sqrt((d+e*x)/d)/((c*d-b*e)*sqrt(-d)*sqrt(e)*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2*A*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(-b)*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d*sqrt(c)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2*(B*d-A*e)*sqrt(b*x+c*x^2)/(d*(c*d-b*e)*sqrt(d+e*x))
+--E 488
+
+--S 489 of 1125
+d0:=D(m0,x)
+--E 489
+
+)clear all
+
+--S 490 of 1125
+t0:=(A+B*x)/((d+e*x)^(5/2)*sqrt(b*x+c*x^2))
+--E 490
+
+--S 491 of 1125
+--r0:=2/3*(2*A*e*(2*c*d-b*e)-B*d*(c*d+b*e))*(b+c*x)*elliptic_e(asin(_
+--     sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(x)*sqrt((d+e*x)/d)/_
+--     ((-d)^(3/2)*(c*d-b*e)^2*sqrt(e)*sqrt((b+c*x)/b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2/3*(b*B*d-3*A*c*d+2*A*b*e)*elliptic_f(asin(_
+--     sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(-b)*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d^2*(c*d-b*e)*sqrt(c)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/3*(B*d-A*e)*sqrt(b*x+c*x^2)/(d*(c*d-b*e)*_
+--     (d+e*x)^(3/2))-2/3*(2*A*e*(2*c*d-b*e)-B*d*(c*d+b*e))*sqrt(b*x+_
+--     c*x^2)/(d^2*(c*d-b*e)^2*sqrt(d+e*x))
+--E 491
+
+--S 492 of 1125
+d0:=D(m0,x)
+--E 492
+
+)clear all
+
+--S 493 of 1125
+t0:=(A+B*x)/((d+e*x)^(7/2)*sqrt(b*x+c*x^2))
+--E 493
+
+--S 494 of 1125
+--r0:=2/15*(B*d*(3*c^2*d^2+7*b*c*d*e-2*b^2*e^2)-A*e*(23*c^2*d^2-_
+--     23*b*c*d*e+8*b^2*e^2))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/_
+--     sqrt(-d)),c*d/(b*e))*sqrt(x)*sqrt((d+e*x)/d)/((-d)^(5/2)*_
+--     (c*d-b*e)^3*sqrt(e)*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+_
+--     2/15*(15*A*c^2*d^2+2*b^2*e*(B*d+4*A*e)-b*c*d*(6*B*d+19*A*e))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(-b)*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(d^3*(c*d-b*e)^2*sqrt(c)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/5*(B*d-A*e)*sqrt(b*x+c*x^2)/_
+--     (d*(c*d-b*e)*(d+e*x)^(5/2))-2/15*(4*A*e*(2*c*d-b*e)-B*d*(3*c*d+_
+--     b*e))*sqrt(b*x+c*x^2)/(d^2*(c*d-b*e)^2*(d+e*x)^(3/2))+2/15*(B*d*_
+--     (3*c^2*d^2+7*b*c*d*e-2*b^2*e^2)-A*e*(23*c^2*d^2-23*b*c*d*e+_
+--     8*b^2*e^2))*sqrt(b*x+c*x^2)/(d^3*(c*d-b*e)^3*sqrt(d+e*x))
+--E 494
+
+--S 495 of 1125
+d0:=D(m0,x)
+--E 495
+
+)clear all
+
+--S 496 of 1125
+t0:=(A+B*x)*(d+e*x)^(7/2)/(b*x+c*x^2)^(3/2)
+--E 496
+
+--S 497 of 1125
+--r0:=-2*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(7/2)/(b^2*sqrt(b*x+c*x^2))+_
+--     2/15*(30*A*c^4*d^3+48*b^4*B*e^3-15*b*c^3*d^2*(B*d+3*A*e)-_
+--     8*b^3*c*e^2*(16*B*d+5*A*e)+b^2*c^2*d*e*(103*B*d+95*A*e))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*_
+--     sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^2*c^4*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/15*e*(c*d-b*e)*(15*A*c^3*d^2-_
+--     48*b^3*B*e^2-15*b*c^2*d*(4*B*d+5*A*e)+8*b^2*c*e*(13*B*d+5*A*e))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(9/2)*sqrt(-b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2/5*e*(10*A*c^2*d+6*b^2*B*e-5*b*c*(B*d+A*e))*_
+--     (d+e*x)^(3/2)*sqrt(b*x+c*x^2)/(b^2*c^2)-2*(b*B-2*A*c)*e*_
+--     (d+e*x)^(5/2)*sqrt(b*x+c*x^2)/(b^2*c)+2/15*e*(30*A*c^3*d^2-_
+--     24*b^3*B*e^2-15*b*c^2*d*(B*d+2*A*e)+b^2*c*e*(43*B*d+20*A*e))*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2)/(b^2*c^3)
+--E 497
+
+--S 498 of 1125
+d0:=D(m0,x)
+--E 498
+
+)clear all
+
+--S 499 of 1125
+t0:=(A+B*x)*(d+e*x)^(5/2)/(b*x+c*x^2)^(3/2)
+--E 499
+
+--S 500 of 1125
+--r0:=-2*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(5/2)/(b^2*sqrt(b*x+c*x^2))+_
+--     2/3*(6*A*c^3*d^2-8*b^3*B*e^2-3*b*c^2*d*(B*d+2*A*e)+b^2*c*e*_
+--     (13*B*d+6*A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(-d)*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^2*c^3*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*e*(c*d-b*e)*_
+--     (9*b*B*c*d-3*A*c^2*d-8*b^2*B*e+6*A*b*c*e)*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/(c^(7/2)*sqrt(-b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2*(b*B-2*A*c)*e*(d+e*x)^(3/2)*sqrt(b*x+c*x^2)/(b^2*c)+2/3*e*_
+--     (6*A*c^2*d+4*b^2*B*e-3*b*c*(B*d+A*e))*sqrt(d+e*x)*sqrt(b*x+c*x^2)/_
+--     (b^2*c^2)
+--E 500
+
+--S 501 of 1125
+d0:=D(m0,x)
+--E 501
+
+)clear all
+
+--S 502 of 1125
+t0:=(A+B*x)*(d+e*x)^(3/2)/(b*x+c*x^2)^(3/2)
+--E 502
+
+--S 503 of 1125
+--r0:=-2*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(3/2)/(b^2*sqrt(b*x+c*x^2))+_
+--     2*(2*A*c^2*d+2*b^2*B*e-b*c*(B*d+A*e))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*_
+--     sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^2*c^2*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2*(2*b*B-A*c)*e*(c*d-b*e)*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(5/2)*sqrt(-b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2*(b*B-2*A*c)*e*sqrt(d+e*x)*sqrt(b*x+c*x^2)/(b^2*c)
+--E 503
+
+--S 504 of 1125
+d0:=D(m0,x)
+--E 504
+
+)clear all
+
+--S 505 of 1125
+t0:=(A+B*x)*sqrt(d+e*x)/(b*x+c*x^2)^(3/2)
+--E 505
+
+--S 506 of 1125
+--r0:=-2*(A*b-(b*B-2*A*c)*x)*sqrt(d+e*x)/(b^2*sqrt(b*x+c*x^2))-_
+--     2*(b*B-2*A*c)*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(-d)*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^2*c*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2*(b*B-A*c)*e*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/(c^(3/2)*sqrt(-b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))
+--E 506
+
+--S 507 of 1125
+d0:=D(m0,x)
+--E 507
+
+)clear all
+
+--S 508 of 1125
+t0:=(A+B*x)/((b*x+c*x^2)^(3/2)*sqrt(d+e*x))
+--E 508
+
+--S 509 of 1125
+--r0:=-2*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)*sqrt(d+e*x)/(b^2*d*_
+--     (c*d-b*e)*sqrt(b*x+c*x^2))+2*(b*B*d-2*A*c*d+A*b*e)*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(e)*_
+--     sqrt(x)*sqrt((d+e*x)/d)/(b^2*(c*d-b*e)*sqrt(-d)*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2*A*e*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/(d*sqrt(-b)*sqrt(c)*sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 509
+
+--S 510 of 1125
+d0:=D(m0,x)
+--E 510
+
+)clear all
+
+--S 511 of 1125
+t0:=(A+B*x)/((d+e*x)^(3/2)*(b*x+c*x^2)^(3/2))
+--E 511
+
+--S 512 of 1125
+--r0:=-2*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2*(2*A*c^2*d^2-b^2*e*(B*d-2*A*e)-_
+--     b*c*d*(B*d+2*A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/_
+--     sqrt(-d)),c*d/(b*e))*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/_
+--     (b^2*(-d)^(3/2)*(c*d-b*e)^2*sqrt((b+c*x)/b)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))+2*e*(b*B*d+A*c*d-2*A*b*e)*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/(d^2*(c*d-b*e)*sqrt(-b)*sqrt(c)*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2))-2*e*(2*A*c^2*d^2-b^2*e*(B*d-2*A*e)-b*c*d*(B*d+_
+--     2*A*e))*sqrt(b*x+c*x^2)/(b^2*d^2*(c*d-b*e)^2*sqrt(d+e*x))
+--E 512
+
+--S 513 of 1125
+d0:=D(m0,x)
+--E 513
+
+)clear all
+
+--S 514 of 1125
+t0:=(A+B*x)/((d+e*x)^(5/2)*(b*x+c*x^2)^(3/2))
+--E 514
+
+--S 515 of 1125
+--r0:=-2*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*_
+--     (d+e*x)^(3/2)*sqrt(b*x+c*x^2))-2/3*(6*A*c^3*d^3-b^2*c*d*e*(7*B*d-_
+--     19*A*e)+2*b^3*e^2*(B*d-4*A*e)-3*b*c^2*d^2*(B*d+3*A*e))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(e)*_
+--     sqrt(x)*sqrt((d+e*x)/d)/(b^2*(-d)^(5/2)*(c*d-b*e)^3*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*e*(3*A*c^2*d^2+3*b*c*d*(2*B*d-_
+--     5*A*e)-2*b^2*e*(B*d-4*A*e))*elliptic_f(asin(sqrt(c)*sqrt(x)/_
+--     sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/_
+--     (d^3*(c*d-b*e)^2*sqrt(-b)*sqrt(c)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2/3*e*(6*A*c^2*d^2-b^2*e*(B*d-4*A*e)-3*b*c*d*(B*d+2*A*e))*_
+--     sqrt(b*x+c*x^2)/(b^2*d^2*(c*d-b*e)^2*(d+e*x)^(3/2))-_
+--     2/3*e*(6*A*c^3*d^3-b^2*c*d*e*(7*B*d-19*A*e)+2*b^3*e^2*(B*d-4*A*e)-_
+--     3*b*c^2*d^2*(B*d+3*A*e))*sqrt(b*x+c*x^2)/(b^2*d^3*(c*d-b*e)^3*_
+--     sqrt(d+e*x))
+--E 515
+
+--S 516 of 1125
+d0:=D(m0,x)
+--E 516
+
+)clear all
+
+--S 517 of 1125
+t0:=(A+B*x)*(d+e*x)^(7/2)/(b*x+c*x^2)^(5/2)
+--E 517
+
+--S 518 of 1125
+--r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(7/2)/(b^2*(b*x+c*x^2)^(3/2))-_
+--     2/3*(d+e*x)^(5/2)*(b*(4*b*B*d-8*A*c*d+7*A*b*e)-(16*A*c^2*d-_
+--     3*b^2*B*e-8*b*c*(B*d+A*e))*x)/(b^4*sqrt(b*x+c*x^2))-2/3*_
+--     (16*A*c^4*d^3-8*b^4*B*e^3+b^3*c*e^2*(5*B*d+2*A*e)-8*b*c^3*d^2*_
+--     (B*d+3*A*e)+b^2*c^2*d*e*(5*B*d+4*A*e))*(b+c*x)*elliptic_e(asin(_
+--     sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(-d)*sqrt(e)*sqrt(x)*_
+--     sqrt((d+e*x)/d)/(b^4*c^3*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+_
+--     c*x^2))-2/3*e*(c*d-b*e)*(8*A*c^3*d^2+8*b^3*B*e^2-b^2*c*e*(B*d+_
+--     2*A*e)-b*c^2*d*(4*B*d+5*A*e))*elliptic_f(asin(sqrt(c)*sqrt(x)/_
+--     sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/_
+--     ((-b)^(5/2)*c^(7/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*e*_
+--     (16*A*c^2*d-3*b^2*B*e-8*b*c*(B*d+A*e))*(d+e*x)^(3/2)*_
+--     sqrt(b*x+c*x^2)/(b^4*c)-2/3*e*(16*A*c^3*d^2+4*b^3*B*e^2+b^2*c*e*_
+--     (B*d-A*e)-8*b*c^2*d*(B*d+2*A*e))*sqrt(d+e*x)*sqrt(b*x+c*x^2)/(b^4*c^2)
+--E 518
+
+--S 519 of 1125
+d0:=D(m0,x)
+--E 519
+
+)clear all
+
+--S 520 of 1125
+t0:=(A+B*x)*(d+e*x)^(5/2)/(b*x+c*x^2)^(5/2)
+--E 520
+
+--S 521 of 1125
+--r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(5/2)/(b^2*(b*x+c*x^2)^(3/2))-_
+--     2/3*(d+e*x)^(3/2)*(b*(4*b*B*d-8*A*c*d+5*A*b*e)-(16*A*c^2*d-_
+--     b^2*B*e-8*b*c*(B*d+A*e))*x)/(b^4*sqrt(b*x+c*x^2))-2/3*_
+--     (16*A*c^3*d^2+2*b^3*B*e^2+b^2*c*e*(3*B*d+A*e)-8*b*c^2*d*(B*d+_
+--     2*A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/_
+--     (b*e))*sqrt(-d)*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^4*c^2*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*e*(c*d-b*e)*_
+--     (8*A*c^2*d-2*b^2*B*e-b*c*(4*B*d+A*e))*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/((-b)^(5/2)*c^(5/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-_
+--     2/3*e*(16*A*c^2*d-b^2*B*e-8*b*c*(B*d+A*e))*sqrt(d+e*x)*_
+--     sqrt(b*x+c*x^2)/(b^4*c)
+--E 521
+
+--S 522 of 1125
+d0:=D(m0,x)
+--E 522
+
+)clear all
+
+--S 523 of 1125
+t0:=(A+B*x)*(d+e*x)^(3/2)/(b*x+c*x^2)^(5/2)
+--E 523
+
+--S 524 of 1125
+--r0:=-2/3*(A*b-(b*B-2*A*c)*x)*(d+e*x)^(3/2)/(b^2*(b*x+c*x^2)^(3/2))-_
+--     2/3*(b*(4*b*B*d-8*A*c*d+3*A*b*e)-(16*A*c^2*d+b^2*B*e-8*b*c*_
+--     (B*d+A*e))*x)*sqrt(d+e*x)/(b^4*sqrt(b*x+c*x^2))-2/3*(16*A*c^2*d+_
+--     b^2*B*e-8*b*c*(B*d+A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/_
+--     sqrt(-d)),c*d/(b*e))*sqrt(-d)*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/_
+--     (b^4*c*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*e*_
+--     (4*b*B*c*d-8*A*c^2*d-b^2*B*e+5*A*b*c*e)*elliptic_f(asin(sqrt(c)*_
+--     sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*sqrt((b+c*x)/b)*_
+--     sqrt((d+e*x)/d)/((-b)^(5/2)*c^(3/2)*sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 524
+
+--S 525 of 1125
+d0:=D(m0,x)
+--E 525
+
+)clear all
+
+--S 526 of 1125
+t0:=(A+B*x)*sqrt(d+e*x)/(b*x+c*x^2)^(5/2)
+--E 526
+
+--S 527 of 1125
+--r0:=-2/3*(A*b-(b*B-2*A*c)*x)*sqrt(d+e*x)/(b^2*(b*x+c*x^2)^(3/2))-_
+--     2/3*(b*(c*d-b*e)*(4*b*B*d-8*A*c*d+A*b*e)-c*(16*A*c^2*d^2+b^2*e*_
+--     (7*B*d+A*e)-8*b*c*d*(B*d+2*A*e))*x)*sqrt(d+e*x)/(b^4*d*(c*d-b*e)*_
+--     sqrt(b*x+c*x^2))+2/3*(16*A*c^2*d^2+b^2*e*(7*B*d+A*e)-8*b*c*d*_
+--     (B*d+2*A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),_
+--     c*d/(b*e))*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^4*(c*d-b*e)*sqrt(-d)*_
+--     sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*e*(4*b*B*d-_
+--     8*A*c*d+A*b*e)*elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*_
+--     sqrt(x)*sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/((-b)^(5/2)*d*sqrt(c)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 527
+
+--S 528 of 1125
+d0:=D(m0,x)
+--E 528
+
+)clear all
+
+--S 529 of 1125
+t0:=(A+B*x)/((b*x+c*x^2)^(5/2)*sqrt(d+e*x))
+--E 529
+
+--S 530 of 1125
+--r0:=-2/3*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)*sqrt(d+e*x)/_
+--     (b^2*d*(c*d-b*e)*(b*x+c*x^2)^(3/2))+2/3*(b*(c*d-b*e)*(8*A*c^2*d^2+_
+--     b^2*e*(3*B*d-2*A*e)-b*c*d*(4*B*d+5*A*e))+c*(16*A*c^3*d^3-b^3*e^2*_
+--     (3*B*d-2*A*e)-8*b*c^2*d^2*(B*d+3*A*e)+b^2*c*d*e*(13*B*d+4*A*e))*x)*_
+--     sqrt(d+e*x)/(b^4*d^2*(c*d-b*e)^2*sqrt(b*x+c*x^2))-2/3*_
+--     (16*A*c^3*d^3-b^3*e^2*(3*B*d-2*A*e)-8*b*c^2*d^2*(B*d+3*A*e)+_
+--     b^2*c*d*e*(13*B*d+4*A*e))*(b+c*x)*elliptic_e(asin(sqrt(e)*sqrt(x)/_
+--     sqrt(-d)),c*d/(b*e))*sqrt(e)*sqrt(x)*sqrt((d+e*x)/d)/(b^4*(-d)^(3/2)*_
+--     (c*d-b*e)^2*sqrt((b+c*x)/b)*sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*e*_
+--     (8*A*c^2*d^2+b^2*e*(3*B*d-2*A*e)-b*c*d*(4*B*d+5*A*e))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/((-b)^(5/2)*d^2*(c*d-b*e)*sqrt(c)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))
+--E 530
+
+--S 531 of 1125
+d0:=D(m0,x)
+--E 531
+
+)clear all
+
+--S 532 of 1125
+t0:=(A+B*x)/((d+e*x)^(3/2)*(b*x+c*x^2)^(5/2))
+--E 532
+
+--S 533 of 1125
+--r0:=-2/3*(A*b*(c*d-b*e)+c*(2*A*c*d-b*(B*d+A*e))*x)/(b^2*d*(c*d-b*e)*_
+--     (b*x+c*x^2)^(3/2)*sqrt(d+e*x))+2/3*(b*(c*d-b*e)*(8*A*c^2*d^2+b^2*_
+--     e*(3*B*d-4*A*e)-b*c*d*(4*B*d+3*A*e))+c*(16*A*c^3*d^3+15*b^2*B*_
+--     c*d^2*e-b^3*e^2*(3*B*d-4*A*e)-8*b*c^2*d^2*(B*d+3*A*e))*x)/_
+--     (b^4*d^2*(c*d-b*e)^2*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*_
+--     (16*A*c^4*d^4-b^3*c*d*e^2*(9*B*d-7*A*e)-8*b*c^3*d^3*(B*d+4*A*e)+_
+--     b^2*c^2*d^2*e*(19*B*d+9*A*e)+b^4*(6*B*d*e^3-8*A*e^4))*(b+c*x)*_
+--     elliptic_e(asin(sqrt(e)*sqrt(x)/sqrt(-d)),c*d/(b*e))*sqrt(e)*_
+--     sqrt(x)*sqrt((d+e*x)/d)/(b^4*(-d)^(5/2)*(c*d-b*e)^3*sqrt((b+c*x)/b)*_
+--     sqrt(d+e*x)*sqrt(b*x+c*x^2))-2/3*e*(8*A*c^3*d^3+3*b^2*c*d*e*_
+--     (2*B*d-A*e)-b*c^2*d^2*(4*B*d+9*A*e)-b^3*(6*B*d*e^2-8*A*e^3))*_
+--     elliptic_f(asin(sqrt(c)*sqrt(x)/sqrt(-b)),b*e/(c*d))*sqrt(x)*_
+--     sqrt((b+c*x)/b)*sqrt((d+e*x)/d)/((-b)^(5/2)*d^3*(c*d-b*e)^2*_
+--     sqrt(c)*sqrt(d+e*x)*sqrt(b*x+c*x^2))+2/3*e*(16*A*c^4*d^4-_
+--     b^3*c*d*e^2*(9*B*d-7*A*e)-8*b*c^3*d^3*(B*d+4*A*e)+b^2*c^2*d^2*_
+--     e*(19*B*d+9*A*e)+b^4*(6*B*d*e^3-8*A*e^4))*sqrt(b*x+c*x^2)/_
+--     (b^4*d^3*(c*d-b*e)^3*sqrt(d+e*x))
+--E 533
+
+--S 534 of 1125
+d0:=D(m0,x)
+--E 534
+
+)clear all
+
+--S 535 of 1125
+t0:=(A+B*x)*(d+e*x)^m*(a+c*x^2)
+--E 535
+
+--S 536 of 1125
+r0:=-(B*d-A*e)*(c*d^2+a*e^2)*(d+e*x)^(1+m)/(e^4*(1+m))+(3*B*c*d^2-2*A*_
+     c*d*e+a*B*e^2)*(d+e*x)^(2+m)/(e^4*(2+m))-c*(3*B*d-A*e)*_
+     (d+e*x)^(3+m)/(e^4*(3+m))+B*c*(d+e*x)^(4+m)/(e^4*(4+m))
+--E 536
+
+--S 537 of 1125
+d0:=normalize(D(m0,x))
+--E 537
+
+)clear all
+
+--S 538 of 1125
+t0:=(A+B*x)*(d+e*x)^5*(a+c*x^2)
+--E 538
+
+--S 539 of 1125
+r0:=-1/6*(B*d-A*e)*(c*d^2+a*e^2)*(d+e*x)^6/e^4+1/7*(3*B*c*d^2-2*A*c*d*e+_
+     a*B*e^2)*(d+e*x)^7/e^4-1/8*c*(3*B*d-A*e)*(d+e*x)^8/e^4+1/9*B*_
+     c*(d+e*x)^9/e^4
+--E 539
+
+--S 540 of 1125
+d0:=D(m0,x)
+--E 540
+
+)clear all
+
+--S 541 of 1125
+t0:=(A+B*x)*(d+e*x)^4*(a+c*x^2)
+--E 541
+
+--S 542 of 1125
+r0:=-1/5*(B*d-A*e)*(c*d^2+a*e^2)*(d+e*x)^5/e^4+1/6*(3*B*c*d^2-2*A*c*d*e+_
+     a*B*e^2)*(d+e*x)^6/e^4-1/7*c*(3*B*d-A*e)*(d+e*x)^7/e^4+1/8*B*c*_
+     (d+e*x)^8/e^4
+--E 542
+
+--S 543 of 1125
+d0:=D(m0,x)
+--E 543
+
+)clear all
+
+--S 544 of 1125
+t0:=(A+B*x)*(d+e*x)^3*(a+c*x^2)
+--E 544
+
+--S 545 of 1125
+r0:=-1/4*(B*d-A*e)*(c*d^2+a*e^2)*(d+e*x)^4/e^4+1/5*(3*B*c*d^2-2*A*c*d*e+_
+     a*B*e^2)*(d+e*x)^5/e^4-1/6*c*(3*B*d-A*e)*(d+e*x)^6/e^4+_
+     1/7*B*c*(d+e*x)^7/e^4
+--E 545
+
+--S 546 of 1125
+d0:=D(m0,x)
+--E 546
+
+)clear all
+
+--S 547 of 1125
+t0:=(A+B*x)*(d+e*x)^2*(a+c*x^2)
+--E 547
+
+--S 548 of 1125
+r0:=a*A*d^2*x+1/2*a*d*(B*d+2*A*e)*x^2+1/3*(A*c*d^2+2*a*B*d*e+a*A*e^2)*x^3+_
+     1/4*(B*c*d^2+2*A*c*d*e+a*B*e^2)*x^4+1/5*c*e*(2*B*d+A*e)*x^5+_
+     1/6*B*c*e^2*x^6
+--E 548
+
+--S 549 of 1125
+d0:=D(m0,x)
+--E 549
+
+)clear all
+
+--S 550 of 1125
+t0:=(A+B*x)*(d+e*x)*(a+c*x^2)
+--E 550
+
+--S 551 of 1125
+r0:=a*A*d*x+1/2*a*(B*d+A*e)*x^2+1/3*(A*c*d+a*B*e)*x^3+1/4*c*(B*d+A*e)*x^4+_
+     1/5*B*c*e*x^5
+--E 551
+
+--S 552 of 1125
+d0:=D(m0,x)
+--E 552
+
+)clear all
+
+--S 553 of 1125
+t0:=(A+B*x)*(a+c*x^2)
+--E 553
+
+--S 554 of 1125
+r0:=a*A*x+1/2*a*B*x^2+1/3*A*c*x^3+1/4*B*c*x^4
+--E 554
+
+--S 555 of 1125
+d0:=D(m0,x)
+--E 555
+
+)clear all
+
+--S 556 of 1125
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)
+--E 556
+
+--S 557 of 1125
+r0:=(B*c*d^2-A*c*d*e+a*B*e^2)*x/e^3-1/2*c*(B*d-A*e)*x^2/e^2+1/3*B*c*x^3/e-_
+     (B*d-A*e)*(c*d^2+a*e^2)*log(d+e*x)/e^4
+--E 557
+
+--S 558 of 1125
+d0:=D(m0,x)
+--E 558
+
+)clear all
+
+--S 559 of 1125
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^2
+--E 559
+
+--S 560 of 1125
+r0:=-c*(2*B*d-A*e)*x/e^3+1/2*B*c*x^2/e^2+(B*d-A*e)*(c*d^2+a*e^2)/_
+     (e^4*(d+e*x))+(3*B*c*d^2-2*A*c*d*e+a*B*e^2)*log(d+e*x)/e^4
+--E 560
+
+--S 561 of 1125
+d0:=D(m0,x)
+--E 561
+
+)clear all
+
+--S 562 of 1125
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^3
+--E 562
+
+--S 563 of 1125
+r0:=B*c*x/e^3+1/2*(B*d-A*e)*(c*d^2+a*e^2)/(e^4*(d+e*x)^2)+(-3*B*c*d^2+_
+     2*A*c*d*e-a*B*e^2)/(e^4*(d+e*x))-c*(3*B*d-A*e)*log(d+e*x)/e^4
+--E 563
+
+--S 564 of 1125
+d0:=D(m0,x)
+--E 564
+
+)clear all
+
+--S 565 of 1125
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^4
+--E 565
+
+--S 566 of 1125
+r0:=1/3*(B*d-A*e)*(c*d^2+a*e^2)/(e^4*(d+e*x)^3)+1/2*(-3*B*c*d^2+2*A*c*d*e-_
+     a*B*e^2)/(e^4*(d+e*x)^2)+c*(3*B*d-A*e)/(e^4*(d+e*x))+B*c*log(d+e*x)/e^4
+--E 566
+
+--S 567 of 1125
+d0:=D(m0,x)
+--E 567
+
+)clear all
+
+--S 568 of 1125
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^5
+--E 568
+
+--S 569 of 1125
+r0:=1/4*(B*d-A*e)*(c*d^2+a*e^2)/(e^4*(d+e*x)^4)+1/3*(-3*B*c*d^2+2*A*c*d*e-_
+     a*B*e^2)/(e^4*(d+e*x)^3)+1/2*c*(3*B*d-A*e)/(e^4*(d+e*x)^2)-_
+     B*c/(e^4*(d+e*x))
+--E 569
+
+--S 570 of 1125
+d0:=D(m0,x)
+--E 570
+
+)clear all
+
+--S 571 of 1125
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^6
+--E 571
+
+--S 572 of 1125
+r0:=1/5*(B*d-A*e)*(c*d^2+a*e^2)/(e^4*(d+e*x)^5)+1/4*(-3*B*c*d^2+2*A*c*d*e-_
+     a*B*e^2)/(e^4*(d+e*x)^4)+1/3*c*(3*B*d-A*e)/(e^4*(d+e*x)^3)-_
+     1/2*B*c/(e^4*(d+e*x)^2)
+--E 572
+
+--S 573 of 1125
+d0:=D(m0,x)
+--E 573
+
+)clear all
+
+--S 574 of 1125
+t0:=(A+B*x)*(a+c*x^2)/(d+e*x)^7
+--E 574
+
+--S 575 of 1125
+r0:=1/6*(B*d-A*e)*(c*d^2+a*e^2)/(e^4*(d+e*x)^6)+1/5*(-3*B*c*d^2+2*A*c*d*e-_
+     a*B*e^2)/(e^4*(d+e*x)^5)+1/4*c*(3*B*d-A*e)/(e^4*(d+e*x)^4)-_
+     1/3*B*c/(e^4*(d+e*x)^3)
+--E 575
+
+--S 576 of 1125
+d0:=D(m0,x)
+--E 576
+
+)clear all
+
+--S 577 of 1125
+t0:=(A+B*x)*(d+e*x)^m*(a+c*x^2)^2
+--E 577
+
+--S 578 of 1125
+r0:=-(B*d-A*e)*(c*d^2+a*e^2)^2*(d+e*x)^(1+m)/(e^6*(1+m))+(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)*(d+e*x)^(2+m)/(e^6*(2+m))-2*c*_
+     (5*B*c*d^3-3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^(3+m)/(e^6*_
+     (3+m))+2*c*(5*B*c*d^2-2*A*c*d*e+a*B*e^2)*(d+e*x)^(4+m)/(e^6*(4+m))-_
+     c^2*(5*B*d-A*e)*(d+e*x)^(5+m)/(e^6*(5+m))+B*c^2*(d+e*x)^(6+m)/(e^6*(6+m))
+--E 578
+
+--S 579 of 1125
+d0:=normalize(D(m0,x))
+--E 579
+
+)clear all
+
+--S 580 of 1125
+t0:=(A+B*x)*(d+e*x)^5*(a+c*x^2)^2
+--E 580
+
+--S 581 of 1125
+r0:=-1/6*(B*d-A*e)*(c*d^2+a*e^2)^2*(d+e*x)^6/e^6+1/7*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)*(d+e*x)^7/e^6-1/4*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^8/e^6+2/9*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)*(d+e*x)^9/e^6-1/10*c^2*(5*B*d-A*e)*(d+e*x)^10/e^6+_
+     1/11*B*c^2*(d+e*x)^11/e^6
+--E 581
+
+--S 582 of 1125
+d0:=D(m0,x)
+--E 582
+
+)clear all
+
+--S 583 of 1125
+t0:=(A+B*x)*(d+e*x)^4*(a+c*x^2)^2
+--E 583
+
+--S 584 of 1125
+r0:=-1/5*(B*d-A*e)*(c*d^2+a*e^2)^2*(d+e*x)^5/e^6+1/6*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)*(d+e*x)^6/e^6-2/7*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^7/e^6+1/4*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)*(d+e*x)^8/e^6-1/9*c^2*(5*B*d-A*e)*(d+e*x)^9/e^6+_
+     1/10*B*c^2*(d+e*x)^10/e^6
+--E 584
+
+--S 585 of 1125
+d0:=D(m0,x)
+--E 585
+
+)clear all
+
+--S 586 of 1125
+t0:=(A+B*x)*(d+e*x)^3*(a+c*x^2)^2
+--E 586
+
+--S 587 of 1125
+r0:=-1/4*(B*d-A*e)*(c*d^2+a*e^2)^2*(d+e*x)^4/e^6+1/5*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)*(d+e*x)^5/e^6-1/3*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^6/e^6+2/7*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)*(d+e*x)^7/e^6-1/8*c^2*(5*B*d-A*e)*(d+e*x)^8/e^6+_
+     1/9*B*c^2*(d+e*x)^9/e^6
+--E 587
+
+--S 588 of 1125
+d0:=D(m0,x)
+--E 588
+
+)clear all
+
+--S 589 of 1125
+t0:=(A+B*x)*(d+e*x)^2*(a+c*x^2)^2
+--E 589
+
+--S 590 of 1125
+r0:=a^2*A*d^2*x+1/2*a^2*d*(B*d+2*A*e)*x^2+1/3*a*(2*A*c*d^2+2*a*B*d*e+_
+     a*A*e^2)*x^3+1/4*a*(2*B*c*d^2+4*A*c*d*e+a*B*e^2)*x^4+1/5*c*(A*c*d^2+_
+     4*a*B*d*e+2*a*A*e^2)*x^5+1/6*c*(B*c*d^2+2*A*c*d*e+2*a*B*e^2)*x^6+_
+     1/7*c^2*e*(2*B*d+A*e)*x^7+1/8*B*c^2*e^2*x^8
+--E 590
+
+--S 591 of 1125
+d0:=D(m0,x)
+--E 591
+
+)clear all
+
+--S 592 of 1125
+t0:=(A+B*x)*(d+e*x)*(a+c*x^2)^2
+--E 592
+
+--S 593 of 1125
+r0:=a^2*A*d*x+1/2*a^2*(B*d+A*e)*x^2+1/3*a*(2*A*c*d+a*B*e)*x^3+1/2*a*c*_
+     (B*d+A*e)*x^4+1/5*c*(A*c*d+2*a*B*e)*x^5+1/6*c^2*(B*d+A*e)*x^6+_
+     1/7*B*c^2*e*x^7
+--E 593
+
+--S 594 of 1125
+d0:=D(m0,x)
+--E 594
+
+)clear all
+
+--S 595 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2
+--E 595
+
+--S 596 of 1125
+r0:=a^2*A*x+2/3*a*A*c*x^3+1/5*A*c^2*x^5+1/6*B*(a+c*x^2)^3/c
+--E 596
+
+--S 597 of 1125
+d0:=D(m0,x)
+--E 597
+
+)clear all
+
+--S 598 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)
+--E 598
+
+--S 599 of 1125
+r0:=(B*(c*d^2+a*e^2)^2-A*c*d*e*(c*d^2+2*a*e^2))*x/e^5-1/2*c*(B*d-A*e)*_
+     (c*d^2+2*a*e^2)*x^2/e^4+1/3*c*(B*c*d^2-A*c*d*e+2*a*B*e^2)*x^3/e^3-_
+     1/4*c^2*(B*d-A*e)*x^4/e^2+1/5*B*c^2*x^5/e-(B*d-A*e)*(c*d^2+a*e^2)^2*_
+     log(d+e*x)/e^6
+--E 599
+
+--S 600 of 1125
+d0:=D(m0,x)
+--E 600
+
+)clear all
+
+--S 601 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^2
+--E 601
+
+--S 602 of 1125
+r0:=-c*(4*B*c*d^3-3*A*c*d^2*e+4*a*B*d*e^2-2*a*A*e^3)*x/e^5+1/2*c*_
+     (3*B*c*d^2-2*A*c*d*e+2*a*B*e^2)*x^2/e^4-1/3*c^2*(2*B*d-A*e)*x^3/e^3+_
+     1/4*B*c^2*x^4/e^2+(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x))+_
+     (c*d^2+a*e^2)*(5*B*c*d^2-4*A*c*d*e+a*B*e^2)*log(d+e*x)/e^6
+--E 602
+
+--S 603 of 1125
+d0:=D(m0,x)
+--E 603
+
+)clear all
+
+--S 604 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^3
+--E 604
+
+--S 605 of 1125
+r0:=c*(6*B*c*d^2-3*A*c*d*e+2*a*B*e^2)*x/e^5-1/2*c^2*(3*B*d-A*e)*x^2/e^4+_
+     1/3*B*c^2*x^3/e^3+1/2*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^2)-_
+     (c*d^2+a*e^2)*(5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x))-_
+     2*c*(5*B*c*d^3-3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*log(d+e*x)/e^6
+--E 605
+
+--S 606 of 1125
+d0:=D(m0,x)
+--E 606
+
+)clear all
+
+--S 607 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^4
+--E 607
+
+--S 608 of 1125
+r0:=-c^2*(4*B*d-A*e)*x/e^5+1/2*B*c^2*x^2/e^4+1/3*(B*d-A*e)*(c*d^2+_
+     a*e^2)^2/(e^6*(d+e*x)^3)-1/2*(c*d^2+a*e^2)*(5*B*c*d^2-4*A*c*d*e+_
+     a*B*e^2)/(e^6*(d+e*x)^2)+2*c*(5*B*c*d^3-3*A*c*d^2*e+3*a*B*d*e^2-_
+     a*A*e^3)/(e^6*(d+e*x))+2*c*(5*B*c*d^2-2*A*c*d*e+a*B*e^2)*log(d+e*x)/e^6
+--E 608
+
+--S 609 of 1125
+d0:=D(m0,x)
+--E 609
+
+)clear all
+
+--S 610 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^5
+--E 610
+
+--S 611 of 1125
+r0:=B*c^2*x/e^5+1/4*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^4)-1/3*(c*d^2+_
+     a*e^2)*(5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^3)+c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^2)-2*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x))-c^2*(5*B*d-A*e)*log(d+e*x)/e^6
+--E 611
+
+--S 612 of 1125
+d0:=D(m0,x)
+--E 612
+
+)clear all
+
+--S 613 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^6
+--E 613
+
+--S 614 of 1125
+r0:=1/5*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^5)-1/4*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^4)+2/3*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^3)-c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^2)+c^2*(5*B*d-A*e)/(e^6*(d+e*x))+_
+     B*c^2*log(d+e*x)/e^6
+--E 614
+
+--S 615 of 1125
+d0:=D(m0,x)
+--E 615
+
+)clear all
+
+--S 616 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^7
+--E 616
+
+--S 617 of 1125
+r0:=1/6*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^6)-1/5*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^5)+1/2*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^4)-2/3*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^3)+1/2*c^2*(5*B*d-A*e)/_
+     (e^6*(d+e*x)^2)-B*c^2/(e^6*(d+e*x))
+--E 617
+
+--S 618 of 1125
+d0:=D(m0,x)
+--E 618
+
+)clear all
+
+--S 619 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^8
+--E 619
+
+--S 620 of 1125
+r0:=1/7*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^7)-1/6*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^6)+2/5*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^5)-1/2*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^4)+1/3*c^2*(5*B*d-A*e)/(e^6*_
+     (d+e*x)^3)-1/2*B*c^2/(e^6*(d+e*x)^2)
+--E 620
+
+--S 621 of 1125
+d0:=D(m0,x)
+--E 621
+
+)clear all
+
+--S 622 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^9
+--E 622
+
+--S 623 of 1125
+r0:=1/8*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^8)-1/7*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^7)+1/3*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^6)-2/5*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^5)+1/4*c^2*(5*B*d-A*e)/(e^6*_
+     (d+e*x)^4)-1/3*B*c^2/(e^6*(d+e*x)^3)
+--E 623
+
+--S 624 of 1125
+d0:=D(m0,x)
+--E 624
+
+)clear all
+
+--S 625 of 1125
+t0:=(A+B*x)*(a+c*x^2)^2/(d+e*x)^10
+--E 625
+
+--S 626 of 1125
+r0:=1/9*(B*d-A*e)*(c*d^2+a*e^2)^2/(e^6*(d+e*x)^9)-1/8*(c*d^2+a*e^2)*_
+     (5*B*c*d^2-4*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^8)+2/7*c*(5*B*c*d^3-_
+     3*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^6*(d+e*x)^7)-1/3*c*(5*B*c*d^2-_
+     2*A*c*d*e+a*B*e^2)/(e^6*(d+e*x)^6)+1/5*c^2*(5*B*d-A*e)/(e^6*_
+     (d+e*x)^5)-1/4*B*c^2/(e^6*(d+e*x)^4)
+--E 626
+
+--S 627 of 1125
+d0:=D(m0,x)
+--E 627
+
+)clear all
+
+--S 628 of 1125
+t0:=(A+B*x)*(d+e*x)^m*(a+c*x^2)^3
+--E 628
+
+--S 629 of 1125
+r0:=-(B*d-A*e)*(c*d^2+a*e^2)^3*(d+e*x)^(1+m)/(e^8*(1+m))+(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)*(d+e*x)^(2+m)/(e^8*(2+m))-3*c*(c*d^2+_
+     a*e^2)*(7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^(3+m)/_
+     (e^8*(3+m))-c*(4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*_
+     c*d^2*e^2+3*a^2*e^4))*(d+e*x)^(4+m)/(e^8*(4+m))-c^2*(35*B*c*d^3-_
+     15*A*c*d^2*e+15*a*B*d*e^2-3*a*A*e^3)*(d+e*x)^(5+m)/(e^8*(5+m))+_
+     3*c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)*(d+e*x)^(6+m)/(e^8*(6+m))-_
+     c^3*(7*B*d-A*e)*(d+e*x)^(7+m)/(e^8*(7+m))+B*c^3*(d+e*x)^(8+m)/(e^8*(8+m))
+--E 629
+
+--S 630 of 1125
+d0:=normalize(D(m0,x))
+--E 630
+
+)clear all
+
+--S 631 of 1125
+t0:=(A+B*x)*(d+e*x)^5*(a+c*x^2)^3
+--E 631
+
+--S 632 of 1125
+r0:=-1/6*(B*d-A*e)*(c*d^2+a*e^2)^3*(d+e*x)^6/e^8+1/7*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)*(d+e*x)^7/e^8-3/8*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^8/e^8-1/9*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*_
+     a^2*e^4))*(d+e*x)^9/e^8-1/10*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*_
+     B*d*e^2-3*a*A*e^3)*(d+e*x)^10/e^8+3/11*c^2*(7*B*c*d^2-2*A*c*d*e+_
+     a*B*e^2)*(d+e*x)^11/e^8-1/12*c^3*(7*B*d-A*e)*(d+e*x)^12/e^8+1/13*_
+     B*c^3*(d+e*x)^13/e^8
+--E 632
+
+--S 633 of 1125
+d0:=D(m0,x)
+--E 633
+
+)clear all
+
+--S 634 of 1125
+t0:=(A+B*x)*(d+e*x)^4*(a+c*x^2)^3
+--E 634
+
+--S 635 of 1125
+r0:=-1/5*(B*d-A*e)*(c*d^2+a*e^2)^3*(d+e*x)^5/e^8+1/6*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)*(d+e*x)^6/e^8-3/7*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*(d+e*x)^7/e^8-1/8*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*_
+     e^4))*(d+e*x)^8/e^8-1/9*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*d*e^2-_
+     3*a*A*e^3)*(d+e*x)^9/e^8+3/10*c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)*_
+     (d+e*x)^10/e^8-1/11*c^3*(7*B*d-A*e)*(d+e*x)^11/e^8+1/12*B*c^3*_
+     (d+e*x)^12/e^8
+--E 635
+
+--S 636 of 1125
+d0:=D(m0,x)
+--E 636
+
+)clear all
+
+--S 637 of 1125
+t0:=(A+B*x)*(d+e*x)^3*(a+c*x^2)^3
+--E 637
+
+--S 638 of 1125
+r0:=a^3*A*d^3*x+1/2*a^3*d^2*(B*d+3*A*e)*x^2+a^2*d*(A*c*d^2+a*B*d*e+_
+     a*A*e^2)*x^3+1/4*a^2*(3*B*c*d^3+9*A*c*d^2*e+3*a*B*d*e^2+a*A*e^3)*_
+     x^4+1/5*a*(a*B*e*(9*c*d^2+a*e^2)+3*A*c*d*(c*d^2+3*a*e^2))*x^5+_
+     1/2*a*c*(B*c*d^3+3*A*c*d^2*e+3*a*B*d*e^2+a*A*e^3)*x^6+1/7*c*(3*a*_
+     B*e*(3*c*d^2+a*e^2)+A*c*d*(c*d^2+9*a*e^2))*x^7+1/8*c^2*(B*c*d^3+3*_
+     A*c*d^2*e+9*a*B*d*e^2+3*a*A*e^3)*x^8+1/3*c^2*e*(B*c*d^2+A*c*d*e+_
+     a*B*e^2)*x^9+1/10*c^3*e^2*(3*B*d+A*e)*x^10+1/11*B*c^3*e^3*x^11
+--E 638
+
+--S 639 of 1125
+d0:=D(m0,x)
+--E 639
+
+)clear all
+
+--S 640 of 1125
+t0:=(A+B*x)*(d+e*x)^2*(a+c*x^2)^3
+--E 640
+
+--S 641 of 1125
+r0:=a^3*A*d^2*x+1/2*a^3*d*(B*d+2*A*e)*x^2+1/3*a^2*(3*A*c*d^2+2*a*B*d*e+_
+     a*A*e^2)*x^3+1/4*a^2*(3*B*c*d^2+6*A*c*d*e+a*B*e^2)*x^4+3/5*a*c*_
+     (A*c*d^2+2*a*B*d*e+a*A*e^2)*x^5+1/2*a*c*(B*c*d^2+2*A*c*d*e+a*B*_
+     e^2)*x^6+1/7*c^2*(A*c*d^2+6*a*B*d*e+3*a*A*e^2)*x^7+1/8*c^2*(B*c*d^2+_
+     2*A*c*d*e+3*a*B*e^2)*x^8+1/9*c^3*e*(2*B*d+A*e)*x^9+1/10*B*c^3*e^2*x^10
+--E 641
+
+--S 642 of 1125
+d0:=D(m0,x)
+--E 642
+
+)clear all
+
+--S 643 of 1125
+t0:=(A+B*x)*(d+e*x)*(a+c*x^2)^3
+--E 643
+
+--S 644 of 1125
+r0:=a^3*A*d*x+1/2*a^3*(B*d+A*e)*x^2+1/3*a^2*(3*A*c*d+a*B*e)*x^3+3/4*_
+     a^2*c*(B*d+A*e)*x^4+3/5*a*c*(A*c*d+a*B*e)*x^5+1/2*a*c^2*(B*d+A*e)*_
+     x^6+1/7*c^2*(A*c*d+3*a*B*e)*x^7+1/8*c^3*(B*d+A*e)*x^8+1/9*B*c^3*e*x^9
+--E 644
+
+--S 645 of 1125
+d0:=D(m0,x)
+--E 645
+
+)clear all
+
+--S 646 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3
+--E 646
+
+--S 647 of 1125
+r0:=a^3*A*x+a^2*A*c*x^3+3/5*a*A*c^2*x^5+1/7*A*c^3*x^7+1/8*B*(a+c*x^2)^4/c
+--E 647
+
+--S 648 of 1125
+d0:=D(m0,x)
+--E 648
+
+)clear all
+
+--S 649 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)
+--E 649
+
+--S 650 of 1125
+r0:=(B*(c*d^2+a*e^2)^3-A*c*d*e*(c^2*d^4+3*a*c*d^2*e^2+3*a^2*e^4))*x/e^7-_
+     1/2*c*(B*d-A*e)*(c^2*d^4+3*a*c*d^2*e^2+3*a^2*e^4)*x^2/e^6-1/3*c*_
+     (A*c*d*e*(c*d^2+3*a*e^2)-B*(c^2*d^4+3*a*c*d^2*e^2+3*a^2*e^4))*_
+     x^3/e^5-1/4*c^2*(B*d-A*e)*(c*d^2+3*a*e^2)*x^4/e^4+1/5*c^2*(B*c*_
+     d^2-A*c*d*e+3*a*B*e^2)*x^5/e^3-1/6*c^3*(B*d-A*e)*x^6/e^2+1/7*B*_
+     c^3*x^7/e-(B*d-A*e)*(c*d^2+a*e^2)^3*log(d+e*x)/e^8
+--E 650
+
+--S 651 of 1125
+d0:=D(m0,x)
+--E 651
+
+)clear all
+
+--S 652 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^2
+--E 652
+
+--S 653 of 1125
+r0:=-c*(6*B*d*(c*d^2+a*e^2)^2-A*e*(5*c^2*d^4+9*a*c*d^2*e^2+3*a^2*e^4))*_
+     x/e^7-1/2*c*(2*A*c*d*e*(2*c*d^2+3*a*e^2)-B*(5*c^2*d^4+9*a*c*d^2*e^2+_
+     3*a^2*e^4))*x^2/e^6+1/3*c^2*(3*A*e*(c*d^2+a*e^2)-B*(4*c*d^3+_
+     6*a*d*e^2))*x^3/e^5-1/4*c^2*(2*A*c*d*e-3*B*(c*d^2+a*e^2))*x^4/e^4-_
+     1/5*c^3*(2*B*d-A*e)*x^5/e^3+1/6*B*c^3*x^6/e^2+(B*d-A*e)*(c*d^2+_
+     a*e^2)^3/(e^8*(d+e*x))+(c*d^2+a*e^2)^2*(7*B*c*d^2-6*A*c*d*e+_
+     a*B*e^2)*log(d+e*x)/e^8
+--E 653
+
+--S 654 of 1125
+d0:=D(m0,x)
+--E 654
+
+)clear all
+
+--S 655 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^3
+--E 655
+
+--S 656 of 1125
+r0:=-c*(A*c*d*e*(10*c*d^2+9*a*e^2)-3*B*(5*c^2*d^4+6*a*c*d^2*e^2+_
+     a^2*e^4))*x/e^7-1/2*c^2*(10*B*c*d^3-6*A*c*d^2*e+9*a*B*d*e^2-_
+     3*a*A*e^3)*x^2/e^6+c^2*(2*B*c*d^2-A*c*d*e+a*B*e^2)*x^3/e^5-_
+     1/4*c^3*(3*B*d-A*e)*x^4/e^4+1/5*B*c^3*x^5/e^3+1/2*(B*d-A*e)*_
+     (c*d^2+a*e^2)^3/(e^8*(d+e*x)^2)-(c*d^2+a*e^2)^2*(7*B*c*d^2-_
+     6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x))-3*c*(c*d^2+a*e^2)*(7*B*c*d^3-_
+     5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)*log(d+e*x)/e^8
+--E 656
+
+--S 657 of 1125
+d0:=D(m0,x)
+--E 657
+
+)clear all
+
+--S 658 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^4
+--E 658
+
+--S 659 of 1125
+r0:=-c^2*(20*B*c*d^3-10*A*c*d^2*e+12*a*B*d*e^2-3*a*A*e^3)*x/e^7+1/2*_
+     c^2*(10*B*c*d^2-4*A*c*d*e+3*a*B*e^2)*x^2/e^6-1/3*c^3*(4*B*d-A*e)*_
+     x^3/e^5+1/4*B*c^3*x^4/e^4+1/3*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+_
+     e*x)^3)-1/2*(c*d^2+a*e^2)^2*(7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*_
+     (d+e*x)^2)+3*c*(c*d^2+a*e^2)*(7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-_
+     a*A*e^3)/(e^8*(d+e*x))-c*(4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*_
+     d^4+30*a*c*d^2*e^2+3*a^2*e^4))*log(d+e*x)/e^8
+--E 659
+
+--S 660 of 1125
+d0:=D(m0,x)
+--E 660
+
+)clear all
+
+--S 661 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^5
+--E 661
+
+--S 662 of 1125
+r0:=-c^2*(5*A*c*d*e-3*B*(5*c*d^2+a*e^2))*x/e^7-1/2*c^3*(5*B*d-A*e)*_
+     x^2/e^6+1/3*B*c^3*x^3/e^5+1/4*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*_
+     (d+e*x)^4)-1/3*(c*d^2+a*e^2)^2*(7*B*c*d^2-6*A*c*d*e+a*B*e^2)/_
+     (e^8*(d+e*x)^3)+3/2*c*(c*d^2+a*e^2)*(7*B*c*d^3-5*A*c*d^2*e+3*a*B*_
+     d*e^2-a*A*e^3)/(e^8*(d+e*x)^2)+c*(4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*_
+     (35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*e^4))/(e^8*(d+e*x))-c^2*(35*B*c*_
+     d^3-15*A*c*d^2*e+15*a*B*d*e^2-3*a*A*e^3)*log(d+e*x)/e^8
+--E 662
+
+--S 663 of 1125
+d0:=D(m0,x)
+--E 663
+
+)clear all
+
+--S 664 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^6
+--E 664
+
+--S 665 of 1125
+r0:=-c^3*(6*B*d-A*e)*x/e^7+1/2*B*c^3*x^2/e^6+1/5*(B*d-A*e)*(c*d^2+_
+     a*e^2)^3/(e^8*(d+e*x)^5)-1/4*(c*d^2+a*e^2)^2*(7*B*c*d^2-6*A*c*d*e+_
+     a*B*e^2)/(e^8*(d+e*x)^4)+c*(c*d^2+a*e^2)*(7*B*c*d^3-5*A*c*d^2*e+_
+     3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^3)+1/2*c*(4*A*c*d*e*(5*c*d^2+_
+     3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*e^4))/(e^8*(d+e*x)^2)+_
+     c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*d*e^2-3*a*A*e^3)/(e^8*(d+e*x))+_
+     3*c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)*log(d+e*x)/e^8
+--E 665
+
+--S 666 of 1125
+d0:=D(m0,x)
+--E 666
+
+)clear all
+
+--S 667 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^7
+--E 667
+
+--S 668 of 1125
+r0:=B*c^3*x/e^7+1/6*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+e*x)^6)-1/5*(c*d^2+_
+     a*e^2)^2*(7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x)^5)+3/4*c*(c*d^2+_
+     a*e^2)*(7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^4)+_
+     1/3*c*(4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*_
+     a^2*e^4))/(e^8*(d+e*x)^3)+1/2*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*_
+     d*e^2-3*a*A*e^3)/(e^8*(d+e*x)^2)-3*c^2*(7*B*c*d^2-2*A*c*d*e+a*_
+     B*e^2)/(e^8*(d+e*x))-c^3*(7*B*d-A*e)*log(d+e*x)/e^8
+--E 668
+
+--S 669 of 1125
+d0:=D(m0,x)
+--E 669
+
+)clear all
+
+--S 670 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^8
+--E 670
+
+--S 671 of 1125
+r0:=1/7*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+e*x)^7)-1/6*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x)^6)+3/5*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^5)+1/4*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*_
+     e^4))/(e^8*(d+e*x)^4)+1/3*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*d*e^2-_
+     3*a*A*e^3)/(e^8*(d+e*x)^3)-3/2*c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)/_
+     (e^8*(d+e*x)^2)+c^3*(7*B*d-A*e)/(e^8*(d+e*x))+B*c^3*log(d+e*x)/e^8
+--E 671
+
+--S 672 of 1125
+d0:=D(m0,x)
+--E 672
+
+)clear all
+
+--S 673 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^9
+--E 673
+
+--S 674 of 1125
+r0:=1/8*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+e*x)^8)-1/7*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x)^7)+1/2*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^6)+1/5*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*_
+     e^4))/(e^8*(d+e*x)^5)+1/4*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*d*e^2-_
+     3*a*A*e^3)/(e^8*(d+e*x)^4)-c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)/(e^8*_
+     (d+e*x)^3)+1/2*c^3*(7*B*d-A*e)/(e^8*(d+e*x)^2)-B*c^3/(e^8*(d+e*x))
+--E 674
+
+--S 675 of 1125
+d0:=D(m0,x)
+--E 675
+
+)clear all
+
+--S 676 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^10
+--E 676
+
+--S 677 of 1125
+r0:=1/9*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+e*x)^9)-1/8*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x)^8)+3/7*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^7)+1/6*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*_
+     a^2*e^4))/(e^8*(d+e*x)^6)+1/5*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*_
+     d*e^2-3*a*A*e^3)/(e^8*(d+e*x)^5)-3/4*c^2*(7*B*c*d^2-2*A*c*d*e+_
+     a*B*e^2)/(e^8*(d+e*x)^4)+1/3*c^3*(7*B*d-A*e)/(e^8*(d+e*x)^3)-_
+     1/2*B*c^3/(e^8*(d+e*x)^2)
+--E 677
+
+--S 678 of 1125
+d0:=D(m0,x)
+--E 678
+
+)clear all
+
+--S 679 of 1125
+t0:=(A+B*x)*(a+c*x^2)^3/(d+e*x)^11
+--E 679
+
+--S 680 of 1125
+r0:=1/10*(B*d-A*e)*(c*d^2+a*e^2)^3/(e^8*(d+e*x)^10)-1/9*(c*d^2+a*e^2)^2*_
+     (7*B*c*d^2-6*A*c*d*e+a*B*e^2)/(e^8*(d+e*x)^9)+3/8*c*(c*d^2+a*e^2)*_
+     (7*B*c*d^3-5*A*c*d^2*e+3*a*B*d*e^2-a*A*e^3)/(e^8*(d+e*x)^8)+1/7*c*_
+     (4*A*c*d*e*(5*c*d^2+3*a*e^2)-B*(35*c^2*d^4+30*a*c*d^2*e^2+3*a^2*_
+     e^4))/(e^8*(d+e*x)^7)+1/6*c^2*(35*B*c*d^3-15*A*c*d^2*e+15*a*B*d*e^2-_
+     3*a*A*e^3)/(e^8*(d+e*x)^6)-3/5*c^2*(7*B*c*d^2-2*A*c*d*e+a*B*e^2)/_
+     (e^8*(d+e*x)^5)+1/4*c^3*(7*B*d-A*e)/(e^8*(d+e*x)^4)-1/3*B*c^3/_
+     (e^8*(d+e*x)^3)
+--E 680
+
+--S 681 of 1125
+d0:=D(m0,x)
+--E 681
+
+)clear all
+
+--S 682 of 1125
+t0:=(A+B*x)*(d+e*x)^m/(a+c*x^2)
+--E 682
+
+--S 683 of 1125
+--r0:=-1/2*(d+e*x)^(1+m)*hypergeometric(1,1+m,2+m,(d+e*x)*sqrt(c)/_
+--     (e*sqrt(-a)+d*sqrt(c)))*(A+B*sqrt(-a)/sqrt(c))/((1+m)*sqrt(-a)*_
+--     (e*sqrt(-a)+d*sqrt(c)))-1/2*(d+e*x)^(1+m)*hypergeometric(1,1+m,2+_
+--     m,(d+e*x)*sqrt(c)/(-e*sqrt(-a)+d*sqrt(c)))*(a*B+A*sqrt(-a)*sqrt(c))/_
+--     (a*(1+m)*sqrt(c)*(-e*sqrt(-a)+d*sqrt(c)))
+--E 683
+
+--S 684 of 1125
+d0:=D(m0,x)
+--E 684
+
+)clear all
+
+--S 685 of 1125
+t0:=(A+B*x)*(d+e*x)^(1+m)/(a+c*x^2)
+--E 685
+
+--S 686 of 1125
+--r0:=-1/2*(d+e*x)^(2+m)*hypergeometric(1,2+m,3+m,(d+e*x)*sqrt(c)/(e*_
+--     sqrt(-a)+d*sqrt(c)))*(A+B*sqrt(-a)/sqrt(c))/((2+m)*sqrt(-a)*(e*_
+--     sqrt(-a)+d*sqrt(c)))-1/2*(d+e*x)^(2+m)*hypergeometric(1,2+m,3+m,_
+--     (d+e*x)*sqrt(c)/(-e*sqrt(-a)+d*sqrt(c)))*(a*B+A*sqrt(-a)*sqrt(c))/_
+--     (a*(2+m)*sqrt(c)*(-e*sqrt(-a)+d*sqrt(c)))
+--E 686
+
+--S 687 of 1125
+d0:=D(m0,x)
+--E 687
+
+)clear all
+
+--S 688 of 1125
+t0:=(A+B*x)*(d+e*x)^4/(a+c*x^2)
+--E 688
+
+--S 689 of 1125
+r0:=e*(4*B*c*d^3+6*A*c*d^2*e-4*a*B*d*e^2-a*A*e^3)*x/c^2+1/2*e^2*(6*B*c*d^2+_
+     4*A*c*d*e-a*B*e^2)*x^2/c^2+1/3*e^3*(4*B*d+A*e)*x^3/c+1/4*B*e^4*x^4/c+_
+     1/2*(4*A*c*d*e*(c*d^2-a*e^2)+B*(c^2*d^4-6*a*c*d^2*e^2+a^2*e^4))*_
+     log(a+c*x^2)/c^3-(4*a*B*d*e*(c*d^2-a*e^2)-A*(c^2*d^4-6*a*c*d^2*_
+     e^2+a^2*e^4))*atan(x*sqrt(c)/sqrt(a))/(c^(5/2)*sqrt(a))
+--E 689
+
+--S 690 of 1125
+d0:=D(m0,x)
+--E 690
+
+)clear all
+
+--S 691 of 1125
+t0:=(A+B*x)*(d+e*x)^3/(a+c*x^2)
+--E 691
+
+--S 692 of 1125
+r0:=e*(3*B*c*d^2+3*A*c*d*e-a*B*e^2)*x/c^2+1/2*e^2*(3*B*d+A*e)*x^2/c+_
+     1/3*B*e^3*x^3/c+1/2*(B*c*d^3+3*A*c*d^2*e-3*a*B*d*e^2-a*A*e^3)*_
+     log(a+c*x^2)/c^2+(A*c*d*(c*d^2-3*a*e^2)-a*B*e*(3*c*d^2-a*e^2))*_
+     atan(x*sqrt(c)/sqrt(a))/(c^(5/2)*sqrt(a))
+--E 692
+
+--S 693 of 1125
+d0:=D(m0,x)
+--E 693
+
+)clear all
+
+--S 694 of 1125
+t0:=(A+B*x)*(d+e*x)^2/(a+c*x^2)
+--E 694
+
+--S 695 of 1125
+r0:=e*(2*B*d+A*e)*x/c+1/2*B*e^2*x^2/c+1/2*(B*c*d^2+2*A*c*d*e-a*B*e^2)*_
+     log(a+c*x^2)/c^2+(A*c*d^2-2*a*B*d*e-a*A*e^2)*atan(x*sqrt(c)/_
+     sqrt(a))/(c^(3/2)*sqrt(a))
+--E 695
+
+--S 696 of 1125
+d0:=D(m0,x)
+--E 696
+
+)clear all
+
+--S 697 of 1125
+t0:=(A+B*x)*(d+e*x)/(a+c*x^2)
+--E 697
+
+--S 698 of 1125
+r0:=B*e*x/c+1/2*(B*d+A*e)*log(a+c*x^2)/c+(A*c*d-a*B*e)*atan(x*sqrt(c)/_
+     sqrt(a))/(c^(3/2)*sqrt(a))
+--E 698
+
+--S 699 of 1125
+d0:=D(m0,x)
+--E 699
+
+)clear all
+
+--S 700 of 1125
+t0:=(A+B*x)/(a+c*x^2)
+--E 700
+
+--S 701 of 1125
+r0:=1/2*B*log(a+c*x^2)/c+A*atan(x*sqrt(c)/sqrt(a))/(sqrt(a)*sqrt(c))
+--E 701
+
+--S 702 of 1125
+d0:=D(m0,x)
+--E 702
+
+)clear all
+
+--S 703 of 1125
+t0:=(A+B*x)/((d+e*x)*(a+c*x^2))
+--E 703
+
+--S 704 of 1125
+r0:=-(B*d-A*e)*log(d+e*x)/(c*d^2+a*e^2)+1/2*(B*d-A*e)*log(a+c*x^2)/_
+     (c*d^2+a*e^2)+(A*c*d+a*B*e)*atan(x*sqrt(c)/sqrt(a))/((c*d^2+a*e^2)*_
+     sqrt(a)*sqrt(c))
+--E 704
+
+--S 705 of 1125
+d0:=D(m0,x)
+--E 705
+
+)clear all
+
+--S 706 of 1125
+t0:=(A+B*x)/((d+e*x)^2*(a+c*x^2))
+--E 706
+
+--S 707 of 1125
+r0:=(B*d-A*e)/((c*d^2+a*e^2)*(d+e*x))-(B*c*d^2-2*A*c*d*e-a*B*e^2)*_
+     log(d+e*x)/(c*d^2+a*e^2)^2+1/2*(B*c*d^2-2*A*c*d*e-a*B*e^2)*_
+     log(a+c*x^2)/(c*d^2+a*e^2)^2+(A*c*d^2+2*a*B*d*e-a*A*e^2)*_
+     atan(x*sqrt(c)/sqrt(a))*sqrt(c)/((c*d^2+a*e^2)^2*sqrt(a))
+--E 707
+
+--S 708 of 1125
+d0:=D(m0,x)
+--E 708
+
+)clear all
+
+--S 709 of 1125
+t0:=(A+B*x)/((d+e*x)^3*(a+c*x^2))
+--E 709
+
+--S 710 of 1125
+r0:=1/2*(B*d-A*e)/((c*d^2+a*e^2)*(d+e*x)^2)+(B*c*d^2-2*A*c*d*e-a*B*e^2)/_
+     ((c*d^2+a*e^2)^2*(d+e*x))-c*(B*c*d^3-3*A*c*d^2*e-3*a*B*d*e^2+_
+     a*A*e^3)*log(d+e*x)/(c*d^2+a*e^2)^3+1/2*c*(B*c*d^3-3*A*c*d^2*e-_
+     3*a*B*d*e^2+a*A*e^3)*log(a+c*x^2)/(c*d^2+a*e^2)^3+(A*c*d*(c*d^2-_
+     3*a*e^2)+a*B*e*(3*c*d^2-a*e^2))*atan(x*sqrt(c)/sqrt(a))*sqrt(c)/_
+     ((c*d^2+a*e^2)^3*sqrt(a))
+--E 710
+
+--S 711 of 1125
+d0:=D(m0,x)
+--E 711
+
+)clear all
+
+--S 712 of 1125
+t0:=(A+B*x)*(d+e*x)^5/(a+c*x^2)^2
+--E 712
+
+--S 713 of 1125
+r0:=-5/2*e^2*(A*c*d*(2*c*d^2-3*a*e^2)-a*B*e*(6*c*d^2-a*e^2))*x/(a*c^3)-_
+     e^3*(5*A*c*d^2-5*a*B*d*e-a*A*e^2)*x^2/(a*c^2)-5/6*e^4*(3*A*c*d-a*B*e)*_
+     x^3/(a*c^2)-1/2*A*e^5*x^4/(a*c)-1/2*(a*B-A*c*x)*(d+e*x)^5/(a*c*_
+     (a+c*x^2))+1/2*(A*c*d*(c^2*d^4+10*a*c*d^2*e^2-15*a^2*e^4)+5*a*B*_
+     e*(c^2*d^4-6*a*c*d^2*e^2+a^2*e^4))*atan(x*sqrt(c)/sqrt(a))/_
+     (a^(3/2)*c^(7/2))+e^2*(5*B*c*d^3+5*A*c*d^2*e-5*a*B*d*e^2-a*A*e^3)*_
+     log(a+c*x^2)/c^3
+--E 713
+
+--S 714 of 1125
+d0:=D(m0,x)
+--E 714
+
+)clear all
+
+--S 715 of 1125
+t0:=(A+B*x)*(d+e*x)^4/(a+c*x^2)^2
+--E 715
+
+--S 716 of 1125
+r0:=-3/2*e^2*(2*A*c*d^2-4*a*B*d*e-a*A*e^2)*x/(a*c^2)-e^3*(2*A*c*d-a*B*e)*_
+     x^2/(a*c^2)-1/2*A*e^4*x^3/(a*c)-1/2*(a*B-A*c*x)*(d+e*x)^4/(a*c*_
+     (a+c*x^2))+1/2*(4*a*B*d*e*(c*d^2-3*a*e^2)+A*(c^2*d^4+6*a*c*d^2*_
+     e^2-3*a^2*e^4))*atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*c^(5/2))+e^2*_
+     (3*B*c*d^2+2*A*c*d*e-a*B*e^2)*log(a+c*x^2)/c^3
+--E 716
+
+--S 717 of 1125
+d0:=D(m0,x)
+--E 717
+
+)clear all
+
+--S 718 of 1125
+t0:=(A+B*x)*(d+e*x)^3/(a+c*x^2)^2
+--E 718
+
+--S 719 of 1125
+r0:=-3/2*e^2*(A*c*d-a*B*e)*x/(a*c^2)-1/2*A*e^3*x^2/(a*c)-1/2*(a*B-A*c*x)*_
+     (d+e*x)^3/(a*c*(a+c*x^2))+1/2*(3*a*B*e*(c*d^2-a*e^2)+A*c*d*_
+     (c*d^2+3*a*e^2))*atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*c^(5/2))+1/2*_
+     e^2*(3*B*d+A*e)*log(a+c*x^2)/c^2
+--E 719
+
+--S 720 of 1125
+d0:=D(m0,x)
+--E 720
+
+)clear all
+
+--S 721 of 1125
+t0:=(A+B*x)*(d+e*x)^2/(a+c*x^2)^2
+--E 721
+
+--S 722 of 1125
+r0:=-1/2*A*e^2*x/(a*c)-1/2*(a*B-A*c*x)*(d+e*x)^2/(a*c*(a+c*x^2))+_
+     1/2*(A*c*d^2+2*a*B*d*e+a*A*e^2)*atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*_
+     c^(3/2))+1/2*B*e^2*log(a+c*x^2)/c^2
+--E 722
+
+--S 723 of 1125
+d0:=D(m0,x)
+--E 723
+
+)clear all
+
+--S 724 of 1125
+t0:=(A+B*x)*(d+e*x)/(a+c*x^2)^2
+--E 724
+
+--S 725 of 1125
+r0:=-1/2*(a*B-A*c*x)*(d+e*x)/(a*c*(a+c*x^2))+1/2*(A*c*d+a*B*e)*_
+     atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*c^(3/2))
+--E 725
+
+--S 726 of 1125
+d0:=D(m0,x)
+--E 726
+
+)clear all
+
+--S 727 of 1125
+t0:=(A+B*x)/(a+c*x^2)^2
+--E 727
+
+--S 728 of 1125
+r0:=1/2*(-a*B+A*c*x)/(a*c*(a+c*x^2))+1/2*A*atan(x*sqrt(c)/sqrt(a))/_
+     (a^(3/2)*sqrt(c))
+--E 728
+
+--S 729 of 1125
+d0:=D(m0,x)
+--E 729
+
+)clear all
+
+--S 730 of 1125
+t0:=(A+B*x)/((d+e*x)*(a+c*x^2)^2)
+--E 730
+
+--S 731 of 1125
+r0:=1/2*(-a*(B*d-A*e)+(A*c*d+a*B*e)*x)/(a*(c*d^2+a*e^2)*(a+c*x^2))-_
+     e^2*(B*d-A*e)*log(d+e*x)/(c*d^2+a*e^2)^2+1/2*e^2*(B*d-A*e)*log(a+_
+     c*x^2)/(c*d^2+a*e^2)^2-1/2*(a*B*e*(c*d^2-a*e^2)-A*c*d*(c*d^2+_
+     3*a*e^2))*atan(x*sqrt(c)/sqrt(a))/(a^(3/2)*(c*d^2+a*e^2)^2*sqrt(c))
+--E 731
+
+--S 732 of 1125
+d0:=D(m0,x)
+--E 732
+
+)clear all
+
+--S 733 of 1125
+t0:=(A+B*x)/((d+e*x)^2*(a+c*x^2)^2)
+--E 733
+
+--S 734 of 1125
+r0:=1/2*e*(A*c*d^2+4*a*B*d*e-3*a*A*e^2)/(a*(c*d^2+a*e^2)^2*(d+e*x))+_
+     1/2*(-a*(B*d-A*e)+(A*c*d+a*B*e)*x)/(a*(c*d^2+a*e^2)*(d+e*x)*_
+     (a+c*x^2))-e^2*(3*B*c*d^2-4*A*c*d*e-a*B*e^2)*log(d+e*x)/(c*d^2+_
+     a*e^2)^3+1/2*e^2*(3*B*c*d^2-4*A*c*d*e-a*B*e^2)*log(a+c*x^2)/_
+     (c*d^2+a*e^2)^3-1/2*(2*a*B*d*e*(c*d^2-3*a*e^2)-A*(c^2*d^4+6*a*_
+     c*d^2*e^2-3*a^2*e^4))*atan(x*sqrt(c)/sqrt(a))*sqrt(c)/(a^(3/2)*_
+     (c*d^2+a*e^2)^3)
+--E 734
+
+--S 735 of 1125
+d0:=D(m0,x)
+--E 735
+
+)clear all
+
+--S 736 of 1125
+t0:=(A+B*x)*(d+e*x)^5/(a+c*x^2)^3
+--E 736
+
+--S 737 of 1125
+r0:=-3/8*e^2*(5*a*B*e*(2*c*d^2-a*e^2)+A*c*d*(6*c*d^2+5*a*e^2))*x/(a^2*c^3)-_
+     1/2*e^3*(3*A*c*d^2+5*a*B*d*e+a*A*e^2)*x^2/(a^2*c^2)-1/8*e^4*(3*A*_
+     c*d+5*a*B*e)*x^3/(a^2*c^2)-1/4*(a*B-A*c*x)*(d+e*x)^5/(a*c*(a+_
+     c*x^2)^2)+1/8*(d+e*x)^4*(2*a*A*e+(3*A*c*d+5*a*B*e)*x)/(a^2*c*(a+_
+     c*x^2))+1/8*(5*a*B*e*(c^2*d^4+6*a*c*d^2*e^2-3*a^2*e^4)+A*c*d*_
+     (3*c^2*d^4+10*a*c*d^2*e^2+15*a^2*e^4))*atan(x*sqrt(c)/sqrt(a))/_
+     (a^(5/2)*c^(7/2))+1/2*e^4*(5*B*d+A*e)*log(a+c*x^2)/c^3
+--E 737
+
+--S 738 of 1125
+d0:=D(m0,x)
+--E 738
+
+)clear all
+
+--S 739 of 1125
+t0:=(A+B*x)*(d+e*x)^4/(a+c*x^2)^3
+--E 739
+
+--S 740 of 1125
+r0:=-3/8*e^2*(3*A*c*d^2+4*a*B*d*e+a*A*e^2)*x/(a^2*c^2)-1/8*e^3*(3*A*c*d+_
+     4*a*B*e)*x^2/(a^2*c^2)-1/4*(a*B-A*c*x)*(d+e*x)^4/(a*c*(a+c*x^2)^2)+_
+     1/8*(d+e*x)^3*(a*A*e+(3*A*c*d+4*a*B*e)*x)/(a^2*c*(a+c*x^2))+_
+     1/8*(3*A*(c*d^2+a*e^2)^2+4*a*B*d*e*(c*d^2+3*a*e^2))*atan(x*_
+     sqrt(c)/sqrt(a))/(a^(5/2)*c^(5/2))+1/2*B*e^4*log(a+c*x^2)/c^3
+--E 740
+
+--S 741 of 1125
+d0:=D(m0,x)
+--E 741
+
+)clear all
+
+--S 742 of 1125
+t0:=(A+B*x)*(d+e*x)^3/(a+c*x^2)^3
+--E 742
+
+--S 743 of 1125
+r0:=-1/4*(a*B-A*c*x)*(d+e*x)^3/(a*c*(a+c*x^2)^2)-3/8*(A*c*d+a*B*e)*_
+     (a*e-c*d*x)*(d+e*x)/(a^2*c^2*(a+c*x^2))+3/8*(A*c*d+a*B*e)*(c*d^2+_
+     a*e^2)*atan(x*sqrt(c)/sqrt(a))/(a^(5/2)*c^(5/2))
+--E 743
+
+--S 744 of 1125
+d0:=D(m0,x)
+--E 744
+
+)clear all
+
+--S 745 of 1125
+t0:=(A+B*x)*(d+e*x)^2/(a+c*x^2)^3
+--E 745
+
+--S 746 of 1125
+r0:=-1/4*(a*B-A*c*x)*(d+e*x)^2/(a*c*(a+c*x^2)^2)-1/8*(a*e-c*d*x)*_
+     (3*A*c*d+2*a*B*e+A*c*e*x)/(a^2*c^2*(a+c*x^2))+1/8*(3*A*c*d^2+2*a*_
+     B*d*e+a*A*e^2)*atan(x*sqrt(c)/sqrt(a))/(a^(5/2)*c^(3/2))
+--E 746
+
+--S 747 of 1125
+d0:=D(m0,x)
+--E 747
+
+)clear all
+
+--S 748 of 1125
+t0:=(A+B*x)*(d+e*x)/(a+c*x^2)^3
+--E 748
+
+--S 749 of 1125
+r0:=-1/4*(a*B-A*c*x)*(d+e*x)/(a*c*(a+c*x^2)^2)+1/8*(-2*a*A*e+(3*A*c*d+_
+     a*B*e)*x)/(a^2*c*(a+c*x^2))+1/8*(3*A*c*d+a*B*e)*atan(x*sqrt(c)/_
+     sqrt(a))/(a^(5/2)*c^(3/2))
+--E 749
+
+--S 750 of 1125
+d0:=D(m0,x)
+--E 750
+
+)clear all
+
+--S 751 of 1125
+t0:=(A+B*x)/(a+c*x^2)^3
+--E 751
+
+--S 752 of 1125
+r0:=1/4*(-a*B+A*c*x)/(a*c*(a+c*x^2)^2)+3/8*A*x/(a^2*(a+c*x^2))+_
+     3/8*A*atan(x*sqrt(c)/sqrt(a))/(a^(5/2)*sqrt(c))
+--E 752
+
+--S 753 of 1125
+d0:=D(m0,x)
+--E 753
+
+)clear all
+
+--S 754 of 1125
+t0:=(A+B*x)/((d+e*x)*(a+c*x^2)^3)
+--E 754
+
+--S 755 of 1125
+r0:=1/4*(-a*(B*d-A*e)+(A*c*d+a*B*e)*x)/(a*(c*d^2+a*e^2)*(a+c*x^2)^2)+_
+     1/8*(-4*a^2*e^2*(B*d-A*e)-(a*B*e*(c*d^2-3*a*e^2)-A*c*d*(3*c*d^2+7*_
+     a*e^2))*x)/(a^2*(c*d^2+a*e^2)^2*(a+c*x^2))-e^4*(B*d-A*e)*log(d+_
+     e*x)/(c*d^2+a*e^2)^3+1/2*e^4*(B*d-A*e)*log(a+c*x^2)/(c*d^2+_
+     a*e^2)^3-1/8*(a*B*e*(c^2*d^4+6*a*c*d^2*e^2-3*a^2*e^4)-A*c*d*_
+     (3*c^2*d^4+10*a*c*d^2*e^2+15*a^2*e^4))*atan(x*sqrt(c)/sqrt(a))/_
+     (a^(5/2)*(c*d^2+a*e^2)^3*sqrt(c))
+--E 755
+
+--S 756 of 1125
+d0:=D(m0,x)
+--E 756
+
+)clear all
+
+--S 757 of 1125
+t0:=(A+B*x)/((d+e*x)^2*(a+c*x^2)^3)
+--E 757
+
+--S 758 of 1125
+r0:=-1/8*e*(2*a*B*d*e*(c*d^2-11*a*e^2)-3*A*(c^2*d^4+4*a*c*d^2*e^2-_
+     5*a^2*e^4))/(a^2*(c*d^2+a*e^2)^3*(d+e*x))+1/4*(-a*(B*d-A*e)+_
+     (A*c*d+a*B*e)*x)/(a*(c*d^2+a*e^2)*(d+e*x)*(a+c*x^2)^2)+1/8*(-a*_
+     e*(A*c*d^2+6*a*B*d*e-5*a*A*e^2)-(2*a*B*e*(c*d^2-2*a*e^2)-3*A*c*d*_
+     (c*d^2+3*a*e^2))*x)/(a^2*(c*d^2+a*e^2)^2*(d+e*x)*(a+c*x^2))-e^4*_
+     (5*B*c*d^2-6*A*c*d*e-a*B*e^2)*log(d+e*x)/(c*d^2+a*e^2)^4+1/2*e^4*_
+     (5*B*c*d^2-6*A*c*d*e-a*B*e^2)*log(a+c*x^2)/(c*d^2+a*e^2)^4-1/8*_
+     (2*a*B*d*e*(c^2*d^4+10*a*c*d^2*e^2-15*a^2*e^4)-3*A*(c^3*d^6+_
+     5*a*c^2*d^4*e^2+15*a^2*c*d^2*e^4-5*a^3*e^6))*atan(x*sqrt(c)/_
+     sqrt(a))*sqrt(c)/(a^(5/2)*(c*d^2+a*e^2)^4)
+--E 758
+
+--S 759 of 1125
+d0:=D(m0,x)
+--E 759
+
+)clear all
+
+--S 760 of 1125
+t0:=(-11+6*x)/((-1+2*x)*(-1+x^2))
+--E 760
+
+--S 761 of 1125
+r0:=16/3*log(1-2*x)-5/2*log(1-x)-17/6*log(1+x)
+--E 761
+
+--S 762 of 1125
+d0:=D(m0,x)
+--E 762
+
+)clear all
+
+--S 763 of 1125
+t0:=(5-x)*(3+2*x)^4*sqrt(2+3*x^2)
+--E 763
+
+--S 764 of 1125
+r0:=8275/162*(2+3*x^2)^(3/2)+923/315*(3+2*x)^2*(2+3*x^2)^(3/2)+29/63*_
+     (3+2*x)^3*(2+3*x^2)^(3/2)-1/21*(3+2*x)^4*(2+3*x^2)^(3/2)+1/270*_
+     (4583+6132*x)*(2+3*x^2)^(3/2)+2341/9*asinh(x*sqrt(3/2))/sqrt(3)+_
+     2341/18*x*sqrt(2+3*x^2)
+--E 764
+
+--S 765 of 1125
+d0:=D(m0,x)
+--E 765
+
+--S 766 of 1125
+t0:=x^2*(a*x^2+b*x^3+c*x^4)
+--E 766
+
+--S 767 of 1125
+r0:=1/5*a*x^5+1/6*b*x^6+1/7*c*x^7
+--E 767
+
+--S 768 of 1125
+d0:=D(m0,x)
+--E 768
+
+)clear all
+
+--S 769 of 1125
+t0:=x*(a*x^2+b*x^3+c*x^4)
+--E 769
+
+--S 770 of 1125
+r0:=1/4*a*x^4+1/5*b*x^5+1/6*c*x^6
+--E 770
+
+--S 771 of 1125
+d0:=D(m0,x)
+--E 771
+
+)clear all
+
+--S 772 of 1125
+t0:=a*x^2+b*x^3+c*x^4
+--E 772
+
+--S 773 of 1125
+r0:=1/3*a*x^3+1/4*b*x^4+1/5*c*x^5
+--E 773
+
+--S 774 of 1125
+d0:=D(m0,x)
+--E 774
+
+)clear all
+
+--S 775 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)/x
+--E 775
+
+--S 776 of 1125
+r0:=1/2*a*x^2+1/3*b*x^3+1/4*c*x^4
+--E 776
+
+--S 777 of 1125
+d0:=D(m0,x)
+--E 777
+
+)clear all
+
+--S 778 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)/x^2
+--E 778
+
+--S 779 of 1125
+r0:=a*x+1/2*b*x^2+1/3*c*x^3
+--E 779
+
+--S 780 of 1125
+d0:=D(m0,x)
+--E 780
+
+)clear all
+
+--S 781 of 1125
+t0:=x^2*(a*x^2+b*x^3+c*x^4)^2
+--E 781
+
+--S 782 of 1125
+r0:=1/7*a^2*x^7+1/4*a*b*x^8+1/9*(b^2+2*a*c)*x^9+1/5*b*c*x^10+1/11*c^2*x^11
+--E 782
+
+--S 783 of 1125
+d0:=D(m0,x)
+--E 783
+
+)clear all
+
+--S 784 of 1125
+t0:=x*(a*x^2+b*x^3+c*x^4)^2
+--E 784
+
+--S 785 of 1125
+r0:=1/6*a^2*x^6+2/7*a*b*x^7+1/8*(b^2+2*a*c)*x^8+2/9*b*c*x^9+1/10*c^2*x^10
+--E 785
+
+--S 786 of 1125
+d0:=D(m0,x)
+--E 786
+
+)clear all
+
+--S 787 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^2
+--E 787
+
+--S 788 of 1125
+r0:=1/5*a^2*x^5+1/3*a*b*x^6+1/7*(b^2+2*a*c)*x^7+1/4*b*c*x^8+1/9*c^2*x^9
+--E 788
+
+--S 789 of 1125
+d0:=D(m0,x)
+--E 789
+
+)clear all
+
+--S 790 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^2/x
+--E 790
+
+--S 791 of 1125
+r0:=1/4*a^2*x^4+2/5*a*b*x^5+1/6*(b^2+2*a*c)*x^6+2/7*b*c*x^7+1/8*c^2*x^8
+--E 791
+
+--S 792 of 1125
+d0:=D(m0,x)
+--E 792
+
+)clear all
+
+--S 793 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^2/x^2
+--E 793
+
+--S 794 of 1125
+r0:=1/3*a^2*x^3+1/2*a*b*x^4+1/5*(b^2+2*a*c)*x^5+1/3*b*c*x^6+1/7*c^2*x^7
+--E 794
+
+--S 795 of 1125
+d0:=D(m0,x)
+--E 795
+
+)clear all
+
+--S 796 of 1125
+t0:=x^5/(a*x^2+b*x^3+c*x^4)
+--E 796
+
+--S 797 of 1125
+r0:=-b*x/c^2+1/2*x^2/c+1/2*(b^2-a*c)*log(a+b*x+c*x^2)/c^3+b*(b^2-3*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^3*sqrt(b^2-4*a*c))
+--E 797
+
+--S 798 of 1125
+d0:=D(m0a,x)
+--E 798
+
+)clear all
+
+--S 799 of 1125
+t0:=x^4/(a*x^2+b*x^3+c*x^4)
+--E 799
+
+--S 800 of 1125
+r0:=x/c-1/2*b*log(a+b*x+c*x^2)/c^2-(b^2-2*a*c)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--E 800
+
+--S 801 of 1125
+d0:=D(m0a,x)
+--E 801
+
+)clear all
+
+--S 802 of 1125
+t0:=x^3/(a*x^2+b*x^3+c*x^4)
+--E 802
+
+--S 803 of 1125
+r0:=1/2*log(a+b*x+c*x^2)/c+b*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--E 803
+
+--S 804 of 1125
+d0:=D(m0a,x)
+--E 804
+
+)clear all
+
+--S 805 of 1125
+t0:=x^2/(a*x^2+b*x^3+c*x^4)
+--E 805
+
+--S 806 of 1125
+r0:=-2*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--E 806
+
+--S 807 of 1125
+d0:=D(m0a,x)
+--E 807
+
+)clear all
+
+--S 808 of 1125
+t0:=x/(a*x^2+b*x^3+c*x^4)
+--E 808
+
+--S 809 of 1125
+r0:=log(x)/a-1/2*log(a+b*x+c*x^2)/a+b*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (a*sqrt(b^2-4*a*c))
+--E 809
+
+--S 810 of 1125
+d0:=D(m0a,x)
+--E 810
+
+)clear all
+
+--S 811 of 1125
+t0:=1/(a*x^2+b*x^3+c*x^4)
+--E 811
+
+--S 812 of 1125
+r0:=(-1)/(a*x)-b*log(x)/a^2+1/2*b*log(a+b*x+c*x^2)/a^2-(b^2-2*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--E 812
+
+--S 813 of 1125
+d0:=D(m0a,x)
+--E 813
+
+)clear all
+
+--S 814 of 1125
+t0:=1/(x*(a*x^2+b*x^3+c*x^4))
+--E 814
+
+--S 815 of 1125
+r0:=(-1/2)/(a*x^2)+b/(a^2*x)+(b^2-a*c)*log(x)/a^3-1/2*(b^2-a*c)*_
+   log(a+b*x+c*x^2)/a^3+b*(b^2-3*a*c)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (a^3*sqrt(b^2-4*a*c))
+--E 815
+
+--S 816 of 1125
+d0:=D(m0a,x)
+--E 816
+
+)clear all
+
+--S 817 of 1125
+t0:=1/(x^2*(a*x^2+b*x^3+c*x^4))
+--E 817
+
+--S 818 of 1125
+r0:=(-1/3)/(a*x^3)+1/2*b/(a^2*x^2)+(-b^2+a*c)/(a^3*x)-b*(b^2-2*a*c)*_
+   log(x)/a^4+1/2*b*(b^2-2*a*c)*log(a+b*x+c*x^2)/a^4-(b^4-4*a*b^2*c+_
+   2*a^2*c^2)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^4*sqrt(b^2-4*a*c))
+--E 818
+
+--S 819 of 1125
+d0:=D(m0a,x)
+--E 819
+
+)clear all
+
+--S 820 of 1125
+t0:=x^8/(a*x^2+b*x^3+c*x^4)^2
+--E 820
+
+--S 821 of 1125
+r0:=2*(b^2-3*a*c)*x/(c^2*(b^2-4*a*c))-b*x^2/(c*(b^2-4*a*c))+_
+   x^3*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))-2*(b^4-6*a*b^2*c+6*a^2*c^2)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^3*(b^2-4*a*c)^(3/2))-_
+   b*log(a+b*x+c*x^2)/c^3
+--E 821
+
+--S 822 of 1125
+d0:=D(m0a,x)
+--E 822
+
+)clear all
+
+--S 823 of 1125
+t0:=x^7/(a*x^2+b*x^3+c*x^4)^2
+--E 823
+
+--S 824 of 1125
+r0:=-b*x/(c*(b^2-4*a*c))+x^2*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))+_
+   b*(b^2-6*a*c)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(c^2*(b^2-_
+   4*a*c)^(3/2))+1/2*log(a+b*x+c*x^2)/c^2
+--E 824
+
+--S 825 of 1125
+d0:=D(m0a,x)
+--E 825
+
+)clear all
+
+--S 826 of 1125
+t0:=x^6/(a*x^2+b*x^3+c*x^4)^2
+--E 826
+
+--S 827 of 1125
+r0:=x*(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))+4*a*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--E 827
+
+--S 828 of 1125
+d0:=D(m0a,x)
+--E 828
+
+)clear all
+
+--S 829 of 1125
+t0:=x^5/(a*x^2+b*x^3+c*x^4)^2
+--E 829
+
+--S 830 of 1125
+r0:=(2*a+b*x)/((b^2-4*a*c)*(a+b*x+c*x^2))-2*b*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--E 830
+
+--S 831 of 1125
+d0:=D(m0a,x)
+--E 831
+
+)clear all
+
+--S 832 of 1125
+t0:=x^4/(a*x^2+b*x^3+c*x^4)^2
+--E 832
+
+--S 833 of 1125
+r0:=(-b-2*c*x)/((b^2-4*a*c)*(a+b*x+c*x^2))+4*c*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--E 833
+
+--S 834 of 1125
+d0:=D(m0a,x)
+--E 834
+
+)clear all
+
+--S 835 of 1125
+t0:=x^3/(a*x^2+b*x^3+c*x^4)^2
+--E 835
+
+--S 836 of 1125
+r0:=(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*(a+b*x+c*x^2))+b*(b^2-6*a*c)*_
+   atanh((b+2*c*x)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)^(3/2))+log(x)/a^2-_
+   1/2*log(a+b*x+c*x^2)/a^2
+--E 836
+
+--S 837 of 1125
+d0:=D(m0a,x)
+--E 837
+
+)clear all
+
+--S 838 of 1125
+t0:=x^2/(a*x^2+b*x^3+c*x^4)^2
+--E 838
+
+--S 839 of 1125
+r0:=-2*(b^2-3*a*c)/(a^2*(b^2-4*a*c)*x)+(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*_
+   x*(a+b*x+c*x^2))-2*(b^4-6*a*b^2*c+6*a^2*c^2)*atanh((b+2*c*x)/_
+   sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(3/2))-2*b*log(x)/a^3+_
+   b*log(a+b*x+c*x^2)/a^3
+--E 839
+
+--S 840 of 1125
+d0:=D(m0a,x)
+--E 840
+
+)clear all
+
+--S 841 of 1125
+t0:=x/(a*x^2+b*x^3+c*x^4)^2
+--E 841
+
+--S 842 of 1125
+r0:=1/2*(-3*b^2+8*a*c)/(a^2*(b^2-4*a*c)*x^2)+b*(3*b^2-11*a*c)/(a^3*_
+   (b^2-4*a*c)*x)+(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^2*(a+b*x+c*x^2))+_
+   b*(3*b^4-20*a*b^2*c+30*a^2*c^2)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (a^4*(b^2-4*a*c)^(3/2))+(3*b^2-2*a*c)*log(x)/a^4-1/2*(3*b^2-2*a*c)*_
+   log(a+b*x+c*x^2)/a^4
+--E 842
+
+--S 843 of 1125
+d0:=D(m0a,x)
+--E 843
+
+)clear all
+
+--S 844 of 1125
+t0:=1/(a*x^2+b*x^3+c*x^4)^2
+--E 844
+
+--S 845 of 1125
+r0:=-2/3*(2*b^2-5*a*c)/(a^2*(b^2-4*a*c)*x^3)+b*(2*b^2-7*a*c)/(a^3*_
+   (b^2-4*a*c)*x^2)-2*(2*b^4-9*a*b^2*c+5*a^2*c^2)/(a^4*(b^2-4*a*c)*x)+_
+   (b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^3*(a+b*x+c*x^2))-2*(2*b^6-_
+   15*a*b^4*c+30*a^2*b^2*c^2-10*a^3*c^3)*atanh((b+2*c*x)/sqrt(b^2-4*a*c))/_
+   (a^5*(b^2-4*a*c)^(3/2))-2*b*(2*b^2-3*a*c)*log(x)/a^5+b*(2*b^2-3*a*c)*_
+   log(a+b*x+c*x^2)/a^5
+--E 845
+
+--S 846 of 1125
+d0:=D(m0a,x)
+--E 846
+
+)clear all
+
+--S 847 of 1125
+t0:=1/(x*(a*x^2+b*x^3+c*x^4)^2)
+--E 847
+
+--S 848 of 1125
+r0:=1/4*(-5*b^2+12*a*c)/(a^2*(b^2-4*a*c)*x^4)+1/3*b*(5*b^2-17*a*c)/_
+   (a^3*(b^2-4*a*c)*x^3)+1/2*(-5*b^4+22*a*b^2*c-12*a^2*c^2)/(a^4*_
+   (b^2-4*a*c)*x^2)+b*(5*b^4-27*a*b^2*c+29*a^2*c^2)/(a^5*(b^2-4*a*c)*x)+_
+   (b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^4*(a+b*x+c*x^2))+b*(5*b^6-_
+   42*a*b^4*c+105*a^2*b^2*c^2-70*a^3*c^3)*atanh((b+2*c*x)/sqrt(b^2-_
+   4*a*c))/(a^6*(b^2-4*a*c)^(3/2))+(5*b^4-12*a*b^2*c+3*a^2*c^2)*log(x)/a^6-_
+   1/2*(5*b^4-12*a*b^2*c+3*a^2*c^2)*log(a+b*x+c*x^2)/a^6
+--E 848
+
+--S 849 of 1125
+d0:=D(m0a,x)
+--E 849
+
+)clear all
+
+--S 850 of 1125
+t0:=x^2*sqrt(a*x^2+b*x^3+c*x^4)
+--E 850
+
+--S 851 of 1125
+r0:=1/256*b*(7*b^2-12*a*c)*(b^2-4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(c^(9/2)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   1/960*b*(35*b^2-116*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/c^3-1/1920*(105*b^4-_
+   460*a*b^2*c+256*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/(c^4*x)-1/240*(7*b^2-_
+   16*a*c)*x*sqrt(a*x^2+b*x^3+c*x^4)/c^2+1/40*x^2*(b+8*c*x)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/c
+--E 851
+
+--S 852 of 1125
+d0:=D(m0a,x)
+--E 852
+
+)clear all
+
+--S 853 of 1125
+t0:=x*sqrt(a*x^2+b*x^3+c*x^4)
+--E 853
+
+--S 854 of 1125
+r0:=-1/128*(b^2-4*a*c)*(5*b^2-4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(c^(7/2)*sqrt(a*x^2+b*x^3+c*x^4))-_
+   1/96*(5*b^2-12*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/c^2+1/192*b*(15*b^2-52*a*c)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(c^3*x)+1/24*x*(b+6*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/c
+--E 854
+
+--S 855 of 1125
+d0:=D(m0a,x)
+--E 855
+
+)clear all
+
+--S 856 of 1125
+t0:=sqrt(a*x^2+b*x^3+c*x^4)
+--E 856
+
+--S 857 of 1125
+r0:=-1/8*b*(b+2*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/(c^2*x)+1/3*(a+b*x+c*x^2)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(c*x)+1/16*b*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a*x^2+b*x^3+c*x^4)/(c^(5/2)*_
+   x*sqrt(a+b*x+c*x^2))
+--E 857
+
+--S 858 of 1125
+d0:=D(m0a,x)
+--E 858
+
+)clear all
+
+--S 859 of 1125
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x
+--E 859
+
+--S 860 of 1125
+r0:=-1/8*(b^2-4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(c^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))+1/4*(b+2*c*x)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(c*x)
+--E 860
+
+--S 861 of 1125
+d0:=D(m0a,x)
+--E 861
+
+)clear all
+
+--S 862 of 1125
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x^2
+--E 862
+
+--S 863 of 1125
+r0:=-x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a)*_
+   sqrt(a+b*x+c*x^2)/sqrt(a*x^2+b*x^3+c*x^4)+1/2*b*x*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(sqrt(c)*sqrt(a*x^2+_
+   b*x^3+c*x^4))+sqrt(a*x^2+b*x^3+c*x^4)/x
+--E 863
+
+--S 864 of 1125
+d0:=D(m0a,x)
+--E 864
+
+)clear all
+
+--S 865 of 1125
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x^3
+--E 865
+
+--S 866 of 1125
+r0:=-1/2*b*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(sqrt(a)*sqrt(a*x^2+b*x^3+c*x^4))+x*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(c)*sqrt(a+b*x+c*x^2)/_
+   sqrt(a*x^2+b*x^3+c*x^4)-sqrt(a*x^2+b*x^3+c*x^4)/x^2
+--E 866
+
+--S 867 of 1125
+d0:=D(m0a,x)
+--E 867
+
+)clear all
+
+--S 868 of 1125
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x^4
+--E 868
+
+--S 869 of 1125
+r0:=1/8*(b^2-4*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/2*sqrt(a*x^2+_
+   b*x^3+c*x^4)/x^3-1/4*b*sqrt(a*x^2+b*x^3+c*x^4)/(a*x^2)
+--E 869
+
+--S 870 of 1125
+d0:=D(m0,x)
+--E 870
+
+)clear all
+
+--S 871 of 1125
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x^5
+--E 871
+
+--S 872 of 1125
+r0:=-1/16*b*(b^2-4*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/3*sqrt(a*x^2+_
+   b*x^3+c*x^4)/x^4-1/12*b*sqrt(a*x^2+b*x^3+c*x^4)/(a*x^3)+1/24*(3*b^2-_
+   8*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*x^2)
+--E 872
+
+--S 873 of 1125
+d0:=D(m0,x)
+--E 873
+
+)clear all
+
+--S 874 of 1125
+t0:=sqrt(a*x^2+b*x^3+c*x^4)/x^6
+--E 874
+
+--S 875 of 1125
+r0:=1/128*(b^2-4*a*c)*(5*b^2-4*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(a^(7/2)*sqrt(a*x^2+b*x^3+_
+   c*x^4))-1/4*sqrt(a*x^2+b*x^3+c*x^4)/x^5-1/24*b*sqrt(a*x^2+b*x^3+_
+   c*x^4)/(a*x^4)+1/96*(5*b^2-12*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*x^3)-_
+   1/192*b*(15*b^2-52*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^3*x^2)
+--E 875
+
+--S 876 of 1125
+d0:=D(m0,x)
+--E 876
+
+)clear all
+
+--S 877 of 1125
+t0:=x*(a*x^2+b*x^3+c*x^4)^(3/2)
+--E 877
+
+--S 878 of 1125
+r0:=1/112*x*(3*b+14*c*x)*(a*x^2+b*x^3+c*x^4)^(3/2)/c+3/32768*(b^2-4*a*c)^2*_
+   (33*b^4-72*a*b^2*c+16*a^2*c^2)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(c^(13/2)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   1/286720*(1155*b^6-8988*a*b^4*c+18896*a^2*b^2*c^2-6720*a^3*c^3)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/c^5-1/573440*b*(3465*b^6-30660*a*b^4*c+81648*_
+   a^2*b^2*c^2-58816*a^3*c^3)*sqrt(a*x^2+b*x^3+c*x^4)/(c^6*x)-_
+   1/71680*b*(231*b^4-1560*a*b^2*c+2416*a^2*c^2)*x*sqrt(a*x^2+b*x^3+_
+   c*x^4)/c^4+1/35840*(99*b^4-568*a*b^2*c+560*a^2*c^2)*x^2*sqrt(a*x^2+_
+   b*x^3+c*x^4)/c^3-1/4480*x^3*(b*(11*b^2+68*a*c)+10*c*(11*b^2-28*a*c)*_
+   x)*sqrt(a*x^2+b*x^3+c*x^4)/c^2
+--E 878
+
+--S 879 of 1125
+d0:=D(m0,x)
+--E 879
+
+)clear all
+
+--S 880 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)
+--E 880
+
+--S 881 of 1125
+r0:=1/7*x*(a*x^2+b*x^3+c*x^4)^(3/2)-3/2048*b*(b^2-4*a*c)^2*(3*b^2-4*a*c)*_
+   x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (c^(11/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/17920*b*(105*b^4-728*a*b^2*c+_
+   1168*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/c^4+1/35840*(315*b^6-2520*a*b^4*c+_
+   5488*a^2*b^2*c^2-2048*a^3*c^3)*sqrt(a*x^2+b*x^3+c*x^4)/(c^5*x)+_
+   1/4480*(7*b^2-32*a*c)*(3*b^2-4*a*c)*x*sqrt(a*x^2+b*x^3+c*x^4)/c^3-_
+   1/2240*b*(9*b^2-44*a*c)*x^2*sqrt(a*x^2+b*x^3+c*x^4)/c^2+1/280*x^3*_
+   (b^2+24*a*c+10*b*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/c
+--E 881
+
+--S 882 of 1125
+d0:=D(m0a,x)
+--E 882
+
+)clear all
+
+--S 883 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x
+--E 883
+
+--S 884 of 1125
+r0:=1/60*(3*b+10*c*x)*(a*x^2+b*x^3+c*x^4)^(3/2)/(c*x)+1/1024*(b^2-4*a*c)^2*_
+   (7*b^2-4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(c^(9/2)*sqrt(a*x^2+b*x^3+c*x^4))+1/3840*(35*b^4-_
+   216*a*b^2*c+240*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/c^3-1/7680*b*(105*b^4-_
+   760*a*b^2*c+1296*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/(c^4*x)-1/960*x*_
+   (b*(7*b^2+12*a*c)+6*c*(7*b^2-20*a*c)*x)*sqrt(a*x^2+b*x^3+c*x^4)/c^2
+--E 884
+
+--S 885 of 1125
+d0:=D(m0a,x)
+--E 885
+
+)clear all
+
+--S 886 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^2
+--E 886
+
+--S 887 of 1125
+r0:=-1/16*b*(b+2*c*x)*(a*x^2+b*x^3+c*x^4)^(3/2)/(c^2*x^3)+1/5*(a*x^2+b*x^3+_
+   c*x^4)^(5/2)/(c*x^5)-3/256*b*(b^2-4*a*c)^2*x*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(c^(7/2)*sqrt(a*x^2+b*_
+   x^3+c*x^4))+3/128*b*(b^2-4*a*c)*(b+2*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/(c^3*x)
+--E 887
+
+--S 888 of 1125
+d0:=D(m0a,x)
+--E 888
+
+)clear all
+
+--S 889 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^3
+--E 889
+
+--S 890 of 1125
+r0:=1/8*(b+2*c*x)*(a*x^2+b*x^3+c*x^4)^(3/2)/(c*x^3)+3/128*(b^2-4*a*c)^2*x*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (c^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))-3/64*(b^2-4*a*c)*(b+2*c*x)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(c^2*x)
+--E 890
+
+--S 891 of 1125
+d0:=D(m0a,x)
+--E 891
+
+)clear all
+
+--S 892 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^4
+--E 892
+
+--S 893 of 1125
+r0:=1/3*(a*x^2+b*x^3+c*x^4)^(3/2)/x^3-a^(3/2)*x*atanh(1/2*(2*a+b*x)/_
+   (sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/sqrt(a*x^2+b*x^3+c*x^4)-_
+   1/16*b*(b^2-12*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(c^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))+1/8*(b^2+8*a*c+_
+   2*b*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/(c*x)
+--E 893
+
+--S 894 of 1125
+d0:=D(m0a,x)
+--E 894
+
+)clear all
+
+--S 895 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^5
+--E 895
+
+--S 896 of 1125
+r0:=-(a*x^2+b*x^3+c*x^4)^(3/2)/x^4-3/2*b*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a)*sqrt(a+b*x+c*x^2)/sqrt(a*x^2+b*x^3+c*x^4)+_
+   3/8*(b^2+4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(sqrt(c)*sqrt(a*x^2+b*x^3+c*x^4))+3/4*(3*b+2*c*x)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/x
+--E 896
+
+--S 897 of 1125
+d0:=D(m0a,x)
+--E 897
+
+)clear all
+
+--S 898 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^6
+--E 898
+
+--S 899 of 1125
+r0:=-1/2*(a*x^2+b*x^3+c*x^4)^(3/2)/x^5-3/8*(b^2+4*a*c)*x*atanh(1/2*_
+   (2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(sqrt(a)*_
+   sqrt(a*x^2+b*x^3+c*x^4))+3/2*b*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+_
+   b*x+c*x^2)))*sqrt(c)*sqrt(a+b*x+c*x^2)/sqrt(a*x^2+b*x^3+c*x^4)-_
+   3/4*(b-2*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/x^2
+--E 899
+
+--S 900 of 1125
+d0:=D(m0a,x)
+--E 900
+
+)clear all
+
+--S 901 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^7
+--E 901
+
+--S 902 of 1125
+r0:=-1/3*(a*x^2+b*x^3+c*x^4)^(3/2)/x^6-1/4*b*(a*x^2+b*x^3+c*x^4)^(3/2)/_
+   (a*x^5)+1/16*b*(b^2-12*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+_
+   b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(a^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   c^(3/2)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+_
+   b*x+c*x^2)/sqrt(a*x^2+b*x^3+c*x^4)+1/8*(b^2-8*a*c+2*b*c*x)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a*x^2)
+--E 902
+
+--S 903 of 1125
+d0:=D(m0a,x)
+--E 903
+
+)clear all
+
+--S 904 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^8
+--E 904
+
+--S 905 of 1125
+r0:=-1/4*(a*x^2+b*x^3+c*x^4)^(3/2)/x^7-3/128*(b^2-4*a*c)^2*x*atanh(1/2*_
+   (2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(a^(5/2)*_
+   sqrt(a*x^2+b*x^3+c*x^4))-1/32*(b^2-12*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/_
+   (a*x^3)+1/64*b*(3*b^2-20*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*x^2)-_
+   1/8*(b+6*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/x^4
+--E 905
+
+--S 906 of 1125
+d0:=D(m0,x)
+--E 906
+
+)clear all
+
+--S 907 of 1125
+t0:=(a*x^2+b*x^3+c*x^4)^(3/2)/x^9
+--E 907
+
+--S 908 of 1125
+r0:=-1/5*(a*x^2+b*x^3+c*x^4)^(3/2)/x^8+3/256*b*(b^2-4*a*c)^2*x*_
+   atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (a^(7/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/80*(b^2-8*a*c)*sqrt(a*x^2+b*x^3+_
+   c*x^4)/(a*x^4)+1/320*b*(5*b^2-28*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*x^3)-_
+   1/640*(15*b^4-100*a*b^2*c+128*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/_
+   (a^3*x^2)-3/40*(b+4*c*x)*sqrt(a*x^2+b*x^3+c*x^4)/x^5
+--E 908
+
+--S 909 of 1125
+d0:=D(m0,x)
+--E 909
+
+)clear all
+
+--S 910 of 1125
+t0:=x^3/sqrt(a*x^2+b*x^3+c*x^4)
+--E 910
+
+--S 911 of 1125
+r0:=1/8*(3*b^2-4*a*c)*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(c^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))+1/2*sqrt(a*x^2+_
+   b*x^3+c*x^4)/c-3/4*b*sqrt(a*x^2+b*x^3+c*x^4)/(c^2*x)
+--E 911
+
+--S 912 of 1125
+d0:=D(m0a,x)
+--E 912
+
+)clear all
+
+--S 913 of 1125
+t0:=x^2/sqrt(a*x^2+b*x^3+c*x^4)
+--E 913
+
+--S 914 of 1125
+r0:=-1/2*b*x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(c^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   sqrt(a*x^2+b*x^3+c*x^4)/(c*x)
+--E 914
+
+--S 915 of 1125
+d0:=D(m0a,x)
+--E 915
+
+)clear all
+
+--S 916 of 1125
+t0:=x/sqrt(a*x^2+b*x^3+c*x^4)
+--E 916
+
+--S 917 of 1125
+r0:=x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (sqrt(c)*sqrt(a*x^2+b*x^3+c*x^4))
+--E 917
+
+--S 918 of 1125
+d0:=D(m0a,x)
+--E 918
+
+)clear all
+
+--S 919 of 1125
+t0:=1/sqrt(a*x^2+b*x^3+c*x^4)
+--E 919
+
+--S 920 of 1125
+r0:=-x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (sqrt(a)*sqrt(a*x^2+b*x^3+c*x^4))
+--E 920
+
+--S 921 of 1125
+d0:=D(m0,x)
+--E 921
+
+)clear all
+
+--S 922 of 1125
+t0:=1/(x*sqrt(a*x^2+b*x^3+c*x^4))
+--E 922
+
+--S 923 of 1125
+r0:=1/2*b*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))-_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a*x^2)
+--E 923
+
+--S 924 of 1125
+d0:=D(m0,x)
+--E 924
+
+)clear all
+
+--S 925 of 1125
+t0:=1/(x^2*sqrt(a*x^2+b*x^3+c*x^4))
+--E 925
+
+--S 926 of 1125
+r0:=-1/8*(3*b^2-4*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))-_
+   1/2*sqrt(a*x^2+b*x^3+c*x^4)/(a*x^3)+3/4*b*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*x^2)
+--E 926
+
+--S 927 of 1125
+d0:=D(m0,x)
+--E 927
+
+)clear all
+
+--S 928 of 1125
+t0:=x^7/(a*x^2+b*x^3+c*x^4)^(3/2)
+--E 928
+
+--S 929 of 1125
+r0:=2*x^4*(2*a+b*x)/((b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))+3/8*(5*b^2-4*a*c)*_
+   x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (c^(7/2)*sqrt(a*x^2+b*x^3+c*x^4))+1/2*(5*b^2-12*a*c)*sqrt(a*x^2+_
+   b*x^3+c*x^4)/(c^2*(b^2-4*a*c))-1/4*b*(15*b^2-52*a*c)*sqrt(a*x^2+_
+   b*x^3+c*x^4)/(c^3*(b^2-4*a*c)*x)-2*b*x*sqrt(a*x^2+b*x^3+c*x^4)/_
+   (c*(b^2-4*a*c))
+--E 929
+
+--S 930 of 1125
+d0:=D(m0a,x)
+--E 930
+
+)clear all
+
+--S 931 of 1125
+t0:=x^6/(a*x^2+b*x^3+c*x^4)^(3/2)
+--E 931
+
+--S 932 of 1125
+r0:=2*x^3*(2*a+b*x)/((b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))-3/2*b*x*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (c^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))-2*b*sqrt(a*x^2+b*x^3+c*x^4)/_
+   (c*(b^2-4*a*c))+(3*b^2-8*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(c^2*(b^2-4*a*c)*x)
+--E 932
+
+--S 933 of 1125
+d0:=D(m0a,x)
+--E 933
+
+)clear all
+
+--S 934 of 1125
+t0:=x^5/(a*x^2+b*x^3+c*x^4)^(3/2)
+--E 934
+
+--S 935 of 1125
+r0:=2*x^2*(2*a+b*x)/((b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   x*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (c^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))-2*b*sqrt(a*x^2+b*x^3+c*x^4)/_
+   (c*(b^2-4*a*c)*x)
+--E 935
+
+--S 936 of 1125
+d0:=D(m0a,x)
+--E 936
+
+)clear all
+
+--S 937 of 1125
+t0:=x^4/(a*x^2+b*x^3+c*x^4)^(3/2)
+--E 937
+
+--S 938 of 1125
+r0:=2*x*(2*a+b*x)/((b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))
+--E 938
+
+--S 939 of 1125
+d0:=D(m0,x)
+--E 939
+
+)clear all
+
+--S 940 of 1125
+t0:=x^3/(a*x^2+b*x^3+c*x^4)^(3/2)
+--E 940
+
+--S 941 of 1125
+r0:=-2*x*(b+2*c*x)/((b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))
+--E 941
+
+--S 942 of 1125
+d0:=D(m0,x)
+--E 942
+
+)clear all
+
+--S 943 of 1125
+t0:=x^2/(a*x^2+b*x^3+c*x^4)^(3/2)
+--E 943
+
+--S 944 of 1125
+r0:=2*x*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))-_
+   x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/_
+   (a^(3/2)*sqrt(a*x^2+b*x^3+c*x^4))
+--E 944
+
+--S 945 of 1125
+d0:=D(m0,x)
+--E 945
+
+)clear all
+
+--S 946 of 1125
+t0:=x/(a*x^2+b*x^3+c*x^4)^(3/2)
+--E 946
+
+--S 947 of 1125
+r0:=2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*sqrt(a*x^2+b*x^3+c*x^4))+_
+   3/2*b*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+_
+   c*x^2)/(a^(5/2)*sqrt(a*x^2+b*x^3+c*x^4))-(3*b^2-8*a*c)*sqrt(a*x^2+_
+   b*x^3+c*x^4)/(a^2*(b^2-4*a*c)*x^2)
+--E 947
+
+--S 948 of 1125
+d0:=D(m0,x)
+--E 948
+
+)clear all
+
+--S 949 of 1125
+t0:=1/(a*x^2+b*x^3+c*x^4)^(3/2)
+--E 949
+
+--S 950 of 1125
+r0:=2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x*sqrt(a*x^2+b*x^3+c*x^4))-_
+   3/8*(5*b^2-4*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(7/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/2*(5*b^2-12*a*c)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a^2*(b^2-4*a*c)*x^3)+1/4*b*(15*b^2-52*a*c)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a^3*(b^2-4*a*c)*x^2)
+--E 950
+
+--S 951 of 1125
+d0:=D(m0,x)
+--E 951
+
+)clear all
+
+--S 952 of 1125
+t0:=1/(x*(a*x^2+b*x^3+c*x^4)^(3/2))
+--E 952
+
+--S 953 of 1125
+r0:=2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^2*sqrt(a*x^2+b*x^3+c*x^4))+_
+   5/16*b*(7*b^2-12*a*c)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a+b*x+c*x^2)/(a^(9/2)*sqrt(a*x^2+b*x^3+c*x^4))-1/3*(7*b^2-16*a*c)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a^2*(b^2-4*a*c)*x^4)+1/12*b*(35*b^2-116*a*c)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a^3*(b^2-4*a*c)*x^3)-1/24*(105*b^4-_
+   460*a*b^2*c+256*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/(a^4*(b^2-4*a*c)*x^2)
+--E 953
+
+--S 954 of 1125
+d0:=D(m0,x)
+--E 954
+
+)clear all
+
+--S 955 of 1125
+t0:=1/(x^2*(a*x^2+b*x^3+c*x^4)^(3/2))
+--E 955
+
+--S 956 of 1125
+r0:=2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*x^3*sqrt(a*x^2+b*x^3+c*x^4))-_
+   15/128*(21*b^4-56*a*b^2*c+16*a^2*c^2)*x*atanh(1/2*(2*a+b*x)/(sqrt(a)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a+b*x+c*x^2)/(a^(11/2)*sqrt(a*x^2+b*x^3+c*x^4))-_
+   1/4*(9*b^2-20*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^2*(b^2-4*a*c)*x^5)+_
+   1/8*b*(21*b^2-68*a*c)*sqrt(a*x^2+b*x^3+c*x^4)/(a^3*(b^2-4*a*c)*x^4)-_
+   1/32*(105*b^4-448*a*b^2*c+240*a^2*c^2)*sqrt(a*x^2+b*x^3+c*x^4)/(a^4*_
+   (b^2-4*a*c)*x^3)+1/64*b*(315*b^4-1680*a*b^2*c+1808*a^2*c^2)*_
+   sqrt(a*x^2+b*x^3+c*x^4)/(a^5*(b^2-4*a*c)*x^2)
+--E 956
+
+--S 957 of 1125
+d0:=D(m0,x)
+--E 957
+
+)clear all
+
+--S 958 of 1125
+t0:=x^m*(a*x+b*x^3+c*x^5)
+--E 958
+
+--S 959 of 1125
+r0:=a*x^(2+m)/(2+m)+b*x^(4+m)/(4+m)+c*x^(6+m)/(6+m)
+--E 959
+
+--S 960 of 1125
+d0:=D(m0,x)
+--E 960
+
+)clear all
+
+--S 961 of 1125
+t0:=x^2*(a*x+b*x^3+c*x^5)
+--E 961
+
+--S 962 of 1125
+r0:=1/4*a*x^4+1/6*b*x^6+1/8*c*x^8
+--E 962
+
+--S 963 of 1125
+d0:=D(m0,x)
+--E 963
+
+)clear all
+
+--S 964 of 1125
+t0:=x*(a*x+b*x^3+c*x^5)
+--E 964
+
+--S 965 of 1125
+r0:=1/3*a*x^3+1/5*b*x^5+1/7*c*x^7
+--E 965
+
+--S 966 of 1125
+d0:=D(m0,x)
+--E 966
+
+)clear all
+
+--S 967 of 1125
+t0:=a*x+b*x^3+c*x^5
+--E 967
+
+--S 968 of 1125
+r0:=1/2*a*x^2+1/4*b*x^4+1/6*c*x^6
+--E 968
+
+--S 969 of 1125
+d0:=D(m0,x)
+--E 969
+
+)clear all
+
+--S 970 of 1125
+t0:=(a*x+b*x^3+c*x^5)/x
+--E 970
+
+--S 971 of 1125
+r0:=a*x+1/3*b*x^3+1/5*c*x^5
+--E 971
+
+--S 972 of 1125
+d0:=D(m0,x)
+--E 972
+
+)clear all
+
+--S 973 of 1125
+t0:=(a*x+b*x^3+c*x^5)/x^2
+--E 973
+
+--S 974 of 1125
+r0:=1/2*b*x^2+1/4*c*x^4+a*log(x)
+--E 974
+
+--S 975 of 1125
+d0:=D(m0,x)
+--E 975
+
+)clear all
+
+--S 976 of 1125
+t0:=(a*x+b*x^3+c*x^5)/x^3
+--E 976
+
+--S 977 of 1125
+r0:=-a/x+b*x+1/3*c*x^3
+--E 977
+
+--S 978 of 1125
+d0:=D(m0,x)
+--E 978
+
+)clear all
+
+--S 979 of 1125
+t0:=x^m*(a*x+b*x^3+c*x^5)^2
+--E 979
+
+--S 980 of 1125
+r0:=a^2*x^(3+m)/(3+m)+2*a*b*x^(5+m)/(5+m)+(b^2+2*a*c)*x^(7+m)/(7+m)+_
+   2*b*c*x^(9+m)/(9+m)+c^2*x^(11+m)/(11+m)
+--E 980
+
+--S 981 of 1125
+d0:=D(m0,x)
+--E 981
+
+)clear all
+
+--S 982 of 1125
+t0:=x^2*(a*x+b*x^3+c*x^5)^2
+--E 982
+
+--S 983 of 1125
+r0:=1/5*a^2*x^5+2/7*a*b*x^7+1/9*(b^2+2*a*c)*x^9+2/11*b*c*x^11+1/13*c^2*x^13
+--E 983
+
+--S 984 of 1125
+d0:=D(m0,x)
+--E 984
+
+)clear all
+
+--S 985 of 1125
+t0:=x*(a*x+b*x^3+c*x^5)^2
+--E 985
+
+--S 986 of 1125
+r0:=1/4*a^2*x^4+1/3*a*b*x^6+1/8*(b^2+2*a*c)*x^8+1/5*b*c*x^10+1/12*c^2*x^12
+--E 986
+
+--S 987 of 1125
+d0:=D(m0,x)
+--E 987
+
+)clear all
+
+--S 988 of 1125
+t0:=(a*x+b*x^3+c*x^5)^2
+--E 988
+
+--S 989 of 1125
+r0:=1/3*a^2*x^3+2/5*a*b*x^5+1/7*(b^2+2*a*c)*x^7+2/9*b*c*x^9+1/11*c^2*x^11
+--E 989
+
+--S 990 of 1125
+d0:=D(m0,x)
+--E 990
+
+)clear all
+
+--S 991 of 1125
+t0:=(a*x+b*x^3+c*x^5)^2/x
+--E 991
+
+--S 992 of 1125
+r0:=1/2*a^2*x^2+1/2*a*b*x^4+1/6*(b^2+2*a*c)*x^6+1/4*b*c*x^8+1/10*c^2*x^10
+--E 992
+
+--S 993 of 1125
+d0:=D(m0,x)
+--E 993
+
+)clear all
+
+--S 994 of 1125
+t0:=(a*x+b*x^3+c*x^5)^2/x^2
+--E 994
+
+--S 995 of 1125
+r0:=a^2*x+2/3*a*b*x^3+1/5*(b^2+2*a*c)*x^5+2/7*b*c*x^7+1/9*c^2*x^9
+--E 995
+
+--S 996 of 1125
+d0:=D(m0,x)
+--E 996
+
+)clear all
+
+--S 997 of 1125
+t0:=x^8/(a*x+b*x^3+c*x^5)
+--E 997
+
+--S 998 of 1125
+r0:=-1/2*b*x^2/c^2+1/4*x^4/c+1/4*(b^2-a*c)*log(a+b*x^2+c*x^4)/c^3+_
+   1/2*b*(b^2-3*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^3*sqrt(b^2-4*a*c))
+--E 998
+
+--S 999 of 1125
+d0:=D(m0a,x)
+--E 999
+
+)clear all
+
+--S 1000 of 1125
+t0:=x^7/(a*x+b*x^3+c*x^5)
+--E 1000
+
+--S 1001 of 1125
+r0:=-b*x/c^2+1/3*x^3/c+atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b^2-a*c-b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (b^2-a*c+b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--E 1001
+
+--S 1002 of 1125
+d0:=D(m0,x)
+--E 1002
+
+)clear all
+
+--S 1003 of 1125
+t0:=x^6/(a*x+b*x^3+c*x^5)
+--E 1003
+
+--S 1004 of 1125
+r0:=1/2*x^2/c-1/4*b*log(a+b*x^2+c*x^4)/c^2-1/2*(b^2-2*a*c)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-4*a*c))
+--E 1004
+
+--S 1005 of 1125
+d0:=D(m0a,x)
+--E 1005
+
+)clear all
+
+--S 1006 of 1125
+t0:=x^5/(a*x+b*x^3+c*x^5)
+--E 1006
+
+--S 1007 of 1125
+r0:=x/c-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+_
+   (-b^2+2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b+(b^2-2*a*c)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--E 1007
+
+--S 1008 of 1125
+d0:=D(m0,x)
+--E 1008
+
+)clear all
+
+--S 1009 of 1125
+t0:=x^4/(a*x+b*x^3+c*x^5)
+--E 1009
+
+--S 1010 of 1125
+r0:=1/4*log(a+b*x^2+c*x^4)/c+1/2*b*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c*sqrt(b^2-4*a*c))
+--E 1010
+
+--S 1011 of 1125
+d0:=D(m0a,x)
+--E 1011
+
+)clear all
+
+--S 1012 of 1125
+t0:=x^3/(a*x+b*x^3+c*x^5)
+--E 1012
+
+--S 1013 of 1125
+r0:=-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(b-_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))+atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))/(sqrt(2)*_
+   sqrt(c)*sqrt(b^2-4*a*c))
+--E 1013
+
+--S 1014 of 1125
+d0:=D(m0,x)
+--E 1014
+
+)clear all
+
+--S 1015 of 1125
+t0:=x^2/(a*x+b*x^3+c*x^5)
+--E 1015
+
+--S 1016 of 1125
+r0:=-atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)
+--E 1016
+
+--S 1017 of 1125
+d0:=D(m0a,x)
+--E 1017
+
+)clear all
+
+--S 1018 of 1125
+t0:=x/(a*x+b*x^3+c*x^5)
+--E 1018
+
+--S 1019 of 1125
+r0:=atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/_
+   (sqrt(b^2-4*a*c)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--E 1019
+
+--S 1020 of 1125
+d0:=D(m0,x)
+--E 1020
+
+)clear all
+
+--S 1021 of 1125
+t0:=1/(a*x+b*x^3+c*x^5)
+--E 1021
+
+--S 1022 of 1125
+r0:=log(x)/a-1/4*log(a+b*x^2+c*x^4)/a+1/2*b*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))
+--E 1022
+
+--S 1023 of 1125
+d0:=D(m0a,x)
+--E 1023
+
+)clear all
+
+--S 1024 of 1125
+t0:=1/(x*(a*x+b*x^3+c*x^5))
+--E 1024
+
+--S 1025 of 1125
+r0:=(-1)/(a*x)-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*_
+   (1+b/sqrt(b^2-4*a*c))/(a*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(1-b/sqrt(b^2-4*a*c))/_
+   (a*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--E 1025
+
+--S 1026 of 1125
+d0:=D(m0,x)
+--E 1026
+
+)clear all
+
+--S 1027 of 1125
+t0:=1/(x^2*(a*x+b*x^3+c*x^5))
+--E 1027
+
+--S 1028 of 1125
+r0:=(-1/2)/(a*x^2)-b*log(x)/a^2+1/4*b*log(a+b*x^2+c*x^4)/a^2-_
+   1/2*(b^2-2*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))
+--E 1028
+
+--S 1029 of 1125
+d0:=D(m0a,x)
+--E 1029
+
+)clear all
+
+--S 1030 of 1125
+t0:=x^11/(a*x+b*x^3+c*x^5)^2
+--E 1030
+
+--S 1031 of 1125
+r0:=(b^2-3*a*c)*x^2/(c^2*(b^2-4*a*c))-1/2*b*x^4/(c*(b^2-4*a*c))+_
+   1/2*x^6*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-(b^4-6*a*b^2*c+_
+   6*a^2*c^2)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^3*(b^2-4*a*c)^(3/2))-_
+   1/2*b*log(a+b*x^2+c*x^4)/c^3
+--E 1031
+
+--S 1032 of 1125
+d0:=D(m0a,x)
+--E 1032
+
+)clear all
+
+--S 1033 of 1125
+t0:=x^10/(a*x+b*x^3+c*x^5)^2
+--E 1033
+
+--S 1034 of 1125
+r0:=1/2*(3*b^2-10*a*c)*x/(c^2*(b^2-4*a*c))-1/2*b*x^3/(c*(b^2-4*a*c))+_
+   1/2*x^5*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(3*b^3-13*a*b*c+(-3*b^4+19*a*b^2*c-_
+   20*a^2*c^2)/sqrt(b^2-4*a*c))/(c^(5/2)*(b^2-4*a*c)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (3*b^3-13*a*b*c+(3*b^4-19*a*b^2*c+20*a^2*c^2)/sqrt(b^2-4*a*c))/_
+   (c^(5/2)*(b^2-4*a*c)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--E 1034
+
+--S 1035 of 1125
+d0:=D(m0,x)
+--E 1035
+
+)clear all
+
+--S 1036 of 1125
+t0:=x^9/(a*x+b*x^3+c*x^5)^2
+--E 1036
+
+--S 1037 of 1125
+r0:=-1/2*b*x^2/(c*(b^2-4*a*c))+1/2*x^4*(2*a+b*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/2*b*(b^2-6*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/_
+   (c^2*(b^2-4*a*c)^(3/2))+1/4*log(a+b*x^2+c*x^4)/c^2
+--E 1037
+
+--S 1038 of 1125
+d0:=D(m0a,x)
+--E 1038
+
+)clear all
+
+--S 1039 of 1125
+t0:=x^8/(a*x+b*x^3+c*x^5)^2
+--E 1039
+
+--S 1040 of 1125
+r0:=-1/2*b*x/(c*(b^2-4*a*c))+1/2*x^3*(2*a+b*x^2)/((b^2-4*a*c)*_
+   (a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   (b^2-6*a*c-b*(b^2-8*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-_
+   4*a*c)))*(b^2-6*a*c+b*(b^2-8*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*(b^2-4*a*c)*_
+   sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--E 1040
+
+--S 1041 of 1125
+d0:=D(m0,x)
+--E 1041
+
+)clear all
+
+--S 1042 of 1125
+t0:=x^7/(a*x+b*x^3+c*x^5)^2
+--E 1042
+
+--S 1043 of 1125
+r0:=1/2*x^2*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   2*a*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--E 1043
+
+--S 1044 of 1125
+d0:=D(m0a,x)
+--E 1044
+
+)clear all
+
+--S 1045 of 1125
+t0:=x^6/(a*x+b*x^3+c*x^5)^2
+--E 1045
+
+--S 1046 of 1125
+r0:=1/2*x*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+(-b^2-4*a*c)/sqrt(b^2-4*a*c))/_
+   ((b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*_
+   sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(b^2+4*a*c+b*_
+   sqrt(b^2-4*a*c))/((b^2-4*a*c)^(3/2)*sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--E 1046
+
+--S 1047 of 1125
+d0:=D(m0,x)
+--E 1047
+
+)clear all
+
+--S 1048 of 1125
+t0:=x^5/(a*x+b*x^3+c*x^5)^2
+--E 1048
+
+--S 1049 of 1125
+r0:=1/2*(2*a+b*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))-b*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--E 1049
+
+--S 1050 of 1125
+d0:=D(m0a,x)
+--E 1050
+
+)clear all
+
+--S 1051 of 1125
+t0:=x^4/(a*x+b*x^3+c*x^5)^2
+--E 1051
+
+--S 1052 of 1125
+r0:=-1/2*x*(b+2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(2*b-sqrt(b^2-4*a*c))/((b^2-_
+   4*a*c)^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(2*b+sqrt(b^2-4*a*c))/((b^2-_
+   4*a*c)^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--E 1052
+
+--S 1053 of 1125
+d0:=D(m0,x)
+--E 1053
+
+)clear all
+
+--S 1054 of 1125
+t0:=x^3/(a*x+b*x^3+c*x^5)^2
+--E 1054
+
+--S 1055 of 1125
+r0:=1/2*(-b-2*c*x^2)/((b^2-4*a*c)*(a+b*x^2+c*x^4))+2*c*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(b^2-4*a*c)^(3/2)
+--E 1055
+
+--S 1056 of 1125
+d0:=D(m0a,x)
+--E 1056
+
+)clear all
+
+--S 1057 of 1125
+t0:=x^2/(a*x+b*x^3+c*x^5)^2
+--E 1057
+
+--S 1058 of 1125
+r0:=1/2*x*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(b+(b^2-_
+   12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(b+_
+   (-b^2+12*a*c)/sqrt(b^2-4*a*c))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(b+_
+   sqrt(b^2-4*a*c)))
+--E 1058
+
+--S 1059 of 1125
+d0:=D(m0,x)
+--E 1059
+
+)clear all
+
+--S 1060 of 1125
+t0:=x/(a*x+b*x^3+c*x^5)^2
+--E 1060
+
+--S 1061 of 1125
+r0:=1/2*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*(a+b*x^2+c*x^4))+_
+   1/2*b*(b^2-6*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^2*_
+   (b^2-4*a*c)^(3/2))+log(x)/a^2-1/4*log(a+b*x^2+c*x^4)/a^2
+--E 1061
+
+--S 1062 of 1125
+d0:=D(m0a,x)
+--E 1062
+
+)clear all
+
+--S 1063 of 1125
+t0:=1/(a*x+b*x^3+c*x^5)^2
+--E 1063
+
+--S 1064 of 1125
+r0:=1/2*(-3*b^2+10*a*c)/(a^2*(b^2-4*a*c)*x)+1/2*(b^2-2*a*c+b*c*x^2)/_
+   (a*(b^2-4*a*c)*x*(a+b*x^2+c*x^4))-1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2-10*a*c+b*(3*b^2-16*a*c)/sqrt(b^2-_
+   4*a*c))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-_
+   1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(3*b^2-_
+   10*a*c+(-3*b^3+16*a*b*c)/sqrt(b^2-4*a*c))/(a^2*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--E 1064
+
+--S 1065 of 1125
+d0:=D(m0,x)
+--E 1065
+
+)clear all
+
+--S 1066 of 1125
+t0:=1/(x*(a*x+b*x^3+c*x^5)^2)
+--E 1066
+
+--S 1067 of 1125
+r0:=(-b^2+3*a*c)/(a^2*(b^2-4*a*c)*x^2)+1/2*(b^2-2*a*c+b*c*x^2)/(a*_
+   (b^2-4*a*c)*x^2*(a+b*x^2+c*x^4))-(b^4-6*a*b^2*c+6*a^2*c^2)*_
+   atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)^(3/2))-_
+   2*b*log(x)/a^3+1/2*b*log(a+b*x^2+c*x^4)/a^3
+--E 1067
+
+--S 1068 of 1125
+d0:=D(m0a,x)
+--E 1068
+
+)clear all
+
+--S 1069 of 1125
+t0:=1/(x^2*(a*x+b*x^3+c*x^5)^2)
+--E 1069
+
+--S 1070 of 1125
+r0:=1/6*(-5*b^2+14*a*c)/(a^2*(b^2-4*a*c)*x^3)+1/2*b*(5*b^2-19*a*c)/_
+   (a^3*(b^2-4*a*c)*x)+1/2*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^3*_
+   (a+b*x^2+c*x^4))+1/2*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*_
+   sqrt(c)*(5*b^3-19*a*b*c+(5*b^4-29*a*b^2*c+28*a^2*c^2)/sqrt(b^2-4*a*c))/_
+   (a^3*(b^2-4*a*c)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+1/2*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(5*b^3-19*a*b*c+(-5*b^4+_
+   29*a*b^2*c-28*a^2*c^2)/sqrt(b^2-4*a*c))/(a^3*(b^2-4*a*c)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--E 1070
+
+--S 1071 of 1125
+d0:=D(m0,x)
+--E 1071
+
+)clear all
+
+--S 1072 of 1125
+t0:=1/(x^3*(a*x+b*x^3+c*x^5)^2)
+--E 1072
+
+--S 1073 of 1125
+r0:=1/4*(-3*b^2+8*a*c)/(a^2*(b^2-4*a*c)*x^4)+1/2*b*(3*b^2-11*a*c)/_
+   (a^3*(b^2-4*a*c)*x^2)+1/2*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^4*_
+   (a+b*x^2+c*x^4))+1/2*b*(3*b^4-20*a*b^2*c+30*a^2*c^2)*atanh((b+_
+   2*c*x^2)/sqrt(b^2-4*a*c))/(a^4*(b^2-4*a*c)^(3/2))+(3*b^2-2*a*c)*_
+   log(x)/a^4-1/4*(3*b^2-2*a*c)*log(a+b*x^2+c*x^4)/a^4
+--E 1073
+
+--S 1074 of 1125
+d0:=D(m0a,x)
+--E 1074
+
+)clear all
+
+--S 1075 of 1125
+t0:=x^(3/2)*sqrt(a*x+b*x^3+c*x^5)
+--E 1075
+
+--S 1076 of 1125
+--r0:=1/15*(b+3*c*x^2)*sqrt(x)*sqrt(a*x+b*x^3+c*x^5)/c-1/15*(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))+1/15*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))
+--E 1076
+
+--S 1077 of 1125
+d0:=D(m0,x)
+--E 1077
+
+)clear all
+
+--S 1078 of 1125
+t0:=sqrt(x)*sqrt(a*x+b*x^3+c*x^5)
+--E 1078
+
+--S 1079 of 1125
+r0:=-1/16*(b^2-4*a*c)*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))*_
+   sqrt(x)*sqrt(a+b*x^2+c*x^4)/(c^(3/2)*sqrt(a*x+b*x^3+c*x^5))+_
+   1/8*(b+2*c*x^2)*sqrt(a*x+b*x^3+c*x^5)/(c*sqrt(x))
+--E 1079
+
+--S 1080 of 1125
+d0:=D(m0,x)
+--E 1080
+
+)clear all
+
+--S 1081 of 1125
+t0:=sqrt(a*x+b*x^3+c*x^5)/sqrt(x)
+--E 1081
+
+--S 1082 of 1125
+--r0:=1/3*sqrt(x)*sqrt(a*x+b*x^3+c*x^5)+1/6*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))-1/6*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(3/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))
+--E 1082
+
+--S 1083 of 1125
+d0:=D(m0,x)
+--E 1083
+
+)clear all
+
+--S 1084 of 1125
+t0:=sqrt(a*x+b*x^3+c*x^5)/x^(3/2)
+--E 1084
+
+--S 1085 of 1125
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))*sqrt(a)*_
+   sqrt(x)*sqrt(a+b*x^2+c*x^4)/sqrt(a*x+b*x^3+c*x^5)+1/4*b*atanh(1/2*(b+_
+   2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*sqrt(a+b*x^2+c*x^4)/_
+   (sqrt(c)*sqrt(a*x+b*x^3+c*x^5))+1/2*sqrt(a*x+b*x^3+c*x^5)/sqrt(x)
+--E 1085
+
+-- integrate: implementation incomplete (non-algebraic residues)
+--S 1086 of 1125
+d0:=D(m0,x)
+--E 1086
+
+)clear all
+
+--S 1087 of 1125
+t0:=x^(3/2)*(a*x+b*x^3+c*x^5)^(3/2)
+--E 1087
+
+--S 1088 of 1125
+r0:=1/80*(3*b+8*c*x^2)*(a*x+b*x^3+c*x^5)^(3/2)*sqrt(x)/c-_
+   3/512*b*(b^2-4*a*c)^2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+_
+   b*x^2+c*x^4)))*sqrt(x)*sqrt(a+b*x^2+c*x^4)/(c^(7/2)*sqrt(a*x+b*x^3+_
+   c*x^5))-1/640*x^(3/2)*(b*(5*b^2-4*a*c)+4*c*(5*b^2-16*a*c)*x^2)*_
+   sqrt(a*x+b*x^3+c*x^5)/c^2+1/1280*(15*b^4-100*a*b^2*c+128*a^2*c^2)*_
+   sqrt(a*x+b*x^3+c*x^5)/(c^3*sqrt(x))
+--E 1088
+
+--S 1089 of 1125
+d0:=D(m0,x)
+--E 1089
+
+)clear all
+
+--S 1090 of 1125
+t0:=(a*x+b*x^3+c*x^5)^(3/2)*sqrt(x)
+--E 1090
+
+--S 1091 of 1125
+--r0:=1/63*(3*b+7*c*x^2)*(a*x+b*x^3+c*x^5)^(3/2)/(c*sqrt(x))-1/315*(b*(4*b^2-9*a*c)+6*c*(2*b^2-7*a*c)*x^2)*sqrt(x)*sqrt(a*x+b*x^3+c*x^5)/c^2+1/630*(8*b^4-57*a*b^2*c+84*a^2*c^2)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))-1/630*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*(8*b^4-57*a*b^2*c+84*a^2*c^2-8*a*b*c*(b^2-6*a*c)/(b+sqrt(b^2-4*a*c)))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(7/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))
+--E 1091
+
+--S 1092 of 1125
+d0:=D(m0,x)
+--E 1092
+
+)clear all
+
+--S 1093 of 1125
+t0:=(a*x+b*x^3+c*x^5)^(3/2)/sqrt(x)
+--E 1093
+
+--S 1094 of 1125
+r0:=1/16*(b+2*c*x^2)*(a*x+b*x^3+c*x^5)^(3/2)/(c*x^(3/2))+3/256*(b^2-_
+   4*a*c)^2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*_
+   sqrt(a+b*x^2+c*x^4)/(c^(5/2)*sqrt(a*x+b*x^3+c*x^5))-3/128*(b^2-4*a*c)*_
+   (b+2*c*x^2)*sqrt(a*x+b*x^3+c*x^5)/(c^2*sqrt(x))
+--E 1094
+
+--S 1095 of 1125
+d0:=D(m0,x)
+--E 1095
+
+)clear all
+
+--S 1096 of 1125
+t0:=(a*x+b*x^3+c*x^5)^(3/2)/x^(3/2)
+--E 1096
+
+--S 1097 of 1125
+--r0:=1/7*(a*x+b*x^3+c*x^5)^(3/2)/sqrt(x)+1/35*(b^2+10*a*c+3*b*c*x^2)*sqrt(x)*sqrt(a*x+b*x^3+c*x^5)/c-1/35*b*(b^2-8*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))+1/35*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^4-9*a*b^2*c+20*a^2*c^2+b*(b^2-8*a*c)*sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(c^(5/2)*sqrt(2)*sqrt(a*x+b*x^3+c*x^5))
+--E 1097
+
+--S 1098 of 1125
+d0:=D(m0,x)
+--E 1098
+
+)clear all
+
+--S 1099 of 1125
+t0:=x^(3/2)/sqrt(a*x+b*x^3+c*x^5)
+--E 1099
+
+--S 1100 of 1125
+r0:=1/2*atanh(1/2*(b+2*c*x^2)/(sqrt(c)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*_
+   sqrt(a+b*x^2+c*x^4)/(sqrt(c)*sqrt(a*x+b*x^3+c*x^5))
+--E 1100
+
+--S 1101 of 1125
+d0:=D(m0,x)
+--E 1101
+
+)clear all
+
+--S 1102 of 1125
+t0:=sqrt(x)/sqrt(a*x+b*x^3+c*x^5)
+--E 1102
+
+--S 1103 of 1125
+--r0:=elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))
+--E 1103
+
+--S 1104 of 1125
+d0:=D(m0,x)
+--E 1104
+
+)clear all
+
+--S 1105 of 1125
+t0:=1/(sqrt(x)*sqrt(a*x+b*x^3+c*x^5))
+--E 1105
+
+--S 1106 of 1125
+r0:=-1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*_
+   sqrt(a+b*x^2+c*x^4)/(sqrt(a)*sqrt(a*x+b*x^3+c*x^5))
+--E 1106
+
+--S 1107 of 1125
+d0:=D(m0,x)
+--E 1107
+
+)clear all
+
+--S 1108 of 1125
+t0:=1/(x^(3/2)*sqrt(a*x+b*x^3+c*x^5))
+--E 1108
+
+--S 1109 of 1125
+--r0:=-sqrt(a*x+b*x^3+c*x^5)/(a*x^(3/2))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(-b+sqrt(b^2-4*a*c))^(3/2)*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))+1/2*elliptic_e(asin(x*sqrt(2)*sqrt(-c)/sqrt(b+sqrt(b^2-4*a*c))),(b+sqrt(b^2-4*a*c))/(b-sqrt(b^2-4*a*c)))*(b-sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*sqrt(2)*sqrt(-c)*sqrt(a*x+b*x^3+c*x^5))
+--E 1109
+
+--S 1110 of 1125
+d0:=D(m0,x)
+--E 1110
+
+)clear all
+
+--S 1111 of 1125
+t0:=x^(3/2)/(a*x+b*x^3+c*x^5)^(3/2)
+--E 1111
+
+--S 1112 of 1125
+--r0:=x^(3/2)*(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*sqrt(a*x+b*x^3+c*x^5))-1/2*b*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))+1/2*elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^2-4*a*c+b*sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))
+--E 1112
+
+--S 1113 of 1125
+d0:=D(m0,x)
+--E 1113
+
+)clear all
+
+--S 1114 of 1125
+t0:=sqrt(x)/(a*x+b*x^3+c*x^5)^(3/2)
+--E 1114
+
+--S 1115 of 1125
+r0:=(b^2-2*a*c+b*c*x^2)*sqrt(x)/(a*(b^2-4*a*c)*sqrt(a*x+b*x^3+c*x^5))-_
+   1/2*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*_
+   sqrt(a+b*x^2+c*x^4)/(a^(3/2)*sqrt(a*x+b*x^3+c*x^5))
+--E 1115
+
+--S 1116 of 1125
+d0:=D(m0,x)
+--E 1116
+
+)clear all
+
+--S 1117 of 1125
+t0:=1/((a*x+b*x^3+c*x^5)^(3/2)*sqrt(x))
+--E 1117
+
+--S 1118 of 1125
+--r0:=(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*sqrt(x)*sqrt(a*x+b*x^3+c*x^5))-2*(b^2-3*a*c)*sqrt(a*x+b*x^3+c*x^5)/(a^2*(b^2-4*a*c)*x^(3/2))+(b^2-3*a*c)*elliptic_e(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b+sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))-elliptic_f(asin(x*sqrt(2)*sqrt(c)/sqrt(-b+sqrt(b^2-4*a*c))),(b-sqrt(b^2-4*a*c))/(b+sqrt(b^2-4*a*c)))*(b^3-4*a*b*c+(b^2-3*a*c)*sqrt(b^2-4*a*c))*sqrt(x)*sqrt(1+2*c*x^2/(b-sqrt(b^2-4*a*c)))*sqrt(-b+sqrt(b^2-4*a*c))*sqrt(1+2*c*x^2/(b+sqrt(b^2-4*a*c)))/(a^2*(b^2-4*a*c)*sqrt(2)*sqrt(c)*sqrt(a*x+b*x^3+c*x^5))
+--E 1118
+
+--S 1119 of 1125
+d0:=D(m0,x)
+--E 1119
+
+)clear all
+
+--S 1120 of 1125
+t0:=1/(x^(3/2)*(a*x+b*x^3+c*x^5)^(3/2))
+--E 1120
+
+--S 1121 of 1125
+r0:=(b^2-2*a*c+b*c*x^2)/(a*(b^2-4*a*c)*x^(3/2)*sqrt(a*x+b*x^3+c*x^5))+_
+   3/4*b*atanh(1/2*(2*a+b*x^2)/(sqrt(a)*sqrt(a+b*x^2+c*x^4)))*sqrt(x)*_
+   sqrt(a+b*x^2+c*x^4)/(a^(5/2)*sqrt(a*x+b*x^3+c*x^5))-1/2*(3*b^2-8*a*c)*_
+   sqrt(a*x+b*x^3+c*x^5)/(a^2*(b^2-4*a*c)*x^(5/2))
+--E 1121
+
+--S 1122 of 1125
+d0:=D(m0,x)
+--E 1122
+
+)clear all
+
+--S 1123 of 1125
+t0:=x^(3/2*(-1+n))/(a*x^(-1+n)+b*x^n+c*x^(1+n))^(3/2)
+--E 1123
+
+--S 1124 of 1125
+r0:=-2*x^(1/2*(-1+n))*(b+2*c*x)/((b^2-4*a*c)*sqrt(a*x^(-1+n)+b*x^n+c*x^(1+n)))
+--E 1124
+
+-- integrate: implementation incomplete (constant residues)
+--S 1125 of 1125
+d0:=D(m0,x)
+--E 1125
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder19.input.pamphlet b/src/input/richder19.input.pamphlet
new file mode 100644
index 0000000..6f2c3cc
--- /dev/null
+++ b/src/input/richder19.input.pamphlet
@@ -0,0 +1,16291 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder19.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a+b x+c x^2)^p (d+e x+f x^2)^q|
+
+\verb|x^m (a+b x+c x^2)^(p/2) (d+e x+f x^2) when b=0|
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder19.output
+)spool richder19.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 940
+t0:=x^2*sqrt(a+c*x^2)/(d+e*x+f*x^2)
+--R 
+--R
+--R            +--------+
+--R          2 |   2
+--R         x \|c x  + a
+--R   (1)  --------------
+--R           2
+--R        f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 940
+r0:=1/2*a*atanh(x*sqrt(c)/sqrt(a+c*x^2))/(f*sqrt(c))+(e^2-d*f)*_
+   atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f^3-e*sqrt(a+c*x^2)/f^2+1/2*x*_
+   sqrt(a+c*x^2)/f-atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (-2*d*f*(a*f^2+c*(e^2-d*f))+e*(a*f^2+c*(e^2-2*d*f))*(e-sqrt(e^2-4*d*f)))/_
+   (f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*_
+   sqrt(e^2-4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (-2*d*f*(a*f^2+c*(e^2-d*f))+e*(a*f^2+c*(e^2-2*d*f))*(e+sqrt(e^2-4*d*f)))/_
+   (f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                        +-----------+
+--R                  2                  3  |          2          3
+--R           (2a e f  - 4c d e f + 2c e )\|- 4d f + e   + 4a d f
+--R         + 
+--R                  2       2  2         2        4
+--R           (- 2a e  - 4c d )f  + 8c d e f - 2c e
+--R      *
+--R              +-----------------------------------------+
+--R              |    +-----------+
+--R          +-+ |    |          2        2               2
+--R         \|c \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                          +-----------+
+--R                    2                  3  |          2          3
+--R           (- 2a e f  + 4c d e f - 2c e )\|- 4d f + e   + 4a d f
+--R         + 
+--R                  2       2  2         2        4
+--R           (- 2a e  - 4c d )f  + 8c d e f - 2c e
+--R      *
+--R              +-------------------------------------------+
+--R              |      +-----------+
+--R          +-+ |      |          2        2               2
+--R         \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                       +-----------+           +-+
+--R               2                2  +-+ |          2          x\|c
+--R           (a f  - 2c d f + 2c e )\|2 \|- 4d f + e  atanh(-----------)
+--R                                                           +--------+
+--R                                                           |   2
+--R                                                          \|c x  + a
+--R         + 
+--R                            +-----------+     +--------+
+--R             2          +-+ |          2  +-+ |   2
+--R           (f x - 2e f)\|2 \|- 4d f + e  \|c \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                 +-------------------------------------------+
+--R               +-----------+     |      +-----------+
+--R         3 +-+ |          2  +-+ |      |          2        2               2
+--R       2f \|2 \|- 4d f + e  \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 940
+t0:=x*sqrt(a+c*x^2)/(d+e*x+f*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R         x\|c x  + a
+--R   (1)  --------------
+--R           2
+--R        f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 940
+r0:=-e*atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f^2+sqrt(a+c*x^2)/f-_
+   atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*c*d*e*f-(a*f^2+_
+   c*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+atanh((2*a*f-_
+   c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))))*(2*c*d*e*f-(a*f^2+c*(e^2-d*f))*(e+_
+   sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                  +-----------+
+--R                2              2  |          2         2                 3
+--R         ((- a f  + c d f - c e )\|- 4d f + e   + a e f  - 3c d e f + c e )
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                +-----------+
+--R              2              2  |          2         2                 3
+--R         ((a f  - c d f + c e )\|- 4d f + e   + a e f  - 3c d e f + c e )
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                   +-----------+               +-+
+--R               +-+ |          2  +-+         x\|c
+--R           - e\|2 \|- 4d f + e  \|c atanh(-----------)
+--R                                           +--------+
+--R                                           |   2
+--R                                          \|c x  + a
+--R         + 
+--R                 +-----------+ +--------+
+--R             +-+ |          2  |   2
+--R           f\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                            +-------------------------------------------+
+--R              +-----------+ |      +-----------+
+--R        2 +-+ |          2  |      |          2        2               2
+--R       f \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 940
+t0:=sqrt(a+c*x^2)/(d+e*x+f*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R          \|c x  + a
+--R   (1)  --------------
+--R           2
+--R        f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 940
+r0:=atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f-atanh((2*a*f-c*x*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f)))))*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))/(f*sqrt(2)*_
+   sqrt(e^2-4*d*f))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))/(f*sqrt(2)*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +-------------------------------------------+
+--R             |      +-----------+
+--R             |      |          2        2               2
+--R            \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R                                   +-----------+
+--R                                   |          2
+--R                               c x\|- 4d f + e   - c e x + 2a f
+--R          atanh(-------------------------------------------------------------)
+--R                                +-------------------------------------------+
+--R                     +--------+ |      +-----------+
+--R                 +-+ |   2      |      |          2        2               2
+--R                \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R       -
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R                                    +-----------+
+--R                                    |          2
+--R                                c x\|- 4d f + e   + c e x - 2a f
+--R            atanh(-----------------------------------------------------------)
+--R                                  +-----------------------------------------+
+--R                       +--------+ |    +-----------+
+--R                   +-+ |   2      |    |          2        2               2
+--R                  \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R            +-----------+               +-+
+--R        +-+ |          2  +-+         x\|c
+--R       \|2 \|- 4d f + e  \|c atanh(-----------)
+--R                                    +--------+
+--R                                    |   2
+--R                                   \|c x  + a
+--R  /
+--R           +-----------+
+--R       +-+ |          2
+--R     f\|2 \|- 4d f + e
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 940
+t0:=sqrt(a+c*x^2)/(x*(d+e*x+f*x^2))
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R           \|c x  + a
+--R   (1)  -----------------
+--R           3      2
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 940
+r0:=-atanh(sqrt(a+c*x^2)/sqrt(a))*sqrt(a)/d+atanh((2*a*f-c*x*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f)))))*(2*a*e*f+(c*d-a*f)*(e-sqrt(e^2-4*d*f)))/(d*sqrt(2)*sqrt(e^2-_
+   4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-atanh((2*a*f-_
+   c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))))*(2*a*e*f+(c*d-a*f)*(e+sqrt(e^2-4*d*f)))/_
+   (d*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                      +-----------+
+--R                      |          2
+--R         ((a f - c d)\|- 4d f + e   + a e f + c d e)
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                        +-----------+
+--R                        |          2
+--R         ((- a f + c d)\|- 4d f + e   + a e f + c d e)
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R       -
+--R                                         +--------+
+--R                 +-----------+           |   2
+--R             +-+ |          2  +-+      \|c x  + a
+--R            \|2 \|- 4d f + e  \|a atanh(-----------)
+--R                                             +-+
+--R                                            \|a
+--R         *
+--R             +-------------------------------------------+
+--R             |      +-----------+
+--R             |      |          2        2               2
+--R            \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                           +-------------------------------------------+
+--R             +-----------+ |      +-----------+
+--R         +-+ |          2  |      |          2        2               2
+--R       d\|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 940
+t0:=sqrt(a+c*x^2)/(x^2*(d+e*x+f*x^2))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|c x  + a
+--R   (1)  ------------------
+--R           4      3      2
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 940
+r0:=e*atanh(sqrt(a+c*x^2)/sqrt(a))*sqrt(a)/d^2-sqrt(a+c*x^2)/(d*x)-_
+   f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*c*d^2+a*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))/(d^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+f*atanh((2*a*f-c*x*(e+sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-_
+   4*d*f)))))*(2*c*d^2+a*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))/(d^2*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                    +-----------+
+--R                    |          2           2         2       2
+--R         (- a e f x\|- 4d f + e   + (2a d f  + (- a e  - 2c d )f)x)
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                  +-----------+
+--R                  |          2           2         2       2
+--R         (a e f x\|- 4d f + e   + (2a d f  + (- a e  - 2c d )f)x)
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                           +--------+
+--R                   +-----------+           |   2
+--R               +-+ |          2  +-+      \|c x  + a
+--R           e x\|2 \|- 4d f + e  \|a atanh(-----------)
+--R                                               +-+
+--R                                              \|a
+--R         + 
+--R                   +-----------+ +--------+
+--R               +-+ |          2  |   2
+--R           - d\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                             +-------------------------------------------+
+--R               +-----------+ |      +-----------+
+--R        2  +-+ |          2  |      |          2        2               2
+--R       d x\|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 940
+t0:=sqrt(a+c*x^2)/(x^3*(d+e*x+f*x^2))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R            \|c x  + a
+--R   (1)  ------------------
+--R           5      4      3
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 940
+r0:=-1/2*c*atanh(sqrt(a+c*x^2)/sqrt(a))/(d*sqrt(a))-(e^2-d*f)*_
+   atanh(sqrt(a+c*x^2)/sqrt(a))*sqrt(a)/d^3-1/2*sqrt(a+c*x^2)/(d*x^2)+_
+   e*sqrt(a+c*x^2)/(d^2*x)+f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (2*e*(c*d^2+a*(e^2-2*d*f))-(c*d^2+a*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/_
+   (d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f))))-f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+_
+   c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*e*(c*d^2+_
+   a*(e^2-2*d*f))-(c*d^2+a*(e^2-d*f))*(e+sqrt(e^2-4*d*f)))/(d^3*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                            +-----------+
+--R                    2        2       2    2 |          2
+--R           (- 2a d f  + (2a e  + 2c d )f)x \|- 4d f + e
+--R         + 
+--R                      2        3       2     2
+--R           (- 6a d e f  + (2a e  + 2c d e)f)x
+--R      *
+--R              +-----------------------------------------+
+--R              |    +-----------+
+--R          +-+ |    |          2        2               2
+--R         \|a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                            +-----------+
+--R                  2          2       2    2 |          2
+--R           (2a d f  + (- 2a e  - 2c d )f)x \|- 4d f + e
+--R         + 
+--R                      2        3       2     2
+--R           (- 6a d e f  + (2a e  + 2c d e)f)x
+--R      *
+--R              +-------------------------------------------+
+--R              |      +-----------+
+--R          +-+ |      |          2        2               2
+--R         \|a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                             +--------+
+--R                                         +-----------+       |   2
+--R                         2      2  2 +-+ |          2       \|c x  + a
+--R           (2a d f - 2a e  - c d )x \|2 \|- 4d f + e  atanh(-----------)
+--R                                                                 +-+
+--R                                                                \|a
+--R         + 
+--R                             +-----------+     +--------+
+--R                      2  +-+ |          2  +-+ |   2
+--R           (2d e x - d )\|2 \|- 4d f + e  \|a \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                   +-------------------------------------------+
+--R                 +-----------+     |      +-----------+
+--R         3 2 +-+ |          2  +-+ |      |          2        2               2
+--R       2d x \|2 \|- 4d f + e  \|a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 940
+t0:=x^2*(a+c*x^2)^(3/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R                      +--------+
+--R            4      2  |   2
+--R        (c x  + a x )\|c x  + a
+--R   (1)  ------------------------
+--R                2
+--R             f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 940
+r0:=-1/3*e*(a+c*x^2)^(3/2)/f^2+1/4*x*(a+c*x^2)^(3/2)/f+3/8*a^2*_
+   atanh(x*sqrt(c)/sqrt(a+c*x^2))/(f*sqrt(c))+1/2*a*(e^2-d*f)*_
+   atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f^3+(a*f^2*(e^2-d*f)+_
+   c*(e^4-3*d*e^2*f+d^2*f^2))*atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f^5-_
+   e*(a*f^2+c*(e^2-2*d*f))*sqrt(a+c*x^2)/f^4+3/8*a*x*sqrt(a+c*x^2)/f+_
+   1/2*c*(e^2-d*f)*x*sqrt(a+c*x^2)/f^3-atanh((2*a*f-c*x*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f)))))*(-2*d*f*(a^2*f^4+2*a*c*f^2*(e^2-d*f)+c^2*(e^4-3*d*e^2*f+_
+   d^2*f^2))+e*(a*f^2+c*(e^2-3*d*f))*(a*f^2+c*(e^2-d*f))*(e-sqrt(e^2-_
+   4*d*f)))/(f^5*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-_
+   e*sqrt(e^2-4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (-2*d*f*(a^2*f^4+2*a*c*f^2*(e^2-d*f)+c^2*(e^4-3*d*e^2*f+d^2*f^2))+_
+   e*(a*f^2+c*(e^2-3*d*f))*(a*f^2+c*(e^2-d*f))*(e+sqrt(e^2-4*d*f)))/_
+   (f^5*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                  2   4              3           3      2 2   2      2   3
+--R               24a e f  - 96a c d e f  + (48a c e  + 72c d e)f  - 96c d e f
+--R             + 
+--R                  2 5
+--R               24c e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R              2   5         2 2          2  4              2      2 3  3
+--R           48a d f  + (- 24a e  - 96a c d )f  + (192a c d e  + 48c d )f
+--R         + 
+--R                     4       2 2 2  2       2   4       2 6
+--R           (- 48a c e  - 216c d e )f  + 144c d e f - 24c e
+--R      *
+--R              +-----------------------------------------+
+--R              |    +-----------+
+--R          +-+ |    |          2        2               2
+--R         \|c \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                    2   4              3             3      2 2   2      2   3
+--R               - 24a e f  + 96a c d e f  + (- 48a c e  - 72c d e)f  + 96c d e f
+--R             + 
+--R                    2 5
+--R               - 24c e
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R              2   5         2 2          2  4              2      2 3  3
+--R           48a d f  + (- 24a e  - 96a c d )f  + (192a c d e  + 48c d )f
+--R         + 
+--R                     4       2 2 2  2       2   4       2 6
+--R           (- 48a c e  - 216c d e )f  + 144c d e f - 24c e
+--R      *
+--R              +-------------------------------------------+
+--R              |      +-----------+
+--R          +-+ |      |          2        2               2
+--R         \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                2 4            3           2      2 2  2      2   2       2 4
+--R             (9a f  - 36a c d f  + (36a c e  + 24c d )f  - 72c d e f + 24c e )
+--R          *
+--R                  +-----------+           +-+
+--R              +-+ |          2          x\|c
+--R             \|2 \|- 4d f + e  atanh(-----------)
+--R                                      +--------+
+--R                                      |   2
+--R                                     \|c x  + a
+--R         + 
+--R                   4 3         3 2         4          3        2 2            3
+--R               6c f x  - 8c e f x  + (15a f  - 12c d f  + 12c e f )x - 32a e f
+--R             + 
+--R                        2        3
+--R               48c d e f  - 24c e f
+--R          *
+--R                  +-----------+     +--------+
+--R              +-+ |          2  +-+ |   2
+--R             \|2 \|- 4d f + e  \|c \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                  +-------------------------------------------+
+--R                +-----------+     |      +-----------+
+--R          5 +-+ |          2  +-+ |      |          2        2               2
+--R       24f \|2 \|- 4d f + e  \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 940
+t0:=x*(a+c*x^2)^(3/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R                     +--------+
+--R            3        |   2
+--R        (c x  + a x)\|c x  + a
+--R   (1)  -----------------------
+--R                2
+--R             f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 940
+r0:=1/3*(a+c*x^2)^(3/2)/f-1/2*a*e*atanh(x*sqrt(c)/sqrt(a+c*x^2))*_
+   sqrt(c)/f^2-e*(a*f^2+c*(e^2-2*d*f))*atanh(x*sqrt(c)/sqrt(a+c*x^2))*_
+   sqrt(c)/f^4+(a*f^2+c*(e^2-d*f))*sqrt(a+c*x^2)/f^3-1/2*c*e*x*sqrt(a+_
+   c*x^2)/f^2-atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+_
+   c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*c*d*e*f*_
+   (2*a*f^2+c*(e^2-2*d*f))+(c^2*d*e^2*f-(a*f^2+c*(e^2-d*f))^2)*(e-_
+   sqrt(e^2-4*d*f)))/(f^4*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f-e*sqrt(e^2-4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (2*c*d*e*f*(2*a*f^2+c*(e^2-2*d*f))+(c^2*d*e^2*f-(a*f^2+c*(e^2-d*f))^2)*_
+   (e+sqrt(e^2-4*d*f)))/(f^4*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                  2 4            3             2     2 2  2      2   2      2 4
+--R             (- 6a f  + 12a c d f  + (- 12a c e  - 6c d )f  + 18c d e f - 6c e )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R             2   4              3           3      2 2   2      2   3      2 5
+--R           6a e f  - 36a c d e f  + (12a c e  + 30c d e)f  - 30c d e f + 6c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                2 4            3           2     2 2  2      2   2      2 4
+--R             (6a f  - 12a c d f  + (12a c e  + 6c d )f  - 18c d e f + 6c e )
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R             2   4              3           3      2 2   2      2   3      2 5
+--R           6a e f  - 36a c d e f  + (12a c e  + 30c d e)f  - 30c d e f + 6c e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                 +-----------+
+--R                      2                   3  +-+ |          2  +-+
+--R             (- 9a e f  + 12c d e f - 6c e )\|2 \|- 4d f + e  \|c
+--R          *
+--R                        +-+
+--R                      x\|c
+--R             atanh(-----------)
+--R                    +--------+
+--R                    |   2
+--R                   \|c x  + a
+--R         + 
+--R                                                                 +-----------+
+--R                  3 2         2        3         2       2   +-+ |          2
+--R             (2c f x  - 3c e f x + 8a f  - 6c d f  + 6c e f)\|2 \|- 4d f + e
+--R          *
+--R              +--------+
+--R              |   2
+--R             \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                             +-------------------------------------------+
+--R               +-----------+ |      +-----------+
+--R         4 +-+ |          2  |      |          2        2               2
+--R       6f \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 940
+t0:=(a+c*x^2)^(3/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (c x  + a)\|c x  + a
+--R   (1)  ---------------------
+--R               2
+--R            f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 940
+r0:=1/2*a*atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f+(a*f^2+c*(e^2-d*f))*_
+   atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/f^3-c*e*sqrt(a+c*x^2)/f^2+_
+   1/2*c*x*sqrt(a+c*x^2)/f+atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (2*f*(c^2*d*e^2-f*(c*d-a*f)^2)-c*e*(2*a*f^2+c*(e^2-2*d*f))*_
+   (e-sqrt(e^2-4*d*f)))/(f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*_
+   (e^2-2*d*f-e*sqrt(e^2-4*d*f))))-atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (2*f*(c^2*d*e^2-f*(c*d-a*f)^2)-c*e*(2*a*f^2+c*(e^2-2*d*f))*_
+   (e+sqrt(e^2-4*d*f)))/(f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                          +-----------+
+--R                    2     2          2 3  |          2      2 4           3
+--R           (4a c e f  - 4c d e f + 2c e )\|- 4d f + e   - 4a f  + 8a c d f
+--R         + 
+--R                    2     2 2  2     2   2      2 4
+--R           (- 4a c e  - 4c d )f  + 8c d e f - 2c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                            +-----------+
+--R                      2     2          2 3  |          2      2 4           3
+--R           (- 4a c e f  + 4c d e f - 2c e )\|- 4d f + e   - 4a f  + 8a c d f
+--R         + 
+--R                    2     2 2  2     2   2      2 4
+--R           (- 4a c e  - 4c d )f  + 8c d e f - 2c e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                        +-----------+               +-+
+--R                2                2  +-+ |          2  +-+         x\|c
+--R           (3a f  - 2c d f + 2c e )\|2 \|- 4d f + e  \|c atanh(-----------)
+--R                                                                +--------+
+--R                                                                |   2
+--R                                                               \|c x  + a
+--R         + 
+--R                                +-----------+ +--------+
+--R               2            +-+ |          2  |   2
+--R           (c f x - 2c e f)\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                             +-------------------------------------------+
+--R               +-----------+ |      +-----------+
+--R         3 +-+ |          2  |      |          2        2               2
+--R       2f \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 940
+t0:=(a+c*x^2)^(3/2)/(x*(d+e*x+f*x^2))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (c x  + a)\|c x  + a
+--R   (1)  ---------------------
+--R             3      2
+--R          f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 940
+r0:=-c^(3/2)*e*atanh(x*sqrt(c)/sqrt(a+c*x^2))/f^2-a^(3/2)*atanh(sqrt(a+_
+   c*x^2)/sqrt(a))/d+a*sqrt(a+c*x^2)/d+(c*d-a*f)*sqrt(a+c*x^2)/(d*f)-_
+   atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*e*f*(c^2*d^2-_
+   a^2*f^2)-(2*a*c*d*f^2-a^2*f^3+c^2*d*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/_
+   (d*f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+_
+   c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*e*f*_
+   (c^2*d^2-a^2*f^2)-(2*a*c*d*f^2-a^2*f^3+c^2*d*(e^2-d*f))*(e+_
+   sqrt(e^2-4*d*f)))/(d*f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*_
+   (e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                               +-----------+
+--R             2 3           2    2 2     2   2  |          2     2   3
+--R           (a f  - 2a c d f  + c d f - c d e )\|- 4d f + e   + a e f
+--R         + 
+--R                     2     2 2       2   3
+--R           2a c d e f  - 3c d e f + c d e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                 +-----------+
+--R               2 3           2    2 2     2   2  |          2     2   3
+--R           (- a f  + 2a c d f  - c d f + c d e )\|- 4d f + e   + a e f
+--R         + 
+--R                     2     2 2       2   3
+--R           2a c d e f  - 3c d e f + c d e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                              +--------+
+--R                      +-----------+           |   2
+--R                2 +-+ |          2  +-+      \|c x  + a
+--R           - a f \|2 \|- 4d f + e  \|a atanh(-----------)
+--R                                                  +-+
+--R                                                 \|a
+--R         + 
+--R                       +-----------+               +-+
+--R                   +-+ |          2  +-+         x\|c
+--R           - c d e\|2 \|- 4d f + e  \|c atanh(-----------)
+--R                                               +--------+
+--R                                               |   2
+--R                                              \|c x  + a
+--R         + 
+--R                     +-----------+ +--------+
+--R                 +-+ |          2  |   2
+--R           c d f\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                              +-------------------------------------------+
+--R                +-----------+ |      +-----------+
+--R          2 +-+ |          2  |      |          2        2               2
+--R       d f \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 940
+t0:=(a+c*x^2)^(3/2)/(x^2*(d+e*x+f*x^2))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (c x  + a)\|c x  + a
+--R   (1)  ---------------------
+--R             4      3      2
+--R          f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 940
+r0:=-(a+c*x^2)^(3/2)/(d*x)+a^(3/2)*e*atanh(sqrt(a+c*x^2)/sqrt(a))/d^2+_
+   a*atanh(x*sqrt(c)/sqrt(a+c*x^2))*sqrt(c)/d+(c*d-a*f)*atanh(x*sqrt(c)/_
+   sqrt(a+c*x^2))*sqrt(c)/(d*f)+c*x*sqrt(a+c*x^2)/d-atanh((2*a*f-c*x*_
+   (e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f-e*sqrt(e^2-4*d*f)))))*(-2*f*(c^2*d^3-2*a*c*d^2*f-a^2*f*(e^2-_
+   d*f))+e*(c*d-a*f)*(c*d+a*f)*(e-sqrt(e^2-4*d*f)))/(d^2*f*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+_
+   atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(-2*f*(c^2*d^3-_
+   2*a*c*d^2*f-a^2*f*(e^2-d*f))+e*(c*d-a*f)*(c*d+a*f)*(e+sqrt(e^2-_
+   4*d*f)))/(d^2*f*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+_
+   e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                               +-----------+
+--R               2   2    2 2    |          2
+--R           (- a e f  + c d e)x\|- 4d f + e
+--R         + 
+--R              2   3       2 2         2  2     2 3     2 2 2
+--R           (2a d f  + (- a e  - 4a c d )f  + 2c d f - c d e )x
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                             +-----------+
+--R             2   2    2 2    |          2
+--R           (a e f  - c d e)x\|- 4d f + e
+--R         + 
+--R              2   3       2 2         2  2     2 3     2 2 2
+--R           (2a d f  + (- a e  - 4a c d )f  + 2c d f - c d e )x
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                               +--------+
+--R                       +-----------+           |   2
+--R                   +-+ |          2  +-+      \|c x  + a
+--R           a e f x\|2 \|- 4d f + e  \|a atanh(-----------)
+--R                                                   +-+
+--R                                                  \|a
+--R         + 
+--R                     +-----------+               +-+
+--R              2  +-+ |          2  +-+         x\|c
+--R           c d x\|2 \|- 4d f + e  \|c atanh(-----------)
+--R                                             +--------+
+--R                                             |   2
+--R                                            \|c x  + a
+--R         + 
+--R                       +-----------+ +--------+
+--R                   +-+ |          2  |   2
+--R           - a d f\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                               +-------------------------------------------+
+--R                 +-----------+ |      +-----------+
+--R        2    +-+ |          2  |      |          2        2               2
+--R       d f x\|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 940
+t0:=(a+c*x^2)^(3/2)/(x^3*(d+e*x+f*x^2))
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (c x  + a)\|c x  + a
+--R   (1)  ---------------------
+--R             5      4      3
+--R          f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 940
+r0:=-1/2*(a+c*x^2)^(3/2)/(d*x^2)+e*(a+c*x^2)^(3/2)/(d^2*x)-a^(3/2)*_
+   (e^2-d*f)*atanh(sqrt(a+c*x^2)/sqrt(a))/d^3-3/2*c*atanh(sqrt(a+c*x^2)/_
+   sqrt(a))*sqrt(a)/d+3/2*c*sqrt(a+c*x^2)/d+a*(e^2-d*f)*sqrt(a+c*x^2)/d^3-_
+   (c*d^2+a*(e^2-d*f))*sqrt(a+c*x^2)/d^3-c*e*x*sqrt(a+c*x^2)/d^2+_
+   atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*a*e*f*(2*c*d^2+a*_
+   (e^2-2*d*f))+(c^2*d^3-2*a*c*d^2*f-a^2*f*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/_
+   (d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f))))-atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (2*a*e*f*(2*c*d^2+a*(e^2-2*d*f))+(c^2*d^3-2*a*c*d^2*f-a^2*f*(e^2-d*f))*_
+   (e+sqrt(e^2-4*d*f)))/(d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                                      +-----------+
+--R                2   2      2 2         2       2 3  2 |          2
+--R           (- 2a d f  + (2a e  + 4a c d )f - 2c d )x \|- 4d f + e
+--R         + 
+--R                2     2      2 3         2        2 3   2
+--R           (- 6a d e f  + (2a e  + 4a c d e)f + 2c d e)x
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                      +-----------+
+--R              2   2        2 2         2       2 3  2 |          2
+--R           (2a d f  + (- 2a e  - 4a c d )f + 2c d )x \|- 4d f + e
+--R         + 
+--R                2     2      2 3         2        2 3   2
+--R           (- 6a d e f  + (2a e  + 4a c d e)f + 2c d e)x
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                                  +--------+
+--R                                          +-----------+           |   2
+--R                         2       2  2 +-+ |          2  +-+      \|c x  + a
+--R           (2a d f - 2a e  - 3c d )x \|2 \|- 4d f + e  \|a atanh(-----------)
+--R                                                                      +-+
+--R                                                                     \|a
+--R         + 
+--R                                 +-----------+ +--------+
+--R                          2  +-+ |          2  |   2
+--R           (2a d e x - a d )\|2 \|- 4d f + e  \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                               +-------------------------------------------+
+--R                 +-----------+ |      +-----------+
+--R         3 2 +-+ |          2  |      |          2        2               2
+--R       2d x \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 940
+t0:=x^3/((d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                      3
+--R                     x
+--R   (1)  ---------------------------
+--R                         +--------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 940
+r0:=-e*atanh(x*sqrt(c)/sqrt(a+c*x^2))/(f^2*sqrt(c))+sqrt(a+c*x^2)/(c*f)-_
+   atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*d*e*f-(e^2-d*f)*_
+   (e-sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (2*d*e*f-(e^2-d*f)*(e+sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                         +-----------+
+--R                      2  |          2                  3  +-+
+--R         ((c d f - c e )\|- 4d f + e   - 3c d e f + c e )\|c
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                           +-----------+
+--R                        2  |          2                  3  +-+
+--R         ((- c d f + c e )\|- 4d f + e   - 3c d e f + c e )\|c
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                     +-----------+           +-+
+--R                 +-+ |          2          x\|c
+--R           - c e\|2 \|- 4d f + e  atanh(-----------)
+--R                                         +--------+
+--R                                         |   2
+--R                                        \|c x  + a
+--R         + 
+--R                 +-----------+     +--------+
+--R             +-+ |          2  +-+ |   2
+--R           f\|2 \|- 4d f + e  \|c \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                  +-------------------------------------------+
+--R                +-----------+     |      +-----------+
+--R          2 +-+ |          2  +-+ |      |          2        2               2
+--R       c f \|2 \|- 4d f + e  \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 940
+t0:=x^2/((d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R                         +--------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 940
+r0:=atanh(x*sqrt(c)/sqrt(a+c*x^2))/(f*sqrt(c))-atanh((2*a*f-_
+   c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(e^2-2*d*f-e*sqrt(e^2-4*d*f))/_
+   (f*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f))))-atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+_
+   c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*d*f-_
+   e*(e+sqrt(e^2-4*d*f)))/(f*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R            +-----------+
+--R            |          2            2  +-+
+--R         (e\|- 4d f + e   + 2d f - e )\|c
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R              +-----------+
+--R              |          2            2  +-+
+--R         (- e\|- 4d f + e   + 2d f - e )\|c
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R              +-----------+           +-+
+--R          +-+ |          2          x\|c
+--R         \|2 \|- 4d f + e  atanh(-----------)
+--R                                  +--------+
+--R                                  |   2
+--R                                 \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                               +-------------------------------------------+
+--R             +-----------+     |      +-----------+
+--R         +-+ |          2  +-+ |      |          2        2               2
+--R       f\|2 \|- 4d f + e  \|c \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 940
+t0:=x/((d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                     x
+--R   (1)  ---------------------------
+--R                         +--------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 940
+r0:=atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(e-sqrt(e^2-4*d*f))/_
+   (sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-_
+   atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(e+sqrt(e^2-4*d*f))/_
+   (sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                +-----------------------------------------+
+--R             +-----------+      |    +-----------+
+--R             |          2       |    |          2        2               2
+--R         (- \|- 4d f + e   + e)\|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                              +-------------------------------------------+
+--R           +-----------+      |      +-----------+
+--R           |          2       |      |          2        2               2
+--R         (\|- 4d f + e   + e)\|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                          +-------------------------------------------+
+--R            +-----------+ |      +-----------+
+--R        +-+ |          2  |      |          2        2               2
+--R       \|2 \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 940
+t0:=1/((d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                         +--------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 940
+r0:=-f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*sqrt(2)/(sqrt(e^2-_
+   4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+f*atanh((2*a*f-_
+   c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))))*sqrt(2)/(sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R       -
+--R                  +-----------------------------------------+
+--R                  |    +-----------+
+--R              +-+ |    |          2        2               2
+--R            f\|2 \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R                                   +-----------+
+--R                                   |          2
+--R                               c x\|- 4d f + e   - c e x + 2a f
+--R          atanh(-------------------------------------------------------------)
+--R                                +-------------------------------------------+
+--R                     +--------+ |      +-----------+
+--R                 +-+ |   2      |      |          2        2               2
+--R                \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R       -
+--R                  +-------------------------------------------+
+--R                  |      +-----------+
+--R              +-+ |      |          2        2               2
+--R            f\|2 \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R                                    +-----------+
+--R                                    |          2
+--R                                c x\|- 4d f + e   + c e x - 2a f
+--R            atanh(-----------------------------------------------------------)
+--R                                  +-----------------------------------------+
+--R                       +--------+ |    +-----------+
+--R                   +-+ |   2      |    |          2        2               2
+--R                  \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                      +-------------------------------------------+
+--R        +-----------+ |      +-----------+
+--R        |          2  |      |          2        2               2
+--R       \|- 4d f + e  \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 940
+t0:=1/(x*(d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                            +--------+
+--R            3      2        |   2
+--R        (f x  + e x  + d x)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 940
+r0:=-atanh(sqrt(a+c*x^2)/sqrt(a))/(d*sqrt(a))+f*atanh((2*a*f-c*x*_
+   (e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f-e*sqrt(e^2-4*d*f)))))*(e+sqrt(e^2-4*d*f))/(d*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-_
+   f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(e-sqrt(e^2-4*d*f))/_
+   (d*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                     +-----------------------------------------+
+--R            +-----------+            |    +-----------+
+--R            |          2         +-+ |    |          2        2               2
+--R         (f\|- 4d f + e   + e f)\|a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R              +-----------+
+--R              |          2         +-+
+--R         (- f\|- 4d f + e   + e f)\|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R       -
+--R                                     +--------+
+--R                 +-----------+       |   2
+--R             +-+ |          2       \|c x  + a
+--R            \|2 \|- 4d f + e  atanh(-----------)
+--R                                         +-+
+--R                                        \|a
+--R         *
+--R             +-------------------------------------------+
+--R             |      +-----------+
+--R             |      |          2        2               2
+--R            \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R         *
+--R             +-----------------------------------------+
+--R             |    +-----------+
+--R             |    |          2        2               2
+--R            \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                               +-------------------------------------------+
+--R             +-----------+     |      +-----------+
+--R         +-+ |          2  +-+ |      |          2        2               2
+--R       d\|2 \|- 4d f + e  \|a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 940
+t0:=1/(x^2*(d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                             +--------+
+--R            4      3      2  |   2
+--R        (f x  + e x  + d x )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 940
+r0:=e*atanh(sqrt(a+c*x^2)/sqrt(a))/(d^2*sqrt(a))-sqrt(a+c*x^2)/(a*d*x)-_
+   f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(e^2-2*d*f+_
+   e*sqrt(e^2-4*d*f))/(d^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+f*atanh((2*a*f-c*x*(e+sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*_
+   sqrt(e^2-4*d*f)))))*(e^2-2*d*f-e*sqrt(e^2-4*d*f))/(d^2*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                    +-----------+
+--R                    |          2           2      2     +-+
+--R         (- a e f x\|- 4d f + e   + (2a d f  - a e f)x)\|a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                  +-----------+
+--R                  |          2           2      2     +-+
+--R         (a e f x\|- 4d f + e   + (2a d f  - a e f)x)\|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                         +--------+
+--R                     +-----------+       |   2
+--R                 +-+ |          2       \|c x  + a
+--R           a e x\|2 \|- 4d f + e  atanh(-----------)
+--R                                             +-+
+--R                                            \|a
+--R         + 
+--R                   +-----------+     +--------+
+--R               +-+ |          2  +-+ |   2
+--R           - d\|2 \|- 4d f + e  \|a \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                   +-------------------------------------------+
+--R                 +-----------+     |      +-----------+
+--R          2  +-+ |          2  +-+ |      |          2        2               2
+--R       a d x\|2 \|- 4d f + e  \|a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 940
+t0:=1/(x^3*(d+e*x+f*x^2)*sqrt(a+c*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                             +--------+
+--R            5      4      3  |   2
+--R        (f x  + e x  + d x )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 940
+r0:=1/2*c*atanh(sqrt(a+c*x^2)/sqrt(a))/(a^(3/2)*d)-(e^2-d*f)*_
+   atanh(sqrt(a+c*x^2)/sqrt(a))/(d^3*sqrt(a))-1/2*sqrt(a+c*x^2)/_
+   (a*d*x^2)+e*sqrt(a+c*x^2)/(a*d^2*x)+f*atanh((2*a*f-c*x*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-_
+   e*sqrt(e^2-4*d*f)))))*(2*e^3-4*d*e*f-(e^2-d*f)*(e-sqrt(e^2-4*d*f)))/_
+   (d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f))))-f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+_
+   c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*e^3-_
+   4*d*e*f-(e^2-d*f)*(e+sqrt(e^2-4*d*f)))/(d^3*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                 +-----------+
+--R                   2       2   2 |          2               2       3   2  +-+
+--R         ((- 2a d f  + 2a e f)x \|- 4d f + e   + (- 6a d e f  + 2a e f)x )\|a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                               +-----------+
+--R                 2       2   2 |          2               2       3   2  +-+
+--R         ((2a d f  - 2a e f)x \|- 4d f + e   + (- 6a d e f  + 2a e f)x )\|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                             +--------+
+--R                                         +-----------+       |   2
+--R                         2      2  2 +-+ |          2       \|c x  + a
+--R           (2a d f - 2a e  + c d )x \|2 \|- 4d f + e  atanh(-----------)
+--R                                                                 +-+
+--R                                                                \|a
+--R         + 
+--R                             +-----------+     +--------+
+--R                      2  +-+ |          2  +-+ |   2
+--R           (2d e x - d )\|2 \|- 4d f + e  \|a \|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                   +-----------+
+--R           3 2 +-+ |          2  +-+
+--R       2a d x \|2 \|- 4d f + e  \|a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 940
+t0:=x^3/((a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                     3
+--R                                    x
+--R   (1)  ----------------------------------------------------------
+--R                                                        +--------+
+--R              4        3               2                |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x + a d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 940
+r0:=(-1)/(c*f*sqrt(a+c*x^2))-e*x/(a*f^2*sqrt(a+c*x^2))+(a*f*(c*d^2+_
+   a*(e^2-d*f))+c*e*(c*d^2+a*(e^2-2*d*f))*x)/(a*f^2*(c^2*d^2+a^2*f^2+_
+   a*c*(e^2-2*d*f))*sqrt(a+c*x^2))-atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (2*a*d*e*f-(c*d^2+a*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/((c^2*d^2+_
+   a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*_
+   (2*a*d*e*f-(c*d^2+a*(e^2-d*f))*(e+sqrt(e^2-4*d*f)))/((c^2*d^2+_
+   a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                    +-----------+
+--R                          2    2 2  |          2                      3    2 2
+--R         ((a c d f - a c e  - c d )\|- 4d f + e   - 3a c d e f + a c e  + c d e)
+--R      *
+--R                     +-----------------------------------------+
+--R          +--------+ |    +-----------+
+--R          |   2      |    |          2        2               2
+--R         \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                         +-----------+
+--R                               2    2 2  |          2                      3
+--R             (- a c d f + a c e  + c d )\|- 4d f + e   - 3a c d e f + a c e
+--R           + 
+--R              2 2
+--R             c d e
+--R      *
+--R                     +-------------------------------------------+
+--R          +--------+ |      +-----------+
+--R          |   2      |      |          2        2               2
+--R         \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                       +-----------+
+--R                       2           +-+ |          2
+--R         (- a c e x - a f + a c d)\|2 \|- 4d f + e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                               +-----------+ +--------+
+--R         2   2       2         2 2    3 2  +-+ |          2  |   2
+--R       (a c f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 940
+t0:=x^2/((a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                     2
+--R                                    x
+--R   (1)  ----------------------------------------------------------
+--R                                                        +--------+
+--R              4        3               2                |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x + a d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 940
+r0:=x/(a*f*sqrt(a+c*x^2))+(-a^2*e*f-c*(c*d^2+a*(e^2-d*f))*x)/(a*f*_
+   (c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(a+c*x^2))-f*atanh((2*a*f-_
+   c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+_
+   c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*d*(c*d-a*f)+a*e*(e-sqrt(e^2-_
+   4*d*f)))/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+f*atanh((2*a*f-_
+   c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))))*(2*d*(c*d-a*f)+a*e*(e+sqrt(e^2-4*d*f)))/_
+   ((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                +-----------+                                +--------+
+--R                |          2          2         2       2    |   2
+--R         (a e f\|- 4d f + e   + 2a d f  + (- a e  - 2c d )f)\|c x  + a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                  +-----------+                                +--------+
+--R                  |          2          2         2       2    |   2
+--R         (- a e f\|- 4d f + e   + 2a d f  + (- a e  - 2c d )f)\|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                  +-----------+
+--R                              +-+ |          2
+--R         ((a f - c d)x - a e)\|2 \|- 4d f + e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                             +-----------+ +--------+
+--R         2 2                   2    2 2  +-+ |          2  |   2
+--R       (a f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 940
+t0:=x/((a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                     x
+--R   (1)  ----------------------------------------------------------
+--R                                                        +--------+
+--R              4        3               2                |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x + a d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 940
+r0:=(-c*d+a*f+c*e*x)/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(a+c*x^2))+_
+   f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*c*d*e-(c*d-a*f)*_
+   (e-sqrt(e^2-4*d*f)))/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-_
+   f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*c*d*e-(c*d-a*f)*_
+   (e+sqrt(e^2-4*d*f)))/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                           +-----------+                     +--------+
+--R                2          |          2         2            |   2
+--R         ((- a f  + c d f)\|- 4d f + e   + a e f  + c d e f)\|c x  + a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                         +-----------+                     +--------+
+--R              2          |          2         2            |   2
+--R         ((a f  - c d f)\|- 4d f + e   + a e f  + c d e f)\|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                 +-----------+
+--R                             +-+ |          2
+--R         (c e x + a f - c d)\|2 \|- 4d f + e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                             +-----------+ +--------+
+--R         2 2                   2    2 2  +-+ |          2  |   2
+--R       (a f  - 2a c d f + a c e  + c d )\|2 \|- 4d f + e  \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 940
+t0:=1/((a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                     1
+--R   (1)  ----------------------------------------------------------
+--R                                                        +--------+
+--R              4        3               2                |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x + a d)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 940
+r0:=c*(a*e+(c*d-a*f)*x)/(a*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(a+c*x^2))-_
+   f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))+_
+   f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*a*f^2+c*(e^2-_
+   2*d*f-e*sqrt(e^2-4*d*f)))/((c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                    +-----------+                                +--------+
+--R                    |          2      2 3           2        2   |   2
+--R         (- a c e f\|- 4d f + e   - 2a f  + 2a c d f  - a c e f)\|c x  + a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                  +-----------+                                +--------+
+--R                  |          2      2 3           2        2   |   2
+--R         (a c e f\|- 4d f + e   - 2a f  + 2a c d f  - a c e f)\|c x  + a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                        +-----------+
+--R                      2             +-+ |          2
+--R         ((- a c f + c d)x + a c e)\|2 \|- 4d f + e
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                               +-----------+ +--------+
+--R         3 2     2         2   2      2 2  +-+ |          2  |   2
+--R       (a f  - 2a c d f + a c e  + a c d )\|2 \|- 4d f + e  \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 940
+t0:=1/(x*(a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                      1
+--R   (1)  -------------------------------------------------------------
+--R                                                           +--------+
+--R              5        4               3        2          |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x  + a d x)\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 940
+r0:=-atanh(sqrt(a+c*x^2)/sqrt(a))/(a^(3/2)*d)+1/(a*d*sqrt(a+c*x^2))+_
+   (-a*(a*f^2+c*(e^2-d*f))-c^2*d*e*x)/(a*d*(c^2*d^2+a^2*f^2+a*c*_
+   (e^2-2*d*f))*sqrt(a+c*x^2))+f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (2*e*(a*f^2+c*(e^2-2*d*f))-(a*f^2+c*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/_
+   (d*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-f*atanh((2*a*f-_
+   c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f)))))*(2*e*(a*f^2+c*(e^2-2*d*f))-(a*f^2+c*(e^2-_
+   d*f))*(e+sqrt(e^2-4*d*f)))/(d*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*_
+   sqrt(2)*sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                       +-----------+
+--R             2 3          2        2   |          2     2   3             2
+--R           (a f  - a c d f  + a c e f)\|- 4d f + e   + a e f  - 3a c d e f
+--R         + 
+--R                3
+--R           a c e f
+--R      *
+--R                         +-----------------------------------------+
+--R              +--------+ |    +-----------+
+--R          +-+ |   2      |    |          2        2               2
+--R         \|a \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                         +-----------+
+--R               2 3          2        2   |          2     2   3             2
+--R           (- a f  + a c d f  - a c e f)\|- 4d f + e   + a e f  - 3a c d e f
+--R         + 
+--R                3
+--R           a c e f
+--R      *
+--R                         +-------------------------------------------+
+--R              +--------+ |      +-----------+
+--R          +-+ |   2      |      |          2        2               2
+--R         \|a \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                     +-----------+ +--------+
+--R                 2 2                   2    2 2  +-+ |          2  |   2
+--R             (- a f  + 2a c d f - a c e  - c d )\|2 \|- 4d f + e  \|c x  + a
+--R          *
+--R                    +--------+
+--R                    |   2
+--R                   \|c x  + a
+--R             atanh(-----------)
+--R                        +-+
+--R                       \|a
+--R         + 
+--R                                            +-----------+
+--R               2                   2 2  +-+ |          2  +-+
+--R           (- c d e x - a c d f + c d )\|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                                   +-----------+     +--------+
+--R         3   2     2   2     2     2      2 3  +-+ |          2  +-+ |   2
+--R       (a d f  - 2a c d f + a c d e  + a c d )\|2 \|- 4d f + e  \|a \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 940
+t0:=1/(x^2*(a+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                                       1
+--R   (1)  --------------------------------------------------------------
+--R                                                            +--------+
+--R              6        5               4        3        2  |   2
+--R        (c f x  + c e x  + (a f + c d)x  + a e x  + a d x )\|c x  + a
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 940
+r0:=e*atanh(sqrt(a+c*x^2)/sqrt(a))/(a^(3/2)*d^2)-e/(a*d^2*sqrt(a+c*x^2))+_
+   1/(a*d*x*sqrt(a+c*x^2))+(a*e*(a*f^2+c*(e^2-2*d*f))+c*d*(a*f^2+c*(e^2-_
+   d*f))*x)/(a*d^2*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(a+c*x^2))-_
+   2*sqrt(a+c*x^2)/(a^2*d*x)+f*atanh((2*a*f-c*x*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+c*x^2)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f)))))*_
+   (2*(c*d*e^2*f-(e^2-d*f)*(a*f^2+c*(e^2-d*f)))+e*(a*f^2+c*(e^2-2*d*f))*_
+   (e-sqrt(e^2-4*d*f)))/(d^2*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))-_
+   f*atanh((2*a*f-c*x*(e+sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+c*x^2)*_
+   sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))))*(2*(c*d*e^2*f-_
+   (e^2-d*f)*(a*f^2+c*(e^2-d*f)))+e*(a*f^2+c*(e^2-2*d*f))*(e+sqrt(e^2-_
+   4*d*f)))/(d^2*(c^2*d^2+a^2*f^2+a*c*(e^2-2*d*f))*sqrt(2)*sqrt(e^2-_
+   4*d*f)*sqrt(2*a*f^2+c*(e^2-2*d*f+e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                                               +-----------+
+--R               3   3     2       2    2   3    |          2
+--R           (- a e f  + 2a c d e f  - a c e f)x\|- 4d f + e
+--R         + 
+--R              3   4       3 2     2   2  3     2     2 2    2   4
+--R           (2a d f  + (- a e  - 2a c d )f  + 4a c d e f  - a c e f)x
+--R      *
+--R                         +-----------------------------------------+
+--R              +--------+ |    +-----------+
+--R          +-+ |   2      |    |          2        2               2
+--R         \|a \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                  +-----------+
+--R                                  |          2
+--R                              c x\|- 4d f + e   - c e x + 2a f
+--R         atanh(-------------------------------------------------------------)
+--R                               +-------------------------------------------+
+--R                    +--------+ |      +-----------+
+--R                +-+ |   2      |      |          2        2               2
+--R               \|2 \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                             +-----------+
+--R             3   3     2       2    2   3    |          2
+--R           (a e f  - 2a c d e f  + a c e f)x\|- 4d f + e
+--R         + 
+--R              3   4       3 2     2   2  3     2     2 2    2   4
+--R           (2a d f  + (- a e  - 2a c d )f  + 4a c d e f  - a c e f)x
+--R      *
+--R                         +-------------------------------------------+
+--R              +--------+ |      +-----------+
+--R          +-+ |   2      |      |          2        2               2
+--R         \|a \|c x  + a \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R                                 +-----------+
+--R                                 |          2
+--R                             c x\|- 4d f + e   + c e x - 2a f
+--R         atanh(-----------------------------------------------------------)
+--R                               +-----------------------------------------+
+--R                    +--------+ |    +-----------+
+--R                +-+ |   2      |    |          2        2               2
+--R               \|2 \|c x  + a \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R     + 
+--R                                                           +-----------+
+--R               3   2     2           2   3      2 2    +-+ |          2
+--R             (a e f  - 2a c d e f + a c e  + a c d e)x\|2 \|- 4d f + e
+--R          *
+--R                               +--------+
+--R              +--------+       |   2
+--R              |   2           \|c x  + a
+--R             \|c x  + a atanh(-----------)
+--R                                   +-+
+--R                                  \|a
+--R         + 
+--R                   2     2       2 2       2   2     3 3  2      2 2       3   2
+--R               (- a c d f  + 3a c d f - a c d e  - 2c d )x  - a c d e x - a d f
+--R             + 
+--R                 2   2     2     2      2 3
+--R               2a c d f - a c d e  - a c d
+--R          *
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R             \|2 \|- 4d f + e  \|a
+--R      *
+--R          +-------------------------------------------+
+--R          |      +-----------+
+--R          |      |          2        2               2
+--R         \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------+
+--R          |    |          2        2               2
+--R         \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R  /
+--R                                                    +-----------+     +--------+
+--R         4 2 2     3   3     3   2 2    2 2 4   +-+ |          2  +-+ |   2
+--R       (a d f  - 2a c d f + a c d e  + a c d )x\|2 \|- 4d f + e  \|a \|c x  + a
+--R    *
+--R        +-------------------------------------------+
+--R        |      +-----------+
+--R        |      |          2        2               2
+--R       \|- c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R    *
+--R        +-----------------------------------------+
+--R        |    +-----------+
+--R        |    |          2        2               2
+--R       \|c e\|- 4d f + e   + 2a f  - 2c d f + c e
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 940
+t0:=x^3*(a+b*x+c*x^2)^(1/2)/(d+f*x^2)
+--R 
+--R
+--R           +--------------+
+--R         3 |   2
+--R        x \|c x  + b x + a
+--R   (1)  -------------------
+--R                 2
+--R              f x  + d
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 940
+r0:=1/3*(a+b*x+c*x^2)^(3/2)/(c*f)+1/16*b*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(5/2)*f)-1/2*b*d*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(f^2*sqrt(c))-d*sqrt(a+b*x+c*x^2)/f^2-_
+   1/8*b*(b+2*c*x)*sqrt(a+b*x+c*x^2)/(c^2*f)+1/2*d*atan(1/2*(b*sqrt(-d)+_
+   2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-_
+   a*f-b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))/f^(5/2)-_
+   1/2*d*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f+_
+   b*sqrt(-d)*sqrt(f))/f^(5/2)
+--R 
+--R
+--R   (2)
+--R                   +-------------------------+
+--R            2  +-+ |    +---+ +-+
+--R         24c d\|c \|- b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                   +-----------------------+
+--R            2  +-+ |  +---+ +-+
+--R         24c d\|c \|b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                       3          2   +-+             2c x + b
+--R       ((- 12a b c + 3b )f - 24b c d)\|f atanh(----------------------)
+--R                                                     +--------------+
+--R                                                 +-+ |   2
+--R                                               2\|c \|c x  + b x + a
+--R     + 
+--R                                                              +--------------+
+--R           2   2                         2        2   +-+ +-+ |   2
+--R       (16c f x  + 4b c f x + (16a c - 6b )f - 48c d)\|c \|f \|c x  + b x + a
+--R  /
+--R        2 2 +-+ +-+
+--R     48c f \|c \|f
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 940
+t0:=x^2*(a+b*x+c*x^2)^(1/2)/(d+f*x^2)
+--R 
+--R
+--R           +--------------+
+--R         2 |   2
+--R        x \|c x  + b x + a
+--R   (1)  -------------------
+--R                 2
+--R              f x  + d
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 940
+r0:=-1/8*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (c^(3/2)*f)-d*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(c)/f^2+1/4*(b+2*c*x)*sqrt(a+b*x+c*x^2)/(c*f)-1/2*atan(1/2*(b*_
+   sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(-d)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))/f^2-1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-_
+   b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*_
+   sqrt(-d)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))/f^2
+--R 
+--R
+--R   (2)
+--R       -
+--R                         +-------------------------+
+--R               +---+ +-+ |    +---+ +-+
+--R            4c\|- d \|c \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                      +-----------------------+
+--R            +---+ +-+ |  +---+ +-+
+--R         4c\|- d \|c \|b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                 2       2               2c x + b
+--R       ((4a c - b )f - 8c d)atanh(----------------------)
+--R                                        +--------------+
+--R                                    +-+ |   2
+--R                                  2\|c \|c x  + b x + a
+--R     + 
+--R                           +--------------+
+--R                       +-+ |   2
+--R       (4c f x + 2b f)\|c \|c x  + b x + a
+--R  /
+--R         2 +-+
+--R     8c f \|c
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 940
+t0:=x*(a+b*x+c*x^2)^(1/2)/(d+f*x^2)
+--R 
+--R
+--R          +--------------+
+--R          |   2
+--R        x\|c x  + b x + a
+--R   (1)  ------------------
+--R                2
+--R             f x  + d
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 940
+r0:=1/2*b*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f*sqrt(c))+_
+   sqrt(a+b*x+c*x^2)/f-1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*_
+   sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))/f^(3/2)+1/2*atan(1/2*(b*_
+   sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))/f^(3/2)
+--R 
+--R
+--R   (2)
+--R       -
+--R                 +-------------------------+
+--R             +-+ |    +---+ +-+
+--R            \|c \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                 +-----------------------+
+--R             +-+ |  +---+ +-+
+--R            \|c \|b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                                                      +--------------+
+--R         +-+             2c x + b             +-+ +-+ |   2
+--R       b\|f atanh(----------------------) + 2\|c \|f \|c x  + b x + a
+--R                        +--------------+
+--R                    +-+ |   2
+--R                  2\|c \|c x  + b x + a
+--R  /
+--R        +-+ +-+
+--R     2f\|c \|f
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 940
+t0:=(a+b*x+c*x^2)^(1/2)/(d+f*x^2)
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R                2
+--R             f x  + d
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 940
+r0:=atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(c)/f-_
+   1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))/(f*sqrt(-d))-1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*_
+   sqrt(f))))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))/(f*sqrt(-d))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +-------------------------+
+--R             |    +---+ +-+
+--R            \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R         +---+ +-+             2c x + b
+--R       2\|- d \|c atanh(----------------------)
+--R                              +--------------+
+--R                          +-+ |   2
+--R                        2\|c \|c x  + b x + a
+--R  /
+--R        +---+
+--R     2f\|- d
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 940
+t0:=(a+b*x+c*x^2)^(1/2)/(x*(d+f*x^2))
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R               3
+--R            f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 940
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a)/d+_
+   1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))/(d*sqrt(f))-1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*_
+   sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))/(d*sqrt(f))
+--R 
+--R
+--R   (2)
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R           +-+ +-+             b x + 2a
+--R       - 2\|a \|f atanh(----------------------)
+--R                              +--------------+
+--R                          +-+ |   2
+--R                        2\|a \|c x  + b x + a
+--R  /
+--R        +-+
+--R     2d\|f
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 940
+t0:=(a+b*x+c*x^2)^(1/2)/(x^2*(d+f*x^2))
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R              4      2
+--R           f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 940
+r0:=-1/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(d*sqrt(a))-_
+   sqrt(a+b*x+c*x^2)/(d*x)-1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*_
+   sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))/(-d)^(3/2)-1/2*atan(1/2*_
+   (b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*sqrt(c*d-a*f+b*sqrt(-d)*_
+   sqrt(f))/(-d)^(3/2)
+--R 
+--R
+--R   (2)
+--R               +-------------------------+
+--R           +-+ |    +---+ +-+
+--R         x\|a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                  +-----------------------+
+--R              +-+ |  +---+ +-+
+--R            x\|a \|b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                                                              +--------------+
+--R             +---+             b x + 2a             +---+ +-+ |   2
+--R       - b x\|- d atanh(----------------------) - 2\|- d \|a \|c x  + b x + a
+--R                              +--------------+
+--R                          +-+ |   2
+--R                        2\|a \|c x  + b x + a
+--R  /
+--R          +---+ +-+
+--R     2d x\|- d \|a
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 940
+t0:=(a+b*x+c*x^2)^(1/2)/(x^3*(d+f*x^2))
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R              5      3
+--R           f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 940
+r0:=1/8*(b^2-4*a*c)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (a^(3/2)*d)+f*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(a)/d^2-1/4*(2*a+b*x)*sqrt(a+b*x+c*x^2)/(a*d*x^2)-1/2*atan(1/2*_
+   (b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+_
+   c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(f)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))/d^2+1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*_
+   sqrt(-d)*sqrt(f))))*sqrt(f)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))/d^2
+--R 
+--R
+--R   (2)
+--R       -
+--R                          +-------------------------+
+--R                2 +-+ +-+ |    +---+ +-+
+--R            4a x \|a \|f \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                          +-----------------------+
+--R                2 +-+ +-+ |  +---+ +-+
+--R            4a x \|a \|f \|b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R          2               2    2             b x + 2a
+--R       (8a f + (- 4a c + b )d)x atanh(----------------------)
+--R                                            +--------------+
+--R                                        +-+ |   2
+--R                                      2\|a \|c x  + b x + a
+--R     + 
+--R                             +--------------+
+--R                         +-+ |   2
+--R       (- 2b d x - 4a d)\|a \|c x  + b x + a
+--R  /
+--R         2 2 +-+
+--R     8a d x \|a
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 940
+t0:=x^3*(a+b*x+c*x^2)^(3/2)/(d+f*x^2)
+--R 
+--R
+--R                             +--------------+
+--R            5      4      3  |   2
+--R        (c x  + b x  + a x )\|c x  + b x + a
+--R   (1)  -------------------------------------
+--R                          2
+--R                       f x  + d
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 940
+r0:=-1/3*d*(a+b*x+c*x^2)^(3/2)/f^2-1/16*b*(b+2*c*x)*(a+b*x+c*x^2)^(3/2)/_
+   (c^2*f)+1/5*(a+b*x+c*x^2)^(5/2)/(c*f)+1/16*b*(b^2-4*a*c)*d*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f^2)-3/256*b*(b^2-_
+   4*a*c)^2*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(7/2)*f)+_
+   1/2*b*d*(3*c*d-a*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f^3*sqrt(c))+d*(c*d-a*f)*sqrt(a+b*x+c*x^2)/f^3-1/8*b*d*(b+2*c*x)*_
+   sqrt(a+b*x+c*x^2)/(c*f^2)+3/128*b*(b^2-4*a*c)*(b+2*c*x)*sqrt(a+b*x+_
+   c*x^2)/(c^3*f)+1/2*d*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+_
+   b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*_
+   (b^2*d*f-(c*d-a*f)^2+2*b*(c*d-a*f)*sqrt(-d)*sqrt(f))/(f^(7/2)*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*d*atan(1/2*(b*sqrt(-d)-2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+_
+   b*sqrt(-d)*sqrt(f))))*(b^2*d*f-(c*d-a*f)^2-2*b*(c*d-a*f)*sqrt(-d)*_
+   sqrt(f))/(f^(7/2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                       3             4 2  +---+ +-+ +-+
+--R           (- 3840a b c d f + 3840b c d )\|- d \|c \|f
+--R         + 
+--R                   2 3   2           4        2 3  2         5 3  +-+
+--R           (- 1920a c d f  + (3840a c  + 1920b c )d f - 1920c d )\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                     3             4 2  +---+ +-+ +-+
+--R           (3840a b c d f - 3840b c d )\|- d \|c \|f
+--R         + 
+--R                   2 3   2           4        2 3  2         5 3  +-+
+--R           (- 1920a c d f  + (3840a c  + 1920b c )d f - 1920c d )\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                      2   2         3       5  2               3       3 2
+--R               (- 720a b c  + 360a b c - 45b )f  + (- 2880a b c  + 240b c )d f
+--R             + 
+--R                      4 2
+--R               5760b c d
+--R          *
+--R              +-+             2c x + b
+--R             \|f atanh(----------------------)
+--R                             +--------------+
+--R                         +-+ |   2
+--R                       2\|c \|c x  + b x + a
+--R         + 
+--R                   4 2 4          3 2 3            3      2 2  2        4     2
+--R               768c f x  + 1056b c f x  + ((1536a c  + 48b c )f  - 1280c d f)x
+--R             + 
+--R                         2      3   2          3
+--R               ((336a b c  - 60b c)f  - 2240b c d f)x
+--R             + 
+--R                    2 2         2       4  2             3       2 2
+--R               (768a c  - 600a b c + 90b )f  + (- 5120a c  - 480b c )d f
+--R             + 
+--R                    4 2
+--R               3840c d
+--R          *
+--R                      +--------------+
+--R              +-+ +-+ |   2
+--R             \|c \|f \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                      +-------------------------+ +-----------------------+
+--R          3 3 +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     3840c f \|c \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 940
+t0:=x^2*(a+b*x+c*x^2)^(3/2)/(d+f*x^2)
+--R 
+--R
+--R                             +--------------+
+--R            4      3      2  |   2
+--R        (c x  + b x  + a x )\|c x  + b x + a
+--R   (1)  -------------------------------------
+--R                          2
+--R                       f x  + d
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 940
+r0:=1/8*(b+2*c*x)*(a+b*x+c*x^2)^(3/2)/(c*f)+3/128*(b^2-4*a*c)^2*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(5/2)*f)+_
+   1/8*(b^2-4*a*c)*d*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f^2*sqrt(c))+1/2*d*(2*c^2*d-b^2*f-2*a*c*f)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(f^3*sqrt(c))-b*d*sqrt(a+b*x+c*x^2)/f^2-_
+   1/4*d*(b+2*c*x)*sqrt(a+b*x+c*x^2)/f^2-3/64*(b^2-4*a*c)*(b+2*c*x)*_
+   sqrt(a+b*x+c*x^2)/(c^2*f)+1/2*d*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*_
+   sqrt(-d)*sqrt(f))))*((b^2*d*f-(c*d-a*f)^2)/sqrt(-d)+2*b*(c*d-a*f)*_
+   sqrt(f))/(f^3*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*d*atan(1/2*(b*_
+   sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*((-b^2*d*f+(c*d-a*f)^2)/sqrt(-d)+_
+   2*b*(c*d-a*f)*sqrt(f))/(f^3*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                      2            3 2  +---+ +-+ +-+
+--R           (- 128a b c d f + 128b c d )\|- d \|c \|f
+--R         + 
+--R                 2 2   2          3      2 2  2       4 3  +-+
+--R           (- 64a c d f  + (128a c  + 64b c )d f - 64c d )\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                      2            3 2  +---+ +-+ +-+
+--R           (- 128a b c d f + 128b c d )\|- d \|c \|f
+--R         + 
+--R               2 2   2            3      2 2  2       4 3  +-+
+--R           (64a c d f  + (- 128a c  - 64b c )d f + 64c d )\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                  2 2        2      4  2            3      2 2           4 2
+--R             ((48a c  - 24a b c + 3b )f  + (- 192a c  - 48b c )d f + 128c d )
+--R          *
+--R              +---+             2c x + b
+--R             \|- d atanh(----------------------)
+--R                               +--------------+
+--R                           +-+ |   2
+--R                         2\|c \|c x  + b x + a
+--R         + 
+--R                  3 2 3        2 2 2          2     2   2      3
+--R               32c f x  + 48b c f x  + ((80a c  + 4b c)f  - 64c d f)x
+--R             + 
+--R                            3  2         2
+--R               (40a b c - 6b )f  - 160b c d f
+--R          *
+--R                        +--------------+
+--R              +---+ +-+ |   2
+--R             \|- d \|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                       +-------------------------+ +-----------------------+
+--R         2 3 +---+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     128c f \|- d \|c \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 940
+t0:=x*(a+b*x+c*x^2)^(3/2)/(d+f*x^2)
+--R 
+--R
+--R                            +--------------+
+--R            3      2        |   2
+--R        (c x  + b x  + a x)\|c x  + b x + a
+--R   (1)  ------------------------------------
+--R                         2
+--R                      f x  + d
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 940
+r0:=1/3*(a+b*x+c*x^2)^(3/2)/f-1/16*b*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f)-1/2*b*(3*c*d-a*f)*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f^2*sqrt(c))-(c*d-a*f)*_
+   sqrt(a+b*x+c*x^2)/f^2+1/8*b*(b+2*c*x)*sqrt(a+b*x+c*x^2)/(c*f)-_
+   1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*(b^2*d*f-_
+   (c*d-a*f)^2+2*b*(c*d-a*f)*sqrt(-d)*sqrt(f))/(f^(5/2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f)))+1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*_
+   sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*_
+   sqrt(f))))*(b^2*d*f-(c*d-a*f)^2-2*b*(c*d-a*f)*sqrt(-d)*sqrt(f))/_
+   (f^(5/2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                             2   +---+ +-+ +-+
+--R           (48a b c f - 48b c d)\|- d \|c \|f
+--R         + 
+--R               2   2           2      2           3 2  +-+
+--R           (24a c f  + (- 48a c  - 24b c)d f + 24c d )\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                               2   +---+ +-+ +-+
+--R           (- 48a b c f + 48b c d)\|- d \|c \|f
+--R         + 
+--R               2   2           2      2           3 2  +-+
+--R           (24a c f  + (- 48a c  - 24b c)d f + 24c d )\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                         3          2   +-+             2c x + b
+--R           ((36a b c - 3b )f - 72b c d)\|f atanh(----------------------)
+--R                                                       +--------------+
+--R                                                   +-+ |   2
+--R                                                 2\|c \|c x  + b x + a
+--R         + 
+--R                 2   2                          2        2   +-+ +-+
+--R             (16c f x  + 28b c f x + (64a c + 6b )f - 48c d)\|c \|f
+--R          *
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                    +-------------------------+ +-----------------------+
+--R          2 +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     48c f \|c \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 940
+t0:=(a+b*x+c*x^2)^(3/2)/(d+f*x^2)
+--R 
+--R
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R   (1)  ---------------------------------
+--R                        2
+--R                     f x  + d
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 940
+r0:=-1/8*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f*sqrt(c))-1/2*(2*c^2*d-b^2*f-2*a*c*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/(f^2*sqrt(c))+b*sqrt(a+b*x+c*x^2)/f+1/4*(b+2*c*x)*_
+   sqrt(a+b*x+c*x^2)/f-1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*_
+   sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))))*((b^2*d*f-(c*d-a*f)^2)/sqrt(-d)+2*b*(c*d-a*f)*sqrt(f))/_
+   (f^2*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+1/2*atan(1/2*(b*sqrt(-d)-_
+   2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f))))*((-b^2*d*f+(c*d-a*f)^2)/sqrt(-d)+2*b*_
+   (c*d-a*f)*sqrt(f))/(f^2*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                             +---+ +-+ +-+
+--R           (8a b f - 8b c d)\|- d \|c \|f
+--R         + 
+--R              2 2               2         2 2  +-+
+--R           (4a f  + (- 8a c - 4b )d f + 4c d )\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                             +---+ +-+ +-+
+--R           (8a b f - 8b c d)\|- d \|c \|f
+--R         + 
+--R                2 2             2         2 2  +-+
+--R           (- 4a f  + (8a c + 4b )d f - 4c d )\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                       2       2   +---+             2c x + b
+--R           ((12a c + 3b )f - 8c d)\|- d atanh(----------------------)
+--R                                                    +--------------+
+--R                                                +-+ |   2
+--R                                              2\|c \|c x  + b x + a
+--R         + 
+--R                                      +--------------+
+--R                            +---+ +-+ |   2
+--R           (4c f x + 10b f)\|- d \|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                   +-------------------------+ +-----------------------+
+--R       2 +---+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     8f \|- d \|c \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 940
+t0:=(a+b*x+c*x^2)^(3/2)/(x*(d+f*x^2))
+--R 
+--R
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R   (1)  ---------------------------------
+--R                       3
+--R                    f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 940
+r0:=-a^(3/2)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/d-_
+   1/16*b*(b^2-12*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (c^(3/2)*d)+1/16*b*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+_
+   b*x+c*x^2)))/(c^(3/2)*d)+1/2*b*(3*c*d-a*f)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(d*f*sqrt(c))+(c*d-a*f)*sqrt(a+b*x+_
+   c*x^2)/(d*f)-1/8*b*(b+2*c*x)*sqrt(a+b*x+c*x^2)/(c*d)+1/8*(b^2+8*a*c+_
+   2*b*c*x)*sqrt(a+b*x+c*x^2)/(c*d)+1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*_
+   sqrt(-d)*sqrt(f))))*(b^2*d*f-(c*d-a*f)^2+2*b*(c*d-a*f)*sqrt(-d)*_
+   sqrt(f))/(d*f^(3/2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*atan(1/2*_
+   (b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*(b^2*d*f-(c*d-a*f)^2-2*b*(c*d-a*f)*_
+   sqrt(-d)*sqrt(f))/(d*f^(3/2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                               +---+ +-+ +-+
+--R           (- 2a b f + 2b c d)\|- d \|c \|f
+--R         + 
+--R               2 2            2        2 2  +-+
+--R           (- a f  + (2a c + b )d f - c d )\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                               +---+ +-+ +-+
+--R             (2a b f - 2b c d)\|- d \|c \|f
+--R           + 
+--R                 2 2            2        2 2  +-+
+--R             (- a f  + (2a c + b )d f - c d )\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                  +-+ +-+ +-+             b x + 2a
+--R           - 2a f\|a \|c \|f atanh(----------------------)
+--R                                         +--------------+
+--R                                     +-+ |   2
+--R                                   2\|a \|c x  + b x + a
+--R         + 
+--R                                                                +--------------+
+--R                +-+             2c x + b                +-+ +-+ |   2
+--R         3b c d\|f atanh(----------------------) + 2c d\|c \|f \|c x  + b x + a
+--R                               +--------------+
+--R                           +-+ |   2
+--R                         2\|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                  +-------------------------+ +-----------------------+
+--R          +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2d f\|c \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 940
+t0:=(a+b*x+c*x^2)^(3/2)/(x^2*(d+f*x^2))
+--R 
+--R
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R   (1)  ---------------------------------
+--R                      4      2
+--R                   f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 940
+r0:=-(a+b*x+c*x^2)^(3/2)/(d*x)-3/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(a)/d+1/8*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/(d*sqrt(c))+3/8*(b^2+4*a*c)*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(d*sqrt(c))+1/2*(2*c^2*d-b^2*f-_
+   2*a*c*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(d*f*_
+   sqrt(c))-b*sqrt(a+b*x+c*x^2)/d-1/4*(b+2*c*x)*sqrt(a+b*x+c*x^2)/d+_
+   3/4*(3*b+2*c*x)*sqrt(a+b*x+c*x^2)/d+1/2*atan(1/2*(b*sqrt(-d)+2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))))*((b^2*d*f-(c*d-a*f)^2)/sqrt(-d)+2*b*(c*d-a*f)*_
+   sqrt(f))/(d*f*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*atan(1/2*(b*_
+   sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*((-b^2*d*f+(c*d-a*f)^2)/sqrt(-d)+_
+   2*b*(c*d-a*f)*sqrt(f))/(d*f*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                                +---+ +-+ +-+
+--R           (- 2a b f + 2b c d)x\|- d \|c \|f
+--R         + 
+--R               2 2            2        2 2   +-+
+--R           (- a f  + (2a c + b )d f - c d )x\|c
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                                +---+ +-+ +-+
+--R           (- 2a b f + 2b c d)x\|- d \|c \|f
+--R         + 
+--R             2 2              2        2 2   +-+
+--R           (a f  + (- 2a c - b )d f + c d )x\|c
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                    +---+ +-+ +-+             b x + 2a
+--R           - 3b f x\|- d \|a \|c atanh(----------------------)
+--R                                             +--------------+
+--R                                         +-+ |   2
+--R                                       2\|a \|c x  + b x + a
+--R         + 
+--R             2    +---+             2c x + b
+--R           2c d x\|- d atanh(----------------------)
+--R                                   +--------------+
+--R                               +-+ |   2
+--R                             2\|c \|c x  + b x + a
+--R         + 
+--R                            +--------------+
+--R                  +---+ +-+ |   2
+--R           - 2a f\|- d \|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                      +-------------------------+ +-----------------------+
+--R            +---+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2d f x\|- d \|c \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 940
+t0:=(a+b*x+c*x^2)^(3/2)/(x^3*(d+f*x^2))
+--R 
+--R
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R   (1)  ---------------------------------
+--R                      5      3
+--R                   f x  + d x
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 940
+r0:=-1/2*(a+b*x+c*x^2)^(3/2)/(d*x^2)+a^(3/2)*f*atanh(1/2*(2*a+b*x)/_
+   (sqrt(a)*sqrt(a+b*x+c*x^2)))/d^2+1/16*b*(b^2-12*a*c)*f*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*d^2)-1/16*b*(b^2-4*a*c)*_
+   f*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*d^2)-_
+   3/8*(b^2+4*a*c)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (d*sqrt(a))-1/2*b*(3*c*d-a*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/(d^2*sqrt(c))+3/2*b*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))*sqrt(c)/d-(c*d-a*f)*sqrt(a+b*x+c*x^2)/d^2-_
+   3/4*(b-2*c*x)*sqrt(a+b*x+c*x^2)/(d*x)+1/8*b*f*(b+2*c*x)*sqrt(a+b*x+_
+   c*x^2)/(c*d^2)-1/8*f*(b^2+8*a*c+2*b*c*x)*sqrt(a+b*x+c*x^2)/(c*d^2)-_
+   1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*(b^2*d*f-_
+   (c*d-a*f)^2+2*b*(c*d-a*f)*sqrt(-d)*sqrt(f))/(d^2*sqrt(f)*sqrt(c*d-_
+   a*f-b*sqrt(-d)*sqrt(f)))+1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+_
+   b*sqrt(-d)*sqrt(f))))*(b^2*d*f-(c*d-a*f)^2-2*b*(c*d-a*f)*sqrt(-d)*_
+   sqrt(f))/(d^2*sqrt(f)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                             2 +---+ +-+ +-+
+--R           (8a b f - 8b c d)x \|- d \|a \|f
+--R         + 
+--R              2 2               2         2 2  2 +-+
+--R           (4a f  + (- 8a c - 4b )d f + 4c d )x \|a
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                               2 +---+ +-+ +-+
+--R           (- 8a b f + 8b c d)x \|- d \|a \|f
+--R         + 
+--R              2 2               2         2 2  2 +-+
+--R           (4a f  + (- 8a c - 4b )d f + 4c d )x \|a
+--R      *
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R              2                 2    2 +-+             b x + 2a
+--R           (8a f + (- 12a c - 3b )d)x \|f atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|a \|c x  + b x + a
+--R         + 
+--R                                      +--------------+
+--R                              +-+ +-+ |   2
+--R           (- 10b d x - 4a d)\|a \|f \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                   +-------------------------+ +-----------------------+
+--R       2 2 +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     8d x \|a \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 940
+t0:=(a+b*x+c*x^2)^(3/2)/(1-x^2)
+--R 
+--R
+--R                           +--------------+
+--R              2            |   2
+--R        (- c x  - b x - a)\|c x  + b x + a
+--R   (1)  -----------------------------------
+--R                        2
+--R                       x  - 1
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 940
+r0:=-1/2*(a-b+c)^(3/2)*atanh(1/2*(2*a-b+(b-2*c)*x)/(sqrt(a-b+c)*_
+   sqrt(a+b*x+c*x^2)))+1/2*(a+b+c)^(3/2)*atanh(1/2*(2*a+b+(b+2*c)*x)/_
+   (sqrt(a+b+c)*sqrt(a+b*x+c*x^2)))+1/8*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/_
+   (sqrt(c)*sqrt(a+b*x+c*x^2)))/sqrt(c)-1/2*(b^2+2*c*(a+c))*atanh(1/2*_
+   (b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/sqrt(c)-b*sqrt(a+b*x+c*x^2)-_
+   1/4*(b+2*c*x)*sqrt(a+b*x+c*x^2)
+--R 
+--R
+--R   (2)
+--R                      +---------+ +-+            (2c - b)x + b - 2a
+--R       (4c - 4b + 4a)\|c - b + a \|c atanh(------------------------------)
+--R                                                         +--------------+
+--R                                             +---------+ |   2
+--R                                           2\|c - b + a \|c x  + b x + a
+--R     + 
+--R            2             2              2c x + b
+--R       (- 8c  - 12a c - 3b )atanh(----------------------)
+--R                                        +--------------+
+--R                                    +-+ |   2
+--R                                  2\|c \|c x  + b x + a
+--R     + 
+--R                      +-+ +---------+            (2c + b)x + b + 2a
+--R       (4c + 4b + 4a)\|c \|c + b + a atanh(------------------------------)
+--R                                                         +--------------+
+--R                                             +---------+ |   2
+--R                                           2\|c + b + a \|c x  + b x + a
+--R     + 
+--R                          +--------------+
+--R                      +-+ |   2
+--R       (- 4c x - 10b)\|c \|c x  + b x + a
+--R  /
+--R       +-+
+--R     8\|c
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 940
+t0:=sqrt(-1-x+x^2)/(1-x^2)
+--R 
+--R
+--R           +----------+
+--R           | 2
+--R          \|x  - x - 1
+--R   (1)  - -------------
+--R               2
+--R              x  - 1
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 940
+r0:=-1/2*atan(1/2*(3-x)/sqrt(-1-x+x^2))+atanh(1/2*(1-2*x)/sqrt(-1-x+x^2))+_
+   1/2*atanh(1/2*(1+3*x)/sqrt(-1-x+x^2))
+--R 
+--R
+--R                  3x + 1                   2x - 1                  x - 3
+--R        atanh(--------------) - 2atanh(--------------) + atan(--------------)
+--R                +----------+             +----------+           +----------+
+--R                | 2                      | 2                    | 2
+--R              2\|x  - x - 1            2\|x  - x - 1          2\|x  - x - 1
+--R   (2)  ---------------------------------------------------------------------
+--R                                          2
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 940
+t0:=(x+x^2)^(3/2)/(1+x^2)
+--R 
+--R
+--R                 +------+
+--R          2      | 2
+--R        (x  + x)\|x  + x
+--R   (1)  -----------------
+--R               2
+--R              x  + 1
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 940
+r0:=-5/4*atanh(x/sqrt(x+x^2))-atan(1/2*(%i+(1+2*%i)*x)/(sqrt(1-%i)*_
+   sqrt(x+x^2)))/sqrt(1-%i)+atan(1/2*(%i+(-1+2*%i)*x)/(sqrt(1+%i)*_
+   sqrt(x+x^2)))/sqrt(1+%i)+5/4*sqrt(x+x^2)+1/2*x*sqrt(x+x^2)
+--R 
+--R
+--R   (2)
+--R           +------+ +------+          x
+--R       - 5\|1 - %i \|1 + %i atanh(---------)
+--R                                   +------+
+--R                                   | 2
+--R                                  \|x  + x
+--R     + 
+--R           +------+       (1 + 2%i)x + %i
+--R       - 4\|1 + %i atan(-------------------)
+--R                                   +------+
+--R                          +------+ | 2
+--R                        2\|1 - %i \|x  + x
+--R     + 
+--R                                                                        +------+
+--R         +------+       (1 - 2%i)x - %i               +------+ +------+ | 2
+--R     - 4\|1 - %i atan(-------------------) + (2x + 5)\|1 - %i \|1 + %i \|x  + x
+--R                                 +------+
+--R                        +------+ | 2
+--R                      2\|1 + %i \|x  + x
+--R  /
+--R       +------+ +------+
+--R     4\|1 - %i \|1 + %i
+--R                                           Type: Expression(Complex(Integer))
+--E 125
+
+--S 126 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                           Type: Expression(Complex(Integer))
+--E 126
+
+)clear all
+
+--S 127 of 940
+t0:=x^4/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                      4
+--R                     x
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 940
+r0:=1/8*(3*b^2-4*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (c^(5/2)*f)-d*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f^2*sqrt(c))-3/4*b*sqrt(a+b*x+c*x^2)/(c^2*f)+1/2*x*sqrt(a+b*x+c*x^2)/_
+   (c*f)+1/2*(-d)^(3/2)*atanh(1/2*(b*d+2*a*sqrt(-d)*sqrt(f)+x*(2*c*d+_
+   b*sqrt(-d)*sqrt(f)))/(sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f-_
+   b*sqrt(-d)*sqrt(f))))/(f^2*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*(-d)^(3/2)*atanh(1/2*(b*d-2*a*sqrt(-d)*sqrt(f)+x*(2*c*d-_
+   b*sqrt(-d)*sqrt(f)))/(sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f+_
+   b*sqrt(-d)*sqrt(f))))/(f^2*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R       -
+--R                           +-----------------------+
+--R              2  +---+ +-+ |  +---+ +-+
+--R            4c d\|- d \|c \|b\|- d \|f  + a f - c d
+--R         *
+--R                                      +---+ +-+
+--R                           (b x + 2a)\|- d \|f  + 2c d x + b d
+--R            atanh(----------------------------------------------------)
+--R                          +--------------+ +-------------------------+
+--R                    +---+ |   2            |    +---+ +-+
+--R                  2\|- d \|c x  + b x + a \|- b\|- d \|f  + a f - c d
+--R     + 
+--R                        +-------------------------+
+--R           2  +---+ +-+ |    +---+ +-+
+--R         4c d\|- d \|c \|- b\|- d \|f  + a f - c d
+--R      *
+--R                                  +---+ +-+
+--R                       (b x + 2a)\|- d \|f  - 2c d x - b d
+--R         atanh(--------------------------------------------------)
+--R                       +--------------+ +-----------------------+
+--R                 +---+ |   2            |  +---+ +-+
+--R               2\|- d \|c x  + b x + a \|b\|- d \|f  + a f - c d
+--R     + 
+--R                        2       2               2c x + b
+--R           ((- 4a c + 3b )f - 8c d)atanh(----------------------)
+--R                                               +--------------+
+--R                                           +-+ |   2
+--R                                         2\|c \|c x  + b x + a
+--R         + 
+--R                               +--------------+
+--R                           +-+ |   2
+--R           (4c f x - 6b f)\|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R  /
+--R               +-------------------------+ +-----------------------+
+--R       2 2 +-+ |    +---+ +-+              |  +---+ +-+
+--R     8c f \|c \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 940
+t0:=x^3/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                      3
+--R                     x
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 940
+r0:=-1/2*b*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f)+_
+   sqrt(a+b*x+c*x^2)/(c*f)-1/2*d*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))))/(f^(3/2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*d*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))/(f^(3/2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R       -
+--R                    +-----------------------+
+--R                +-+ |  +---+ +-+
+--R            c d\|c \|b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                    +-------------------------+
+--R                +-+ |    +---+ +-+
+--R            c d\|c \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                                                           +--------------+
+--R              +-+             2c x + b             +-+ +-+ |   2
+--R         (- b\|f atanh(----------------------) + 2\|c \|f \|c x  + b x + a )
+--R                             +--------------+
+--R                         +-+ |   2
+--R                       2\|c \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                  +-------------------------+ +-----------------------+
+--R          +-+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2c f\|c \|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 940
+t0:=x^2/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 940
+r0:=atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f*sqrt(c))+_
+   1/2*atanh(1/2*(b*d+2*a*sqrt(-d)*sqrt(f)+x*(2*c*d+b*sqrt(-d)*sqrt(f)))/_
+   (sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f))))*_
+   sqrt(-d)/(f*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f)))+1/2*atanh(1/2*(b*d-_
+   2*a*sqrt(-d)*sqrt(f)+x*(2*c*d-b*sqrt(-d)*sqrt(f)))/(sqrt(-d)*_
+   sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f))))*sqrt(-d)/_
+   (f*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                    +-----------------------+
+--R          +---+ +-+ |  +---+ +-+
+--R         \|- d \|c \|b\|- d \|f  + a f - c d
+--R      *
+--R                                   +---+ +-+
+--R                        (b x + 2a)\|- d \|f  + 2c d x + b d
+--R         atanh(----------------------------------------------------)
+--R                       +--------------+ +-------------------------+
+--R                 +---+ |   2            |    +---+ +-+
+--R               2\|- d \|c x  + b x + a \|- b\|- d \|f  + a f - c d
+--R     + 
+--R       -
+--R                       +-------------------------+
+--R             +---+ +-+ |    +---+ +-+
+--R            \|- d \|c \|- b\|- d \|f  + a f - c d
+--R         *
+--R                                     +---+ +-+
+--R                          (b x + 2a)\|- d \|f  - 2c d x - b d
+--R            atanh(--------------------------------------------------)
+--R                          +--------------+ +-----------------------+
+--R                    +---+ |   2            |  +---+ +-+
+--R                  2\|- d \|c x  + b x + a \|b\|- d \|f  + a f - c d
+--R     + 
+--R                                        +-------------------------+
+--R                       2c x + b         |    +---+ +-+
+--R         2atanh(----------------------)\|- b\|- d \|f  + a f - c d
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|c \|c x  + b x + a
+--R      *
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  + a f - c d
+--R  /
+--R            +-------------------------+ +-----------------------+
+--R        +-+ |    +---+ +-+              |  +---+ +-+
+--R     2f\|c \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 940
+t0:=x/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                     x
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 940
+r0:=1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))/(sqrt(f)*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*atan(1/2*(b*sqrt(-d)-2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+_
+   b*sqrt(-d)*sqrt(f))))/(sqrt(f)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R          +-------------------------+
+--R          |    +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R  /
+--R           +-------------------------+ +-----------------------+
+--R       +-+ |    +---+ +-+              |  +---+ +-+
+--R     2\|f \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 940
+t0:=1/((a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                   +--------------+
+--R            2      |   2
+--R        (f x  + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 940
+r0:=1/2*atanh(1/2*(b*d+2*a*sqrt(-d)*sqrt(f)+x*(2*c*d+b*sqrt(-d)*sqrt(f)))/_
+   (sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f))))/_
+   (sqrt(-d)*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f)))+1/2*atanh(1/2*(b*d-_
+   2*a*sqrt(-d)*sqrt(f)+x*(2*c*d-b*sqrt(-d)*sqrt(f)))/(sqrt(-d)*_
+   sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f))))/(sqrt(-d)*_
+   sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R          +-----------------------+
+--R          |  +---+ +-+
+--R         \|b\|- d \|f  + a f - c d
+--R      *
+--R                                   +---+ +-+
+--R                        (b x + 2a)\|- d \|f  + 2c d x + b d
+--R         atanh(----------------------------------------------------)
+--R                       +--------------+ +-------------------------+
+--R                 +---+ |   2            |    +---+ +-+
+--R               2\|- d \|c x  + b x + a \|- b\|- d \|f  + a f - c d
+--R     + 
+--R       -
+--R             +-------------------------+
+--R             |    +---+ +-+
+--R            \|- b\|- d \|f  + a f - c d
+--R         *
+--R                                     +---+ +-+
+--R                          (b x + 2a)\|- d \|f  - 2c d x - b d
+--R            atanh(--------------------------------------------------)
+--R                          +--------------+ +-----------------------+
+--R                    +---+ |   2            |  +---+ +-+
+--R                  2\|- d \|c x  + b x + a \|b\|- d \|f  + a f - c d
+--R  /
+--R             +-------------------------+ +-----------------------+
+--R       +---+ |    +---+ +-+              |  +---+ +-+
+--R     2\|- d \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 940
+t0:=1/(x*(a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R                     +--------------+
+--R            3        |   2
+--R        (f x  + d x)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 940
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(d*sqrt(a))-_
+   1/2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*sqrt(f)/(d*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+1/2*atan(1/2*(b*sqrt(-d)-2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+_
+   b*sqrt(-d)*sqrt(f))))*sqrt(f)/(d*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R       -
+--R                     +-----------------------+
+--R             +-+ +-+ |  +---+ +-+
+--R            \|a \|f \|b\|- d \|f  - a f + c d
+--R         *
+--R                                   +-+              +---+
+--R                        (b x + 2a)\|f  + (2c x + b)\|- d
+--R            atan(----------------------------------------------)
+--R                   +--------------+ +-------------------------+
+--R                   |   2            |    +---+ +-+
+--R                 2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                     +-------------------------+
+--R             +-+ +-+ |    +---+ +-+
+--R            \|a \|f \|- b\|- d \|f  - a f + c d
+--R         *
+--R                                 +-+                +---+
+--R                      (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R            atan(--------------------------------------------)
+--R                   +--------------+ +-----------------------+
+--R                   |   2            |  +---+ +-+
+--R                 2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R       -
+--R                                           +-------------------------+
+--R                          b x + 2a         |    +---+ +-+
+--R            2atanh(----------------------)\|- b\|- d \|f  - a f + c d
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|a \|c x  + b x + a
+--R         *
+--R             +-----------------------+
+--R             |  +---+ +-+
+--R            \|b\|- d \|f  - a f + c d
+--R  /
+--R            +-------------------------+ +-----------------------+
+--R        +-+ |    +---+ +-+              |  +---+ +-+
+--R     2d\|a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 940
+t0:=1/(x^2*(a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                      +--------------+
+--R            4      2  |   2
+--R        (f x  + d x )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 940
+r0:=1/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(a^(3/2)*d)-_
+   sqrt(a+b*x+c*x^2)/(a*d*x)+1/2*f*atanh(1/2*(b*d+2*a*sqrt(-d)*sqrt(f)+_
+   x*(2*c*d+b*sqrt(-d)*sqrt(f)))/(sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+_
+   a*f-b*sqrt(-d)*sqrt(f))))/((-d)^(3/2)*sqrt(-c*d+a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*f*atanh(1/2*(b*d-2*a*sqrt(-d)*sqrt(f)+x*(2*c*d-b*sqrt(-d)*sqrt(f)))/_
+   (sqrt(-d)*sqrt(a+b*x+c*x^2)*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f))))/_
+   ((-d)^(3/2)*sqrt(-c*d+a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R       -
+--R                      +-----------------------+
+--R                  +-+ |  +---+ +-+
+--R            a f x\|a \|b\|- d \|f  + a f - c d
+--R         *
+--R                                      +---+ +-+
+--R                           (b x + 2a)\|- d \|f  + 2c d x + b d
+--R            atanh(----------------------------------------------------)
+--R                          +--------------+ +-------------------------+
+--R                    +---+ |   2            |    +---+ +-+
+--R                  2\|- d \|c x  + b x + a \|- b\|- d \|f  + a f - c d
+--R     + 
+--R                   +-------------------------+
+--R               +-+ |    +---+ +-+
+--R         a f x\|a \|- b\|- d \|f  + a f - c d
+--R      *
+--R                                  +---+ +-+
+--R                       (b x + 2a)\|- d \|f  - 2c d x - b d
+--R         atanh(--------------------------------------------------)
+--R                       +--------------+ +-----------------------+
+--R                 +---+ |   2            |  +---+ +-+
+--R               2\|- d \|c x  + b x + a \|b\|- d \|f  + a f - c d
+--R     + 
+--R                                                               +--------------+
+--R              +---+             b x + 2a             +---+ +-+ |   2
+--R         (b x\|- d atanh(----------------------) - 2\|- d \|a \|c x  + b x + a )
+--R                               +--------------+
+--R                           +-+ |   2
+--R                         2\|a \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R  /
+--R                      +-------------------------+ +-----------------------+
+--R            +---+ +-+ |    +---+ +-+              |  +---+ +-+
+--R     2a d x\|- d \|a \|- b\|- d \|f  + a f - c d \|b\|- d \|f  + a f - c d
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 940
+t0:=1/(x^3*(a+b*x+c*x^2)^(1/2)*(d+f*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                      +--------------+
+--R            5      3  |   2
+--R        (f x  + d x )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 940
+r0:=-1/8*(3*b^2-4*a*c)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (a^(5/2)*d)+f*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (d^2*sqrt(a))-1/2*sqrt(a+b*x+c*x^2)/(a*d*x^2)+3/4*b*sqrt(a+b*x+c*x^2)/_
+   (a^2*d*x)+1/2*f^(3/2)*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+_
+   b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))/_
+   (d^2*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*f^(3/2)*atan(1/2*(b*sqrt(-d)-_
+   2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f))))/(d^2*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                         +-----------------------+
+--R           2   2 +-+ +-+ |  +---+ +-+
+--R         4a f x \|a \|f \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                         +-------------------------+
+--R           2   2 +-+ +-+ |    +---+ +-+
+--R         4a f x \|a \|f \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R              2              2    2             b x + 2a
+--R           (8a f + (4a c - 3b )d)x atanh(----------------------)
+--R                                               +--------------+
+--R                                           +-+ |   2
+--R                                         2\|a \|c x  + b x + a
+--R         + 
+--R                               +--------------+
+--R                           +-+ |   2
+--R           (6b d x - 4a d)\|a \|c x  + b x + a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R                 +-------------------------+ +-----------------------+
+--R       2 2 2 +-+ |    +---+ +-+              |  +---+ +-+
+--R     8a d x \|a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 940
+t0:=x^4/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                        4
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 940
+r0:=atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f)+2*x*_
+   (2*a+b*x)/((b^2-4*a*c)*f*sqrt(a+b*x+c*x^2))+2*d*(b+2*c*x)/((b^2-4*a*c)*_
+   f^2*sqrt(a+b*x+c*x^2))-2*d^2*(b*(c^2*d+b^2*f-3*a*c*f)+c*(2*c^2*d+_
+   b^2*f-2*a*c*f)*x)/((b^2-4*a*c)*f^2*(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*_
+   sqrt(a+b*x+c*x^2))-2*b*sqrt(a+b*x+c*x^2)/(c*(b^2-4*a*c)*f)-_
+   1/2*d^2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*((c*d-a*f)/_
+   sqrt(-d)+b*sqrt(f))/(f*(c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-_
+   a*f-b*sqrt(-d)*sqrt(f)))+1/2*d^2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*_
+   sqrt(-d)*sqrt(f))))*((-c*d+a*f)/sqrt(-d)+b*sqrt(f))/(f*(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                    2    3   2 +---+ +-+ +-+
+--R           (- 4a b c  + b c)d \|- d \|c \|f
+--R         + 
+--R               2 2      2   2           3    2 2  3  +-+
+--R           ((4a c  - a b c)d f + (- 4a c  + b c )d )\|c
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                    2    3   2 +---+ +-+ +-+
+--R           (- 4a b c  + b c)d \|- d \|c \|f
+--R         + 
+--R                 2 2      2   2         3    2 2  3  +-+
+--R           ((- 4a c  + a b c)d f + (4a c  - b c )d )\|c
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                  3      2 2  2         2 2        2      4
+--R               (8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f
+--R             + 
+--R                    3     2 2  2
+--R               (8a c  - 2b c )d
+--R          *
+--R                    +--------------+
+--R              +---+ |   2                        2c x + b
+--R             \|- d \|c x  + b x + a atanh(----------------------)
+--R                                                +--------------+
+--R                                            +-+ |   2
+--R                                          2\|c \|c x  + b x + a
+--R         + 
+--R                     3      2 2  2      2 2        2      4           3   2
+--R               ((- 8a c + 4a b )f  + (8a c  - 16a b c + 4b )d f)x + 4a b f
+--R             + 
+--R                     2          3
+--R               (- 12a b c + 4a b )d f
+--R          *
+--R              +---+ +-+
+--R             \|- d \|c
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R            3 2     2 2   3         2 3        2 2     4     2
+--R         (8a c  - 2a b c)f  + (- 16a c  + 12a b c  - 2b c)d f
+--R       + 
+--R              4     2 3  2
+--R         (8a c  - 2b c )d f
+--R    *
+--R                  +--------------+ +-------------------------+
+--R        +---+ +-+ |   2            |    +---+ +-+
+--R       \|- d \|c \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 940
+t0:=x^3/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                        3
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 940
+r0:=2*(2*a+b*x)/((b^2-4*a*c)*f*sqrt(a+b*x+c*x^2))-2*d*(a*(2*c^2*d+b^2*f-_
+   2*a*c*f)+b*c*(c*d+a*f)*x)/((b^2-4*a*c)*f*(c^2*d^2-2*a*c*d*f+f*(b^2*d+_
+   a^2*f))*sqrt(a+b*x+c*x^2))+1/2*d*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*_
+   sqrt(-d)*sqrt(f))))*(c*d-a*f+b*sqrt(-d)*sqrt(f))/((c^2*d^2-2*a*c*d*f+_
+   f*(b^2*d+a^2*f))*sqrt(f)*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*d*_
+   atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(f)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                     3   +---+ +-+        2       2            2    2   2
+--R         ((4a b c - b )d\|- d \|f  + (- 4a c + a b )d f + (4a c  - b c)d )
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                       3   +---+ +-+        2       2            2    2   2
+--R         ((- 4a b c + b )d\|- d \|f  + (- 4a c + a b )d f + (4a c  - b c)d )
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R               2                   3         3       2        2    +-+
+--R         ((- 4a b f + (12a b c - 4b )d)x - 8a f + (8a c - 4a b )d)\|f
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R           3      2 2  2         2 2        2      4            3     2 2  2
+--R       ((8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f + (8a c  - 2b c )d )
+--R    *
+--R          +--------------+ +-------------------------+ +-----------------------+
+--R      +-+ |   2            |    +---+ +-+              |  +---+ +-+
+--R     \|f \|c x  + b x + a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 940
+t0:=x^2/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                        2
+--R                                       x
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 940
+r0:=-2*(b+2*c*x)/((b^2-4*a*c)*f*sqrt(a+b*x+c*x^2))+2*d*(b*(c^2*d+b^2*f-_
+   3*a*c*f)+c*(2*c^2*d+b^2*f-2*a*c*f)*x)/((b^2-4*a*c)*f*(c^2*d^2-2*a*c*d*f+_
+   f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))+1/2*d*atan(1/2*(b*sqrt(-d)+2*a*_
+   sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))))*((c*d-a*f)/sqrt(-d)+b*sqrt(f))/((c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-_
+   1/2*d*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*((-c*d+a*f)/_
+   sqrt(-d)+b*sqrt(f))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                     3   +---+ +-+        2       2            2    2   2
+--R         ((4a b c - b )d\|- d \|f  + (- 4a c + a b )d f + (4a c  - b c)d )
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                     3   +---+ +-+      2       2              2    2   2
+--R         ((4a b c - b )d\|- d \|f  + (4a c - a b )d f + (- 4a c  + b c)d )
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R             2             2     2          2                +---+
+--R         ((8a c f + (- 8a c  + 4b c)d)x + 4a b f + 4a b c d)\|- d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R           3      2 2  2         2 2        2      4            3     2 2  2
+--R       ((8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f + (8a c  - 2b c )d )
+--R    *
+--R              +--------------+ +-------------------------+
+--R        +---+ |   2            |    +---+ +-+
+--R       \|- d \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 940
+t0:=x/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                        x
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 940
+r0:=2*(a*(2*c^2*d+b^2*f-2*a*c*f)+b*c*(c*d+a*f)*x)/((b^2-4*a*c)*(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))-1/2*atan(1/2*(b*sqrt(-d)+_
+   2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))))*sqrt(f)*(c*d-a*f+b*sqrt(-d)*sqrt(f))/((c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*sqrt(f)*(c*d-a*f-_
+   b*sqrt(-d)*sqrt(f))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R              2       2            2    2     +-+                3   +---+
+--R         (((4a c - a b )f + (- 4a c  + b c)d)\|f  + (- 4a b c + b )f\|- d )
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R              2       2            2    2     +-+              3   +---+
+--R         (((4a c - a b )f + (- 4a c  + b c)d)\|f  + (4a b c - b )f\|- d )
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                            2         2        2         2
+--R         ((- 4a b c f - 4b c d)x + (8a c - 4a b )f - 8a c d)
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R           3      2 2  2         2 2        2      4            3     2 2  2
+--R       ((8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f + (8a c  - 2b c )d )
+--R    *
+--R        +--------------+ +-------------------------+ +-----------------------+
+--R        |   2            |    +---+ +-+              |  +---+ +-+
+--R       \|c x  + b x + a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 940
+t0:=1/((a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                        1
+--R   (1)  ----------------------------------------------------------------
+--R                                                        +--------------+
+--R              4        3               2                |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x + a d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 940
+r0:=-2*(b*(c^2*d+b^2*f-3*a*c*f)+c*(2*c^2*d+b^2*f-2*a*c*f)*x)/((b^2-4*a*c)*_
+   (c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))-1/2*f*atan(1/2*_
+   (b*sqrt(-d)+2*a*sqrt(f)+x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f))))*((c*d-a*f)/sqrt(-d)+b*sqrt(f))/_
+   ((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))+_
+   1/2*f*atan(1/2*(b*sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/_
+   (sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*((-c*d+a*f)/_
+   sqrt(-d)+b*sqrt(f))/((c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                       3   +---+ +-+      2       2  2          2    2
+--R         ((- 4a b c + b )f\|- d \|f  + (4a c - a b )f  + (- 4a c  + b c)d f)
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                       3   +---+ +-+        2       2  2        2    2
+--R         ((- 4a b c + b )f\|- d \|f  + (- 4a c + a b )f  + (4a c  - b c)d f)
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                  2     2        3                     3         2   +---+
+--R         (((- 8a c  + 4b c)f + 8c d)x + (- 12a b c + 4b )f + 4b c d)\|- d
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R           3      2 2  2         2 2        2      4            3     2 2  2
+--R       ((8a c - 2a b )f  + (- 16a c  + 12a b c - 2b )d f + (8a c  - 2b c )d )
+--R    *
+--R              +--------------+ +-------------------------+
+--R        +---+ |   2            |    +---+ +-+
+--R       \|- d \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 940
+t0:=1/(x*(a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                         1
+--R   (1)  -------------------------------------------------------------------
+--R                                                           +--------------+
+--R              5        4               3        2          |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x  + a d x)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 940
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(a^(3/2)*d)+2*(b^2-_
+   2*a*c+b*c*x)/(a*(b^2-4*a*c)*d*sqrt(a+b*x+c*x^2))-2*f*(a*(2*c^2*d+b^2*f-_
+   2*a*c*f)+b*c*(c*d+a*f)*x)/((b^2-4*a*c)*d*(c^2*d^2-2*a*c*d*f+f*(b^2*d+_
+   a^2*f))*sqrt(a+b*x+c*x^2))+1/2*f^(3/2)*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))))*(c*d-a*f+b*sqrt(-d)*sqrt(f))/(d*(c^2*d^2-2*a*c*d*f+f*(b^2*d+_
+   a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*f^(3/2)*atan(1/2*(b*_
+   sqrt(-d)-2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*_
+   sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f))))*(c*d-a*f-b*sqrt(-d)*sqrt(f))/(d*_
+   (c^2*d^2-2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R                 3     2 2  2      2 2      2       +-+ +-+
+--R           ((- 4a c + a b )f  + (4a c  - a b c)d f)\|a \|f
+--R         + 
+--R              2         3  2 +---+ +-+
+--R           (4a b c - a b )f \|- d \|a
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R                 3     2 2  2      2 2      2       +-+ +-+
+--R           ((- 4a c + a b )f  + (4a c  - a b c)d f)\|a \|f
+--R         + 
+--R                2         3  2 +---+ +-+
+--R           (- 4a b c + a b )f \|- d \|a
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                    3      2 2  2       2 2        2      4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2b )d f
+--R             + 
+--R                      3     2 2  2
+--R               (- 8a c  + 2b c )d
+--R          *
+--R              +--------------+
+--R              |   2                        b x + 2a
+--R             \|c x  + b x + a atanh(----------------------)
+--R                                          +--------------+
+--R                                      +-+ |   2
+--R                                    2\|a \|c x  + b x + a
+--R         + 
+--R                        2     3            3 2          2 2        2      4
+--R               ((12a b c  - 4b c)d f - 4b c d )x + (- 8a c  + 16a b c - 4b )d f
+--R             + 
+--R                    3     2 2  2
+--R               (8a c  - 4b c )d
+--R          *
+--R              +-+
+--R             \|a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R            4      3 2    2         3 2      2 2        4  2
+--R         (8a c - 2a b )d f  + (- 16a c  + 12a b c - 2a b )d f
+--R       + 
+--R            2 3       2 2  3
+--R         (8a c  - 2a b c )d
+--R    *
+--R          +--------------+ +-------------------------+ +-----------------------+
+--R      +-+ |   2            |    +---+ +-+              |  +---+ +-+
+--R     \|a \|c x  + b x + a \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 940
+t0:=1/(x^2*(a+b*x+c*x^2)^(3/2)*(d+f*x^2))
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R                                                            +--------------+
+--R              6        5               4        3        2  |   2
+--R        (c f x  + b f x  + (a f + c d)x  + b d x  + a d x )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 940
+r0:=3/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(a^(5/2)*d)+_
+   2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*d*x*sqrt(a+b*x+c*x^2))+2*f*(b*(c^2*d+_
+   b^2*f-3*a*c*f)+c*(2*c^2*d+b^2*f-2*a*c*f)*x)/((b^2-4*a*c)*d*(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(a+b*x+c*x^2))-(3*b^2-8*a*c)*sqrt(a+b*x+_
+   c*x^2)/(a^2*(b^2-4*a*c)*d*x)+1/2*f^2*atan(1/2*(b*sqrt(-d)+2*a*sqrt(f)+_
+   x*(2*c*sqrt(-d)+b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-a*f-b*sqrt(-d)*_
+   sqrt(f))))*((c*d-a*f)/sqrt(-d)+b*sqrt(f))/(d*(c^2*d^2-2*a*c*d*f+f*(b^2*d+_
+   a^2*f))*sqrt(c*d-a*f-b*sqrt(-d)*sqrt(f)))-1/2*f^2*atan(1/2*(b*sqrt(-d)-_
+   2*a*sqrt(f)+x*(2*c*sqrt(-d)-b*sqrt(f)))/(sqrt(a+b*x+c*x^2)*sqrt(c*d-_
+   a*f+b*sqrt(-d)*sqrt(f))))*((-c*d+a*f)/sqrt(-d)+b*sqrt(f))/(d*(c^2*d^2-_
+   2*a*c*d*f+f*(b^2*d+a^2*f))*sqrt(c*d-a*f+b*sqrt(-d)*sqrt(f)))
+--R 
+--R
+--R   (2)
+--R              3       2 3  2  +---+ +-+ +-+
+--R           (4a b c - a b )f x\|- d \|a \|f
+--R         + 
+--R                 4     3 2  3      3 2    2 2     2   +-+
+--R           ((- 4a c + a b )f  + (4a c  - a b c)d f )x\|a
+--R      *
+--R          +--------------+ +-----------------------+
+--R          |   2            |  +---+ +-+
+--R         \|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R      *
+--R                                +-+              +---+
+--R                     (b x + 2a)\|f  + (2c x + b)\|- d
+--R         atan(----------------------------------------------)
+--R                +--------------+ +-------------------------+
+--R                |   2            |    +---+ +-+
+--R              2\|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R     + 
+--R              3       2 3  2  +---+ +-+ +-+
+--R           (4a b c - a b )f x\|- d \|a \|f
+--R         + 
+--R               4     3 2  3        3 2    2 2     2   +-+
+--R           ((4a c - a b )f  + (- 4a c  + a b c)d f )x\|a
+--R      *
+--R          +--------------+ +-------------------------+
+--R          |   2            |    +---+ +-+
+--R         \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R      *
+--R                              +-+                +---+
+--R                   (b x + 2a)\|f  + (- 2c x - b)\|- d
+--R         atan(--------------------------------------------)
+--R                +--------------+ +-----------------------+
+--R                |   2            |  +---+ +-+
+--R              2\|c x  + b x + a \|b\|- d \|f  - a f + c d
+--R     + 
+--R                   3        2 3  2         2   2        3      5
+--R               (12a b c - 3a b )f  + (- 24a b c  + 18a b c - 3b )d f
+--R             + 
+--R                       3     3 2  2
+--R               (12a b c  - 3b c )d
+--R          *
+--R                     +--------------+
+--R               +---+ |   2                        b x + 2a
+--R             x\|- d \|c x  + b x + a atanh(----------------------)
+--R                                                 +--------------+
+--R                                             +-+ |   2
+--R                                           2\|a \|c x  + b x + a
+--R         + 
+--R                        3 2     2 2   2       2 3        2 2     4
+--R                   (- 8a c  + 2a b c)f  + (24a c  - 28a b c  + 6b c)d f
+--R                 + 
+--R                           4     2 3  2
+--R                   (- 16a c  + 6b c )d
+--R              *
+--R                  2
+--R                 x
+--R             + 
+--R                        3        2 3  2       2   2        3      5
+--R                   (- 8a b c + 2a b )f  + (36a b c  - 32a b c + 6b )d f
+--R                 + 
+--R                             3     3 2  2
+--R                   (- 20a b c  + 6b c )d
+--R              *
+--R                 x
+--R             + 
+--R                    4      3 2  2       3 2      2 2        4
+--R               (- 8a c + 2a b )f  + (16a c  - 12a b c + 2a b )d f
+--R             + 
+--R                    2 3       2 2  2
+--R               (- 8a c  + 2a b c )d
+--R          *
+--R              +---+ +-+
+--R             \|- d \|a
+--R      *
+--R          +-------------------------+ +-----------------------+
+--R          |    +---+ +-+              |  +---+ +-+
+--R         \|- b\|- d \|f  - a f + c d \|b\|- d \|f  - a f + c d
+--R  /
+--R            5      4 2    2         4 2      3 2      2 4  2
+--R         (8a c - 2a b )d f  + (- 16a c  + 12a b c - 2a b )d f
+--R       + 
+--R            3 3     2 2 2  3
+--R         (8a c  - 2a b c )d
+--R    *
+--R                   +--------------+ +-------------------------+
+--R         +---+ +-+ |   2            |    +---+ +-+
+--R       x\|- d \|a \|c x  + b x + a \|- b\|- d \|f  - a f + c d
+--R    *
+--R        +-----------------------+
+--R        |  +---+ +-+
+--R       \|b\|- d \|f  - a f + c d
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 940
+t0:=x^2*(a+b*x+c*x^2)^(1/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R           +--------------+
+--R         2 |   2
+--R        x \|c x  + b x + a
+--R   (1)  -------------------
+--R              2
+--R           f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 940
+r0:=-1/8*(b^2-4*a*c)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (c^(3/2)*f)+1/2*(2*c*e^2-2*c*d*f-b*e*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/(f^3*sqrt(c))-e*sqrt(a+b*x+c*x^2)/f^2+1/4*(b+2*c*x)*_
+   sqrt(a+b*x+c*x^2)/(c*f)+atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-_
+   b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*f*(c*e^2-c*d*f-b*e*f+_
+   a*f^2)+(f*(b*e^2-b*d*f-a*e*f)-c*(e^3-2*d*e*f))*(e-sqrt(e^2-4*d*f)))/_
+   (f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f)))-atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-_
+   c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*f*(c*e^2-c*d*f-b*e*f+_
+   a*f^2)+(f*(b*e^2-b*d*f-a*e*f)-c*(e^3-2*d*e*f))*(e+sqrt(e^2-4*d*f)))/_
+   (f^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                                                  +-----------+
+--R                                2          2      2          2 3  |          2
+--R           ((- 8a c e - 8b c d)f  + (8b c e  + 16c d e)f - 8c e )\|- 4d f + e
+--R         + 
+--R                    3            2                  2 2  2
+--R           16a c d f  + (- 8a c e  - 24b c d e - 16c d )f
+--R         + 
+--R                  3      2   2       2 4
+--R           (8b c e  + 32c d e )f - 8c e
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|c \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                                  +-----------+
+--R                              2            2      2          2 3  |          2
+--R           ((8a c e + 8b c d)f  + (- 8b c e  - 16c d e)f + 8c e )\|- 4d f + e
+--R         + 
+--R                    3            2                  2 2  2
+--R           16a c d f  + (- 8a c e  - 24b c d e - 16c d )f
+--R         + 
+--R                  3      2   2       2 4
+--R           (8b c e  + 32c d e )f - 8c e
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|c \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                              +-----------+
+--R                       2  2                 2        2 2  +-+ |          2
+--R             ((4a c - b )f  + (- 4b c e - 8c d)f + 8c e )\|2 \|- 4d f + e
+--R          *
+--R                          2c x + b
+--R             atanh(----------------------)
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|c \|c x  + b x + a
+--R         + 
+--R                                         +-----------+     +--------------+
+--R                2        2           +-+ |          2  +-+ |   2
+--R           (4c f x + 2b f  - 8c e f)\|2 \|- 4d f + e  \|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                 +-----------+
+--R           3 +-+ |          2  +-+
+--R       8c f \|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 940
+t0:=x*(a+b*x+c*x^2)^(1/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R          +--------------+
+--R          |   2
+--R        x\|c x  + b x + a
+--R   (1)  ------------------
+--R             2
+--R          f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 940
+r0:=-1/2*(2*c*e-b*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (f^2*sqrt(c))+sqrt(a+b*x+c*x^2)/f-atanh(1/2*(4*a*f+2*x*(b*f-c*(e-_
+   sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*f*_
+   (c*e-b*f)+(f*(b*e-a*f)-c*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f)))+atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*f*(c*e-b*f)+(f*(b*e-a*f)-c*(e^2-d*f))*_
+   (e+sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                              +-----------+
+--R                2                          2  |          2                  2
+--R           (2a f  + (- 2b e - 2c d)f + 2c e )\|- 4d f + e   + (2a e + 4b d)f
+--R         + 
+--R                  2                  3
+--R           (- 2b e  - 6c d e)f + 2c e
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|c \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                              +-----------+
+--R                  2                        2  |          2                  2
+--R           (- 2a f  + (2b e + 2c d)f - 2c e )\|- 4d f + e   + (2a e + 4b d)f
+--R         + 
+--R                  2                  3
+--R           (- 2b e  - 6c d e)f + 2c e
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|c \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                            +-----------+
+--R                        +-+ |          2              2c x + b
+--R           (b f - 2c e)\|2 \|- 4d f + e  atanh(----------------------)
+--R                                                     +--------------+
+--R                                                 +-+ |   2
+--R                                               2\|c \|c x  + b x + a
+--R         + 
+--R                  +-----------+     +--------------+
+--R              +-+ |          2  +-+ |   2
+--R           2f\|2 \|- 4d f + e  \|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R               +-----------+
+--R         2 +-+ |          2  +-+
+--R       2f \|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 940
+t0:=(a+b*x+c*x^2)^(1/2)/(d+e*x+f*x^2)
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R             2
+--R          f x  + e x + d
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 940
+r0:=atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(c)/f-atanh(1/2*_
+   (4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f))))*sqrt(f*(2*a*f-b*(e-sqrt(e^2-4*d*f)))+c*(e^2-2*d*f-e*sqrt(e^2-_
+   4*d*f)))/(f*sqrt(2)*sqrt(e^2-4*d*f))+atanh(1/2*(4*a*f-b*(e+sqrt(e^2-_
+   4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*sqrt(c*_
+   (e^2-2*d*f+e*sqrt(e^2-4*d*f))+f*(2*a*f-b*(e+sqrt(e^2-4*d*f))))/(f*_
+   sqrt(2)*sqrt(e^2-4*d*f))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +------------------------------------------------------------+
+--R             |              +-----------+
+--R             |              |          2        2                        2
+--R            \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            atanh
+--R                            +-----------+
+--R                            |          2
+--R                 (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R              /
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|2 \|c x  + b x + a
+--R                *
+--R                  +------------------------------------------------------------+
+--R                  |              +-----------+
+--R                  |              |          2        2                        2
+--R                 \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R       -
+--R             +----------------------------------------------------------+
+--R             |            +-----------+
+--R             |            |          2        2                        2
+--R            \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            atanh
+--R                            +-----------+
+--R                            |          2
+--R                 (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R              /
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|2 \|c x  + b x + a
+--R                *
+--R                  +----------------------------------------------------------+
+--R                  |            +-----------+
+--R                  |            |          2        2                        2
+--R                 \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R            +-----------+
+--R        +-+ |          2  +-+             2c x + b
+--R       \|2 \|- 4d f + e  \|c atanh(----------------------)
+--R                                         +--------------+
+--R                                     +-+ |   2
+--R                                   2\|c \|c x  + b x + a
+--R  /
+--R           +-----------+
+--R       +-+ |          2
+--R     f\|2 \|- 4d f + e
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 940
+t0:=(a+b*x+c*x^2)^(1/2)/(x*(d+e*x+f*x^2))
+--R 
+--R
+--R         +--------------+
+--R         |   2
+--R        \|c x  + b x + a
+--R   (1)  -----------------
+--R           3      2
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 940
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a)/d-atanh(1/2*_
+   (4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f))))*(2*(b*d-a*e)*f-(c*d-a*f)*(e-sqrt(e^2-4*d*f)))/(d*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f)))+atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(2*(b*d-a*e)*f-(c*d-a*f)*(e+sqrt(e^2-_
+   4*d*f)))/(d*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                        +-----------+
+--R                        |          2
+--R         ((- a f + c d)\|- 4d f + e   + (a e - 2b d)f + c d e)
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                      +-----------+
+--R                      |          2
+--R         ((a f - c d)\|- 4d f + e   + (a e - 2b d)f + c d e)
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2  +-+             b x + 2a
+--R            \|2 \|- 4d f + e  \|a atanh(----------------------)
+--R                                              +--------------+
+--R                                          +-+ |   2
+--R                                        2\|a \|c x  + b x + a
+--R         *
+--R             +------------------------------------------------------------+
+--R             |              +-----------+
+--R             |              |          2        2                        2
+--R            \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R             +----------------------------------------------------------+
+--R             |            +-----------+
+--R             |            |          2        2                        2
+--R            \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R             +-----------+
+--R         +-+ |          2
+--R       d\|2 \|- 4d f + e
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 940
+t0:=(a+b*x+c*x^2)^(1/2)/(x^2*(d+e*x+f*x^2))
+--R 
+--R
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R   (1)  ------------------
+--R           4      3      2
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 940
+r0:=-1/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(d*sqrt(a))+_
+   e*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))*sqrt(a)/d^2-1/2*b*_
+   e*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(d^2*sqrt(c))-_
+   1/2*(2*c*d-b*e)*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/_
+   (d^2*sqrt(c))+atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*_
+   sqrt(c)/d-sqrt(a+b*x+c*x^2)/(d*x)-f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-_
+   sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*c*d^2-_
+   b*d*(e+sqrt(e^2-4*d*f))+a*(e^2-2*d*f+e*sqrt(e^2-4*d*f)))/(d^2*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f)))+f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+_
+   sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*(c*d^2-b*d*e+a*(e^2-d*f))+_
+   (b*d-a*e)*(e+sqrt(e^2-4*d*f)))/(d^2*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                            +-----------+
+--R                            |          2
+--R           (2a e - 2b d)f x\|- 4d f + e
+--R         + 
+--R                  2          2                2
+--R           (4a d f  + (- 2a e  + 2b d e - 4c d )f)x
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|a \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                              +-----------+
+--R                              |          2
+--R           (- 2a e + 2b d)f x\|- 4d f + e
+--R         + 
+--R                  2          2                2
+--R           (4a d f  + (- 2a e  + 2b d e - 4c d )f)x
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|a \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                             +-----------+
+--R                         +-+ |          2              b x + 2a
+--R           (2a e - b d)x\|2 \|- 4d f + e  atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|a \|c x  + b x + a
+--R         + 
+--R                    +-----------+     +--------------+
+--R                +-+ |          2  +-+ |   2
+--R           - 2d\|2 \|- 4d f + e  \|a \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                +-----------+
+--R         2  +-+ |          2  +-+
+--R       2d x\|2 \|- 4d f + e  \|a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 940
+t0:=(a+b*x+c*x^2)^(1/2)/(x^3*(d+e*x+f*x^2))
+--R 
+--R
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R   (1)  ------------------
+--R           5      4      3
+--R        f x  + e x  + d x
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 940
+r0:=1/8*(b^2-4*a*c)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (a^(3/2)*d)+1/2*b*e*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (d^2*sqrt(a))-(e^2-d*f)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+_
+   c*x^2)))*sqrt(a)/d^3+1/2*b*(e^2-d*f)*atanh(1/2*(b+2*c*x)/(sqrt(c)*_
+   sqrt(a+b*x+c*x^2)))/(d^3*sqrt(c))+1/2*(2*c*d*e-b*e^2+b*d*f)*_
+   atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(d^3*sqrt(c))-_
+   e*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))*sqrt(c)/d^2+_
+   e*sqrt(a+b*x+c*x^2)/(d^2*x)-1/4*(2*a+b*x)*sqrt(a+b*x+c*x^2)/(a*d*x^2)-_
+   f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(-2*(c*d^2*e+a*e*(e^2-2*d*f)-b*d*(e^2-_
+   d*f))+(c*d^2-b*d*e+a*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/(d^3*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f)))+f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+_
+   sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(-2*(c*d^2*e+a*e*(e^2-_
+   2*d*f)-b*d*(e^2-d*f))+(c*d^2-b*d*e+a*(e^2-d*f))*(e+sqrt(e^2-4*d*f)))/_
+   (d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                                         +-----------+
+--R              2   2        2 2                    2    2 |          2
+--R           (8a d f  + (- 8a e  + 8a b d e - 8a c d )f)x \|- 4d f + e
+--R         + 
+--R                  2             2  2      2 3           2         2     2
+--R           ((- 24a d e + 16a b d )f  + (8a e  - 8a b d e  + 8a c d e)f)x
+--R      *
+--R              +----------------------------------------------------------+
+--R              |            +-----------+
+--R          +-+ |            |          2        2                        2
+--R         \|a \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                         +-----------+
+--R                2   2      2 2                    2    2 |          2
+--R           (- 8a d f  + (8a e  - 8a b d e + 8a c d )f)x \|- 4d f + e
+--R         + 
+--R                  2             2  2      2 3           2         2     2
+--R           ((- 24a d e + 16a b d )f  + (8a e  - 8a b d e  + 8a c d e)f)x
+--R      *
+--R              +------------------------------------------------------------+
+--R              |              +-----------+
+--R          +-+ |              |          2        2                        2
+--R         \|a \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                                 +-----------+
+--R                2        2 2                         2  2  2 +-+ |          2
+--R             (8a d f - 8a e  + 4a b d e + (- 4a c + b )d )x \|2 \|- 4d f + e
+--R          *
+--R                          b x + 2a
+--R             atanh(----------------------)
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|a \|c x  + b x + a
+--R         + 
+--R                                           +-----------+     +--------------+
+--R                          2         2  +-+ |          2  +-+ |   2
+--R           ((8a d e - 2b d )x - 4a d )\|2 \|- 4d f + e  \|a \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                   +-----------+
+--R           3 2 +-+ |          2  +-+
+--R       8a d x \|2 \|- 4d f + e  \|a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 940
+t0:=sqrt(-3-4*x-x^2)/(3+4*x+2*x^2)
+--R 
+--R
+--R         +-------------+
+--R         |   2
+--R        \|- x  - 4x - 3
+--R   (1)  ----------------
+--R            2
+--R          2x  + 4x + 3
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 940
+r0:=atan(sqrt(-1-x)/sqrt(3+x))-1/4*log(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/_
+   sqrt(3+x))+1/4*log(1-3*(1+x)/(3+x)+2*sqrt(-1-x)/sqrt(3+x))+atan((1-_
+   3*sqrt(-1-x)/sqrt(3+x))/sqrt(2))/sqrt(2)-atan((1+3*sqrt(-1-x)/_
+   sqrt(3+x))/sqrt(2))/sqrt(2),-1/2*asin(2+x)-1/4*%i*atanh((2*(1+%i*_
+   sqrt(2))+x*(2+%i*sqrt(2)))/(sqrt(-3-4*x-x^2)*sqrt(2*(1-2*%i*sqrt(2)))))*_
+   sqrt(1-2*%i*sqrt(2))+1/4*%i*atanh((2*(1-%i*sqrt(2))+x*(2-%i*sqrt(2)))/_
+   (sqrt(-3-4*x-x^2)*sqrt(2*(1+2*%i*sqrt(2)))))*sqrt(1+2*%i*sqrt(2))
+--R 
+--R
+--R   (2)
+--R   [
+--R                        +-----+            +-------+
+--R         1  +-+    - 2x\|x + 3  + (2x + 6)\|- x - 1
+--R         - \|2 log(---------------------------------)
+--R         4                          +-----+
+--R                            (x + 3)\|x + 3
+--R       + 
+--R                          +-----+              +-------+
+--R           1  +-+    - 2x\|x + 3  + (- 2x - 6)\|- x - 1
+--R         - - \|2 log(-----------------------------------)
+--R           4                           +-----+
+--R                               (x + 3)\|x + 3
+--R       + 
+--R                 +-----+     +-------+          +-----+     +-------+
+--R                \|x + 3  + 3\|- x - 1          \|x + 3  - 3\|- x - 1
+--R         - atan(----------------------) + atan(----------------------)
+--R                      +-+ +-----+                    +-+ +-----+
+--R                     \|2 \|x + 3                    \|2 \|x + 3
+--R       + 
+--R                   +-------+
+--R          +-+     \|- x - 1
+--R         \|2 atan(----------)
+--R                    +-----+
+--R                   \|x + 3
+--R    /
+--R        +-+
+--R       \|2
+--R     ,
+--R
+--R              +-------------+                       +-+
+--R         1    |      +-+               (%i x + 2%i)\|2  + 2x + 2
+--R       - - %i\|- 2%i\|2  + 1 atanh(--------------------------------)
+--R         4                          +-------------+ +-------------+
+--R                                    |      +-+      |   2
+--R                                   \|- 4%i\|2  + 2 \|- x  - 4x - 3
+--R     + 
+--R            +-----------+                      +-+
+--R       1    |    +-+              (%i x + 2%i)\|2  - 2x - 2      1
+--R     - - %i\|2%i\|2  + 1 atanh(------------------------------) - - asin(x + 2)
+--R       4                        +-------------+ +-----------+    2
+--R                                |   2           |    +-+
+--R                               \|- x  - 4x - 3 \|4%i\|2  + 2
+--R     ]
+--R                          Type: Tuple(Expression(Complex(Fraction(Integer))))
+--E 191
+
+--S 192 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +-------------+
+--R         |   2           +-------+ +-----+    2
+--R        \|- x  - 4x - 3 \|- x - 1 \|x + 3  + x  + 4x + 3
+--R   (3)  ------------------------------------------------
+--R                   2           +-------+ +-----+
+--R                (2x  + 4x + 3)\|- x - 1 \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 940
+t0:=x^3/((a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                         3
+--R                        x
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 940
+r0:=-1/2*b*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(c^(3/2)*f)-_
+   e*atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f^2*sqrt(c))+_
+   sqrt(a+b*x+c*x^2)/(c*f)-atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-_
+   4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*e*f-(e^2-d*f)*_
+   (e-sqrt(e^2-4*d*f)))/(f^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))+atanh(1/2*(4*a*f-b*(e+_
+   sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(2*d*e*f-(e^2-d*f)*(e+sqrt(e^2-4*d*f)))/(f^2*_
+   sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                             +-----------+
+--R                          2  |          2                   3  +-+
+--R         ((- 2c d f + 2c e )\|- 4d f + e   - 6c d e f + 2c e )\|c
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                           +-----------+
+--R                        2  |          2                   3  +-+
+--R         ((2c d f - 2c e )\|- 4d f + e   - 6c d e f + 2c e )\|c
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                              +-----------+
+--R                          +-+ |          2              2c x + b
+--R           (- b f - 2c e)\|2 \|- 4d f + e  atanh(----------------------)
+--R                                                       +--------------+
+--R                                                   +-+ |   2
+--R                                                 2\|c \|c x  + b x + a
+--R         + 
+--R                  +-----------+     +--------------+
+--R              +-+ |          2  +-+ |   2
+--R           2f\|2 \|- 4d f + e  \|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                 +-----------+
+--R           2 +-+ |          2  +-+
+--R       2c f \|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 940
+t0:=x^2/((a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                         2
+--R                        x
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 940
+r0:=atanh(1/2*(b+2*c*x)/(sqrt(c)*sqrt(a+b*x+c*x^2)))/(f*sqrt(c))-_
+   atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(e^2-2*d*f-e*sqrt(e^2-4*d*f))/(f*sqrt(2)*sqrt(e^2-_
+   4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*f-e*(e+sqrt(e^2-4*d*f)))/_
+   (f*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R              +-----------+
+--R              |          2            2  +-+
+--R         (- e\|- 4d f + e   + 2d f - e )\|c
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R            +-----------+
+--R            |          2            2  +-+
+--R         (e\|- 4d f + e   + 2d f - e )\|c
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R              +-----------+
+--R          +-+ |          2              2c x + b
+--R         \|2 \|- 4d f + e  atanh(----------------------)
+--R                                       +--------------+
+--R                                   +-+ |   2
+--R                                 2\|c \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R             +-----------+
+--R         +-+ |          2  +-+
+--R       f\|2 \|- 4d f + e  \|c
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 940
+t0:=x/((a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                        x
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 940
+r0:=atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(e-sqrt(e^2-4*d*f))/(sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/_
+   (sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(e+sqrt(e^2-4*d*f))/(sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R           +-----------+
+--R           |          2
+--R         (\|- 4d f + e   + e)
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R             +-----------+
+--R             |          2
+--R         (- \|- 4d f + e   + e)
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            +-----------+
+--R        +-+ |          2
+--R       \|2 \|- 4d f + e
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 940
+t0:=1/((a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (f x  + e x + d)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 940
+r0:=-f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*sqrt(2)/(sqrt(e^2-4*d*f)*sqrt(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))+f*atanh(1/2*(4*a*f-_
+   b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*sqrt(2)/(sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R       -
+--R                  +----------------------------------------------------------+
+--R                  |            +-----------+
+--R              +-+ |            |          2        2                        2
+--R            f\|2 \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            atanh
+--R                            +-----------+
+--R                            |          2
+--R                 (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R              /
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|2 \|c x  + b x + a
+--R                *
+--R                  +------------------------------------------------------------+
+--R                  |              +-----------+
+--R                  |              |          2        2                        2
+--R                 \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R       -
+--R                  +------------------------------------------------------------+
+--R                  |              +-----------+
+--R              +-+ |              |          2        2                        2
+--R            f\|2 \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R            atanh
+--R                            +-----------+
+--R                            |          2
+--R                 (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R              /
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|2 \|c x  + b x + a
+--R                *
+--R                  +----------------------------------------------------------+
+--R                  |            +-----------+
+--R                  |            |          2        2                        2
+--R                 \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R        +-----------+
+--R        |          2
+--R       \|- 4d f + e
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 940
+t0:=1/(x*(a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                          1
+--R   (1)  ------------------------------------
+--R                            +--------------+
+--R            3      2        |   2
+--R        (f x  + e x  + d x)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 940
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(d*sqrt(a))+_
+   f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-_
+   4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(e+sqrt(e^2-4*d*f))/(d*sqrt(2)*sqrt(e^2-_
+   4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(e-sqrt(e^2-4*d*f))/(d*sqrt(2)*sqrt(e^2-_
+   4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R              +-----------+
+--R              |          2         +-+
+--R         (- f\|- 4d f + e   + e f)\|a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R            +-----------+
+--R            |          2         +-+
+--R         (f\|- 4d f + e   + e f)\|a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R       -
+--R                 +-----------+
+--R             +-+ |          2              b x + 2a
+--R            \|2 \|- 4d f + e  atanh(----------------------)
+--R                                          +--------------+
+--R                                      +-+ |   2
+--R                                    2\|a \|c x  + b x + a
+--R         *
+--R             +------------------------------------------------------------+
+--R             |              +-----------+
+--R             |              |          2        2                        2
+--R            \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R         *
+--R             +----------------------------------------------------------+
+--R             |            +-----------+
+--R             |            |          2        2                        2
+--R            \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R             +-----------+
+--R         +-+ |          2  +-+
+--R       d\|2 \|- 4d f + e  \|a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 940
+t0:=1/(x^2*(a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R                             +--------------+
+--R            4      3      2  |   2
+--R        (f x  + e x  + d x )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 940
+r0:=1/2*b*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(a^(3/2)*d)+_
+   e*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(d^2*sqrt(a))-_
+   sqrt(a+b*x+c*x^2)/(a*d*x)+f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+_
+   2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(e^2-2*d*f-e*_
+   sqrt(e^2-4*d*f))/(d^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))-f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-_
+   sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f))/(d^2*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(f*(2*a*f-_
+   b*(e-sqrt(e^2-4*d*f)))+c*(e^2-2*d*f-e*sqrt(e^2-4*d*f))))
+--R 
+--R
+--R   (2)
+--R                   +-----------+
+--R                   |          2           2       2     +-+
+--R         (2a e f x\|- 4d f + e   + (4a d f  - 2a e f)x)\|a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                     +-----------+
+--R                     |          2           2       2     +-+
+--R         (- 2a e f x\|- 4d f + e   + (4a d f  - 2a e f)x)\|a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                             +-----------+
+--R                         +-+ |          2              b x + 2a
+--R           (2a e + b d)x\|2 \|- 4d f + e  atanh(----------------------)
+--R                                                      +--------------+
+--R                                                  +-+ |   2
+--R                                                2\|a \|c x  + b x + a
+--R         + 
+--R                    +-----------+     +--------------+
+--R                +-+ |          2  +-+ |   2
+--R           - 2d\|2 \|- 4d f + e  \|a \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                  +-----------+
+--R           2  +-+ |          2  +-+
+--R       2a d x\|2 \|- 4d f + e  \|a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 940
+t0:=1/(x^3*(a+b*x+c*x^2)^(1/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R                          1
+--R   (1)  -------------------------------------
+--R                             +--------------+
+--R            5      4      3  |   2
+--R        (f x  + e x  + d x )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 940
+r0:=-1/8*(3*b^2-4*a*c)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (a^(5/2)*d)-1/2*b*e*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (a^(3/2)*d^2)-(e^2-d*f)*atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/_
+   (d^3*sqrt(a))-1/2*sqrt(a+b*x+c*x^2)/(a*d*x^2)+3/4*b*sqrt(a+b*x+c*x^2)/_
+   (a^2*d*x)+e*sqrt(a+b*x+c*x^2)/(a*d^2*x)+f*atanh(1/2*(4*a*f+2*x*(b*f-_
+   c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*e^3-_
+   4*d*e*f-(e^2-d*f)*(e-sqrt(e^2-4*d*f)))/(d^3*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f))))*(2*e^3-4*d*e*f-(e^2-d*f)*(e+sqrt(e^2-_
+   4*d*f)))/(d^3*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                               +-----------+
+--R             2   2     2 2   2 |          2          2     2     2 3   2  +-+
+--R         ((8a d f  - 8a e f)x \|- 4d f + e   + (- 24a d e f  + 8a e f)x )\|a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                 +-----------+
+--R               2   2     2 2   2 |          2          2     2     2 3   2  +-+
+--R         ((- 8a d f  + 8a e f)x \|- 4d f + e   + (- 24a d e f  + 8a e f)x )\|a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                                +-----------+
+--R                2        2 2                        2  2  2 +-+ |          2
+--R             (8a d f - 8a e  - 4a b d e + (4a c - 3b )d )x \|2 \|- 4d f + e
+--R          *
+--R                          b x + 2a
+--R             atanh(----------------------)
+--R                         +--------------+
+--R                     +-+ |   2
+--R                   2\|a \|c x  + b x + a
+--R         + 
+--R                                           +-----------+     +--------------+
+--R                          2         2  +-+ |          2  +-+ |   2
+--R           ((8a d e + 6b d )x - 4a d )\|2 \|- 4d f + e  \|a \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R                   +-----------+
+--R         2 3 2 +-+ |          2  +-+
+--R       8a d x \|2 \|- 4d f + e  \|a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 940
+t0:=x^3/((a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R      3
+--R     x
+--R  /
+--R             4               3                     2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 940
+r0:=2*(2*a+b*x)/((b^2-4*a*c)*f*sqrt(a+b*x+c*x^2))+2*e*(b+2*c*x)/_
+   ((b^2-4*a*c)*f^2*sqrt(a+b*x+c*x^2))-2*(b^3*d*e*f+b*c*e*(c*d^2+_
+   a*(e^2-4*d*f))+2*a*c*f*(c*d^2+a*(e^2-d*f))-b^2*(c*d*e^2+a*f*(e^2-d*f))+_
+   c*(2*c^2*d^2*e+b*f*(b*d*e-a*e^2+a*d*f)+c*(2*a*e*(e^2-2*d*f)-_
+   b*d*(2*e^2-d*f)))*x)/((b^2-4*a*c)*f^2*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))*sqrt(a+b*x+c*x^2))+atanh(1/2*(4*a*f+_
+   2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(2*d*(b*d-a*e)*f+(c*d^2-b*d*e+a*(e^2-d*f))*(e-_
+   sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-_
+   2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))-atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+_
+   2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*(b*d-a*e)*f+_
+   (c*d^2-b*d*e+a*(e^2-d*f))*(e+sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-_
+   a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                    2       2          2       2  2                3
+--R               (- 4a c + a b )d f + (4a c - a b )e  + (- 4a b c + b )d e
+--R             + 
+--R                    2    2   2
+--R               (4a c  - b c)d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2        2                   3  2        2       2  3
+--R           ((- 12a c + 3a b )d e + (8a b c - 2b )d )f + (4a c - a b )e
+--R         + 
+--R                        3    2        2    2   2
+--R           (- 4a b c + b )d e  + (4a c  - b c)d e
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                  2       2            2       2  2              3
+--R               (4a c - a b )d f + (- 4a c + a b )e  + (4a b c - b )d e
+--R             + 
+--R                      2    2   2
+--R               (- 4a c  + b c)d
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R                  2        2                   3  2        2       2  3
+--R           ((- 12a c + 3a b )d e + (8a b c - 2b )d )f + (4a c - a b )e
+--R         + 
+--R                        3    2        2    2   2
+--R           (- 4a b c + b )d e  + (4a c  - b c)d e
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                2           2        2                 3         3      2
+--R           (- 2a b f + (- 4a c + 2a b )e + (6a b c - 2b )d)x - 4a f + 2a b e
+--R         + 
+--R              2        2
+--R           (4a c - 2a b )d
+--R      *
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            3     2 2  2         2         3          2 2       2     4
+--R         (4a c - a b )f  + ((- 4a b c + a b )e + (- 8a c  + 6a b c - b )d)f
+--R       + 
+--R            2 2      2   2            2    3             3    2 2  2
+--R         (4a c  - a b c)e  + (- 4a b c  + b c)d e + (4a c  - b c )d
+--R    *
+--R            +-----------+ +--------------+
+--R        +-+ |          2  |   2
+--R       \|2 \|- 4d f + e  \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 940
+t0:=x^2/((a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R      2
+--R     x
+--R  /
+--R             4               3                     2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 940
+r0:=-2*(b+2*c*x)/((b^2-4*a*c)*f*sqrt(a+b*x+c*x^2))+2*(b^3*d*f+2*a^2*c*e*f-_
+   b^2*e*(c*d+a*f)+b*c*(c*d^2+a*(e^2-3*d*f))+c*(2*c^2*d^2+b*(b*d-a*e)*f-_
+   2*c*(b*d*e-a*e^2+a*d*f))*x)/((b^2-4*a*c)*f*(c^2*d^2+f*(b^2*d-a*b*e+_
+   a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(a+b*x+c*x^2))-f*atanh(1/2*_
+   (4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/_
+   (sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*_
+   sqrt(e^2-4*d*f))))*(2*d*(c*d-a*f)-(b*d-a*e)*(e-sqrt(e^2-4*d*f)))/_
+   ((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*_
+   sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f)))+f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+_
+   sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*(c*d-a*f)-(b*d-a*e)*_
+   (e+sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-_
+   2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                                +-----------+
+--R                 2       2                3     |          2
+--R           ((- 4a c + a b )e + (4a b c - b )d)f\|- 4d f + e
+--R         + 
+--R              2        2    2
+--R           (8a c - 2a b )d f
+--R         + 
+--R                 2       2  2              3              2     2   2
+--R           ((- 4a c + a b )e  + (4a b c - b )d e + (- 8a c  + 2b c)d )f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                +-----------+
+--R               2       2                  3     |          2
+--R           ((4a c - a b )e + (- 4a b c + b )d)f\|- 4d f + e
+--R         + 
+--R              2        2    2
+--R           (8a c - 2a b )d f
+--R         + 
+--R                 2       2  2              3              2     2   2
+--R           ((- 4a c + a b )e  + (4a b c - b )d e + (- 8a c  + 2b c)d )f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R             2                        2     2          2        2
+--R         ((4a c f - 2a b c e + (- 4a c  + 2b c)d)x + 2a b f - 4a c e + 2a b c d)
+--R      *
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            3     2 2  2         2         3          2 2       2     4
+--R         (4a c - a b )f  + ((- 4a b c + a b )e + (- 8a c  + 6a b c - b )d)f
+--R       + 
+--R            2 2      2   2            2    3             3    2 2  2
+--R         (4a c  - a b c)e  + (- 4a b c  + b c)d e + (4a c  - b c )d
+--R    *
+--R            +-----------+ +--------------+
+--R        +-+ |          2  |   2
+--R       \|2 \|- 4d f + e  \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 940
+t0:=x/((a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R     x
+--R  /
+--R             4               3                     2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 940
+r0:=2*(a*(2*c^2*d+b^2*f-c*(b*e+2*a*f))+c*(b*c*d-2*a*c*e+a*b*f)*x)/_
+   ((b^2-4*a*c)*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*_
+   sqrt(a+b*x+c*x^2))+f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-_
+   b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*(c*e-b*f)-(c*d-a*f)*_
+   (e-sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-_
+   2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))-f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+_
+   2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-_
+   2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*d*(c*e-b*f)-_
+   (c*d-a*f)*(e+sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                                  +-----------+
+--R               2       2  2          2    2       |          2
+--R           ((4a c - a b )f  + (- 4a c  + b c)d f)\|- 4d f + e
+--R         + 
+--R               2       2                   3    2        2    2
+--R           ((4a c - a b )e + (- 8a b c + 2b )d)f  + (4a c  - b c)d e f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                  +-----------+
+--R                 2       2  2        2    2       |          2
+--R           ((- 4a c + a b )f  + (4a c  - b c)d f)\|- 4d f + e
+--R         + 
+--R               2       2                   3    2        2    2
+--R           ((4a c - a b )e + (- 8a b c + 2b )d)f  + (4a c  - b c)d e f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                            2        2         2        2                    2
+--R         ((- 2a b c f + 4a c e - 2b c d)x + (4a c - 2a b )f + 2a b c e - 4a c d)
+--R      *
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            3     2 2  2         2         3          2 2       2     4
+--R         (4a c - a b )f  + ((- 4a b c + a b )e + (- 8a c  + 6a b c - b )d)f
+--R       + 
+--R            2 2      2   2            2    3             3    2 2  2
+--R         (4a c  - a b c)e  + (- 4a b c  + b c)d e + (4a c  - b c )d
+--R    *
+--R            +-----------+ +--------------+
+--R        +-+ |          2  |   2
+--R       \|2 \|- 4d f + e  \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 940
+t0:=1/((a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R             4               3                     2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x + a d)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 940
+r0:=2*(b^2*c*e-2*a*c^2*e-b^3*f-b*c*(c*d-3*a*f)-c*(2*c^2*d-b*c*e+b^2*f-_
+   2*a*c*f)*x)/((b^2-4*a*c)*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*_
+   (e^2-2*d*f)))*sqrt(a+b*x+c*x^2))-f*atanh(1/2*(4*a*f+2*x*(b*f-c*(e-_
+   sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*sqrt(a+b*x+c*x^2)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f))))*(c*(e^2-_
+   2*d*f+e*sqrt(e^2-4*d*f))+f*(2*a*f-b*(e+sqrt(e^2-4*d*f))))/((c^2*d^2+_
+   f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*_
+   sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-_
+   f*atanh(1/2*(4*a*f-b*(e+sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-_
+   4*d*f))))/(sqrt(2)*sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+_
+   2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*(2*(f*(b*e-a*f)-c*(e^2-d*f))+_
+   (c*e-b*f)*(e+sqrt(e^2-4*d*f)))/((c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                                  +-----------+
+--R                         3  2        2    2       |          2
+--R           ((- 4a b c + b )f  + (4a c  - b c)e f)\|- 4d f + e
+--R         + 
+--R                2        2  3               3          2     2     2
+--R           (- 8a c + 2a b )f  + ((4a b c - b )e + (8a c  - 2b c)d)f
+--R         + 
+--R                  2    2   2
+--R           (- 4a c  + b c)e f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                                                  +-----------+
+--R                       3  2          2    2       |          2
+--R           ((4a b c - b )f  + (- 4a c  + b c)e f)\|- 4d f + e
+--R         + 
+--R                2        2  3               3          2     2     2
+--R           (- 8a c + 2a b )f  + ((4a b c - b )e + (8a c  - 2b c)d)f
+--R         + 
+--R                  2    2   2
+--R           (- 4a c  + b c)e f
+--R      *
+--R          +--------------+
+--R          |   2
+--R         \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                   2     2          2      3                    3
+--R           ((- 4a c  + 2b c)f - 2b c e + 4c d)x + (- 6a b c + 2b )f
+--R         + 
+--R                2     2          2
+--R           (4a c  - 2b c)e + 2b c d
+--R      *
+--R              +-----------+
+--R          +-+ |          2
+--R         \|2 \|- 4d f + e
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            3     2 2  2         2         3          2 2       2     4
+--R         (4a c - a b )f  + ((- 4a b c + a b )e + (- 8a c  + 6a b c - b )d)f
+--R       + 
+--R            2 2      2   2            2    3             3    2 2  2
+--R         (4a c  - a b c)e  + (- 4a b c  + b c)d e + (4a c  - b c )d
+--R    *
+--R            +-----------+ +--------------+
+--R        +-+ |          2  |   2
+--R       \|2 \|- 4d f + e  \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 940
+t0:=1/(x*(a+b*x+c*x^2)^(3/2)*(d+e*x+f*x^2))
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R             5               4                     3               2
+--R       (c f x  + (b f + c e)x  + (a f + b e + c d)x  + (a e + b d)x  + a d x)
+--R    *
+--R        +--------------+
+--R        |   2
+--R       \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 940
+r0:=-atanh(1/2*(2*a+b*x)/(sqrt(a)*sqrt(a+b*x+c*x^2)))/(a^(3/2)*d)+_
+   2*(b^2-2*a*c+b*c*x)/(a*(b^2-4*a*c)*d*sqrt(a+b*x+c*x^2))+2*(b*(c^2*_
+   d*e-b*c*e^2+b*f*(b*e-a*f))-2*a*c*(f*(b*e-a*f)-c*(e^2-d*f))+c*(2*c^2*d*e+_
+   b*f*(b*e-a*f)-b*c*(e^2+d*f))*x)/((b^2-4*a*c)*d*(c^2*d^2+f*(b^2*d-a*b*e+_
+   a^2*f)-c*(b*d*e-a*(e^2-2*d*f)))*sqrt(a+b*x+c*x^2))+f*atanh(1/2*(4*a*f+_
+   2*x*(b*f-c*(e-sqrt(e^2-4*d*f)))-b*(e-sqrt(e^2-4*d*f)))/(sqrt(2)*_
+   sqrt(a+b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-_
+   4*d*f))))*(-2*(f*(b*e^2-b*d*f-a*e*f)-c*(e^3-2*d*e*f))+(f*(b*e-a*f)-_
+   c*(e^2-d*f))*(e-sqrt(e^2-4*d*f)))/(d*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-_
+   c*(b*d*e-a*(e^2-2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-_
+   b*e*f+2*a*f^2-(c*e-b*f)*sqrt(e^2-4*d*f)))-f*atanh(1/2*(4*a*f-b*(e+_
+   sqrt(e^2-4*d*f))+2*x*(b*f-c*(e+sqrt(e^2-4*d*f))))/(sqrt(2)*sqrt(a+_
+   b*x+c*x^2)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+(c*e-b*f)*sqrt(e^2-4*d*f))))*_
+   (-2*(f*(b*e^2-b*d*f-a*e*f)-c*(e^3-2*d*e*f))+(f*(b*e-a*f)-c*(e^2-d*f))*_
+   (e+sqrt(e^2-4*d*f)))/(d*(c^2*d^2+f*(b^2*d-a*b*e+a^2*f)-c*(b*d*e-a*(e^2-_
+   2*d*f)))*sqrt(2)*sqrt(e^2-4*d*f)*sqrt(c*e^2-2*c*d*f-b*e*f+2*a*f^2+_
+   (c*e-b*f)*sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                    3     2 2  3       2         3        2 2      2     2
+--R               (- 4a c + a b )f  + ((4a b c - a b )e + (4a c  - a b c)d)f
+--R             + 
+--R                    2 2      2   2
+--R               (- 4a c  + a b c)e f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R               3     2 2        2          3    3
+--R           ((4a c - a b )e + (8a b c - 2a b )d)f
+--R         + 
+--R               2         3  2         2 2       2       2      2 2      2   3
+--R         ((- 4a b c + a b )e  + (- 12a c  + 3a b c)d e)f  + (4a c  - a b c)e f
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (- 2b f + 2c e)x - 4a f + b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +------------------------------------------------------------+
+--R                 |              +-----------+
+--R                 |              |          2        2                        2
+--R                \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                  3     2 2  3         2         3          2 2      2     2
+--R               (4a c - a b )f  + ((- 4a b c + a b )e + (- 4a c  + a b c)d)f
+--R             + 
+--R                  2 2      2   2
+--R               (4a c  - a b c)e f
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4d f + e
+--R         + 
+--R               3     2 2        2          3    3
+--R           ((4a c - a b )e + (8a b c - 2a b )d)f
+--R         + 
+--R               2         3  2         2 2       2       2      2 2      2   3
+--R         ((- 4a b c + a b )e  + (- 12a c  + 3a b c)d e)f  + (4a c  - a b c)e f
+--R      *
+--R              +--------------+
+--R          +-+ |   2
+--R         \|a \|c x  + b x + a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R         atanh
+--R                         +-----------+
+--R                         |          2
+--R              (2c x + b)\|- 4d f + e   + (2b f - 2c e)x + 4a f - b e
+--R           /
+--R                      +--------------+
+--R                  +-+ |   2
+--R                2\|2 \|c x  + b x + a
+--R             *
+--R                 +----------------------------------------------------------+
+--R                 |            +-----------+
+--R                 |            |          2        2                        2
+--R                \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R     + 
+--R                    3     2 2  2       2         3        2 2       2     4
+--R               (- 4a c + a b )f  + ((4a b c - a b )e + (8a c  - 6a b c + b )d)f
+--R             + 
+--R                    2 2      2   2          2    3               3    2 2  2
+--R               (- 4a c  + a b c)e  + (4a b c  - b c)d e + (- 4a c  + b c )d
+--R          *
+--R                  +-----------+ +--------------+
+--R              +-+ |          2  |   2                        b x + 2a
+--R             \|2 \|- 4d f + e  \|c x  + b x + a atanh(----------------------)
+--R                                                            +--------------+
+--R                                                        +-+ |   2
+--R                                                      2\|a \|c x  + b x + a
+--R         + 
+--R                       2     3               3     2 2           3 2
+--R               ((6a b c  - 2b c)d f + (- 4a c  + 2b c )d e - 2b c d )x
+--R             + 
+--R                    2 2       2      4                2     3
+--R               (- 4a c  + 8a b c - 2b )d f + (- 6a b c  + 2b c)d e
+--R             + 
+--R                    3     2 2  2
+--R               (4a c  - 2b c )d
+--R          *
+--R                  +-----------+
+--R              +-+ |          2  +-+
+--R             \|2 \|- 4d f + e  \|a
+--R      *
+--R          +------------------------------------------------------------+
+--R          |              +-----------+
+--R          |              |          2        2                        2
+--R         \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R      *
+--R          +----------------------------------------------------------+
+--R          |            +-----------+
+--R          |            |          2        2                        2
+--R         \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R  /
+--R            4     3 2    2
+--R         (4a c - a b )d f
+--R       + 
+--R               3       2 3            3 2     2 2       4  2
+--R         ((- 4a b c + a b )d e + (- 8a c  + 6a b c - a b )d )f
+--R       + 
+--R            3 2    2 2     2        2   2      3   2       2 3      2 2  3
+--R         (4a c  - a b c)d e  + (- 4a b c  + a b c)d e + (4a c  - a b c )d
+--R    *
+--R            +-----------+     +--------------+
+--R        +-+ |          2  +-+ |   2
+--R       \|2 \|- 4d f + e  \|a \|c x  + b x + a
+--R    *
+--R        +------------------------------------------------------------+
+--R        |              +-----------+
+--R        |              |          2        2                        2
+--R       \|(- b f + c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R    *
+--R        +----------------------------------------------------------+
+--R        |            +-----------+
+--R        |            |          2        2                        2
+--R       \|(b f - c e)\|- 4d f + e   + 2a f  + (- b e - 2c d)f + c e
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 940
+t0:=sqrt(-1+x^2)/sqrt(-1+x^4)
+--R 
+--R
+--R         +------+
+--R         | 2
+--R        \|x  - 1
+--R   (1)  ---------
+--R         +------+
+--R         | 4
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 940
+r0:=asinh(x)*sqrt(-1+x^2)*sqrt(1+x^2)/sqrt(-1+x^4)
+--R 
+--R
+--R                 +------+ +------+
+--R                 | 2      | 2
+--R        asinh(x)\|x  - 1 \|x  + 1
+--R   (2)  --------------------------
+--R                  +------+
+--R                  | 4
+--R                 \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 940
+t0:=sqrt(1+x^2)/sqrt(-1+x^4)
+--R 
+--R
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R   (1)  ---------
+--R         +------+
+--R         | 4
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 940
+r0:=-asin(x)*sqrt(-1+x^4)/sqrt(1-x^4),atanh(x/sqrt(-1+x^2))*sqrt(-1+x^2)*_
+   sqrt(1+x^2)/sqrt(-1+x^4)
+--R 
+--R
+--R                             +------+ +------+
+--R                             | 2      | 2               x
+--R                            \|x  - 1 \|x  + 1 atanh(---------)
+--R                   +------+                          +------+
+--R                   | 4                               | 2
+--R           asin(x)\|x  - 1                          \|x  - 1
+--R   (2)  [- ----------------,----------------------------------]
+--R               +--------+                 +------+
+--R               |   4                      | 4
+--R              \|- x  + 1                 \|x  - 1
+--R                                             Type: Tuple(Expression(Integer))
+--E 233
+
+--S 234 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +--------+ +--------+ +------+
+--R         |   4      |   2      | 2         4
+--R        \|- x  + 1 \|- x  + 1 \|x  + 1  + x  - 1
+--R   (3)  ----------------------------------------
+--R              +--------+ +--------+ +------+
+--R              |   4      |   2      | 4
+--R             \|- x  + 1 \|- x  + 1 \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 940
+t0:=(-sqrt(-1+x^2)+sqrt(1+x^2))/sqrt(-1+x^4)
+--R 
+--R
+--R         +------+    +------+
+--R         | 2         | 2
+--R        \|x  + 1  - \|x  - 1
+--R   (1)  ---------------------
+--R               +------+
+--R               | 4
+--R              \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 940
+r0:=-asin(x)*sqrt(-1+x^4)/(sqrt(1-x^2)*sqrt(1+x^2))+asinh(x)*sqrt(-1+x^2)*_
+   sqrt(-1+x^4)/((1-x^2)*sqrt(1+x^2)),-asinh(x)*sqrt(-1+x^2)*sqrt(1+x^2)/_
+   sqrt(-1+x^4)+atanh(x/sqrt(-1+x^2))*sqrt(-1+x^2)*sqrt(1+x^2)/sqrt(-1+x^4)
+--R 
+--R
+--R   (2)
+--R                +--------+ +------+                      +------+
+--R                |   2      | 2            2              | 4
+--R    (- asinh(x)\|- x  + 1 \|x  - 1  + (- x  + 1)asin(x))\|x  - 1
+--R   [-------------------------------------------------------------,
+--R                              +--------+ +------+
+--R                       2      |   2      | 2
+--R                     (x  - 1)\|- x  + 1 \|x  + 1
+--R     +------+ +------+                            +------+ +------+
+--R     | 2      | 2               x                 | 2      | 2
+--R    \|x  - 1 \|x  + 1 atanh(---------) - asinh(x)\|x  - 1 \|x  + 1
+--R                             +------+
+--R                             | 2
+--R                            \|x  - 1
+--R    ---------------------------------------------------------------]
+--R                                +------+
+--R                                | 4
+--R                               \|x  - 1
+--R                                             Type: Tuple(Expression(Integer))
+--E 236
+
+--S 237 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 940
+t0:=x/(1-x^2)^5
+--R 
+--R
+--R                          x
+--R   (1)  - ---------------------------------
+--R           10     8      6      4     2
+--R          x   - 5x  + 10x  - 10x  + 5x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 238
+
+--S 239 of 940
+r0:=1/8/(1-x^2)^4
+--R 
+--R
+--R                    1
+--R                    -
+--R                    8
+--R   (2)  ------------------------
+--R         8     6     4     2
+--R        x  - 4x  + 6x  - 4x  + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 239
+
+--S 240 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 940
+t0:=(-1/32)/(-1+x)^5+3/64/(-1+x)^4+(-5/128)/(-1+x)^3+5/256/(-1+x)^2+_
+   (-1/32)/(1+x)^5+(-3/64)/(1+x)^4+(-5/128)/(1+x)^3+(-5/256)/(1+x)^2
+--R 
+--R
+--R                          x
+--R   (1)  - ---------------------------------
+--R           10     8      6      4     2
+--R          x   - 5x  + 10x  - 10x  + 5x  - 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 241
+
+--S 242 of 940
+r0:=1/8/(1-x^2)^4,1/128/(1-x)^4+1/64/(1-x)^3+5/256/(1-x)^2+5/256/(1-x)+_
+   1/128/(1+x)^4+1/64/(1+x)^3+5/256/(1+x)^2+5/256/(1+x)
+--R 
+--R
+--R                     1                        1
+--R                     -                        -
+--R                     8                        8
+--R   (2)  [------------------------,------------------------]
+--R          8     6     4     2      8     6     4     2
+--R         x  - 4x  + 6x  - 4x  + 1 x  - 4x  + 6x  - 4x  + 1
+--R                         Type: Tuple(Fraction(Polynomial(Fraction(Integer))))
+--E 242
+
+--S 243 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 940
+t0:=(2+x)/(-1+2*x+x^2)
+--R 
+--R
+--R           x + 2
+--R   (1)  -----------
+--R         2
+--R        x  + 2x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 244
+
+--S 245 of 940
+r0:=1/4*log(1+x+sqrt(2))*(2-sqrt(2))+1/4*log(1+x-sqrt(2))*(2+sqrt(2))
+--R 
+--R
+--R            +-+          +-+              +-+            +-+
+--R        (- \|2  + 2)log(\|2  + x + 1) + (\|2  + 2)log(- \|2  + x + 1)
+--R   (2)  -------------------------------------------------------------
+--R                                      4
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 940
+t0:=(-4+x^2)/(2-5*x+x^3)
+--R 
+--R
+--R           x + 2
+--R   (1)  -----------
+--R         2
+--R        x  + 2x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 247
+
+--S 248 of 940
+r0:=1/4*log(1+x+sqrt(2))*(2-sqrt(2))+1/4*log(1+x-sqrt(2))*(2+sqrt(2))
+--R 
+--R
+--R            +-+          +-+              +-+            +-+
+--R        (- \|2  + 2)log(\|2  + x + 1) + (\|2  + 2)log(- \|2  + x + 1)
+--R   (2)  -------------------------------------------------------------
+--R                                      4
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 940
+t0:=(1+2*x^8)/(x*(1+x^8)^(3/2))
+--R 
+--R
+--R               8
+--R             2x  + 1
+--R   (1)  -----------------
+--R                 +------+
+--R          9      | 8
+--R        (x  + x)\|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 940
+r0:=-1/4*atanh(sqrt(1+x^8))+(-1/4)/sqrt(1+x^8)
+--R 
+--R
+--R           +------+       +------+
+--R           | 8            | 8
+--R        - \|x  + 1 atanh(\|x  + 1 ) - 1
+--R   (2)  -------------------------------
+--R                     +------+
+--R                     | 8
+--R                   4\|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 940
+t0:=(1+2*x^8)*sqrt(1+x^8)/(x+2*x^9+x^17)
+--R 
+--R
+--R                  +------+
+--R           8      | 8
+--R        (2x  + 1)\|x  + 1
+--R   (1)  ------------------
+--R            17     9
+--R           x   + 2x  + x
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 940
+r0:=-1/4*atanh(sqrt(1+x^8))+(-1/4)/sqrt(1+x^8)
+--R 
+--R
+--R           +------+       +------+
+--R           | 8            | 8
+--R        - \|x  + 1 atanh(\|x  + 1 ) - 1
+--R   (2)  -------------------------------
+--R                     +------+
+--R                     | 8
+--R                   4\|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 940
+t0:=1-9*x^2+x/sqrt(1-9*x^2)
+--R 
+--R
+--R                    +---------+
+--R             2      |    2
+--R        (- 9x  + 1)\|- 9x  + 1  + x
+--R   (1)  ---------------------------
+--R                 +---------+
+--R                 |    2
+--R                \|- 9x  + 1
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 940
+r0:=x-3*x^3-1/9*sqrt(1-9*x^2)
+--R 
+--R
+--R           +---------+
+--R           |    2           3
+--R        - \|- 9x  + 1  - 27x  + 9x
+--R   (2)  --------------------------
+--R                     9
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 940
+t0:=(x+(1-9*x^2)^(3/2))/sqrt(1-9*x^2)
+--R 
+--R
+--R                    +---------+
+--R             2      |    2
+--R        (- 9x  + 1)\|- 9x  + 1  + x
+--R   (1)  ---------------------------
+--R                 +---------+
+--R                 |    2
+--R                \|- 9x  + 1
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 940
+r0:=x-3*x^3-1/9*sqrt(1-9*x^2)
+--R 
+--R
+--R           +---------+
+--R           |    2           3
+--R        - \|- 9x  + 1  - 27x  + 9x
+--R   (2)  --------------------------
+--R                     9
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 940
+t0:=(x-3*sqrt(x))^(2/3)*(-3+2*sqrt(x))/sqrt(x)
+--R 
+--R
+--R                    +-----------+2
+--R           +-+     3|    +-+
+--R        (2\|x  - 3)\|- 3\|x  + x
+--R   (1)  --------------------------
+--R                    +-+
+--R                   \|x
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 940
+r0:=6/5*(x-3*sqrt(x))^(5/3)
+--R 
+--R
+--R                        +-----------+2
+--R              +-+      3|    +-+
+--R        (- 18\|x  + 6x)\|- 3\|x  + x
+--R   (2)  ------------------------------
+--R                       5
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 940
+t0:=(9+2*x-9*sqrt(x))/(x-3*sqrt(x))^(1/3)
+--R 
+--R
+--R            +-+
+--R        - 9\|x  + 2x + 9
+--R   (1)  ----------------
+--R          +-----------+
+--R         3|    +-+
+--R         \|- 3\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 940
+r0:=6/5*(x-3*sqrt(x))^(5/3)
+--R 
+--R
+--R                        +-----------+2
+--R              +-+      3|    +-+
+--R        (- 18\|x  + 6x)\|- 3\|x  + x
+--R   (2)  ------------------------------
+--R                       5
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 940
+t0:=2/(-1+4*x^2)
+--R 
+--R
+--R           2
+--R   (1)  -------
+--R          2
+--R        4x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 268
+
+--S 269 of 940
+r0:=-atanh(2*x)
+--R 
+--R
+--R   (2)  - atanh(2x)
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 940
+t0:=1/(-1+2*x)+(-1)/(1+2*x)
+--R 
+--R
+--R           2
+--R   (1)  -------
+--R          2
+--R        4x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 271
+
+--S 272 of 940
+r0:=1/2*log(1-2*x)-1/2*log(1+2*x)
+--R 
+--R
+--R        - log(2x + 1) + log(- 2x + 1)
+--R   (2)  -----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 940
+t0:=1/sqrt(4-9*x^2)
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         +---------+
+--R         |    2
+--R        \|- 9x  + 4
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 940
+r0:=1/3*asin(3/2*x)
+--R 
+--R
+--R             3x
+--R        asin(--)
+--R              2
+--R   (2)  --------
+--R            3
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 940
+t0:=1/(sqrt(2-3*x)*sqrt(2+3*x))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +--------+ +------+
+--R        \|- 3x + 2 \|3x + 2
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 940
+r0:=1/3*asin(3/2*x)
+--R 
+--R
+--R             3x
+--R        asin(--)
+--R              2
+--R   (2)  --------
+--R            3
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                                  +---------+
+--R           +--------+ +------+    |    2
+--R        - \|- 3x + 2 \|3x + 2  + \|- 9x  + 4
+--R   (3)  -------------------------------------
+--R            +---------+
+--R            |    2      +--------+ +------+
+--R           \|- 9x  + 4 \|- 3x + 2 \|3x + 2
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 940
+t0:=1/sqrt((2-3*x)*(2+3*x))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         +---------+
+--R         |    2
+--R        \|- 9x  + 4
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 940
+r0:=1/3*asin(3/2*x)
+--R 
+--R
+--R             3x
+--R        asin(--)
+--R              2
+--R   (2)  --------
+--R            3
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 940
+t0:=1/(sqrt(3-x)*sqrt(5+x))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +-------+ +-----+
+--R        \|- x + 3 \|x + 5
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 940
+r0:=-asin(1/4*(-1-x))
+--R 
+--R
+--R             x + 1
+--R   (2)  asin(-----)
+--R               4
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                                +--------------+
+--R           +-------+ +-----+    |   2
+--R        - \|- x + 3 \|x + 5  + \|- x  - 2x + 15
+--R   (3)  ----------------------------------------
+--R            +--------------+
+--R            |   2            +-------+ +-----+
+--R           \|- x  - 2x + 15 \|- x + 3 \|x + 5
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 940
+t0:=1/sqrt((3-x)*(5+x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|- x  - 2x + 15
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 940
+r0:=-asin(1/4*(-1-x))
+--R 
+--R
+--R             x + 1
+--R   (2)  asin(-----)
+--R               4
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 940
+t0:=1/sqrt(15-2*x-x^2)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|- x  - 2x + 15
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 940
+r0:=-asin(1/4*(-1-x))
+--R 
+--R
+--R             x + 1
+--R   (2)  asin(-----)
+--R               4
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 940
+t0:=1/(sqrt(-3-x)*sqrt(5+x))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +-------+ +-----+
+--R        \|- x - 3 \|x + 5
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 940
+r0:=asin(4+x)
+--R 
+--R
+--R   (2)  asin(x + 4)
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                                +--------------+
+--R           +-------+ +-----+    |   2
+--R        - \|- x - 3 \|x + 5  + \|- x  - 8x - 15
+--R   (3)  ----------------------------------------
+--R            +--------------+
+--R            |   2            +-------+ +-----+
+--R           \|- x  - 8x - 15 \|- x - 3 \|x + 5
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 940
+t0:=1/sqrt((-3-x)*(5+x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|- x  - 8x - 15
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 940
+r0:=asin(4+x)
+--R 
+--R
+--R   (2)  asin(x + 4)
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 940
+t0:=1/sqrt(-15-8*x-x^2)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         +--------------+
+--R         |   2
+--R        \|- x  - 8x - 15
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 940
+r0:=asin(4+x)
+--R 
+--R
+--R   (2)  asin(x + 4)
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 940
+t0:=1-sqrt(x)
+--R 
+--R
+--R           +-+
+--R   (1)  - \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 940
+r0:=x-2/3*x^(3/2)
+--R 
+--R
+--R             +-+
+--R        - 2x\|x  + 3x
+--R   (2)  -------------
+--R              3
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 940
+t0:=(1-x)/(1+sqrt(x))
+--R 
+--R
+--R         - x + 1
+--R   (1)  --------
+--R         +-+
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 940
+r0:=x-2/3*x^(3/2)
+--R 
+--R
+--R             +-+
+--R        - 2x\|x  + 3x
+--R   (2)  -------------
+--R              3
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 940
+t0:=sqrt(1/(1-x^2))
+--R 
+--R
+--R         +--------+
+--R         |     1
+--R   (1)   |- ------
+--R         |   2
+--R        \|  x  - 1
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 940
+r0:=asin(x)*sqrt(1/(1-x^2))*sqrt(1-x^2)
+--R 
+--R
+--R                +--------+ +--------+
+--R                |   2      |     1
+--R   (2)  asin(x)\|- x  + 1  |- ------
+--R                           |   2
+--R                          \|  x  - 1
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 940
+t0:=sqrt((1+x^2)/(1-x^4))
+--R 
+--R
+--R         +--------+
+--R         |     1
+--R   (1)   |- ------
+--R         |   2
+--R        \|  x  - 1
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 940
+r0:=asin(x)*sqrt(1/(1-x^2))*sqrt(1-x^2)
+--R 
+--R
+--R                +--------+ +--------+
+--R                |   2      |     1
+--R   (2)  asin(x)\|- x  + 1  |- ------
+--R                           |   2
+--R                          \|  x  - 1
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 940
+t0:=sqrt(1/(-1+x^2))
+--R 
+--R
+--R         +------+
+--R         |   1
+--R   (1)   |------
+--R         | 2
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 940
+r0:=atanh(x/sqrt(-1+x^2))*sqrt(1/(-1+x^2))*sqrt(-1+x^2)
+--R 
+--R
+--R         +------+ +------+
+--R         |   1    | 2               x
+--R   (2)   |------ \|x  - 1 atanh(---------)
+--R         | 2                     +------+
+--R        \|x  - 1                 | 2
+--R                                \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 940
+t0:=sqrt((1+x^2)/(-1+x^4))
+--R 
+--R
+--R         +------+
+--R         |   1
+--R   (1)   |------
+--R         | 2
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 940
+r0:=atanh(x/sqrt(-1+x^2))*sqrt(1/(-1+x^2))*sqrt(-1+x^2)
+--R 
+--R
+--R         +------+ +------+
+--R         |   1    | 2               x
+--R   (2)   |------ \|x  - 1 atanh(---------)
+--R         | 2                     +------+
+--R        \|x  - 1                 | 2
+--R                                \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 940
+t0:=(1+x^6)/(-1+x^6)
+--R 
+--R
+--R         6
+--R        x  + 1
+--R   (1)  ------
+--R         6
+--R        x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 319
+
+--S 320 of 940
+r0:=x-2/3*atanh(x)+1/6*log(1-x+x^2)-1/6*log(1+x+x^2)+_
+   atan((1-2*x)/sqrt(3))/sqrt(3)-atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          +-+     2             +-+     2              +-+
+--R       - \|3 log(x  + x + 1) + \|3 log(x  - x + 1) - 4\|3 atanh(x)
+--R     + 
+--R                        +-+                   +-+
+--R               (2x + 1)\|3           (2x - 1)\|3        +-+
+--R       - 6atan(------------) - 6atan(------------) + 6x\|3
+--R                     3                     3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 940
+t0:=(1/x^3+x^3)/((-1)/x^3+x^3)
+--R 
+--R
+--R         6
+--R        x  + 1
+--R   (1)  ------
+--R         6
+--R        x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 322
+
+--S 323 of 940
+r0:=x-2/3*atanh(x)+1/6*log(1-x+x^2)-1/6*log(1+x+x^2)+_
+   atan((1-2*x)/sqrt(3))/sqrt(3)-atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          +-+     2             +-+     2              +-+
+--R       - \|3 log(x  + x + 1) + \|3 log(x  - x + 1) - 4\|3 atanh(x)
+--R     + 
+--R                        +-+                   +-+
+--R               (2x + 1)\|3           (2x - 1)\|3        +-+
+--R       - 6atan(------------) - 6atan(------------) + 6x\|3
+--R                     3                     3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+)clear all
+
+--S 325 of 940
+t0:=1/sqrt(1-x)
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R         +-------+
+--R        \|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 940
+r0:=-2*sqrt(1-x)
+--R 
+--R
+--R            +-------+
+--R   (2)  - 2\|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 940
+t0:=sqrt(1+x)/sqrt(1-x^2)
+--R 
+--R
+--R           +-----+
+--R          \|x + 1
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 940
+r0:=-2*sqrt(1-x)
+--R 
+--R
+--R            +-------+
+--R   (2)  - 2\|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                              +--------+
+--R         +-------+ +-----+    |   2
+--R        \|- x + 1 \|x + 1  - \|- x  + 1
+--R   (3)  --------------------------------
+--R               +--------+
+--R               |   2      +-------+
+--R              \|- x  + 1 \|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 940
+t0:=1/sqrt(1+x)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R         +-----+
+--R        \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 940
+r0:=2*sqrt(1+x)
+--R 
+--R
+--R          +-----+
+--R   (2)  2\|x + 1
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 940
+t0:=sqrt(1-x)/sqrt(1-x^2)
+--R 
+--R
+--R          +-------+
+--R         \|- x + 1
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 940
+r0:=2*sqrt(1+x)
+--R 
+--R
+--R          +-----+
+--R   (2)  2\|x + 1
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                              +--------+
+--R         +-------+ +-----+    |   2
+--R        \|- x + 1 \|x + 1  - \|- x  + 1
+--R   (3)  --------------------------------
+--R                +--------+
+--R                |   2      +-----+
+--R               \|- x  + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 940
+t0:=sqrt(1-x)
+--R 
+--R
+--R         +-------+
+--R   (1)  \|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 940
+r0:=-2/3*(1-x)^(3/2)
+--R 
+--R
+--R                 +-------+
+--R        (2x - 2)\|- x + 1
+--R   (2)  ------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 940
+t0:=sqrt(1-x^2)/sqrt(1+x)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R   (1)  -----------
+--R           +-----+
+--R          \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 940
+r0:=-2/3*(1-x)^(3/2)
+--R 
+--R
+--R                 +-------+
+--R        (2x - 2)\|- x + 1
+--R   (2)  ------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                           +--------+
+--R                +-----+    |   2      +-------+
+--R        (x - 1)\|x + 1  + \|- x  + 1 \|- x + 1
+--R   (3)  ---------------------------------------
+--R                    +-------+ +-----+
+--R                   \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 940
+t0:=sqrt(1+x)
+--R 
+--R
+--R         +-----+
+--R   (1)  \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 940
+r0:=2/3*(1+x)^(3/2)
+--R 
+--R
+--R                 +-----+
+--R        (2x + 2)\|x + 1
+--R   (2)  ----------------
+--R                3
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 940
+t0:=sqrt(1-x^2)/sqrt(1-x)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R   (1)  -----------
+--R          +-------+
+--R         \|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 940
+r0:=2/3*(1+x)^(3/2)
+--R 
+--R
+--R                 +-----+
+--R        (2x + 2)\|x + 1
+--R   (2)  ----------------
+--R                3
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +--------+
+--R         |   2      +-----+             +-------+
+--R        \|- x  + 1 \|x + 1  + (- x - 1)\|- x + 1
+--R   (3)  -----------------------------------------
+--R                     +-------+ +-----+
+--R                    \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 940
+t0:=sqrt(2+3*x)/sqrt(1+x)
+--R 
+--R
+--R         +------+
+--R        \|3x + 2
+--R   (1)  ---------
+--R          +-----+
+--R         \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 940
+r0:=-asinh(sqrt(2+3*x))/sqrt(3)+sqrt(1+x)*sqrt(2+3*x)
+--R 
+--R
+--R                 +------+     +-+ +-----+ +------+
+--R        - asinh(\|3x + 2 ) + \|3 \|x + 1 \|3x + 2
+--R   (2)  ------------------------------------------
+--R                            +-+
+--R                           \|3
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R            +------+    +-+ +-----+
+--R         - \|3x + 3  + \|3 \|x + 1
+--R   (3)  ---------------------------
+--R          +-----+ +------+ +------+
+--R        2\|x + 1 \|3x + 2 \|3x + 3
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 940
+t0:=sqrt(1-x)*sqrt(2+3*x)/sqrt(1-x^2)
+--R 
+--R
+--R         +-------+ +------+
+--R        \|- x + 1 \|3x + 2
+--R   (1)  -------------------
+--R             +--------+
+--R             |   2
+--R            \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 940
+r0:=-asinh(sqrt(2+3*x))/sqrt(3)+sqrt(1+x)*sqrt(2+3*x)
+--R 
+--R
+--R                 +------+     +-+ +-----+ +------+
+--R        - asinh(\|3x + 2 ) + \|3 \|x + 1 \|3x + 2
+--R   (2)  ------------------------------------------
+--R                            +-+
+--R                           \|3
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                +--------+
+--R                 +-------+ +-----+              |   2       +------+
+--R       ((6x + 4)\|- x + 1 \|x + 1  + (- 6x - 5)\|- x  + 1 )\|3x + 3
+--R     + 
+--R            +--------+
+--R        +-+ |   2      +-----+
+--R       \|3 \|- x  + 1 \|x + 1
+--R  /
+--R       +--------+
+--R       |   2      +-----+ +------+ +------+
+--R     2\|- x  + 1 \|x + 1 \|3x + 2 \|3x + 3
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 940
+t0:=(1+x)^(3/2)/((1-x)^(3/2)*x)
+--R 
+--R
+--R                   +-----+
+--R         (- x - 1)\|x + 1
+--R   (1)  ------------------
+--R          2      +-------+
+--R        (x  - x)\|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 940
+r0:=-asin(x)-2*atanh(sqrt(1-x)/sqrt(1+x))+2*(1+x)^(3/2)/sqrt(1-x)+_
+   2*sqrt(1-x)*sqrt(1+x)
+--R 
+--R
+--R                            +-------+
+--R            +-------+      \|- x + 1       +-----+           +-------+
+--R        - 2\|- x + 1 atanh(----------) + 4\|x + 1  - asin(x)\|- x + 1
+--R                             +-----+
+--R                            \|x + 1
+--R   (2)  --------------------------------------------------------------
+--R                                   +-------+
+--R                                  \|- x + 1
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                              +--------+
+--R         +-------+ +-----+    |   2
+--R        \|- x + 1 \|x + 1  - \|- x  + 1
+--R   (3)  --------------------------------
+--R           +--------+
+--R           |   2      +-------+ +-----+
+--R          \|- x  + 1 \|- x + 1 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 940
+t0:=(1+x)^3/(x*(1-x^2)^(3/2))
+--R 
+--R
+--R              2
+--R           - x  - 2x - 1
+--R   (1)  -------------------
+--R                 +--------+
+--R          2      |   2
+--R        (x  - x)\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 940
+r0:=-asin(x)-atanh(sqrt(1-x^2))+4/sqrt(1-x^2)+4*x/sqrt(1-x^2)
+--R 
+--R
+--R           +--------+       +--------+            +--------+
+--R           |   2            |   2                 |   2
+--R        - \|- x  + 1 atanh(\|- x  + 1 ) - asin(x)\|- x  + 1  + 4x + 4
+--R   (2)  -------------------------------------------------------------
+--R                                  +--------+
+--R                                  |   2
+--R                                 \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 940
+t0:=(1+a*x)^(3/2)/(x*(1-a*x)^(3/2))
+--R 
+--R
+--R                     +-------+
+--R         (- a x - 1)\|a x + 1
+--R   (1)  ----------------------
+--R            2      +---------+
+--R        (a x  - x)\|- a x + 1
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 940
+r0:=-asin(a*x)-2*atanh(sqrt(1-a*x)/sqrt(1+a*x))+2*(1+a*x)^(3/2)/_
+   sqrt(1-a*x)+2*sqrt(1-a*x)*sqrt(1+a*x)
+--R 
+--R
+--R   (2)
+--R                         +---------+
+--R       +---------+      \|- a x + 1       +-------+             +---------+
+--R   - 2\|- a x + 1 atanh(------------) + 4\|a x + 1  - asin(a x)\|- a x + 1
+--R                          +-------+
+--R                         \|a x + 1
+--R   ------------------------------------------------------------------------
+--R                                  +---------+
+--R                                 \|- a x + 1
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                                    +----------+
+--R          +---------+ +-------+     |   2 2
+--R        a\|- a x + 1 \|a x + 1  - a\|- a x  + 1
+--R   (3)  ----------------------------------------
+--R            +----------+
+--R            |   2 2      +---------+ +-------+
+--R           \|- a x  + 1 \|- a x + 1 \|a x + 1
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 940
+t0:=(1+a*x)^3/(x*(1-a^2*x^2)^(3/2))
+--R 
+--R
+--R              2 2
+--R           - a x  - 2a x - 1
+--R   (1)  -----------------------
+--R                   +----------+
+--R            2      |   2 2
+--R        (a x  - x)\|- a x  + 1
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 940
+r0:=-asin(a*x)-atanh(sqrt(1-a^2*x^2))+4/sqrt(1-a^2*x^2)+4*a*x/sqrt(1-a^2*x^2)
+--R 
+--R
+--R   (2)
+--R      +----------+       +----------+              +----------+
+--R      |   2 2            |   2 2                   |   2 2
+--R   - \|- a x  + 1 atanh(\|- a x  + 1 ) - asin(a x)\|- a x  + 1  + 4a x + 4
+--R   -----------------------------------------------------------------------
+--R                                 +----------+
+--R                                 |   2 2
+--R                                \|- a x  + 1
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 940
+t0:=1/sqrt(1-x^2)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 940
+r0:=asin(x)
+--R 
+--R
+--R   (2)  asin(x)
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 940
+t0:=sqrt(1+x^2)/sqrt(1-x^4)
+--R 
+--R
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 940
+r0:=asin(x)
+--R 
+--R
+--R   (2)  asin(x)
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +--------+ +------+    +--------+
+--R         |   2      | 2         |   4
+--R        \|- x  + 1 \|x  + 1  - \|- x  + 1
+--R   (3)  ----------------------------------
+--R               +--------+ +--------+
+--R               |   4      |   2
+--R              \|- x  + 1 \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 940
+t0:=1/sqrt(1+x^2)
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 940
+r0:=asinh(x)
+--R 
+--R
+--R   (2)  asinh(x)
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 940
+t0:=sqrt(1-x^2)/sqrt(1-x^4)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 940
+r0:=asinh(x)
+--R 
+--R
+--R   (2)  asinh(x)
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +--------+ +------+    +--------+
+--R         |   2      | 2         |   4
+--R        \|- x  + 1 \|x  + 1  - \|- x  + 1
+--R   (3)  ----------------------------------
+--R                +--------+ +------+
+--R                |   4      | 2
+--R               \|- x  + 1 \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 940
+t0:=sqrt(1-x^2)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R   (1)  \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 940
+r0:=1/2*asin(x)+1/2*x*sqrt(1-x^2)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        x\|- x  + 1  + asin(x)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 940
+t0:=sqrt(1-x^4)/sqrt(1+x^2)
+--R 
+--R
+--R         +--------+
+--R         |   4
+--R        \|- x  + 1
+--R   (1)  -----------
+--R          +------+
+--R          | 2
+--R         \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 940
+r0:=1/2*asin(x)+1/2*x*sqrt(1-x^2)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        x\|- x  + 1  + asin(x)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                 +------+    +--------+ +--------+
+--R          2      | 2         |   4      |   2
+--R        (x  - 1)\|x  + 1  + \|- x  + 1 \|- x  + 1
+--R   (3)  ------------------------------------------
+--R                    +--------+ +------+
+--R                    |   2      | 2
+--R                   \|- x  + 1 \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 940
+t0:=sqrt(1+x^2)
+--R 
+--R
+--R         +------+
+--R         | 2
+--R   (1)  \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 940
+r0:=1/2*asinh(x)+1/2*x*sqrt(1+x^2)
+--R 
+--R
+--R          +------+
+--R          | 2
+--R        x\|x  + 1  + asinh(x)
+--R   (2)  ---------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 940
+t0:=sqrt(1-x^4)/sqrt(1-x^2)
+--R 
+--R
+--R         +--------+
+--R         |   4
+--R        \|- x  + 1
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 940
+r0:=1/2*asinh(x)+1/2*x*sqrt(1+x^2)
+--R 
+--R
+--R          +------+
+--R          | 2
+--R        x\|x  + 1  + asinh(x)
+--R   (2)  ---------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +--------+ +------+              +--------+
+--R         |   4      | 2            2      |   2
+--R        \|- x  + 1 \|x  + 1  + (- x  - 1)\|- x  + 1
+--R   (3)  --------------------------------------------
+--R                     +--------+ +------+
+--R                     |   2      | 2
+--R                    \|- x  + 1 \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 940
+t0:=(a^2*c+a^2*d*x+2*a*b*c*x^2+2*a*b*d*x^3+b^2*c*x^4+b^2*d*x^5)/(c+d*x)
+--R 
+--R
+--R         2 4         2    2
+--R   (1)  b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 391
+
+--S 392 of 940
+r0:=a^2*x+2/3*a*b*x^3+1/5*b^2*x^5
+--R 
+--R
+--R        1  2 5   2      3    2
+--R   (2)  - b x  + - a b x  + a x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 392
+
+--S 393 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 940
+t0:=(a^2*c+a^2*d*x+2*a*b*c*x^2+2*a*b*d*x^3+b^2*c*x^4+b^2*d*x^5)/(c+d*x)^2
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R              d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 394
+
+--S 395 of 940
+r0:=-b*c*(b*c^2+2*a*d^2)*x/d^4+1/2*b*(b*c^2+2*a*d^2)*x^2/d^3-_
+   1/3*b^2*c*x^3/d^2+1/4*b^2*x^4/d+(b*c^2+a*d^2)^2*log(c+d*x)/d^5
+--R 
+--R
+--R   (2)
+--R           2 4          2 2      2 4                  2 4 4     2   3 3
+--R       (12a d  + 24a b c d  + 12b c )log(d x + c) + 3b d x  - 4b c d x
+--R     + 
+--R               4     2 2 2  2               3      2 3
+--R       (12a b d  + 6b c d )x  + (- 24a b c d  - 12b c d)x
+--R  /
+--R        5
+--R     12d
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 940
+t0:=(a^2*c+a^2*d*x+2*a*b*c*x^2+2*a*b*d*x^3+b^2*c*x^4+b^2*d*x^5)/(a+b*x^2)
+--R 
+--R
+--R             3        2
+--R   (1)  b d x  + b c x  + a d x + a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 397
+
+--S 398 of 940
+r0:=a*c*x+1/2*a*d*x^2+1/3*b*c*x^3+1/4*b*d*x^4
+--R 
+--R
+--R        1      4   1      3   1      2
+--R   (2)  - b d x  + - b c x  + - a d x  + a c x
+--R        4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 398
+
+--S 399 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 940
+t0:=(a^2*c+a^2*d*x+2*a*b*c*x^2+2*a*b*d*x^3+b^2*c*x^4+b^2*d*x^5)/(a+b*x^2)^2
+--R 
+--R
+--R   (1)  d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 400
+
+--S 401 of 940
+r0:=c*x+1/2*d*x^2
+--R 
+--R
+--R        1    2
+--R   (2)  - d x  + c x
+--R        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 401
+
+--S 402 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 940
+t0:=(a^2*c+a^2*d*x+2*a*b*c*x^2+2*a*b*d*x^3+b^2*c*x^4+b^2*d*x^5)/(a+b*x^2)^3
+--R 
+--R
+--R         d x + c
+--R   (1)  --------
+--R           2
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 403
+
+--S 404 of 940
+r0:=1/2*d*log(a+b*x^2)/b+c*atan(x*sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b))
+--R 
+--R
+--R                    +-+
+--R                  x\|b              2      +-+ +-+
+--R        2b c atan(-----) + d log(b x  + a)\|a \|b
+--R                    +-+
+--R                   \|a
+--R   (2)  ------------------------------------------
+--R                           +-+ +-+
+--R                        2b\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 940
+t0:=((a+b+c*x^2)/d)^m
+--R 
+--R
+--R            2         m
+--R         c x  + b + a
+--R   (1)  (------------)
+--R               d
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 940
+--r0:=x*((a+b)/d+c*x^2/d)^m*_
+--   hypergeometric(1/2,-m,3/2,-c*x^2/(a+b))/((a+b+c*x^2)/(a+b))^m
+--E 407
+
+--S 408 of 940
+--d0:=normalize(t0-D(r0,x))
+--E 408
+
+)clear all
+
+--S 409 of 940
+t0:=1/(x-sqrt(1+x^2))
+--R 
+--R
+--R                1
+--R   (1)  - -------------
+--R           +------+
+--R           | 2
+--R          \|x  + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 940
+r0:=-1/2*x^2-1/2*asinh(x)-1/2*x*sqrt(1+x^2)
+--R 
+--R
+--R            +------+
+--R            | 2                    2
+--R        - x\|x  + 1  - asinh(x) - x
+--R   (2)  ----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 940
+t0:=1/(x-sqrt(1-x^2))
+--R 
+--R
+--R                 1
+--R   (1)  - ---------------
+--R           +--------+
+--R           |   2
+--R          \|- x  + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 940
+r0:=-1/2*asin(x)-1/2*atanh(x/sqrt(1-x^2))+1/4*log(1-2*x^2)
+--R 
+--R
+--R                      x                 2
+--R        - 2atanh(-----------) + log(- 2x  + 1) - 2asin(x)
+--R                  +--------+
+--R                  |   2
+--R                 \|- x  + 1
+--R   (2)  -------------------------------------------------
+--R                                4
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 940
+t0:=1/(x-sqrt(1+2*x^2))
+--R 
+--R
+--R                 1
+--R   (1)  - --------------
+--R           +-------+
+--R           |  2
+--R          \|2x  + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 940
+r0:=atanh(x/sqrt(1+2*x^2))-1/2*log(1+x^2)-asinh(x*sqrt(2))*sqrt(2)
+--R 
+--R
+--R                    x             2          +-+        +-+
+--R        2atanh(----------) - log(x  + 1) - 2\|2 asinh(x\|2 )
+--R                +-------+
+--R                |  2
+--R               \|2x  + 1
+--R   (2)  ----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 940
+t0:=(2*x-x^3+x^2*sqrt(2-x^2))/(-2+2*x^2)
+--R 
+--R
+--R           +--------+
+--R         2 |   2         3
+--R        x \|- x  + 2  - x  + 2x
+--R   (1)  -----------------------
+--R                  2
+--R                2x  - 2
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 940
+r0:=-1/4*x^2-1/2*atanh(x/sqrt(2-x^2))+1/4*log(1-x^2)+1/4*x*sqrt(2-x^2)
+--R 
+--R
+--R                                  +--------+
+--R                      x           |   2               2         2
+--R        - 2atanh(-----------) + x\|- x  + 2  + log(- x  + 1) - x
+--R                  +--------+
+--R                  |   2
+--R                 \|- x  + 2
+--R   (2)  ---------------------------------------------------------
+--R                                    4
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 940
+t0:=x*sqrt(2-x^2)/(x-sqrt(2-x^2))
+--R 
+--R
+--R              +--------+
+--R              |   2
+--R            x\|- x  + 2
+--R   (1)  - ---------------
+--R           +--------+
+--R           |   2
+--R          \|- x  + 2  - x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 940
+r0:=-1/4*x^2-1/2*atanh(x/sqrt(2-x^2))+1/4*log(1-x)+1/4*log(1+x)+_
+   1/4*x*sqrt(2-x^2)
+--R 
+--R
+--R                                  +--------+
+--R                      x           |   2                                     2
+--R        - 2atanh(-----------) + x\|- x  + 2  + log(x + 1) + log(- x + 1) - x
+--R                  +--------+
+--R                  |   2
+--R                 \|- x  + 2
+--R   (2)  ---------------------------------------------------------------------
+--R                                          4
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 940
+t0:=x/(-x+sqrt(2*x-x^2))
+--R 
+--R
+--R                x
+--R   (1)  ----------------
+--R         +---------+
+--R         |   2
+--R        \|- x  + 2x  - x
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 940
+r0:=-1/2*x+1/2*atanh(sqrt(2*x-x^2))-1/2*log(1-x)-1/2*sqrt(2*x-x^2)
+--R 
+--R
+--R               +---------+     +---------+
+--R               |   2           |   2
+--R        atanh(\|- x  + 2x ) - \|- x  + 2x  - log(- x + 1) - x
+--R   (2)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 940
+t0:=(x+sqrt(2*x-x^2))/(2-2*x)
+--R 
+--R
+--R           +---------+
+--R           |   2
+--R        - \|- x  + 2x  - x
+--R   (1)  ------------------
+--R              2x - 2
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 940
+r0:=-1/2*x+1/2*atanh(sqrt(2*x-x^2))-1/2*log(1-x)-1/2*sqrt(2*x-x^2)
+--R 
+--R
+--R               +---------+     +---------+
+--R               |   2           |   2
+--R        atanh(\|- x  + 2x ) - \|- x  + 2x  - log(- x + 1) - x
+--R   (2)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 940
+t0:=(x+sqrt(2-x)*sqrt(x))/(2-2*x)
+--R 
+--R
+--R           +-------+ +-+
+--R        - \|- x + 2 \|x  - x
+--R   (1)  --------------------
+--R               2x - 2
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 940
+r0:=-1/2*x+1/2*atanh(sqrt(2*x-x^2))-1/2*log(1-x)-1/2*sqrt(2*x-x^2)
+--R 
+--R
+--R               +---------+     +---------+
+--R               |   2           |   2
+--R        atanh(\|- x  + 2x ) - \|- x  + 2x  - log(- x + 1) - x
+--R   (2)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           +---------+
+--R           |   2       +-------+ +-+    2
+--R        - \|- x  + 2x \|- x + 2 \|x  - x  + 2x
+--R   (3)  --------------------------------------
+--R                          +---------+
+--R                          |   2
+--R                 (2x - 2)\|- x  + 2x
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 940
+t0:=sqrt(x)/(sqrt(2-x)-sqrt(x))
+--R 
+--R
+--R                  +-+
+--R                 \|x
+--R   (1)  - -----------------
+--R           +-+    +-------+
+--R          \|x  - \|- x + 2
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 940
+r0:=-1/2*x+1/2*atanh(sqrt(2*x-x^2))-1/2*log(1-x)-1/2*sqrt(2*x-x^2)
+--R 
+--R
+--R               +---------+     +---------+
+--R               |   2           |   2
+--R        atanh(\|- x  + 2x ) - \|- x  + 2x  - log(- x + 1) - x
+--R   (2)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R              +---------+                       +---------+
+--R              |   2          2       +-+        |   2          2       +-------+
+--R   ((- x + 2)\|- x  + 2x  - x  + 2x)\|x  + (- x\|- x  + 2x  + x  - 2x)\|- x + 2
+--R   -----------------------------------------------------------------------------
+--R                     +---------+                  +---------+
+--R                     |   2       +-+              |   2       +-------+
+--R            (2x - 2)\|- x  + 2x \|x  + (- 2x + 2)\|- x  + 2x \|- x + 2
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 940
+t0:=(2*sqrt(3-x)+3/sqrt(1+x))^2/x
+--R 
+--R
+--R           +-------+ +-----+     2
+--R        12\|- x + 3 \|x + 1  - 4x  + 8x + 21
+--R   (1)  ------------------------------------
+--R                        2
+--R                       x  + x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 940
+r0:=-4*x+12*asin(1/2*(1-x))+21*log(x)-9*log(1+x)-_
+   24*atanh(sqrt(3)*sqrt(1+x)/sqrt(3-x))*sqrt(3)
+--R 
+--R
+--R   (2)
+--R                  +-+ +-----+
+--R        +-+      \|3 \|x + 1                                     x - 1
+--R   - 24\|3 atanh(------------) - 9log(x + 1) + 21log(x) - 12asin(-----) - 4x
+--R                   +-------+                                       2
+--R                  \|- x + 3
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                                  +-------------+
+--R           +-------+ +-----+      |   2
+--R        12\|- x + 3 \|x + 1  - 12\|- x  + 2x + 3
+--R   (3)  -----------------------------------------
+--R             +-------------+
+--R             |   2           +-------+ +-----+
+--R            \|- x  + 2x + 3 \|- x + 3 \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 940
+t0:=(-1+x+x^2)/(1+sqrt(1+x^2))
+--R 
+--R
+--R           2
+--R          x  + x - 1
+--R   (1)  -------------
+--R         +------+
+--R         | 2
+--R        \|x  + 1  + 1
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 940
+r0:=(-1)/x-x-1/2*asinh(x)-log(1+sqrt(1+x^2))+sqrt(1+x^2)+_
+   sqrt(1+x^2)/x+1/2*x*sqrt(1+x^2)
+--R 
+--R
+--R   (2)
+--R             +------+                      +------+
+--R             | 2               2           | 2                       2
+--R   - 2x log(\|x  + 1  + 1) + (x  + 2x + 2)\|x  + 1  - x asinh(x) - 2x  - 2
+--R   -----------------------------------------------------------------------
+--R                                      2x
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 940
+t0:=(-1+x+x^2)/(1+x+sqrt(1+x^2))
+--R 
+--R
+--R             2
+--R            x  + x - 1
+--R   (1)  -----------------
+--R         +------+
+--R         | 2
+--R        \|x  + 1  + x + 1
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 940
+r0a:=1/12*(6*x^2+2*x^3-3*asinh(x)-6*log(1+sqrt(1+x^2))+_
+   (4-3*x-2*x^2)*sqrt(1+x^2))
+--R 
+--R
+--R   (2)
+--R           +------+                         +------+
+--R           | 2                  2           | 2                      3     2
+--R   - 6log(\|x  + 1  + 1) + (- 2x  - 3x + 4)\|x  + 1  - 3asinh(x) + 2x  + 6x
+--R   -------------------------------------------------------------------------
+--R                                       12
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 940
+r0b:=1/2*x^2+1/6*x^3-1/6*(1+x^2)^(3/2)-1/4*asinh(x)-1/2*atanh(sqrt(1+x^2))-_
+   1/2*log(x)+1/2*sqrt(1+x^2)-1/4*x*sqrt(1+x^2)
+--R 
+--R
+--R   (3)
+--R                 +------+                     +------+
+--R                 | 2              2           | 2
+--R       - 6atanh(\|x  + 1 ) + (- 2x  - 3x + 4)\|x  + 1  - 6log(x) - 3asinh(x)
+--R     + 
+--R         3     2
+--R       2x  + 6x
+--R  /
+--R     12
+--R                                                    Type: Expression(Integer)
+--E 444
+
+--S 445 of 940
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 940
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 446
+
+)clear all
+
+--S 447 of 940
+t0:=(x+2*sqrt(-1+x))/(x*sqrt(-1+x))
+--R 
+--R
+--R          +-----+
+--R        2\|x - 1  + x
+--R   (1)  -------------
+--R            +-----+
+--R          x\|x - 1
+--R                                                    Type: Expression(Integer)
+--E 447
+
+--S 448 of 940
+r0:=2*log(x)+2*sqrt(-1+x)
+--R 
+--R
+--R          +-----+
+--R   (2)  2\|x - 1  + 2log(x)
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 449
+
+)clear all
+
+--S 450 of 940
+t0:=(a+b*x^(2/3)+c*sqrt(x))^2
+--R 
+--R
+--R              +-+        3+-+2    2 3+-+        +-+    2     2
+--R   (1)  (2b c\|x  + 2a b)\|x   + b x\|x  + 2a c\|x  + c x + a
+--R                                                    Type: Expression(Integer)
+--E 450
+
+--S 451 of 940
+r0:=a^2*x+4/3*a*c*x^(3/2)+6/5*a*b*x^(5/3)+1/2*c^2*x^2+12/13*b*c*x^(13/6)+_
+   3/7*b^2*x^(7/3)
+--R 
+--R
+--R   (2)
+--R                2 6+-+            3+-+2        2 2 3+-+            +-+
+--R       2520b c x  \|x + 3276a b x \|x   + 1170b x  \|x + 3640a c x\|x
+--R     + 
+--R            2 2        2
+--R       1365c x  + 2730a x
+--R  /
+--R     2730
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 452
+
+)clear all
+
+--S 453 of 940
+t0:=(a+b*x^(2/3)+c*sqrt(x))^3
+--R 
+--R
+--R   (1)
+--R             +-+       2      2  3+-+2      2    +-+       2  3+-+
+--R     (6a b c\|x  + 3b c x + 3a b)\|x   + (3b c x\|x  + 3a b x)\|x
+--R   + 
+--R       3      2   +-+    3 2       2     3
+--R     (c x + 3a c)\|x  + b x  + 3a c x + a
+--R                                                    Type: Expression(Integer)
+--E 453
+
+--S 454 of 940
+r0:=a^3*x+2*a^2*c*x^(3/2)+9/5*a^2*b*x^(5/3)+3/2*a*c^2*x^2+_
+   36/13*a*b*c*x^(13/6)+9/7*a*b^2*x^(7/3)+2/5*c^3*x^(5/2)+_
+   9/8*b*c^2*x^(8/3)+18/17*b^2*c*x^(17/6)+1/3*b^3*x^3
+--R 
+--R
+--R   (2)
+--R              2   2 6+-+5               2 6+-+
+--R       196560b c x  \|x  + 514080a b c x  \|x
+--R     + 
+--R                 2 2          2    3+-+2            2 2 3+-+
+--R       (208845b c x  + 334152a b x)\|x   + 238680a b x  \|x
+--R     + 
+--R              3 2          2     +-+         3 3            2 2          3
+--R       (74256c x  + 371280a c x)\|x  + 61880b x  + 278460a c x  + 185640a x
+--R  /
+--R     185640
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 455
+
+)clear all
+
+--S 456 of 940
+t0:=(-1+x^2)/(x^3*sqrt(a-b+b/x^2))
+--R 
+--R
+--R                2
+--R               x  - 1
+--R   (1)  --------------------
+--R           +---------------+
+--R           |          2
+--R         3 |(- b + a)x  + b
+--R        x  |---------------
+--R           |        2
+--R          \|       x
+--R                                                    Type: Expression(Integer)
+--E 456
+
+--S 457 of 940
+r0:=atanh(sqrt(a-b+b/x^2)/sqrt(a-b))/sqrt(a-b)+sqrt(a-b+b/x^2)/b
+--R 
+--R
+--R                 +---------------+
+--R                 |          2
+--R                 |(- b + a)x  + b
+--R                 |---------------                +---------------+
+--R                 |        2                      |          2
+--R                \|       x             +-------+ |(- b + a)x  + b
+--R        b atanh(------------------) + \|- b + a  |---------------
+--R                     +-------+                   |        2
+--R                    \|- b + a                   \|       x
+--R   (2)  ----------------------------------------------------------
+--R                                  +-------+
+--R                                b\|- b + a
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 458
+
+)clear all
+
+--S 459 of 940
+t0:=(-1+x^2)/(x^3*sqrt(a+b*(-1+1/x^2)))
+--R 
+--R
+--R                2
+--R               x  - 1
+--R   (1)  --------------------
+--R           +---------------+
+--R           |          2
+--R         3 |(- b + a)x  + b
+--R        x  |---------------
+--R           |        2
+--R          \|       x
+--R                                                    Type: Expression(Integer)
+--E 459
+
+--S 460 of 940
+r0:=atanh(sqrt(a-b+b/x^2)/sqrt(a-b))/sqrt(a-b)+sqrt(a-b+b/x^2)/b
+--R 
+--R
+--R                 +---------------+
+--R                 |          2
+--R                 |(- b + a)x  + b
+--R                 |---------------                +---------------+
+--R                 |        2                      |          2
+--R                \|       x             +-------+ |(- b + a)x  + b
+--R        b atanh(------------------) + \|- b + a  |---------------
+--R                     +-------+                   |        2
+--R                    \|- b + a                   \|       x
+--R   (2)  ----------------------------------------------------------
+--R                                  +-------+
+--R                                b\|- b + a
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 461
+
+)clear all
+
+--S 462 of 940
+t0:=(1+x)/((4+x^2)*sqrt(9+x^2))
+--R 
+--R
+--R              x + 1
+--R   (1)  -----------------
+--R                 +------+
+--R          2      | 2
+--R        (x  + 4)\|x  + 9
+--R                                                    Type: Expression(Integer)
+--E 462
+
+--S 463 of 940
+r0:=1/2*atan(1/2*x*sqrt(5)/sqrt(9+x^2))/sqrt(5)-_
+   atanh(sqrt(9+x^2)/sqrt(5))/sqrt(5)
+--R 
+--R
+--R                  +------+
+--R                  | 2                   +-+
+--R                 \|x  + 9             x\|5
+--R        - 2atanh(---------) + atan(----------)
+--R                     +-+             +------+
+--R                    \|5              | 2
+--R                                   2\|x  + 9
+--R   (2)  --------------------------------------
+--R                           +-+
+--R                         2\|5
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 464
+
+)clear all
+
+--S 465 of 940
+t0:=x*(1+sqrt(1-x^2))
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R   (1)  x\|- x  + 1  + x
+--R                                                    Type: Expression(Integer)
+--E 465
+
+--S 466 of 940
+r0:=1/2*x^2-1/3*(1-x^2)^(3/2)
+--R 
+--R
+--R                  +--------+
+--R           2      |   2          2
+--R        (2x  - 2)\|- x  + 1  + 3x
+--R   (2)  --------------------------
+--R                     6
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 467
+
+)clear all
+
+--S 468 of 940
+t0:=x*(1+sqrt(1-x)*sqrt(1+x))
+--R 
+--R
+--R          +-------+ +-----+
+--R   (1)  x\|- x + 1 \|x + 1  + x
+--R                                                    Type: Expression(Integer)
+--E 468
+
+--S 469 of 940
+r0:=1/2*x^2-1/3*(1-x^2)^(3/2)
+--R 
+--R
+--R                  +--------+
+--R           2      |   2          2
+--R        (2x  - 2)\|- x  + 1  + 3x
+--R   (2)  --------------------------
+--R                     6
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R          +--------+
+--R          |   2      +-------+ +-----+    3
+--R        x\|- x  + 1 \|- x + 1 \|x + 1  + x  - x
+--R   (3)  ---------------------------------------
+--R                       +--------+
+--R                       |   2
+--R                      \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 470
+
+)clear all
+
+--S 471 of 940
+t0:=x*(1+1/(sqrt(2+x)*sqrt(3+x)))
+--R 
+--R
+--R          +-----+ +-----+
+--R        x\|x + 2 \|x + 3  + x
+--R   (1)  ---------------------
+--R            +-----+ +-----+
+--R           \|x + 2 \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 471
+
+--S 472 of 940
+r0:=1/2*x^2-5*asinh(sqrt(2+x))+sqrt(2+x)*sqrt(3+x)
+--R 
+--R
+--R                   +-----+      +-----+ +-----+    2
+--R        - 10asinh(\|x + 2 ) + 2\|x + 2 \|x + 3  + x
+--R   (2)  --------------------------------------------
+--R                              2
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 473
+
+)clear all
+
+--S 474 of 940
+t0:=(x-sqrt(x^6))/(x*(1-x^4))
+--R 
+--R
+--R         +--+
+--R         | 6
+--R        \|x   - x
+--R   (1)  ---------
+--R           5
+--R          x  - x
+--R                                                    Type: Expression(Integer)
+--E 474
+
+--S 475 of 940
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(x^6)/x^3-_
+   1/2*atanh(x)*sqrt(x^6)/x^3
+--R 
+--R
+--R                               +--+
+--R                               | 6     3            3
+--R        (- atanh(x) + atan(x))\|x   + x atanh(x) + x atan(x)
+--R   (2)  ----------------------------------------------------
+--R                                   3
+--R                                 2x
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 476
+
+)clear all
+
+--S 477 of 940
+t0:=(1-sqrt(x^6)/x)/(1-x^4)
+--R 
+--R
+--R         +--+
+--R         | 6
+--R        \|x   - x
+--R   (1)  ---------
+--R           5
+--R          x  - x
+--R                                                    Type: Expression(Integer)
+--E 477
+
+--S 478 of 940
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(x^6)/x^3-_
+   1/2*atanh(x)*sqrt(x^6)/x^3
+--R 
+--R
+--R                               +--+
+--R                               | 6     3            3
+--R        (- atanh(x) + atan(x))\|x   + x atanh(x) + x atan(x)
+--R   (2)  ----------------------------------------------------
+--R                                   3
+--R                                 2x
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 479
+
+)clear all
+
+--S 480 of 940
+t0:=(x-sqrt(x^6))/(x-x^5)
+--R 
+--R
+--R         +--+
+--R         | 6
+--R        \|x   - x
+--R   (1)  ---------
+--R           5
+--R          x  - x
+--R                                                    Type: Expression(Integer)
+--E 480
+
+--S 481 of 940
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(x^6)/x^3-_
+   1/2*atanh(x)*sqrt(x^6)/x^3
+--R 
+--R
+--R                               +--+
+--R                               | 6     3            3
+--R        (- atanh(x) + atan(x))\|x   + x atanh(x) + x atan(x)
+--R   (2)  ----------------------------------------------------
+--R                                   3
+--R                                 2x
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 482
+
+)clear all
+
+--S 483 of 940
+t0:=x/(x+sqrt(x^6))
+--R 
+--R
+--R            x
+--R   (1)  ---------
+--R         +--+
+--R         | 6
+--R        \|x   + x
+--R                                                    Type: Expression(Integer)
+--E 483
+
+--S 484 of 940
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(x^6)/x^3-_
+   1/2*atanh(x)*sqrt(x^6)/x^3
+--R 
+--R
+--R                               +--+
+--R                               | 6     3            3
+--R        (- atanh(x) + atan(x))\|x   + x atanh(x) + x atan(x)
+--R   (2)  ----------------------------------------------------
+--R                                   3
+--R                                 2x
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 485
+
+)clear all
+
+--S 486 of 940
+t0:=(sqrt(x)-sqrt(x^3))/(x-x^3)
+--R 
+--R
+--R         +--+
+--R         | 3     +-+
+--R        \|x   - \|x
+--R   (1)  ------------
+--R            3
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 486
+
+--S 487 of 940
+r0:=atan(sqrt(x))+atanh(sqrt(x))+atan(sqrt(x))*sqrt(x^3)/x^(3/2)-_
+   atanh(sqrt(x))*sqrt(x^3)/x^(3/2)
+--R 
+--R
+--R            +--+                         +--+
+--R            | 3      +-+        +-+      | 3      +-+       +-+
+--R        (- \|x   + x\|x )atanh(\|x ) + (\|x   + x\|x )atan(\|x )
+--R   (2)  --------------------------------------------------------
+--R                                    +-+
+--R                                  x\|x
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 488
+
+)clear all
+
+--S 489 of 940
+t0:=1/(sqrt(x)+sqrt(x^3))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         +--+
+--R         | 3     +-+
+--R        \|x   + \|x
+--R                                                    Type: Expression(Integer)
+--E 489
+
+--S 490 of 940
+r0:=atan(sqrt(x))+atanh(sqrt(x))+atan(sqrt(x))*sqrt(x^3)/x^(3/2)-_
+   atanh(sqrt(x))*sqrt(x^3)/x^(3/2)
+--R 
+--R
+--R            +--+                         +--+
+--R            | 3      +-+        +-+      | 3      +-+       +-+
+--R        (- \|x   + x\|x )atanh(\|x ) + (\|x   + x\|x )atan(\|x )
+--R   (2)  --------------------------------------------------------
+--R                                    +-+
+--R                                  x\|x
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 491
+
+)clear all
+
+--S 492 of 940
+t0:=1/(sqrt(-1+x)+sqrt((-1+x)^3))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R         +-----------------+
+--R         | 3     2              +-----+
+--R        \|x  - 3x  + 3x - 1  + \|x - 1
+--R                                                    Type: Expression(Integer)
+--E 492
+
+--S 493 of 940
+r0:=atan(sqrt(-1+x))+atanh(sqrt(-1+x))+atan(sqrt(-1+x))*_
+   sqrt((-1+x)^3)/(-1+x)^(3/2)-atanh(sqrt(-1+x))*sqrt((-1+x)^3)/(-1+x)^(3/2)
+--R 
+--R
+--R   (2)
+--R           +-----------------+
+--R           | 3     2                     +-----+        +-----+
+--R       (- \|x  - 3x  + 3x - 1  + (x - 1)\|x - 1 )atanh(\|x - 1 )
+--R     + 
+--R         +-----------------+
+--R         | 3     2                     +-----+       +-----+
+--R       (\|x  - 3x  + 3x - 1  + (x - 1)\|x - 1 )atan(\|x - 1 )
+--R  /
+--R             +-----+
+--R     (x - 1)\|x - 1
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 494
+
+)clear all
+
+--S 495 of 940
+t0:=(-5-4*x-3*sqrt(1-x^2))/((4+5*x)^2*sqrt(1-x^2))
+--R 
+--R
+--R               +--------+
+--R               |   2
+--R           - 3\|- x  + 1  - 4x - 5
+--R   (1)  ----------------------------
+--R                          +--------+
+--R            2             |   2
+--R        (25x  + 40x + 16)\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 495
+
+--S 496 of 940
+r0:=3/5/(4+5*x)+sqrt(1-x^2)/(4+5*x)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        5\|- x  + 1  + 3
+--R   (2)  ----------------
+--R            25x + 20
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 497
+
+)clear all
+
+--S 498 of 940
+t0:=(-1+sqrt(1-x^2))/((2+x-2*sqrt(1-x^2))^2*sqrt(1-x^2))
+--R 
+--R
+--R                          +--------+
+--R                          |   2
+--R                       - \|- x  + 1  + 1
+--R   (1)  ----------------------------------------------
+--R                       +--------+
+--R           2           |   2          3     2
+--R        (3x  - 4x - 8)\|- x  + 1  - 4x  - 8x  + 4x + 8
+--R                                                    Type: Expression(Integer)
+--E 498
+
+--S 499 of 940
+r0:=3/5/(4+5*x)+sqrt(1-x^2)/(4+5*x)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        5\|- x  + 1  + 3
+--R   (2)  ----------------
+--R            25x + 20
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 500
+
+)clear all
+
+--S 501 of 940
+t0:=1/(3*(1-x^2)+(-5-4*x)*sqrt(1-x^2))
+--R 
+--R
+--R                        1
+--R   (1)  - -----------------------------
+--R                   +--------+
+--R                   |   2          2
+--R          (4x + 5)\|- x  + 1  + 3x  - 3
+--R                                                    Type: Expression(Integer)
+--E 501
+
+--S 502 of 940
+r0:=3/5/(4+5*x)+sqrt(1-x^2)/(4+5*x)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R        5\|- x  + 1  + 3
+--R   (2)  ----------------
+--R            25x + 20
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 503
+
+)clear all
+
+--S 504 of 940
+t0:=(a+b*x^(-1+n))/(c*x+d*x^n)
+--R 
+--R
+--R           n - 1
+--R        b x      + a
+--R   (1)  ------------
+--R            n
+--R         d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 504
+
+--S 505 of 940
+r0:=b*log(x)/d-(b*c-a*d)*log(d+c*x^(1-n))/(c*d*(1-n))
+--R 
+--R
+--R                            - n + 1
+--R        (- a d + b c)log(c x        + d) + (b c n - b c)log(x)
+--R   (2)  ------------------------------------------------------
+--R                              c d n - c d
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 506
+
+)clear all
+
+--S 507 of 940
+t0:=1/((8+12*x+5*x^2)*sqrt(-7+2*x+5*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                        +------------+
+--R           2            |  2
+--R        (5x  + 12x + 8)\|5x  + 2x - 7
+--R                                                    Type: Expression(Integer)
+--E 507
+
+--S 508 of 940
+r0:=(-1/20+1/10*%i)*atan((1/50+1/100*%i)*(-164-8*%i+(-100-40*%i)*x)/_
+   sqrt(-7+2*x+5*x^2))+(-1/10+1/20*%i)*atanh((1/100+1/50*%i)*_
+   (-164+8*%i+(-100+40*%i)*x)/sqrt(-7+2*x+5*x^2))
+--R 
+--R
+--R   (2)
+--R                        9   8        9   16
+--R                       (- + - %i)x + - + -- %i
+--R       1    1           5   5        5    5
+--R     (-- - -- %i)atanh(-----------------------)
+--R      10   20               +------------+
+--R                            |  2
+--R                           \|5x  + 2x - 7
+--R   + 
+--R                       8   9        16   9
+--R                      (- + - %i)x + -- + - %i
+--R       1    1          5   5         5   5
+--R     (-- - -- %i)atan(-----------------------)
+--R      20   10              +------------+
+--R                           |  2
+--R                          \|5x  + 2x - 7
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 508
+
+--S 509 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                 Type: Expression(Complex(Fraction(Integer)))
+--E 509
+
+)clear all
+
+--S 510 of 940
+t0:=(-x+2*x^3+4*x^5)/(3+2*x^2+x^4)^2
+--R 
+--R
+--R                 5     3
+--R               4x  + 2x  - x
+--R   (1)  --------------------------
+--R         8     6      4      2
+--R        x  + 4x  + 10x  + 12x  + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 510
+
+--S 511 of 940
+r0a:=1/8*(5-7*x^2)/(3+2*x^2+x^4)+9/8*atan((1+x^2)/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                2      +-+
+--R           4      2           (x  + 1)\|2          2      +-+
+--R        (9x  + 18x  + 27)atan(------------) + (- 7x  + 5)\|2
+--R                                    2
+--R   (2)  -----------------------------------------------------
+--R                           4      2       +-+
+--R                        (8x  + 16x  + 24)\|2
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 940
+r0b:=-2*x^2/(3+2*x^2+x^4)+1/8*(5+9*x^2)/(3+2*x^2+x^4)+_
+   9/8*atan((1+x^2)/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                2      +-+
+--R           4      2           (x  + 1)\|2          2      +-+
+--R        (9x  + 18x  + 27)atan(------------) + (- 7x  + 5)\|2
+--R                                    2
+--R   (3)  -----------------------------------------------------
+--R                           4      2       +-+
+--R                        (8x  + 16x  + 24)\|2
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 940
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 513
+
+--S 514 of 940
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 514
+
+)clear all
+
+--S 515 of 940
+t0:=(x+x^5)/(1+2*x^2+2*x^4)^3
+--R 
+--R
+--R                            5
+--R                           x  + x
+--R   (1)  -------------------------------------------
+--R          12      10      8      6      4     2
+--R        8x   + 24x   + 36x  + 32x  + 18x  + 6x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 515
+
+--S 516 of 940
+r0:=1/16*(3+4*x^2)/(1+2*x^2+2*x^4)^2+1/2*(1+2*x^2)/(1+2*x^2+2*x^4)+_
+   atan(1+2*x^2)
+--R 
+--R
+--R   (2)
+--R       8       6       4      2             2           6      4      2
+--R   (64x  + 128x  + 128x  + 64x  + 16)atan(2x  + 1) + 32x  + 48x  + 36x  + 11
+--R   -------------------------------------------------------------------------
+--R                           8       6       4      2
+--R                        64x  + 128x  + 128x  + 64x  + 16
+--R                                                    Type: Expression(Integer)
+--E 516
+
+--S 517 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 517
+
+)clear all
+
+--S 518 of 940
+t0:=(a+b*x+c*x^2)/(d+e*x^2+f*x^4)
+--R 
+--R
+--R            2
+--R         c x  + b x + a
+--R   (1)  ---------------
+--R           4      2
+--R        f x  + e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 518
+
+--S 519 of 940
+r0:=-b*atanh((e+2*f*x^2)/sqrt(e^2-4*d*f))/sqrt(e^2-4*d*f)+atan(x*sqrt(2)*_
+   sqrt(f)/sqrt(e-sqrt(e^2-4*d*f)))*(c+(-c*e+2*a*f)/sqrt(e^2-4*d*f))/_
+   (sqrt(2)*sqrt(f)*sqrt(e-sqrt(e^2-4*d*f)))+atan(x*sqrt(2)*sqrt(f)/_
+   sqrt(e+sqrt(e^2-4*d*f)))*(c+(c*e-2*a*f)/sqrt(e^2-4*d*f))/(sqrt(2)*_
+   sqrt(f)*sqrt(e+sqrt(e^2-4*d*f)))
+--R 
+--R
+--R   (2)
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2                | |          2
+--R         (c\|- 4d f + e   + 2a f - c e)\|\|- 4d f + e   + e
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|f
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4d f + e   + e
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2                |   |          2
+--R         (c\|- 4d f + e   - 2a f + c e)\|- \|- 4d f + e   + e
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|f
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4d f + e   + e
+--R     + 
+--R       -
+--R                                           +--------------------+
+--R                                  2        |   +-----------+
+--R              +-+ +-+         2f x  + e    |   |          2
+--R            b\|2 \|f atanh(--------------)\|- \|- 4d f + e   + e
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4d f + e
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4d f + e   + e
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4d f + e  \|f \|- \|- 4d f + e   + e \|\|- 4d f + e   + e
+--R                                                    Type: Expression(Integer)
+--E 519
+
+--S 520 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 520
+
+)clear all
+
+--S 521 of 940
+t0:=(d+e*x)^2/(a+b*x^2+c*x^4)
+--R 
+--R
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R   (1)  ------------------
+--R             4      2
+--R          c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 521
+
+--S 522 of 940
+r0:=-2*d*e*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)+_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(e^2+(2*c*d^2-b*e^2)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(e^2+(-2*c*d^2+b*e^2)/_
+   sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                           +------------------+
+--R             +-----------+                 | +-----------+
+--R           2 |          2       2       2  | |          2
+--R         (e \|- 4a c + b   - b e  + 2c d )\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                           +--------------------+
+--R             +-----------+                 |   +-----------+
+--R           2 |          2       2       2  |   |          2
+--R         (e \|- 4a c + b   + b e  - 2c d )\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                                              +--------------------+
+--R                                     2        |   +-----------+
+--R                 +-+ +-+         2c x  + b    |   |          2
+--R            2d e\|2 \|c atanh(--------------)\|- \|- 4a c + b   + b
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 522
+
+--S 523 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 523
+
+)clear all
+
+--S 524 of 940
+t0:=sqrt(1+2*x^2)/(1+sqrt(1+2*x^2))
+--R 
+--R
+--R           +-------+
+--R           |  2
+--R          \|2x  + 1
+--R   (1)  --------------
+--R         +-------+
+--R         |  2
+--R        \|2x  + 1  + 1
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 940
+r0:=(-1/2)/x+x-asinh(x*sqrt(2))/sqrt(2)+1/2*sqrt(1+2*x^2)/x
+--R 
+--R
+--R             +-------+
+--R         +-+ |  2                   +-+       2      +-+
+--R        \|2 \|2x  + 1  - 2x asinh(x\|2 ) + (2x  - 1)\|2
+--R   (2)  ------------------------------------------------
+--R                                +-+
+--R                             2x\|2
+--R                                                    Type: Expression(Integer)
+--E 525
+
+--S 526 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 526
+
+)clear all
+
+--S 527 of 940
+t0:=sqrt(-1+4*x^2)/(x+sqrt(-1+4*x^2))
+--R 
+--R
+--R           +-------+
+--R           |  2
+--R          \|4x  - 1
+--R   (1)  --------------
+--R         +-------+
+--R         |  2
+--R        \|4x  - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 940
+r0:=4/3*x-1/3*atanh(x*sqrt(3))/sqrt(3)+1/3*atanh(sqrt(3)*_
+   sqrt(-1+4*x^2))/sqrt(3)-1/3*sqrt(-1+4*x^2)
+--R 
+--R
+--R                   +-------+         +-------+
+--R               +-+ |  2          +-+ |  2                +-+       +-+
+--R        atanh(\|3 \|4x  - 1 ) - \|3 \|4x  - 1  - atanh(x\|3 ) + 4x\|3
+--R   (2)  --------------------------------------------------------------
+--R                                       +-+
+--R                                     3\|3
+--R                                                    Type: Expression(Integer)
+--E 528
+
+--S 529 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 529
+
+)clear all
+
+--S 530 of 940
+t0:=x^2/((a+b*x)*(c+d*x))
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R             2
+--R        b d x  + (a d + b c)x + a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 530
+
+--S 531 of 940
+r0:=x/(b*d)+a^2*log(a+b*x)/(b^2*(b*c-a*d))-c^2*log(c+d*x)/(d^2*(b*c-a*d))
+--R 
+--R
+--R         2 2                2 2                     2    2
+--R        b c log(d x + c) - a d log(b x + a) + (a b d  - b c d)x
+--R   (2)  -------------------------------------------------------
+--R                               2 3    3   2
+--R                            a b d  - b c d
+--R                                                    Type: Expression(Integer)
+--E 531
+
+--S 532 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 532
+
+)clear all
+
+--S 533 of 940
+t0:=x^2/((c+d*x)*(a+b*x^2))
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R             3        2
+--R        b d x  + b c x  + a d x + a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 533
+
+--S 534 of 940
+r0:=c^2*log(c+d*x)/(d*(b*c^2+a*d^2))+1/2*a*d*log(a+b*x^2)/(b*(b*c^2+a*d^2))-_
+   c*atan(x*sqrt(b)/sqrt(a))*sqrt(a)/((b*c^2+a*d^2)*sqrt(b))
+--R 
+--R
+--R                           +-+
+--R                 +-+     x\|b         2       2            2              +-+
+--R        - 2b c d\|a atan(-----) + (a d log(b x  + a) + 2b c log(d x + c))\|b
+--R                           +-+
+--R                          \|a
+--R   (2)  ---------------------------------------------------------------------
+--R                                       3     2 2   +-+
+--R                                (2a b d  + 2b c d)\|b
+--R                                                    Type: Expression(Integer)
+--E 534
+
+--S 535 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 535
+
+)clear all
+
+--S 536 of 940
+t0:=x^2/((c+d*x)*(a+b*x^3))
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R             4        3
+--R        b d x  + b c x  + a d x + a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 536
+
+--S 537 of 940
+r0:=1/3*a^(1/3)*d*(b^(1/3)*c+a^(1/3)*d)*log(a^(1/3)+b^(1/3)*x)/(b^(2/3)*_
+   (b*c^3-a*d^3))-c^2*log(c+d*x)/(b*c^3-a*d^3)-1/6*a^(1/3)*d*(b^(1/3)*c+_
+   a^(1/3)*d)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(b^(2/3)*(b*c^3-_
+   a*d^3))+1/3*c^2*log(a+b*x^3)/(b*c^3-a*d^3)-a^(1/3)*d*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(b^(2/3)*(b^(2/3)*c^2+a^(1/3)*b^(1/3)*_
+   c*d+a^(2/3)*d^2)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              4      3   +-+3+-+3+-+2       2 2 +-+3+-+2 3+-+          3 +-+
+--R         ((a d  + b c d)\|3 \|a \|b   + 2b c d \|3 \|a   \|b + 2a b c d \|3 )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R                    4       3   +-+3+-+3+-+2       2 2 +-+3+-+2 3+-+
+--R             (- 2a d  - 2b c d)\|3 \|a \|b   - 4b c d \|3 \|a   \|b
+--R           + 
+--R                       3 +-+
+--R             - 4a b c d \|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                                       3+-+   3+-+
+--R            4       3  3+-+3+-+2     2x\|b  - \|a
+--R       (6a d  - 6b c d)\|a \|b  atan(-------------)
+--R                                         +-+3+-+
+--R                                        \|3 \|a
+--R     + 
+--R              3  +-+       3            3  +-+             3+-+3+-+2
+--R       (- 2b c d\|3 log(b x  + a) + 6b c d\|3 log(d x + c))\|a \|b
+--R     + 
+--R              2 2 +-+       3            2 2 +-+             3+-+2 3+-+
+--R       (- 2b c d \|3 log(b x  + a) + 6b c d \|3 log(d x + c))\|a   \|b
+--R     + 
+--R           2 4 +-+       3          2 4 +-+
+--R       - 2b c \|3 log(b x  + a) + 6b c \|3 log(d x + c)
+--R  /
+--R                4     2 4   +-+3+-+3+-+2          5     2 3 2  +-+3+-+2 3+-+
+--R       (6a b c d  - 6b c d)\|3 \|a \|b   + (6a b d  - 6b c d )\|3 \|a   \|b
+--R     + 
+--R            2 2 3     3 5  +-+
+--R       (6a b c d  - 6b c )\|3
+--R                                                    Type: Expression(Integer)
+--E 537
+
+--S 538 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 538
+
+)clear all
+
+--S 539 of 940
+t0:=x^2/((c+d*x)*(a+b*x^4))
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R             5        4
+--R        b d x  + b c x  + a d x + a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 539
+
+--S 540 of 940
+r0:=c^2*d*log(c+d*x)/(b*c^4+a*d^4)-1/4*c^2*d*log(a+b*x^4)/(b*c^4+a*d^4)+_
+   1/2*d^3*atan(x^2*sqrt(b)/sqrt(a))*sqrt(a)/((b*c^4+a*d^4)*sqrt(b))-_
+   1/2*c*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(-d^2*sqrt(a)+c^2*sqrt(b))/_
+   (a^(1/4)*b^(1/4)*(b*c^4+a*d^4)*sqrt(2))+1/2*c*atan(1+b^(1/4)*x*_
+   sqrt(2)/a^(1/4))*(-d^2*sqrt(a)+c^2*sqrt(b))/(a^(1/4)*b^(1/4)*_
+   (b*c^4+a*d^4)*sqrt(2))+1/4*c*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+_
+   x^2*sqrt(b))*(d^2*sqrt(a)+c^2*sqrt(b))/(a^(1/4)*b^(1/4)*(b*c^4+a*d^4)*_
+   sqrt(2))-1/4*c*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*_
+   (d^2*sqrt(a)+c^2*sqrt(b))/(a^(1/4)*b^(1/4)*(b*c^4+a*d^4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2 +-+ +-+      3       +-+4+-+4+-+    2 +-+    +-+
+--R       (- c d \|a \|b  - b c )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R           2 +-+ +-+      3         +-+4+-+4+-+    2 +-+    +-+
+--R       (c d \|a \|b  + b c )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                       +-+4+-+   4+-+
+--R              2 +-+ +-+       3      x\|2 \|b  + \|a
+--R       (- 2c d \|a \|b  + 2b c )atan(----------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                       +-+4+-+   4+-+
+--R              2 +-+ +-+       3      x\|2 \|b  - \|a
+--R       (- 2c d \|a \|b  + 2b c )atan(----------------)
+--R                                           4+-+
+--R                                           \|a
+--R     + 
+--R                                2 +-+
+--R         3 +-+ +-+4+-+4+-+     x \|b
+--R       2d \|2 \|a \|a \|b atan(------)
+--R                                 +-+
+--R                                \|a
+--R     + 
+--R           2  +-+       4          2  +-+             4+-+ +-+4+-+
+--R       (- c d\|2 log(b x  + a) + 4c d\|2 log(d x + c))\|a \|b \|b
+--R  /
+--R          4       4  +-+4+-+ +-+4+-+
+--R     (4a d  + 4b c )\|2 \|a \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 540
+
+--S 541 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 541
+
+)clear all
+
+--S 542 of 940
+t0:=x/((1-x)*(1+x)^2)
+--R 
+--R
+--R                 x
+--R   (1)  - ---------------
+--R           3    2
+--R          x  + x  - x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 542
+
+--S 543 of 940
+r0:=1/2/(1+x)+1/2*atanh(x)
+--R 
+--R
+--R        (x + 1)atanh(x) + 1
+--R   (2)  -------------------
+--R               2x + 2
+--R                                                    Type: Expression(Integer)
+--E 543
+
+--S 544 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 544
+
+)clear all
+
+--S 545 of 940
+t0:=x^2/((1-x^2)*(1+x^2)^2)
+--R 
+--R
+--R                  2
+--R                 x
+--R   (1)  - ----------------
+--R           6    4    2
+--R          x  + x  - x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 545
+
+--S 546 of 940
+r0:=-1/4*x/(1+x^2)+1/4*atanh(x)
+--R 
+--R
+--R          2
+--R        (x  + 1)atanh(x) - x
+--R   (2)  --------------------
+--R                 2
+--R               4x  + 4
+--R                                                    Type: Expression(Integer)
+--E 546
+
+--S 547 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 547
+
+)clear all
+
+--S 548 of 940
+t0:=x^3/((1-x^3)*(1+x^3)^2)
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  - ----------------
+--R           9    6    3
+--R          x  + x  - x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 548
+
+--S 549 of 940
+r0:=-1/6*x/(1+x^3)+1/6*atanh(x)-1/9*log(1+x)+1/72*log(1-x+x^2)+_
+   1/24*log(1+x+x^2)+1/12*atan((1-2*x)/sqrt(3))/sqrt(3)+_
+   1/4*atan((1+2*x)/sqrt(3))/sqrt(3),1/18/(1+x)+1/18*(-1-x)/(1-x+x^2)-_
+   1/12*log(1-x)-1/36*log(1+x)+1/72*log(1-x+x^2)+1/24*log(1+x+x^2)+_
+   1/12*atan((1-2*x)/sqrt(3))/sqrt(3)+1/4*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R   [
+--R            3      +-+     2              3      +-+     2
+--R         (3x  + 3)\|3 log(x  + x + 1) + (x  + 1)\|3 log(x  - x + 1)
+--R       + 
+--R              3      +-+                 3       +-+
+--R         (- 8x  - 8)\|3 log(x + 1) + (12x  + 12)\|3 atanh(x)
+--R       + 
+--R                                +-+                             +-+
+--R           3           (2x + 1)\|3          3          (2x - 1)\|3         +-+
+--R       (18x  + 18)atan(------------) + (- 6x  - 6)atan(------------) - 12x\|3
+--R                             3                               3
+--R    /
+--R           3       +-+
+--R       (72x  + 72)\|3
+--R     ,
+--R
+--R            3      +-+     2              3      +-+     2
+--R         (3x  + 3)\|3 log(x  + x + 1) + (x  + 1)\|3 log(x  - x + 1)
+--R       + 
+--R              3      +-+                  3      +-+
+--R         (- 2x  - 2)\|3 log(x + 1) + (- 6x  - 6)\|3 log(- x + 1)
+--R       + 
+--R                                +-+                             +-+
+--R           3           (2x + 1)\|3          3          (2x - 1)\|3         +-+
+--R       (18x  + 18)atan(------------) + (- 6x  - 6)atan(------------) - 12x\|3
+--R                             3                               3
+--R    /
+--R           3       +-+
+--R       (72x  + 72)\|3
+--R     ]
+--R                                             Type: Tuple(Expression(Integer))
+--E 549
+
+--S 550 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 550
+
+)clear all
+
+--S 551 of 940
+t0:=(9+x+3*x^2+x^3)/((1+x^2)*(3+x^2))
+--R 
+--R
+--R         3     2
+--R        x  + 3x  + x + 9
+--R   (1)  ----------------
+--R           4     2
+--R          x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 551
+
+--S 552 of 940
+r0:=3*atan(x)+1/2*log(3+x^2)
+--R 
+--R
+--R             2
+--R        log(x  + 3) + 6atan(x)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 552
+
+--S 553 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 553
+
+)clear all
+
+--S 554 of 940
+t0:=(3+x+x^2+x^3)/((1+x^2)*(3+x^2))
+--R 
+--R
+--R         3    2
+--R        x  + x  + x + 3
+--R   (1)  ---------------
+--R           4     2
+--R          x  + 4x  + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 554
+
+--S 555 of 940
+r0:=atan(x)+1/2*log(3+x^2)
+--R 
+--R
+--R             2
+--R        log(x  + 3) + 2atan(x)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 555
+
+--S 556 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 556
+
+)clear all
+
+--S 557 of 940
+t0:=(-4+6*x-x^2+3*x^3)/((1+x^2)*(2+x^2))
+--R 
+--R
+--R          3    2
+--R        3x  - x  + 6x - 4
+--R   (1)  -----------------
+--R            4     2
+--R           x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 557
+
+--S 558 of 940
+r0:=-3*atan(x)+3/2*log(1+x^2)+atan(x/sqrt(2))*sqrt(2)
+--R 
+--R
+--R                                   +-+
+--R              2          +-+     x\|2
+--R        3log(x  + 1) + 2\|2 atan(-----) - 6atan(x)
+--R                                   2
+--R   (2)  ------------------------------------------
+--R                             2
+--R                                                    Type: Expression(Integer)
+--E 558
+
+--S 559 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 559
+
+)clear all
+
+--S 560 of 940
+t0:=(1-3*x^4)/((-2+x)*(1+x^2)^2)
+--R 
+--R
+--R                      4
+--R                  - 3x  + 1
+--R   (1)  ----------------------------
+--R         5     4     3     2
+--R        x  - 2x  + 2x  - 4x  + x - 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 560
+
+--S 561 of 940
+r0:=1/5*(-1+2*x)/(1+x^2)-46/25*atan(x)-47/25*log(2-x)-14/25*log(1+x^2)
+--R 
+--R
+--R   (2)
+--R             2           2              2
+--R       (- 14x  - 14)log(x  + 1) + (- 47x  - 47)log(- x + 2)
+--R     + 
+--R             2
+--R       (- 46x  - 46)atan(x) + 10x - 5
+--R  /
+--R        2
+--R     25x  + 25
+--R                                                    Type: Expression(Integer)
+--E 561
+
+--S 562 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 562
+
+)clear all
+
+--S 563 of 940
+t0:=(-9-9*x+2*x^2)/(-9*x+x^3)
+--R 
+--R
+--R          2
+--R        2x  - 9x - 9
+--R   (1)  ------------
+--R            3
+--R           x  - 9x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 563
+
+--S 564 of 940
+r0:=-log(3-x)+log(x)+2*log(3+x)
+--R 
+--R
+--R   (2)  2log(x + 3) + log(x) - log(- x + 3)
+--R                                                    Type: Expression(Integer)
+--E 564
+
+--S 565 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 565
+
+)clear all
+
+--S 566 of 940
+t0:=(1+2*x^2+x^5)/(-x+x^3)
+--R 
+--R
+--R         5     2
+--R        x  + 2x  + 1
+--R   (1)  ------------
+--R            3
+--R           x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 566
+
+--S 567 of 940
+r0:=x+1/3*x^3+2*log(1-x)-log(x)+log(1+x)
+--R 
+--R
+--R                                                 3
+--R        3log(x + 1) - 3log(x) + 6log(- x + 1) + x  + 3x
+--R   (2)  -----------------------------------------------
+--R                               3
+--R                                                    Type: Expression(Integer)
+--E 567
+
+--S 568 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 568
+
+)clear all
+
+--S 569 of 940
+t0:=(3+2*x^2)/((-1+x)^2*x)
+--R 
+--R
+--R             2
+--R           2x  + 3
+--R   (1)  ------------
+--R         3     2
+--R        x  - 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 569
+
+--S 570 of 940
+r0:=5/(1-x)-log(1-x)+3*log(x)
+--R 
+--R
+--R        (3x - 3)log(x) + (- x + 1)log(- x + 1) - 5
+--R   (2)  ------------------------------------------
+--R                           x - 1
+--R                                                    Type: Expression(Integer)
+--E 570
+
+--S 571 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 571
+
+)clear all
+
+--S 572 of 940
+t0:=(-1+2*x^2)/((-1+4*x)*(1+x^2))
+--R 
+--R
+--R               2
+--R             2x  - 1
+--R   (1)  -----------------
+--R          3    2
+--R        4x  - x  + 4x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 572
+
+--S 573 of 940
+r0:=3/17*atan(x)-7/34*log(1-4*x)+6/17*log(1+x^2)
+--R 
+--R
+--R               2
+--R        12log(x  + 1) - 7log(- 4x + 1) + 6atan(x)
+--R   (2)  -----------------------------------------
+--R                            34
+--R                                                    Type: Expression(Integer)
+--E 573
+
+--S 574 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 574
+
+)clear all
+
+--S 575 of 940
+t0:=(-3+2*x-3*x^2+x^3)/(1+x^2)
+--R 
+--R
+--R         3     2
+--R        x  - 3x  + 2x - 3
+--R   (1)  -----------------
+--R               2
+--R              x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 575
+
+--S 576 of 940
+r0:=-3*x+1/2*x^2+1/2*log(1+x^2)
+--R 
+--R
+--R             2         2
+--R        log(x  + 1) + x  - 6x
+--R   (2)  ---------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 576
+
+--S 577 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 577
+
+)clear all
+
+--S 578 of 940
+t0:=(x+10*x^2+6*x^3+x^4)/(10+6*x+x^2)
+--R 
+--R
+--R         4     3      2
+--R        x  + 6x  + 10x  + x
+--R   (1)  -------------------
+--R             2
+--R            x  + 6x + 10
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 578
+
+--S 579 of 940
+r0:=1/3*x^3-3*atan(3+x)+1/2*log(10+6*x+x^2)
+--R 
+--R
+--R              2                                3
+--R        3log(x  + 6x + 10) - 18atan(x + 3) + 2x
+--R   (2)  ----------------------------------------
+--R                            6
+--R                                                    Type: Expression(Integer)
+--E 579
+
+--S 580 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 580
+
+)clear all
+
+--S 581 of 940
+t0:=1/(-18+27*x-7*x^2-3*x^3+x^4)
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R         4     3     2
+--R        x  - 3x  - 7x  + 27x - 18
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 581
+
+--S 582 of 940
+r0:=1/8*log(1-x)-1/5*log(2-x)+1/12*log(3-x)-1/120*log(3+x)
+--R 
+--R
+--R        - log(x + 3) + 10log(- x + 3) - 24log(- x + 2) + 15log(- x + 1)
+--R   (2)  ---------------------------------------------------------------
+--R                                      120
+--R                                                    Type: Expression(Integer)
+--E 582
+
+--S 583 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 583
+
+)clear all
+
+--S 584 of 940
+t0:=(1+x^3)/(-2+x)
+--R 
+--R
+--R         3
+--R        x  + 1
+--R   (1)  ------
+--R         x - 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 584
+
+--S 585 of 940
+r0:=4*x+x^2+1/3*x^3+9*log(2-x)
+--R 
+--R
+--R                          3     2
+--R        27log(- x + 2) + x  + 3x  + 12x
+--R   (2)  -------------------------------
+--R                       3
+--R                                                    Type: Expression(Integer)
+--E 585
+
+--S 586 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 586
+
+)clear all
+
+--S 587 of 940
+t0:=x/(2-3*x+x^3)
+--R 
+--R
+--R             x
+--R   (1)  -----------
+--R         3
+--R        x  - 3x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 587
+
+--S 588 of 940
+r0:=1/3/(1-x)+2/9*log(1-x)-2/9*log(2+x)
+--R 
+--R
+--R        (- 2x + 2)log(x + 2) + (2x - 2)log(- x + 1) - 3
+--R   (2)  -----------------------------------------------
+--R                             9x - 9
+--R                                                    Type: Expression(Integer)
+--E 588
+
+--S 589 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 589
+
+)clear all
+
+--S 590 of 940
+t0:=(-6+2*x+x^4)/(-2*x+x^2+x^3)
+--R 
+--R
+--R          4
+--R         x  + 2x - 6
+--R   (1)  ------------
+--R         3    2
+--R        x  + x  - 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 590
+
+--S 591 of 940
+r0:=-x+1/2*x^2-log(1-x)+3*log(x)+log(2+x)
+--R 
+--R
+--R                                                 2
+--R        2log(x + 2) + 6log(x) - 2log(- x + 1) + x  - 2x
+--R   (2)  -----------------------------------------------
+--R                               2
+--R                                                    Type: Expression(Integer)
+--E 591
+
+--S 592 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 592
+
+)clear all
+
+--S 593 of 940
+t0:=(7+8*x^3)/((1+x)*(1+2*x)^3)
+--R 
+--R
+--R                    3
+--R                  8x  + 7
+--R   (1)  --------------------------
+--R          4      3      2
+--R        8x  + 20x  + 18x  + 7x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 593
+
+--S 594 of 940
+r0:=(-3)/(1+2*x)^2+3/(1+2*x)+log(1+x)
+--R 
+--R
+--R           2
+--R        (4x  + 4x + 1)log(x + 1) + 6x
+--R   (2)  -----------------------------
+--R                   2
+--R                 4x  + 4x + 1
+--R                                                    Type: Expression(Integer)
+--E 594
+
+--S 595 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 595
+
+)clear all
+
+--S 596 of 940
+t0:=(1+x^4)/(x*(1+x^2)^2)
+--R 
+--R
+--R            4
+--R           x  + 1
+--R   (1)  ------------
+--R         5     3
+--R        x  + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 596
+
+--S 597 of 940
+r0:=1/(1+x^2)+log(x)
+--R 
+--R
+--R          2
+--R        (x  + 1)log(x) + 1
+--R   (2)  ------------------
+--R               2
+--R              x  + 1
+--R                                                    Type: Expression(Integer)
+--E 597
+
+--S 598 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 598
+
+)clear all
+
+--S 599 of 940
+t0:=(1-x^3)/(x*(1+x^2))
+--R 
+--R
+--R           3
+--R        - x  + 1
+--R   (1)  --------
+--R          3
+--R         x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 599
+
+--S 600 of 940
+r0:=-x+atan(x)+log(x)-1/2*log(1+x^2)
+--R 
+--R
+--R               2
+--R        - log(x  + 1) + 2log(x) + 2atan(x) - 2x
+--R   (2)  ---------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 600
+
+--S 601 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 601
+
+)clear all
+
+--S 602 of 940
+t0:=(3*x-4*x^2+3*x^3)/(1+x^2)
+--R 
+--R
+--R          3     2
+--R        3x  - 4x  + 3x
+--R   (1)  --------------
+--R             2
+--R            x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 602
+
+--S 603 of 940
+r0:=-4*x+3/2*x^2+4*atan(x)
+--R 
+--R
+--R                     2
+--R        8atan(x) + 3x  - 8x
+--R   (2)  -------------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 603
+
+--S 604 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 604
+
+)clear all
+
+--S 605 of 940
+t0:=(5+3*x)/(1-x-x^2+x^3)
+--R 
+--R
+--R             3x + 5
+--R   (1)  ---------------
+--R         3    2
+--R        x  - x  - x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 605
+
+--S 606 of 940
+r0:=4/(1-x)+atanh(x)
+--R 
+--R
+--R        (x - 1)atanh(x) - 4
+--R   (2)  -------------------
+--R               x - 1
+--R                                                    Type: Expression(Integer)
+--E 606
+
+--S 607 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 607
+
+)clear all
+
+--S 608 of 940
+t0:=(-1-x-x^3+x^4)/(-x^2+x^3)
+--R 
+--R
+--R         4    3
+--R        x  - x  - x - 1
+--R   (1)  ---------------
+--R             3    2
+--R            x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 608
+
+--S 609 of 940
+r0:=(-1)/x+1/2*x^2-2*log(1-x)+2*log(x)
+--R 
+--R
+--R                                       3
+--R        4x log(x) - 4x log(- x + 1) + x  - 2
+--R   (2)  ------------------------------------
+--R                         2x
+--R                                                    Type: Expression(Integer)
+--E 609
+
+--S 610 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 610
+
+)clear all
+
+--S 611 of 940
+t0:=(2+x+x^2+x^3)/(2+3*x^2+x^4)
+--R 
+--R
+--R         3    2
+--R        x  + x  + x + 2
+--R   (1)  ---------------
+--R           4     2
+--R          x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 611
+
+--S 612 of 940
+r0:=atan(x)+1/2*log(2+x^2)
+--R 
+--R
+--R             2
+--R        log(x  + 2) + 2atan(x)
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 612
+
+--S 613 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 613
+
+)clear all
+
+--S 614 of 940
+t0:=(-4+8*x-4*x^2+4*x^3-x^4+x^5)/(2+x^2)^3
+--R 
+--R
+--R         5    4     3     2
+--R        x  - x  + 4x  - 4x  + 8x - 4
+--R   (1)  ----------------------------
+--R              6     4      2
+--R             x  + 6x  + 12x  + 8
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 614
+
+--S 615 of 940
+r0:=(-1)/(2+x^2)^2+1/2*log(2+x^2)-atan(x/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                                                +-+
+--R          4     2      +-+     2             4     2          x\|2       +-+
+--R        (x  + 4x  + 4)\|2 log(x  + 2) + (- 2x  - 8x  - 8)atan(-----) - 2\|2
+--R                                                                2
+--R   (2)  --------------------------------------------------------------------
+--R                                    4     2      +-+
+--R                                 (2x  + 8x  + 8)\|2
+--R                                                    Type: Expression(Integer)
+--E 615
+
+--S 616 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 616
+
+)clear all
+
+--S 617 of 940
+t0:=(-1-3*x+x^2)/(-2*x+x^2+x^3)
+--R 
+--R
+--R          2
+--R         x  - 3x - 1
+--R   (1)  ------------
+--R         3    2
+--R        x  + x  - 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 617
+
+--S 618 of 940
+r0:=-log(1-x)+1/2*log(x)+3/2*log(2+x)
+--R 
+--R
+--R        3log(x + 2) + log(x) - 2log(- x + 1)
+--R   (2)  ------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 618
+
+--S 619 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 619
+
+)clear all
+
+--S 620 of 940
+t0:=(3-x+3*x^2-2*x^3+x^4)/(3*x-2*x^2+x^3)
+--R 
+--R
+--R         4     3     2
+--R        x  - 2x  + 3x  - x + 3
+--R   (1)  ----------------------
+--R              3     2
+--R             x  - 2x  + 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 620
+
+--S 621 of 940
+r0:=1/2*x^2+log(x)-1/2*log(3-2*x+x^2)
+--R 
+--R
+--R               2                        2
+--R        - log(x  - 2x + 3) + 2log(x) + x
+--R   (2)  ---------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 621
+
+--S 622 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 622
+
+)clear all
+
+--S 623 of 940
+t0:=(-1+x+x^3)/(1+x^2)^2
+--R 
+--R
+--R          3
+--R         x  + x - 1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 623
+
+--S 624 of 940
+r0:=-1/2*x/(1+x^2)-1/2*atan(x)+1/2*log(1+x^2)
+--R 
+--R
+--R          2          2            2
+--R        (x  + 1)log(x  + 1) + (- x  - 1)atan(x) - x
+--R   (2)  -------------------------------------------
+--R                            2
+--R                          2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 624
+
+--S 625 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 625
+
+)clear all
+
+--S 626 of 940
+t0:=(1+2*x-x^2+8*x^3+x^4)/((x+x^2)*(1+x^3))
+--R 
+--R
+--R         4     3    2
+--R        x  + 8x  - x  + 2x + 1
+--R   (1)  ----------------------
+--R            5    4    2
+--R           x  + x  + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 626
+
+--S 627 of 940
+r0:=(-3)/(1+x)+log(x)-2*log(1+x)+log(1-x+x^2)-2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R               +-+     2                       +-+                     +-+
+--R       (x + 1)\|3 log(x  - x + 1) + (- 2x - 2)\|3 log(x + 1) + (x + 1)\|3 log(x)
+--R     + 
+--R                             +-+
+--R                    (2x - 1)\|3       +-+
+--R       (2x + 2)atan(------------) - 3\|3
+--R                          3
+--R  /
+--R             +-+
+--R     (x + 1)\|3
+--R                                                    Type: Expression(Integer)
+--E 627
+
+--S 628 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 628
+
+)clear all
+
+--S 629 of 940
+t0:=(15-5*x+x^2+x^3)/((5+x^2)*(3+2*x+x^2))
+--R 
+--R
+--R             3    2
+--R            x  + x  - 5x + 15
+--R   (1)  -------------------------
+--R         4     3     2
+--R        x  + 2x  + 8x  + 10x + 15
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 629
+
+--S 630 of 940
+r0:=1/2*log(3+2*x+x^2)+5*atan((1+x)/sqrt(2))/sqrt(2)-atan(x/sqrt(5))*sqrt(5)
+--R 
+--R
+--R                                               +-+                   +-+
+--R         +-+     2               +-+ +-+     x\|5            (x + 1)\|2
+--R        \|2 log(x  + 2x + 3) - 2\|2 \|5 atan(-----) + 10atan(-----------)
+--R                                               5                  2
+--R   (2)  -----------------------------------------------------------------
+--R                                        +-+
+--R                                      2\|2
+--R                                                    Type: Expression(Integer)
+--E 630
+
+--S 631 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 631
+
+)clear all
+
+--S 632 of 940
+t0:=(-3+25*x+23*x^2+32*x^3+15*x^4+7*x^5+x^6)/((1+x^2)^2*(2+x+x^2)^2)
+--R 
+--R
+--R               6     5      4      3      2
+--R              x  + 7x  + 15x  + 32x  + 23x  + 25x - 3
+--R   (1)  --------------------------------------------------
+--R         8     7     6     5      4      3      2
+--R        x  + 2x  + 7x  + 8x  + 15x  + 10x  + 13x  + 4x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 632
+
+--S 633 of 940
+r0:=(-3)/(1+x^2)+1/(2+x+x^2)+log(1+x^2)-log(2+x+x^2)
+--R 
+--R
+--R   (2)
+--R           4    3     2              2
+--R       (- x  - x  - 3x  - x - 2)log(x  + x + 2)
+--R     + 
+--R         4    3     2              2          2
+--R       (x  + x  + 3x  + x + 2)log(x  + 1) - 2x  - 3x - 5
+--R  /
+--R      4    3     2
+--R     x  + x  + 3x  + x + 2
+--R                                                    Type: Expression(Integer)
+--E 633
+
+--S 634 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 634
+
+)clear all
+
+--S 635 of 940
+t0:=1/((1+x^2)*(4+x^2))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         4     2
+--R        x  + 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 635
+
+--S 636 of 940
+r0:=-1/6*atan(1/2*x)+1/3*atan(x)
+--R 
+--R
+--R                        x
+--R        2atan(x) - atan(-)
+--R                        2
+--R   (2)  ------------------
+--R                 6
+--R                                                    Type: Expression(Integer)
+--E 636
+
+--S 637 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 637
+
+)clear all
+
+--S 638 of 940
+t0:=(a+b*x^3)/(1+x^2)
+--R 
+--R
+--R           3
+--R        b x  + a
+--R   (1)  --------
+--R          2
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 638
+
+--S 639 of 940
+r0:=1/2*b*x^2+a*atan(x)-1/2*b*log(1+x^2)
+--R 
+--R
+--R                 2                        2
+--R        - b log(x  + 1) + 2a atan(x) + b x
+--R   (2)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 639
+
+--S 640 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 640
+
+)clear all
+
+--S 641 of 940
+t0:=(x+x^2)/((4+x)*(-4+x^2))
+--R 
+--R
+--R               2
+--R              x  + x
+--R   (1)  ------------------
+--R         3     2
+--R        x  + 4x  - 4x - 16
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 641
+
+--S 642 of 940
+r0:=-1/2*atanh(1/2*x)+log(4+x)
+--R 
+--R
+--R                            x
+--R        2log(x + 4) - atanh(-)
+--R                            2
+--R   (2)  ----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 642
+
+--S 643 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 643
+
+)clear all
+
+--S 644 of 940
+t0:=(4+x^2)/((1+x^2)*(2+x^2))
+--R 
+--R
+--R            2
+--R           x  + 4
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 644
+
+--S 645 of 940
+r0:=3*atan(x)-atan(x/sqrt(2))*sqrt(2)
+--R 
+--R
+--R                     +-+
+--R           +-+     x\|2
+--R   (2)  - \|2 atan(-----) + 3atan(x)
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 645
+
+--S 646 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 646
+
+)clear all
+
+--S 647 of 940
+t0:=(5-4*x+3*x^2+x^4)/((-1+x)^2*(1+x^2))
+--R 
+--R
+--R            4     2
+--R           x  + 3x  - 4x + 5
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  - 2x  + 2x  - 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 647
+
+--S 648 of 940
+r0:=5/2/(1-x)+x+2*atan(x)+1/2*log(1-x)+3/4*log(1+x^2)
+--R 
+--R
+--R   (2)
+--R                2                                                   2
+--R   (3x - 3)log(x  + 1) + (2x - 2)log(- x + 1) + (8x - 8)atan(x) + 4x  - 4x - 10
+--R   ----------------------------------------------------------------------------
+--R                                      4x - 4
+--R                                                    Type: Expression(Integer)
+--E 648
+
+--S 649 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 649
+
+)clear all
+
+--S 650 of 940
+t0:=(1+x^4)/(2+x^2)
+--R 
+--R
+--R         4
+--R        x  + 1
+--R   (1)  ------
+--R         2
+--R        x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 650
+
+--S 651 of 940
+r0:=-2*x+1/3*x^3+5*atan(x/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                 +-+
+--R               x\|2       3       +-+
+--R        15atan(-----) + (x  - 6x)\|2
+--R                 2
+--R   (2)  -----------------------------
+--R                      +-+
+--R                    3\|2
+--R                                                    Type: Expression(Integer)
+--E 651
+
+--S 652 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 652
+
+)clear all
+
+--S 653 of 940
+t0:=(2+2*x+x^4)/(x^4+x^5)
+--R 
+--R
+--R         4
+--R        x  + 2x + 2
+--R   (1)  -----------
+--R           5    4
+--R          x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 653
+
+--S 654 of 940
+r0:=(-2/3)/x^3+log(1+x)
+--R 
+--R
+--R          3
+--R        3x log(x + 1) - 2
+--R   (2)  -----------------
+--R                 3
+--R               3x
+--R                                                    Type: Expression(Integer)
+--E 654
+
+--S 655 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 655
+
+)clear all
+
+--S 656 of 940
+t0:=(-1-5*x+2*x^2)/(2-x-2*x^2+x^3)
+--R 
+--R
+--R            2
+--R          2x  - 5x - 1
+--R   (1)  ----------------
+--R         3     2
+--R        x  - 2x  - x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 656
+
+--S 657 of 940
+r0:=2*log(1-x)-log(2-x)+log(1+x)
+--R 
+--R
+--R   (2)  log(x + 1) - log(- x + 2) + 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 657
+
+--S 658 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 658
+
+)clear all
+
+--S 659 of 940
+t0:=(2+x+x^3)/(1+2*x^2+x^4)
+--R 
+--R
+--R          3
+--R         x  + x + 2
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 659
+
+--S 660 of 940
+r0:=x/(1+x^2)+atan(x)+1/2*log(1+x^2)
+--R 
+--R
+--R          2          2           2
+--R        (x  + 1)log(x  + 1) + (2x  + 2)atan(x) + 2x
+--R   (2)  -------------------------------------------
+--R                            2
+--R                          2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 660
+
+--S 661 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 661
+
+)clear all
+
+--S 662 of 940
+t0:=(1+2*x+x^2+x^3)/(1+2*x^2+x^4)
+--R 
+--R
+--R         3    2
+--R        x  + x  + 2x + 1
+--R   (1)  ----------------
+--R           4     2
+--R          x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 662
+
+--S 663 of 940
+r0:=(-1/2)/(1+x^2)+atan(x)+1/2*log(1+x^2)
+--R 
+--R
+--R          2          2           2
+--R        (x  + 1)log(x  + 1) + (2x  + 2)atan(x) - 1
+--R   (2)  ------------------------------------------
+--R                            2
+--R                          2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 663
+
+--S 664 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 664
+
+)clear all
+
+--S 665 of 940
+t0:=(3+4*x)/((1+x^2)*(2+x^2))
+--R 
+--R
+--R           4x + 3
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 665
+
+--S 666 of 940
+r0:=3*atan(x)+2*log(1+x^2)-2*log(2+x^2)-3*atan(x/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                                        +-+
+--R            +-+     2          +-+     2              x\|2       +-+
+--R        - 2\|2 log(x  + 2) + 2\|2 log(x  + 1) - 3atan(-----) + 3\|2 atan(x)
+--R                                                        2
+--R   (2)  -------------------------------------------------------------------
+--R                                         +-+
+--R                                        \|2
+--R                                                    Type: Expression(Integer)
+--E 666
+
+--S 667 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 667
+
+)clear all
+
+--S 668 of 940
+t0:=(2+x)/((1+x^2)*(4+x^2))
+--R 
+--R
+--R            x + 2
+--R   (1)  ------------
+--R         4     2
+--R        x  + 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 668
+
+--S 669 of 940
+r0:=-1/3*atan(1/2*x)+2/3*atan(x)+1/6*log(1+x^2)-1/6*log(4+x^2)
+--R 
+--R
+--R               2             2                         x
+--R        - log(x  + 4) + log(x  + 1) + 4atan(x) - 2atan(-)
+--R                                                       2
+--R   (2)  -------------------------------------------------
+--R                                6
+--R                                                    Type: Expression(Integer)
+--E 669
+
+--S 670 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 670
+
+)clear all
+
+--S 671 of 940
+t0:=(2-x+x^3)/(-7-6*x+x^2)
+--R 
+--R
+--R          3
+--R         x  - x + 2
+--R   (1)  -----------
+--R         2
+--R        x  - 6x - 7
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 671
+
+--S 672 of 940
+r0:=6*x+1/2*x^2+169/4*log(7-x)-1/4*log(1+x)
+--R 
+--R
+--R                                           2
+--R        - log(x + 1) + 169log(- x + 7) + 2x  + 24x
+--R   (2)  ------------------------------------------
+--R                             4
+--R                                                    Type: Expression(Integer)
+--E 672
+
+--S 673 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 673
+
+)clear all
+
+--S 674 of 940
+t0:=(-1+x^5)/(-1+x^2)
+--R 
+--R
+--R         4    3    2
+--R        x  + x  + x  + x + 1
+--R   (1)  --------------------
+--R                x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 674
+
+--S 675 of 940
+r0:=1/2*x^2+1/4*x^4+log(1+x)
+--R 
+--R
+--R                       4     2
+--R        4log(x + 1) + x  + 2x
+--R   (2)  ----------------------
+--R                   4
+--R                                                    Type: Expression(Integer)
+--E 675
+
+--S 676 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 676
+
+)clear all
+
+--S 677 of 940
+t0:=(5+2*x-x^2+x^3)/(1+x+x^2)
+--R 
+--R
+--R         3    2
+--R        x  - x  + 2x + 5
+--R   (1)  ----------------
+--R            2
+--R           x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 677
+
+--S 678 of 940
+r0:=-2*x+1/2*x^2+3/2*log(1+x+x^2)+11*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                               +-+
+--R          +-+     2                   (2x + 1)\|3       2       +-+
+--R        3\|3 log(x  + x + 1) + 22atan(------------) + (x  - 4x)\|3
+--R                                            3
+--R   (2)  -----------------------------------------------------------
+--R                                     +-+
+--R                                   2\|3
+--R                                                    Type: Expression(Integer)
+--E 678
+
+--S 679 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 679
+
+)clear all
+
+--S 680 of 940
+t0:=(-3+x-2*x^3+x^4)/(10-8*x+2*x^2)
+--R 
+--R
+--R         4     3
+--R        x  - 2x  + x - 3
+--R   (1)  ----------------
+--R            2
+--R          2x  - 8x + 10
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 680
+
+--S 681 of 940
+r0:=3/2*x+1/2*x^2+1/6*x^3+6*atan(2-x)+3/4*log(5-4*x+x^2)
+--R 
+--R
+--R              2                               3     2
+--R        9log(x  - 4x + 5) - 72atan(x - 2) + 2x  + 6x  + 18x
+--R   (2)  ---------------------------------------------------
+--R                                 12
+--R                                                    Type: Expression(Integer)
+--E 681
+
+--S 682 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 682
+
+)clear all
+
+--S 683 of 940
+t0:=(1+2*x+3*x^2+x^3)/((-3+x)*(-2+x)*(-1+x))
+--R 
+--R
+--R          3     2
+--R         x  + 3x  + 2x + 1
+--R   (1)  ------------------
+--R         3     2
+--R        x  - 6x  + 11x - 6
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 683
+
+--S 684 of 940
+r0:=x+7/2*log(1-x)-25*log(2-x)+61/2*log(3-x)
+--R 
+--R
+--R        61log(- x + 3) - 50log(- x + 2) + 7log(- x + 1) + 2x
+--R   (2)  ----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 684
+
+--S 685 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 685
+
+)clear all
+
+--S 686 of 940
+t0:=(2-7*x+x^2-x^3+x^4)/(-24-14*x+x^2+x^3)
+--R 
+--R
+--R         4    3    2
+--R        x  - x  + x  - 7x + 2
+--R   (1)  ---------------------
+--R           3    2
+--R          x  + x  - 14x - 24
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 686
+
+--S 687 of 940
+r0:=-2*x+1/2*x^2+13/3*log(4-x)-22/3*log(2+x)+20*log(3+x)
+--R 
+--R
+--R                                                          2
+--R        120log(x + 3) - 44log(x + 2) + 26log(- x + 4) + 3x  - 12x
+--R   (2)  ---------------------------------------------------------
+--R                                    6
+--R                                                    Type: Expression(Integer)
+--E 687
+
+--S 688 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 688
+
+)clear all
+
+--S 689 of 940
+t0:=(2+x^2)/((-1+x)^2*x*(1+x))
+--R 
+--R
+--R              2
+--R             x  + 2
+--R   (1)  ----------------
+--R         4    3    2
+--R        x  - x  - x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 689
+
+--S 690 of 940
+r0:=3/2/(1-x)-5/4*log(1-x)+2*log(x)-3/4*log(1+x)
+--R 
+--R
+--R        (- 3x + 3)log(x + 1) + (8x - 8)log(x) + (- 5x + 5)log(- x + 1) - 6
+--R   (2)  ------------------------------------------------------------------
+--R                                      4x - 4
+--R                                                    Type: Expression(Integer)
+--E 690
+
+--S 691 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 691
+
+)clear all
+
+--S 692 of 940
+t0:=(3+x^2+x^3)/(2+x^2)^2
+--R 
+--R
+--R          3    2
+--R         x  + x  + 3
+--R   (1)  ------------
+--R         4     2
+--R        x  + 4x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 692
+
+--S 693 of 940
+r0:=1/4*(4+x)/(2+x^2)+1/2*log(2+x^2)+5/4*atan(x/sqrt(2))/sqrt(2)
+--R 
+--R
+--R                                                    +-+
+--R           2      +-+     2           2           x\|2             +-+
+--R        (2x  + 4)\|2 log(x  + 2) + (5x  + 10)atan(-----) + (x + 4)\|2
+--R                                                    2
+--R   (2)  --------------------------------------------------------------
+--R                                    2      +-+
+--R                                 (4x  + 8)\|2
+--R                                                    Type: Expression(Integer)
+--E 693
+
+--S 694 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 694
+
+)clear all
+
+--S 695 of 940
+t0:=(-35+70*x-4*x^2+2*x^3)/((26-10*x+x^2)*(17-2*x+x^2))
+--R 
+--R
+--R               3     2
+--R             2x  - 4x  + 70x - 35
+--R   (1)  -----------------------------
+--R         4      3      2
+--R        x  - 12x  + 63x  - 222x + 442
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 695
+
+--S 696 of 940
+r0:=-15033/1025*atan(5-x)+4607/4100*atan(1/4-1/4*x)+_
+   1003/1025*log(26-10*x+x^2)+22/1025*log(17-2*x+x^2)
+--R 
+--R
+--R   (2)
+--R              2                       2
+--R       88log(x  - 2x + 17) + 4012log(x  - 10x + 26) + 60132atan(x - 5)
+--R     + 
+--R                  x - 1
+--R       - 4607atan(-----)
+--R                    4
+--R  /
+--R     4100
+--R                                                    Type: Expression(Integer)
+--E 696
+
+--S 697 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 697
+
+)clear all
+
+--S 698 of 940
+t0:=(2+x^2)/((-5+x)*(-3+x)*(4+x))
+--R 
+--R
+--R                2
+--R               x  + 2
+--R   (1)  -------------------
+--R         3     2
+--R        x  - 4x  - 17x + 60
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 698
+
+--S 699 of 940
+r0:=-11/14*log(3-x)+3/2*log(5-x)+2/7*log(4+x)
+--R 
+--R
+--R        4log(x + 4) + 21log(- x + 5) - 11log(- x + 3)
+--R   (2)  ---------------------------------------------
+--R                              14
+--R                                                    Type: Expression(Integer)
+--E 699
+
+--S 700 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 700
+
+)clear all
+
+--S 701 of 940
+t0:=x^4/((-1+x)*(2+x^2))
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ----------------
+--R         3    2
+--R        x  - x  + 2x - 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 701
+
+--S 702 of 940
+r0:=x+1/2*x^2+1/3*log(1-x)-2/3*log(2+x^2)-2/3*atan(x/sqrt(2))*sqrt(2)
+--R 
+--R
+--R                                                     +-+
+--R                2                          +-+     x\|2       2
+--R        - 4log(x  + 2) + 2log(- x + 1) - 4\|2 atan(-----) + 3x  + 6x
+--R                                                     2
+--R   (2)  ------------------------------------------------------------
+--R                                      6
+--R                                                    Type: Expression(Integer)
+--E 702
+
+--S 703 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 703
+
+)clear all
+
+--S 704 of 940
+t0:=(-1+7*x+2*x^2)/(-1-x+x^2+x^3)
+--R 
+--R
+--R            2
+--R          2x  + 7x - 1
+--R   (1)  ---------------
+--R         3    2
+--R        x  + x  - x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 704
+
+--S 705 of 940
+r0:=(-3)/(1+x)+2*log(1-x)
+--R 
+--R
+--R        (2x + 2)log(- x + 1) - 3
+--R   (2)  ------------------------
+--R                  x + 1
+--R                                                    Type: Expression(Integer)
+--E 705
+
+--S 706 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 706
+
+)clear all
+
+--S 707 of 940
+t0:=(1+2*x)/(-1+3*x-3*x^2+x^3)
+--R 
+--R
+--R              2x + 1
+--R   (1)  -----------------
+--R         3     2
+--R        x  - 3x  + 3x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 707
+
+--S 708 of 940
+r0:=-1/6*(1+2*x)^2/(1-x)^2
+--R 
+--R
+--R          2  2   2     1
+--R        - - x  - - x - -
+--R          3      3     6
+--R   (2)  ----------------
+--R            2
+--R           x  - 2x + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 708
+
+--S 709 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 709
+
+)clear all
+
+--S 710 of 940
+t0:=(5-5*x+7*x^2+x^3)/((-1+x)^2*(1+x)^3)
+--R 
+--R
+--R              3     2
+--R             x  + 7x  - 5x + 5
+--R   (1)  ---------------------------
+--R         5    4     3     2
+--R        x  + x  - 2x  - 2x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 710
+
+--S 711 of 940
+r0:=1/(1-x)+(-2)/(1+x)^2
+--R 
+--R
+--R            2
+--R         - x  - 4x + 1
+--R   (2)  ---------------
+--R         3    2
+--R        x  + x  - x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 711
+
+--S 712 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 712
+
+)clear all
+
+--S 713 of 940
+t0:=(1+3*x+3*x^2)/(1+2*x+2*x^2+x^3)
+--R 
+--R
+--R             2
+--R           3x  + 3x + 1
+--R   (1)  -----------------
+--R         3     2
+--R        x  + 2x  + 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 713
+
+--S 714 of 940
+r0:=log(1+x)+log(1+x+x^2)-2*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                              +-+
+--R         +-+     2             +-+                   (2x + 1)\|3
+--R        \|3 log(x  + x + 1) + \|3 log(x + 1) - 2atan(------------)
+--R                                                           3
+--R   (2)  ----------------------------------------------------------
+--R                                    +-+
+--R                                   \|3
+--R                                                    Type: Expression(Integer)
+--E 714
+
+--S 715 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 715
+
+)clear all
+
+--S 716 of 940
+t0:=(-1+2*x+x^2)/(-2*x+3*x^2+2*x^3)
+--R 
+--R
+--R           2
+--R          x  + 2x - 1
+--R   (1)  --------------
+--R          3     2
+--R        2x  + 3x  - 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 716
+
+--S 717 of 940
+r0:=1/10*log(1-2*x)+1/2*log(x)-1/10*log(2+x)
+--R 
+--R
+--R        - log(x + 2) + 5log(x) + log(- 2x + 1)
+--R   (2)  --------------------------------------
+--R                          10
+--R                                                    Type: Expression(Integer)
+--E 717
+
+--S 718 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 718
+
+)clear all
+
+--S 719 of 940
+t0:=(1+4*x-2*x^2+x^4)/(1-x-x^2+x^3)
+--R 
+--R
+--R         4     2
+--R        x  - 2x  + 4x + 1
+--R   (1)  -----------------
+--R          3    2
+--R         x  - x  - x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 719
+
+--S 720 of 940
+r0:=2/(1-x)+x+1/2*x^2-2*atanh(x)
+--R 
+--R
+--R                              3    2
+--R        (- 4x + 4)atanh(x) + x  + x  - 2x - 4
+--R   (2)  -------------------------------------
+--R                        2x - 2
+--R                                                    Type: Expression(Integer)
+--E 720
+
+--S 721 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 721
+
+)clear all
+
+--S 722 of 940
+t0:=(4-x+2*x^2)/(4*x+x^3)
+--R 
+--R
+--R          2
+--R        2x  - x + 4
+--R   (1)  -----------
+--R           3
+--R          x  + 4x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 722
+
+--S 723 of 940
+r0:=-1/2*atan(1/2*x)+log(x)+1/2*log(4+x^2)
+--R 
+--R
+--R             2                       x
+--R        log(x  + 4) + 2log(x) - atan(-)
+--R                                     2
+--R   (2)  -------------------------------
+--R                       2
+--R                                                    Type: Expression(Integer)
+--E 723
+
+--S 724 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 724
+
+)clear all
+
+--S 725 of 940
+t0:=(1+x^2+x^3)/((-1+x)*x*(1+x^2)^3*(1+x+x^2))
+--R 
+--R
+--R                        3    2
+--R                       x  + x  + 1
+--R   (1)  -----------------------------------------
+--R         10     8    7     6     5    4     3
+--R        x   + 3x  - x  + 3x  - 3x  + x  - 3x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 725
+
+--S 726 of 940
+r0:=1/8*(1+x)/(1+x^2)^2-3/8*(1-x)/(1+x^2)+3/16*x/(1+x^2)+_
+   7/16*atan(x)+1/8*log(1-x)-log(x)+15/16*log(1+x^2)-_
+   1/2*log(1+x+x^2)-atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R            4      2      +-+     2                4      2       +-+     2
+--R       (- 8x  - 16x  - 8)\|3 log(x  + x + 1) + (15x  + 30x  + 15)\|3 log(x  + 1)
+--R     + 
+--R             4      2       +-+            4     2      +-+
+--R       (- 16x  - 32x  - 16)\|3 log(x) + (2x  + 4x  + 2)\|3 log(- x + 1)
+--R     + 
+--R                                         +-+
+--R             4      2           (2x + 1)\|3        4      2      +-+
+--R       (- 16x  - 32x  - 16)atan(------------) + (7x  + 14x  + 7)\|3 atan(x)
+--R                                      3
+--R     + 
+--R          3     2            +-+
+--R       (9x  - 6x  + 11x - 4)\|3
+--R  /
+--R         4      2       +-+
+--R     (16x  + 32x  + 16)\|3
+--R                                                    Type: Expression(Integer)
+--E 726
+
+--S 727 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 727
+
+)clear all
+
+--S 728 of 940
+t0:=(1-3*x+2*x^2-x^3)/(1+x^2)^2
+--R 
+--R
+--R           3     2
+--R        - x  + 2x  - 3x + 1
+--R   (1)  -------------------
+--R             4     2
+--R            x  + 2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 728
+
+--S 729 of 940
+r0:=1/2*(2-x)/(1+x^2)+3/2*atan(x)-1/2*log(1+x^2)
+--R 
+--R
+--R            2          2           2
+--R        (- x  - 1)log(x  + 1) + (3x  + 3)atan(x) - x + 2
+--R   (2)  ------------------------------------------------
+--R                               2
+--R                             2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 729
+
+--S 730 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 730
+
+)clear all
+
+--S 731 of 940
+t0:=(1-3*x+2*x^2-x^3)/(x*(1+x^2)^2)
+--R 
+--R
+--R           3     2
+--R        - x  + 2x  - 3x + 1
+--R   (1)  -------------------
+--R             5     3
+--R            x  + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 731
+
+--S 732 of 940
+r0:=1/2*(-1-2*x)/(1+x^2)-2*atan(x)+log(x)-1/2*log(1+x^2)
+--R 
+--R
+--R            2          2           2                   2
+--R        (- x  - 1)log(x  + 1) + (2x  + 2)log(x) + (- 4x  - 4)atan(x) - 2x - 1
+--R   (2)  ---------------------------------------------------------------------
+--R                                         2
+--R                                       2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 732
+
+--S 733 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 733
+
+)clear all
+
+--S 734 of 940
+t0:=(1-x-x^2+x^3+x^4)/(-x+x^3)
+--R 
+--R
+--R         4    3    2
+--R        x  + x  - x  - x + 1
+--R   (1)  --------------------
+--R                3
+--R               x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 734
+
+--S 735 of 940
+r0:=x+1/2*x^2-log(x)+1/2*log(1-x^2)
+--R 
+--R
+--R                           2         2
+--R        - 2log(x) + log(- x  + 1) + x  + 2x
+--R   (2)  -----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 735
+
+--S 736 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 736
+
+)clear all
+
+--S 737 of 940
+t0:=(2-4*x^2+x^3)/((1+x^2)*(2+x^2))
+--R 
+--R
+--R         3     2
+--R        x  - 4x  + 2
+--R   (1)  ------------
+--R         4     2
+--R        x  + 3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 737
+
+--S 738 of 940
+r0:=6*atan(x)-1/2*log(1+x^2)+log(2+x^2)-5*atan(x/sqrt(2))*sqrt(2)
+--R 
+--R
+--R                                                  +-+
+--R              2             2           +-+     x\|2
+--R        2log(x  + 2) - log(x  + 1) - 10\|2 atan(-----) + 12atan(x)
+--R                                                  2
+--R   (2)  ----------------------------------------------------------
+--R                                     2
+--R                                                    Type: Expression(Integer)
+--E 738
+
+--S 739 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 739
+
+)clear all
+
+--S 740 of 940
+t0:=(1+x^2+x^4)/((1+x^2)*(4+x^2)^2)
+--R 
+--R
+--R              4    2
+--R             x  + x  + 1
+--R   (1)  --------------------
+--R         6     4      2
+--R        x  + 9x  + 24x  + 16
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 740
+
+--S 741 of 940
+r0:=-13/24*x/(4+x^2)+25/144*atan(1/2*x)+1/9*atan(x)
+--R 
+--R
+--R            2                    2            x
+--R        (16x  + 64)atan(x) + (25x  + 100)atan(-) - 78x
+--R                                              2
+--R   (2)  ----------------------------------------------
+--R                              2
+--R                          144x  + 576
+--R                                                    Type: Expression(Integer)
+--E 741
+
+--S 742 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 742
+
+)clear all
+
+--S 743 of 940
+t0:=(1+x^2+x^3)/(2*x^2+x^3+x^4)
+--R 
+--R
+--R          3    2
+--R         x  + x  + 1
+--R   (1)  -------------
+--R         4    3     2
+--R        x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 743
+
+--S 744 of 940
+r0:=(-1/2)/x-1/4*log(x)+5/8*log(2+x+x^2)+1/4*atan((1+2*x)/sqrt(7))/sqrt(7)
+--R 
+--R
+--R                                                                +-+
+--R           +-+     2               +-+                 (2x + 1)\|7       +-+
+--R        5x\|7 log(x  + x + 2) - 2x\|7 log(x) + 2x atan(------------) - 4\|7
+--R                                                             7
+--R   (2)  --------------------------------------------------------------------
+--R                                          +-+
+--R                                       8x\|7
+--R                                                    Type: Expression(Integer)
+--E 744
+
+--S 745 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 745
+
+)clear all
+
+--S 746 of 940
+t0:=(1-12*x+x^2+x^3)/(-12+x+x^2)
+--R 
+--R
+--R         3    2
+--R        x  + x  - 12x + 1
+--R   (1)  -----------------
+--R            2
+--R           x  + x - 12
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 746
+
+--S 747 of 940
+r0:=1/2*x^2-2/7*atanh(1/7*(1+2*x)),1/2*x^2+1/7*log(3-x)-1/7*log(4+x)
+--R 
+--R
+--R                  2x + 1      2
+--R         - 4atanh(------) + 7x                                    2
+--R                     7          - 2log(x + 4) + 2log(- x + 3) + 7x
+--R   (2)  [----------------------,-----------------------------------]
+--R                   14                            14
+--R                                             Type: Tuple(Expression(Integer))
+--E 747
+
+--S 748 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 748
+
+)clear all
+
+--S 749 of 940
+t0:=(-3+5*x+6*x^2)/(-3*x+2*x^2+x^3)
+--R 
+--R
+--R           2
+--R         6x  + 5x - 3
+--R   (1)  -------------
+--R         3     2
+--R        x  + 2x  - 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 749
+
+--S 750 of 940
+r0:=2*log(1-x)+log(x)+3*log(3+x)
+--R 
+--R
+--R   (2)  3log(x + 3) + log(x) + 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 750
+
+--S 751 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 751
+
+)clear all
+
+--S 752 of 940
+t0:=(-2+3*x+5*x^2)/(2*x^2+x^3)
+--R 
+--R
+--R          2
+--R        5x  + 3x - 2
+--R   (1)  ------------
+--R           3     2
+--R          x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 752
+
+--S 753 of 940
+r0:=1/x+2*log(x)+3*log(2+x)
+--R 
+--R
+--R        3x log(x + 2) + 2x log(x) + 1
+--R   (2)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 753
+
+--S 754 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 754
+
+)clear all
+
+--S 755 of 940
+t0:=(18-2*x-4*x^2)/(-6+x+4*x^2+x^3)
+--R 
+--R
+--R             2
+--R         - 4x  - 2x + 18
+--R   (1)  ----------------
+--R         3     2
+--R        x  + 4x  + x - 6
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 755
+
+--S 756 of 940
+r0:=log(1-x)-2*log(2+x)-3*log(3+x)
+--R 
+--R
+--R   (2)  - 3log(x + 3) - 2log(x + 2) + log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 756
+
+--S 757 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 757
+
+)clear all
+
+--S 758 of 940
+t0:=(1+x-2*x^2+x^3)/(4+5*x^2+x^4)
+--R 
+--R
+--R         3     2
+--R        x  - 2x  + x + 1
+--R   (1)  ----------------
+--R           4     2
+--R          x  + 5x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 758
+
+--S 759 of 940
+r0:=-3/2*atan(1/2*x)+atan(x)+1/2*log(4+x^2)
+--R 
+--R
+--R             2                         x
+--R        log(x  + 4) + 2atan(x) - 3atan(-)
+--R                                       2
+--R   (2)  ---------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 759
+
+--S 760 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 760
+
+)clear all
+
+--S 761 of 940
+t0:=(-32+5*x-27*x^2+4*x^3)/(-70-299*x-286*x^2+50*x^3-13*x^4+30*x^5)
+--R 
+--R
+--R                   3      2
+--R                 4x  - 27x  + 5x - 32
+--R   (1)  --------------------------------------
+--R           5      4      3       2
+--R        30x  - 13x  + 50x  - 286x  - 299x - 70
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 761
+
+--S 762 of 940
+r0:=-3146/80155*log(7-3*x)-334/323*log(1+2*x)+4822/4879*log(2+5*x)+_
+   11049/260015*log(5+x+x^2)+3988/13685*atan((1+2*x)/sqrt(19))/sqrt(19)
+--R 
+--R
+--R   (2)
+--R              +--+     2                     +--+
+--R       453009\|19 log(x  + x + 5) + 10536070\|19 log(5x + 2)
+--R     + 
+--R                  +--+                     +--+
+--R       - 11023670\|19 log(2x + 1) - 418418\|19 log(- 3x + 7)
+--R     + 
+--R                            +--+
+--R                   (2x + 1)\|19
+--R       3106652atan(-------------)
+--R                         19
+--R  /
+--R              +--+
+--R     10660615\|19
+--R                                                    Type: Expression(Integer)
+--E 762
+
+--S 763 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 763
+
+)clear all
+
+--S 764 of 940
+t0:=(8-13*x^2-7*x^3+12*x^5)/(4-20*x+41*x^2-80*x^3+116*x^4-80*x^5+100*x^6)
+--R 
+--R
+--R                       5     3      2
+--R                    12x  - 7x  - 13x  + 8
+--R   (1)  --------------------------------------------
+--R            6      5       4      3      2
+--R        100x  - 80x  + 116x  - 80x  + 41x  - 20x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 764
+
+--S 765 of 940
+r0:=5828/9075/(2-5*x)+1/1452*(-313-502*x)/(1+2*x^2)-_
+   59096/99825*log(2-5*x)+2843/7986*log(1+2*x^2)+503/7986*atan(x*sqrt(2))/_
+   sqrt(2),5828/9075/(2-5*x)+1/1452*(-313-502*x)/(1+2*x^2)-_
+   59096/99825*log(2-5*x)+2843/7986*log(1+2*x^2)-_
+   251/726*atan(x*sqrt(2))/sqrt(2)+272/1331*atan(x*sqrt(2))*sqrt(2)
+--R 
+--R
+--R   (2)
+--R   [
+--R                  3          2                     +-+      2
+--R         (1421500x  - 568600x  + 710750x - 284300)\|2 log(2x  + 1)
+--R       + 
+--R                    3          2                      +-+
+--R         (- 2363840x  + 945536x  - 1181920x + 472768)\|2 log(- 5x + 2)
+--R       + 
+--R                 3          2                          +-+
+--R         (251500x  - 100600x  + 125750x - 50300)atan(x\|2 )
+--R       + 
+--R                    2                    +-+
+--R         (- 1203114x  - 154275x - 84282)\|2
+--R    /
+--R                3           2                      +-+
+--R       (3993000x  - 1597200x  + 1996500x - 798600)\|2
+--R     ,
+--R
+--R                  3          2                     +-+      2
+--R         (1421500x  - 568600x  + 710750x - 284300)\|2 log(2x  + 1)
+--R       + 
+--R                    3          2                      +-+
+--R         (- 2363840x  + 945536x  - 1181920x + 472768)\|2 log(- 5x + 2)
+--R       + 
+--R                 3          2                          +-+
+--R         (251500x  - 100600x  + 125750x - 50300)atan(x\|2 )
+--R       + 
+--R                    2                    +-+
+--R         (- 1203114x  - 154275x - 84282)\|2
+--R    /
+--R                3           2                      +-+
+--R       (3993000x  - 1597200x  + 1996500x - 798600)\|2
+--R     ]
+--R                                             Type: Tuple(Expression(Integer))
+--E 765
+
+--S 766 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 766
+
+)clear all
+
+--S 767 of 940
+t0:=(9+x^4)/(x^2*(9+x^2))
+--R 
+--R
+--R          4
+--R         x  + 9
+--R   (1)  --------
+--R         4     2
+--R        x  + 9x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 767
+
+--S 768 of 940
+r0:=(-1)/x+x-10/3*atan(1/3*x)
+--R 
+--R
+--R                   x      2
+--R        - 10x atan(-) + 3x  - 3
+--R                   3
+--R   (2)  -----------------------
+--R                   3x
+--R                                                    Type: Expression(Integer)
+--E 768
+
+--S 769 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 769
+
+)clear all
+
+--S 770 of 940
+t0:=(2*x+x^4)/(1+x^2)
+--R 
+--R
+--R         4
+--R        x  + 2x
+--R   (1)  -------
+--R          2
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 770
+
+--S 771 of 940
+r0:=-x+1/3*x^3+atan(x)+log(1+x^2)
+--R 
+--R
+--R              2                    3
+--R        3log(x  + 1) + 3atan(x) + x  - 3x
+--R   (2)  ---------------------------------
+--R                        3
+--R                                                    Type: Expression(Integer)
+--E 771
+
+--S 772 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 772
+
+)clear all
+
+--S 773 of 940
+t0:=(-x+x^3)/((-1+x)^2*(1+x^2))
+--R 
+--R
+--R              2
+--R             x  + x
+--R   (1)  ---------------
+--R         3    2
+--R        x  - x  + x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 773
+
+--S 774 of 940
+r0:=atan(x)+log(1-x)
+--R 
+--R
+--R   (2)  log(- x + 1) + atan(x)
+--R                                                    Type: Expression(Integer)
+--E 774
+
+--S 775 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 775
+
+)clear all
+
+--S 776 of 940
+t0:=(2+5*x+3*x^2+2*x^3)/(1+x+x^2)
+--R 
+--R
+--R          3     2
+--R        2x  + 3x  + 5x + 2
+--R   (1)  ------------------
+--R             2
+--R            x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 776
+
+--S 777 of 940
+r0:=x+x^2+log(1+x+x^2)
+--R 
+--R
+--R             2             2
+--R   (2)  log(x  + x + 1) + x  + x
+--R                                                    Type: Expression(Integer)
+--E 777
+
+--S 778 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 778
+
+)clear all
+
+--S 779 of 940
+t0:=(3-4*x-5*x^2+3*x^3)/(x^3*(-1+x+x^2))
+--R 
+--R
+--R          3     2
+--R        3x  - 5x  - 4x + 3
+--R   (1)  ------------------
+--R            5    4    3
+--R           x  + x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 779
+
+--S 780 of 940
+r0:=3/2/x^2+(-1)/x+3*log(x)-1/10*log(1+2*x-sqrt(5))*(15-sqrt(5))-_
+   1/10*log(1+2*x+sqrt(5))*(15+sqrt(5))
+--R 
+--R
+--R   (2)
+--R           2 +-+      2      +-+                2
+--R       (- x \|5  - 15x )log(\|5  + 2x + 1) + 30x log(x)
+--R     + 
+--R         2 +-+      2        +-+
+--R       (x \|5  - 15x )log(- \|5  + 2x + 1) - 10x + 15
+--R  /
+--R        2
+--R     10x
+--R                                                    Type: Expression(Integer)
+--E 780
+
+--S 781 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 781
+
+)clear all
+
+--S 782 of 940
+t0:=(4+8*x+5*x^2+2*x^3)/(2+2*x+x^2)^2
+--R 
+--R
+--R             3     2
+--R           2x  + 5x  + 8x + 4
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  + 4x  + 8x  + 8x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 782
+
+--S 783 of 940
+r0:=(-1)/(2+2*x+x^2)-atan(1+x)+log(2+2*x+x^2)
+--R 
+--R
+--R          2               2                 2
+--R        (x  + 2x + 2)log(x  + 2x + 2) + (- x  - 2x - 2)atan(x + 1) - 1
+--R   (2)  --------------------------------------------------------------
+--R                                   2
+--R                                  x  + 2x + 2
+--R                                                    Type: Expression(Integer)
+--E 783
+
+--S 784 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 784
+
+)clear all
+
+--S 785 of 940
+t0:=(-1+x)^4*x^4/(1+x^2)
+--R 
+--R
+--R         8     7     6     5    4
+--R        x  - 4x  + 6x  - 4x  + x
+--R   (1)  -------------------------
+--R                   2
+--R                  x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 785
+
+--S 786 of 940
+r0:=4*x-4/3*x^3+x^5-2/3*x^6+1/7*x^7-4*atan(x)
+--R 
+--R
+--R                        7      6      5      3
+--R        - 84atan(x) + 3x  - 14x  + 21x  - 28x  + 84x
+--R   (2)  --------------------------------------------
+--R                             21
+--R                                                    Type: Expression(Integer)
+--E 786
+
+--S 787 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 787
+
+)clear all
+
+--S 788 of 940
+t0:=(-20*x+4*x^2)/(9-10*x^2+x^4)
+--R 
+--R
+--R            2
+--R          4x  - 20x
+--R   (1)  -------------
+--R         4      2
+--R        x  - 10x  + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 788
+
+--S 789 of 940
+r0:=log(1-x)-1/2*log(3-x)+3/2*log(1+x)-2*log(3+x)
+--R 
+--R
+--R        - 4log(x + 3) + 3log(x + 1) - log(- x + 3) + 2log(- x + 1)
+--R   (2)  ----------------------------------------------------------
+--R                                     2
+--R                                                    Type: Expression(Integer)
+--E 789
+
+--S 790 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 790
+
+)clear all
+
+--S 791 of 940
+t0:=(-1+x+4*x^3)/((-1+x)*x^2*(1+x^2))
+--R 
+--R
+--R             3
+--R           4x  + x - 1
+--R   (1)  -----------------
+--R         5    4    3    2
+--R        x  - x  + x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 791
+
+--S 792 of 940
+r0:=(-1)/x+atan(x)+2*log(1-x)-log(1+x^2)
+--R 
+--R
+--R                 2
+--R        - x log(x  + 1) + 2x log(- x + 1) + x atan(x) - 1
+--R   (2)  -------------------------------------------------
+--R                                x
+--R                                                    Type: Expression(Integer)
+--E 792
+
+--S 793 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 793
+
+)clear all
+
+--S 794 of 940
+t0:=(1-3*x+2*x^2-4*x^3+x^4)/(1+x^2)^3
+--R 
+--R
+--R         4     3     2
+--R        x  - 4x  + 2x  - 3x + 1
+--R   (1)  -----------------------
+--R            6     4     2
+--R           x  + 3x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 794
+
+--S 795 of 940
+r0:=(-1/4)/(1+x^2)^2+2/(1+x^2)+atan(x),1/4*(7-4*x)/(1+x^2)^2+2*x^2/(1+x^2)^2-_
+   x^3/(1+x^2)^2+x/(1+x^2)+atan(x)
+--R 
+--R
+--R            4     2                 2        4     2                 2
+--R         (4x  + 8x  + 4)atan(x) + 8x  + 7 (4x  + 8x  + 4)atan(x) + 8x  + 7
+--R   (2)  [--------------------------------,--------------------------------]
+--R                     4     2                          4     2
+--R                   4x  + 8x  + 4                    4x  + 8x  + 4
+--R                                             Type: Tuple(Expression(Integer))
+--E 795
+
+--S 796 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 796
+
+)clear all
+
+--S 797 of 940
+t0:=(1-3*x+2*x^2-4*x^3+x^4)/(1+3*x^2+3*x^4+x^6)
+--R 
+--R
+--R         4     3     2
+--R        x  - 4x  + 2x  - 3x + 1
+--R   (1)  -----------------------
+--R            6     4     2
+--R           x  + 3x  + 3x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 797
+
+--S 798 of 940
+r0:=(-1/4)/(1+x^2)^2+2/(1+x^2)+atan(x),1/4*(7-4*x)/(1+x^2)^2+2*x^2/(1+x^2)^2-_
+   x^3/(1+x^2)^2+x/(1+x^2)+atan(x)
+--R 
+--R
+--R            4     2                 2        4     2                 2
+--R         (4x  + 8x  + 4)atan(x) + 8x  + 7 (4x  + 8x  + 4)atan(x) + 8x  + 7
+--R   (2)  [--------------------------------,--------------------------------]
+--R                     4     2                          4     2
+--R                   4x  + 8x  + 4                    4x  + 8x  + 4
+--R                                             Type: Tuple(Expression(Integer))
+--E 798
+
+--S 799 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 799
+
+)clear all
+
+--S 800 of 940
+t0:=(1+x+2*x^2+2*x^3)/(x^2+x^3+x^4)
+--R 
+--R
+--R          3     2
+--R        2x  + 2x  + x + 1
+--R   (1)  -----------------
+--R            4    3    2
+--R           x  + x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 800
+
+--S 801 of 940
+r0:=(-1)/x+log(1+x+x^2)
+--R 
+--R
+--R               2
+--R        x log(x  + x + 1) - 1
+--R   (2)  ---------------------
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 801
+
+--S 802 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 802
+
+)clear all
+
+--S 803 of 940
+t0:=1/((4-4*x+x^2)*(5-4*x+x^2))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R         4     3      2
+--R        x  - 8x  + 25x  - 36x + 20
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 803
+
+--S 804 of 940
+r0:=1/(2-x)+atan(2-x)
+--R 
+--R
+--R        (- x + 2)atan(x - 2) - 1
+--R   (2)  ------------------------
+--R                  x - 2
+--R                                                    Type: Expression(Integer)
+--E 804
+
+--S 805 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 805
+
+)clear all
+
+--S 806 of 940
+t0:=(-3+x+x^2)/((-3+x)*x^2)
+--R 
+--R
+--R         2
+--R        x  + x - 3
+--R   (1)  ----------
+--R          3     2
+--R         x  - 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 806
+
+--S 807 of 940
+r0:=(-1)/x+log(3-x)
+--R 
+--R
+--R        x log(- x + 3) - 1
+--R   (2)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 807
+
+--S 808 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 808
+
+)clear all
+
+--S 809 of 940
+t0:=(1+x+4*x^2)/(x+4*x^3)
+--R 
+--R
+--R          2
+--R        4x  + x + 1
+--R   (1)  -----------
+--R            3
+--R          4x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 809
+
+--S 810 of 940
+r0:=1/2*atan(2*x)+log(x)
+--R 
+--R
+--R        2log(x) + atan(2x)
+--R   (2)  ------------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 810
+
+--S 811 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 811
+
+)clear all
+
+--S 812 of 940
+t0:=(1-x+3*x^2)/(-x^2+x^3)
+--R 
+--R
+--R          2
+--R        3x  - x + 1
+--R   (1)  -----------
+--R           3    2
+--R          x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 812
+
+--S 813 of 940
+r0:=1/x+3*log(1-x)
+--R 
+--R
+--R        3x log(- x + 1) + 1
+--R   (2)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 813
+
+--S 814 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 814
+
+)clear all
+
+--S 815 of 940
+t0:=(4+3*x+x^2)/(x+x^2)
+--R 
+--R
+--R         2
+--R        x  + 3x + 4
+--R   (1)  -----------
+--R            2
+--R           x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 815
+
+--S 816 of 940
+r0:=x+4*log(x)-2*log(1+x)
+--R 
+--R
+--R   (2)  - 2log(x + 1) + 4log(x) + x
+--R                                                    Type: Expression(Integer)
+--E 816
+
+--S 817 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 817
+
+)clear all
+
+--S 818 of 940
+t0:=(4+x+3*x^2)/(x+x^3)
+--R 
+--R
+--R          2
+--R        3x  + x + 4
+--R   (1)  -----------
+--R            3
+--R           x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 818
+
+--S 819 of 940
+r0:=atan(x)+4*log(x)-1/2*log(1+x^2)
+--R 
+--R
+--R               2
+--R        - log(x  + 1) + 8log(x) + 2atan(x)
+--R   (2)  ----------------------------------
+--R                         2
+--R                                                    Type: Expression(Integer)
+--E 819
+
+--S 820 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 820
+
+)clear all
+
+--S 821 of 940
+t0:=(7-4*x+8*x^2)/((1+4*x)*(1+x^2))
+--R 
+--R
+--R             2
+--R           8x  - 4x + 7
+--R   (1)  -----------------
+--R          3    2
+--R        4x  + x  + 4x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 821
+
+--S 822 of 940
+r0:=-atan(x)+2*log(1+4*x)
+--R 
+--R
+--R   (2)  2log(4x + 1) - atan(x)
+--R                                                    Type: Expression(Integer)
+--E 822
+
+--S 823 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 823
+
+)clear all
+
+--S 824 of 940
+t0:=x^2/((-1+x)*(1+2*x+x^2))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R         3    2
+--R        x  + x  - x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 824
+
+--S 825 of 940
+r0:=1/2/(1+x)+1/4*log(1-x)+3/4*log(1+x)
+--R 
+--R
+--R        (3x + 3)log(x + 1) + (x + 1)log(- x + 1) + 2
+--R   (2)  --------------------------------------------
+--R                           4x + 4
+--R                                                    Type: Expression(Integer)
+--E 825
+
+--S 826 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 826
+
+)clear all
+
+--S 827 of 940
+t0:=(-4+3*x+x^2)/((-1+2*x)^2*(3+2*x))
+--R 
+--R
+--R             2
+--R            x  + 3x - 4
+--R   (1)  -------------------
+--R          3     2
+--R        8x  + 4x  - 10x + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 827
+
+--S 828 of 940
+r0:=(-9/32)/(1-2*x)+41/128*log(1-2*x)-25/128*log(3+2*x)
+--R 
+--R
+--R        (- 50x + 25)log(2x + 3) + (82x - 41)log(- 2x + 1) + 36
+--R   (2)  ------------------------------------------------------
+--R                              256x - 128
+--R                                                    Type: Expression(Integer)
+--E 828
+
+--S 829 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 829
+
+)clear all
+
+--S 830 of 940
+t0:=(5-4*x+3*x^2)/((-1+x)*(1+x^2))
+--R 
+--R
+--R            2
+--R          3x  - 4x + 5
+--R   (1)  ---------------
+--R         3    2
+--R        x  - x  + x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 830
+
+--S 831 of 940
+r0:=-3*atan(x)+2*log(1-x)+1/2*log(1+x^2)
+--R 
+--R
+--R             2
+--R        log(x  + 1) + 4log(- x + 1) - 6atan(x)
+--R   (2)  --------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 831
+
+--S 832 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 832
+
+)clear all
+
+--S 833 of 940
+t0:=(-1-2*x+x^2)/((-1+x)^2*(1+x^2))
+--R 
+--R
+--R               2
+--R              x  - 2x - 1
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  - 2x  + 2x  - 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 833
+
+--S 834 of 940
+r0:=1/(-1+x)+atan(x)+log(1-x)-1/2*log(1+x^2)
+--R 
+--R
+--R                      2
+--R        (- x + 1)log(x  + 1) + (2x - 2)log(- x + 1) + (2x - 2)atan(x) + 2
+--R   (2)  -----------------------------------------------------------------
+--R                                      2x - 2
+--R                                                    Type: Expression(Integer)
+--E 834
+
+--S 835 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 835
+
+)clear all
+
+--S 836 of 940
+t0:=(5+x^3)/((10-6*x+x^2)*(1/2-x+x^2))
+--R 
+--R
+--R                   3
+--R                  x  + 5
+--R   (1)  --------------------------
+--R         4     3   33  2
+--R        x  - 7x  + -- x  - 13x + 5
+--R                    2
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 836
+
+--S 837 of 940
+r0:=-261/221*atan(1-2*x)-1026/221*atan(3-x)+56/221*log(10-6*x+x^2)+_
+   109/442*log(1-2*x+2*x^2)
+--R 
+--R
+--R   (2)
+--R                2                     2
+--R       109log(2x  - 2x + 1) + 112log(x  - 6x + 10) + 522atan(2x - 1)
+--R     + 
+--R       2052atan(x - 3)
+--R  /
+--R     442
+--R                                                    Type: Expression(Integer)
+--E 837
+
+--S 838 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 838
+
+)clear all
+
+--S 839 of 940
+t0:=(4+3*x+x^2)/((-3+x)*(-2+x)*(-1+x))
+--R 
+--R
+--R             2
+--R            x  + 3x + 4
+--R   (1)  ------------------
+--R         3     2
+--R        x  - 6x  + 11x - 6
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 839
+
+--S 840 of 940
+r0:=4*log(1-x)-14*log(2-x)+11*log(3-x)
+--R 
+--R
+--R   (2)  11log(- x + 3) - 14log(- x + 2) + 4log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 840
+
+--S 841 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 841
+
+)clear all
+
+--S 842 of 940
+t0:=(1+16*x)/((5+x)^2*(-3+2*x)*(1+x+x^2))
+--R 
+--R
+--R                      16x + 1
+--R   (1)  -----------------------------------
+--R          5      4      3      2
+--R        2x  + 19x  + 39x  - 38x  - 55x - 75
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 842
+
+--S 843 of 940
+r0:=(-79/273)/(5+x)+200/3211*log(3-2*x)+2731/24843*log(5+x)-_
+   481/5586*log(1+x+x^2)+451/2793*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                           +-+     2                               +-+
+--R       (- 81289x - 406445)\|3 log(x  + x + 1) + (103778x + 518890)\|3 log(x + 5)
+--R     + 
+--R                                                                            +-+
+--R                         +-+                                       (2x + 1)\|3
+--R       (58800x + 294000)\|3 log(- 2x + 3) + (152438x + 762190)atan(------------)
+--R                                                                         3
+--R     + 
+--R                +-+
+--R       - 273182\|3
+--R  /
+--R                         +-+
+--R     (944034x + 4720170)\|3
+--R                                                    Type: Expression(Integer)
+--E 843
+
+--S 844 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 844
+
+)clear all
+
+--S 845 of 940
+t0:=(-1+x^3)/(1+x+x^2)
+--R 
+--R
+--R   (1)  x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 845
+
+--S 846 of 940
+r0:=-x+1/2*x^2
+--R 
+--R
+--R        1  2
+--R   (2)  - x  - x
+--R        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 846
+
+--S 847 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 847
+
+)clear all
+
+--S 848 of 940
+t0:=(-3+x^3)/(-7-6*x+x^2)
+--R 
+--R
+--R            3
+--R           x  - 3
+--R   (1)  -----------
+--R         2
+--R        x  - 6x - 7
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 848
+
+--S 849 of 940
+r0:=6*x+1/2*x^2+85/2*log(7-x)+1/2*log(1+x)
+--R 
+--R
+--R                                       2
+--R        log(x + 1) + 85log(- x + 7) + x  + 12x
+--R   (2)  --------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 849
+
+--S 850 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 850
+
+)clear all
+
+--S 851 of 940
+t0:=(1+x^3)/(13+4*x+x^2)^2
+--R 
+--R
+--R                    3
+--R                   x  + 1
+--R   (1)  ----------------------------
+--R         4     3      2
+--R        x  + 8x  + 42x  + 104x + 169
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 851
+
+--S 852 of 940
+r0:=1/18*(67+47*x)/(13+4*x+x^2)-61/54*atan(2/3+1/3*x)+1/2*log(13+4*x+x^2)
+--R 
+--R
+--R   (2)
+--R           2                   2                    2                   x + 2
+--R       (27x  + 108x + 351)log(x  + 4x + 13) + (- 61x  - 244x - 793)atan(-----)
+--R                                                                          3
+--R     + 
+--R       141x + 201
+--R  /
+--R        2
+--R     54x  + 216x + 702
+--R                                                    Type: Expression(Integer)
+--E 852
+
+--S 853 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 853
+
+)clear all
+
+--S 854 of 940
+t0:=(-32+36*x-42*x^2+21*x^3-10*x^4+3*x^5)/(x*(1+x^2)*(4+x^2)^2)
+--R 
+--R
+--R          5      4      3      2
+--R        3x  - 10x  + 21x  - 42x  + 36x - 32
+--R   (1)  -----------------------------------
+--R                7     5      3
+--R               x  + 9x  + 24x  + 16x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 854
+
+--S 855 of 940
+r0:=1/(4+x^2)+1/2*atan(1/2*x)+2*atan(x)-2*log(x)+log(4+x^2)
+--R 
+--R
+--R   (2)
+--R          2          2             2                  2
+--R       (2x  + 8)log(x  + 4) + (- 4x  - 16)log(x) + (4x  + 16)atan(x)
+--R     + 
+--R         2          x
+--R       (x  + 4)atan(-) + 2
+--R                    2
+--R  /
+--R       2
+--R     2x  + 8
+--R                                                    Type: Expression(Integer)
+--E 855
+
+--S 856 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 856
+
+)clear all
+
+--S 857 of 940
+t0:=(-1+x^4+7*x^5+x^9)/(-7+6*x^4+x^8)
+--R 
+--R
+--R         9     5    4
+--R        x  + 7x  + x  - 1
+--R   (1)  -----------------
+--R            8     4
+--R           x  + 6x  - 7
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 857
+
+--S 858 of 940
+r0:=1/2*x^2+1/4*log(1-x^2)-1/4*log(1+x^2)-1/2*atan(1-x*sqrt(2)/7^(1/4))/_
+   (7^(3/4)*sqrt(2))+1/2*atan(1+x*sqrt(2)/7^(1/4))/(7^(3/4)*sqrt(2))-_
+   1/4*log(x^2-7^(1/4)*x*sqrt(2)+sqrt(7))/(7^(3/4)*sqrt(2))+_
+   1/4*log(x^2+7^(1/4)*x*sqrt(2)+sqrt(7))/(7^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             +-+4+-+    +-+    2     +-+4+-+3     2
+--R       log(x\|2 \|7  + \|7  + x ) - \|2 \|7  log(x  + 1)
+--R     + 
+--R        +-+4+-+3       2                +-+4+-+    +-+    2
+--R       \|2 \|7  log(- x  + 1) - log(- x\|2 \|7  + \|7  + x )
+--R     + 
+--R               +-+4+-+3                +-+4+-+3
+--R             x\|2 \|7   + 7          x\|2 \|7   - 7      2 +-+4+-+3
+--R       2atan(--------------) + 2atan(--------------) + 2x \|2 \|7
+--R                    7                       7
+--R  /
+--R       +-+4+-+3
+--R     4\|2 \|7
+--R                                                    Type: Expression(Integer)
+--E 858
+
+--S 859 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 859
+
+)clear all
+
+--S 860 of 940
+t0:=(1+x^3+x^6)/(x+x^5)
+--R 
+--R
+--R         6    3
+--R        x  + x  + 1
+--R   (1)  -----------
+--R            5
+--R           x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 860
+
+--S 861 of 940
+r0:=1/2*x^2-1/2*atan(x^2)+log(x)-1/4*log(1+x^4)-_
+   1/2*atan(1-x*sqrt(2))/sqrt(2)+1/2*atan(1+x*sqrt(2))/sqrt(2)+_
+   1/4*log(1+x^2-x*sqrt(2))/sqrt(2)-1/4*log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R               +-+    2         +-+     4          +-+
+--R       - log(x\|2  + x  + 1) - \|2 log(x  + 1) + 4\|2 log(x)
+--R     + 
+--R               +-+    2                +-+                +-+
+--R       log(- x\|2  + x  + 1) + 2atan(x\|2  + 1) + 2atan(x\|2  - 1)
+--R     + 
+--R           +-+      2      2 +-+
+--R       - 2\|2 atan(x ) + 2x \|2
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 861
+
+--S 862 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 862
+
+)clear all
+
+--S 863 of 940
+t0:=(1+x^2)/(-x+x^2)
+--R 
+--R
+--R         2
+--R        x  + 1
+--R   (1)  ------
+--R         2
+--R        x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 863
+
+--S 864 of 940
+r0:=x+2*log(1-x)-log(x)
+--R 
+--R
+--R   (2)  - log(x) + 2log(- x + 1) + x
+--R                                                    Type: Expression(Integer)
+--E 864
+
+--S 865 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 865
+
+)clear all
+
+--S 866 of 940
+t0:=(1+x^3)/(-x+x^3)
+--R 
+--R
+--R         2
+--R        x  - x + 1
+--R   (1)  ----------
+--R           2
+--R          x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 866
+
+--S 867 of 940
+r0:=x+log(1-x)-log(x)
+--R 
+--R
+--R   (2)  - log(x) + log(- x + 1) + x
+--R                                                    Type: Expression(Integer)
+--E 867
+
+--S 868 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 868
+
+)clear all
+
+--S 869 of 940
+t0:=(1+x^3)/(-x^2+x^3)
+--R 
+--R
+--R          3
+--R         x  + 1
+--R   (1)  -------
+--R         3    2
+--R        x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 869
+
+--S 870 of 940
+r0:=1/x+x+2*log(1-x)-log(x)
+--R 
+--R
+--R                                        2
+--R        - x log(x) + 2x log(- x + 1) + x  + 1
+--R   (2)  -------------------------------------
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 870
+
+--S 871 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 871
+
+)clear all
+
+--S 872 of 940
+t0:=(-1+x^5)/(-x+x^3)
+--R 
+--R
+--R         4    3    2
+--R        x  + x  + x  + x + 1
+--R   (1)  --------------------
+--R                2
+--R               x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 872
+
+--S 873 of 940
+r0:=x+1/3*x^3+log(x)-log(1+x)
+--R 
+--R
+--R                                   3
+--R        - 3log(x + 1) + 3log(x) + x  + 3x
+--R   (2)  ---------------------------------
+--R                        3
+--R                                                    Type: Expression(Integer)
+--E 873
+
+--S 874 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 874
+
+)clear all
+
+--S 875 of 940
+t0:=(1+x^4)/(x^3+x^5)
+--R 
+--R
+--R          4
+--R         x  + 1
+--R   (1)  -------
+--R         5    3
+--R        x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 875
+
+--S 876 of 940
+r0:=(-1/2)/x^2-log(x)+log(1+x^2)
+--R 
+--R
+--R          2     2          2
+--R        2x log(x  + 1) - 2x log(x) - 1
+--R   (2)  ------------------------------
+--R                        2
+--R                      2x
+--R                                                    Type: Expression(Integer)
+--E 876
+
+--S 877 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 877
+
+)clear all
+
+--S 878 of 940
+t0:=(1+x^2)/(x+2*x^2+x^3)
+--R 
+--R
+--R            2
+--R           x  + 1
+--R   (1)  ------------
+--R         3     2
+--R        x  + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 878
+
+--S 879 of 940
+r0:=2/(1+x)+log(x)
+--R 
+--R
+--R        (x + 1)log(x) + 2
+--R   (2)  -----------------
+--R              x + 1
+--R                                                    Type: Expression(Integer)
+--E 879
+
+--S 880 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 880
+
+)clear all
+
+--S 881 of 940
+t0:=(1+x^5)/(-10*x-3*x^2+x^3)
+--R 
+--R
+--R             5
+--R            x  + 1
+--R   (1)  --------------
+--R         3     2
+--R        x  - 3x  - 10x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 881
+
+--S 882 of 940
+r0:=19*x+3/2*x^2+1/3*x^3+3126/35*log(5-x)-1/10*log(x)-31/14*log(2+x)
+--R 
+--R
+--R                                                            3       2
+--R        - 465log(x + 2) - 21log(x) + 18756log(- x + 5) + 70x  + 315x  + 3990x
+--R   (2)  ---------------------------------------------------------------------
+--R                                         210
+--R                                                    Type: Expression(Integer)
+--E 882
+
+--S 883 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 883
+
+)clear all
+
+--S 884 of 940
+t0:=(15-5*x+x^2+x^3)/((5+x^2)*(3+2*x+x^2))
+--R 
+--R
+--R             3    2
+--R            x  + x  - 5x + 15
+--R   (1)  -------------------------
+--R         4     3     2
+--R        x  + 2x  + 8x  + 10x + 15
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 884
+
+--S 885 of 940
+r0:=1/2*log(3+2*x+x^2)+5*atan((1+x)/sqrt(2))/sqrt(2)-atan(x/sqrt(5))*sqrt(5)
+--R 
+--R
+--R                                               +-+                   +-+
+--R         +-+     2               +-+ +-+     x\|5            (x + 1)\|2
+--R        \|2 log(x  + 2x + 3) - 2\|2 \|5 atan(-----) + 10atan(-----------)
+--R                                               5                  2
+--R   (2)  -----------------------------------------------------------------
+--R                                        +-+
+--R                                      2\|2
+--R                                                    Type: Expression(Integer)
+--E 885
+
+--S 886 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 886
+
+)clear all
+
+--S 887 of 940
+t0:=1/((1+x^2)*(3+10*x/(1+x^2)))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R          2
+--R        3x  + 10x + 3
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 887
+
+--S 888 of 940
+r0:=-1/8*log(3+x)+1/8*log(1+3*x)
+--R 
+--R
+--R        log(3x + 1) - log(x + 3)
+--R   (2)  ------------------------
+--R                    8
+--R                                                    Type: Expression(Integer)
+--E 888
+
+--S 889 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 889
+
+)clear all
+
+--S 890 of 940
+t0:=x^3/(13+2/x+15*x)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 890
+
+--S 891 of 940
+r0:=139/3375*x-13/450*x^2+1/45*x^3-16/567*log(2+3*x)+1/4375*log(1+5*x)
+--R 
+--R
+--R                                                  3         2
+--R        162log(5x + 1) - 20000log(3x + 2) + 15750x  - 20475x  + 29190x
+--R   (2)  --------------------------------------------------------------
+--R                                    708750
+--R                                                    Type: Expression(Integer)
+--E 891
+
+--S 892 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 892
+
+)clear all
+
+--S 893 of 940
+t0:=x^2/(13+2/x+15*x)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 893
+
+--S 894 of 940
+r0:=-13/225*x+1/30*x^2+8/189*log(2+3*x)-1/875*log(1+5*x)
+--R 
+--R
+--R                                                 2
+--R        - 54log(5x + 1) + 2000log(3x + 2) + 1575x  - 2730x
+--R   (2)  --------------------------------------------------
+--R                               47250
+--R                                                    Type: Expression(Integer)
+--E 894
+
+--S 895 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 895
+
+)clear all
+
+--S 896 of 940
+t0:=x/(13+2/x+15*x)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 896
+
+--S 897 of 940
+r0:=1/15*x-4/63*log(2+3*x)+1/175*log(1+5*x)
+--R 
+--R
+--R        9log(5x + 1) - 100log(3x + 2) + 105x
+--R   (2)  ------------------------------------
+--R                        1575
+--R                                                    Type: Expression(Integer)
+--E 897
+
+--S 898 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 898
+
+)clear all
+
+--S 899 of 940
+t0:=1/(13+2/x+15*x)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 899
+
+--S 900 of 940
+r0:=2/21*log(2+3*x)-1/35*log(1+5*x)
+--R 
+--R
+--R        - 3log(5x + 1) + 10log(3x + 2)
+--R   (2)  ------------------------------
+--R                      105
+--R                                                    Type: Expression(Integer)
+--E 900
+
+--S 901 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 901
+
+)clear all
+
+--S 902 of 940
+t0:=1/(x*(13+2/x+15*x))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R           2
+--R        15x  + 13x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 902
+
+--S 903 of 940
+r0:=-1/7*log(2+3*x)+1/7*log(1+5*x)
+--R 
+--R
+--R        log(5x + 1) - log(3x + 2)
+--R   (2)  -------------------------
+--R                    7
+--R                                                    Type: Expression(Integer)
+--E 903
+
+--S 904 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 904
+
+)clear all
+
+--S 905 of 940
+t0:=1/(x^2*(13+2/x+15*x))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           3      2
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 905
+
+--S 906 of 940
+r0:=1/2*log(x)+3/14*log(2+3*x)-5/7*log(1+5*x)
+--R 
+--R
+--R        - 10log(5x + 1) + 3log(3x + 2) + 7log(x)
+--R   (2)  ----------------------------------------
+--R                           14
+--R                                                    Type: Expression(Integer)
+--E 906
+
+--S 907 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 907
+
+)clear all
+
+--S 908 of 940
+t0:=1/(x^3*(13+2/x+15*x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           4      3     2
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 908
+
+--S 909 of 940
+r0:=(-1/2)/x-13/4*log(x)-9/28*log(2+3*x)+25/7*log(1+5*x)
+--R 
+--R
+--R        100x log(5x + 1) - 9x log(3x + 2) - 91x log(x) - 14
+--R   (2)  ---------------------------------------------------
+--R                                28x
+--R                                                    Type: Expression(Integer)
+--E 909
+
+--S 910 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 910
+
+)clear all
+
+--S 911 of 940
+t0:=1/(x^4*(13+2/x+15*x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           5      4     3
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 911
+
+--S 912 of 940
+r0:=(-1/4)/x^2+13/4/x+139/8*log(x)+27/56*log(2+3*x)-125/7*log(1+5*x)
+--R 
+--R
+--R               2                 2                  2
+--R        - 1000x log(5x + 1) + 27x log(3x + 2) + 973x log(x) + 182x - 14
+--R   (2)  ---------------------------------------------------------------
+--R                                         2
+--R                                      56x
+--R                                                    Type: Expression(Integer)
+--E 912
+
+--S 913 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 913
+
+)clear all
+
+--S 914 of 940
+t0:=1/(x^5*(13+2/x+15*x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R           6      5     4
+--R        15x  + 13x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 914
+
+--S 915 of 940
+r0:=(-1/6)/x^3+13/8/x^2+(-139/8)/x-1417/16*log(x)-81/112*log(2+3*x)+_
+   625/7*log(1+5*x)
+--R 
+--R
+--R   (2)
+--R         3                  3                    3              2
+--R   30000x log(5x + 1) - 243x log(3x + 2) - 29757x log(x) - 5838x  + 546x - 56
+--R   --------------------------------------------------------------------------
+--R                                          3
+--R                                      336x
+--R                                                    Type: Expression(Integer)
+--E 915
+
+--S 916 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 916
+
+)clear all
+
+--S 917 of 940
+t0:=(1-x^2)/(a+b*(1-x^2)^4)
+--R 
+--R
+--R                         2
+--R                      - x  + 1
+--R   (1)  ------------------------------------
+--R           8       6       4       2
+--R        b x  - 4b x  + 6b x  - 4b x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 917
+
+--S 918 of 940
+r0:=1/4*atan(b^(1/8)*x/sqrt(%i*(-a)^(1/4)-b^(1/4)))/(b^(3/8)*sqrt(-a)*_
+   sqrt(%i*(-a)^(1/4)-b^(1/4)))-1/4*atan(b^(1/8)*x/sqrt((-a)^(1/4)-_
+   b^(1/4)))/(b^(3/8)*sqrt(-a)*sqrt((-a)^(1/4)-b^(1/4)))-_
+   1/4*atanh(b^(1/8)*x/sqrt(%i*(-a)^(1/4)+b^(1/4)))/(b^(3/8)*sqrt(-a)*_
+   sqrt(%i*(-a)^(1/4)+b^(1/4)))+1/4*atanh(b^(1/8)*x/sqrt((-a)^(1/4)+_
+   b^(1/4)))/(b^(3/8)*sqrt(-a)*sqrt((-a)^(1/4)+b^(1/4)))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +-----------------+ +---------------+ +-------------+
+--R             |  4+-+     4+---+  |  4+-+   4+---+  |4+-+   4+---+
+--R            \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + \|- a
+--R         *
+--R                          8+-+
+--R                         x\|b
+--R            atanh(------------------)
+--R                   +---------------+
+--R                   |4+-+     4+---+
+--R                  \|\|b  + %i\|- a
+--R     + 
+--R          +-----------------+ +---------------+ +---------------+
+--R          |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R                      8+-+
+--R                     x\|b
+--R         atanh(----------------)
+--R                +-------------+
+--R                |4+-+   4+---+
+--R               \|\|b  + \|- a
+--R     + 
+--R          +---------------+ +---------------+ +-------------+
+--R          |  4+-+   4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R         \|- \|b  + \|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R      *
+--R                       8+-+
+--R                      x\|b
+--R         atan(--------------------)
+--R               +-----------------+
+--R               |  4+-+     4+---+
+--R              \|- \|b  + %i\|- a
+--R     + 
+--R       -
+--R             +-----------------+ +---------------+ +-------------+
+--R             |  4+-+     4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R            \|- \|b  + %i\|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R         *
+--R                         8+-+
+--R                        x\|b
+--R            atan(------------------)
+--R                  +---------------+
+--R                  |  4+-+   4+---+
+--R                 \|- \|b  + \|- a
+--R  /
+--R                    +-----------------+ +---------------+ +---------------+
+--R         +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R       4\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R    *
+--R        +-------------+
+--R        |4+-+   4+---+
+--R       \|\|b  + \|- a
+--R                                           Type: Expression(Complex(Integer))
+--E 918
+
+--S 919 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                           Type: Expression(Complex(Integer))
+--E 919
+
+)clear all
+
+--S 920 of 940
+t0:=(1-x^2)/(a+b*(-1+x^2)^4)
+--R 
+--R
+--R                         2
+--R                      - x  + 1
+--R   (1)  ------------------------------------
+--R           8       6       4       2
+--R        b x  - 4b x  + 6b x  - 4b x  + b + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 920
+
+--S 921 of 940
+r0:=1/4*atan(b^(1/8)*x/sqrt(%i*(-a)^(1/4)-b^(1/4)))/(b^(3/8)*sqrt(-a)*_
+   sqrt(%i*(-a)^(1/4)-b^(1/4)))-1/4*atan(b^(1/8)*x/sqrt((-a)^(1/4)-_
+   b^(1/4)))/(b^(3/8)*sqrt(-a)*sqrt((-a)^(1/4)-b^(1/4)))-_
+   1/4*atanh(b^(1/8)*x/sqrt(%i*(-a)^(1/4)+b^(1/4)))/(b^(3/8)*sqrt(-a)*_
+   sqrt(%i*(-a)^(1/4)+b^(1/4)))+1/4*atanh(b^(1/8)*x/sqrt((-a)^(1/4)+_
+   b^(1/4)))/(b^(3/8)*sqrt(-a)*sqrt((-a)^(1/4)+b^(1/4)))
+--R 
+--R
+--R   (2)
+--R       -
+--R             +-----------------+ +---------------+ +-------------+
+--R             |  4+-+     4+---+  |  4+-+   4+---+  |4+-+   4+---+
+--R            \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + \|- a
+--R         *
+--R                          8+-+
+--R                         x\|b
+--R            atanh(------------------)
+--R                   +---------------+
+--R                   |4+-+     4+---+
+--R                  \|\|b  + %i\|- a
+--R     + 
+--R          +-----------------+ +---------------+ +---------------+
+--R          |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R         \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R      *
+--R                      8+-+
+--R                     x\|b
+--R         atanh(----------------)
+--R                +-------------+
+--R                |4+-+   4+---+
+--R               \|\|b  + \|- a
+--R     + 
+--R          +---------------+ +---------------+ +-------------+
+--R          |  4+-+   4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R         \|- \|b  + \|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R      *
+--R                       8+-+
+--R                      x\|b
+--R         atan(--------------------)
+--R               +-----------------+
+--R               |  4+-+     4+---+
+--R              \|- \|b  + %i\|- a
+--R     + 
+--R       -
+--R             +-----------------+ +---------------+ +-------------+
+--R             |  4+-+     4+---+  |4+-+     4+---+  |4+-+   4+---+
+--R            \|- \|b  + %i\|- a  \|\|b  + %i\|- a  \|\|b  + \|- a
+--R         *
+--R                         8+-+
+--R                        x\|b
+--R            atan(------------------)
+--R                  +---------------+
+--R                  |  4+-+   4+---+
+--R                 \|- \|b  + \|- a
+--R  /
+--R                    +-----------------+ +---------------+ +---------------+
+--R         +---+8+-+3 |  4+-+     4+---+  |  4+-+   4+---+  |4+-+     4+---+
+--R       4\|- a \|b  \|- \|b  + %i\|- a  \|- \|b  + \|- a  \|\|b  + %i\|- a
+--R    *
+--R        +-------------+
+--R        |4+-+   4+---+
+--R       \|\|b  + \|- a
+--R                                           Type: Expression(Complex(Integer))
+--E 921
+
+--S 922 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                           Type: Expression(Complex(Integer))
+--E 922
+
+)clear all
+
+--S 923 of 940
+t0:=(-1+4*x^5)/(1+x+x^5)^2
+--R 
+--R
+--R                     5
+--R                   4x  - 1
+--R   (1)  -----------------------------
+--R         10     6     5    2
+--R        x   + 2x  + 2x  + x  + 2x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 923
+
+--S 924 of 940
+r0:=-x/(1+x+x^5)
+--R 
+--R
+--R               x
+--R   (2)  - ----------
+--R           5
+--R          x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 924
+
+--S 925 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 925
+
+)clear all
+
+--S 926 of 940
+t0:=(b*c-a*d-2*a*e*x-b*e*x^2-3*a*f*x^2-2*b*f*x^3)/(c+d*x+e*x^2+f*x^3)^2
+--R 
+--R
+--R   (1)
+--R             3                  2
+--R     - 2b f x  + (- 3a f - b e)x  - 2a e x - a d + b c
+--R  /
+--R        2 6         5            2  4                 3            2  2
+--R       f x  + 2e f x  + (2d f + e )x  + (2c f + 2d e)x  + (2c e + d )x  + 2c d x
+--R     + 
+--R        2
+--R       c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 926
+
+--S 927 of 940
+r0:=a/(c+d*x+e*x^2+f*x^3)+b*x/(c+d*x+e*x^2+f*x^3)
+--R 
+--R
+--R               b x + a
+--R   (2)  ---------------------
+--R           3      2
+--R        f x  + e x  + d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 927
+
+--S 928 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 928
+
+)clear all
+
+--S 929 of 940
+t0:=(9-40*x-18*x^2+174*x^4+24*x^5+26*x^6-39*x^8)/(3+2*x^2+x^4)^3
+--R 
+--R
+--R             8      6      5       4      2
+--R        - 39x  + 26x  + 24x  + 174x  - 18x  - 40x + 9
+--R   (1)  ---------------------------------------------
+--R          12     10      8      6      4      2
+--R         x   + 6x   + 21x  + 44x  + 63x  + 54x  + 27
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 929
+
+--S 930 of 940
+r0:=2/(3+2*x^2+x^4)^2+3*x/(3+2*x^2+x^4)^2-4*x^2/(3+2*x^2+x^4)^2+_
+   13*x^5/(3+2*x^2+x^4)^2
+--R 
+--R
+--R               5     2
+--R            13x  - 4x  + 3x + 2
+--R   (2)  --------------------------
+--R         8     6      4      2
+--R        x  + 4x  + 10x  + 12x  + 9
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 930
+
+--S 931 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 931
+
+)clear all
+
+--S 932 of 940
+t0:=(-15+36*x-5*x^2-12*x^3+34*x^4-140*x^5-15*x^6-8*x^7+30*x^9)/(3+x+x^4)^4
+--R 
+--R
+--R   (1)
+--R        9     7      6       5      4      3     2
+--R     30x  - 8x  - 15x  - 140x  + 34x  - 12x  - 5x  + 36x - 15
+--R  /
+--R        16     13      12     10      9      8     7      6       5       4
+--R       x   + 4x   + 12x   + 6x   + 36x  + 54x  + 4x  + 36x  + 108x  + 109x
+--R     + 
+--R          3      2
+--R       12x  + 54x  + 108x + 81
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 932
+
+--S 933 of 940
+r0:=2/(3+x+x^4)^3-3*x/(3+x+x^4)^3+5*x^2/(3+x+x^4)^3+x^4/(3+x+x^4)^3-_
+   5*x^6/(3+x+x^4)^3
+--R 
+--R
+--R                            6    4     2
+--R                        - 5x  + x  + 5x  - 3x + 2
+--R   (2)  ---------------------------------------------------------
+--R         12     9     8     6      5      4    3     2
+--R        x   + 3x  + 9x  + 3x  + 18x  + 27x  + x  + 9x  + 27x + 27
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 933
+
+--S 934 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 934
+
+)clear all
+
+--S 935 of 940
+t0:=3*(-47+228*x+120*x^2+19*x^3)/(3+x+x^4)^4+_
+   (42-320*x-75*x^2-8*x^3)/(3+x+x^4)^3+30*x/(3+x+x^4)^2
+--R 
+--R
+--R   (1)
+--R        9     7      6       5      4      3     2
+--R     30x  - 8x  - 15x  - 140x  + 34x  - 12x  - 5x  + 36x - 15
+--R  /
+--R        16     13      12     10      9      8     7      6       5       4
+--R       x   + 4x   + 12x   + 6x   + 36x  + 54x  + 4x  + 36x  + 108x  + 109x
+--R     + 
+--R          3      2
+--R       12x  + 54x  + 108x + 81
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 935
+
+--S 936 of 940
+r0:=(2-3*x+5*x^2+x^4-5*x^6)/(3+x+x^4)^3
+--R 
+--R
+--R                            6    4     2
+--R                        - 5x  + x  + 5x  - 3x + 2
+--R   (2)  ---------------------------------------------------------
+--R         12     9     8     6      5      4    3     2
+--R        x   + 3x  + 9x  + 3x  + 18x  + 27x  + x  + 9x  + 27x + 27
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 936
+
+--S 937 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 937
+
+)clear all
+
+--S 938 of 940
+t0:=(-3+10*x+4*x^3-30*x^5)/(3+x+x^4)^3-3*(1+4*x^3)*_
+   (2-3*x+5*x^2+x^4-5*x^6)/(3+x+x^4)^4
+--R 
+--R
+--R   (1)
+--R        9     7      6       5      4      3     2
+--R     30x  - 8x  - 15x  - 140x  + 34x  - 12x  - 5x  + 36x - 15
+--R  /
+--R        16     13      12     10      9      8     7      6       5       4
+--R       x   + 4x   + 12x   + 6x   + 36x  + 54x  + 4x  + 36x  + 108x  + 109x
+--R     + 
+--R          3      2
+--R       12x  + 54x  + 108x + 81
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 938
+
+--S 939 of 940
+r0:=(2-3*x+5*x^2+x^4-5*x^6)/(3+x+x^4)^3
+--R 
+--R
+--R                            6    4     2
+--R                        - 5x  + x  + 5x  - 3x + 2
+--R   (2)  ---------------------------------------------------------
+--R         12     9     8     6      5      4    3     2
+--R        x   + 3x  + 9x  + 3x  + 18x  + 27x  + x  + 9x  + 27x + 27
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 939
+
+--S 940 of 940
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 940
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
+
diff --git a/src/input/richder20a.input.pamphlet b/src/input/richder20a.input.pamphlet
new file mode 100644
index 0000000..bce2bd0
--- /dev/null
+++ b/src/input/richder20a.input.pamphlet
@@ -0,0 +1,5810 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder20a.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|y'[x] f[y[x]]|
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder20a.output
+)spool richder20a.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 361
+t0:=(b+2*c*x+3*d*x^2)*(a+b*x+c*x^2+d*x^3)^n
+--R 
+--R
+--R             2                3      2           n
+--R   (1)  (3d x  + 2c x + b)(d x  + c x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 361
+r0:=(a+b*x+c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2           n + 1
+--R        (d x  + c x  + b x + a)
+--R   (2)  ----------------------------
+--R                    n + 1
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 361
+t0:=(b+2*c*x+3*d*x^2)*(b*x+c*x^2+d*x^3)^n
+--R 
+--R
+--R             2                3      2       n
+--R   (1)  (3d x  + 2c x + b)(d x  + c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 361
+r0:=(b*x+c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2       n + 1
+--R        (d x  + c x  + b x)
+--R   (2)  ------------------------
+--R                  n + 1
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 361
+t0:=x^n*(b+c*x+d*x^2)^n*(b+2*c*x+3*d*x^2)
+--R 
+--R
+--R             2             n    2           n
+--R   (1)  (3d x  + 2c x + b)x (d x  + c x + b)
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 361
+r0:=x^(1+n)*(b+c*x+d*x^2)^(1+n)/(1+n)
+--R 
+--R
+--R         n + 1    2           n + 1
+--R        x     (d x  + c x + b)
+--R   (2)  ---------------------------
+--R                   n + 1
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 361
+t0:=(b+3*d*x^2)*(a+b*x+d*x^3)^n
+--R 
+--R
+--R             2         3           n
+--R   (1)  (3d x  + b)(d x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 361
+r0:=(a+b*x+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3           n + 1
+--R        (d x  + b x + a)
+--R   (2)  ---------------------
+--R                n + 1
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 361
+t0:=(b+3*d*x^2)*(b*x+d*x^3)^n
+--R 
+--R
+--R             2         3       n
+--R   (1)  (3d x  + b)(d x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 361
+r0:=(b*x+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3       n + 1
+--R        (d x  + b x)
+--R   (2)  -----------------
+--R              n + 1
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 361
+t0:=x^n*(b+d*x^2)^n*(b+3*d*x^2)
+--R 
+--R
+--R             2      n    2     n
+--R   (1)  (3d x  + b)x (d x  + b)
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 361
+r0:=x^(1+n)*(b+d*x^2)^(1+n)/(1+n)
+--R 
+--R
+--R         n + 1    2     n + 1
+--R        x     (d x  + b)
+--R   (2)  ---------------------
+--R                n + 1
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 361
+t0:=(2*c*x+3*d*x^2)*(a+c*x^2+d*x^3)^n
+--R 
+--R
+--R             2            3      2     n
+--R   (1)  (3d x  + 2c x)(d x  + c x  + a)
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 361
+r0:=(a+c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2     n + 1
+--R        (d x  + c x  + a)
+--R   (2)  ----------------------
+--R                 n + 1
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 361
+t0:=(2*c*x+3*d*x^2)*(c*x^2+d*x^3)^n
+--R 
+--R
+--R             2            3      2 n
+--R   (1)  (3d x  + 2c x)(d x  + c x )
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 361
+r0:=(c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2 n + 1
+--R        (d x  + c x )
+--R   (2)  ------------------
+--R               n + 1
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 361
+t0:=x^n*(c*x+d*x^2)^n*(2*c*x+3*d*x^2)
+--R 
+--R
+--R             2         n    2       n
+--R   (1)  (3d x  + 2c x)x (d x  + c x)
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 361
+r0:=x^(1+n)*(c*x+d*x^2)^(1+n)/(1+n)
+--R 
+--R
+--R         n + 1    2       n + 1
+--R        x     (d x  + c x)
+--R   (2)  -----------------------
+--R                 n + 1
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 361
+t0:=x^(2*n)*(c+d*x)^n*(2*c*x+3*d*x^2)
+--R 
+--R
+--R             2         2n         n
+--R   (1)  (3d x  + 2c x)x  (d x + c)
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 361
+r0:=x^(2*(1+n))*(c+d*x)^(1+n)/(1+n)
+--R 
+--R
+--R         2n + 2         n + 1
+--R        x      (d x + c)
+--R   (2)  ---------------------
+--R                n + 1
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 361
+t0:=x*(2*c+3*d*x)*(a+c*x^2+d*x^3)^n
+--R 
+--R
+--R             2            3      2     n
+--R   (1)  (3d x  + 2c x)(d x  + c x  + a)
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 361
+r0:=(a+c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2     n + 1
+--R        (d x  + c x  + a)
+--R   (2)  ----------------------
+--R                 n + 1
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 361
+t0:=x*(2*c+3*d*x)*(c*x^2+d*x^3)^n
+--R 
+--R
+--R             2            3      2 n
+--R   (1)  (3d x  + 2c x)(d x  + c x )
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 361
+r0:=(c*x^2+d*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R            3      2 n + 1
+--R        (d x  + c x )
+--R   (2)  ------------------
+--R               n + 1
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 361
+t0:=(b+2*c*x+3*d*x^2)*(a+b*x+c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22         7      2 6  21
+--R     3d x   + 23c d x   + (22b d  + 77c d )x
+--R   + 
+--R           7           6       3 5  20
+--R     (21a d  + 147b c d  + 147c d )x
+--R   + 
+--R                   2  6         2 5       4 4  19
+--R     ((140a c + 70b )d  + 420b c d  + 175c d )x
+--R   + 
+--R              6          2       2   5         3 4       5 3  18
+--R     (133a b d  + (399a c  + 399b c)d  + 665b c d  + 133c d )x
+--R   + 
+--R            2 6                   3  5          3       2 2  4         4 3
+--R         63a d  + (756a b c + 126b )d  + (630a c  + 945b c )d  + 630b c d
+--R       + 
+--R            6 2
+--R         63c d
+--R    *
+--R        17
+--R       x
+--R   + 
+--R              2          2  5             2       3   4          4        2 3  3
+--R         (357a c + 357a b )d  + (1785a b c  + 595b c)d  + (595a c  + 1190b c )d
+--R       + 
+--R               5 2      7
+--R         357b c d  + 17c d
+--R    *
+--R        16
+--R       x
+--R   + 
+--R             2   5        2 2          2        4  4             3        3 2  3
+--R         336a b d  + (840a c  + 1680a b c + 140b )d  + (2240a b c  + 1120b c )d
+--R       + 
+--R                5       2 4  2         6      8
+--R         (336a c  + 840b c )d  + 112b c d + 2c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R             3 5         2            3  4         2 3          2 2       4   3
+--R         105a d  + (1575a b c + 525a b )d  + (1050a c  + 3150a b c  + 525b c)d
+--R       + 
+--R                   4        3 3  2          6       2 5          7
+--R         (1575a b c  + 1050b c )d  + (105a c  + 315b c )d + 15b c
+--R    *
+--R        14
+--R       x
+--R   + 
+--R              3        2 2  4         2   2          3       5  3
+--R         (490a c + 735a b )d  + (2940a b c  + 1960a b c + 98b )d
+--R       + 
+--R              2 4          2 3       4 2  2            5       3 4          7
+--R         (735a c  + 2940a b c  + 735b c )d  + (588a b c  + 490b c )d + 14a c
+--R       + 
+--R            2 6
+--R         49b c
+--R    *
+--R        13
+--R       x
+--R   + 
+--R             3   4        3 2        2 2          4  3
+--R         455a b d  + (910a c  + 2730a b c + 455a b )d
+--R       + 
+--R               2   3          3 2       5   2
+--R         (2730a b c  + 2730a b c  + 273b c)d
+--R       + 
+--R              2 5          2 4       4 3            6      3 5
+--R         (273a c  + 1365a b c  + 455b c )d + 91a b c  + 91b c
+--R    *
+--R        12
+--R       x
+--R   + 
+--R             4 4         3          2 3  3
+--R         105a d  + (1680a b c + 840a b )d
+--R       + 
+--R              3 3        2 2 2          4       6  2
+--R         (840a c  + 3780a b c  + 1260a b c + 42b )d
+--R       + 
+--R               2   4          3 3       5 2        2 6         2 5       4 4
+--R         (1260a b c  + 1680a b c  + 252b c )d + 42a c  + 252a b c  + 105b c
+--R    *
+--R        11
+--R       x
+--R   + 
+--R              4        3 2  3         3   2        2 3          5  2
+--R         (385a c + 770a b )d  + (2310a b c  + 2310a b c + 231a b )d
+--R       + 
+--R              3 4        2 2 3          4 2      6          2   5         3 4
+--R         (385a c  + 2310a b c  + 1155a b c  + 77b c)d + 231a b c  + 385a b c
+--R       + 
+--R            5 3
+--R         77b c
+--R    *
+--R        10
+--R       x
+--R   + 
+--R             4   3        4 2        3 2        2 4  2
+--R         350a b d  + (525a c  + 2100a b c + 525a b )d
+--R       + 
+--R               3   3        2 3 2         5       7        3 5       2 2 4
+--R         (1400a b c  + 2100a b c  + 420a b c + 10b )d + 70a c  + 525a b c
+--R       + 
+--R               4 3      6 2
+--R         350a b c  + 35b c
+--R    *
+--R        9
+--R       x
+--R   + 
+--R            5 3        4          3 3  2
+--R         63a d  + (945a b c + 630a b )d
+--R       + 
+--R              4 3        3 2 2       2 4         6         3   4       2 3 3
+--R         (315a c  + 1890a b c  + 945a b c + 63a b )d + 315a b c  + 630a b c
+--R       + 
+--R               5 2     7
+--R         189a b c  + 9b c
+--R    *
+--R        8
+--R       x
+--R   + 
+--R              5        4 2  2        4   2        3 3        2 5        4 4
+--R         (168a c + 420a b )d  + (840a b c  + 1120a b c + 168a b )d + 70a c
+--R       + 
+--R             3 2 3       2 4 2        6     8
+--R         560a b c  + 420a b c  + 56a b c + b
+--R    *
+--R        7
+--R       x
+--R   + 
+--R             5   2        5 2       4 2        3 4         4   3       3 3 2
+--R         147a b d  + (147a c  + 735a b c + 245a b )d + 245a b c  + 490a b c
+--R       + 
+--R             2 5        7
+--R         147a b c + 7a b
+--R    *
+--R        6
+--R       x
+--R   + 
+--R         6 2        5          4 3        5 3       4 2 2       3 4       2 6  5
+--R     (21a d  + (252a b c + 210a b )d + 42a c  + 315a b c  + 210a b c + 21a b )x
+--R   + 
+--R          6        5 2         5   2       4 3       3 5  4
+--R     ((35a c + 105a b )d + 105a b c  + 175a b c + 35a b )x
+--R   + 
+--R         6         6 2      5 2       4 4  3      7       6         5 3  2
+--R     (28a b d + 14a c  + 84a b c + 35a b )x  + (3a d + 21a b c + 21a b )x
+--R   + 
+--R        7      6 2      7
+--R     (2a c + 7a b )x + a b
+--R                                                    Type: Polynomial(Integer)
+--E 37
+
+--S 38 of 361
+r0:=1/8*(a+b*x+c*x^2+d*x^3)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23       7   7  2 6  22       7         6     3 5  21
+--R     - d x   + c d x   + (b d  + - c d )x   + (a d  + 7b c d  + 7c d )x
+--R     8                           2
+--R   + 
+--R              7  2  6        2 5   35  4 4  20
+--R     ((7a c + - b )d  + 21b c d  + -- c d )x
+--R              2                     4
+--R   + 
+--R            6         2      2   5        3 4     5 3  19
+--R     (7a b d  + (21a c  + 21b c)d  + 35b c d  + 7c d )x
+--R   + 
+--R      7  2 6                3  5         3   105  2 2  4        4 3   7  6 2  18
+--R     (- a d  + (42a b c + 7b )d  + (35a c  + --- b c )d  + 35b c d  + - c d )x
+--R      2                                       2                       2
+--R   + 
+--R             2         2  5            2      3   4         4      2 3  3
+--R         (21a c + 21a b )d  + (105a b c  + 35b c)d  + (35a c  + 70b c )d
+--R       + 
+--R              5 2    7
+--R         21b c d  + c d
+--R    *
+--R        17
+--R       x
+--R   + 
+--R            2   5    105  2 2         2    35  4  4            3      3 2  3
+--R         21a b d  + (--- a c  + 105a b c + -- b )d  + (140a b c  + 70b c )d
+--R                      2                     4
+--R       + 
+--R               5   105  2 4  2       6    1  8
+--R         (21a c  + --- b c )d  + 7b c d + - c
+--R                    2                     8
+--R    *
+--R        16
+--R       x
+--R   + 
+--R           3 5        2           3  4       2 3         2 2      4   3
+--R         7a d  + (105a b c + 35a b )d  + (70a c  + 210a b c  + 35b c)d
+--R       + 
+--R                  4      3 3  2        6      2 5        7
+--R         (105a b c  + 70b c )d  + (7a c  + 21b c )d + b c
+--R    *
+--R        15
+--R       x
+--R   + 
+--R             3    105  2 2  4        2   2         3      5  3
+--R         (35a c + --- a b )d  + (210a b c  + 140a b c + 7b )d
+--R                   2
+--R       + 
+--R          105  2 4         2 3   105  4 2  2           5      3 4        7
+--R         (--- a c  + 210a b c  + --- b c )d  + (42a b c  + 35b c )d + a c
+--R           2                      2
+--R       + 
+--R         7  2 6
+--R         - b c
+--R         2
+--R    *
+--R        14
+--R       x
+--R   + 
+--R            3   4       3 2       2 2         4  3
+--R         35a b d  + (70a c  + 210a b c + 35a b )d
+--R       + 
+--R              2   3         3 2      5   2       2 5         2 4      4 3
+--R         (210a b c  + 210a b c  + 21b c)d  + (21a c  + 105a b c  + 35b c )d
+--R       + 
+--R               6     3 5
+--R         7a b c  + 7b c
+--R    *
+--R        13
+--R       x
+--R   + 
+--R         35  4 4        3         2 3  3
+--R         -- a d  + (140a b c + 70a b )d
+--R          4
+--R       + 
+--R             3 3       2 2 2         4    7  6  2
+--R         (70a c  + 315a b c  + 105a b c + - b )d
+--R                                          2
+--R       + 
+--R              2   4         3 3      5 2     7  2 6        2 5   35  4 4
+--R         (105a b c  + 140a b c  + 21b c )d + - a c  + 21a b c  + -- b c
+--R                                             2                    4
+--R    *
+--R        12
+--R       x
+--R   + 
+--R             4       3 2  3        3   2       2 3         5  2
+--R         (35a c + 70a b )d  + (210a b c  + 210a b c + 21a b )d
+--R       + 
+--R             3 4       2 2 3         4 2     6         2   5        3 4     5 3
+--R         (35a c  + 210a b c  + 105a b c  + 7b c)d + 21a b c  + 35a b c  + 7b c
+--R    *
+--R        11
+--R       x
+--R   + 
+--R            4   3    105  4 2       3 2    105  2 4  2
+--R         35a b d  + (--- a c  + 210a b c + --- a b )d
+--R                      2                     2
+--R       + 
+--R              3   3       2 3 2        5     7       3 5   105  2 2 4        4 3
+--R         (140a b c  + 210a b c  + 42a b c + b )d + 7a c  + --- a b c  + 35a b c
+--R                                                            2
+--R       + 
+--R         7  6 2
+--R         - b c
+--R         2
+--R    *
+--R        10
+--R       x
+--R   + 
+--R           5 3        4         3 3  2
+--R         7a d  + (105a b c + 70a b )d
+--R       + 
+--R             4 3       3 2 2       2 4        6        3   4      2 3 3
+--R         (35a c  + 210a b c  + 105a b c + 7a b )d + 35a b c  + 70a b c
+--R       + 
+--R              5 2    7
+--R         21a b c  + b c
+--R    *
+--R        9
+--R       x
+--R   + 
+--R             5    105  4 2  2        4   2       3 3       2 5     35  4 4
+--R         (21a c + --- a b )d  + (105a b c  + 140a b c + 21a b )d + -- a c
+--R                   2                                                4
+--R       + 
+--R            3 2 3   105  2 4 2       6    1  8
+--R         70a b c  + --- a b c  + 7a b c + - b
+--R                     2                    8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R            5   2       5 2       4 2       3 4        4   3      3 3 2
+--R         21a b d  + (21a c  + 105a b c + 35a b )d + 35a b c  + 70a b c
+--R       + 
+--R            2 5       7
+--R         21a b c + a b
+--R    *
+--R        7
+--R       x
+--R   + 
+--R      7  6 2       5         4 3       5 3   105  4 2 2      3 4    7  2 6  6
+--R     (- a d  + (42a b c + 35a b )d + 7a c  + --- a b c  + 35a b c + - a b )x
+--R      2                                       2                     2
+--R   + 
+--R         6       5 2        5   2      4 3      3 5  5
+--R     ((7a c + 21a b )d + 21a b c  + 35a b c + 7a b )x
+--R   + 
+--R        6      7  6 2      5 2    35  4 4  4     7      6        5 3  3
+--R     (7a b d + - a c  + 21a b c + -- a b )x  + (a d + 7a b c + 7a b )x
+--R               2                   4
+--R   + 
+--R       7    7  6 2  2    7      1  8
+--R     (a c + - a b )x  + a b x + - a
+--R            2                   8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 38
+
+--S 39 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 361
+t0:=(b+2*c*x+3*d*x^2)*(b*x+c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22         7      2 6  21            6       3 5  20
+--R     3d x   + 23c d x   + (22b d  + 77c d )x   + (147b c d  + 147c d )x
+--R   + 
+--R         2 6         2 5       4 4  19        2   5         3 4       5 3  18
+--R     (70b d  + 420b c d  + 175c d )x   + (399b c d  + 665b c d  + 133c d )x
+--R   + 
+--R          3 5       2 2 4         4 3      6 2  17
+--R     (126b d  + 945b c d  + 630b c d  + 63c d )x
+--R   + 
+--R          3   4        2 3 3         5 2      7   16
+--R     (595b c d  + 1190b c d  + 357b c d  + 17c d)x
+--R   + 
+--R          4 4        3 2 3       2 4 2         6      8  15
+--R     (140b d  + 1120b c d  + 840b c d  + 112b c d + 2c )x
+--R   + 
+--R          4   3        3 3 2       2 5         7  14
+--R     (525b c d  + 1050b c d  + 315b c d + 15b c )x
+--R   + 
+--R         5 3       4 2 2       3 4       2 6  13
+--R     (98b d  + 735b c d  + 490b c d + 49b c )x
+--R   + 
+--R          5   2       4 3       3 5  12       6 2       5 2        4 4  11
+--R     (273b c d  + 455b c d + 91b c )x   + (42b d  + 252b c d + 105b c )x
+--R   + 
+--R         6         5 3  10       7       6 2  9     7   8    8 7
+--R     (77b c d + 77b c )x   + (10b d + 35b c )x  + 9b c x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 40
+
+--S 41 of 361
+r0:=1/8*(b*x+c*x^2+d*x^3)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23       7   7  2 6  22          6     3 5  21
+--R     - d x   + c d x   + (b d  + - c d )x   + (7b c d  + 7c d )x
+--R     8                           2
+--R   + 
+--R      7  2 6        2 5   35  4 4  20       2   5        3 4     5 3  19
+--R     (- b d  + 21b c d  + -- c d )x   + (21b c d  + 35b c d  + 7c d )x
+--R      2                    4
+--R   + 
+--R        3 5   105  2 2 4        4 3   7  6 2  18
+--R     (7b d  + --- b c d  + 35b c d  + - c d )x
+--R               2                      2
+--R   + 
+--R         3   4      2 3 3        5 2    7   17
+--R     (35b c d  + 70b c d  + 21b c d  + c d)x
+--R   + 
+--R      35  4 4      3 2 3   105  2 4 2       6    1  8  16
+--R     (-- b d  + 70b c d  + --- b c d  + 7b c d + - c )x
+--R       4                    2                    8
+--R   + 
+--R         4   3      3 3 2      2 5       7  15
+--R     (35b c d  + 70b c d  + 21b c d + b c )x
+--R   + 
+--R        5 3   105  4 2 2      3 4    7  2 6  14
+--R     (7b d  + --- b c d  + 35b c d + - b c )x
+--R               2                     2
+--R   + 
+--R         5   2      4 3      3 5  13    7  6 2      5 2    35  4 4  12
+--R     (21b c d  + 35b c d + 7b c )x   + (- b d  + 21b c d + -- b c )x
+--R                                        2                   4
+--R   + 
+--R        6        5 3  11     7    7  6 2  10    7   9   1  8 8
+--R     (7b c d + 7b c )x   + (b d + - b c )x   + b c x  + - b x
+--R                                  2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 41
+
+--S 42 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 361
+t0:=x^7*(b+c*x+d*x^2)^7*(b+2*c*x+3*d*x^2)
+--R 
+--R
+--R   (1)
+--R       8 23        7 22         7      2 6  21            6       3 5  20
+--R     3d x   + 23c d x   + (22b d  + 77c d )x   + (147b c d  + 147c d )x
+--R   + 
+--R         2 6         2 5       4 4  19        2   5         3 4       5 3  18
+--R     (70b d  + 420b c d  + 175c d )x   + (399b c d  + 665b c d  + 133c d )x
+--R   + 
+--R          3 5       2 2 4         4 3      6 2  17
+--R     (126b d  + 945b c d  + 630b c d  + 63c d )x
+--R   + 
+--R          3   4        2 3 3         5 2      7   16
+--R     (595b c d  + 1190b c d  + 357b c d  + 17c d)x
+--R   + 
+--R          4 4        3 2 3       2 4 2         6      8  15
+--R     (140b d  + 1120b c d  + 840b c d  + 112b c d + 2c )x
+--R   + 
+--R          4   3        3 3 2       2 5         7  14
+--R     (525b c d  + 1050b c d  + 315b c d + 15b c )x
+--R   + 
+--R         5 3       4 2 2       3 4       2 6  13
+--R     (98b d  + 735b c d  + 490b c d + 49b c )x
+--R   + 
+--R          5   2       4 3       3 5  12       6 2       5 2        4 4  11
+--R     (273b c d  + 455b c d + 91b c )x   + (42b d  + 252b c d + 105b c )x
+--R   + 
+--R         6         5 3  10       7       6 2  9     7   8    8 7
+--R     (77b c d + 77b c )x   + (10b d + 35b c )x  + 9b c x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 43
+
+--S 44 of 361
+r0:=1/8*x^8*(b+c*x+d*x^2)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23       7   7  2 6  22          6     3 5  21
+--R     - d x   + c d x   + (b d  + - c d )x   + (7b c d  + 7c d )x
+--R     8                           2
+--R   + 
+--R      7  2 6        2 5   35  4 4  20       2   5        3 4     5 3  19
+--R     (- b d  + 21b c d  + -- c d )x   + (21b c d  + 35b c d  + 7c d )x
+--R      2                    4
+--R   + 
+--R        3 5   105  2 2 4        4 3   7  6 2  18
+--R     (7b d  + --- b c d  + 35b c d  + - c d )x
+--R               2                      2
+--R   + 
+--R         3   4      2 3 3        5 2    7   17
+--R     (35b c d  + 70b c d  + 21b c d  + c d)x
+--R   + 
+--R      35  4 4      3 2 3   105  2 4 2       6    1  8  16
+--R     (-- b d  + 70b c d  + --- b c d  + 7b c d + - c )x
+--R       4                    2                    8
+--R   + 
+--R         4   3      3 3 2      2 5       7  15
+--R     (35b c d  + 70b c d  + 21b c d + b c )x
+--R   + 
+--R        5 3   105  4 2 2      3 4    7  2 6  14
+--R     (7b d  + --- b c d  + 35b c d + - b c )x
+--R               2                     2
+--R   + 
+--R         5   2      4 3      3 5  13    7  6 2      5 2    35  4 4  12
+--R     (21b c d  + 35b c d + 7b c )x   + (- b d  + 21b c d + -- b c )x
+--R                                        2                   4
+--R   + 
+--R        6        5 3  11     7    7  6 2  10    7   9   1  8 8
+--R     (7b c d + 7b c )x   + (b d + - b c )x   + b c x  + - b x
+--R                                  2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 44
+
+--S 45 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 361
+t0:=(b+3*d*x^2)*(a+b*x+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 21        7 20      2 6 19           6 18
+--R     3d x   + 22b d x   + 21a d x   + 70b d x   + 133a b d x
+--R   + 
+--R         2 6       3 5  17         2 5 16        2   5       4 4  15
+--R     (63a d  + 126b d )x   + 357a b d x   + (336a b d  + 140b d )x
+--R   + 
+--R          3 5         3 4  14        2 2 4      5 3  13
+--R     (105a d  + 525a b d )x   + (735a b d  + 98b d )x
+--R   + 
+--R          3   4         4 3  12        4 4       2 3 3      6 2  11
+--R     (455a b d  + 455a b d )x   + (105a d  + 840a b d  + 42b d )x
+--R   + 
+--R          3 2 3         5 2  10        4   3       2 4 2      7   9
+--R     (770a b d  + 231a b d )x   + (350a b d  + 525a b d  + 10b d)x
+--R   + 
+--R         5 3       3 3 2        6   8        4 2 2       2 5     8  7
+--R     (63a d  + 630a b d  + 63a b d)x  + (420a b d  + 168a b d + b )x
+--R   + 
+--R          5   2       3 4        7  6       6 2       4 3       2 6  5
+--R     (147a b d  + 245a b d + 7a b )x  + (21a d  + 210a b d + 21a b )x
+--R   + 
+--R          5 2       3 5  4       6         4 4  3      7       5 3  2     6 2
+--R     (105a b d + 35a b )x  + (28a b d + 35a b )x  + (3a d + 21a b )x  + 7a b x
+--R   + 
+--R      7
+--R     a b
+--R                                                    Type: Polynomial(Integer)
+--E 46
+
+--S 47 of 361
+r0:=1/8*(a+b*x+d*x^3)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 22      7 21   7  2 6 20         6 19    7  2 6     3 5  18
+--R     - d x   + b d x   + a d x   + - b d x   + 7a b d x   + (- a d  + 7b d )x
+--R     8                             2                         2
+--R   + 
+--R          2 5 17       2   5   35  4 4  16      3 5        3 4  15
+--R     21a b d x   + (21a b d  + -- b d )x   + (7a d  + 35a b d )x
+--R                                4
+--R   + 
+--R      105  2 2 4     5 3  14       3   4        4 3  13
+--R     (--- a b d  + 7b d )x   + (35a b d  + 35a b d )x
+--R       2
+--R   + 
+--R      35  4 4      2 3 3   7  6 2  12       3 2 3        5 2  11
+--R     (-- a d  + 70a b d  + - b d )x   + (70a b d  + 21a b d )x
+--R       4                   2
+--R   + 
+--R         4   3   105  2 4 2    7   10      5 3      3 3 2       6   9
+--R     (35a b d  + --- a b d  + b d)x   + (7a d  + 70a b d  + 7a b d)x
+--R                  2
+--R   + 
+--R      105  4 2 2      2 5    1  8  8       5   2      3 4       7  7
+--R     (--- a b d  + 21a b d + - b )x  + (21a b d  + 35a b d + a b )x
+--R       2                     8
+--R   + 
+--R      7  6 2      4 3    7  2 6  6       5 2      3 5  5      6      35  4 4  4
+--R     (- a d  + 35a b d + - a b )x  + (21a b d + 7a b )x  + (7a b d + -- a b )x
+--R      2                  2                                            4
+--R   + 
+--R       7      5 3  3   7  6 2 2    7      1  8
+--R     (a d + 7a b )x  + - a b x  + a b x + - a
+--R                       2                  8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 47
+
+--S 48 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 361
+t0:=x^7*(b+d*x^2)^7*(b+3*d*x^2)
+--R 
+--R
+--R   (1)
+--R       8 23        7 21      2 6 19       3 5 17       4 4 15      5 3 13
+--R     3d x   + 22b d x   + 70b d x   + 126b d x   + 140b d x   + 98b d x
+--R   + 
+--R        6 2 11      7   9    8 7
+--R     42b d x   + 10b d x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 49
+
+--S 50 of 361
+r0:=1/8*x^8*(b+d*x^2)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 22   7  2 6 20     3 5 18   35  4 4 16     5 3 14
+--R     - d x   + b d x   + - b d x   + 7b d x   + -- b d x   + 7b d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 12    7   10   1  8 8
+--R     - b d x   + b d x   + - b x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 50
+
+--S 51 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 361
+t0:=(b+3*d*x^2)*(b*x+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 21      2 6 19       3 5 17       4 4 15      5 3 13
+--R     3d x   + 22b d x   + 70b d x   + 126b d x   + 140b d x   + 98b d x
+--R   + 
+--R        6 2 11      7   9    8 7
+--R     42b d x   + 10b d x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 52
+
+--S 53 of 361
+r0:=1/8*x^8*(b+d*x^2)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 22   7  2 6 20     3 5 18   35  4 4 16     5 3 14
+--R     - d x   + b d x   + - b d x   + 7b d x   + -- b d x   + 7b d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 12    7   10   1  8 8
+--R     - b d x   + b d x   + - b x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 53
+
+--S 54 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 361
+t0:=(2*c*x+3*d*x^2)*(a+c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21         7       3 5  20
+--R     3d x   + 23c d x   + 77c d x   + (21a d  + 147c d )x
+--R   + 
+--R              6       4 4  19          2 5       5 3  18
+--R     (140a c d  + 175c d )x   + (399a c d  + 133c d )x
+--R   + 
+--R         2 6         3 4      6 2  17        2   5         4 3      7   16
+--R     (63a d  + 630a c d  + 63c d )x   + (357a c d  + 595a c d  + 17c d)x
+--R   + 
+--R          2 2 4         5 2     8  15        3 5        2 3 3         6   14
+--R     (840a c d  + 336a c d  + 2c )x   + (105a d  + 1050a c d  + 105a c d)x
+--R   + 
+--R          3   4       2 4 2        7  13        3 2 3       2 5   12
+--R     (490a c d  + 735a c d  + 14a c )x   + (910a c d  + 273a c d)x
+--R   + 
+--R          4 4       3 3 2      2 6  11        4   3       3 4   10
+--R     (105a d  + 840a c d  + 42a c )x   + (385a c d  + 385a c d)x
+--R   + 
+--R          4 2 2      3 5  9       5 3       4 3   8        5   2      4 4  7
+--R     (525a c d  + 70a c )x  + (63a d  + 315a c d)x  + (168a c d  + 70a c )x
+--R   + 
+--R       5 2   6       6 2      5 3  5      6     4      6 2 3     7   2     7
+--R   147a c d x  + (21a d  + 42a c )x  + 35a c d x  + 14a c x  + 3a d x  + 2a c x
+--R                                                    Type: Polynomial(Integer)
+--E 55
+
+--S 56 of 361
+r0:=1/8*(a+c*x^2+d*x^3)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22       7     3 5  21          6   35  4 4  20
+--R     - d x   + c d x   + - c d x   + (a d  + 7c d )x   + (7a c d  + -- c d )x
+--R     8                   2                                           4
+--R   + 
+--R           2 5     5 3  19    7  2 6        3 4   7  6 2  18
+--R     (21a c d  + 7c d )x   + (- a d  + 35a c d  + - c d )x
+--R                              2                   2
+--R   + 
+--R         2   5        4 3    7   17    105  2 2 4        5 2   1  8  16
+--R     (21a c d  + 35a c d  + c d)x   + (--- a c d  + 21a c d  + - c )x
+--R                                        2                      8
+--R   + 
+--R        3 5      2 3 3       6   15       3   4   105  2 4 2      7  14
+--R     (7a d  + 70a c d  + 7a c d)x   + (35a c d  + --- a c d  + a c )x
+--R                                                   2
+--R   + 
+--R         3 2 3      2 5   13    35  4 4      3 3 2   7  2 6  12
+--R     (70a c d  + 21a c d)x   + (-- a d  + 70a c d  + - a c )x
+--R                                 4                   2
+--R   + 
+--R         4   3      3 4   11    105  4 2 2     3 5  10      5 3      4 3   9
+--R     (35a c d  + 35a c d)x   + (--- a c d  + 7a c )x   + (7a d  + 35a c d)x
+--R                                 2
+--R   + 
+--R         5   2   35  4 4  8      5 2   7    7  6 2     5 3  6     6     5
+--R     (21a c d  + -- a c )x  + 21a c d x  + (- a d  + 7a c )x  + 7a c d x
+--R                  4                         2
+--R   + 
+--R     7  6 2 4    7   3    7   2   1  8
+--R     - a c x  + a d x  + a c x  + - a
+--R     2                            8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 56
+
+--S 57 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 361
+t0:=(2*c*x+3*d*x^2)*(c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 58
+
+--S 59 of 361
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 59
+
+--S 60 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 361
+t0:=x^7*(c*x+d*x^2)^7*(2*c*x+3*d*x^2)
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 61
+
+--S 62 of 361
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 62
+
+--S 63 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 361
+t0:=x^14*(c+d*x)^7*(2*c*x+3*d*x^2)
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 64
+
+--S 65 of 361
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 65
+
+--S 66 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 361
+t0:=x*(2*c+3*d*x)*(a+c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21         7       3 5  20
+--R     3d x   + 23c d x   + 77c d x   + (21a d  + 147c d )x
+--R   + 
+--R              6       4 4  19          2 5       5 3  18
+--R     (140a c d  + 175c d )x   + (399a c d  + 133c d )x
+--R   + 
+--R         2 6         3 4      6 2  17        2   5         4 3      7   16
+--R     (63a d  + 630a c d  + 63c d )x   + (357a c d  + 595a c d  + 17c d)x
+--R   + 
+--R          2 2 4         5 2     8  15        3 5        2 3 3         6   14
+--R     (840a c d  + 336a c d  + 2c )x   + (105a d  + 1050a c d  + 105a c d)x
+--R   + 
+--R          3   4       2 4 2        7  13        3 2 3       2 5   12
+--R     (490a c d  + 735a c d  + 14a c )x   + (910a c d  + 273a c d)x
+--R   + 
+--R          4 4       3 3 2      2 6  11        4   3       3 4   10
+--R     (105a d  + 840a c d  + 42a c )x   + (385a c d  + 385a c d)x
+--R   + 
+--R          4 2 2      3 5  9       5 3       4 3   8        5   2      4 4  7
+--R     (525a c d  + 70a c )x  + (63a d  + 315a c d)x  + (168a c d  + 70a c )x
+--R   + 
+--R       5 2   6       6 2      5 3  5      6     4      6 2 3     7   2     7
+--R   147a c d x  + (21a d  + 42a c )x  + 35a c d x  + 14a c x  + 3a d x  + 2a c x
+--R                                                    Type: Polynomial(Integer)
+--E 67
+
+--S 68 of 361
+r0:=1/8*(a+c*x^2+d*x^3)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22       7     3 5  21          6   35  4 4  20
+--R     - d x   + c d x   + - c d x   + (a d  + 7c d )x   + (7a c d  + -- c d )x
+--R     8                   2                                           4
+--R   + 
+--R           2 5     5 3  19    7  2 6        3 4   7  6 2  18
+--R     (21a c d  + 7c d )x   + (- a d  + 35a c d  + - c d )x
+--R                              2                   2
+--R   + 
+--R         2   5        4 3    7   17    105  2 2 4        5 2   1  8  16
+--R     (21a c d  + 35a c d  + c d)x   + (--- a c d  + 21a c d  + - c )x
+--R                                        2                      8
+--R   + 
+--R        3 5      2 3 3       6   15       3   4   105  2 4 2      7  14
+--R     (7a d  + 70a c d  + 7a c d)x   + (35a c d  + --- a c d  + a c )x
+--R                                                   2
+--R   + 
+--R         3 2 3      2 5   13    35  4 4      3 3 2   7  2 6  12
+--R     (70a c d  + 21a c d)x   + (-- a d  + 70a c d  + - a c )x
+--R                                 4                   2
+--R   + 
+--R         4   3      3 4   11    105  4 2 2     3 5  10      5 3      4 3   9
+--R     (35a c d  + 35a c d)x   + (--- a c d  + 7a c )x   + (7a d  + 35a c d)x
+--R                                 2
+--R   + 
+--R         5   2   35  4 4  8      5 2   7    7  6 2     5 3  6     6     5
+--R     (21a c d  + -- a c )x  + 21a c d x  + (- a d  + 7a c )x  + 7a c d x
+--R                  4                         2
+--R   + 
+--R     7  6 2 4    7   3    7   2   1  8
+--R     - a c x  + a d x  + a c x  + - a
+--R     2                            8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 68
+
+--S 69 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 361
+t0:=x*(2*c+3*d*x)*(c*x^2+d*x^3)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 70
+
+--S 71 of 361
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 71
+
+--S 72 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 361
+t0:=x^8*(2*c+3*d*x)*(c*x+d*x^2)^7
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 73
+
+--S 74 of 361
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 74
+
+--S 75 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 361
+t0:=x^15*(c+d*x)^7*(2*c+3*d*x)
+--R 
+--R
+--R   (1)
+--R       8 23        7 22      2 6 21       3 5 20       4 4 19       5 3 18
+--R     3d x   + 23c d x   + 77c d x   + 147c d x   + 175c d x   + 133c d x
+--R   + 
+--R        6 2 17      7   16     8 15
+--R     63c d x   + 17c d x   + 2c x
+--R                                                    Type: Polynomial(Integer)
+--E 76
+
+--S 77 of 361
+r0:=1/8*x^16*(c+d*x)^8
+--R 
+--R
+--R   (2)
+--R     1  8 24      7 23   7  2 6 22     3 5 21   35  4 4 20     5 3 19
+--R     - d x   + c d x   + - c d x   + 7c d x   + -- c d x   + 7c d x
+--R     8                   2                       4
+--R   + 
+--R     7  6 2 18    7   17   1  8 16
+--R     - c d x   + c d x   + - c x
+--R     2                     8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 77
+
+--S 78 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 361
+t0:=(a+b*x)*(1+(a*x+1/2*b*x^2)^4)
+--R 
+--R
+--R         1  5 9    9    4 8     2 3 7   7  3 2 6     4   5    5 4
+--R   (1)  -- b x  + -- a b x  + 2a b x  + - a b x  + 3a b x  + a x  + b x + a
+--R        16        16                    2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 79
+
+--S 80 of 361
+r0:=a*x+1/2*b*x^2+1/5*(a*x+1/2*b*x^2)^5
+--R 
+--R
+--R   (2)
+--R      1   5 10    1    4 9   1  2 3 8   1  3 2 7   1  4   6   1  5 5   1    2
+--R     --- b x   + -- a b x  + - a b x  + - a b x  + - a b x  + - a x  + - b x
+--R     160         16          4          2          2          5        2
+--R   + 
+--R     a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 80
+
+--S 81 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 361
+t0:=(a+b*x)*(1+(c+a*x+1/2*b*x^2)^4)
+--R 
+--R
+--R   (1)
+--R      1  5 9    9    4 8    1  4      2 3  7    7    3    7  3 2  6
+--R     -- b x  + -- a b x  + (- b c + 2a b )x  + (- a b c + - a b )x
+--R     16        16           2                   2         2
+--R   + 
+--R      3  3 2     2 2      4   5    15    2 2      3       5  4
+--R     (- b c  + 9a b c + 3a b)x  + (-- a b c  + 10a b c + a )x
+--R      2                             2
+--R   + 
+--R        2 3      2   2     4   3          3     3 2  2       4     2 3
+--R     (2b c  + 12a b c  + 4a c)x  + (6a b c  + 6a c )x  + (b c  + 4a c  + b)x
+--R   + 
+--R        4
+--R     a c  + a
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 82
+
+--S 83 of 361
+r0:=a*x+1/2*b*x^2+1/5*(c+a*x+1/2*b*x^2)^5
+--R 
+--R
+--R   (2)
+--R      1   5 10    1    4 9     1  4    1  2 3  8    1    3    1  3 2  7
+--R     --- b x   + -- a b x  + (-- b c + - a b )x  + (- a b c + - a b )x
+--R     160         16           16       4            2         2
+--R   + 
+--R      1  3 2   3  2 2    1  4   6    3    2 2     3      1  5  5
+--R     (- b c  + - a b c + - a b)x  + (- a b c  + 2a b c + - a )x
+--R      4        2         2           2                   5
+--R   + 
+--R      1  2 3     2   2    4   4          3     3 2  3    1    4     2 3   1    2
+--R     (- b c  + 3a b c  + a c)x  + (2a b c  + 2a c )x  + (- b c  + 2a c  + - b)x
+--R      2                                                  2                2
+--R   + 
+--R         4         1  5
+--R     (a c  + a)x + - c
+--R                   5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 83
+
+--S 84 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 361
+t0:=(a+b*x)*(1+(a*x+1/2*b*x^2)^n)
+--R 
+--R
+--R                     2        n
+--R                  b x  + 2a x
+--R   (1)  (b x + a)(-----------)  + b x + a
+--R                       2
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 361
+r0:=a*x+1/2*b*x^2+(a*x+1/2*b*x^2)^(1+n)/(1+n)
+--R 
+--R
+--R             2        n + 1
+--R          b x  + 2a x                   2
+--R        2(-----------)      + (b n + b)x  + (2a n + 2a)x
+--R               2
+--R   (2)  ------------------------------------------------
+--R                             2n + 2
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 361
+t0:=(a+b*x)*(1+(c+a*x+1/2*b*x^2)^n)
+--R 
+--R
+--R                     2             n
+--R                  b x  + 2a x + 2c
+--R   (1)  (b x + a)(----------------)  + b x + a
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 361
+r0:=a*x+1/2*b*x^2+(c+a*x+1/2*b*x^2)^(1+n)/(1+n)
+--R 
+--R
+--R             2             n + 1
+--R          b x  + 2a x + 2c                   2
+--R        2(----------------)      + (b n + b)x  + (2a n + 2a)x
+--R                  2
+--R   (2)  -----------------------------------------------------
+--R                                2n + 2
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 361
+t0:=(a+c*x^2)*(1+(a*x+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    16    5 15   35  2 4 13   40  3 3 11   25  4 2 9   8  5   7
+--R     --- c x   + --- a c x   + -- a c x   + -- a c x   + -- a c x  + - a c x
+--R     243         243           81           27            9          3
+--R   + 
+--R      6 5      2
+--R     a x  + c x  + a
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 91
+
+--S 92 of 361
+r0:=a*x+1/3*c*x^3+1/6*(a*x+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 16    5   2 4 14   10  3 3 12    5  4 2 10   1  5   8
+--R     ---- c x   + --- a c x   + --- a c x   + -- a c x   + -- a c x   + - a c x
+--R     4374         243           162           81           18           3
+--R   + 
+--R     1  6 6   1    3
+--R     - a x  + - c x  + a x
+--R     6        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 92
+
+--S 93 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 361
+t0:=(a+c*x^2)*(1+(d+a*x+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    16    5 15    5  5   14   35  2 4 13   65    4   12
+--R     --- c x   + --- a c x   + -- c d x   + -- a c x   + -- a c d x
+--R     243         243           81           81           81
+--R   + 
+--R      10  4 2   40  3 3  11   110  2 3   10    100    3 2   25  4 2  9
+--R     (-- c d  + -- a c )x   + --- a c d x   + (--- a c d  + -- a c )x
+--R      27        27             27               27           9
+--R   + 
+--R      10  3 3      3 2   8    40  2 2 2   8  5   7    70    2 3   35  4     6
+--R     (-- c d  + 10a c d)x  + (-- a c d  + - a c)x  + (-- a c d  + -- a c d)x
+--R       9                       3          3            9           3
+--R   + 
+--R      5  2 4      3   2    6  5    50  2   3     5   4    20      4      4 2  3
+--R     (- c d  + 20a c d  + a )x  + (-- a c d  + 5a d)x  + (-- a c d  + 10a d )x
+--R      3                             3                      3
+--R   + 
+--R         5      3 3      2     2 4       5
+--R     (c d  + 10a d  + c)x  + 5a d x + a d  + a
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 94
+
+--S 95 of 361
+r0:=a*x+1/3*c*x^3+1/6*(d+a*x+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 16    1   5   15    5   2 4 14    5    4   13
+--R     ---- c x   + --- a c x   + --- c d x   + --- a c x   + -- a c d x
+--R     4374         243           243           162           81
+--R   + 
+--R       5   4 2   10  3 3  12   10  2 3   11    10    3 2    5  4 2  10
+--R     (--- c d  + -- a c )x   + -- a c d x   + (-- a c d  + -- a c )x
+--R      162        81            27              27          18
+--R   + 
+--R      10  3 3   10  3 2   9    5  2 2 2   1  5   8    10    2 3   5  4     7
+--R     (-- c d  + -- a c d)x  + (- a c d  + - a c)x  + (-- a c d  + - a c d)x
+--R      81         9             3          3            9          3
+--R   + 
+--R       5  2 4   10  3   2   1  6  6    10  2   3    5   5
+--R     (-- c d  + -- a c d  + - a )x  + (-- a c d  + a d)x
+--R      18         3          6           3
+--R   + 
+--R      5      4   5  4 2  4    1    5   10  3 3   1    3   5  2 4 2       5
+--R     (- a c d  + - a d )x  + (- c d  + -- a d  + - c)x  + - a d x  + (a d  + a)x
+--R      3          2            3         3        3        2
+--R   + 
+--R     1  6
+--R     - d
+--R     6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 95
+
+--S 96 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 361
+t0:=(b*x+c*x^2)*(1+(1/2*b*x^2+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    17    5 16   10  2 4 15    25  3 3 14    35  4 2 13
+--R     --- c x   + --- b c x   + -- b c x   + --- b c x   + --- b c x
+--R     243         486           81           108           144
+--R   + 
+--R     13  5   12    1  6 11      2
+--R     -- b c x   + -- b x   + c x  + b x
+--R     96           32
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 97
+
+--S 98 of 361
+r0:=1/2*b*x^2+1/3*c*x^3+1/6*(1/2*b*x^2+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 17    5   2 4 16    5   3 3 15    5   4 2 14
+--R     ---- c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R     4374         486           648           324           288
+--R   + 
+--R      1  5   13    1   6 12   1    3   1    2
+--R     -- b c x   + --- b x   + - c x  + - b x
+--R     96           384         3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 98
+
+--S 99 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 361
+t0:=(b*x+c*x^2)*(1+(d+1/2*b*x^2+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    17    5 16   10  2 4 15     5  5     25  3 3  14
+--R     --- c x   + --- b c x   + -- b c x   + (-- c d + --- b c )x
+--R     243         486           81            81       108
+--R   + 
+--R      35    4     35  4 2  13    65  2 3    13  5   12
+--R     (-- b c d + --- b c )x   + (-- b c d + -- b c)x
+--R      81         144             54         96
+--R   + 
+--R      10  4 2   5  3 2     1  6  11    55    3 2   55  4     10
+--R     (-- c d  + - b c d + -- b )x   + (-- b c d  + -- b c d)x
+--R      27        3         32           27          48
+--R   + 
+--R      25  2 2 2    5  5   9    10  3 3   15  3   2  8    40    2 3   5  4 2  7
+--R     (-- b c d  + -- b d)x  + (-- c d  + -- b c d )x  + (-- b c d  + - b d )x
+--R       6          16            9         4               9          4
+--R   + 
+--R     35  2   3 6    5  2 4   5  3 3  5   25      4 4   5  2 4 3       5      2
+--R     -- b c d x  + (- c d  + - b d )x  + -- b c d x  + - b d x  + (c d  + c)x
+--R      6             3        2            6            2
+--R   + 
+--R         5
+--R     (b d  + b)x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 100
+
+--S 101 of 361
+r0:=1/2*b*x^2+1/3*c*x^3+1/6*(d+1/2*b*x^2+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 17    5   2 4 16     1   5     5   3 3  15
+--R     ---- c x   + --- b c x   + --- b c x   + (--- c d + --- b c )x
+--R     4374         486           648            243       324
+--R   + 
+--R       5     4     5   4 2  14     5  2 3     1  5   13
+--R     (--- b c d + --- b c )x   + (-- b c d + -- b c)x
+--R      162         288             54         96
+--R   + 
+--R       5   4 2    5  3 2     1   6  12     5    3 2    5  4     11
+--R     (--- c d  + -- b c d + --- b )x   + (-- b c d  + -- b c d)x
+--R      162        36         384           27          48
+--R   + 
+--R       5  2 2 2    1  5   10    10  3 3    5  3   2  9    5    2 3    5  4 2  8
+--R     (-- b c d  + -- b d)x   + (-- c d  + -- b c d )x  + (- b c d  + -- b d )x
+--R      12          32            81        12              9          32
+--R   + 
+--R     5  2   3 7     5  2 4    5  3 3  6   5      4 5   5  2 4 4
+--R     - b c d x  + (-- c d  + -- b d )x  + - b c d x  + - b d x
+--R     6             18        12           6            8
+--R   + 
+--R      1    5   1    3    1    5   1    2   1  6
+--R     (- c d  + - c)x  + (- b d  + - b)x  + - d
+--R      3        3         2        2        6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 101
+
+--S 102 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 361
+t0:=(a+b*x+c*x^2)*(1+(a*x+1/2*b*x^2+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    17    5 16     16    5   10  2 4  15
+--R     --- c x   + --- b c x   + (--- a c  + -- b c )x
+--R     243         486            243        81
+--R   + 
+--R      25      4    25  3 3  14    35  2 4   35    2 3    35  4 2  13
+--R     (-- a b c  + --- b c )x   + (-- a c  + -- a b c  + --- b c )x
+--R      54          108             81        27          144
+--R   + 
+--R      65  2   3   65    3 2   13  5   12
+--R     (-- a b c  + -- a b c  + -- b c)x
+--R      27          36          96
+--R   + 
+--R      40  3 3     2 2 2   5    4     1  6  11
+--R     (-- a c  + 5a b c  + - a b c + -- b )x
+--R      27                  4         32
+--R   + 
+--R      55  3   2   55  2 3    11    5  10    25  4 2   25  3 2    25  2 4  9
+--R     (-- a b c  + -- a b c + -- a b )x   + (-- a c  + -- a b c + -- a b )x
+--R       9          12         32              9         3         16
+--R   + 
+--R    15  4      15  3 3  8    8  5      4 2  7   7  5   6    6 5      2
+--R   (-- a b c + -- a b )x  + (- a c + 5a b )x  + - a b x  + a x  + c x  + b x + a
+--R     2          4            3                  2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 103
+
+--S 104 of 361
+r0:=a*x+1/2*b*x^2+1/3*c*x^3+1/6*(a*x+1/2*b*x^2+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 17     1     5    5   2 4  16
+--R     ---- c x   + --- b c x   + (--- a c  + --- b c )x
+--R     4374         486            243        648
+--R   + 
+--R       5       4    5   3 3  15     5   2 4    5    2 3    5   4 2  14
+--R     (--- a b c  + --- b c )x   + (--- a c  + -- a b c  + --- b c )x
+--R      162          324             162        54          288
+--R   + 
+--R       5  2   3    5    3 2    1  5   13
+--R     (-- a b c  + -- a b c  + -- b c)x
+--R      27          36          96
+--R   + 
+--R      10  3 3    5  2 2 2    5    4     1   6  12
+--R     (-- a c  + -- a b c  + -- a b c + --- b )x
+--R      81        12          48         384
+--R   + 
+--R      5  3   2    5  2 3     1    5  11     5  4 2   5  3 2     5  2 4  10
+--R     (- a b c  + -- a b c + -- a b )x   + (-- a c  + - a b c + -- a b )x
+--R      9          12         32             18        6         32
+--R   + 
+--R      5  4       5  3 3  9    1  5    5  4 2  8   1  5   7   1  6 6   1    3
+--R     (- a b c + -- a b )x  + (- a c + - a b )x  + - a b x  + - a x  + - c x
+--R      6         12            3       8           2          6        3
+--R   + 
+--R     1    2
+--R     - b x  + a x
+--R     2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 104
+
+--S 105 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 361
+t0:=(a+b*x+c*x^2)*(1+(d+a*x+1/2*b*x^2+1/3*c*x^3)^5)
+--R 
+--R
+--R   (1)
+--R      1   6 17    17    5 16     16    5   10  2 4  15
+--R     --- c x   + --- b c x   + (--- a c  + -- b c )x
+--R     243         486            243        81
+--R   + 
+--R       5  5    25      4    25  3 3  14
+--R     (-- c d + -- a b c  + --- b c )x
+--R      81       54          108
+--R   + 
+--R      35    4    35  2 4   35    2 3    35  4 2  13
+--R     (-- b c d + -- a c  + -- a b c  + --- b c )x
+--R      81         81        27          144
+--R   + 
+--R       65    4   65  2 3     65  2   3   65    3 2   13  5   12
+--R     ((-- a c  + -- b c )d + -- a b c  + -- a b c  + -- b c)x
+--R       81        54          27          36          96
+--R   + 
+--R      10  4 2    40      3   5  3 2     40  3 3     2 2 2   5    4     1  6  11
+--R     (-- c d  + (-- a b c  + - b c )d + -- a c  + 5a b c  + - a b c + -- b )x
+--R      27          9          3          27                  4         32
+--R   + 
+--R         55    3 2    110  2 3   55    2 2   55  4      55  3   2   55  2 3
+--R         -- b c d  + (--- a c  + -- a b c  + -- b c)d + -- a b c  + -- a b c
+--R         27            27         6          48          9          12
+--R       + 
+--R         11    5
+--R         -- a b
+--R         32
+--R    *
+--R        10
+--R       x
+--R   + 
+--R          100    3   25  2 2  2    50  2   2   25    3     5  5     25  4 2
+--R         (--- a c  + -- b c )d  + (-- a b c  + -- a b c + -- b )d + -- a c
+--R           27         6             3           3         16         9
+--R       + 
+--R         25  3 2    25  2 4
+--R         -- a b c + -- a b
+--R          3         16
+--R    *
+--R        9
+--R       x
+--R   + 
+--R         10  3 3           2   15  3   2       3 2   45  2 2    45    4
+--R         -- c d  + (15a b c  + -- b c)d  + (10a c  + -- a b c + -- a b )d
+--R          9                     4                     2         16
+--R       + 
+--R         15  4      15  3 3
+--R         -- a b c + -- a b
+--R          2          4
+--R    *
+--R        8
+--R       x
+--R   + 
+--R         40    2 3    40  2 2        2    5  4  2    80  3         2 3     8  5
+--R         -- b c d  + (-- a c  + 20a b c + - b )d  + (-- a b c + 10a b )d + - a c
+--R          9            3                  4           3                    3
+--R       + 
+--R           4 2
+--R         5a b
+--R    *
+--R        7
+--R       x
+--R   + 
+--R          70    2   35  2   3       2      35    3  2    35  4    35  3 2
+--R         (-- a c  + -- b c)d  + (35a b c + -- a b )d  + (-- a c + -- a b )d
+--R           9         6                      4             3        2
+--R       + 
+--R         7  5
+--R         - a b
+--R         2
+--R    *
+--R        6
+--R       x
+--R   + 
+--R      5  2 4              5  3  3       3    45  2 2  2      4       6  5
+--R     (- c d  + (20a b c + - b )d  + (20a c + -- a b )d  + 15a b d + a )x
+--R      3                   2                   2
+--R   + 
+--R      25      4    50  2    25    2  3      3   2     5   4
+--R     (-- b c d  + (-- a c + -- a b )d  + 25a b d  + 5a d)x
+--R       6            3        2
+--R   + 
+--R       20       5  2  4      2   3      4 2  3
+--R     ((-- a c + - b )d  + 20a b d  + 10a d )x
+--R        3       2
+--R   + 
+--R         5   15      4      3 3      2       5     2 4            5
+--R     (c d  + -- a b d  + 10a d  + c)x  + (b d  + 5a d  + b)x + a d  + a
+--R              2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 106
+
+--S 107 of 361
+r0:=a*x+1/2*b*x^2+1/3*c*x^3+1/6*(d+a*x+1/2*b*x^2+1/3*c*x^3)^6
+--R 
+--R
+--R   (2)
+--R       1   6 18    1     5 17     1     5    5   2 4  16
+--R     ---- c x   + --- b c x   + (--- a c  + --- b c )x
+--R     4374         486            243        648
+--R   + 
+--R       1   5     5       4    5   3 3  15
+--R     (--- c d + --- a b c  + --- b c )x
+--R      243       162          324
+--R   + 
+--R       5     4     5   2 4    5    2 3    5   4 2  14
+--R     (--- b c d + --- a c  + -- a b c  + --- b c )x
+--R      162         162        54          288
+--R   + 
+--R        5    4    5  2 3      5  2   3    5    3 2    1  5   13
+--R     ((-- a c  + -- b c )d + -- a b c  + -- a b c  + -- b c)x
+--R       81        54          27          36          96
+--R   + 
+--R          5   4 2    10      3    5  3 2     10  3 3    5  2 2 2    5    4
+--R         --- c d  + (-- a b c  + -- b c )d + -- a c  + -- a b c  + -- a b c
+--R         162         27          36          81        12          48
+--R       + 
+--R          1   6
+--R         --- b
+--R         384
+--R    *
+--R        12
+--R       x
+--R   + 
+--R          5    3 2    10  2 3   5    2 2    5  4      5  3   2    5  2 3
+--R         -- b c d  + (-- a c  + - a b c  + -- b c)d + - a b c  + -- a b c
+--R         27           27        6          48         9          12
+--R       + 
+--R          1    5
+--R         -- a b
+--R         32
+--R    *
+--R        11
+--R       x
+--R   + 
+--R          10    3    5  2 2  2    5  2   2   5    3     1  5      5  4 2
+--R         (-- a c  + -- b c )d  + (- a b c  + - a b c + -- b )d + -- a c
+--R          27        12            3          6         32        18
+--R       + 
+--R         5  3 2     5  2 4
+--R         - a b c + -- a b
+--R         6         32
+--R    *
+--R        10
+--R       x
+--R   + 
+--R         10  3 3    5      2    5  3   2    10  3 2   5  2 2     5    4
+--R         -- c d  + (- a b c  + -- b c)d  + (-- a c  + - a b c + -- a b )d
+--R         81         3          12            9        2         16
+--R       + 
+--R         5  4       5  3 3
+--R         - a b c + -- a b
+--R         6         12
+--R    *
+--R        9
+--R       x
+--R   + 
+--R         5    2 3    5  2 2   5    2     5  4  2    10  3      5  2 3     1  5
+--R         - b c d  + (- a c  + - a b c + -- b )d  + (-- a b c + - a b )d + - a c
+--R         9           3        2         32           3         4          3
+--R       + 
+--R         5  4 2
+--R         - a b
+--R         8
+--R    *
+--R        8
+--R       x
+--R   + 
+--R       10    2   5  2   3      2      5    3  2    5  4    5  3 2     1  5   7
+--R     ((-- a c  + - b c)d  + (5a b c + - a b )d  + (- a c + - a b )d + - a b)x
+--R        9        6                    4            3       2          2
+--R   + 
+--R       5  2 4    10          5  3  3    10  3    15  2 2  2   5  4      1  6  6
+--R     (-- c d  + (-- a b c + -- b )d  + (-- a c + -- a b )d  + - a b d + - a )x
+--R      18          3         12           3        4           2         6
+--R   + 
+--R      5      4    10  2    5    2  3     3   2    5   5
+--R     (- b c d  + (-- a c + - a b )d  + 5a b d  + a d)x
+--R      6            3       2
+--R   + 
+--R       5       5  2  4     2   3   5  4 2  4
+--R     ((- a c + - b )d  + 5a b d  + - a d )x
+--R       3       8                   2
+--R   + 
+--R      1    5   5      4   10  3 3   1    3    1    5   5  2 4   1    2
+--R     (- c d  + - a b d  + -- a d  + - c)x  + (- b d  + - a d  + - b)x
+--R      3        2           3        3         2        2        2
+--R   + 
+--R         5         1  6
+--R     (a d  + a)x + - d
+--R                   6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 107
+
+--S 108 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 361
+t0:=(a+c*x^2)*(1+(a*x+1/3*c*x^3)^n)
+--R 
+--R
+--R                      3        n
+--R            2      c x  + 3a x        2
+--R   (1)  (c x  + a)(-----------)  + c x  + a
+--R                        3
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 361
+r0:=a*x+1/3*c*x^3+(a*x+1/3*c*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R             3        n + 1
+--R          c x  + 3a x                   3
+--R        3(-----------)      + (c n + c)x  + (3a n + 3a)x
+--R               3
+--R   (2)  ------------------------------------------------
+--R                             3n + 3
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 361
+t0:=(b*x+c*x^2)*(1+(1/2*b*x^2+1/3*c*x^3)^n)
+--R 
+--R
+--R                         3       2 n
+--R            2        2c x  + 3b x         2
+--R   (1)  (c x  + b x)(-------------)  + c x  + b x
+--R                           6
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 361
+r0:=1/2*b*x^2+1/3*c*x^3+(1/2*b*x^2+1/3*c*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R              3       2 n + 1
+--R          2c x  + 3b x                      3               2
+--R        6(-------------)      + (2c n + 2c)x  + (3b n + 3b)x
+--R                6
+--R   (2)  -----------------------------------------------------
+--R                                6n + 6
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 361
+t0:=(a+b*x+c*x^2)*(1+(a*x+1/2*b*x^2+1/3*c*x^3)^n)
+--R 
+--R
+--R                             3       2        n
+--R            2            2c x  + 3b x  + 6a x        2
+--R   (1)  (c x  + b x + a)(--------------------)  + c x  + b x + a
+--R                                   6
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 361
+r0:=a*x+1/2*b*x^2+1/3*c*x^3+(a*x+1/2*b*x^2+1/3*c*x^3)^(1+n)/(1+n)
+--R 
+--R
+--R   (2)
+--R         3       2        n + 1
+--R     2c x  + 3b x  + 6a x                     3               2
+--R   6(--------------------)      + (2c n + 2c)x  + (3b n + 3b)x  + (6a n + 6a)x
+--R               6
+--R   ---------------------------------------------------------------------------
+--R                                      6n + 6
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 361
+t0:=(b+2*c*x)*(b*x+c*x^2)^13
+--R 
+--R
+--R   (1)
+--R       14 27        13 26       2 12 25       3 11 24        4 10 23
+--R     2c  x   + 27b c  x   + 169b c  x   + 650b c  x   + 1716b c  x
+--R   + 
+--R          5 9 22        6 8 21        7 7 20        8 6 19        9 5 18
+--R     3289b c x   + 4719b c x   + 5148b c x   + 4290b c x   + 2717b c x
+--R   + 
+--R          10 4 17       11 3 16       12 2 15      13   14    14 13
+--R     1287b  c x   + 442b  c x   + 104b  c x   + 15b  c x   + b  x
+--R                                                    Type: Polynomial(Integer)
+--E 118
+
+--S 119 of 361
+r0:=1/14*x^14*(b+c*x)^14
+--R 
+--R
+--R   (2)
+--R      1  14 28      13 27   13  2 12 26      3 11 25   143  4 10 24       5 9 23
+--R     -- c  x   + b c  x   + -- b c  x   + 26b c  x   + --- b c  x   + 143b c x
+--R     14                      2                          2
+--R   + 
+--R     429  6 8 22   1716  7 7 21   429  8 6 20       9 5 19   143  10 4 18
+--R     --- b c x   + ---- b c x   + --- b c x   + 143b c x   + --- b  c x
+--R      2              7             2                          2
+--R   + 
+--R        11 3 17   13  12 2 16    13   15    1  14 14
+--R     26b  c x   + -- b  c x   + b  c x   + -- b  x
+--R                   2                       14
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 119
+
+--S 120 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 361
+t0:=x^14*(b+2*c*x^2)*(b*x+c*x^3)^13
+--R 
+--R
+--R   (1)
+--R       14 55        13 53       2 12 51       3 11 49        4 10 47
+--R     2c  x   + 27b c  x   + 169b c  x   + 650b c  x   + 1716b c  x
+--R   + 
+--R          5 9 45        6 8 43        7 7 41        8 6 39        9 5 37
+--R     3289b c x   + 4719b c x   + 5148b c x   + 4290b c x   + 2717b c x
+--R   + 
+--R          10 4 35       11 3 33       12 2 31      13   29    14 27
+--R     1287b  c x   + 442b  c x   + 104b  c x   + 15b  c x   + b  x
+--R                                                    Type: Polynomial(Integer)
+--E 121
+
+--S 122 of 361
+r0:=1/28*x^28*(b+c*x^2)^14
+--R 
+--R
+--R   (2)
+--R      1  14 56   1    13 54   13  2 12 52      3 11 50   143  4 10 48
+--R     -- c  x   + - b c  x   + -- b c  x   + 13b c  x   + --- b c  x
+--R     28          2             4                          4
+--R   + 
+--R     143  5 9 46   429  6 8 44   858  7 7 42   429  8 6 40   143  9 5 38
+--R     --- b c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R      2             4             7             4             2
+--R   + 
+--R     143  10 4 36      11 3 34   13  12 2 32   1  13   30    1  14 28
+--R     --- b  c x   + 13b  c x   + -- b  c x   + - b  c x   + -- b  x
+--R      4                           4            2            28
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 122
+
+--S 123 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 361
+t0:=x^28*(b+2*c*x^3)*(b*x+c*x^4)^13
+--R 
+--R
+--R   (1)
+--R       14 83        13 80       2 12 77       3 11 74        4 10 71
+--R     2c  x   + 27b c  x   + 169b c  x   + 650b c  x   + 1716b c  x
+--R   + 
+--R          5 9 68        6 8 65        7 7 62        8 6 59        9 5 56
+--R     3289b c x   + 4719b c x   + 5148b c x   + 4290b c x   + 2717b c x
+--R   + 
+--R          10 4 53       11 3 50       12 2 47      13   44    14 41
+--R     1287b  c x   + 442b  c x   + 104b  c x   + 15b  c x   + b  x
+--R                                                    Type: Polynomial(Integer)
+--E 124
+
+--S 125 of 361
+r0:=1/42*x^42*(b+c*x^3)^14
+--R 
+--R
+--R   (2)
+--R      1  14 84   1    13 81   13  2 12 78   26  3 11 75   143  4 10 72
+--R     -- c  x   + - b c  x   + -- b c  x   + -- b c  x   + --- b c  x
+--R     42          3             6             3             6
+--R   + 
+--R     143  5 9 69   143  6 8 66   572  7 7 63   143  8 6 60   143  9 5 57
+--R     --- b c x   + --- b c x   + --- b c x   + --- b c x   + --- b c x
+--R      3             2             7             2             3
+--R   + 
+--R     143  10 4 54   26  11 3 51   13  12 2 48   1  13   45    1  14 42
+--R     --- b  c x   + -- b  c x   + -- b  c x   + - b  c x   + -- b  x
+--R      6              3             6            3            42
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 125
+
+--S 126 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 361
+t0:=x^(14*(-1+n))*(b+2*c*x^n)*(b*x+c*x^(1+n))^13
+--R 
+--R
+--R   (1)
+--R          14 n      13   n + 1 13         13   n      2 12    n + 1 12
+--R       (2c  x  + b c  )(x     )   + (26b c  x x  + 13b c  x)(x     )
+--R     + 
+--R            2 12 2 n      3 11 2   n + 1 11
+--R       (156b c  x x  + 78b c  x )(x     )
+--R     + 
+--R            3 11 3 n       4 10 3   n + 1 10
+--R       (572b c  x x  + 286b c  x )(x     )
+--R     + 
+--R             4 10 4 n       5 9 4   n + 1 9
+--R       (1430b c  x x  + 715b c x )(x     )
+--R     + 
+--R             5 9 5 n        6 8 5   n + 1 8
+--R       (2574b c x x  + 1287b c x )(x     )
+--R     + 
+--R             6 8 6 n        7 7 6   n + 1 7
+--R       (3432b c x x  + 1716b c x )(x     )
+--R     + 
+--R             7 7 7 n        8 6 7   n + 1 6
+--R       (3432b c x x  + 1716b c x )(x     )
+--R     + 
+--R             8 6 8 n        9 5 8   n + 1 5
+--R       (2574b c x x  + 1287b c x )(x     )
+--R     + 
+--R             9 5 9 n       10 4 9   n + 1 4
+--R       (1430b c x x  + 715b  c x )(x     )
+--R     + 
+--R            10 4 10 n       11 3 10   n + 1 3
+--R       (572b  c x  x  + 286b  c x  )(x     )
+--R     + 
+--R            11 3 11 n      12 2 11   n + 1 2       12 2 12 n      13   12  n + 1
+--R       (156b  c x  x  + 78b  c x  )(x     )  + (26b  c x  x  + 13b  c x  )x
+--R     + 
+--R         13   13 n    14 13
+--R       2b  c x  x  + b  x
+--R  *
+--R      14n - 14
+--R     x
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 361
+r0:=1/14*x^(14*n)*(b+c*x^n)^14/n
+--R 
+--R
+--R   (2)
+--R          14  n 14        13  n 13      2 12  n 12       3 11  n 11
+--R         c  (x )   + 14b c  (x )   + 91b c  (x )   + 364b c  (x )
+--R       + 
+--R              4 10  n 10        5 9  n 9        6 8  n 8        7 7  n 7
+--R         1001b c  (x )   + 2002b c (x )  + 3003b c (x )  + 3432b c (x )
+--R       + 
+--R              8 6  n 6        9 5  n 5        10 4  n 4       11 3  n 3
+--R         3003b c (x )  + 2002b c (x )  + 1001b  c (x )  + 364b  c (x )
+--R       + 
+--R            12 2  n 2      13   n    14
+--R         91b  c (x )  + 14b  c x  + b
+--R    *
+--R        14n
+--R       x
+--R  /
+--R     14n
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 361
+t0:=(b+2*c*x)/(b*x+c*x^2)
+--R 
+--R
+--R         2c x + b
+--R   (1)  ----------
+--R           2
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 130
+
+--S 131 of 361
+r0:=log(x)+log(b+c*x)
+--R 
+--R
+--R   (2)  log(c x + b) + log(x)
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 361
+t0:=(b+2*c*x^2)/(b*x+c*x^3)
+--R 
+--R
+--R             2
+--R         2c x  + b
+--R   (1)  ----------
+--R           3
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 133
+
+--S 134 of 361
+r0:=log(x)+1/2*log(b+c*x^2)
+--R 
+--R
+--R               2
+--R        log(c x  + b) + 2log(x)
+--R   (2)  -----------------------
+--R                   2
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 361
+t0:=(b+2*c*x^3)/(b*x+c*x^4)
+--R 
+--R
+--R             3
+--R         2c x  + b
+--R   (1)  ----------
+--R           4
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 136
+
+--S 137 of 361
+r0:=log(x)+1/3*log(b+c*x^3)
+--R 
+--R
+--R               3
+--R        log(c x  + b) + 3log(x)
+--R   (2)  -----------------------
+--R                   3
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 361
+t0:=(b+2*c*x^n)/(b*x+c*x^(1+n))
+--R 
+--R
+--R               n
+--R           2c x  + b
+--R   (1)  --------------
+--R           n + 1
+--R        c x      + b x
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 361
+r0:=log(x)+log(b+c*x^n)/n
+--R 
+--R
+--R               n
+--R        log(c x  + b) + n log(x)
+--R   (2)  ------------------------
+--R                    n
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 361
+t0:=(b+2*c*x)/(b*x+c*x^2)^8
+--R 
+--R
+--R   (1)
+--R     2c x + b
+--R  /
+--R        8 16       7 15      2 6 14      3 5 13      4 4 12      5 3 11
+--R       c x   + 8b c x   + 28b c x   + 56b c x   + 70b c x   + 56b c x
+--R     + 
+--R          6 2 10     7   9    8 8
+--R       28b c x   + 8b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 142
+
+--S 143 of 361
+r0:=(-1/7)/(x^7*(b+c*x)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R        1
+--R        -
+--R        7
+--R     /
+--R           7 14       6 13      2 5 12      3 4 11      4 3 10      5 2 9
+--R          c x   + 7b c x   + 21b c x   + 35b c x   + 35b c x   + 21b c x
+--R        + 
+--R            6   8    7 7
+--R          7b c x  + b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 143
+
+--S 144 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 361
+t0:=(b+2*c*x^2)/(x^7*(b*x+c*x^3)^8)
+--R 
+--R
+--R   (1)
+--R         2
+--R     2c x  + b
+--R  /
+--R        8 31       7 29      2 6 27      3 5 25      4 4 23      5 3 21
+--R       c x   + 8b c x   + 28b c x   + 56b c x   + 70b c x   + 56b c x
+--R     + 
+--R          6 2 19     7   17    8 15
+--R       28b c x   + 8b c x   + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 145
+
+--S 146 of 361
+r0:=(-1/14)/(x^14*(b+c*x^2)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R         1
+--R        --
+--R        14
+--R     /
+--R           7 28       6 26      2 5 24      3 4 22      4 3 20      5 2 18
+--R          c x   + 7b c x   + 21b c x   + 35b c x   + 35b c x   + 21b c x
+--R        + 
+--R            6   16    7 14
+--R          7b c x   + b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 146
+
+--S 147 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 361
+t0:=(b+2*c*x^3)/(x^14*(b*x+c*x^4)^8)
+--R 
+--R
+--R   (1)
+--R         3
+--R     2c x  + b
+--R  /
+--R        8 46       7 43      2 6 40      3 5 37      4 4 34      5 3 31
+--R       c x   + 8b c x   + 28b c x   + 56b c x   + 70b c x   + 56b c x
+--R     + 
+--R          6 2 28     7   25    8 22
+--R       28b c x   + 8b c x   + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 148
+
+--S 149 of 361
+r0:=(-1/21)/(x^21*(b+c*x^3)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R         1
+--R        --
+--R        21
+--R     /
+--R           7 42       6 39      2 5 36      3 4 33      4 3 30      5 2 27
+--R          c x   + 7b c x   + 21b c x   + 35b c x   + 35b c x   + 21b c x
+--R        + 
+--R            6   24    7 21
+--R          7b c x   + b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 149
+
+--S 150 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 361
+t0:=(b+2*c*x^n)/(x^(7*(-1+n))*(b*x+c*x^(1+n))^8)
+--R 
+--R
+--R   (1)
+--R         n
+--R     2c x  + b
+--R  /
+--R          8  n + 1 8       7    n + 1 7      2 6 2  n + 1 6      3 5 3  n + 1 5
+--R         c (x     )  + 8b c x (x     )  + 28b c x (x     )  + 56b c x (x     )
+--R       + 
+--R            4 4 4  n + 1 4      5 3 5  n + 1 3      6 2 6  n + 1 2
+--R         70b c x (x     )  + 56b c x (x     )  + 28b c x (x     )
+--R       + 
+--R           7   7 n + 1    8 8
+--R         8b c x x      + b x
+--R    *
+--R        7n - 7
+--R       x
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 361
+r0:=(-1/7)/(n*x^(7*n)*(b+c*x^n)^7)
+--R 
+--R
+--R   (2)
+--R   -
+--R        1
+--R     /
+--R              7    n 7        6    n 6       2 5    n 5       3 4    n 4
+--R            7c n (x )  + 49b c n (x )  + 147b c n (x )  + 245b c n (x )
+--R          + 
+--R                4 3    n 3       5 2    n 2      6     n     7
+--R            245b c n (x )  + 147b c n (x )  + 49b c n x  + 7b n
+--R       *
+--R           7n
+--R          x
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 361
+t0:=(b+2*c*x)*(b*x+c*x^2)^p
+--R 
+--R
+--R                      2       p
+--R   (1)  (2c x + b)(c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 361
+r0:=(b*x+c*x^2)^(1+p)/(1+p)
+--R 
+--R
+--R            2       p + 1
+--R        (c x  + b x)
+--R   (2)  -----------------
+--R              p + 1
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 361
+t0:=x^(1+p)*(b+2*c*x^2)*(b*x+c*x^3)^p
+--R 
+--R
+--R             2      p + 1    3       p
+--R   (1)  (2c x  + b)x     (c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 361
+r0:=1/2*x^(1+p)*(b*x+c*x^3)^(1+p)/(1+p)
+--R 
+--R
+--R         p + 1    3       p + 1
+--R        x     (c x  + b x)
+--R   (2)  -----------------------
+--R                 2p + 2
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 361
+t0:=b*x^(1+p)*(b*x+c*x^3)^p+2*c*x^(3+p)*(b*x+c*x^3)^p
+--R 
+--R
+--R             p + 3      p + 1     3       p
+--R   (1)  (2c x      + b x     )(c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 361
+r0:=1/2*x^(1+p)*(b*x+c*x^3)^(1+p)/(1+p)
+--R 
+--R
+--R         p + 1    3       p + 1
+--R        x     (c x  + b x)
+--R   (2)  -----------------------
+--R                 2p + 2
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 361
+t0:=x^(2*(1+p))*(b+2*c*x^3)*(b*x+c*x^4)^p
+--R 
+--R
+--R             3      2p + 2    4       p
+--R   (1)  (2c x  + b)x      (c x  + b x)
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 361
+r0:=1/3*x^(3+2*p)*(b+c*x^3)*(b*x+c*x^4)^p/(1+p)
+--R 
+--R
+--R            3      2p + 3    4       p
+--R        (c x  + b)x      (c x  + b x)
+--R   (2)  ------------------------------
+--R                    3p + 3
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 361
+t0:=x^((-1+n)*(1+p))*(b+2*c*x^n)*(b*x+c*x^(1+n))^p
+--R 
+--R
+--R             n      (n - 1)p + n - 1    n + 1       p
+--R   (1)  (2c x  + b)x                (c x      + b x)
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 361
+r0:=x^(n-p+n*p)*(b+c*x^n)*(b*x+c*x^(1+n))^p/(n*(1+p))
+--R 
+--R
+--R            n      (n - 1)p + n    n + 1       p
+--R        (c x  + b)x            (c x      + b x)
+--R   (2)  ----------------------------------------
+--R                         n p + n
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 361
+t0:=(-4+4*x+x^2)*(5-12*x+6*x^2+x^3)
+--R 
+--R
+--R         5      4     3      2
+--R   (1)  x  + 10x  + 8x  - 67x  + 68x - 20
+--R                                                    Type: Polynomial(Integer)
+--E 169
+
+--S 170 of 361
+r0:=1/6*(5-12*x+6*x^2+x^3)^2
+--R 
+--R
+--R        1  6     5     4   67  3      2         25
+--R   (2)  - x  + 2x  + 2x  - -- x  + 34x  - 20x + --
+--R        6                   3                    6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 170
+
+--S 171 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 361
+t0:=(2*x+x^3)*(1+4*x^2+x^4)
+--R 
+--R
+--R         7     5     3
+--R   (1)  x  + 6x  + 9x  + 2x
+--R                                                    Type: Polynomial(Integer)
+--E 172
+
+--S 173 of 361
+r0:=1/8*(1+4*x^2+x^4)^2
+--R 
+--R
+--R        1  8    6   9  4    2   1
+--R   (2)  - x  + x  + - x  + x  + -
+--R        8           4           8
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 173
+
+--S 174 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 361
+t0:=(1+2*x)*(x+x^2)^3*(-18+7*(x+x^2)^3)^2
+--R 
+--R
+--R   (1)
+--R        19       18        17        16         15         14         13
+--R     98x   + 931x   + 3969x   + 9996x   + 16464x   + 18522x   + 13902x
+--R   + 
+--R          12        11         10         9        8        7        6        5
+--R     4368x   - 6426x   - 13321x   - 12551x  - 6804x  - 1368x  + 2016x  + 2916x
+--R   + 
+--R          4       3
+--R     1620x  + 324x
+--R                                                    Type: Polynomial(Integer)
+--E 175
+
+--S 176 of 361
+r0:=81*x^4*(1+x)^4-36*x^7*(1+x)^7+49/10*x^10*(1+x)^10
+--R 
+--R
+--R   (2)
+--R     49  20      19   441  18       17        16   6174  15       14       13
+--R     -- x   + 49x   + --- x   + 588x   + 1029x   + ---- x   + 993x   + 336x
+--R     10                2                             5
+--R   + 
+--R       1071  12        11   12551  10       9       8       7       6       5
+--R     - ---- x   - 1211x   - ----- x   - 756x  - 171x  + 288x  + 486x  + 324x
+--R         2                    10
+--R   + 
+--R        4
+--R     81x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 176
+
+--S 177 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 361
+t0:=x^3*(1+x)^3*(1+2*x)*(-18+7*x^3*(1+x)^3)^2
+--R 
+--R
+--R   (1)
+--R        19       18        17        16         15         14         13
+--R     98x   + 931x   + 3969x   + 9996x   + 16464x   + 18522x   + 13902x
+--R   + 
+--R          12        11         10         9        8        7        6        5
+--R     4368x   - 6426x   - 13321x   - 12551x  - 6804x  - 1368x  + 2016x  + 2916x
+--R   + 
+--R          4       3
+--R     1620x  + 324x
+--R                                                    Type: Polynomial(Integer)
+--E 178
+
+--S 179 of 361
+r0:=81*x^4*(1+x)^4-36*x^7*(1+x)^7+49/10*x^10*(1+x)^10
+--R 
+--R
+--R   (2)
+--R     49  20      19   441  18       17        16   6174  15       14       13
+--R     -- x   + 49x   + --- x   + 588x   + 1029x   + ---- x   + 993x   + 336x
+--R     10                2                             5
+--R   + 
+--R       1071  12        11   12551  10       9       8       7       6       5
+--R     - ---- x   - 1211x   - ----- x   - 756x  - 171x  + 288x  + 486x  + 324x
+--R         2                    10
+--R   + 
+--R        4
+--R     81x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 179
+
+--S 180 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 361
+t0:=(2-x^2)/(1-6*x+x^3)^5
+--R 
+--R
+--R   (1)
+--R        2
+--R     - x  + 2
+--R  /
+--R        15      13     12       11       10        9        8        7        6
+--R       x   - 30x   + 5x   + 360x   - 120x   - 2150x  + 1080x  + 6300x  - 4310x
+--R     + 
+--R              5        4        3       2
+--R       - 6696x  + 6360x  - 2155x  + 360x  - 30x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 181
+
+--S 182 of 361
+r0:=1/12/(1-6*x+x^3)^4
+--R 
+--R
+--R   (2)
+--R      1
+--R     --
+--R     12
+--R  /
+--R        12      10     9       8      7       6       5        4       3       2
+--R       x   - 24x   + 4x  + 216x  - 72x  - 858x  + 432x  + 1224x  - 860x  + 216x
+--R     + 
+--R       - 24x + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 182
+
+--S 183 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 361
+t0:=(2*x+x^2)/(4+3*x^2+x^3)
+--R 
+--R
+--R            2
+--R           x  + 2x
+--R   (1)  ------------
+--R         3     2
+--R        x  + 3x  + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 184
+
+--S 185 of 361
+r0:=1/3*log(4+3*x^2+x^3)
+--R 
+--R
+--R             3     2
+--R        log(x  + 3x  + 4)
+--R   (2)  -----------------
+--R                3
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 361
+t0:=(2-x^2)/(1-6*x+x^3)^5
+--R 
+--R
+--R   (1)
+--R        2
+--R     - x  + 2
+--R  /
+--R        15      13     12       11       10        9        8        7        6
+--R       x   - 30x   + 5x   + 360x   - 120x   - 2150x  + 1080x  + 6300x  - 4310x
+--R     + 
+--R              5        4        3       2
+--R       - 6696x  + 6360x  - 2155x  + 360x  - 30x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 187
+
+--S 188 of 361
+r0:=1/12/(1-6*x+x^3)^4
+--R 
+--R
+--R   (2)
+--R      1
+--R     --
+--R     12
+--R  /
+--R        12      10     9       8      7       6       5        4       3       2
+--R       x   - 24x   + 4x  + 216x  - 72x  - 858x  + 432x  + 1224x  - 860x  + 216x
+--R     + 
+--R       - 24x + 1
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 188
+
+--S 189 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 361
+t0:=(1+x+x^3)/(4*x+2*x^2+x^4)
+--R 
+--R
+--R           3
+--R          x  + x + 1
+--R   (1)  -------------
+--R         4     2
+--R        x  + 2x  + 4x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 190
+
+--S 191 of 361
+r0:=1/4*log(x*(4+2*x+x^3))
+--R 
+--R
+--R             4     2
+--R        log(x  + 2x  + 4x)
+--R   (2)  ------------------
+--R                 4
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 361
+t0:=(-1+x^3)/(-4*x+x^4)^(2/3)
+--R 
+--R
+--R            3
+--R           x  - 1
+--R   (1)  -----------
+--R         +-------+2
+--R        3| 4
+--R        \|x  - 4x
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 361
+r0:=3/4*(-4*x+x^4)^(1/3)
+--R 
+--R
+--R          +-------+
+--R         3| 4
+--R        3\|x  - 4x
+--R   (2)  -----------
+--R             4
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 361
+t0:=(2-x^2)*(6*x-x^3)^(1/4)
+--R 
+--R
+--R                   +---------+
+--R            2     4|   3
+--R   (1)  (- x  + 2)\|- x  + 6x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 361
+r0:=4/15*(6*x-x^3)^(5/4)
+--R 
+--R
+--R                      +---------+
+--R             3       4|   3
+--R        (- 4x  + 24x)\|- x  + 6x
+--R   (2)  -------------------------
+--R                    15
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 361
+t0:=(1+x^4)*sqrt(5*x+x^5)
+--R 
+--R
+--R                 +-------+
+--R          4      | 5
+--R   (1)  (x  + 1)\|x  + 5x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 361
+r0:=2/15*(5*x+x^5)^(3/2)
+--R 
+--R
+--R                    +-------+
+--R           5        | 5
+--R        (2x  + 10x)\|x  + 5x
+--R   (2)  ---------------------
+--R                  15
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 361
+t0:=(2+5*x^4)*sqrt(2*x+x^5)
+--R 
+--R
+--R                  +-------+
+--R           4      | 5
+--R   (1)  (5x  + 2)\|x  + 2x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 361
+r0:=2/3*(2*x+x^5)^(3/2)
+--R 
+--R
+--R                   +-------+
+--R           5       | 5
+--R        (2x  + 4x)\|x  + 2x
+--R   (2)  --------------------
+--R                  3
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 361
+t0:=(x+3*x^2)/sqrt(x^2+2*x^3)
+--R 
+--R
+--R            2
+--R          3x  + x
+--R   (1)  -----------
+--R         +--------+
+--R         |  3    2
+--R        \|2x  + x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 361
+r0:=sqrt(x^2+2*x^3)
+--R 
+--R
+--R         +--------+
+--R         |  3    2
+--R   (2)  \|2x  + x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 361
+t0:=(2+(1-5*x)^(1/3))/(3+(1-5*x)^(1/3))
+--R 
+--R
+--R        3+--------+
+--R        \|- 5x + 1  + 2
+--R   (1)  ---------------
+--R        3+--------+
+--R        \|- 5x + 1  + 3
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 361
+r0:=-9/5*(1-5*x)^(1/3)+3/10*(1-5*x)^(2/3)+x+27/5*log(3+(1-5*x)^(1/3))
+--R 
+--R
+--R              3+--------+         3+--------+2     3+--------+
+--R        54log(\|- 5x + 1  + 3) + 3\|- 5x + 1   - 18\|- 5x + 1  + 10x
+--R   (2)  ------------------------------------------------------------
+--R                                     10
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 361
+t0:=(1+sqrt(x))/(-1+sqrt(x))
+--R 
+--R
+--R         +-+
+--R        \|x  + 1
+--R   (1)  --------
+--R         +-+
+--R        \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 361
+r0:=x+4*log(1-sqrt(x))+4*sqrt(x)
+--R 
+--R
+--R                +-+          +-+
+--R   (2)  4log(- \|x  + 1) + 4\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 361
+t0:=(1-sqrt(2+3*x))/(1+sqrt(2+3*x))
+--R 
+--R
+--R           +------+
+--R        - \|3x + 2  + 1
+--R   (1)  ---------------
+--R          +------+
+--R         \|3x + 2  + 1
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 361
+r0:=-x-4/3*log(1+sqrt(2+3*x))+4/3*sqrt(2+3*x)
+--R 
+--R
+--R                +------+          +------+
+--R        - 4log(\|3x + 2  + 1) + 4\|3x + 2  - 3x
+--R   (2)  ---------------------------------------
+--R                           3
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 361
+t0:=(-1+sqrt(a+b*x))/(1+sqrt(a+b*x))
+--R 
+--R
+--R         +-------+
+--R        \|b x + a  - 1
+--R   (1)  --------------
+--R         +-------+
+--R        \|b x + a  + 1
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 361
+r0:=x+4*log(1+sqrt(a+b*x))/b-4*sqrt(a+b*x)/b
+--R 
+--R
+--R              +-------+          +-------+
+--R        4log(\|b x + a  + 1) - 4\|b x + a  + b x
+--R   (2)  ----------------------------------------
+--R                            b
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 361
+t0:=(a+b*n*x^(-1+n))/(a*x+b*x^n)
+--R 
+--R
+--R             n - 1
+--R        b n x      + a
+--R   (1)  --------------
+--R             n
+--R          b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 361
+r0a:=log(a*x+b*x^n)
+--R 
+--R
+--R               n
+--R   (2)  log(b x  + a x)
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 361
+r0b:=n*log(x)+log(b+a*x^(1-n))
+--R 
+--R
+--R               - n + 1
+--R   (3)  log(a x        + b) + n log(x)
+--R                                                    Type: Expression(Integer)
+--E 222
+
+--S 223 of 361
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 361
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 224
+
+)clear all
+
+--S 225 of 361
+t0:=(a+b*n*x^(-1+n))/(x^n*(b+a*x^(1-n)))
+--R 
+--R
+--R               n - 1
+--R          b n x      + a
+--R   (1)  ------------------
+--R            - n + 1      n
+--R        (a x        + b)x
+--R                                                    Type: Expression(Integer)
+--E 225
+
+--S 226 of 361
+r0:=n*log(x)+log(b+a*x^(1-n))
+--R 
+--R
+--R               - n + 1
+--R   (2)  log(a x        + b) + n log(x)
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 227
+
+)clear all
+
+--S 228 of 361
+t0:=(-3+2*x)*(-3*x+x^2)^(2/3)
+--R 
+--R
+--R                 +-------+2
+--R                3| 2
+--R   (1)  (2x - 3)\|x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 228
+
+--S 229 of 361
+r0:=3/5*(-3*x+x^2)^(5/3)
+--R 
+--R
+--R                   +-------+2
+--R           2      3| 2
+--R        (3x  - 9x)\|x  - 3x
+--R   (2)  ---------------------
+--R                  5
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 230
+
+)clear all
+
+--S 231 of 361
+t0:=((-3+x)*x)^(2/3)*(-3+2*x)
+--R 
+--R
+--R                 +-------+2
+--R                3| 2
+--R   (1)  (2x - 3)\|x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 231
+
+--S 232 of 361
+r0:=3/5*(-3*x+x^2)^(5/3)
+--R 
+--R
+--R                   +-------+2
+--R           2      3| 2
+--R        (3x  - 9x)\|x  - 3x
+--R   (2)  ---------------------
+--R                  5
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 233
+
+)clear all
+
+--S 234 of 361
+t0:=x*(9-9*x+2*x^2)/((-3+x)*x)^(1/3)
+--R 
+--R
+--R          3     2
+--R        2x  - 9x  + 9x
+--R   (1)  --------------
+--R           +-------+
+--R          3| 2
+--R          \|x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 234
+
+--S 235 of 361
+r0:=3/5*(3-x)^2*x^2/(-(3-x)*x)^(1/3)
+--R 
+--R
+--R          4      3      2
+--R        3x  - 18x  + 27x
+--R   (2)  -----------------
+--R             +-------+
+--R            3| 2
+--R           5\|x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 236
+
+)clear all
+
+--S 237 of 361
+t0:=x^3/(a+b*(c+d*x)^3)
+--R 
+--R
+--R                            3
+--R                           x
+--R   (1)  ----------------------------------------
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 237
+
+--S 238 of 361
+r0:=x/(b*d^3)-1/3*(a+3*a^(1/3)*b^(2/3)*c^2+b*c^3)*log(a^(1/3)+b^(1/3)*_
+   (c+d*x))/(a^(2/3)*b^(4/3)*d^4)+1/6*(a+3*a^(1/3)*b^(2/3)*c^2+b*c^3)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*(c+d*x)+b^(2/3)*(c+d*x)^2)/(a^(2/3)*_
+   b^(4/3)*d^4)-c*log(a+b*(c+d*x)^3)/(b*d^4)+(a-3*a^(1/3)*b^(2/3)*c^2+_
+   b*c^3)*atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*_
+   b^(4/3)*d^4*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            2 +-+3+-+3+-+2       3      +-+
+--R         (3c \|3 \|a \|b   + (b c  + a)\|3 )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R            2 +-+3+-+3+-+2          3       +-+              3+-+   3+-+
+--R       (- 6c \|3 \|a \|b   + (- 2b c  - 2a)\|3 )log((d x + c)\|b  + \|a )
+--R     + 
+--R                                                   3+-+   3+-+
+--R           2 3+-+3+-+2      3           (2d x + 2c)\|b  - \|a
+--R       (18c  \|a \|b  - 6b c  - 6a)atan(----------------------)
+--R                                                +-+3+-+
+--R                                               \|3 \|a
+--R     + 
+--R           +-+       3 3         2 2       2         3             +-+ 3+-+2 3+-+
+--R     (- 6c\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a) + 6d x\|3 )\|a   \|b
+--R  /
+--R         4 +-+3+-+2 3+-+
+--R     6b d \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 239
+
+)clear all
+
+--S 240 of 361
+t0:=x^2/(a+b*(c+d*x)^3)
+--R 
+--R
+--R                            2
+--R                           x
+--R   (1)  ----------------------------------------
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 240
+
+--S 241 of 361
+r0:=1/3*c*(2*a^(1/3)+b^(1/3)*c)*log(a^(1/3)+b^(1/3)*(c+d*x))/(a^(2/3)*_
+   b^(2/3)*d^3)-1/6*c*(2*a^(1/3)+b^(1/3)*c)*log(a^(2/3)-a^(1/3)*b^(1/3)*_
+   (c+d*x)+b^(2/3)*(c+d*x)^2)/(a^(2/3)*b^(2/3)*d^3)+1/3*log(a+b*(c+_
+   d*x)^3)/(b*d^3)+c*(2*a^(1/3)-b^(1/3)*c)*atan((a^(1/3)-2*b^(1/3)*_
+   (c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(2/3)*d^3*sqrt(3))
+--R 
+--R
+--R   (2)
+--R               2 +-+3+-+        +-+3+-+
+--R         (- b c \|3 \|b  - 2b c\|3 \|a )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R            2 +-+3+-+        +-+3+-+              3+-+   3+-+
+--R       (2b c \|3 \|b  + 4b c\|3 \|a )log((d x + c)\|b  + \|a )
+--R     + 
+--R                                              3+-+   3+-+
+--R            2 3+-+       3+-+      (2d x + 2c)\|b  - \|a
+--R       (6b c  \|b - 12b c\|a )atan(----------------------)
+--R                                           +-+3+-+
+--R                                          \|3 \|a
+--R     + 
+--R         +-+       3 3         2 2       2         3     3+-+2 3+-+2
+--R       2\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a)\|a   \|b
+--R  /
+--R         3 +-+3+-+2 3+-+2
+--R     6b d \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 242
+
+)clear all
+
+--S 243 of 361
+t0:=x/(a+b*(c+d*x)^3)
+--R 
+--R
+--R                            x
+--R   (1)  ----------------------------------------
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 243
+
+--S 244 of 361
+r0:=-1/3*(a^(1/3)+b^(1/3)*c)*log(a^(1/3)+b^(1/3)*(c+d*x))/(a^(2/3)*b^(2/3)*_
+   d^2)+1/6*(a^(1/3)+b^(1/3)*c)*log(a^(2/3)-a^(1/3)*b^(1/3)*(c+d*x)+_
+   b^(2/3)*(c+d*x)^2)/(a^(2/3)*b^(2/3)*d^2)-(a^(1/3)-b^(1/3)*c)*_
+   atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*_
+   b^(2/3)*d^2*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +-+3+-+    +-+3+-+
+--R         (c\|3 \|b  + \|3 \|a )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R             +-+3+-+     +-+3+-+              3+-+   3+-+
+--R       (- 2c\|3 \|b  - 2\|3 \|a )log((d x + c)\|b  + \|a )
+--R     + 
+--R                                         3+-+   3+-+
+--R            3+-+    3+-+      (2d x + 2c)\|b  - \|a
+--R       (- 6c\|b  + 6\|a )atan(----------------------)
+--R                                      +-+3+-+
+--R                                     \|3 \|a
+--R  /
+--R       2 +-+3+-+2 3+-+2
+--R     6d \|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 245
+
+)clear all
+
+--S 246 of 361
+t0:=1/(a+b*(c+d*x)^3)
+--R 
+--R
+--R                            1
+--R   (1)  ----------------------------------------
+--R           3 3         2 2       2         3
+--R        b d x  + 3b c d x  + 3b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 246
+
+--S 247 of 361
+r0:=1/3*log(a^(1/3)+b^(1/3)*(c+d*x))/(a^(2/3)*b^(1/3)*d)-1/6*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*(c+d*x)+b^(2/3)*(c+d*x)^2)/(a^(2/3)*b^(1/3)*d)-_
+   atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(1/3)*_
+   d*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          +-+      2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R       - \|3 log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R                                                         3+-+   3+-+
+--R         +-+             3+-+   3+-+          (2d x + 2c)\|b  - \|a
+--R       2\|3 log((d x + c)\|b  + \|a ) + 6atan(----------------------)
+--R                                                      +-+3+-+
+--R                                                     \|3 \|a
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6d\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 248
+
+)clear all
+
+--S 249 of 361
+t0:=1/(x*(a+b*(c+d*x)^3))
+--R 
+--R
+--R                              1
+--R   (1)  --------------------------------------------
+--R           3 4         2 3       2   2       3
+--R        b d x  + 3b c d x  + 3b c d x  + (b c  + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 249
+
+--S 250 of 361
+r0a:=log(x)/(a+b*c^3)-1/3*log(a^(1/3)+b^(1/3)*(c+d*x))/(a^(2/3)*(a^(1/3)+_
+   b^(1/3)*c))-1/6*(2*a^(1/3)-b^(1/3)*c)*log(a^(2/3)-a^(1/3)*b^(1/3)*_
+   (c+d*x)+b^(2/3)*(c+d*x)^2)/(a^(2/3)*(a^(2/3)-a^(1/3)*b^(1/3)*c+_
+   b^(2/3)*c^2))+b^(1/3)*c*atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*_
+   sqrt(3)))/(a^(2/3)*(a^(2/3)-a^(1/3)*b^(1/3)*c+b^(2/3)*c^2)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              4        +-+3+-+3+-+          3       +-+3+-+2
+--R         ((b c  + a c)\|3 \|a \|b  + (- 2b c  - 2a)\|3 \|a  )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R                   2 +-+3+-+2          4         +-+3+-+3+-+
+--R             - 6a c \|3 \|b   + (- 2b c  + 4a c)\|3 \|a \|b
+--R           + 
+--R                  3       +-+3+-+2
+--R             (4b c  - 2a)\|3 \|a
+--R      *
+--R                      3+-+   3+-+
+--R         log((d x + c)\|b  + \|a )
+--R     + 
+--R                                               3+-+   3+-+
+--R              4        3+-+3+-+     (2d x + 2c)\|b  - \|a
+--R       (- 6b c  - 6a c)\|a \|b atan(----------------------)
+--R                                            +-+3+-+
+--R                                           \|3 \|a
+--R     + 
+--R           2 +-+      3+-+2        +-+      3+-+3+-+      +-+      3+-+2
+--R       6a c \|3 log(x)\|b   - 6a c\|3 log(x)\|a \|b  + 6a\|3 log(x)\|a
+--R  /
+--R              5     2 2  +-+3+-+2            4     2   +-+3+-+3+-+
+--R       (6a b c  + 6a c )\|3 \|b   + (- 6a b c  - 6a c)\|3 \|a \|b
+--R     + 
+--R              3     2  +-+3+-+2
+--R       (6a b c  + 6a )\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 361
+r0b:=log(x)/(a+b*c^3)+1/3*b^(1/3)*c*(a^(1/3)-b^(1/3)*c)*log(a^(1/3)+_
+   b^(1/3)*(c+d*x))/(a^(2/3)*(a+b*c^3))-1/6*b^(1/3)*c*(a^(1/3)-b^(1/3)*c)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*(c+d*x)+b^(2/3)*(c+d*x)^2)/(a^(2/3)*(a+b*c^3))-_
+   1/3*log(a+b*(c+d*x)^3)/(a+b*c^3)+b^(1/3)*c*(a^(1/3)+b^(1/3)*c)*_
+   atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*_
+   (a+b*c^3)*sqrt(3))
+--R 
+--R
+--R   (3)
+--R           2 +-+3+-+2     +-+3+-+3+-+
+--R         (c \|3 \|b   - c\|3 \|a \|b )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R            2 +-+3+-+2      +-+3+-+3+-+              3+-+   3+-+
+--R       (- 2c \|3 \|b   + 2c\|3 \|a \|b )log((d x + c)\|b  + \|a )
+--R     + 
+--R                                                3+-+   3+-+
+--R            2 3+-+2    3+-+3+-+      (2d x + 2c)\|b  - \|a
+--R       (- 6c  \|b  - 6c\|a \|b )atan(----------------------)
+--R                                             +-+3+-+
+--R                                            \|3 \|a
+--R     + 
+--R          +-+       3 3         2 2       2         3          +-+       3+-+2
+--R     (- 2\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a) + 6\|3 log(x))\|a
+--R  /
+--R          3       +-+3+-+2
+--R     (6b c  + 6a)\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 361
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 361
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 253
+
+)clear all
+
+--S 254 of 361
+t0:=1/(x^2*(a+b*(c+d*x)^3))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R           3 5         2 4       2   3       3      2
+--R        b d x  + 3b c d x  + 3b c d x  + (b c  + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 254
+
+--S 255 of 361
+r0:=(-1)/((a+b*c^3)*x)-3*b*c^2*d*log(x)/(a+b*c^3)^2+1/3*b^(1/3)*(a^(1/3)*_
+   (a-2*b*c^3)-b^(1/3)*(2*a*c-b*c^4))*d*log(a^(1/3)+b^(1/3)*(c+d*x))/_
+   (a^(2/3)*(a+b*c^3)^2)-1/6*b^(1/3)*(a^(1/3)*(a-2*b*c^3)-b^(1/3)*_
+   (2*a*c-b*c^4))*d*log(a^(2/3)-a^(1/3)*b^(1/3)*(c+d*x)+b^(2/3)*_
+   (c+d*x)^2)/(a^(2/3)*(a+b*c^3)^2)+b*c^2*d*log(a+b*(c+d*x)^3)/(a+b*c^3)^2+_
+   b^(1/3)*(a^(1/3)-b^(1/3)*c)*(a^(1/3)+b^(1/3)*c)^3*d*atan((a^(1/3)-_
+   2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/(a^(2/3)*(a+b*c^3)^2*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                4            +-+3+-+2        3         +-+3+-+3+-+
+--R         ((- b c  + 2a c)d x\|3 \|b   + (2b c  - a)d x\|3 \|a \|b )
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R               4            +-+3+-+2          3          +-+3+-+3+-+
+--R         ((2b c  - 4a c)d x\|3 \|b   + (- 4b c  + 2a)d x\|3 \|a \|b )
+--R      *
+--R                      3+-+   3+-+
+--R         log((d x + c)\|b  + \|a )
+--R     + 
+--R               4             3+-+2         3         3+-+3+-+
+--R         ((6b c  - 12a c)d x \|b   + (12b c  - 6a)d x\|a \|b )
+--R      *
+--R                         3+-+   3+-+
+--R              (2d x + 2c)\|b  - \|a
+--R         atan(----------------------)
+--R                      +-+3+-+
+--R                     \|3 \|a
+--R     + 
+--R               2    +-+       3 3         2 2       2         3
+--R           6b c d x\|3 log(b d x  + 3b c d x  + 3b c d x + b c  + a)
+--R         + 
+--R                  2    +-+                3       +-+
+--R           - 18b c d x\|3 log(x) + (- 6b c  - 6a)\|3
+--R      *
+--R         3+-+2
+--R         \|a
+--R  /
+--R        2 6          3     2   +-+3+-+2
+--R     (6b c  + 12a b c  + 6a )x\|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 255
+
+--S 256 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 256
+
+)clear all
+
+--S 257 of 361
+t0:=1/(x^3*(a+b*(c+d*x)^3))
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R           3 6         2 5       2   4       3      3
+--R        b d x  + 3b c d x  + 3b c d x  + (b c  + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 257
+
+--S 258 of 361
+r0:=(-1/2)/((a+b*c^3)*x^2)+3*b*c^2*d/((a+b*c^3)^2*x)-3*b*c*(a-2*b*c^3)*d^2*_
+   log(x)/(a+b*c^3)^3-1/3*b^(2/3)*(a^2-7*a*b*c^3+b^2*c^6+3*a^(1/3)*_
+   b^(2/3)*c^2*(2*a-b*c^3))*d^2*log(a^(1/3)+b^(1/3)*(c+d*x))/(a^(2/3)*_
+   (a+b*c^3)^3)+1/6*b^(2/3)*(a^2-7*a*b*c^3+b^2*c^6+3*a^(1/3)*b^(2/3)*_
+   c^2*(2*a-b*c^3))*d^2*log(a^(2/3)-a^(1/3)*b^(1/3)*(c+d*x)+b^(2/3)*_
+   (c+d*x)^2)/(a^(2/3)*(a+b*c^3)^3)+b*c*(a-2*b*c^3)*d^2*log(a+b*(c+d*_
+   x)^3)/(a+b*c^3)^3+b^(2/3)*(a^(1/3)+b^(1/3)*c)^3*(a-3*a^(2/3)*b^(1/3)*c+_
+   b*c^3)*d^2*atan((a^(1/3)-2*b^(1/3)*(c+d*x))/(a^(1/3)*sqrt(3)))/_
+   (a^(2/3)*(a+b*c^3)^3*sqrt(3))
+--R 
+--R
+--R   (2)
+--R             2 6         3    2  2 2 +-+3+-+2
+--R           (b c  - 7a b c  + a )d x \|3 \|b
+--R         + 
+--R                2 5         2  2 2 +-+3+-+3+-+
+--R           (- 3b c  + 6a b c )d x \|3 \|a \|b
+--R      *
+--R               2 2             2 3+-+2              3+-+3+-+   3+-+2
+--R         log((d x  + 2c d x + c )\|b   + (- d x - c)\|a \|b  + \|a  )
+--R     + 
+--R                2 6          3     2  2 2 +-+3+-+2
+--R           (- 2b c  + 14a b c  - 2a )d x \|3 \|b
+--R         + 
+--R              2 5          2  2 2 +-+3+-+3+-+
+--R           (6b c  - 12a b c )d x \|3 \|a \|b
+--R      *
+--R                      3+-+   3+-+
+--R         log((d x + c)\|b  + \|a )
+--R     + 
+--R                  2 6          3     2  2 2 3+-+2
+--R             (- 6b c  + 42a b c  - 6a )d x  \|b
+--R           + 
+--R                   2 5          2  2 2 3+-+3+-+
+--R             (- 18b c  + 36a b c )d x  \|a \|b
+--R      *
+--R                         3+-+   3+-+
+--R              (2d x + 2c)\|b  - \|a
+--R         atan(----------------------)
+--R                      +-+3+-+
+--R                     \|3 \|a
+--R     + 
+--R                   2 4           2 2 +-+
+--R             (- 12b c  + 6a b c)d x \|3
+--R          *
+--R                    3 3         2 2       2         3
+--R             log(b d x  + 3b c d x  + 3b c d x + b c  + a)
+--R         + 
+--R               2 4            2 2 +-+
+--R           (36b c  - 18a b c)d x \|3 log(x)
+--R         + 
+--R                2 5          2         2 6         3     2  +-+
+--R           ((18b c  + 18a b c )d x - 3b c  - 6a b c  - 3a )\|3
+--R      *
+--R         3+-+2
+--R         \|a
+--R  /
+--R        3 9        2 6      2   3     3  2 +-+3+-+2
+--R     (6b c  + 18a b c  + 18a b c  + 6a )x \|3 \|a
+--R                                                    Type: Expression(Integer)
+--E 258
+
+--S 259 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 259
+
+)clear all
+
+--S 260 of 361
+t0:=x^3/(a+b*(c+d*x)^4)
+--R 
+--R
+--R                                  3
+--R                                 x
+--R   (1)  ----------------------------------------------------
+--R           4 4         3 3       2 2 2       3         4
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 260
+
+--S 261 of 361
+r0:=1/4*log(a+b*(c+d*x)^4)/(b*d^4)+3/2*c^2*atan((c+d*x)^2*sqrt(b)/sqrt(a))/_
+   (d^4*sqrt(a)*sqrt(b))-1/4*c*log(-a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+_
+   sqrt(a)+(c+d*x)^2*sqrt(b))*(3*sqrt(a)-c^2*sqrt(b))/(a^(3/4)*b^(3/4)*_
+   d^4*sqrt(2))+1/4*c*log(a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*_
+   sqrt(b))*(3*sqrt(a)-c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^4*sqrt(2))+_
+   1/2*c*atan(1-b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))*(3*sqrt(a)+c^2*sqrt(b))/_
+   (a^(3/4)*b^(3/4)*d^4*sqrt(2))-1/2*c*atan(1+b^(1/4)*(c+d*x)*_
+   sqrt(2)/a^(1/4))*(3*sqrt(a)+c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^4*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 +-+    2 3 +-+
+--R         (3a b c\|b  - b c \|a )
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                   +-+    2 3 +-+
+--R         (- 3a b c\|b  + b c \|a )
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                                                +-+4+-+   4+-+
+--R                 +-+     2 3 +-+      (d x + c)\|2 \|b  + \|a
+--R       (- 6a b c\|b  - 2b c \|a )atan(------------------------)
+--R                                                4+-+
+--R                                                \|a
+--R     + 
+--R                                                +-+4+-+   4+-+
+--R                 +-+     2 3 +-+      (d x + c)\|2 \|b  - \|a
+--R       (- 6a b c\|b  - 2b c \|a )atan(------------------------)
+--R                                                4+-+
+--R                                                \|a
+--R     + 
+--R                                  2 2             2  +-+
+--R           2 +-+4+-+3 4+-+3     (d x  + 2c d x + c )\|b
+--R       6b c \|2 \|a   \|b  atan(------------------------)
+--R                                           +-+
+--R                                          \|a
+--R     + 
+--R          +-+       4 4         3 3       2 2 2       3         4      +-+4+-+3
+--R         \|2 log(b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a)\|a \|a
+--R      *
+--R          +-+4+-+3
+--R         \|b \|b
+--R  /
+--R         4 +-+ +-+4+-+3 +-+4+-+3
+--R     4b d \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 262
+
+)clear all
+
+--S 263 of 361
+t0:=x^2/(a+b*(c+d*x)^4)
+--R 
+--R
+--R                                  2
+--R                                 x
+--R   (1)  ----------------------------------------------------
+--R           4 4         3 3       2 2 2       3         4
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 263
+
+--S 264 of 361
+r0:=-c*atan((c+d*x)^2*sqrt(b)/sqrt(a))/(d^3*sqrt(a)*sqrt(b))+_
+   1/4*log(-a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))*_
+   (sqrt(a)-c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^3*sqrt(2))-1/4*log(a^(1/4)*_
+   b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))*(sqrt(a)-_
+   c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^3*sqrt(2))-1/2*atan(1-b^(1/4)*_
+   (c+d*x)*sqrt(2)/a^(1/4))*(sqrt(a)+c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^3*_
+   sqrt(2))+1/2*atan(1+b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))*(sqrt(a)+_
+   c^2*sqrt(b))/(a^(3/4)*b^(3/4)*d^3*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              +-+      2 +-+
+--R         (- a\|b  + b c \|a )
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R            +-+      2 +-+
+--R         (a\|b  - b c \|a )
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                                          +-+4+-+   4+-+
+--R           +-+       2 +-+      (d x + c)\|2 \|b  + \|a
+--R       (2a\|b  + 2b c \|a )atan(------------------------)
+--R                                          4+-+
+--R                                          \|a
+--R     + 
+--R                                          +-+4+-+   4+-+
+--R           +-+       2 +-+      (d x + c)\|2 \|b  - \|a
+--R       (2a\|b  + 2b c \|a )atan(------------------------)
+--R                                          4+-+
+--R                                          \|a
+--R     + 
+--R                                 2 2             2  +-+
+--R            +-+4+-+3 4+-+3     (d x  + 2c d x + c )\|b
+--R       - 4c\|2 \|a   \|b  atan(------------------------)
+--R                                          +-+
+--R                                         \|a
+--R  /
+--R       3 +-+ +-+4+-+3 +-+4+-+3
+--R     4d \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 265
+
+)clear all
+
+--S 266 of 361
+t0:=x/(a+b*(c+d*x)^4)
+--R 
+--R
+--R                                  x
+--R   (1)  ----------------------------------------------------
+--R           4 4         3 3       2 2 2       3         4
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 266
+
+--S 267 of 361
+r0:=1/2*c*atan(1-b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*d^2*_
+   sqrt(2))-1/2*c*atan(1+b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))/(a^(3/4)*_
+   b^(1/4)*d^2*sqrt(2))+1/4*c*log(-a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+_
+   sqrt(a)+(c+d*x)^2*sqrt(b))/(a^(3/4)*b^(1/4)*d^2*sqrt(2))-_
+   1/4*c*log(a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*_
+   sqrt(b))/(a^(3/4)*b^(1/4)*d^2*sqrt(2))+1/2*atan((c+d*x)^2*_
+   sqrt(b)/sqrt(a))/(d^2*sqrt(a)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R           +-+ +-+              +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       - c\|a \|b log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R         +-+ +-+                +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       c\|a \|b log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                                  +-+4+-+   4+-+
+--R            +-+ +-+     (d x + c)\|2 \|b  + \|a
+--R       - 2c\|a \|b atan(------------------------)
+--R                                  4+-+
+--R                                  \|a
+--R     + 
+--R                                  +-+4+-+   4+-+
+--R            +-+ +-+     (d x + c)\|2 \|b  - \|a
+--R       - 2c\|a \|b atan(------------------------)
+--R                                  4+-+
+--R                                  \|a
+--R     + 
+--R                             2 2             2  +-+
+--R         +-+4+-+3 4+-+     (d x  + 2c d x + c )\|b
+--R       2\|2 \|a   \|b atan(------------------------)
+--R                                      +-+
+--R                                     \|a
+--R  /
+--R       2 +-+ +-+4+-+3 +-+4+-+
+--R     4d \|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 268
+
+)clear all
+
+--S 269 of 361
+t0:=1/(a+b*(c+d*x)^4)
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R           4 4         3 3       2 2 2       3         4
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 269
+
+--S 270 of 361
+r0:=-1/2*atan(1-b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*d*_
+   sqrt(2))+1/2*atan(1+b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*_
+   d*sqrt(2))-1/4*log(-a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*_
+   sqrt(b))/(a^(3/4)*b^(1/4)*d*sqrt(2))+1/4*log(a^(1/4)*b^(1/4)*(c+d*x)*_
+   sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))/(a^(3/4)*b^(1/4)*d*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                     +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R       - log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                       +-+4+-+   4+-+                    +-+4+-+   4+-+
+--R             (d x + c)\|2 \|b  + \|a           (d x + c)\|2 \|b  - \|a
+--R       2atan(------------------------) + 2atan(------------------------)
+--R                       4+-+                              4+-+
+--R                       \|a                               \|a
+--R  /
+--R        +-+4+-+3 4+-+
+--R     4d\|2 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 270
+
+--S 271 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 271
+
+)clear all
+
+--S 272 of 361
+t0:=1/(x*(a+b*(c+d*x)^4))
+--R 
+--R
+--R                                    1
+--R   (1)  --------------------------------------------------------
+--R           4 5         3 4       2 2 3       3   2       4
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x  + (b c  + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 272
+
+--S 273 of 361
+r0:=log(x)/(a+b*c^4)-1/4*log(a+b*(c+d*x)^4)/(a+b*c^4)-1/2*c^2*atan((c+d*x)^2*_
+   sqrt(b)/sqrt(a))*sqrt(b)/((a+b*c^4)*sqrt(a))-1/4*b^(1/4)*c*_
+   log(-a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))*_
+   (sqrt(a)-c^2*sqrt(b))/(a^(3/4)*(a+b*c^4)*sqrt(2))+1/4*b^(1/4)*c*_
+   log(a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))*_
+   (sqrt(a)-c^2*sqrt(b))/(a^(3/4)*(a+b*c^4)*sqrt(2))+1/2*b^(1/4)*c*_
+   atan(1-b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))*(sqrt(a)+c^2*sqrt(b))/(a^(3/4)*_
+   (a+b*c^4)*sqrt(2))-1/2*b^(1/4)*c*atan(1+b^(1/4)*(c+d*x)*sqrt(2)/a^(1/4))*_
+   (sqrt(a)+c^2*sqrt(b))/(a^(3/4)*(a+b*c^4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             3 +-+ +-+       4+-+
+--R         (- c \|a \|b  + a c)\|b
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R           3 +-+ +-+       4+-+
+--R         (c \|a \|b  - a c)\|b
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                                                +-+4+-+   4+-+
+--R            3 +-+ +-+        4+-+     (d x + c)\|2 \|b  + \|a
+--R       (- 2c \|a \|b  - 2a c)\|b atan(------------------------)
+--R                                                4+-+
+--R                                                \|a
+--R     + 
+--R                                                +-+4+-+   4+-+
+--R            3 +-+ +-+        4+-+     (d x + c)\|2 \|b  - \|a
+--R       (- 2c \|a \|b  - 2a c)\|b atan(------------------------)
+--R                                                4+-+
+--R                                                \|a
+--R     + 
+--R                                2 2             2  +-+
+--R           2 +-+4+-+3 +-+     (d x  + 2c d x + c )\|b
+--R       - 2c \|2 \|a  \|b atan(------------------------)
+--R                                         +-+
+--R                                        \|a
+--R     + 
+--R              +-+       4 4         3 3       2 2 2       3         4
+--R           - \|2 log(b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a)
+--R         + 
+--R             +-+
+--R           4\|2 log(x)
+--R      *
+--R          +-+4+-+3
+--R         \|a \|a
+--R  /
+--R          4       +-+ +-+4+-+3
+--R     (4b c  + 4a)\|2 \|a \|a
+--R                                                    Type: Expression(Integer)
+--E 273
+
+--S 274 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 274
+
+)clear all
+
+--S 275 of 361
+t0:=1/(x^2*(a+b*(c+d*x)^4))
+--R 
+--R
+--R                                    1
+--R   (1)  ---------------------------------------------------------
+--R           4 6         3 5       2 2 4       3   3       4      2
+--R        b d x  + 4b c d x  + 6b c d x  + 4b c d x  + (b c  + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 275
+
+--S 276 of 361
+r0:=(-1)/((a+b*c^4)*x)-4*b*c^3*d*log(x)/(a+b*c^4)^2+b*c^3*d*log(a+b*(c+_
+   d*x)^4)/(a+b*c^4)^2-c*(a-b*c^4)*d*atan((c+d*x)^2*sqrt(b)/sqrt(a))*_
+   sqrt(b)/((a+b*c^4)^2*sqrt(a))-1/4*b^(1/4)*d*log(-a^(1/4)*b^(1/4)*_
+   (c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*sqrt(b))*(a^(3/2)+b^(3/2)*c^6-_
+   3*b*c^4*sqrt(a)-3*a*c^2*sqrt(b))/(a^(3/4)*(a+b*c^4)^2*sqrt(2))+_
+   1/4*b^(1/4)*d*log(a^(1/4)*b^(1/4)*(c+d*x)*sqrt(2)+sqrt(a)+(c+d*x)^2*_
+   sqrt(b))*(a^(3/2)+b^(3/2)*c^6-3*b*c^4*sqrt(a)-3*a*c^2*sqrt(b))/_
+   (a^(3/4)*(a+b*c^4)^2*sqrt(2))+1/2*b^(1/4)*d*atan(1-b^(1/4)*(c+d*x)*_
+   sqrt(2)/a^(1/4))*((a-3*b*c^4)*sqrt(a)+c^2*(3*a-b*c^4)*sqrt(b))/(a^(3/4)*_
+   (a+b*c^4)^2*sqrt(2))-1/2*b^(1/4)*d*atan(1+b^(1/4)*(c+d*x)*_
+   sqrt(2)/a^(1/4))*((a-3*b*c^4)*sqrt(a)+c^2*(3*a-b*c^4)*sqrt(b))/_
+   (a^(3/4)*(a+b*c^4)^2*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              6       2     +-+ +-+            4    2     4+-+
+--R         ((b c  - 3a c )d x\|a \|b  + (- 3a b c  + a )d x)\|b
+--R      *
+--R                       +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((d x + c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R                6       2     +-+ +-+          4    2     4+-+
+--R         ((- b c  + 3a c )d x\|a \|b  + (3a b c  - a )d x)\|b
+--R      *
+--R                         +-+4+-+4+-+     2 2             2  +-+    +-+
+--R         log((- d x - c)\|2 \|a \|b  + (d x  + 2c d x + c )\|b  + \|a )
+--R     + 
+--R               6       2     +-+ +-+          4     2     4+-+
+--R         ((2b c  - 6a c )d x\|a \|b  + (6a b c  - 2a )d x)\|b
+--R      *
+--R                        +-+4+-+   4+-+
+--R              (d x + c)\|2 \|b  + \|a
+--R         atan(------------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R               6       2     +-+ +-+          4     2     4+-+
+--R         ((2b c  - 6a c )d x\|a \|b  + (6a b c  - 2a )d x)\|b
+--R      *
+--R                        +-+4+-+   4+-+
+--R              (d x + c)\|2 \|b  - \|a
+--R         atan(------------------------)
+--R                        4+-+
+--R                        \|a
+--R     + 
+--R                                            2 2             2  +-+
+--R            5            +-+4+-+3 +-+     (d x  + 2c d x + c )\|b
+--R       (4b c  - 4a c)d x\|2 \|a  \|b atan(------------------------)
+--R                                                     +-+
+--R                                                    \|a
+--R     + 
+--R               3    +-+       4 4         3 3       2 2 2       3         4
+--R           4b c d x\|2 log(b d x  + 4b c d x  + 6b c d x  + 4b c d x + b c  + a)
+--R         + 
+--R                  3    +-+                4       +-+
+--R           - 16b c d x\|2 log(x) + (- 4b c  - 4a)\|2
+--R      *
+--R          +-+4+-+3
+--R         \|a \|a
+--R  /
+--R        2 8         4     2   +-+ +-+4+-+3
+--R     (4b c  + 8a b c  + 4a )x\|2 \|a \|a
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 277
+
+)clear all
+
+--S 278 of 361
+t0:=x^3*(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R              3 +-------+    2   4     2     2  3
+--R   (1)  2a b x \|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 361
+r0:=-a^2*c^3*x/d^3-4/3*a*b*c^3*(c+d*x)^(3/2)/d^4+1/2*c^2*(3*a^2-b^2*c)*_
+   (c+d*x)^2/d^4+12/5*a*b*c^2*(c+d*x)^(5/2)/d^4-c*(a^2-b^2*c)*(c+d*x)^3/d^4-_
+   12/7*a*b*c*(c+d*x)^(7/2)/d^4+1/4*(a^2-3*b^2*c)*(c+d*x)^4/d^4+_
+   4/9*a*b*(c+d*x)^(9/2)/d^4+1/5*b^2*(c+d*x)^5/d^4
+--R 
+--R
+--R   (2)
+--R                  4 4            3 3          2 2 2           3              4
+--R         (560a b d x  + 80a b c d x  - 96a b c d x  + 128a b c d x - 256a b c )
+--R      *
+--R          +-------+
+--R         \|d x + c
+--R     + 
+--R           2 5 5        2        2  4 4      2 5       2 4
+--R       252b d x  + (315b c + 315a )d x  - 63b c  + 945a c
+--R  /
+--R          4
+--R     1260d
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 280
+
+)clear all
+
+--S 281 of 361
+t0:=x^2*(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R              2 +-------+    2   3     2     2  2
+--R   (1)  2a b x \|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 361
+r0:=a^2*c^2*x/d^2+4/3*a*b*c^2*(c+d*x)^(3/2)/d^3-1/2*c*(2*a^2-b^2*c)*_
+   (c+d*x)^2/d^3-8/5*a*b*c*(c+d*x)^(5/2)/d^3+1/3*(a^2-2*b^2*c)*_
+   (c+d*x)^3/d^3+4/7*a*b*(c+d*x)^(7/2)/d^3+1/4*b^2*(c+d*x)^4/d^3
+--R 
+--R
+--R   (2)
+--R                3 3            2 2          2              3  +-------+
+--R       (240a b d x  + 48a b c d x  - 64a b c d x + 128a b c )\|d x + c
+--R     + 
+--R           2 4 4        2        2  3 3      2 4       2 3
+--R       105b d x  + (140b c + 140a )d x  + 35b c  - 280a c
+--R  /
+--R         3
+--R     420d
+--R                                                    Type: Expression(Integer)
+--E 282
+
+--S 283 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 283
+
+)clear all
+
+--S 284 of 361
+t0:=x*(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R               +-------+    2   2     2     2
+--R   (1)  2a b x\|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 361
+r0:=-a^2*c*x/d-4/3*a*b*c*(c+d*x)^(3/2)/d^2+1/2*(a^2-b^2*c)*(c+d*x)^2/d^2+_
+   4/5*a*b*(c+d*x)^(5/2)/d^2+1/3*b^2*(c+d*x)^3/d^2
+--R 
+--R
+--R   (2)
+--R               2 2                       2  +-------+      2 3 3
+--R       (24a b d x  + 8a b c d x - 16a b c )\|d x + c  + 10b d x
+--R     + 
+--R           2       2  2 2     2 3      2 2
+--R       (15b c + 15a )d x  - 5b c  + 15a c
+--R  /
+--R        2
+--R     30d
+--R                                                    Type: Expression(Integer)
+--E 285
+
+--S 286 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 286
+
+)clear all
+
+--S 287 of 361
+t0:=(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R             +-------+    2       2     2
+--R   (1)  2a b\|d x + c  + b d x + b c + a
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 361
+r0:=a^2*x+4/3*a*b*(c+d*x)^(3/2)/d+1/2*b^2*(c+d*x)^2/d
+--R 
+--R
+--R                            +-------+     2 2 2      2      2         2 2
+--R        (8a b d x + 8a b c)\|d x + c  + 3b d x  + (6b c + 6a )d x + 3b c
+--R   (2)  -----------------------------------------------------------------
+--R                                        6d
+--R                                                    Type: Expression(Integer)
+--E 288
+
+--S 289 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 289
+
+)clear all
+
+--S 290 of 361
+t0:=(a+b*sqrt(c+d*x))^2/x
+--R 
+--R
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R   (1)  ---------------------------------
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 361
+r0:=b^2*d*x+(a^2+b^2*c)*log(x)-4*a*b*atanh(sqrt(c+d*x)/sqrt(c))*sqrt(c)+_
+   4*a*b*sqrt(c+d*x)
+--R 
+--R
+--R   (2)
+--R                    +-------+
+--R          +-+      \|d x + c          +-------+     2     2           2
+--R   - 4a b\|c atanh(----------) + 4a b\|d x + c  + (b c + a )log(x) + b d x
+--R                       +-+
+--R                      \|c
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--R
+)clear all
+
+--S 293 of 361
+t0:=(a+b*sqrt(c+d*x))^2/x^2
+--R 
+--R
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R   (1)  ---------------------------------
+--R                         2
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 361
+r0:=b^2*d*log(x)-2*a*b*d*atanh(sqrt(c+d*x)/sqrt(c))/sqrt(c)-_
+   (a+b*sqrt(c+d*x))^2/x
+--R 
+--R
+--R   (2)
+--R                         +-------+
+--R                        \|d x + c          +-+ +-------+
+--R       - 2a b d x atanh(----------) - 2a b\|c \|d x + c
+--R                            +-+
+--R                           \|c
+--R     + 
+--R         2              2       2     2  +-+
+--R       (b d x log(x) - b d x - b c - a )\|c
+--R  /
+--R       +-+
+--R     x\|c
+--R                                                    Type: Expression(Integer)
+--E 294
+
+--S 295 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 295
+
+)clear all
+
+--S 296 of 361
+t0:=(a+b*sqrt(c+d*x))^2/x^3
+--R 
+--R
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R   (1)  ---------------------------------
+--R                         3
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 361
+r0:=1/2*a*b*d^2*atanh(sqrt(c+d*x)/sqrt(c))/c^(3/2)-_
+   1/2*b*d*(b*c+a*sqrt(c+d*x))/(c*x)-1/2*(a+b*sqrt(c+d*x))^2/x^2
+--R 
+--R
+--R   (2)
+--R                      +-------+
+--R            2 2      \|d x + c                          +-+ +-------+
+--R       a b d x atanh(----------) + (- a b d x - 2a b c)\|c \|d x + c
+--R                         +-+
+--R                        \|c
+--R     + 
+--R            2         2 2    2   +-+
+--R       (- 2b c d x - b c  - a c)\|c
+--R  /
+--R         2 +-+
+--R     2c x \|c
+--R                                                    Type: Expression(Integer)
+--E 297
+
+--S 298 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 298
+
+)clear all
+
+--S 299 of 361
+t0:=x^3*sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R           +---------------+
+--R         3 |  +-------+
+--R   (1)  x \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 361
+r0:=-4/3*a*(a^2-b^2*c)^3*(a+b*sqrt(c+d*x))^(3/2)/(b^8*d^4)+4/5*(a^2-b^2*c)^2*_
+   (7*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(5/2)/(b^8*d^4)-12/7*a*(7*a^2-3*b^2*c)*_
+   (a^2-b^2*c)*(a+b*sqrt(c+d*x))^(7/2)/(b^8*d^4)+4/9*(35*a^4-_
+   30*a^2*b^2*c+3*b^4*c^2)*(a+b*sqrt(c+d*x))^(9/2)/(b^8*d^4)-20/11*a*_
+   (7*a^2-3*b^2*c)*(a+b*sqrt(c+d*x))^(11/2)/(b^8*d^4)+12/13*(7*a^2-b^2*c)*_
+   (a+b*sqrt(c+d*x))^(13/2)/(b^8*d^4)-28/15*a*(a+b*sqrt(c+d*x))^(15/2)/_
+   (b^8*d^4)+4/17*(a+b*sqrt(c+d*x))^(17/2)/(b^8*d^4)
+--R 
+--R
+--R   (2)
+--R                     7 3 3              7          3 5  2 2
+--R             12012a b d x  + (- 28224a b c + 14112a b )d x
+--R           + 
+--R                      7 2         3 5          5 3                7 3
+--R             (53376a b c  - 53376a b c + 17920a b )d x - 110592a b c
+--R           + 
+--R                    3 5 2          5 3          7
+--R             165888a b c  - 112640a b c + 28672a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R                8 4 4          8          2 6  3 3
+--R         180180b d x  + (13860b c - 12936a b )d x
+--R       + 
+--R                  8 2         2 6          4 4  2 2
+--R         (- 18480b c  + 32592a b c - 15680a b )d x
+--R       + 
+--R                8 3         2 6 2         4 4          6 2              8 4
+--R         (29568b c  - 71040a b c  + 66560a b c - 21504a b )d x - 118272b c
+--R       + 
+--R                2 6 3          4 4 2          6 2          8
+--R         291840a b c  - 384512a b c  + 239616a b c - 57344a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R            8 4
+--R     765765b d
+--R                                                    Type: Expression(Integer)
+--E 300
+
+--S 301 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 301
+
+)clear all
+
+--S 302 of 361
+t0:=x^2*sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R           +---------------+
+--R         2 |  +-------+
+--R   (1)  x \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 361
+r0:=-4/3*a*(a^2-b^2*c)^2*(a+b*sqrt(c+d*x))^(3/2)/(b^6*d^3)+4/5*(5*a^4-_
+   6*a^2*b^2*c+b^4*c^2)*(a+b*sqrt(c+d*x))^(5/2)/(b^6*d^3)-8/7*a*(5*a^2-_
+   3*b^2*c)*(a+b*sqrt(c+d*x))^(7/2)/(b^6*d^3)+8/9*(5*a^2-b^2*c)*(a+_
+   b*sqrt(c+d*x))^(9/2)/(b^6*d^3)-20/11*a*(a+b*sqrt(c+d*x))^(11/2)/(b^6*_
+   d^3)+4/13*(a+b*sqrt(c+d*x))^(13/2)/(b^6*d^3)
+--R 
+--R
+--R   (2)
+--R                    5 2 2             5         3 3              5 2        3 3
+--R             1260a b d x  + (- 3200a b c + 1600a b )d x + 7552a b c  - 7552a b c
+--R           + 
+--R                  5
+--R             2560a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R               6 3 3         6         2 4  2 2
+--R         13860b d x  + (1540b c - 1400a b )d x
+--R       + 
+--R                 6 2        2 4         4 2            6 3         2 4 2
+--R         (- 2464b c  + 4064a b c - 1920a b )d x + 9856b c  - 18560a b c
+--R       + 
+--R               4 2         6
+--R         16384a b c - 5120a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R           6 3
+--R     45045b d
+--R                                                    Type: Expression(Integer)
+--E 303
+
+--S 304 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 304
+
+)clear all
+
+--S 305 of 361
+t0:=x*sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R          +---------------+
+--R          |  +-------+
+--R   (1)  x\|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 361
+r0:=-4/3*a*(a^2-b^2*c)*(a+b*sqrt(c+d*x))^(3/2)/(b^4*d^2)+4/5*(3*a^2-b^2*c)*_
+   (a+b*sqrt(c+d*x))^(5/2)/(b^4*d^2)-12/7*a*(a+b*sqrt(c+d*x))^(7/2)/_
+   (b^4*d^2)+4/9*(a+b*sqrt(c+d*x))^(9/2)/(b^4*d^2)
+--R 
+--R
+--R   (2)
+--R               3           3       3   +-------+       4 2 2
+--R         (20a b d x - 64a b c + 32a b)\|d x + c  + 140b d x
+--R       + 
+--R             4       2 2           4 2       2 2       4
+--R         (28b c - 24a b )d x - 112b c  + 144a b c - 64a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R         4 2
+--R     315b d
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 307
+
+)clear all
+
+--S 308 of 361
+t0:=sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R         +---------------+
+--R         |  +-------+
+--R   (1)  \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 361
+r0:=-4/3*a*(a+b*sqrt(c+d*x))^(3/2)/(b^2*d)+4/5*(a+b*sqrt(c+d*x))^(5/2)/(b^2*d)
+--R 
+--R
+--R                                                 +---------------+
+--R              +-------+      2         2      2  |  +-------+
+--R        (4a b\|d x + c  + 12b d x + 12b c - 8a )\|b\|d x + c  + a
+--R   (2)  ----------------------------------------------------------
+--R                                      2
+--R                                   15b d
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 310
+
+)clear all
+
+--S 311 of 361
+t0:=sqrt(a+b*sqrt(c+d*x))/x
+--R 
+--R
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 361
+r0:=-2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))*sqrt(a-b*sqrt(c))-_
+   2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a+b*sqrt(c)))*sqrt(a+b*sqrt(c))+_
+   4*sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R   (2)
+--R                             +---------------+
+--R         +-----------+       |  +-------+
+--R         |    +-+           \|b\|d x + c  + a
+--R     - 2\|- b\|c  + a atanh(------------------)
+--R                               +-----------+
+--R                               |    +-+
+--R                              \|- b\|c  + a
+--R   + 
+--R                           +---------------+
+--R         +---------+       |  +-------+           +---------------+
+--R         |  +-+           \|b\|d x + c  + a       |  +-------+
+--R     - 2\|b\|c  + a atanh(------------------) + 4\|b\|d x + c  + a
+--R                              +---------+
+--R                              |  +-+
+--R                             \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 313
+
+)clear all
+
+--S 314 of 361
+t0:=sqrt(a+b*sqrt(c+d*x))/x^2
+--R 
+--R
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R   (1)  ------------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 361
+r0:=1/2*b*d*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))/(sqrt(c)*_
+   sqrt(a-b*sqrt(c)))-1/2*b*d*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a+_
+   b*sqrt(c)))/(sqrt(c)*sqrt(a+b*sqrt(c)))-sqrt(a+b*sqrt(c+d*x))/x
+--R 
+--R
+--R   (2)
+--R                               +---------------+
+--R             +---------+       |  +-------+
+--R             |  +-+           \|b\|d x + c  + a
+--R       b d x\|b\|c  + a atanh(------------------)
+--R                                 +-----------+
+--R                                 |    +-+
+--R                                \|- b\|c  + a
+--R     + 
+--R                                   +---------------+
+--R               +-----------+       |  +-------+
+--R               |    +-+           \|b\|d x + c  + a
+--R       - b d x\|- b\|c  + a atanh(------------------)
+--R                                      +---------+
+--R                                      |  +-+
+--R                                     \|b\|c  + a
+--R     + 
+--R               +-----------+ +---------+ +---------------+
+--R           +-+ |    +-+      |  +-+      |  +-------+
+--R       - 2\|c \|- b\|c  + a \|b\|c  + a \|b\|d x + c  + a
+--R  /
+--R            +-----------+ +---------+
+--R        +-+ |    +-+      |  +-+
+--R     2x\|c \|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 315
+
+--S 316 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 316
+
+)clear all
+
+--S 317 of 361
+t0:=sqrt(a+b*sqrt(c+d*x))/x^3
+--R 
+--R
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R   (1)  ------------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 361
+r0:=-1/16*b*d^2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))*(2*a-_
+   3*b*sqrt(c))/(c^(3/2)*(a-b*sqrt(c))^(3/2))+1/16*b*d^2*atanh(sqrt(a+_
+   b*sqrt(c+d*x))/sqrt(a+b*sqrt(c)))*(2*a+3*b*sqrt(c))/(c^(3/2)*(a+_
+   b*sqrt(c))^(3/2))-1/2*sqrt(a+b*sqrt(c+d*x))/x^2+1/8*b*d*(b*c-_
+   a*sqrt(c+d*x))*sqrt(a+b*sqrt(c+d*x))/(c*(a^2-b^2*c)*x)
+--R 
+--R
+--R   (2)
+--R                                                +---------+
+--R               3      2   2 2 +-+      2   2 2  |  +-+
+--R         ((- 3b c + 2a b)d x \|c  - a b c d x )\|b\|c  + a
+--R      *
+--R                +---------------+
+--R                |  +-------+
+--R               \|b\|d x + c  + a
+--R         atanh(------------------)
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- b\|c  + a
+--R     + 
+--R                                              +-----------+
+--R             3      2   2 2 +-+      2   2 2  |    +-+
+--R         ((3b c - 2a b)d x \|c  - a b c d x )\|- b\|c  + a
+--R      *
+--R                +---------------+
+--R                |  +-------+
+--R               \|b\|d x + c  + a
+--R         atanh(------------------)
+--R                   +---------+
+--R                   |  +-+
+--R                  \|b\|c  + a
+--R     + 
+--R                                                           +-----------+
+--R                     +-------+     2 2        2 3     2 2  |    +-+
+--R         (2a b c d x\|d x + c  - 2b c d x - 8b c  + 8a c )\|- b\|c  + a
+--R      *
+--R          +---------+ +---------------+
+--R          |  +-+      |  +-------+
+--R         \|b\|c  + a \|b\|d x + c  + a
+--R  /
+--R                         +-----------+ +---------+
+--R         2 3      2 2  2 |    +-+      |  +-+
+--R     (16b c  - 16a c )x \|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 318
+
+--S 319 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 319
+
+)clear all
+
+--S 320 of 361
+t0:=x^3/(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ---------------
+--R          +-------+
+--R        b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 361
+r0:=-a*(a^4-3*a^2*b^2*c+3*b^4*c^2)*x/(b^6*d^3)+2/3*(a^4-3*a^2*b^2*c+_
+   3*b^4*c^2)*(c+d*x)^(3/2)/(b^5*d^4)-1/2*a*(a^2-3*b^2*c)*(c+d*x)^2/_
+   (b^4*d^4)+2/5*(a^2-3*b^2*c)*(c+d*x)^(5/2)/(b^3*d^4)-1/3*a*(c+d*x)^3/_
+   (b^2*d^4)+2/7*(c+d*x)^(7/2)/(b*d^4)-2*a*(a^2-b^2*c)^3*log(a+b*_
+   sqrt(c+d*x))/(b^8*d^4)+2*(a^2-b^2*c)^3*sqrt(c+d*x)/(b^7*d^4)
+--R 
+--R
+--R   (2)
+--R              6 3        3 4 2        5 2        7       +-------+
+--R       (420a b c  - 1260a b c  + 1260a b c - 420a )log(b\|d x + c  + a)
+--R     + 
+--R              7 3 3         7       2 5  2 2       7 2       2 5        4 3
+--R           60b d x  + (- 72b c + 84a b )d x  + (96b c  - 252a b c + 140a b )d x
+--R         + 
+--R                 7 3       2 5 2        4 3        6
+--R           - 192b c  + 924a b c  - 1120a b c + 420a b
+--R      *
+--R          +-------+
+--R         \|d x + c
+--R     + 
+--R              6 3 3          6        3 4  2 2
+--R       - 70a b d x  + (105a b c - 105a b )d x
+--R     + 
+--R                6 2       3 4        5 2             6 3       3 4 2
+--R       (- 210a b c  + 420a b c - 210a b )d x + 245a b c  - 105a b c
+--R  /
+--R         8 4
+--R     210b d
+--R                                                    Type: Expression(Integer)
+--E 321
+
+--S 322 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 322
+
+)clear all
+
+--S 323 of 361
+t0:=x^2/(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R          +-------+
+--R        b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 361
+r0:=-a*(a^2-2*b^2*c)*x/(b^4*d^2)+2/3*(a^2-2*b^2*c)*(c+d*x)^(3/2)/(b^3*d^3)-_
+   1/2*a*(c+d*x)^2/(b^2*d^3)+2/5*(c+d*x)^(5/2)/(b*d^3)-2*a*(a^2-b^2*c)^2*_
+   log(a+b*sqrt(c+d*x))/(b^6*d^3)+2*(a^2-b^2*c)^2*sqrt(c+d*x)/(b^5*d^3)
+--R 
+--R
+--R   (2)
+--R               4 2       3 2       5       +-------+
+--R       (- 60a b c  + 120a b c - 60a )log(b\|d x + c  + a)
+--R     + 
+--R           5 2 2         5       2 3          5 2       2 3       4   +-------+
+--R       (12b d x  + (- 16b c + 20a b )d x + 32b c  - 100a b c + 60a b)\|d x + c
+--R     + 
+--R              4 2 2         4       3 2            4 2
+--R       - 15a b d x  + (30a b c - 30a b )d x - 15a b c
+--R  /
+--R        6 3
+--R     30b d
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 325
+
+)clear all
+
+--S 326 of 361
+t0:=x/(a+b*sqrt(c+d*x))
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R          +-------+
+--R        b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 361
+r0:=-a*x/(b^2*d)+2/3*(c+d*x)^(3/2)/(b*d^2)-2*a*(a^2-b^2*c)*_
+   log(a+b*sqrt(c+d*x))/(b^4*d^2)+2*(a^2-b^2*c)*sqrt(c+d*x)/(b^3*d^2)
+--R 
+--R
+--R   (2)
+--R            2      3       +-------+           3        3      2   +-------+
+--R       (6a b c - 6a )log(b\|d x + c  + a) + (2b d x - 4b c + 6a b)\|d x + c
+--R     + 
+--R             2
+--R       - 3a b d x
+--R  /
+--R       4 2
+--R     3b d
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 328
+
+)clear all
+
+--S 329 of 361
+t0:=1/(a+b*sqrt(c+d*x))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          +-------+
+--R        b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 361
+r0:=-2*a*log(a+b*sqrt(c+d*x))/(b^2*d)+2*sqrt(c+d*x)/(b*d)
+--R 
+--R
+--R                   +-------+           +-------+
+--R        - 2a log(b\|d x + c  + a) + 2b\|d x + c
+--R   (2)  ----------------------------------------
+--R                            2
+--R                           b d
+--R                                                    Type: Expression(Integer)
+--E 330
+
+--S 331 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 331
+
+)clear all
+
+--S 332 of 361
+t0:=1/(x*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R            +-------+
+--R        b x\|d x + c  + a x
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 361
+r0:=a*log(x)/(a^2-b^2*c)-2*a*log(a+b*sqrt(c+d*x))/(a^2-b^2*c)+_
+   2*b*atanh(sqrt(c+d*x)/sqrt(c))*sqrt(c)/(a^2-b^2*c)
+--R 
+--R
+--R                                               +-------+
+--R                 +-------+           +-+      \|d x + c
+--R        2a log(b\|d x + c  + a) - 2b\|c atanh(----------) - a log(x)
+--R                                                  +-+
+--R                                                 \|c
+--R   (2)  ------------------------------------------------------------
+--R                                   2     2
+--R                                  b c - a
+--R                                                    Type: Expression(Integer)
+--E 333
+
+--S 334 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 334
+
+)clear all
+
+--S 335 of 361
+t0:=1/(x^2*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R           2 +-------+      2
+--R        b x \|d x + c  + a x
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 361
+r0:=a*b^2*d*log(x)/(a^2-b^2*c)^2-2*a*b^2*d*log(a+b*sqrt(c+d*x))/_
+   (a^2-b^2*c)^2+b*(a^2+b^2*c)*d*atanh(sqrt(c+d*x)/sqrt(c))/((a^2-b^2*c)^2*_
+   sqrt(c))+(-a+b*sqrt(c+d*x))/((a^2-b^2*c)*x)
+--R 
+--R
+--R   (2)
+--R                                                                  +-------+
+--R             2    +-+      +-------+          3     2            \|d x + c
+--R       - 2a b d x\|c log(b\|d x + c  + a) + (b c + a b)d x atanh(----------)
+--R                                                                     +-+
+--R                                                                    \|c
+--R     + 
+--R           3     2   +-+ +-------+       2                2     3  +-+
+--R       (- b c + a b)\|c \|d x + c  + (a b d x log(x) + a b c - a )\|c
+--R  /
+--R       4 2     2 2     4   +-+
+--R     (b c  - 2a b c + a )x\|c
+--R                                                    Type: Expression(Integer)
+--E 336
+
+--S 337 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 337
+
+)clear all
+
+--S 338 of 361
+t0:=1/(x^3*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R           3 +-------+      3
+--R        b x \|d x + c  + a x
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 361
+r0:=-1/4*b*(a^4-6*a^2*b^2*c-3*b^4*c^2)*d^2*atanh(sqrt(c+d*x)/sqrt(c))/_
+   (c^(3/2)*(a^2-b^2*c)^3)+a*b^4*d^2*log(x)/(a^2-b^2*c)^3-2*a*b^4*d^2*_
+   log(a+b*sqrt(c+d*x))/(a^2-b^2*c)^3+1/2*(-a+b*sqrt(c+d*x))/((a^2-_
+   b^2*c)*x^2)-1/4*b*d*(4*a*b*c-(a^2+3*b^2*c)*sqrt(c+d*x))/(c*(a^2-b^2*c)^2*x)
+--R 
+--R
+--R   (2)
+--R           4   2 2 +-+      +-------+
+--R       8a b c d x \|c log(b\|d x + c  + a)
+--R     + 
+--R                                          +-------+
+--R            5 2     2 3     4   2 2      \|d x + c
+--R       (- 3b c  - 6a b c + a b)d x atanh(----------)
+--R                                             +-+
+--R                                            \|c
+--R     + 
+--R           5 2     2 3     4          5 3     2 3 2     4     +-+ +-------+
+--R       ((3b c  - 2a b c - a b)d x - 2b c  + 4a b c  - 2a b c)\|c \|d x + c
+--R     + 
+--R                 4   2 2                4 2     3 2            4 3     3 2 2
+--R           - 4a b c d x log(x) + (- 4a b c  + 4a b c)d x + 2a b c  - 4a b c
+--R         + 
+--R             5
+--R           2a c
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R        6 4      2 4 3      4 2 2     6   2 +-+
+--R     (4b c  - 12a b c  + 12a b c  - 4a c)x \|c
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 340
+
+)clear all
+
+--S 341 of 361
+t0:=x^3/(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R                         3
+--R                        x
+--R   (1)  ---------------------------------
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 361
+r0:=(5*a^4-9*a^2*b^2*c+3*b^4*c^2)*x/(b^6*d^3)-4/3*a*(2*a^2-3*b^2*c)*_
+   (c+d*x)^(3/2)/(b^5*d^4)+3/2*(a^2-b^2*c)*(c+d*x)^2/(b^4*d^4)-4/5*a*_
+   (c+d*x)^(5/2)/(b^3*d^4)+1/3*(c+d*x)^3/(b^2*d^4)+2*(a^2-b^2*c)^2*_
+   (7*a^2-b^2*c)*log(a+b*sqrt(c+d*x))/(b^8*d^4)-12*a*(a^2-b^2*c)^2*_
+   sqrt(c+d*x)/(b^7*d^4)+2*a*(a^2-b^2*c)^3/(b^8*d^4*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R                 7 3       2 5 2       4 3        6   +-------+        6 3
+--R           (- 60b c  + 540a b c  - 900a b c + 420a b)\|d x + c  - 60a b c
+--R         + 
+--R               3 4 2       5 2        7
+--R           540a b c  - 900a b c + 420a
+--R      *
+--R               +-------+
+--R         log(b\|d x + c  + a)
+--R     + 
+--R              7 3 3         7       2 5  2 2       7 2       2 5       4 3
+--R           10b d x  + (- 15b c + 21a b )d x  + (30b c  - 108a b c + 70a b )d x
+--R         + 
+--R                7 3       2 5 2       4 3        6
+--R           - 35b c  - 219a b c  + 640a b c - 360a b
+--R      *
+--R          +-------+
+--R         \|d x + c
+--R     + 
+--R              6 3 3         6       3 4  2 2
+--R       - 14a b d x  + (33a b c - 35a b )d x
+--R     + 
+--R                6 2       3 4        5 2             6 3       3 4 2       5 2
+--R       (- 162a b c  + 380a b c - 210a b )d x - 359a b c  + 865a b c  - 540a b c
+--R     + 
+--R          7
+--R       60a
+--R  /
+--R        9 4 +-------+        8 4
+--R     30b d \|d x + c  + 30a b d
+--R                                                    Type: Expression(Integer)
+--E 342
+
+--S 343 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 343
+
+)clear all
+
+--S 344 of 361
+t0:=x^2/(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R                         2
+--R                        x
+--R   (1)  ---------------------------------
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 361
+r0:=(3*a^2-2*b^2*c)*x/(b^4*d^2)-4/3*a*(c+d*x)^(3/2)/(b^3*d^3)+1/2*(c+d*x)^2/_
+   (b^2*d^3)+2*(5*a^4-6*a^2*b^2*c+b^4*c^2)*log(a+b*sqrt(c+d*x))/(b^6*d^3)-_
+   8*a*(a^2-b^2*c)*sqrt(c+d*x)/(b^5*d^3)+2*a*(a^2-b^2*c)^2/(b^6*d^3*_
+   (a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R              5 2      2 3       4   +-------+        4 2      3 2       5
+--R         ((12b c  - 72a b c + 60a b)\|d x + c  + 12a b c  - 72a b c + 60a )
+--R      *
+--R               +-------+
+--R         log(b\|d x + c  + a)
+--R     + 
+--R          5 2 2        5       2 3         5 2      2 3       4   +-------+
+--R       (3b d x  + (- 6b c + 10a b )d x + 3b c  + 40a b c - 48a b)\|d x + c
+--R     + 
+--R             4 2 2         4       3 2            4 2      3 2       5
+--R       - 5a b d x  + (26a b c - 30a b )d x + 55a b c  - 72a b c + 12a
+--R  /
+--R       7 3 +-------+       6 3
+--R     6b d \|d x + c  + 6a b d
+--R                                                    Type: Expression(Integer)
+--E 345
+
+--S 346 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 346
+
+)clear all
+
+--S 347 of 361
+t0:=x/(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R                        x
+--R   (1)  ---------------------------------
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 361
+r0:=x/(b^2*d)+2*(3*a^2-b^2*c)*log(a+b*sqrt(c+d*x))/(b^4*d^2)-_
+   4*a*sqrt(c+d*x)/(b^3*d^2)+2*a*(a^2-b^2*c)/(b^4*d^2*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R             3      2   +-------+       2      3       +-------+
+--R       ((- 2b c + 6a b)\|d x + c  - 2a b c + 6a )log(b\|d x + c  + a)
+--R     + 
+--R         3        2   +-------+       2          2      3
+--R       (b d x - 4a b)\|d x + c  - 3a b d x - 6a b c + 2a
+--R  /
+--R      5 2 +-------+      4 2
+--R     b d \|d x + c  + a b d
+--R                                                    Type: Expression(Integer)
+--E 348
+
+--S 349 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 349
+
+)clear all
+
+--S 350 of 361
+t0:=1/(a+b*sqrt(c+d*x))^2
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R             +-------+    2       2     2
+--R        2a b\|d x + c  + b d x + b c + a
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 361
+r0:=2*log(a+b*sqrt(c+d*x))/(b^2*d)+2*a/(b^2*d*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R            +-------+            +-------+
+--R        (2b\|d x + c  + 2a)log(b\|d x + c  + a) + 2a
+--R   (2)  --------------------------------------------
+--R                     3  +-------+      2
+--R                    b d\|d x + c  + a b d
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 352
+
+)clear all
+
+--S 353 of 361
+t0:=1/(x*(a+b*sqrt(c+d*x))^2)
+--R 
+--R
+--R                           1
+--R   (1)  ---------------------------------------
+--R               +-------+    2   2     2     2
+--R        2a b x\|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 361
+r0:=(a^2+b^2*c)*log(x)/(a^2-b^2*c)^2-2*(a^2+b^2*c)*log(a+b*sqrt(c+d*x))/_
+   (a^2-b^2*c)^2+4*a*b*atanh(sqrt(c+d*x)/sqrt(c))*sqrt(c)/(a^2-b^2*c)^2+_
+   2*a/((a^2-b^2*c)*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R             3      2   +-------+       2      3       +-------+
+--R       ((- 2b c - 2a b)\|d x + c  - 2a b c - 2a )log(b\|d x + c  + a)
+--R     + 
+--R                                              +-------+
+--R            2 +-+ +-------+     2  +-+       \|d x + c
+--R       (4a b \|c \|d x + c  + 4a b\|c )atanh(----------)
+--R                                                 +-+
+--R                                                \|c
+--R     + 
+--R         3     2         +-------+       2     3              2      3
+--R       (b c + a b)log(x)\|d x + c  + (a b c + a )log(x) - 2a b c + 2a
+--R  /
+--R       5 2     2 3     4   +-------+      4 2     3 2     5
+--R     (b c  - 2a b c + a b)\|d x + c  + a b c  - 2a b c + a
+--R                                                    Type: Expression(Integer)
+--E 354
+
+--S 355 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 355
+
+)clear all
+
+--S 356 of 361
+t0:=1/(x^2*(a+b*sqrt(c+d*x))^2)
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R              2 +-------+    2   3     2     2  2
+--R        2a b x \|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 361
+r0:=b^2*(3*a^2+b^2*c)*d*log(x)/(a^2-b^2*c)^3-2*b^2*(3*a^2+b^2*c)*d*_
+   log(a+b*sqrt(c+d*x))/(a^2-b^2*c)^3+2*a*b*(a^2+3*b^2*c)*d*_
+   atanh(sqrt(c+d*x)/sqrt(c))/((a^2-b^2*c)^3*sqrt(c))+4*a*b^2*d/_
+   ((a^2-b^2*c)^2*(a+b*sqrt(c+d*x)))+(-a+b*sqrt(c+d*x))/((a^2-b^2*c)*_
+   x*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R             5      2 3     +-+ +-------+        4      3 2     +-+
+--R         ((2b c + 6a b )d x\|c \|d x + c  + (2a b c + 6a b )d x\|c )
+--R      *
+--R               +-------+
+--R         log(b\|d x + c  + a)
+--R     + 
+--R                                                                      +-------+
+--R               4      3 2     +-------+        2 3      4            \|d x + c
+--R       ((- 6a b c - 2a b )d x\|d x + c  + (- 6a b c - 2a b)d x)atanh(----------)
+--R                                                                         +-+
+--R                                                                        \|c
+--R     + 
+--R            5      2 3               5 2     2 3     4   +-+ +-------+
+--R       ((- b c - 3a b )d x log(x) - b c  + 2a b c - a b)\|c \|d x + c
+--R     + 
+--R                 4      3 2                   4      3 2          4 2     3 2
+--R           (- a b c - 3a b )d x log(x) + (4a b c - 4a b )d x + a b c  - 2a b c
+--R         + 
+--R            5
+--R           a
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R         7 3     2 5 2     4 3     6    +-+ +-------+
+--R       (b c  - 3a b c  + 3a b c - a b)x\|c \|d x + c
+--R     + 
+--R           6 3     3 4 2     5 2     7   +-+
+--R       (a b c  - 3a b c  + 3a b c - a )x\|c
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 358
+
+)clear all
+
+--S 359 of 361
+t0:=1/(x^3*(a+b*sqrt(c+d*x))^2)
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R              3 +-------+    2   4     2     2  3
+--R        2a b x \|d x + c  + b d x  + (b c + a )x
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 361
+r0:=-1/2*a*b*(a^4-10*a^2*b^2*c-15*b^4*c^2)*d^2*atanh(sqrt(c+d*x)/sqrt(c))/_
+   (c^(3/2)*(a^2-b^2*c)^4)+b^4*(5*a^2+b^2*c)*d^2*log(x)/(a^2-b^2*c)^4-_
+   2*b^4*(5*a^2+b^2*c)*d^2*log(a+b*sqrt(c+d*x))/(a^2-b^2*c)^4+1/2*a*b^2*_
+   (a^2+11*b^2*c)*d^2/(c*(a^2-b^2*c)^3*(a+b*sqrt(c+d*x)))+1/2*(-a+b*_
+   sqrt(c+d*x))/((a^2-b^2*c)*x^2*(a+b*sqrt(c+d*x)))-1/2*b*d*(3*a*b*c-_
+   (a^2+2*b^2*c)*sqrt(c+d*x))/(c*(a^2-b^2*c)^2*x*(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R   (2)
+--R               7 2      2 5   2 2 +-+ +-------+          6 2      3 4   2 2 +-+
+--R         ((- 4b c  - 20a b c)d x \|c \|d x + c  + (- 4a b c  - 20a b c)d x \|c )
+--R      *
+--R               +-------+
+--R         log(b\|d x + c  + a)
+--R     + 
+--R                 6 2      3 4     5 2  2 2 +-------+
+--R           (15a b c  + 10a b c - a b )d x \|d x + c
+--R         + 
+--R               2 5 2      4 3     6   2 2
+--R           (15a b c  + 10a b c - a b)d x
+--R      *
+--R                +-------+
+--R               \|d x + c
+--R         atanh(----------)
+--R                   +-+
+--R                  \|c
+--R     + 
+--R              7 2      2 5   2 2            7 3     2 5 2    6         7 4
+--R           (2b c  + 10a b c)d x log(x) + (2b c  - 3a b c  + a b)d x - b c
+--R         + 
+--R             2 5 3     4 3 2    6
+--R           3a b c  - 3a b c  + a b c
+--R      *
+--R          +-+ +-------+
+--R         \|c \|d x + c
+--R     + 
+--R                6 2      3 4   2 2                 6 2      3 4     5 2  2 2
+--R           (2a b c  + 10a b c)d x log(x) + (- 11a b c  + 10a b c + a b )d x
+--R         + 
+--R                  6 3     3 4 2     5 2           6 4     3 4 3     5 2 2    7
+--R           (- 3a b c  + 6a b c  - 3a b c)d x + a b c  - 3a b c  + 3a b c  - a c
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R          9 5     2 7 4      4 5 3     6 3 2     8     2 +-+ +-------+
+--R       (2b c  - 8a b c  + 12a b c  - 8a b c  + 2a b c)x \|c \|d x + c
+--R     + 
+--R            8 5     3 6 4      5 4 3     7 2 2     9   2 +-+
+--R       (2a b c  - 8a b c  + 12a b c  - 8a b c  + 2a c)x \|c
+--R                                                    Type: Expression(Integer)
+--E 360
+
+--S 361 of 361
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 361
+
+)spool
+)lisp (bye)
+
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder20b.input.pamphlet b/src/input/richder20b.input.pamphlet
new file mode 100644
index 0000000..592e44a
--- /dev/null
+++ b/src/input/richder20b.input.pamphlet
@@ -0,0 +1,5051 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input rich20derb.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|y'[x] f[y[x]]|
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder20b.output
+)spool richder20b.output
+)set message test on
+)set message auto off
+)clear all
+
+
+--S 1 of 368
+t0:=x^3/sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 368
+r0:=4/3*(a^2-b^2*c)^2*(7*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(3/2)/(b^8*d^4)-_
+   12/5*a*(7*a^2-3*b^2*c)*(a^2-b^2*c)*(a+b*sqrt(c+d*x))^(5/2)/(b^8*d^4)+_
+   4/7*(35*a^4-30*a^2*b^2*c+3*b^4*c^2)*(a+b*sqrt(c+d*x))^(7/2)/(b^8*d^4)-_
+   20/9*a*(7*a^2-3*b^2*c)*(a+b*sqrt(c+d*x))^(9/2)/(b^8*d^4)+_
+   12/11*(7*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(11/2)/(b^8*d^4)-_
+   28/13*a*(a+b*sqrt(c+d*x))^(13/2)/(b^8*d^4)+_
+   4/15*(a+b*sqrt(c+d*x))^(15/2)/(b^8*d^4)-4*a*(a^2-b^2*c)^3*_
+   sqrt(a+b*sqrt(c+d*x))/(b^8*d^4)
+--R 
+--R
+--R   (2)
+--R                   7 3 3            7          2 5  2 2
+--R             12012b d x  + (- 13104b c + 14112a b )d x
+--R           + 
+--R                    7 2         2 5          4 3             7 3         2 5 2
+--R             (14976b c  - 34176a b c + 17920a b )d x - 19968b c  + 75264a b c
+--R           + 
+--R                     4 3          6
+--R             - 81920a b c + 28672a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R                   6 3 3            6          3 4  2 2
+--R         - 12936a b d x  + (15792a b c - 15680a b )d x
+--R       + 
+--R                    6 2         3 4          5 2               6 3
+--R         (- 22272a b c  + 43520a b c - 21504a b )d x + 69120a b c
+--R       + 
+--R                  3 4 2          5 2          7
+--R         - 187904a b c  + 178176a b c - 57344a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R           8 4
+--R     45045b d
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 368
+t0:=x^2/sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 368
+r0:=4/3*(5*a^4-6*a^2*b^2*c+b^4*c^2)*(a+b*sqrt(c+d*x))^(3/2)/(b^6*d^3)-_
+   8/5*a*(5*a^2-3*b^2*c)*(a+b*sqrt(c+d*x))^(5/2)/(b^6*d^3)+8/7*(5*a^2-_
+   b^2*c)*(a+b*sqrt(c+d*x))^(7/2)/(b^6*d^3)-20/9*a*(a+b*sqrt(c+d*x))^(9/2)/_
+   (b^6*d^3)+4/11*(a+b*sqrt(c+d*x))^(11/2)/(b^6*d^3)-4*a*(a^2-b^2*c)^2*_
+   sqrt(a+b*sqrt(c+d*x))/(b^6*d^3)
+--R 
+--R
+--R   (2)
+--R                  5 2 2           5         2 3            5 2        2 3
+--R             1260b d x  + (- 1440b c + 1600a b )d x + 1920b c  - 4736a b c
+--R           + 
+--R                  4
+--R             2560a b
+--R        *
+--R            +-------+
+--R           \|d x + c
+--R       + 
+--R                  4 2 2           4         3 2              4 2         3 2
+--R         - 1400a b d x  + (1952a b c - 1920a b )d x - 5888a b c  + 10752a b c
+--R       + 
+--R                5
+--R         - 5120a
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R          6 3
+--R     3465b d
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 368
+t0:=x/sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                 x
+--R   (1)  ------------------
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 368
+r0:=4/3*(3*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(3/2)/(b^4*d^2)-_
+   12/5*a*(a+b*sqrt(c+d*x))^(5/2)/(b^4*d^2)+4/7*(a+b*sqrt(c+d*x))^(7/2)/_
+   (b^4*d^2)-4*a*(a^2-b^2*c)*sqrt(a+b*sqrt(c+d*x))/(b^4*d^2)
+--R 
+--R
+--R   (2)
+--R            3         3       2   +-------+        2            2        3
+--R       ((60b d x - 80b c + 96a b)\|d x + c  - 72a b d x + 208a b c - 192a )
+--R    *
+--R        +---------------+
+--R        |  +-------+
+--R       \|b\|d x + c  + a
+--R  /
+--R         4 2
+--R     105b d
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 368
+t0:=1/sqrt(a+b*sqrt(c+d*x))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         |  +-------+
+--R        \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 368
+r0:=4/3*(a+b*sqrt(c+d*x))^(3/2)/(b^2*d)-4*a*sqrt(a+b*sqrt(c+d*x))/(b^2*d)
+--R 
+--R
+--R                            +---------------+
+--R            +-------+       |  +-------+
+--R        (4b\|d x + c  - 8a)\|b\|d x + c  + a
+--R   (2)  -------------------------------------
+--R                           2
+--R                         3b d
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 368
+t0:=1/(x*sqrt(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R          +---------------+
+--R          |  +-------+
+--R        x\|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 368
+r0:=-2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))/sqrt(a-b*sqrt(c))-_
+   2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a+b*sqrt(c)))/sqrt(a+b*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                             +---------------+
+--R           +---------+       |  +-------+
+--R           |  +-+           \|b\|d x + c  + a
+--R       - 2\|b\|c  + a atanh(------------------)
+--R                               +-----------+
+--R                               |    +-+
+--R                              \|- b\|c  + a
+--R     + 
+--R                               +---------------+
+--R           +-----------+       |  +-------+
+--R           |    +-+           \|b\|d x + c  + a
+--R       - 2\|- b\|c  + a atanh(------------------)
+--R                                  +---------+
+--R                                  |  +-+
+--R                                 \|b\|c  + a
+--R  /
+--R      +-----------+ +---------+
+--R      |    +-+      |  +-+
+--R     \|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 368
+t0:=1/(x^2*sqrt(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         2 |  +-------+
+--R        x \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 368
+r0:=-1/2*b*d*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))/(sqrt(c)*_
+   (a-b*sqrt(c))^(3/2))+1/2*b*d*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a+b*_
+   sqrt(c)))/(sqrt(c)*(a+b*sqrt(c))^(3/2))-(a-b*sqrt(c+d*x))*_
+   sqrt(a+b*sqrt(c+d*x))/((a^2-b^2*c)*x)
+--R 
+--R
+--R   (2)
+--R                                                 +---------------+
+--R                               +---------+       |  +-------+
+--R                +-+    2       |  +-+           \|b\|d x + c  + a
+--R       (a b d x\|c  + b c d x)\|b\|c  + a atanh(------------------)
+--R                                                   +-----------+
+--R                                                   |    +-+
+--R                                                  \|- b\|c  + a
+--R     + 
+--R                                                     +---------------+
+--R                                 +-----------+       |  +-------+
+--R                  +-+    2       |    +-+           \|b\|d x + c  + a
+--R       (- a b d x\|c  + b c d x)\|- b\|c  + a atanh(------------------)
+--R                                                        +---------+
+--R                                                        |  +-+
+--R                                                       \|b\|c  + a
+--R     + 
+--R                                 +-----------+ +---------+ +---------------+
+--R               +-------+         |    +-+      |  +-+      |  +-------+
+--R       (- 2b c\|d x + c  + 2a c)\|- b\|c  + a \|b\|c  + a \|b\|d x + c  + a
+--R  /
+--R                     +-----------+ +---------+
+--R        2 2     2    |    +-+      |  +-+
+--R     (2b c  - 2a c)x\|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 368
+t0:=1/(x^3*sqrt(a+b*sqrt(c+d*x)))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R           +---------------+
+--R         3 |  +-------+
+--R        x \|b\|d x + c  + a
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 368
+r0:=1/16*b*d^2*atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a-b*sqrt(c)))*_
+   (2*a-5*b*sqrt(c))/(c^(3/2)*(a-b*sqrt(c))^(5/2))-1/16*b*d^2*_
+   atanh(sqrt(a+b*sqrt(c+d*x))/sqrt(a+b*sqrt(c)))*(2*a+5*b*sqrt(c))/_
+   (c^(3/2)*(a+b*sqrt(c))^(5/2))-1/2*(a-b*sqrt(c+d*x))*sqrt(a+b*_
+   sqrt(c+d*x))/((a^2-b^2*c)*x^2)-1/8*b*d*(6*a*b*c-(a^2+5*b^2*c)*_
+   sqrt(c+d*x))*sqrt(a+b*sqrt(c+d*x))/(c*(a^2-b^2*c)^2*x)
+--R 
+--R
+--R   (2)
+--R                                                             +---------+
+--R                 3      3   2 2 +-+        4 2    2 2   2 2  |  +-+
+--R         ((- 8a b c + 2a b)d x \|c  + (- 5b c  - a b c)d x )\|b\|c  + a
+--R      *
+--R                +---------------+
+--R                |  +-------+
+--R               \|b\|d x + c  + a
+--R         atanh(------------------)
+--R                  +-----------+
+--R                  |    +-+
+--R                 \|- b\|c  + a
+--R     + 
+--R                                                           +-----------+
+--R               3      3   2 2 +-+        4 2    2 2   2 2  |    +-+
+--R         ((8a b c - 2a b)d x \|c  + (- 5b c  - a b c)d x )\|- b\|c  + a
+--R      *
+--R                +---------------+
+--R                |  +-------+
+--R               \|b\|d x + c  + a
+--R         atanh(------------------)
+--R                   +---------+
+--R                   |  +-+
+--R                  \|b\|c  + a
+--R     + 
+--R                3 2     2            3 3     2   2  +-------+        2 2
+--R           ((10b c  + 2a b c)d x - 8b c  + 8a b c )\|d x + c  - 12a b c d x
+--R         + 
+--R               2 3     3 2
+--R           8a b c  - 8a c
+--R      *
+--R          +-----------+ +---------+ +---------------+
+--R          |    +-+      |  +-+      |  +-------+
+--R         \|- b\|c  + a \|b\|c  + a \|b\|d x + c  + a
+--R  /
+--R                                    +-----------+ +---------+
+--R         4 4      2 2 3      4 2  2 |    +-+      |  +-+
+--R     (16b c  - 32a b c  + 16a c )x \|- b\|c  + a \|b\|c  + a
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 368
+t0:=x^3*(a+b*sqrt(c+d*x))^p
+--R 
+--R
+--R         3   +-------+     p
+--R   (1)  x (b\|d x + c  + a)
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 368
+r0:=-2*a*(a^2-b^2*c)^3*(a+b*sqrt(c+d*x))^(1+p)/(b^8*d^4*(1+p))+_
+   2*(a^2-b^2*c)^2*(7*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(2+p)/(b^8*d^4*(2+p))-_
+   6*a*(7*a^2-3*b^2*c)*(a^2-b^2*c)*(a+b*sqrt(c+d*x))^(3+p)/(b^8*d^4*(3+p))+_
+   2*(35*a^4-30*a^2*b^2*c+3*b^4*c^2)*(a+b*sqrt(c+d*x))^(4+p)/(b^8*_
+   d^4*(4+p))-10*a*(7*a^2-3*b^2*c)*(a+b*sqrt(c+d*x))^(5+p)/(b^8*_
+   d^4*(5+p))+6*(7*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(6+p)/(b^8*d^4*(6+p))-_
+   14*a*(a+b*sqrt(c+d*x))^(7+p)/(b^8*d^4*(7+p))+2*(a+b*sqrt(c+_
+   d*x))^(8+p)/(b^8*d^4*(8+p))
+--R 
+--R
+--R   (2)
+--R            7      6       5        4         3         2
+--R         (2p  + 56p  + 644p  + 3920p  + 13538p  + 26264p  + 26136p + 10080)
+--R      *
+--R            +-------+     p + 8
+--R         (b\|d x + c  + a)
+--R     + 
+--R                  7         6          5           4            3            2
+--R           - 14a p  - 406a p  - 4802a p  - 29890a p  - 105056a p  - 206584a p
+--R         + 
+--R           - 207648a p - 80640a
+--R      *
+--R            +-------+     p + 7
+--R         (b\|d x + c  + a)
+--R     + 
+--R                2       2  7          2         2  6           2          2  5
+--R           (- 6b c + 42a )p  + (- 180b c + 1260a )p  + (- 2196b c + 15372a )p
+--R         + 
+--R                    2          2  4            2           2  3
+--R           (- 14040b c + 98280a )p  + (- 50454b c + 353178a )p
+--R         + 
+--R                     2           2  2             2           2           2
+--R           (- 100980b c + 706860a )p  + (- 102864b c + 720048a )p - 40320b c
+--R         + 
+--R                  2
+--R           282240a
+--R      *
+--R            +-------+     p + 6
+--R         (b\|d x + c  + a)
+--R     + 
+--R                 2       3  7          2         3  6            2          3  5
+--R           (30a b c - 70a )p  + (930a b c - 2170a )p  + (11730a b c - 27370a )p
+--R         + 
+--R                    2           3  4             2           3  3
+--R           (77430a b c - 180670a )p  + (286320a b c - 668080a )p
+--R         + 
+--R                     2            3  2             2            3
+--R           (586920a b c - 1369480a )p  + (609120a b c - 1421280a )p
+--R         + 
+--R                    2           3
+--R           241920a b c - 564480a
+--R      *
+--R            +-------+     p + 5
+--R         (b\|d x + c  + a)
+--R     + 
+--R              4 2      2 2       4  7        4 2        2 2         4  6
+--R           (6b c  - 60a b c + 70a )p  + (192b c  - 1920a b c + 2240a )p
+--R         + 
+--R                 4 2         2 2          4  5
+--R           (2508b c  - 25080a b c + 29260a )p
+--R         + 
+--R                  4 2          2 2           4  4
+--R           (17184b c  - 171840a b c + 200480a )p
+--R         + 
+--R                  4 2          2 2           4  3
+--R           (65958b c  - 659580a b c + 769510a )p
+--R         + 
+--R                   4 2           2 2            4  2
+--R           (139872b c  - 1398720a b c + 1631840a )p
+--R         + 
+--R                   4 2           2 2            4           4 2          2 2
+--R           (149256b c  - 1492560a b c + 1741320a )p + 60480b c  - 604800a b c
+--R         + 
+--R                  4
+--R           705600a
+--R      *
+--R            +-------+     p + 4
+--R         (b\|d x + c  + a)
+--R     + 
+--R                   4 2      3 2       5  7
+--R           (- 18a b c  + 60a b c - 42a )p
+--R         + 
+--R                    4 2        3 2         5  6
+--R           (- 594a b c  + 1980a b c - 1386a )p
+--R         + 
+--R                     4 2         3 2          5  5
+--R           (- 8046a b c  + 26820a b c - 18774a )p
+--R         + 
+--R                      4 2          3 2           5  4
+--R           (- 57510a b c  + 191700a b c - 134190a )p
+--R         + 
+--R                       4 2          3 2           5  3
+--R           (- 231552a b c  + 771840a b c - 540288a )p
+--R         + 
+--R                       4 2           3 2            5  2
+--R           (- 516456a b c  + 1721520a b c - 1205064a )p
+--R         + 
+--R                       4 2           3 2            5              4 2
+--R           (- 576864a b c  + 1922880a b c - 1346016a )p - 241920a b c
+--R         + 
+--R                  3 2           5
+--R           806400a b c - 564480a
+--R      *
+--R            +-------+     p + 3
+--R         (b\|d x + c  + a)
+--R     + 
+--R                6 3      2 4 2      4 2       6  7
+--R           (- 2b c  + 18a b c  - 30a b c + 14a )p
+--R         + 
+--R                 6 3       2 4 2        4 2        6  6
+--R           (- 68b c  + 612a b c  - 1020a b c + 476a )p
+--R         + 
+--R                  6 3        2 4 2         4 2         6  5
+--R           (- 956b c  + 8604a b c  - 14340a b c + 6692a )p
+--R         + 
+--R                   6 3         2 4 2          4 2          6  4
+--R           (- 7160b c  + 64440a b c  - 107400a b c + 50120a )p
+--R         + 
+--R                    6 3          2 4 2          4 2           6  3
+--R           (- 30578b c  + 275202a b c  - 458670a b c + 214046a )p
+--R         + 
+--R                    6 3          2 4 2           4 2           6  2
+--R           (- 73412b c  + 660708a b c  - 1101180a b c + 513884a )p
+--R         + 
+--R                    6 3          2 4 2           4 2           6           6 3
+--R           (- 89424b c  + 804816a b c  - 1341360a b c + 625968a )p - 40320b c
+--R         + 
+--R                  2 4 2          4 2           6
+--R           362880a b c  - 604800a b c + 282240a
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R                6 3     3 4 2     5 2      7  7
+--R           (2a b c  - 6a b c  + 6a b c - 2a )p
+--R         + 
+--R                 6 3       3 4 2       5 2       7  6
+--R           (70a b c  - 210a b c  + 210a b c - 70a )p
+--R         + 
+--R                   6 3        3 4 2        5 2         7  5
+--R           (1022a b c  - 3066a b c  + 3066a b c - 1022a )p
+--R         + 
+--R                   6 3         3 4 2         5 2         7  4
+--R           (8050a b c  - 24150a b c  + 24150a b c - 8050a )p
+--R         + 
+--R                    6 3          3 4 2          5 2          7  3
+--R           (36848a b c  - 110544a b c  + 110544a b c - 36848a )p
+--R         + 
+--R                    6 3          3 4 2          5 2          7  2
+--R           (97720a b c  - 293160a b c  + 293160a b c - 97720a )p
+--R         + 
+--R                     6 3          3 4 2          5 2           7             6 3
+--R           (138528a b c  - 415584a b c  + 415584a b c - 138528a )p + 80640a b c
+--R         + 
+--R                    3 4 2          5 2          7
+--R           - 241920a b c  + 241920a b c - 80640a
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R  /
+--R        8 4 8      8 4 7       8 4 6        8 4 5         8 4 4         8 4 3
+--R       b d p  + 36b d p  + 546b d p  + 4536b d p  + 22449b d p  + 67284b d p
+--R     + 
+--R              8 4 2          8 4          8 4
+--R       118124b d p  + 109584b d p + 40320b d
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 368
+t0:=x^2*(a+b*sqrt(c+d*x))^p
+--R 
+--R
+--R         2   +-------+     p
+--R   (1)  x (b\|d x + c  + a)
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 368
+r0:=-2*a*(a^2-b^2*c)^2*(a+b*sqrt(c+d*x))^(1+p)/(b^6*d^3*(1+p))+2*(5*a^4-_
+   6*a^2*b^2*c+b^4*c^2)*(a+b*sqrt(c+d*x))^(2+p)/(b^6*d^3*(2+p))-_
+   4*a*(5*a^2-3*b^2*c)*(a+b*sqrt(c+d*x))^(3+p)/(b^6*d^3*(3+p))+_
+   4*(5*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(4+p)/(b^6*d^3*(4+p))-_
+   10*a*(a+b*sqrt(c+d*x))^(5+p)/(b^6*d^3*(5+p))+2*(a+b*_
+   sqrt(c+d*x))^(6+p)/(b^6*d^3*(6+p))
+--R 
+--R
+--R   (2)
+--R          5      4       3       2                 +-------+     p + 6
+--R       (2p  + 30p  + 170p  + 450p  + 548p + 240)(b\|d x + c  + a)
+--R     + 
+--R                 5         4         3          2
+--R         (- 10a p  - 160a p  - 950a p  - 2600a p  - 3240a p - 1440a)
+--R      *
+--R            +-------+     p + 5
+--R         (b\|d x + c  + a)
+--R     + 
+--R                2       2  5         2        2  4          2         2  3
+--R           (- 4b c + 20a )p  + (- 68b c + 340a )p  + (- 428b c + 2140a )p
+--R         + 
+--R                   2         2  2           2         2         2         2
+--R           (- 1228b c + 6140a )p  + (- 1584b c + 7920a )p - 720b c + 3600a
+--R      *
+--R            +-------+     p + 4
+--R         (b\|d x + c  + a)
+--R     + 
+--R                 2       3  5          2        3  4           2         3  3
+--R           (12a b c - 20a )p  + (216a b c - 360a )p  + (1452a b c - 2420a )p
+--R         + 
+--R                   2         3  2           2          3            2         3
+--R           (4464a b c - 7440a )p  + (6096a b c - 10160a )p + 2880a b c - 4800a
+--R      *
+--R            +-------+     p + 3
+--R         (b\|d x + c  + a)
+--R     + 
+--R              4 2      2 2       4  5       4 2       2 2        4  4
+--R           (2b c  - 12a b c + 10a )p  + (38b c  - 228a b c + 190a )p
+--R         + 
+--R                4 2        2 2         4  3        4 2        2 2         4  2
+--R           (274b c  - 1644a b c + 1370a )p  + (922b c  - 5532a b c + 4610a )p
+--R         + 
+--R                 4 2        2 2         4         4 2        2 2         4
+--R           (1404b c  - 8424a b c + 7020a )p + 720b c  - 4320a b c + 3600a
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R                  4 2     3 2      5  5           4 2      3 2       5  4
+--R           (- 2a b c  + 4a b c - 2a )p  + (- 40a b c  + 80a b c - 40a )p
+--R         + 
+--R                    4 2       3 2        5  3
+--R           (- 310a b c  + 620a b c - 310a )p
+--R         + 
+--R                     4 2        3 2         5  2
+--R           (- 1160a b c  + 2320a b c - 1160a )p
+--R         + 
+--R                   4 2        3 2         5            4 2        3 2         5
+--R         (- 2088a b c  + 4176a b c - 2088a )p - 1440a b c  + 2880a b c - 1440a
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R  /
+--R        6 3 6      6 3 5       6 3 4       6 3 3        6 3 2        6 3
+--R       b d p  + 21b d p  + 175b d p  + 735b d p  + 1624b d p  + 1764b d p
+--R     + 
+--R           6 3
+--R       720b d
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 368
+t0:=x*(a+b*sqrt(c+d*x))^p
+--R 
+--R
+--R             +-------+     p
+--R   (1)  x (b\|d x + c  + a)
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 368
+r0:=-2*a*(a^2-b^2*c)*(a+b*sqrt(c+d*x))^(1+p)/(b^4*d^2*(1+p))+_
+   2*(3*a^2-b^2*c)*(a+b*sqrt(c+d*x))^(2+p)/(b^4*d^2*(2+p))-_
+   6*a*(a+b*sqrt(c+d*x))^(3+p)/(b^4*d^2*(3+p))+2*(a+b*sqrt(c+d*x))^(4+p)/_
+   (b^4*d^2*(4+p))
+--R 
+--R
+--R   (2)
+--R          3      2               +-------+     p + 4
+--R       (2p  + 12p  + 22p + 12)(b\|d x + c  + a)
+--R     + 
+--R              3        2                  +-------+     p + 3
+--R       (- 6a p  - 42a p  - 84a p - 48a)(b\|d x + c  + a)
+--R     + 
+--R                2      2  3         2       2  2         2        2        2
+--R           (- 2b c + 6a )p  + (- 16b c + 48a )p  + (- 38b c + 114a )p - 24b c
+--R         + 
+--R              2
+--R           72a
+--R      *
+--R            +-------+     p + 2
+--R         (b\|d x + c  + a)
+--R     + 
+--R                2      3  3         2       3  2         2       3          2
+--R           (2a b c - 2a )p  + (18a b c - 18a )p  + (52a b c - 52a )p + 48a b c
+--R         + 
+--R                3
+--R           - 48a
+--R      *
+--R            +-------+     p + 1
+--R         (b\|d x + c  + a)
+--R  /
+--R      4 2 4      4 2 3      4 2 2      4 2       4 2
+--R     b d p  + 10b d p  + 35b d p  + 50b d p + 24b d
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 368
+t0:=(a+b*sqrt(c+d*x))^p
+--R 
+--R
+--R           +-------+     p
+--R   (1)  (b\|d x + c  + a)
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 368
+r0:=-2*a*(a+b*sqrt(c+d*x))^(1+p)/(b^2*d*(1+p))+_
+   2*(a+b*sqrt(c+d*x))^(2+p)/(b^2*d*(2+p))
+--R 
+--R
+--R                   +-------+     p + 2                   +-------+     p + 1
+--R        (2p + 2)(b\|d x + c  + a)      + (- 2a p - 4a)(b\|d x + c  + a)
+--R   (2)  --------------------------------------------------------------------
+--R                                2   2     2        2
+--R                               b d p  + 3b d p + 2b d
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 368
+t0:=(a+b*sqrt(c+d*x))^p/x
+--R 
+--R
+--R           +-------+     p
+--R        (b\|d x + c  + a)
+--R   (1)  ------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 368
+--r0:=-hypergeometric(1,1+p,2+p,(a+b*sqrt(c+d*x))/(a-b*sqrt(c)))*_
+--   (a+b*sqrt(c+d*x))^(1+p)/((1+p)*(a-b*sqrt(c)))-_
+--   hypergeometric(1,1+p,2+p,(a+b*sqrt(c+d*x))/(a+b*sqrt(c)))*_
+--   (a+b*sqrt(c+d*x))^(1+p)/((1+p)*(a+b*sqrt(c)))
+--E 35
+
+--S 36 of 368
+--d0:=normalize(t0-D(r0,x))
+--E 36
+
+)clear all
+
+--S 37 of 368
+t0:=(a+b*(c*x)^n)^(5/2)/x
+--R 
+--R
+--R                                         +------------+
+--R          2      n 2             n    2  |       n
+--R        (b ((c x) )  + 2a b (c x)  + a )\|b (c x)  + a
+--R   (1)  -----------------------------------------------
+--R                               x
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 368
+r0:=2/3*a*(a+b*(c*x)^n)^(3/2)/n+2/5*(a+b*(c*x)^n)^(5/2)/n-_
+   2*a^(5/2)*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))/n+2*a^2*sqrt(a+b*(c*x)^n)/n
+--R 
+--R
+--R   (2)
+--R                        +------------+
+--R                        |       n
+--R            2 +-+      \|b (c x)  + a
+--R       - 30a \|a atanh(---------------)
+--R                              +-+
+--R                             \|a
+--R     + 
+--R                                            +------------+
+--R          2      n 2              n      2  |       n
+--R       (6b ((c x) )  + 22a b (c x)  + 46a )\|b (c x)  + a
+--R  /
+--R     15n
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 368
+t0:=(a+b*(c*x)^n)^(3/2)/x
+--R 
+--R
+--R                       +------------+
+--R                n      |       n
+--R        (b (c x)  + a)\|b (c x)  + a
+--R   (1)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 368
+r0:=2/3*(a+b*(c*x)^n)^(3/2)/n-2*a^(3/2)*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))/n+_
+   2*a*sqrt(a+b*(c*x)^n)/n
+--R 
+--R
+--R                       +------------+
+--R                       |       n                          +------------+
+--R             +-+      \|b (c x)  + a              n       |       n
+--R        - 6a\|a atanh(---------------) + (2b (c x)  + 8a)\|b (c x)  + a
+--R                             +-+
+--R                            \|a
+--R   (2)  ----------------------------------------------------------------
+--R                                       3n
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 368
+t0:=(a+b*(c*x)^n)^(1/2)/x
+--R 
+--R
+--R         +------------+
+--R         |       n
+--R        \|b (c x)  + a
+--R   (1)  ---------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 368
+r0:=-2*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))*sqrt(a)/n+2*sqrt(a+b*(c*x)^n)/n
+--R 
+--R
+--R                      +------------+
+--R                      |       n           +------------+
+--R            +-+      \|b (c x)  + a       |       n
+--R        - 2\|a atanh(---------------) + 2\|b (c x)  + a
+--R                            +-+
+--R                           \|a
+--R   (2)  ------------------------------------------------
+--R                                n
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 368
+t0:=1/(x*(a+b*(c*x)^n)^(1/2))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R          +------------+
+--R          |       n
+--R        x\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 368
+r0:=-2*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))/(n*sqrt(a))
+--R 
+--R
+--R                  +------------+
+--R                  |       n
+--R                 \|b (c x)  + a
+--R          2atanh(---------------)
+--R                        +-+
+--R                       \|a
+--R   (2)  - -----------------------
+--R                     +-+
+--R                   n\|a
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 368
+t0:=1/(x*(a+b*(c*x)^n)^(3/2))
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R                           +------------+
+--R                  n        |       n
+--R        (b x (c x)  + a x)\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 368
+r0:=-2*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))/(a^(3/2)*n)+2/(a*n*sqrt(a+b*(c*x)^n))
+--R 
+--R
+--R                                 +------------+
+--R            +------------+       |       n
+--R            |       n           \|b (c x)  + a       +-+
+--R        - 2\|b (c x)  + a atanh(---------------) + 2\|a
+--R                                       +-+
+--R                                      \|a
+--R   (2)  ------------------------------------------------
+--R                             +------------+
+--R                         +-+ |       n
+--R                     a n\|a \|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 368
+t0:=1/(x*(a+b*(c*x)^n)^(5/2))
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R                                              +------------+
+--R          2        n 2               n    2   |       n
+--R        (b x ((c x) )  + 2a b x (c x)  + a x)\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 368
+r0:=2/3/(a*n*(a+b*(c*x)^n)^(3/2))-2*atanh(sqrt(a+b*(c*x)^n)/sqrt(a))/_
+   (a^(5/2)*n)+2/(a^2*n*sqrt(a+b*(c*x)^n))
+--R 
+--R
+--R   (2)
+--R                                               +------------+
+--R                          +------------+       |       n
+--R                  n       |       n           \|b (c x)  + a
+--R       (- 6b (c x)  - 6a)\|b (c x)  + a atanh(---------------)
+--R                                                     +-+
+--R                                                    \|a
+--R     + 
+--R                n       +-+
+--R       (6b (c x)  + 8a)\|a
+--R  /
+--R                                +------------+
+--R        2         n     3   +-+ |       n
+--R     (3a b n (c x)  + 3a n)\|a \|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 368
+t0:=(-a+b*(c*x)^n)^(5/2)/x
+--R 
+--R
+--R                                         +------------+
+--R          2      n 2             n    2  |       n
+--R        (b ((c x) )  - 2a b (c x)  + a )\|b (c x)  - a
+--R   (1)  -----------------------------------------------
+--R                               x
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 368
+r0:=-2/3*a*(-a+b*(c*x)^n)^(3/2)/n+2/5*(-a+b*(c*x)^n)^(5/2)/n-_
+   2*a^(5/2)*atan(sqrt(-a+b*(c*x)^n)/sqrt(a))/n+2*a^2*sqrt(-a+b*(c*x)^n)/n
+--R 
+--R
+--R   (2)
+--R                       +------------+
+--R                       |       n
+--R            2 +-+     \|b (c x)  - a
+--R       - 30a \|a atan(---------------)
+--R                             +-+
+--R                            \|a
+--R     + 
+--R                                            +------------+
+--R          2      n 2              n      2  |       n
+--R       (6b ((c x) )  - 22a b (c x)  + 46a )\|b (c x)  - a
+--R  /
+--R     15n
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 368
+t0:=(-a+b*(c*x)^n)^(3/2)/x
+--R 
+--R
+--R                       +------------+
+--R                n      |       n
+--R        (b (c x)  - a)\|b (c x)  - a
+--R   (1)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 368
+r0:=2/3*(-a+b*(c*x)^n)^(3/2)/n+2*a^(3/2)*_
+   atan(sqrt(-a+b*(c*x)^n)/sqrt(a))/n-2*a*sqrt(-a+b*(c*x)^n)/n
+--R 
+--R
+--R                    +------------+
+--R                    |       n                          +------------+
+--R           +-+     \|b (c x)  - a              n       |       n
+--R        6a\|a atan(---------------) + (2b (c x)  - 8a)\|b (c x)  - a
+--R                          +-+
+--R                         \|a
+--R   (2)  -------------------------------------------------------------
+--R                                      3n
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 368
+t0:=(-a+b*(c*x)^n)^(1/2)/x
+--R 
+--R
+--R         +------------+
+--R         |       n
+--R        \|b (c x)  - a
+--R   (1)  ---------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 368
+r0:=-2*atan(sqrt(-a+b*(c*x)^n)/sqrt(a))*sqrt(a)/n+2*sqrt(-a+b*(c*x)^n)/n
+--R 
+--R
+--R                     +------------+
+--R                     |       n           +------------+
+--R            +-+     \|b (c x)  - a       |       n
+--R        - 2\|a atan(---------------) + 2\|b (c x)  - a
+--R                           +-+
+--R                          \|a
+--R   (2)  -----------------------------------------------
+--R                               n
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 368
+t0:=1/(x*(-a+b*(c*x)^n)^(1/2))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R          +------------+
+--R          |       n
+--R        x\|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 368
+r0:=2*atan(sqrt(-a+b*(c*x)^n)/sqrt(a))/(n*sqrt(a))
+--R 
+--R
+--R               +------------+
+--R               |       n
+--R              \|b (c x)  - a
+--R        2atan(---------------)
+--R                     +-+
+--R                    \|a
+--R   (2)  ----------------------
+--R                   +-+
+--R                 n\|a
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 368
+t0:=1/(x*(-a+b*(c*x)^n)^(3/2))
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R                           +------------+
+--R                  n        |       n
+--R        (b x (c x)  - a x)\|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 368
+r0:=-2*atan(sqrt(-a+b*(c*x)^n)/sqrt(a))/(a^(3/2)*n)+(-2)/(a*n*_
+   sqrt(-a+b*(c*x)^n))
+--R 
+--R
+--R                                +------------+
+--R            +------------+      |       n
+--R            |       n          \|b (c x)  - a       +-+
+--R        - 2\|b (c x)  - a atan(---------------) - 2\|a
+--R                                      +-+
+--R                                     \|a
+--R   (2)  -----------------------------------------------
+--R                             +------------+
+--R                         +-+ |       n
+--R                     a n\|a \|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 368
+t0:=1/(x*(-a+b*(c*x)^n)^(5/2))
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R                                              +------------+
+--R          2        n 2               n    2   |       n
+--R        (b x ((c x) )  - 2a b x (c x)  + a x)\|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 368
+r0:=(-2/3)/(a*n*(-a+b*(c*x)^n)^(3/2))+2*atan(sqrt(-a+b*(c*x)^n)/_
+   sqrt(a))/(a^(5/2)*n)+2/(a^2*n*sqrt(-a+b*(c*x)^n))
+--R 
+--R
+--R   (2)
+--R                                        +------------+
+--R                    +------------+      |       n
+--R            n       |       n          \|b (c x)  - a              n       +-+
+--R   (6b (c x)  - 6a)\|b (c x)  - a atan(---------------) + (6b (c x)  - 8a)\|a
+--R                                              +-+
+--R                                             \|a
+--R   ---------------------------------------------------------------------------
+--R                                               +------------+
+--R                       2         n     3   +-+ |       n
+--R                    (3a b n (c x)  - 3a n)\|a \|b (c x)  - a
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 368
+t0:=1/(x*sqrt(a+b*x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R          +-------+
+--R        x\|b x + a
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 368
+r0:=-2*atanh(sqrt(a+b*x)/sqrt(a))/sqrt(a)
+--R 
+--R
+--R                  +-------+
+--R                 \|b x + a
+--R          2atanh(----------)
+--R                     +-+
+--R                    \|a
+--R   (2)  - ------------------
+--R                  +-+
+--R                 \|a
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 368
+t0:=1/(x*sqrt(a+b*(c*x)^m))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R          +------------+
+--R          |       m
+--R        x\|b (c x)  + a
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 368
+r0:=-2*atanh(sqrt(a+b*(c*x)^m)/sqrt(a))/(m*sqrt(a))
+--R 
+--R
+--R                  +------------+
+--R                  |       m
+--R                 \|b (c x)  + a
+--R          2atanh(---------------)
+--R                        +-+
+--R                       \|a
+--R   (2)  - -----------------------
+--R                     +-+
+--R                   m\|a
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 368
+t0:=1/(x*sqrt(a+b*(c*(d*x)^m)^n))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R          +-----------------+
+--R          |          m n
+--R        x\|b (c (d x) )  + a
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 368
+r0:=-2*atanh(sqrt(a+b*(c*(d*x)^m)^n)/sqrt(a))/(m*n*sqrt(a))
+--R 
+--R
+--R                  +-----------------+
+--R                  |          m n
+--R                 \|b (c (d x) )  + a
+--R          2atanh(--------------------)
+--R                          +-+
+--R                         \|a
+--R   (2)  - ----------------------------
+--R                         +-+
+--R                     m n\|a
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 368
+t0:=1/(x*sqrt(a+b*(c*(d*(e*x)^m)^n)^p))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R          +----------------------+
+--R          |             m n p
+--R        x\|b (c (d (e x) ) )  + a
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 368
+r0:=-2*atanh(sqrt(a+b*(c*(d*(e*x)^m)^n)^p)/sqrt(a))/(m*n*p*sqrt(a))
+--R 
+--R
+--R                  +----------------------+
+--R                  |             m n p
+--R                 \|b (c (d (e x) ) )  + a
+--R          2atanh(-------------------------)
+--R                             +-+
+--R                            \|a
+--R   (2)  - ---------------------------------
+--R                            +-+
+--R                      m n p\|a
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 368
+t0:=1/(x*sqrt(a+b*(c*(d*(e*(f*x)^m)^n)^p)^q))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R          +---------------------------+
+--R          |                m n p q
+--R        x\|b (c (d (e (f x) ) ) )  + a
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 368
+r0:=-2*atanh(sqrt(a+b*(c*(d*(e*(f*x)^m)^n)^p)^q)/sqrt(a))/(m*n*p*q*sqrt(a))
+--R 
+--R
+--R                  +---------------------------+
+--R                  |                m n p q
+--R                 \|b (c (d (e (f x) ) ) )  + a
+--R          2atanh(------------------------------)
+--R                               +-+
+--R                              \|a
+--R   (2)  - --------------------------------------
+--R                                +-+
+--R                        m n p q\|a
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 368
+t0:=(-1+x^2)^3*sqrt(-1+1/x^2)/x
+--R 
+--R
+--R                             +--------+
+--R                             |   2
+--R          6     4     2      |- x  + 1
+--R        (x  - 3x  + 3x  - 1) |--------
+--R                             |    2
+--R                            \|   x
+--R   (1)  -------------------------------
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 368
+r0:=-35/48*(-1+1/x^2)^(3/2)*x^2-7/24*(-1+1/x^2)^(5/2)*x^4-_
+   1/6*(-1+1/x^2)^(7/2)*x^6-35/16*atan(sqrt(-1+1/x^2))+35/16*sqrt(-1+1/x^2)
+--R 
+--R
+--R                   +--------+                             +--------+
+--R                   |   2                                  |   2
+--R                   |- x  + 1        6      4      2       |- x  + 1
+--R        - 105atan( |-------- ) + (8x  - 38x  + 87x  + 48) |--------
+--R                   |    2                                 |    2
+--R                  \|   x                                 \|   x
+--R   (2)  ------------------------------------------------------------
+--R                                     48
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 368
+t0:=(-1+x^2)^2*sqrt(-1+1/x^2)/x
+--R 
+--R
+--R                       +--------+
+--R                       |   2
+--R          4     2      |- x  + 1
+--R        (x  - 2x  + 1) |--------
+--R                       |    2
+--R                      \|   x
+--R   (1)  -------------------------
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 368
+r0:=5/8*(-1+1/x^2)^(3/2)*x^2+1/4*(-1+1/x^2)^(5/2)*x^4+_
+   15/8*atan(sqrt(-1+1/x^2))-15/8*sqrt(-1+1/x^2)
+--R 
+--R
+--R                +--------+                    +--------+
+--R                |   2                         |   2
+--R                |- x  + 1        4     2      |- x  + 1
+--R        15atan( |-------- ) + (2x  - 9x  - 8) |--------
+--R                |    2                        |    2
+--R               \|   x                        \|   x
+--R   (2)  ------------------------------------------------
+--R                                8
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 368
+t0:=(-1+x^2)*sqrt(-1+1/x^2)/x
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R          2      |- x  + 1
+--R        (x  - 1) |--------
+--R                 |    2
+--R                \|   x
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 368
+r0:=-1/2*(-1+1/x^2)^(3/2)*x^2-3/2*atan(sqrt(-1+1/x^2))+3/2*sqrt(-1+1/x^2)
+--R 
+--R
+--R                 +--------+             +--------+
+--R                 |   2                  |   2
+--R                 |- x  + 1       2      |- x  + 1
+--R        - 3atan( |-------- ) + (x  + 2) |--------
+--R                 |    2                 |    2
+--R                \|   x                 \|   x
+--R   (2)  ------------------------------------------
+--R                             2
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 368
+t0:=sqrt(-1+1/x^2)/(x*(-1+x^2))
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R         |- x  + 1
+--R         |--------
+--R         |    2
+--R        \|   x
+--R   (1)  -----------
+--R            3
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 368
+r0:=sqrt(-1+1/x^2)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R         |- x  + 1
+--R   (2)   |--------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 368
+t0:=sqrt(-1+1/x^2)/(x*(-1+x^2)^2)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R          |--------
+--R          |    2
+--R         \|   x
+--R   (1)  ------------
+--R         5     3
+--R        x  - 2x  + x
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 368
+r0:=1/sqrt(-1+1/x^2)-sqrt(-1+1/x^2)
+--R 
+--R
+--R             2
+--R           2x  - 1
+--R   (2)  -------------
+--R           +--------+
+--R           |   2
+--R         2 |- x  + 1
+--R        x  |--------
+--R           |    2
+--R          \|   x
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 368
+t0:=sqrt(-1+1/x^2)/(x*(-1+x^2)^3)
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R             |- x  + 1
+--R             |--------
+--R             |    2
+--R            \|   x
+--R   (1)  ------------------
+--R         7     5     3
+--R        x  - 3x  + 3x  - x
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 368
+r0:=(-1/3)/(-1+1/x^2)^(3/2)+(-2)/sqrt(-1+1/x^2)+sqrt(-1+1/x^2)
+--R 
+--R
+--R               4      2
+--R           - 8x  + 12x  - 3
+--R   (2)  ----------------------
+--R                    +--------+
+--R                    |   2
+--R           4     2  |- x  + 1
+--R        (3x  - 3x ) |--------
+--R                    |    2
+--R                   \|   x
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 368
+t0:=x*sqrt(1+1/x^2)/(1+x^2)^2
+--R 
+--R
+--R           +------+
+--R           | 2
+--R           |x  + 1
+--R         x |------
+--R           |   2
+--R          \|  x
+--R   (1)  ------------
+--R         4     2
+--R        x  + 2x  + 1
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 368
+r0:=1/sqrt(1+1/x^2)
+--R 
+--R
+--R            1
+--R   (2)  ---------
+--R         +------+
+--R         | 2
+--R         |x  + 1
+--R         |------
+--R         |   2
+--R        \|  x
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 368
+t0:=1/(x*(1+x^2)*sqrt(1+1/x^2))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R                 +------+
+--R                 | 2
+--R          3      |x  + 1
+--R        (x  + x) |------
+--R                 |   2
+--R                \|  x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 368
+r0:=1/sqrt(1+1/x^2)
+--R 
+--R
+--R            1
+--R   (2)  ---------
+--R         +------+
+--R         | 2
+--R         |x  + 1
+--R         |------
+--R         |   2
+--R        \|  x
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 368
+t0:=x/(a+b*x^2+sqrt(a+b*x^2))
+--R 
+--R
+--R                   x
+--R   (1)  ----------------------
+--R         +--------+
+--R         |   2           2
+--R        \|b x  + a  + b x  + a
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 368
+r0:=log(1+sqrt(a+b*x^2))/b
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R        log(\|b x  + a  + 1)
+--R   (2)  --------------------
+--R                  b
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 368
+t0:=x/(x^2-(x^2)^(1/3))
+--R 
+--R
+--R               x
+--R   (1)  - ----------
+--R           +--+
+--R          3| 2     2
+--R          \|x   - x
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 368
+r0:=3/4*log(1-(x^2)^(2/3))
+--R 
+--R
+--R                +--+2
+--R               3| 2
+--R        3log(- \|x    + 1)
+--R   (2)  ------------------
+--R                 4
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 368
+t0:=x*(1+x^2)^3*sqrt(2+2*x^2+x^4)
+--R 
+--R
+--R                             +------------+
+--R          7     5     3      | 4     2
+--R   (1)  (x  + 3x  + 3x  + x)\|x  + 2x  + 2
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 368
+r0:=-1/15*(2+2*x^2+x^4)^(3/2)+1/10*(1+x^2)^2*(2+2*x^2+x^4)^(3/2)
+--R 
+--R
+--R                                       +------------+
+--R           8      6      4      2      | 4     2
+--R        (3x  + 12x  + 19x  + 14x  + 2)\|x  + 2x  + 2
+--R   (2)  ---------------------------------------------
+--R                              30
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 368
+t0:=x*sqrt((1-x^2)/(1+x^2))
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R          |- x  + 1
+--R   (1)  x |--------
+--R          |  2
+--R         \| x  + 1
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 368
+r0a:=-atan(sqrt((1-x^2)/(1+x^2)))+1/2*(1+x^2)*sqrt((1-x^2)/(1+x^2))
+--R 
+--R
+--R                 +--------+             +--------+
+--R                 |   2                  |   2
+--R                 |- x  + 1       2      |- x  + 1
+--R        - 2atan( |-------- ) + (x  + 1) |--------
+--R                 |  2                   |  2
+--R                \| x  + 1              \| x  + 1
+--R   (2)  ------------------------------------------
+--R                             2
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 368
+r0b:=-atan(sqrt((1-x^2)/(1+x^2)))+sqrt((1-x^2)/(1+x^2))/(1+(1-x^2)/(1+x^2))
+--R 
+--R
+--R                 +--------+             +--------+
+--R                 |   2                  |   2
+--R                 |- x  + 1       2      |- x  + 1
+--R        - 2atan( |-------- ) + (x  + 1) |--------
+--R                 |  2                   |  2
+--R                \| x  + 1              \| x  + 1
+--R   (3)  ------------------------------------------
+--R                             2
+--R                                                    Type: Expression(Integer)
+--E 123
+
+--S 124 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 125
+
+)clear all
+
+--S 126 of 368
+t0:=x*sqrt((5-7*x^2)/(7+5*x^2))
+--R 
+--R
+--R          +---------+
+--R          |    2
+--R          |- 7x  + 5
+--R   (1)  x |---------
+--R          |   2
+--R         \| 5x  + 7
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 368
+r0a:=-37/5*atan(sqrt(5/7)*sqrt((5-7*x^2)/(7+5*x^2)))/sqrt(35)+_
+   1/10*(7+5*x^2)*sqrt((5-7*x^2)/(7+5*x^2))
+--R 
+--R
+--R                      +---------+
+--R                      |    2
+--R                  +-+ |- 7x  + 5
+--R                 \|5  |---------                    +---------+
+--R                      |   2                         |    2
+--R                     \| 5x  + 7         2      +--+ |- 7x  + 5
+--R        - 74atan(----------------) + (5x  + 7)\|35  |---------
+--R                        +-+                         |   2
+--R                       \|7                         \| 5x  + 7
+--R   (2)  -------------------------------------------------------
+--R                                   +--+
+--R                                10\|35
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 368
+r0b:=-37/5*atan(sqrt(5/7)*sqrt((5-7*x^2)/(7+5*x^2)))/sqrt(35)+_
+   37/5*sqrt((5-7*x^2)/(7+5*x^2))/(7+5*(5-7*x^2)/(7+5*x^2))
+--R 
+--R
+--R                      +---------+
+--R                      |    2
+--R                  +-+ |- 7x  + 5
+--R                 \|5  |---------                    +---------+
+--R                      |   2                         |    2
+--R                     \| 5x  + 7         2      +--+ |- 7x  + 5
+--R        - 74atan(----------------) + (5x  + 7)\|35  |---------
+--R                        +-+                         |   2
+--R                       \|7                         \| 5x  + 7
+--R   (3)  -------------------------------------------------------
+--R                                   +--+
+--R                                10\|35
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R              +-+ +-+ +--+
+--R        - 37x\|5 \|7 \|35  + 1295x
+--R   (4)  --------------------------
+--R                       +---------+
+--R                       |    2
+--R             2         |- 7x  + 5
+--R        (875x  + 1225) |---------
+--R                       |   2
+--R                      \| 5x  + 7
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R              +-+ +-+ +--+
+--R        - 37x\|5 \|7 \|35  + 1295x
+--R   (5)  --------------------------
+--R                       +---------+
+--R                       |    2
+--R             2         |- 7x  + 5
+--R        (875x  + 1225) |---------
+--R                       |   2
+--R                      \| 5x  + 7
+--R                                                    Type: Expression(Integer)
+--E 130
+
+)clear all
+
+--S 131 of 368
+t0:=x^2*sqrt((1-x^3)/(1+x^3))
+--R 
+--R
+--R           +--------+
+--R           |   3
+--R         2 |- x  + 1
+--R   (1)  x  |--------
+--R           |  3
+--R          \| x  + 1
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 368
+r0a:=-2/3*atan(sqrt((1-x^3)/(1+x^3)))+1/3*(1+x^3)*sqrt((1-x^3)/(1+x^3))
+--R 
+--R
+--R                 +--------+             +--------+
+--R                 |   3                  |   3
+--R                 |- x  + 1       3      |- x  + 1
+--R        - 2atan( |-------- ) + (x  + 1) |--------
+--R                 |  3                   |  3
+--R                \| x  + 1              \| x  + 1
+--R   (2)  ------------------------------------------
+--R                             3
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 368
+r0b:=-2/3*atan(sqrt((1-x^3)/(1+x^3)))+2/3*sqrt((1-x^3)/(1+x^3))/_
+   (1+(1-x^3)/(1+x^3))
+--R 
+--R
+--R                 +--------+             +--------+
+--R                 |   3                  |   3
+--R                 |- x  + 1       3      |- x  + 1
+--R        - 2atan( |-------- ) + (x  + 1) |--------
+--R                 |  3                   |  3
+--R                \| x  + 1              \| x  + 1
+--R   (3)  ------------------------------------------
+--R                             3
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 368
+t0:=x^5*(1+x^9)^2*sqrt(1-x^3)
+--R 
+--R
+--R                          +--------+
+--R          23     14    5  |   3
+--R   (1)  (x   + 2x   + x )\|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 368
+r0:=-8/9*(1-x^3)^(3/2)+32/15*(1-x^3)^(5/2)-22/7*(1-x^3)^(7/2)+_
+   86/27*(1-x^3)^(9/2)-74/33*(1-x^3)^(11/2)+14/13*(1-x^3)^(13/2)-_
+   14/45*(1-x^3)^(15/2)+2/51*(1-x^3)^(17/2)
+--R 
+--R
+--R   (2)
+--R               24        21        18          15         12         9
+--R         90090x   - 6006x   - 6468x   + 271404x   - 38780x   - 44320x
+--R       + 
+--R                6          3
+--R         253122x  - 173014x  - 346028
+--R    *
+--R        +--------+
+--R        |   3
+--R       \|- x  + 1
+--R  /
+--R     2297295
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 368
+t0:=x^8*sqrt((1-x^3)/(1+x^3))
+--R 
+--R
+--R           +--------+
+--R           |   3
+--R         8 |- x  + 1
+--R   (1)  x  |--------
+--R           |  3
+--R          \| x  + 1
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 368
+r0:=-8/9*((1-x^3)/(1+x^3))^(3/2)/(1+(1-x^3)/(1+x^3))^3+2/3*((1-x^3)/_
+   (1+x^3))^(3/2)/(1+(1-x^3)/(1+x^3))^2-1/3*atan(sqrt((1-x^3)/(1+x^3)))+_
+   1/3*sqrt((1-x^3)/(1+x^3))/(1+(1-x^3)/(1+x^3))
+--R 
+--R
+--R                 +--------+                        +--------+
+--R                 |   3                             |   3
+--R                 |- x  + 1        9    6    3      |- x  + 1
+--R        - 6atan( |-------- ) + (2x  - x  + x  + 4) |--------
+--R                 |  3                              |  3
+--R                \| x  + 1                         \| x  + 1
+--R   (2)  -----------------------------------------------------
+--R                                  18
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 368
+t0:=x^9*sqrt((5-7*x^5)/(7+5*x^5))
+--R 
+--R
+--R           +---------+
+--R           |    5
+--R         9 |- 7x  + 5
+--R   (1)  x  |---------
+--R           |   5
+--R          \| 5x  + 7
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 368
+r0:=-2738/175*((5-7*x^5)/(7+5*x^5))^(3/2)/(7+5*(5-7*x^5)/(7+5*x^5))^2+_
+   2257/875*atan(sqrt(5/7)*sqrt((5-7*x^5)/(7+5*x^5)))/sqrt(35)-_
+   2257/875*sqrt((5-7*x^5)/(7+5*x^5))/(7+5*(5-7*x^5)/(7+5*x^5))
+--R 
+--R
+--R                      +---------+
+--R                      |    5
+--R                  +-+ |- 7x  + 5
+--R                 \|5  |---------                                 +---------+
+--R                      |   5                                      |    5
+--R                     \| 5x  + 7           10       5        +--+ |- 7x  + 5
+--R        4514atan(----------------) + (175x   - 185x  - 602)\|35  |---------
+--R                        +-+                                      |   5
+--R                       \|7                                      \| 5x  + 7
+--R   (2)  --------------------------------------------------------------------
+--R                                           +--+
+--R                                      1750\|35
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R             4 +-+ +-+ +--+         4
+--R        2257x \|5 \|7 \|35  - 78995x
+--R   (3)  -----------------------------
+--R                          +---------+
+--R                          |    5
+--R               5          |- 7x  + 5
+--R        (61250x  + 85750) |---------
+--R                          |   5
+--R                         \| 5x  + 7
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 368
+t0:=x/(a+b*x^2)^(3/2)+x/((1+x^2)*sqrt(a+b*x^2))
+--R 
+--R
+--R                       3
+--R               (b + 1)x  + (a + 1)x
+--R   (1)  ---------------------------------
+--R                               +--------+
+--R            4           2      |   2
+--R        (b x  + (b + a)x  + a)\|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 368
+r0:=-atanh(sqrt(a+b*x^2)/sqrt(a-b))/sqrt(a-b)+(-1)/(b*sqrt(a+b*x^2))
+--R 
+--R
+--R                             +--------+
+--R            +--------+       |   2
+--R            |   2           \|b x  + a      +-------+
+--R        - b\|b x  + a atanh(-----------) - \|- b + a
+--R                              +-------+
+--R                             \|- b + a
+--R   (2)  ---------------------------------------------
+--R                                +--------+
+--R                      +-------+ |   2
+--R                    b\|- b + a \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 368
+t0:=x*(1+a+x^2+b*x^2)/((1+x^2)*(a+b*x^2)^(3/2))
+--R 
+--R
+--R                       3
+--R               (b + 1)x  + (a + 1)x
+--R   (1)  ---------------------------------
+--R                               +--------+
+--R            4           2      |   2
+--R        (b x  + (b + a)x  + a)\|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 368
+r0:=-atanh(sqrt(a+b*x^2)/sqrt(a-b))/sqrt(a-b)+(-1)/(b*sqrt(a+b*x^2))
+--R 
+--R
+--R                             +--------+
+--R            +--------+       |   2
+--R            |   2           \|b x  + a      +-------+
+--R        - b\|b x  + a atanh(-----------) - \|- b + a
+--R                              +-------+
+--R                             \|- b + a
+--R   (2)  ---------------------------------------------
+--R                                +--------+
+--R                      +-------+ |   2
+--R                    b\|- b + a \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 368
+t0:=x/(a+b*x^2)^(5/2)+x/(a+b*x^2)^(3/2)+x/((1+x^2)*sqrt(a+b*x^2))
+--R 
+--R
+--R            2      5                       3     2
+--R          (b  + b)x  + ((2a + 1)b + a + 1)x  + (a  + a + 1)x
+--R   (1)  ------------------------------------------------------
+--R                                                    +--------+
+--R          2 6     2         4            2  2    2  |   2
+--R        (b x  + (b  + 2a b)x  + (2a b + a )x  + a )\|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 368
+r0:=(-1/3)/(b*(a+b*x^2)^(3/2))-atanh(sqrt(a+b*x^2)/sqrt(a-b))/sqrt(a-b)+_
+   (-1)/(b*sqrt(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                     +--------+
+--R                    +--------+       |   2
+--R        2 2         |   2           \|b x  + a            2           +-------+
+--R   (- 3b x  - 3a b)\|b x  + a atanh(-----------) + (- 3b x  - 3a - 1)\|- b + a
+--R                                      +-------+
+--R                                     \|- b + a
+--R   ----------------------------------------------------------------------------
+--R                                                 +--------+
+--R                           2 2         +-------+ |   2
+--R                        (3b x  + 3a b)\|- b + a \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 368
+t0:=x*(1+a+a^2+x^2+a*x^2+b*x^2+2*a*b*x^2+b*x^4+b^2*x^4)/((1+x^2)*(a+b*x^2)^(5/2))
+--R 
+--R
+--R            2      5                       3     2
+--R          (b  + b)x  + ((2a + 1)b + a + 1)x  + (a  + a + 1)x
+--R   (1)  ------------------------------------------------------
+--R                                                    +--------+
+--R          2 6     2         4            2  2    2  |   2
+--R        (b x  + (b  + 2a b)x  + (2a b + a )x  + a )\|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 368
+r0:=(-1/3)/(b*(a+b*x^2)^(3/2))-atanh(sqrt(a+b*x^2)/sqrt(a-b))/sqrt(a-b)+_
+   (-1)/(b*sqrt(a+b*x^2))
+--R 
+--R
+--R   (2)
+--R                                     +--------+
+--R                    +--------+       |   2
+--R        2 2         |   2           \|b x  + a            2           +-------+
+--R   (- 3b x  - 3a b)\|b x  + a atanh(-----------) + (- 3b x  - 3a - 1)\|- b + a
+--R                                      +-------+
+--R                                     \|- b + a
+--R   ----------------------------------------------------------------------------
+--R                                                 +--------+
+--R                           2 2         +-------+ |   2
+--R                        (3b x  + 3a b)\|- b + a \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 368
+t0:=1/sqrt(x+sqrt(x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         | +-+
+--R        \|\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 368
+r0:=-2*atanh(sqrt(x)/sqrt(x+sqrt(x)))+2*sqrt(x+sqrt(x))
+--R 
+--R
+--R                      +-+         +--------+
+--R                     \|x          | +-+
+--R   (2)  - 2atanh(-----------) + 2\|\|x  + x
+--R                  +--------+
+--R                  | +-+
+--R                 \|\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 368
+t0:=sqrt(x+sqrt(x))
+--R 
+--R
+--R         +--------+
+--R         | +-+
+--R   (1)  \|\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 368
+r0:=1/4*atanh(sqrt(x)/sqrt(x+sqrt(x)))-1/4*sqrt(x+sqrt(x))+_
+   2/3*x*sqrt(x+sqrt(x))+1/6*sqrt(x)*sqrt(x+sqrt(x))
+--R 
+--R
+--R                    +-+                        +--------+
+--R                   \|x           +-+           | +-+
+--R        3atanh(-----------) + (2\|x  + 8x - 3)\|\|x  + x
+--R                +--------+
+--R                | +-+
+--R               \|\|x  + x
+--R   (2)  -------------------------------------------------
+--R                                12
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 368
+t0:=sqrt(-x)*(x+sqrt(-x))
+--R 
+--R
+--R          +---+
+--R   (1)  x\|- x  - x
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 368
+r0:=2/5*(-x)^(5/2)-1/2*x^2
+--R 
+--R
+--R          2 +---+     2
+--R        4x \|- x  - 5x
+--R   (2)  ---------------
+--R               10
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 368
+t0:=(5+x^(1/4))/(-6+x)
+--R 
+--R
+--R        4+-+
+--R        \|x  + 5
+--R   (1)  --------
+--R          x - 6
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 368
+r0:=4*x^(1/4)-2*6^(1/4)*atan(x^(1/4)/6^(1/4))-_
+   2*6^(1/4)*atanh(x^(1/4)/6^(1/4))+5*log(6-x)
+--R 
+--R
+--R                     4+-+              4+-+
+--R           4+-+      \|x      4+-+     \|x      4+-+
+--R   (2)  - 2\|6 atanh(----) - 2\|6 atan(----) + 4\|x  + 5log(- x + 6)
+--R                     4+-+              4+-+
+--R                     \|6               \|6
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 368
+t0:=1/(4-x+sqrt(4-x))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +-------+
+--R        \|- x + 4  - x + 4
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 368
+r0:=-2*log(1+sqrt(4-x))
+--R 
+--R
+--R                +-------+
+--R   (2)  - 2log(\|- x + 4  + 1)
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 368
+t0:=1/(1+x-sqrt(2+x))
+--R 
+--R
+--R                  1
+--R   (1)  - ----------------
+--R           +-----+
+--R          \|x + 2  - x - 1
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 368
+r0:=1/5*log(1-sqrt(5)-2*sqrt(2+x))*(5-sqrt(5))+_
+   1/5*log(1+sqrt(5)-2*sqrt(2+x))*(5+sqrt(5))
+--R 
+--R
+--R   (2)
+--R         +-+             +-----+    +-+
+--R       (\|5  + 5)log(- 2\|x + 2  + \|5  + 1)
+--R     + 
+--R           +-+             +-----+    +-+
+--R       (- \|5  + 5)log(- 2\|x + 2  - \|5  + 1)
+--R  /
+--R     5
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 368
+t0:=1/(4+x+sqrt(1+x))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R         +-----+
+--R        \|x + 1  + x + 4
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 368
+r0:=log(4+x+sqrt(1+x))-2*atan((1+2*sqrt(1+x))/sqrt(11))/sqrt(11)
+--R 
+--R
+--R                                             +-----+
+--R         +--+     +-----+                  2\|x + 1  + 1
+--R        \|11 log(\|x + 1  + x + 4) - 2atan(-------------)
+--R                                                +--+
+--R                                               \|11
+--R   (2)  -------------------------------------------------
+--R                               +--+
+--R                              \|11
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 368
+t0:=1/(x-sqrt(1+x))
+--R 
+--R
+--R                1
+--R   (1)  - ------------
+--R           +-----+
+--R          \|x + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 368
+r0:=1/5*log(1-sqrt(5)-2*sqrt(1+x))*(5-sqrt(5))+_
+   1/5*log(1+sqrt(5)-2*sqrt(1+x))*(5+sqrt(5))
+--R 
+--R
+--R   (2)
+--R         +-+             +-----+    +-+
+--R       (\|5  + 5)log(- 2\|x + 1  + \|5  + 1)
+--R     + 
+--R           +-+             +-----+    +-+
+--R       (- \|5  + 5)log(- 2\|x + 1  - \|5  + 1)
+--R  /
+--R     5
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 368
+t0:=1/(x-sqrt(2+x))
+--R 
+--R
+--R                1
+--R   (1)  - ------------
+--R           +-----+
+--R          \|x + 2  - x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 368
+r0:=4/3*log(2-sqrt(2+x))+2/3*log(1+sqrt(2+x))
+--R 
+--R
+--R              +-----+                +-----+
+--R        2log(\|x + 2  + 1) + 4log(- \|x + 2  + 2)
+--R   (2)  -----------------------------------------
+--R                            3
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 368
+t0:=1/(x-sqrt(1-x))
+--R 
+--R
+--R                 1
+--R   (1)  - --------------
+--R           +-------+
+--R          \|- x + 1  - x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 368
+r0:=1/5*log(1-sqrt(5)+2*sqrt(1-x))*(5-sqrt(5))+_
+   1/5*log(1+sqrt(5)+2*sqrt(1-x))*(5+sqrt(5))
+--R 
+--R
+--R   (2)
+--R         +-+           +-------+    +-+
+--R       (\|5  + 5)log(2\|- x + 1  + \|5  + 1)
+--R     + 
+--R           +-+           +-------+    +-+
+--R       (- \|5  + 5)log(2\|- x + 1  - \|5  + 1)
+--R  /
+--R     5
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 368
+t0:=1/(sqrt(-1+x)+sqrt(x))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         +-+    +-----+
+--R        \|x  + \|x - 1
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 368
+r0:=-2/3*(-1+x)^(3/2)+2/3*x^(3/2)
+--R 
+--R
+--R           +-+              +-----+
+--R        2x\|x  + (- 2x + 2)\|x - 1
+--R   (2)  ---------------------------
+--R                     3
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 368
+t0:=sqrt(1+x+sqrt(x))
+--R 
+--R
+--R         +------------+
+--R         | +-+
+--R   (1)  \|\|x  + x + 1
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 368
+r0:=-3/8*asinh((1+2*sqrt(x))/sqrt(3))+2/3*(1+x+sqrt(x))^(3/2)-_
+   1/4*(1+2*sqrt(x))*sqrt(1+x+sqrt(x))
+--R 
+--R
+--R                           +------------+            +-+
+--R           +-+             | +-+                   2\|x  + 1
+--R        (4\|x  + 16x + 10)\|\|x  + x + 1  - 9asinh(---------)
+--R                                                       +-+
+--R                                                      \|3
+--R   (2)  -----------------------------------------------------
+--R                                  24
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R            +--------------+     +------------+
+--R            |  +-+               | +-+
+--R        - 3\|4\|x  + 4x + 4  + 6\|\|x  + x + 1
+--R   (3)  ---------------------------------------
+--R                +------------+ +--------------+
+--R            +-+ | +-+          |  +-+
+--R         16\|x \|\|x  + x + 1 \|4\|x  + 4x + 4
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 368
+t0:=sqrt(1+x+sqrt(1+x))
+--R 
+--R
+--R         +----------------+
+--R         | +-----+
+--R   (1)  \|\|x + 1  + x + 1
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 368
+r0:=1/4*atanh(sqrt(1+x)/sqrt(1+x+sqrt(1+x)))-1/4*sqrt(1+x+sqrt(1+x))+_
+   2/3*(1+x)*sqrt(1+x+sqrt(1+x))+1/6*sqrt(1+x)*sqrt(1+x+sqrt(1+x))
+--R 
+--R
+--R                      +-----+                              +----------------+
+--R                     \|x + 1             +-----+           | +-----+
+--R        3atanh(-------------------) + (2\|x + 1  + 8x + 5)\|\|x + 1  + x + 1
+--R                +----------------+
+--R                | +-----+
+--R               \|\|x + 1  + x + 1
+--R   (2)  ---------------------------------------------------------------------
+--R                                          12
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 368
+t0:=sqrt(x+sqrt(-1+x))
+--R 
+--R
+--R         +------------+
+--R         | +-----+
+--R   (1)  \|\|x - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 368
+r0:=-3/8*asinh((1+2*sqrt(-1+x))/sqrt(3))+2/3*(x+sqrt(-1+x))^(3/2)-_
+   1/4*(1+2*sqrt(-1+x))*sqrt(x+sqrt(-1+x))
+--R 
+--R
+--R                              +------------+            +-----+
+--R           +-----+            | +-----+               2\|x - 1  + 1
+--R        (4\|x - 1  + 16x - 6)\|\|x - 1  + x  - 9asinh(-------------)
+--R                                                            +-+
+--R                                                           \|3
+--R   (2)  ------------------------------------------------------------
+--R                                     24
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              +--------------+     +------------+
+--R              |  +-----+           | +-----+
+--R          - 3\|4\|x - 1  + 4x  + 6\|\|x - 1  + x
+--R   (3)  ------------------------------------------
+--R                   +------------+ +--------------+
+--R           +-----+ | +-----+      |  +-----+
+--R        16\|x - 1 \|\|x - 1  + x \|4\|x - 1  + 4x
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 368
+t0:=sqrt(2*x+sqrt(-1+2*x))
+--R 
+--R
+--R         +--------------+
+--R         | +------+
+--R   (1)  \|\|2x - 1  + 2x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 368
+r0:=-3/16*asinh((1+2*sqrt(-1+2*x))/sqrt(3))+1/3*(2*x+sqrt(-1+2*x))^(3/2)-_
+   1/8*(1+2*sqrt(-1+2*x))*sqrt(2*x+sqrt(-1+2*x))
+--R 
+--R
+--R                               +--------------+            +------+
+--R           +------+            | +------+                2\|2x - 1  + 1
+--R        (4\|2x - 1  + 32x - 6)\|\|2x - 1  + 2x  - 9asinh(--------------)
+--R                                                               +-+
+--R                                                              \|3
+--R   (2)  ----------------------------------------------------------------
+--R                                       48
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              +---------------+     +--------------+
+--R              |  +------+           | +------+
+--R          - 3\|4\|2x - 1  + 8x  + 6\|\|2x - 1  + 2x
+--R   (3)  ----------------------------------------------
+--R                    +--------------+ +---------------+
+--R           +------+ | +------+       |  +------+
+--R        16\|2x - 1 \|\|2x - 1  + 2x \|4\|2x - 1  + 8x
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 368
+t0:=sqrt(3*x+sqrt(-7+8*x))
+--R 
+--R
+--R         +--------------+
+--R         | +------+
+--R   (1)  \|\|8x - 7  + 3x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 368
+r0:=-47/36*asinh((4+3*sqrt(-7+8*x))/sqrt(47))/sqrt(6)+1/72*(21-3*(7-8*x)+_
+   8*sqrt(-7+8*x))^(3/2)/sqrt(2)-1/36*(4+3*sqrt(-7+8*x))*_
+   sqrt(21-3*(7-8*x)+8*sqrt(-7+8*x))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R                                       +----------------+
+--R         +-+ +------+             +-+  |  +------+
+--R       (\|6 \|8x - 7  + (12x - 4)\|6 )\|8\|8x - 7  + 24x
+--R     + 
+--R                       +------+
+--R            +-+      3\|8x - 7  + 4
+--R       - 47\|2 asinh(--------------)
+--R                           +--+
+--R                          \|47
+--R  /
+--R        +-+ +-+
+--R     36\|2 \|6
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                       +--------------+ +----------------+
+--R              +------+ | +------+       |  +------+               +-+ +------+
+--R           18\|8x - 7 \|\|8x - 7  + 3x \|8\|8x - 7  + 24x  - 108x\|2 \|8x - 7
+--R         + 
+--R                          +-+
+--R           (- 288x + 205)\|2
+--R      *
+--R          +-----------------+
+--R          |   +------+
+--R         \|24\|8x - 7  + 72x
+--R     + 
+--R              +----------------+
+--R          +-+ |  +------+
+--R       47\|6 \|8\|8x - 7  + 24x
+--R  /
+--R                 +----------------+ +-----------------+
+--R        +------+ |  +------+        |   +------+
+--R     18\|8x - 7 \|8\|8x - 7  + 24x \|24\|8x - 7  + 72x
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 368
+t0:=1/sqrt(x+sqrt(1+x))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R         +------------+
+--R         | +-----+
+--R        \|\|x + 1  + x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 368
+r0:=-atanh(1/2*(1+2*sqrt(1+x))/sqrt(x+sqrt(1+x)))+2*sqrt(x+sqrt(1+x))
+--R 
+--R
+--R                    +-----+           +------------+
+--R                  2\|x + 1  + 1       | +-----+
+--R   (2)  - atanh(----------------) + 2\|\|x + 1  + x
+--R                  +------------+
+--R                  | +-----+
+--R                2\|\|x + 1  + x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 368
+t0:=(1+x)/(4+x+sqrt(-9+6*x))
+--R 
+--R
+--R              x + 1
+--R   (1)  -----------------
+--R         +------+
+--R        \|6x - 9  + x + 4
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 368
+r0:=x+3*log(4+x+sqrt(-9+6*x))+4*atan(1/2*(3+sqrt(-9+6*x))/sqrt(6))*sqrt(6)-_
+   2*sqrt(3)*sqrt(-3+2*x)
+--R 
+--R
+--R   (2)
+--R                                        +------+
+--R         +------+              +-+     \|6x - 9  + 3      +-+ +------+
+--R   3log(\|6x - 9  + x + 4) + 4\|6 atan(-------------) - 2\|3 \|2x - 3  + x
+--R                                             +-+
+--R                                           2\|6
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                     +------+      2             +-+  +------+
+--R       ((- 12x - 48)\|2x - 3  + (2x  + 28x + 14)\|3 )\|6x - 9
+--R     + 
+--R            2             +------+       2              +-+
+--R       (- 6x  - 84x - 42)\|2x - 3  + (24x  + 60x - 144)\|3
+--R  /
+--R       2            +------+ +------+       2             +------+
+--R     (x  + 14x + 7)\|2x - 3 \|6x - 9  + (12x  + 30x - 72)\|2x - 3
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 368
+t0:=(12-x)/(4+x+sqrt(-9+6*x))
+--R 
+--R
+--R             - x + 12
+--R   (1)  -----------------
+--R         +------+
+--R        \|6x - 9  + x + 4
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 368
+r0:=-x+10*log(4+x+sqrt(-9+6*x))-21*atan(1/2*(3+sqrt(-9+6*x))/sqrt(6))*_
+   sqrt(3/2)+2*sqrt(3)*sqrt(-3+2*x)
+--R 
+--R
+--R   (2)
+--R                                                  +------+
+--R          +-+     +------+               +-+     \|6x - 9  + 3
+--R       10\|2 log(\|6x - 9  + x + 4) - 21\|3 atan(-------------)
+--R                                                       +-+
+--R                                                     2\|6
+--R     + 
+--R         +-+ +-+ +------+     +-+
+--R       2\|2 \|3 \|2x - 3  - x\|2
+--R  /
+--R      +-+
+--R     \|2
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R            +-+ +-+ +-+             +------+        2             +-+  +------+
+--R       ((21\|2 \|3 \|6  + 24x - 30)\|2x - 3  + (- 4x  - 56x - 28)\|3 )\|6x - 9
+--R     + 
+--R                   +-+ +-+ +-+      2              +------+
+--R       ((21x + 84)\|2 \|3 \|6  + 12x  + 42x - 420)\|2x - 3
+--R     + 
+--R             2               +-+
+--R       (- 48x  - 120x + 288)\|3
+--R  /
+--R        2             +------+ +------+       2              +------+
+--R     (2x  + 28x + 14)\|2x - 3 \|6x - 9  + (24x  + 60x - 144)\|2x - 3
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 368
+t0:=(-1+x^3)/((1+x^2)*sqrt(x))
+--R 
+--R
+--R            3
+--R           x  - 1
+--R   (1)  ------------
+--R          2      +-+
+--R        (x  + 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 368
+r0:=2/3*x^(3/2)+atan(1-sqrt(2)*sqrt(x))*sqrt(2)-atan(1+sqrt(2)*sqrt(x))*sqrt(2)
+--R 
+--R
+--R            +-+      +-+ +-+          +-+      +-+ +-+           +-+
+--R        - 3\|2 atan(\|2 \|x  + 1) - 3\|2 atan(\|2 \|x  - 1) + 2x\|x
+--R   (2)  ------------------------------------------------------------
+--R                                      3
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 368
+t0:=1/2/(sqrt(-1+x)*sqrt(x-sqrt(-1+x)))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                  +--------------+
+--R          +-----+ |   +-----+
+--R        2\|x - 1 \|- \|x - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 368
+r0:=-asinh((1-2*sqrt(-1+x))/sqrt(3))
+--R 
+--R
+--R                +-----+
+--R              2\|x - 1  - 1
+--R   (2)  asinh(-------------)
+--R                    +-+
+--R                   \|3
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              +--------------+    +----------------+
+--R              |   +-----+         |    +-----+
+--R          - 2\|- \|x - 1  + x  + \|- 4\|x - 1  + 4x
+--R   (3)  ---------------------------------------------
+--R                  +----------------+ +--------------+
+--R          +-----+ |    +-----+       |   +-----+
+--R        2\|x - 1 \|- 4\|x - 1  + 4x \|- \|x - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 368
+t0:=(1+x^(7/2))/(1-x^2)
+--R 
+--R
+--R           3 +-+
+--R        - x \|x  - 1
+--R   (1)  ------------
+--R            2
+--R           x  - 1
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 368
+r0:=-2/5*x^(5/2)+atan(sqrt(x))+atanh(x)+atanh(sqrt(x))-2*sqrt(x)
+--R 
+--R
+--R                +-+           +-+         2       +-+
+--R        5atanh(\|x ) + 5atan(\|x ) + (- 2x  - 10)\|x  + 5atanh(x)
+--R   (2)  ---------------------------------------------------------
+--R                                    5
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 368
+t0:=(4+2*x)/((-1+2*x)^(1/3)+sqrt(-1+2*x))
+--R 
+--R
+--R                2x + 4
+--R   (1)  ---------------------
+--R        3+------+    +------+
+--R        \|2x - 1  + \|2x - 1
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 368
+r0:=-x+18*(-1+2*x)^(1/6)-9*(-1+2*x)^(1/3)-3/4*(-1+2*x)^(2/3)+_
+   3/5*(-1+2*x)^(5/6)+3/7*(-1+2*x)^(7/6)-3/8*(-1+2*x)^(4/3)+_
+   1/3*(-1+2*x)^(3/2)-18*log(1+(-1+2*x)^(1/6))+6*sqrt(-1+2*x)
+--R 
+--R
+--R   (2)
+--R                  6+------+           6+------+5                 6+------+
+--R       - 15120log(\|2x - 1  + 1) + 504\|2x - 1   + (720x + 14760)\|2x - 1
+--R     + 
+--R          3+------+2                  3+------+                 +------+
+--R     - 630\|2x - 1   + (- 630x - 7245)\|2x - 1  + (560x + 4760)\|2x - 1  - 840x
+--R  /
+--R     840
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 368
+t0:=1/sqrt(2+sqrt(1+sqrt(x)))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         | +--------+
+--R         | | +-+
+--R        \|\|\|x  + 1  + 2
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 368
+r0:=88/3*(2+sqrt(1+sqrt(x)))^(3/2)-48/5*(2+sqrt(1+sqrt(x)))^(5/2)+_
+   8/7*(2+sqrt(1+sqrt(x)))^(7/2)-48*sqrt(2+sqrt(1+sqrt(x)))
+--R 
+--R
+--R                                                      +---------------+
+--R                         +--------+                   | +--------+
+--R              +-+        | +-+            +-+         | | +-+
+--R        ((120\|x  + 608)\|\|x  + 1  - 288\|x  - 2240)\|\|\|x  + 1  + 2
+--R   (2)  ---------------------------------------------------------------
+--R                                      105
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 368
+t0:=sqrt(2+sqrt(4+sqrt(x)))
+--R 
+--R
+--R         +---------------+
+--R         | +--------+
+--R         | | +-+
+--R   (1)  \|\|\|x  + 4  + 2
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 368
+r0:=64/5*(2+sqrt(4+sqrt(x)))^(5/2)-48/7*(2+sqrt(4+sqrt(x)))^(7/2)+_
+   8/9*(2+sqrt(4+sqrt(x)))^(9/2)
+--R 
+--R
+--R                                                           +---------------+
+--R                        +--------+                         | +--------+
+--R             +-+        | +-+           +-+                | | +-+
+--R        ((80\|x  - 512)\|\|x  + 4  + 32\|x  + 280x - 1024)\|\|\|x  + 4  + 2
+--R   (2)  --------------------------------------------------------------------
+--R                                         315
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 368
+t0:=sqrt(2-sqrt(4+sqrt(-9+5*x)))
+--R 
+--R
+--R         +----------------------+
+--R         |   +-------------+
+--R         |   | +------+
+--R   (1)  \|- \|\|5x - 9  + 4  + 2
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 368
+r0:=64/25*(2-sqrt(4+sqrt(-9+5*x)))^(5/2)-_
+   48/35*(2-sqrt(4+sqrt(-9+5*x)))^(7/2)+8/45*(2-sqrt(4+sqrt(-9+5*x)))^(9/2)
+--R 
+--R
+--R   (2)
+--R                              +-------------+
+--R              +------+        | +------+           +------+
+--R       ((- 80\|5x - 9  + 512)\|\|5x - 9  + 4  + 32\|5x - 9  + 1400x - 3544)
+--R    *
+--R        +----------------------+
+--R        |   +-------------+
+--R        |   | +------+
+--R       \|- \|\|5x - 9  + 4  + 2
+--R  /
+--R     1575
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 368
+t0:=1/sqrt(2+sqrt(1+sqrt(x)))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         | +--------+
+--R         | | +-+
+--R        \|\|\|x  + 1  + 2
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 368
+r0:=88/3*(2+sqrt(1+sqrt(x)))^(3/2)-48/5*(2+sqrt(1+sqrt(x)))^(5/2)+_
+   8/7*(2+sqrt(1+sqrt(x)))^(7/2)-48*sqrt(2+sqrt(1+sqrt(x)))
+--R 
+--R
+--R                                                      +---------------+
+--R                         +--------+                   | +--------+
+--R              +-+        | +-+            +-+         | | +-+
+--R        ((120\|x  + 608)\|\|x  + 1  - 288\|x  - 2240)\|\|\|x  + 1  + 2
+--R   (2)  ---------------------------------------------------------------
+--R                                      105
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 368
+t0:=sqrt(1+sqrt(1+sqrt(1+sqrt(x))))
+--R 
+--R
+--R         +----------------------+
+--R         | +---------------+
+--R         | | +--------+
+--R         | | | +-+
+--R   (1)  \|\|\|\|x  + 1  + 1  + 1
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 368
+r0:=-32/5*(1+sqrt(1+sqrt(1+sqrt(x))))^(5/2)+48/7*(1+sqrt(1+sqrt(1+_
+   sqrt(x))))^(7/2)+112/9*(1+sqrt(1+sqrt(1+sqrt(x))))^(9/2)-_
+   320/11*(1+sqrt(1+sqrt(1+sqrt(x))))^(11/2)+288/13*(1+sqrt(1+_
+   sqrt(1+sqrt(x))))^(13/2)-112/15*(1+sqrt(1+sqrt(1+sqrt(x))))^(15/2)+_
+   16/17*(1+sqrt(1+sqrt(1+sqrt(x))))^(17/2)
+--R 
+--R
+--R   (2)
+--R                                                               +---------------+
+--R                              +--------+                       | +--------+
+--R                 +-+          | +-+              +-+           | | +-+
+--R         ((48048\|x  - 74752)\|\|x  + 1  - 56448\|x  + 140032)\|\|\|x  + 1  + 1
+--R       + 
+--R                            +--------+
+--R               +-+          | +-+              +-+
+--R         (3696\|x  - 20864)\|\|x  + 1  + 73808\|x  + 720720x - 450432
+--R    *
+--R        +----------------------+
+--R        | +---------------+
+--R        | | +--------+
+--R        | | | +-+
+--R       \|\|\|\|x  + 1  + 1  + 1
+--R  /
+--R     765765
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 368
+t0:=sqrt(2+sqrt(3+sqrt(-1+2*sqrt(x))))
+--R 
+--R
+--R         +-----------------------+
+--R         | +----------------+
+--R         | | +---------+
+--R         | | |  +-+
+--R   (1)  \|\|\|2\|x  - 1  + 3  + 2
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 368
+r0:=-16/3*(2+sqrt(3+sqrt(-1+2*sqrt(x))))^(3/2)+136/5*(2+sqrt(3+_
+   sqrt(-1+2*sqrt(x))))^(5/2)-480/7*(2+sqrt(3+sqrt(-1+2*sqrt(x))))^(7/2)+_
+   304/3*(2+sqrt(3+sqrt(-1+2*sqrt(x))))^(9/2)-760/11*(2+sqrt(3+_
+   sqrt(-1+2*sqrt(x))))^(11/2)+300/13*(2+sqrt(3+sqrt(-1+_
+   2*sqrt(x))))^(13/2)-56/15*(2+sqrt(3+sqrt(-1+2*sqrt(x))))^(15/2)+_
+   4/17*(2+sqrt(3+sqrt(-1+2*sqrt(x))))^(17/2)
+--R 
+--R
+--R   (2)
+--R                                 +---------+
+--R                   +-+           |  +-+              +-+
+--R           ((16016\|x  + 108800)\|2\|x  - 1  - 37632\|x  - 475392)
+--R        *
+--R            +----------------+
+--R            | +---------+
+--R            | |  +-+
+--R           \|\|2\|x  - 1  + 3
+--R       + 
+--R                              +---------+
+--R                 +-+          |  +-+              +-+
+--R         (- 6776\|x  + 13504)\|2\|x  - 1  - 30744\|x  + 240240x - 992640
+--R    *
+--R        +-----------------------+
+--R        | +----------------+
+--R        | | +---------+
+--R        | | |  +-+
+--R       \|\|\|2\|x  - 1  + 3  + 2
+--R  /
+--R     255255
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 368
+t0:=x*sqrt(1+sqrt(1+sqrt(-1+x)))
+--R 
+--R
+--R          +-------------------+
+--R          | +------------+
+--R          | | +-----+
+--R   (1)  x\|\|\|x - 1  + 1  + 1
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 368
+r0:=16/5*(1+sqrt(1+sqrt(-1+x)))^(5/2)-24/7*(1+sqrt(1+sqrt(-1+x)))^(7/2)+_
+   8*(1+sqrt(1+sqrt(-1+x)))^(9/2)-160/11*(1+sqrt(1+sqrt(-1+x)))^(11/2)+_
+   144/13*(1+sqrt(1+sqrt(-1+x)))^(13/2)-56/15*(1+sqrt(1+_
+   sqrt(-1+x)))^(15/2)+8/17*(1+sqrt(1+sqrt(-1+x)))^(17/2)
+--R 
+--R
+--R   (2)
+--R                                                   +------------+
+--R                          +-----+                  | +-----+
+--R         ((8008x + 36352)\|x - 1  - 9408x - 61568)\|\|x - 1  + 1
+--R       + 
+--R                       +-----+          2
+--R         (616x + 8256)\|x - 1  + 120120x  - 14392x - 176704
+--R    *
+--R        +-------------------+
+--R        | +------------+
+--R        | | +-----+
+--R       \|\|\|x - 1  + 1  + 1
+--R  /
+--R     255255
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 368
+t0:=1/(sqrt(-1+x)*sqrt(x-sqrt(-1+x)))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R                 +--------------+
+--R         +-----+ |   +-----+
+--R        \|x - 1 \|- \|x - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 368
+r0:=-2*asinh((1-2*sqrt(-1+x))/sqrt(3))
+--R 
+--R
+--R                 +-----+
+--R               2\|x - 1  - 1
+--R   (2)  2asinh(-------------)
+--R                     +-+
+--R                    \|3
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R             +--------------+    +----------------+
+--R             |   +-----+         |    +-----+
+--R         - 2\|- \|x - 1  + x  + \|- 4\|x - 1  + 4x
+--R   (3)  --------------------------------------------
+--R                 +----------------+ +--------------+
+--R         +-----+ |    +-----+       |   +-----+
+--R        \|x - 1 \|- 4\|x - 1  + 4x \|- \|x - 1  + x
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 368
+t0:=1/sqrt(1+x+sqrt(-1+2*x))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-----------------+
+--R         | +------+
+--R        \|\|2x - 1  + x + 1
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 368
+r0a:=-asinh((1+sqrt(-1+2*x))/sqrt(2))*sqrt(2)+2*sqrt(1+x+sqrt(-1+2*x))
+--R 
+--R
+--R          +-----------------+              +------+
+--R          | +------+             +-+      \|2x - 1  + 1
+--R   (2)  2\|\|2x - 1  + x + 1  - \|2 asinh(-------------)
+--R                                                +-+
+--R                                               \|2
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 368
+r0b:=-asinh((1+sqrt(-1+2*x))/sqrt(2))*sqrt(2)+_
+   sqrt(2)*sqrt(2+2*x+2*sqrt(-1+2*x))
+--R 
+--R
+--R             +-------------------+              +------+
+--R         +-+ |  +------+              +-+      \|2x - 1  + 1
+--R   (3)  \|2 \|2\|2x - 1  + 2x + 2  - \|2 asinh(-------------)
+--R                                                     +-+
+--R                                                    \|2
+--R                                                    Type: Expression(Integer)
+--E 252
+
+--S 253 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)
+--R                       +-------------------+
+--R         +------+      |  +------+
+--R       (\|2x - 1  + 1)\|2\|2x - 1  + 2x + 2
+--R     + 
+--R                                +-----------------+
+--R           +-+ +------+    +-+  | +------+
+--R       (- \|2 \|2x - 1  - \|2 )\|\|2x - 1  + x + 1
+--R  /
+--R               +-----------------+ +-------------------+
+--R      +------+ | +------+          |  +------+
+--R     \|2x - 1 \|\|2x - 1  + x + 1 \|2\|2x - 1  + 2x + 2
+--R                                                    Type: Expression(Integer)
+--E 254
+
+)clear all
+
+--S 255 of 368
+t0:=(q+p*x)/(sqrt(b+a*x)*(f+sqrt(b+a*x)))
+--R 
+--R
+--R               p x + q
+--R   (1)  ---------------------
+--R          +-------+
+--R        f\|a x + b  + a x + b
+--R                                                    Type: Expression(Integer)
+--E 255
+
+--S 256 of 368
+r0:=p*x/a-2*(b*p-f^2*p-a*q)*log(f+sqrt(b+a*x))/a^2-2*f*p*sqrt(b+a*x)/a^2
+--R 
+--R
+--R                   2             +-------+             +-------+
+--R        (2a q + (2f  - 2b)p)log(\|a x + b  + f) - 2f p\|a x + b  + a p x
+--R   (2)  ----------------------------------------------------------------
+--R                                        2
+--R                                       a
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 257
+
+)clear all
+
+--S 258 of 368
+t0:=sqrt(1-x-sqrt(x))
+--R 
+--R
+--R         +--------------+
+--R         |   +-+
+--R   (1)  \|- \|x  - x + 1
+--R                                                    Type: Expression(Integer)
+--E 258
+
+--S 259 of 368
+r0:=-5/8*asin((1+2*sqrt(x))/sqrt(5))-2/3*(1-x-sqrt(x))^(3/2)-_
+   1/4*(1+2*sqrt(x))*sqrt(1-x-sqrt(x))
+--R 
+--R
+--R                           +--------------+            +-+
+--R           +-+             |   +-+                   2\|x  + 1
+--R        (4\|x  + 16x - 22)\|- \|x  - x + 1  - 15asin(---------)
+--R                                                         +-+
+--R                                                        \|5
+--R   (2)  -------------------------------------------------------
+--R                                   24
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           +--------------+     +----------------+
+--R           |   +-+              |    +-+
+--R        10\|- \|x  - x + 1  - 5\|- 4\|x  - 4x + 4
+--R   (3)  ------------------------------------------
+--R               +----------------+ +--------------+
+--R           +-+ |    +-+           |   +-+
+--R        16\|x \|- 4\|x  - 4x + 4 \|- \|x  - x + 1
+--R                                                    Type: Expression(Integer)
+--E 260
+
+)clear all
+
+--S 261 of 368
+t0:=(9+x+6*sqrt(x))/(x+4*sqrt(x))
+--R 
+--R
+--R          +-+
+--R        6\|x  + x + 9
+--R   (1)  -------------
+--R            +-+
+--R          4\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 261
+
+--S 262 of 368
+r0:=x+2*log(4+sqrt(x))+4*sqrt(x)
+--R 
+--R
+--R              +-+          +-+
+--R   (2)  2log(\|x  + 4) + 4\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 263
+
+)clear all
+
+--S 264 of 368
+t0:=(6-8*x^(7/2))/(5-9*sqrt(x))
+--R 
+--R
+--R          3 +-+
+--R        8x \|x  - 6
+--R   (1)  -----------
+--R           +-+
+--R         9\|x  - 5
+--R                                                    Type: Expression(Integer)
+--E 264
+
+--S 265 of 368
+r0:=125000/4782969*x+50000/1594323*x^(3/2)+2500/59049*x^2+400/6561*x^(5/2)+_
+   200/2187*x^3+80/567*x^(7/2)+2/9*x^4-280728140/387420489*log(5-9*sqrt(x))-_
+   56145628/43046721*sqrt(x)
+--R 
+--R
+--R   (2)
+--R                           +-+
+--R       - 1965096980log(- 9\|x  + 5)
+--R     + 
+--R                  3             2                           +-+             4
+--R       (382637520x  + 165337200x  + 85050000x - 3537174564)\|x  + 602654094x
+--R     + 
+--R                 3             2
+--R       248005800x  + 114817500x  + 70875000x
+--R  /
+--R     2711943423
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 266
+
+)clear all
+
+--S 267 of 368
+t0:=(1+x^3)*sqrt(1+x)/(1+x^2)
+--R 
+--R
+--R          3      +-----+
+--R        (x  + 1)\|x + 1
+--R   (1)  ----------------
+--R              2
+--R             x  + 1
+--R                                                    Type: Expression(Integer)
+--E 267
+
+--S 268 of 368
+r0a:=-2/3*(1+x)^(3/2)+2/5*(1+x)^(5/2)+(1-%i)^(3/2)*atanh(sqrt(1+x)/_
+   sqrt(1-%i))+(1+%i)^(3/2)*atanh(sqrt(1+x)/sqrt(1+%i))-2*sqrt(1+x)
+--R 
+--R
+--R   (2)
+--R                                   +-----+
+--R                   +------+       \|x + 1
+--R       (15 - 15%i)\|1 - %i atanh(---------)
+--R                                  +------+
+--R                                 \|1 - %i
+--R     + 
+--R                                   +-----+
+--R                   +------+       \|x + 1        2            +-----+
+--R       (15 + 15%i)\|1 + %i atanh(---------) + (6x  + 2x - 34)\|x + 1
+--R                                  +------+
+--R                                 \|1 + %i
+--R  /
+--R     15
+--R                                           Type: Expression(Complex(Integer))
+--E 268
+
+--S 269 of 368
+r0b:=-2/3*(1+x)^(3/2)+2/5*(1+x)^(5/2)-2*sqrt(1+x)-1/2*log(1+x+sqrt(2)-_
+   sqrt(1+x)*sqrt(2*(1+sqrt(2))))/sqrt(1+sqrt(2))+1/2*log(1+x+sqrt(2)+_
+   sqrt(1+x)*sqrt(2*(1+sqrt(2))))/sqrt(1+sqrt(2))-atan((-2*sqrt(1+x)+_
+   sqrt(2*(1+sqrt(2))))/sqrt(2*(-1+sqrt(2))))*sqrt(1+sqrt(2))+_
+   atan((2*sqrt(1+x)+sqrt(2*(1+sqrt(2))))/sqrt(2*(-1+sqrt(2))))*_
+   sqrt(1+sqrt(2))
+--R 
+--R
+--R   (3)
+--R                      +---------+
+--R              +-----+ |  +-+         +-+
+--R       15log(\|x + 1 \|2\|2  + 2  + \|2  + x + 1)
+--R     + 
+--R                          +---------+
+--R                  +-----+ |  +-+         +-+
+--R       - 15log(- \|x + 1 \|2\|2  + 2  + \|2  + x + 1)
+--R     + 
+--R                          +---------+
+--R                          |  +-+          +-----+
+--R           +-+           \|2\|2  + 2  + 2\|x + 1
+--R       (30\|2  + 30)atan(------------------------)
+--R                                +---------+
+--R                                |  +-+
+--R                               \|2\|2  - 2
+--R     + 
+--R                            +---------+
+--R                            |  +-+          +-----+
+--R             +-+           \|2\|2  + 2  - 2\|x + 1
+--R       (- 30\|2  - 30)atan(------------------------)
+--R                                  +---------+
+--R                                  |  +-+
+--R                                 \|2\|2  - 2
+--R     + 
+--R                                +--------+
+--R           2            +-----+ | +-+
+--R       (12x  + 4x - 68)\|x + 1 \|\|2  + 1
+--R  /
+--R        +--------+
+--R        | +-+
+--R     30\|\|2  + 1
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                           Type: Expression(Complex(Integer))
+--E 270
+
+--S 271 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)
+--R                        +--------+ +---------+
+--R           +-+          | +-+      |  +-+
+--R       (- \|2  + x + 1)\|\|2  + 1 \|2\|2  + 2
+--R     + 
+--R                               +--------+ +---------+
+--R                  +-+          | +-+      |  +-+          +-+
+--R       ((- x - 2)\|2  - x - 3)\|\|2  + 1 \|2\|2  - 2  + 4\|2  + 4
+--R  /
+--R         2      +-+     2      +-----+
+--R     ((2x  + 2)\|2  + 2x  + 2)\|x + 1
+--R                                                    Type: Expression(Integer)
+--E 271
+
+)clear all
+
+--S 272 of 368
+t0:=sqrt(-1+x-sqrt(x))/((-1+x)*sqrt(x))
+--R 
+--R
+--R         +--------------+
+--R         |   +-+
+--R        \|- \|x  + x - 1
+--R   (1)  -----------------
+--R                   +-+
+--R           (x - 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 368
+r0:=atan(1/2*(3-sqrt(x))/sqrt(-1+x-sqrt(x)))-_
+   2*atanh(1/2*(1-2*sqrt(x))/sqrt(-1+x-sqrt(x)))-_
+   atanh(1/2*(1+3*sqrt(x))/sqrt(-1+x-sqrt(x)))
+--R 
+--R
+--R   (2)
+--R                    +-+                          +-+
+--R                  3\|x  + 1                    2\|x  - 1
+--R     - atanh(------------------) + 2atanh(------------------)
+--R               +--------------+             +--------------+
+--R               |   +-+                      |   +-+
+--R             2\|- \|x  + x - 1            2\|- \|x  + x - 1
+--R   + 
+--R                  +-+
+--R                 \|x  - 3
+--R     - atan(------------------)
+--R              +--------------+
+--R              |   +-+
+--R            2\|- \|x  + x - 1
+--R                                                    Type: Expression(Integer)
+--E 273
+
+--S 274 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 274
+
+)clear all
+
+--S 275 of 368
+t0:=1/(sqrt(x)*sqrt(1+x))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R         +-+ +-----+
+--R        \|x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 368
+r0:=2*asinh(sqrt(x))
+--R 
+--R
+--R                +-+
+--R   (2)  2asinh(\|x )
+--R                                                    Type: Expression(Integer)
+--E 276
+
+--S 277 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 277
+
+)clear all
+
+--S 278 of 368
+t0:=sqrt(x/(1+x))/x
+--R 
+--R
+--R         +-----+
+--R         |  x
+--R         |-----
+--R        \|x + 1
+--R   (1)  --------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 368
+r0a:=2*asinh(sqrt(x))
+--R 
+--R
+--R                +-+
+--R   (2)  2asinh(\|x )
+--R                                                    Type: Expression(Integer)
+--E 279
+
+--S 280 of 368
+r0b:=2*atanh(sqrt(x/(1+x)))
+--R 
+--R
+--R                +-----+
+--R                |  x
+--R   (3)  2atanh( |----- )
+--R               \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R         +-----+
+--R         |  x    +-+ +-----+
+--R         |----- \|x \|x + 1  - x
+--R        \|x + 1
+--R   (4)  ------------------------
+--R                +-+ +-----+
+--R              x\|x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 368
+t0:=sqrt(x)/sqrt(1+x)
+--R 
+--R
+--R           +-+
+--R          \|x
+--R   (1)  --------
+--R         +-----+
+--R        \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 368
+r0:=-asinh(sqrt(x))+sqrt(x)*sqrt(1+x)
+--R 
+--R
+--R                 +-+     +-+ +-----+
+--R   (2)  - asinh(\|x ) + \|x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 368
+t0:=sqrt(x/(1+x))
+--R 
+--R
+--R         +-----+
+--R         |  x
+--R   (1)   |-----
+--R        \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 368
+r0a:=-asinh(sqrt(x))+sqrt(x)*sqrt(1+x)
+--R 
+--R
+--R                 +-+     +-+ +-----+
+--R   (2)  - asinh(\|x ) + \|x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 368
+r0b:=-atanh(sqrt(x/(1+x)))+sqrt(x/(1+x))/(1-x/(1+x))
+--R 
+--R
+--R                 +-----+            +-----+
+--R                 |  x               |  x
+--R   (3)  - atanh( |----- ) + (x + 1) |-----
+--R                \|x + 1            \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 288
+
+--S 289 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R         +-----+
+--R         |  x    +-+ +-----+
+--R         |----- \|x \|x + 1  - x
+--R        \|x + 1
+--R   (4)  ------------------------
+--R               +-+ +-----+
+--R              \|x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 290
+
+)clear all
+
+--S 291 of 368
+t0:=sqrt(-1+x)/(x^2*sqrt(1+x))
+--R 
+--R
+--R          +-----+
+--R         \|x - 1
+--R   (1)  ----------
+--R         2 +-----+
+--R        x \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 291
+
+--S 292 of 368
+r0:=2*atan(sqrt(-1+x)/sqrt(1+x))-sqrt(-1+x)*sqrt(1+x)/x
+--R 
+--R
+--R                 +-----+
+--R                \|x - 1      +-----+ +-----+
+--R        2x atan(--------) - \|x - 1 \|x + 1
+--R                 +-----+
+--R                \|x + 1
+--R   (2)  ------------------------------------
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 293
+
+)clear all
+
+--S 294 of 368
+t0:=sqrt((-1+x)/(1+x))/x^2
+--R 
+--R
+--R         +-----+
+--R         |x - 1
+--R         |-----
+--R        \|x + 1
+--R   (1)  --------
+--R            2
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 294
+
+--S 295 of 368
+r0:=2*atan(sqrt((-1+x)/(1+x)))-2*sqrt((-1+x)/(1+x))/(1+(-1+x)/(1+x))
+--R 
+--R
+--R                 +-----+              +-----+
+--R                 |x - 1               |x - 1
+--R        2x atan( |----- ) + (- x - 1) |-----
+--R                \|x + 1              \|x + 1
+--R   (2)  -------------------------------------
+--R                          x
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 296
+
+)clear all
+
+--S 297 of 368
+t0:=x^3*sqrt(-1+x)/sqrt(1+x)
+--R 
+--R
+--R         3 +-----+
+--R        x \|x - 1
+--R   (1)  ----------
+--R          +-----+
+--R         \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 297
+
+--S 298 of 368
+r0:=3/8*acosh(x)-2/3*sqrt(-1+x)*sqrt(1+x)+3/8*x*sqrt(-1+x)*sqrt(1+x)-_
+   1/3*x^2*sqrt(-1+x)*sqrt(1+x)+1/4*x^3*sqrt(-1+x)*sqrt(1+x)
+--R 
+--R
+--R           3     2            +-----+ +-----+
+--R        (6x  - 8x  + 9x - 16)\|x - 1 \|x + 1  + 9acosh(x)
+--R   (2)  -------------------------------------------------
+--R                                24
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R          +------+
+--R          | 2          +-----+ +-----+
+--R        3\|x  - 1  - 3\|x - 1 \|x + 1
+--R   (3)  ------------------------------
+--R                            +------+
+--R            +-----+ +-----+ | 2
+--R          8\|x - 1 \|x + 1 \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 299
+
+)clear all
+
+--S 300 of 368
+t0:=x^3*sqrt((-1+x)/(1+x))
+--R 
+--R
+--R           +-----+
+--R         3 |x - 1
+--R   (1)  x  |-----
+--R          \|x + 1
+--R                                                    Type: Expression(Integer)
+--E 300
+
+--S 301 of 368
+r0a:=3/8*acosh(x)-2/3*sqrt(-1+x)*sqrt(1+x)+3/8*x*sqrt(-1+x)*sqrt(1+x)-_
+   1/3*x^2*sqrt(-1+x)*sqrt(1+x)+1/4*x^3*sqrt(-1+x)*sqrt(1+x)
+--R 
+--R
+--R           3     2            +-----+ +-----+
+--R        (6x  - 8x  + 9x - 16)\|x - 1 \|x + 1  + 9acosh(x)
+--R   (2)  -------------------------------------------------
+--R                                24
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 368
+r0b:=3/4*atanh(sqrt((-1+x)/(1+x)))+1/2*(1+(-1+x)/(1+x))^3*_
+   sqrt((-1+x)/(1+x))/(1+(1-x)/(1+x))^4-2/3*(1+(-1+x)/(1+x))^2*_
+   sqrt((-1+x)/(1+x))/(1+(1-x)/(1+x))^3+3/4*(1+(-1+x)/(1+x))*_
+   sqrt((-1+x)/(1+x))/(1+(1-x)/(1+x))^2-4/3*sqrt((-1+x)/(1+x))/_
+   (1+(1-x)/(1+x))
+--R 
+--R
+--R                 +-----+                               +-----+
+--R                 |x - 1        4     3    2            |x - 1
+--R        18atanh( |----- ) + (6x  - 2x  + x  - 7x - 16) |-----
+--R                \|x + 1                               \|x + 1
+--R   (3)  ------------------------------------------------------
+--R                                  24
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)
+--R        +-----+                                  +------+
+--R      3 |x - 1  +-----+ +-----+     4     3      | 2          +-----+ +-----+
+--R   (8x  |----- \|x - 1 \|x + 1  - 8x  + 8x  + 3)\|x  - 1  - 3\|x - 1 \|x + 1
+--R       \|x + 1
+--R   --------------------------------------------------------------------------
+--R                                             +------+
+--R                             +-----+ +-----+ | 2
+--R                           8\|x - 1 \|x + 1 \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 303
+
+--S 304 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 304
+
+)clear all
+
+--S 305 of 368
+t0:=sqrt(-x/(1+x))/x
+--R 
+--R
+--R         +-------+
+--R         |    x
+--R         |- -----
+--R        \|  x + 1
+--R   (1)  ----------
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 368
+r0:=2*atan(sqrt(-x/(1+x)))
+--R 
+--R
+--R               +-------+
+--R               |    x
+--R   (2)  2atan( |- ----- )
+--R              \|  x + 1
+--R                                                    Type: Expression(Integer)
+--E 306
+
+--S 307 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 307
+
+)clear all
+
+--S 308 of 368
+t0:=sqrt((1-x)/(1+x))/(-1+x)
+--R 
+--R
+--R         +-------+
+--R         |- x + 1
+--R         |-------
+--R        \| x + 1
+--R   (1)  ----------
+--R           x - 1
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 368
+r0:=2*atan(sqrt((1-x)/(1+x)))
+--R 
+--R
+--R               +-------+
+--R               |- x + 1
+--R   (2)  2atan( |------- )
+--R              \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 309
+
+--S 310 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 310
+
+)clear all
+
+--S 311 of 368
+t0:=sqrt((a+b*x)/(c-b*x))/(a+b*x)
+--R 
+--R
+--R         +---------+
+--R         |- b x - a
+--R         |---------
+--R        \| b x - c
+--R   (1)  ------------
+--R           b x + a
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 368
+r0:=2*atan(sqrt((a+b*x)/(c-b*x)))/b
+--R 
+--R
+--R               +---------+
+--R               |- b x - a
+--R        2atan( |--------- )
+--R              \| b x - c
+--R   (2)  -------------------
+--R                 b
+--R                                                    Type: Expression(Integer)
+--E 312
+
+--S 313 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 313
+
+)clear all
+
+--S 314 of 368
+t0:=sqrt((a+b*x)/(c+d*x))/(a+b*x)
+--R 
+--R
+--R         +-------+
+--R         |b x + a
+--R         |-------
+--R        \|d x + c
+--R   (1)  ----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 368
+r0:=2*atanh(sqrt(d)*sqrt((a+b*x)/(c+d*x))/sqrt(b))/(sqrt(b)*sqrt(d))
+--R 
+--R
+--R                +-------+
+--R                |b x + a  +-+
+--R                |------- \|d
+--R               \|d x + c
+--R        2atanh(--------------)
+--R                     +-+
+--R                    \|b
+--R   (2)  ----------------------
+--R                +-+ +-+
+--R               \|b \|d
+--R                                                    Type: Expression(Integer)
+--E 315
+
+--S 316 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 316
+
+)clear all
+
+--S 317 of 368
+t0:=sqrt(-x/(1+x))
+--R 
+--R
+--R         +-------+
+--R         |    x
+--R   (1)   |- -----
+--R        \|  x + 1
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 368
+r0a:=-atan(sqrt(-x/(1+x)))+(1+x)*sqrt(-x/(1+x))
+--R 
+--R
+--R                +-------+            +-------+
+--R                |    x               |    x
+--R   (2)  - atan( |- ----- ) + (x + 1) |- -----
+--R               \|  x + 1            \|  x + 1
+--R                                                    Type: Expression(Integer)
+--E 318
+
+--S 319 of 368
+r0b:=-atan(sqrt(-x/(1+x)))+sqrt(-x/(1+x))/(1-x/(1+x))
+--R 
+--R
+--R                +-------+            +-------+
+--R                |    x               |    x
+--R   (3)  - atan( |- ----- ) + (x + 1) |- -----
+--R               \|  x + 1            \|  x + 1
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 368
+t0:=sqrt((1-x)/(1+x))
+--R 
+--R
+--R         +-------+
+--R         |- x + 1
+--R   (1)   |-------
+--R        \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 368
+r0a:=-2*atan(sqrt((1-x)/(1+x)))+(1+x)*sqrt((1-x)/(1+x))
+--R 
+--R
+--R                 +-------+            +-------+
+--R                 |- x + 1             |- x + 1
+--R   (2)  - 2atan( |------- ) + (x + 1) |-------
+--R                \| x + 1             \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 368
+r0b:=-2*atan(sqrt((1-x)/(1+x)))+2*sqrt((1-x)/(1+x))/(1+(1-x)/(1+x))
+--R 
+--R
+--R                 +-------+            +-------+
+--R                 |- x + 1             |- x + 1
+--R   (3)  - 2atan( |------- ) + (x + 1) |-------
+--R                \| x + 1             \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 324
+
+--S 325 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 326
+
+)clear all
+
+--S 327 of 368
+t0:=sqrt((a+x)/(a-x))
+--R 
+--R
+--R         +-------+
+--R         |- x - a
+--R   (1)   |-------
+--R        \| x - a
+--R                                                    Type: Expression(Integer)
+--E 327
+
+--S 328 of 368
+r0a:=2*a*atan(sqrt((a+x)/(a-x)))-(a-x)*sqrt((a+x)/(a-x))
+--R 
+--R
+--R                 +-------+            +-------+
+--R                 |- x - a             |- x - a
+--R   (2)  2a atan( |------- ) + (x - a) |-------
+--R                \| x - a             \| x - a
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 368
+r0b:=2*a*atan(sqrt((a+x)/(a-x)))-2*a*sqrt((a+x)/(a-x))/(1+(a+x)/(a-x))
+--R 
+--R
+--R                 +-------+            +-------+
+--R                 |- x - a             |- x - a
+--R   (3)  2a atan( |------- ) + (x - a) |-------
+--R                \| x - a             \| x - a
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+--S 331 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 331
+
+)clear all
+
+--S 332 of 368
+t0:=sqrt((-a+x)/(a+x))
+--R 
+--R
+--R         +-----+
+--R         |x - a
+--R   (1)   |-----
+--R        \|x + a
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 368
+r0a:=-2*a*atanh(sqrt((-a+x)/(a+x)))+(a+x)*sqrt((-a+x)/(a+x))
+--R 
+--R
+--R                    +-----+            +-----+
+--R                    |x - a             |x - a
+--R   (2)  - 2a atanh( |----- ) + (x + a) |-----
+--R                   \|x + a            \|x + a
+--R                                                    Type: Expression(Integer)
+--E 333
+
+--S 334 of 368
+r0b:=-2*a*atanh(sqrt((-a+x)/(a+x)))+2*a*sqrt((-a+x)/(a+x))/(1+(a-x)/(a+x))
+--R 
+--R
+--R                    +-----+            +-----+
+--R                    |x - a             |x - a
+--R   (3)  - 2a atanh( |----- ) + (x + a) |-----
+--R                   \|x + a            \|x + a
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 368
+t0:=sqrt((a+b*x)/(c+d*x))
+--R 
+--R
+--R         +-------+
+--R         |b x + a
+--R   (1)   |-------
+--R        \|d x + c
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 368
+r0a:=-(b*c-a*d)*atanh(sqrt(d)*sqrt((a+b*x)/(c+d*x))/sqrt(b))/(d^(3/2)*_
+   sqrt(b))+(c+d*x)*sqrt((a+b*x)/(c+d*x))/d
+--R 
+--R
+--R                          +-------+
+--R                          |b x + a  +-+
+--R                          |------- \|d               +-------+
+--R                         \|d x + c                   |b x + a  +-+ +-+
+--R        (a d - b c)atanh(--------------) + (d x + c) |------- \|b \|d
+--R                               +-+                  \|d x + c
+--R                              \|b
+--R   (2)  --------------------------------------------------------------
+--R                                     +-+ +-+
+--R                                   d\|b \|d
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 368
+r0b:=-(b*c-a*d)*atanh(sqrt(d)*sqrt((a+b*x)/(c+d*x))/sqrt(b))/(d^(3/2)*_
+   sqrt(b))+(b*c-a*d)*sqrt((a+b*x)/(c+d*x))/(d*(b-d*(a+b*x)/(c+d*x)))
+--R 
+--R
+--R                          +-------+
+--R                          |b x + a  +-+
+--R                          |------- \|d               +-------+
+--R                         \|d x + c                   |b x + a  +-+ +-+
+--R        (a d - b c)atanh(--------------) + (d x + c) |------- \|b \|d
+--R                               +-+                  \|d x + c
+--R                              \|b
+--R   (3)  --------------------------------------------------------------
+--R                                     +-+ +-+
+--R                                   d\|b \|d
+--R                                                    Type: Expression(Integer)
+--E 339
+
+--S 340 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 368
+--Rm0c:=a0.1-r0b
+--R 
+--R   There are no library operations named a0 
+--R      Use HyperDoc Browse or issue
+--R                                 )what op a0
+--R      to learn if there is any operation containing " a0 " in its name.
+--R 
+--RDaly Bug
+--R   Cannot find a definition or applicable library operation named a0 
+--R      with argument type(s) 
+--R                               PositiveInteger
+--R      
+--R      Perhaps you should use "@" to indicate the required return type, 
+--R      or "$" to specify which version of the function you need.
+--E 342
+
+--S 343 of 368
+d0c:=D(m0c,x)
+--R 
+--R
+--R   (6)  0
+--R                                                    Type: Polynomial(Integer)
+--E 343
+
+--S 344 of 368
+--Rm0d:=a0.2-r0b
+--R 
+--R   There are no library operations named a0 
+--R      Use HyperDoc Browse or issue
+--R                                 )what op a0
+--R      to learn if there is any operation containing " a0 " in its name.
+--R 
+--RDaly Bug
+--R   Cannot find a definition or applicable library operation named a0 
+--R      with argument type(s) 
+--R                               PositiveInteger
+--R      
+--R      Perhaps you should use "@" to indicate the required return type, 
+--R      or "$" to specify which version of the function you need.
+--E 344
+
+--S 345 of 368
+d0d:=D(m0d,x)
+--R 
+--R
+--R   (7)  0
+--R                                                    Type: Polynomial(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 368
+t0:=sqrt((-1+x)/(5+3*x))
+--R 
+--R
+--R         +------+
+--R         | x - 1
+--R   (1)   |------
+--R        \|3x + 5
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 368
+r0a:=-8/3*atanh(sqrt(3)*sqrt((-1+x)/(5+3*x)))/sqrt(3)+1/3*(5+3*x)*_
+   sqrt((-1+x)/(5+3*x))
+--R 
+--R
+--R                      +------+                 +------+
+--R                  +-+ | x - 1              +-+ | x - 1
+--R        - 8atanh(\|3  |------ ) + (3x + 5)\|3  |------
+--R                     \|3x + 5                 \|3x + 5
+--R   (2)  -----------------------------------------------
+--R                               +-+
+--R                             3\|3
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 368
+r0b:=-8/3*atanh(sqrt(3)*sqrt((-1+x)/(5+3*x)))/sqrt(3)+_
+   8/3*sqrt((-1+x)/(5+3*x))/(1+3*(1-x)/(5+3*x))
+--R 
+--R
+--R                      +------+                 +------+
+--R                  +-+ | x - 1              +-+ | x - 1
+--R        - 8atanh(\|3  |------ ) + (3x + 5)\|3  |------
+--R                     \|3x + 5                 \|3x + 5
+--R   (3)  -----------------------------------------------
+--R                               +-+
+--R                             3\|3
+--R                                                    Type: Expression(Integer)
+--E 348
+
+--S 349 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 350
+
+)clear all
+
+--S 351 of 368
+t0:=sqrt((-1+5*x)/(1+7*x))/x^2
+--R 
+--R
+--R         +------+
+--R         |5x - 1
+--R         |------
+--R        \|7x + 1
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 351
+
+--S 352 of 368
+r0a:=12*atan(sqrt((-1+5*x)/(1+7*x)))-(1+7*x)*sqrt((-1+5*x)/(1+7*x))/x
+--R 
+--R
+--R                  +------+               +------+
+--R                  |5x - 1                |5x - 1
+--R        12x atan( |------ ) + (- 7x - 1) |------
+--R                 \|7x + 1               \|7x + 1
+--R   (2)  -----------------------------------------
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 368
+r0b:=12*atan(sqrt((-1+5*x)/(1+7*x)))-12*sqrt((-1+5*x)/(1+7*x))/_
+   (1+(-1+5*x)/(1+7*x))
+--R 
+--R
+--R                  +------+               +------+
+--R                  |5x - 1                |5x - 1
+--R        12x atan( |------ ) + (- 7x - 1) |------
+--R                 \|7x + 1               \|7x + 1
+--R   (3)  -----------------------------------------
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+--S 355 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 355
+
+)clear all
+
+--S 356 of 368
+t0:=x/((1+x)*sqrt((1-x)/(1+x)))
+--R 
+--R
+--R                x
+--R   (1)  -----------------
+--R                +-------+
+--R                |- x + 1
+--R        (x + 1) |-------
+--R               \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 368
+r0a:=(-1+x)/sqrt((1-x)/(1+x))
+--R 
+--R
+--R           x - 1
+--R   (2)  ----------
+--R         +-------+
+--R         |- x + 1
+--R         |-------
+--R        \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 357
+
+--S 358 of 368
+r0b:=-2*sqrt((1-x)/(1+x))/(1+(1-x)/(1+x))
+--R 
+--R
+--R                  +-------+
+--R                  |- x + 1
+--R   (3)  (- x - 1) |-------
+--R                 \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 368
+t0:=x/((1+x)*sqrt(-1+2/(1+x)))
+--R 
+--R
+--R                x
+--R   (1)  -----------------
+--R                +-------+
+--R                |- x + 1
+--R        (x + 1) |-------
+--R               \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 368
+r0:=-(1+x)*sqrt(-1+2/(1+x))
+--R 
+--R
+--R                  +-------+
+--R                  |- x + 1
+--R   (2)  (- x - 1) |-------
+--R                 \| x + 1
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 368
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 368
+t0:=x/((1+x)*sqrt((2+x)/(3+x)))
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R                +-----+
+--R                |x + 2
+--R        (x + 1) |-----
+--R               \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 368
+r0a:=-asinh(sqrt(2+x))+2*atanh(sqrt(2)*sqrt((2+x)/(3+x)))*sqrt(2)+_
+   sqrt(2+x)*sqrt(3+x)
+--R 
+--R
+--R                        +-----+
+--R          +-+       +-+ |x + 2            +-----+     +-----+ +-----+
+--R   (2)  2\|2 atanh(\|2  |----- ) - asinh(\|x + 2 ) + \|x + 2 \|x + 3
+--R                       \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 368
+r0b:=-atanh(sqrt((2+x)/(3+x)))+2*atanh(sqrt(2)*sqrt((2+x)/(3+x)))*_
+   sqrt(2)+sqrt((2+x)/(3+x))/(1+(-2-x)/(3+x))
+--R 
+--R
+--R                        +-----+           +-----+            +-----+
+--R          +-+       +-+ |x + 2            |x + 2             |x + 2
+--R   (3)  2\|2 atanh(\|2  |----- ) - atanh( |----- ) + (x + 3) |-----
+--R                       \|x + 3           \|x + 3            \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 366
+
+--S 367 of 368
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R                                                  +-----+
+--R                +-----+ +-----+       2           |x + 2
+--R        (x + 2)\|x + 2 \|x + 3  + (- x  - 5x - 6) |-----
+--R                                                 \|x + 3
+--R   (4)  -------------------------------------------------
+--R                         +-----+
+--R                         |x + 2  +-----+ +-----+
+--R                 (x + 3) |----- \|x + 2 \|x + 3
+--R                        \|x + 3
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 368
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 368
+
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder20c.input.pamphlet b/src/input/richder20c.input.pamphlet
new file mode 100644
index 0000000..4c821a0
--- /dev/null
+++ b/src/input/richder20c.input.pamphlet
@@ -0,0 +1,5304 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder20c.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|y'[x] f[y[x]]|
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder20c.output
+)spool richder20c.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 321
+t0:=1/sqrt(1+sqrt(1/x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         | +-+
+--R         | |1
+--R         | |-  + 1
+--R        \|\|x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 321
+r0:=3/2*atanh(sqrt(1+sqrt(1/x)))+x*sqrt(1+sqrt(1/x))-_
+   3/2*sqrt(1+sqrt(1/x))/sqrt(1/x)
+--R 
+--R
+--R                     +--------+                +--------+
+--R           +-+       | +-+            +-+      | +-+
+--R           |1        | |1             |1       | |1
+--R        3  |- atanh( | |-  + 1  + (2x |-  - 3) | |-  + 1
+--R          \|x       \|\|x            \|x      \|\|x
+--R   (2)  -------------------------------------------------
+--R                                 +-+
+--R                                 |1
+--R                              2  |-
+--R                                \|x
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 321
+t0:=sqrt(1+1/x)/(1+x)^2
+--R 
+--R
+--R           +-----+
+--R           |x + 1
+--R           |-----
+--R          \|  x
+--R   (1)  -----------
+--R         2
+--R        x  + 2x + 1
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 321
+r0:=2/sqrt(1+1/x)
+--R 
+--R
+--R            2
+--R   (2)  --------
+--R         +-----+
+--R         |x + 1
+--R         |-----
+--R        \|  x
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 321
+t0:=sqrt(1+1/x)/sqrt(1-x^2)
+--R 
+--R
+--R           +-----+
+--R           |x + 1
+--R           |-----
+--R          \|  x
+--R   (1)  -----------
+--R         +--------+
+--R         |   2
+--R        \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 321
+r0a:=2*asin(sqrt(x))*sqrt(1+1/x)*sqrt(1-x)*sqrt(x)/sqrt(1-x^2)
+--R 
+--R
+--R                    +-----+
+--R          +-------+ |x + 1  +-+      +-+
+--R        2\|- x + 1  |----- \|x asin(\|x )
+--R                   \|  x
+--R   (2)  ---------------------------------
+--R                    +--------+
+--R                    |   2
+--R                   \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 321
+r0b:=-2*x*atan(sqrt(-1+1/x))*sqrt(-1+1/x^2)*sqrt(-1+1/x)*sqrt(1+1/x)/_
+   (sqrt(-2*(1+1/x)+(1+1/x)^2)*sqrt(1-x^2))
+--R 
+--R
+--R             +-------+ +-----+      +-------+
+--R             |- x + 1  |x + 1       |- x + 1
+--R          2x |-------  |----- atan( |------- )
+--R            \|   x    \|  x        \|   x
+--R   (3)  - ------------------------------------
+--R                        +--------+
+--R                        |   2
+--R                       \|- x  + 1
+--R                                                    Type: Expression(Integer)
+--E 9
+
+--S 10 of 321
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 321
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 11
+
+)clear all
+
+--S 12 of 321
+t0:=1/(x+sqrt(3-2*x-x^2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-------------+
+--R         |   2
+--R        \|- x  - 2x + 3  + x
+--R                                                    Type: Expression(Integer)
+--E 12
+
+--S 13 of 321
+r0:=atan((sqrt(3)-sqrt(3-2*x-x^2))/x)-1/2*log(1+(sqrt(3)-_
+   sqrt(3-2*x-x^2))^2/x^2)+1/14*log(1+sqrt(3)+sqrt(7)-sqrt(3)*(sqrt(3)-_
+   sqrt(3-2*x-x^2))/x)*(7-sqrt(7))+1/14*log(1+sqrt(3)-sqrt(7)-_
+   sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))/x)*(7+sqrt(7))
+--R 
+--R
+--R   (2)
+--R                            +-------------+
+--R                        +-+ |   2               +-+     +-+
+--R           +-+         \|3 \|- x  - 2x + 3  + x\|7  + x\|3  + x - 3
+--R       (- \|7  + 7)log(--------------------------------------------)
+--R                                             x
+--R     + 
+--R                          +-------------+
+--R                      +-+ |   2               +-+     +-+
+--R         +-+         \|3 \|- x  - 2x + 3  - x\|7  + x\|3  + x - 3
+--R       (\|7  + 7)log(--------------------------------------------)
+--R                                           x
+--R     + 
+--R                    +-------------+                     +-------------+
+--R                +-+ |   2                               |   2              +-+
+--R            - 2\|3 \|- x  - 2x + 3  - 2x + 6           \|- x  - 2x + 3  - \|3
+--R     - 7log(--------------------------------) - 14atan(-----------------------)
+--R                            2                                     x
+--R                           x
+--R  /
+--R     14
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 14
+
+)clear all
+
+--S 15 of 321
+t0:=1/(x+sqrt(3-2*x-x^2))^2
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R           +-------------+
+--R           |   2
+--R        2x\|- x  - 2x + 3  - 2x + 3
+--R                                                    Type: Expression(Integer)
+--E 15
+
+--S 16 of 321
+r0:=-8/7*atanh((1+sqrt(3)-sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))/x)/sqrt(7))/_
+   sqrt(7)+2/7*(4-sqrt(3)+3*(sqrt(3)-sqrt(3-2*x-x^2))/x)/(2-sqrt(3)-_
+   2*(1+sqrt(3))*(sqrt(3)-sqrt(3-2*x-x^2))/x+sqrt(3)*(sqrt(3)-_
+   sqrt(3-2*x-x^2))^2/x^2)
+--R 
+--R
+--R   (2)
+--R                                  +-------------+
+--R                   +-+            |   2                2             +-+     2
+--R             (- 8x\|3  - 8x + 24)\|- x  - 2x + 3  + (8x  + 16x - 24)\|3  - 8x
+--R           + 
+--R             24x
+--R      *
+--R                    +-------------+
+--R                +-+ |   2               +-+
+--R               \|3 \|- x  - 2x + 3  + x\|3  + x - 3
+--R         atanh(------------------------------------)
+--R                                 +-+
+--R                               x\|7
+--R     + 
+--R                +-------------+
+--R            +-+ |   2                  2       +-+     2  +-+
+--R       - 3x\|7 \|- x  - 2x + 3  + ((- x  + 3x)\|3  + 4x )\|7
+--R  /
+--R                              +-------------+
+--R           +-+            +-+ |   2
+--R       (7x\|3  + 7x - 21)\|7 \|- x  - 2x + 3
+--R     + 
+--R             2             +-+     2        +-+
+--R       ((- 7x  - 14x + 21)\|3  + 7x  - 21x)\|7
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 17
+
+)clear all
+
+--S 18 of 321
+t0:=1/(x+sqrt(3-2*x-x^2))^3
+--R 
+--R
+--R                               1
+--R   (1)  -----------------------------------------------
+--R                       +-------------+
+--R           2           |   2               3     2
+--R        (2x  - 2x + 3)\|- x  - 2x + 3  - 2x  - 6x  + 9x
+--R                                                    Type: Expression(Integer)
+--E 18
+
+--S 19 of 321
+r0:=-12/49*atanh((1+sqrt(3)-sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))/x)/sqrt(7))/_
+   sqrt(7)-2/7*(4-sqrt(3)+(10-7*sqrt(3))*(sqrt(3)-sqrt(3-2*x-x^2))/x)/_
+   (sqrt(3)*(2-sqrt(3)-2*(1+sqrt(3))*(sqrt(3)-sqrt(3-2*x-x^2))/x+sqrt(3)*_
+   (sqrt(3)-sqrt(3-2*x-x^2))^2/x^2)^2)+4/49*sqrt(3)*(1+sqrt(3)-sqrt(3)*_
+   (sqrt(3)-sqrt(3-2*x-x^2))/x)/(2-sqrt(3)-2*(1+sqrt(3))*(sqrt(3)-_
+   sqrt(3-2*x-x^2))/x+sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))^2/x^2)+2/3*(3+_
+   2*sqrt(3))*(sqrt(3)-sqrt(3-2*x-x^2))^2/(x^2*(2-sqrt(3)-2*(1+sqrt(3))*_
+   (sqrt(3)-sqrt(3-2*x-x^2))/x+sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))^2/x^2)^2)-_
+   2*(sqrt(3)-sqrt(3-2*x-x^2))^3/(x^3*(2-sqrt(3)-2*(1+sqrt(3))*(sqrt(3)-_
+   sqrt(3-2*x-x^2))/x+sqrt(3)*(sqrt(3)-sqrt(3-2*x-x^2))^2/x^2)^2)
+--R 
+--R
+--R   (2)
+--R                         13        12        11          10          9
+--R                   - 192x   + 4224x   + 9504x   - 156576x   + 135792x
+--R                 + 
+--R                           8           7          6            5            4
+--R                   1707264x  - 4952664x  - 736776x  + 24441912x  - 46381896x
+--R                 + 
+--R                            3            2
+--R                   40415760x  - 19210608x  + 6141096x - 1417176
+--R              *
+--R                  +-+
+--R                 \|3
+--R             + 
+--R                   13        12         11          10          9           8
+--R               576x   + 7488x   - 24480x   - 354816x   + 560304x  + 3868560x
+--R             + 
+--R                         7           6            5            4            3
+--R               - 9445896x  - 4898880x  + 42987672x  - 73483200x  + 70543872x
+--R             + 
+--R                          2
+--R               - 39680928x  + 9920232x
+--R          *
+--R              +-------------+
+--R              |   2
+--R             \|- x  - 2x + 3
+--R         + 
+--R                   14        13         12         11          10          9
+--R               192x   - 2688x   - 40992x   + 32928x   + 926352x   - 895104x
+--R             + 
+--R                         8            7           6            5            4
+--R               - 7017192x  + 14344776x  + 6491016x  - 54255096x  + 88914672x
+--R             + 
+--R                          3            2
+--R               - 81566352x  + 42987672x  - 9920232x
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R               14        13         12         11           10           9
+--R           576x   + 4032x   - 50400x   - 80640x   + 1136016x   - 1006992x
+--R         + 
+--R                     8            7           6            5             4
+--R           - 9149112x  + 24572160x  + 2367792x  - 96262992x  + 167909112x
+--R         + 
+--R                       3            2
+--R           - 136678752x  + 62828136x  - 19840464x + 4251528
+--R      *
+--R                    +-------------+
+--R                +-+ |   2               +-+
+--R               \|3 \|- x  - 2x + 3  + x\|3  + x - 3
+--R         atanh(------------------------------------)
+--R                                 +-+
+--R                               x\|7
+--R     + 
+--R                   13        12         11          10          9           8
+--R               152x   - 4268x   - 17488x   + 141320x   + 149490x  - 1662165x
+--R             + 
+--R                       7           6            5            4            3
+--R               1899396x  + 4498821x  - 16351956x  + 22205340x  - 15103422x
+--R             + 
+--R                       2
+--R               4481163x  - 236196x
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R                 13        12        11          10         9           8
+--R           - 128x   - 4204x   - 2904x   + 228256x   - 52200x  - 3006117x
+--R         + 
+--R                   7           6            5            4            3
+--R           4641084x  + 8676801x  - 31196826x  + 36705150x  - 22989744x
+--R         + 
+--R                   2
+--R           8929521x  - 1928934x
+--R      *
+--R              +-------------+
+--R          +-+ |   2
+--R         \|7 \|- x  - 2x + 3
+--R     + 
+--R                    14       13         12         11          10         9
+--R               - 96x   + 124x   + 23028x   + 30888x   - 589744x   - 34095x
+--R             + 
+--R                       8           7            6            5            4
+--R               5409621x  - 6851493x  - 12244527x  + 38889234x  - 42526944x
+--R             + 
+--R                        3           2
+--R               25537599x  - 9572499x  + 1928934x
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R                 14        13         12          11          10          9
+--R           - 616x   - 4900x   + 46580x   + 179176x   - 934470x   - 945639x
+--R         + 
+--R                   8           7            6            5            4
+--R           8367651x  - 8978607x  - 17760627x  + 62153082x  - 78784488x
+--R         + 
+--R                    3            2
+--R           49633965x  - 13679685x  + 708588x
+--R      *
+--R          +-+
+--R         \|7
+--R  /
+--R                   13         12         11          10          9           8
+--R               784x   - 17248x   - 38808x   + 639352x   - 554484x  - 6971328x
+--R             + 
+--R                        7           6            5             4             3
+--R               20223378x  + 3008502x  - 99804474x  + 189392742x  - 165031020x
+--R             + 
+--R                        2
+--R               78443316x  - 25076142x + 5786802
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R                  13         12         11           10           9            8
+--R           - 2352x   - 30576x   + 99960x   + 1448832x   - 2287908x  - 15796620x
+--R         + 
+--R                    7            6             5             4             3
+--R           38570742x  + 20003760x  - 175532994x  + 300056400x  - 288054144x
+--R         + 
+--R                     2
+--R           162030456x  - 40507614x
+--R      *
+--R              +-------------+
+--R          +-+ |   2
+--R         \|7 \|- x  - 2x + 3
+--R     + 
+--R                     14         13          12          11           10
+--R               - 784x   + 10976x   + 167384x   - 134456x   - 3782604x
+--R             + 
+--R                       9            8            7            6             5
+--R               3655008x  + 28653534x  - 58574502x  - 26504982x  + 221541642x
+--R             + 
+--R                           4             3             2
+--R               - 363068244x  + 333062604x  - 175532994x  + 40507614x
+--R          *
+--R              +-+
+--R             \|3
+--R         + 
+--R                  14         13          12          11           10           9
+--R           - 2352x   - 16464x   + 205800x   + 329280x   - 4638732x   + 4111884x
+--R         + 
+--R                    8             7           6             5             4
+--R           37358874x  - 100336320x  - 9668484x  + 393073884x  - 685628874x
+--R         + 
+--R                     3             2
+--R           558104904x  - 256548222x  + 81015228x - 17360406
+--R      *
+--R          +-+
+--R         \|7
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 20
+
+)clear all
+
+--S 21 of 321
+t0:=1/(x+sqrt(-3-2*x+x^2))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +-----------+
+--R         | 2
+--R        \|x  - 2x - 3  + x
+--R                                                    Type: Expression(Integer)
+--E 21
+
+--S 22 of 321
+r0:=2*log(1-x-sqrt(-3-2*x+x^2))-3/2*log(x+sqrt(-3-2*x+x^2))+(-2)/(1-x-_
+   sqrt(-3-2*x+x^2))
+--R 
+--R
+--R   (2)
+--R            +-----------+               +-----------+
+--R            | 2                         | 2
+--R       (- 3\|x  - 2x - 3  - 3x + 3)log(\|x  - 2x - 3  + x)
+--R     + 
+--R          +-----------+                 +-----------+
+--R          | 2                           | 2
+--R       (4\|x  - 2x - 3  + 4x - 4)log(- \|x  - 2x - 3  - x + 1) + 4
+--R  /
+--R       +-----------+
+--R       | 2
+--R     2\|x  - 2x - 3  + 2x - 2
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 23
+
+)clear all
+
+--S 24 of 321
+t0:=1/(x+sqrt(-3-2*x+x^2))^2
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R           +-----------+
+--R           | 2               2
+--R        2x\|x  - 2x - 3  + 2x  - 2x - 3
+--R                                                    Type: Expression(Integer)
+--E 24
+
+--S 25 of 321
+r0:=4*log(1-x-sqrt(-3-2*x+x^2))-4*log(x+sqrt(-3-2*x+x^2))+(-2)/(1-x-_
+   sqrt(-3-2*x+x^2))+3/2/(x+sqrt(-3-2*x+x^2))
+--R 
+--R
+--R   (2)
+--R                    +-----------+                        +-----------+
+--R                    | 2                2                 | 2
+--R       ((- 16x + 8)\|x  - 2x - 3  - 16x  + 24x + 24)log(\|x  - 2x - 3  + x)
+--R     + 
+--R                  +-----------+                          +-----------+
+--R                  | 2                2                   | 2
+--R       ((16x - 8)\|x  - 2x - 3  + 16x  - 24x - 24)log(- \|x  - 2x - 3  - x + 1)
+--R     + 
+--R         +-----------+
+--R         | 2
+--R       7\|x  - 2x - 3  + 7x - 3
+--R  /
+--R              +-----------+
+--R              | 2               2
+--R     (4x - 2)\|x  - 2x - 3  + 4x  - 6x - 6
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 26
+
+)clear all
+
+--S 27 of 321
+t0:=1/(x+sqrt(-3-2*x+x^2))^3
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                       +-----------+
+--R           2           | 2               3     2
+--R        (4x  - 2x - 3)\|x  - 2x - 3  + 4x  - 6x  - 9x
+--R                                                    Type: Expression(Integer)
+--E 27
+
+--S 28 of 321
+r0:=6*log(1-x-sqrt(-3-2*x+x^2))-6*log(x+sqrt(-3-2*x+x^2))+(-2)/(1-x-_
+   sqrt(-3-2*x+x^2))+3/4/(x+sqrt(-3-2*x+x^2))^2+4/(x+sqrt(-3-2*x+x^2))
+--R 
+--R
+--R   (2)
+--R                                         +-----------+
+--R                  3       2              | 2                 4       3       2
+--R           (- 192x  + 288x  + 240x - 72)\|x  - 2x - 3  - 192x  + 480x  + 336x
+--R         + 
+--R           - 504x - 216
+--R      *
+--R              +-----------+
+--R              | 2
+--R         log(\|x  - 2x - 3  + x)
+--R     + 
+--R                                       +-----------+
+--R                3       2              | 2                 4       3       2
+--R           (192x  - 288x  - 240x + 72)\|x  - 2x - 3  + 192x  - 480x  - 336x
+--R         + 
+--R           504x + 216
+--R      *
+--R                +-----------+
+--R                | 2
+--R         log(- \|x  - 2x - 3  - x + 1)
+--R     + 
+--R                         +-----------+
+--R           2             | 2                3       2
+--R       (96x  - 74x - 75)\|x  - 2x - 3  + 96x  - 170x  - 193x + 39
+--R  /
+--R                              +-----------+
+--R         3      2             | 2                4      3      2
+--R     (32x  - 48x  - 40x + 12)\|x  - 2x - 3  + 32x  - 80x  - 56x  + 84x + 36
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 29
+
+)clear all
+
+--S 30 of 321
+t0:=1/(x+sqrt(-3-4*x-x^2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-------------+
+--R         |   2
+--R        \|- x  - 4x - 3  + x
+--R                                                    Type: Expression(Integer)
+--E 30
+
+--S 31 of 321
+r0:=-atan(sqrt(-1-x)/sqrt(3+x))-1/2*log(1+(-1-x)/(3+x))+_
+   1/2*log(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/sqrt(3+x))-_
+   atan((1-3*sqrt(-1-x)/sqrt(3+x))/sqrt(2))*sqrt(2)
+--R 
+--R
+--R   (2)
+--R                +-----+              +-------+
+--R           - 2x\|x + 3  + (- 2x - 6)\|- x - 1
+--R       log(-----------------------------------)
+--R                             +-----+
+--R                     (x + 3)\|x + 3
+--R     + 
+--R                    +-----+     +-------+           +-------+
+--R           +-+     \|x + 3  - 3\|- x - 1           \|- x - 1           2
+--R       - 2\|2 atan(----------------------) - 2atan(----------) - log(-----)
+--R                         +-+ +-----+                 +-----+         x + 3
+--R                        \|2 \|x + 3                 \|x + 3
+--R  /
+--R     2
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R                                            +-------------+
+--R                       +-------+ +-----+    |   2
+--R                      \|- x - 1 \|x + 3  - \|- x  - 4x - 3
+--R   (3)  -----------------------------------------------------------------
+--R          +-------------+                            +-------------+
+--R          |   2                +-------+ +-----+     |   2              2
+--R        (\|- x  - 4x - 3  + x)\|- x - 1 \|x + 3  + x\|- x  - 4x - 3  + x
+--R                                                    Type: Expression(Integer)
+--E 32
+
+)clear all
+
+--S 33 of 321
+t0:=1/(x+sqrt(-3-4*x-x^2))^2
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R           +-------------+
+--R           |   2
+--R        2x\|- x  - 4x - 3  - 4x - 3
+--R                                                    Type: Expression(Integer)
+--E 33
+
+--S 34 of 321
+r0:=atan((1-3*sqrt(-1-x)/sqrt(3+x))/sqrt(2))/sqrt(2)+_
+   (1-sqrt(-1-x)/sqrt(3+x))/(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/sqrt(3+x))
+--R 
+--R
+--R   (2)
+--R                                              +-----+     +-------+
+--R           +-----+            +-------+      \|x + 3  - 3\|- x - 1
+--R       (2x\|x + 3  + (2x + 6)\|- x - 1 )atan(----------------------)
+--R                                                   +-+ +-----+
+--R                                                  \|2 \|x + 3
+--R     + 
+--R                 +-+ +-----+           +-+ +-------+
+--R       (- x - 3)\|2 \|x + 3  + (x + 3)\|2 \|- x - 1
+--R  /
+--R        +-+ +-----+            +-+ +-------+
+--R     2x\|2 \|x + 3  + (2x + 6)\|2 \|- x - 1
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                               +-------------+
+--R        +-------+ +-----+      |   2
+--R     2x\|- x - 1 \|x + 3  - 2x\|- x  - 4x - 3
+--R  /
+--R            +-------------+
+--R          2 |   2               2       +-------+ +-----+
+--R       (4x \|- x  - 4x - 3  - 8x  - 6x)\|- x - 1 \|x + 3
+--R     + 
+--R                    +-------------+
+--R            2       |   2                2
+--R       (- 8x  - 6x)\|- x  - 4x - 3  + 16x  + 24x + 9
+--R                                                    Type: Expression(Integer)
+--E 35
+
+)clear all
+
+--S 36 of 321
+t0:=1/(x+sqrt(-3-4*x-x^2))^3
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R                       +-------------+
+--R           2           |   2               3      2
+--R        (2x  - 4x - 3)\|- x  - 4x - 3  - 2x  - 12x  - 9x
+--R                                                    Type: Expression(Integer)
+--E 36
+
+--S 37 of 321
+r0:=-3/2*atan((1-3*sqrt(-1-x)/sqrt(3+x))/sqrt(2))/sqrt(2)+_
+   1/9*(-5+9*sqrt(-1-x)/sqrt(3+x))/(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/sqrt(3+x))+_
+   1/6*(-1+3*sqrt(-1-x)/sqrt(3+x))/(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/sqrt(3+x))-_
+   2/9*(2-sqrt(-1-x)/sqrt(3+x))/(1-3*(1+x)/(3+x)-2*sqrt(-1-x)/sqrt(3+x))^2
+--R 
+--R
+--R   (2)
+--R                2             +-------+ +-----+      3       2
+--R         ((- 36x  + 72x + 54)\|- x - 1 \|x + 3  + 36x  + 216x  + 162x)
+--R      *
+--R               +-----+     +-------+
+--R              \|x + 3  - 3\|- x - 1
+--R         atan(----------------------)
+--R                    +-+ +-----+
+--R                   \|2 \|x + 3
+--R     + 
+--R          2             +-+ +-------+ +-----+       3      2             +-+
+--R       (8x  + 56x + 15)\|2 \|- x - 1 \|x + 3  + (16x  + 42x  - 33x - 45)\|2
+--R  /
+--R         2             +-+ +-------+ +-----+         3       2         +-+
+--R     (24x  - 48x - 36)\|2 \|- x - 1 \|x + 3  + (- 24x  - 144x  - 108x)\|2
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                         +-------------+
+--R              6      5      4      3      2              |   2                6
+--R           (8x  + 16x  - 84x  - 80x  + 90x  + 108x + 27)\|- x  - 4x - 3  + 32x
+--R         + 
+--R              5       4       3       2
+--R           88x  - 160x  - 540x  - 432x  - 108x
+--R      *
+--R          +-------+ +-----+
+--R         \|- x - 1 \|x + 3
+--R     + 
+--R                                                      +-------------+
+--R             6      5       4       3       2         |   2               8
+--R       (- 32x  - 88x  + 160x  + 540x  + 432x  + 108x)\|- x  - 4x - 3  + 8x
+--R     + 
+--R          7     6       5       4       3       2
+--R       48x  + 4x  - 368x  - 482x  + 228x  + 729x  + 432x + 81
+--R  /
+--R                  9       8       7        6        5        4        3        2
+--R               16x  + 192x  + 144x  - 1792x  - 2240x  + 2352x  + 5292x  + 3024x
+--R             + 
+--R               567x
+--R          *
+--R              +-------------+
+--R              |   2
+--R             \|- x  - 4x - 3
+--R         + 
+--R                10       9        8        7       6         5         4
+--R           - 16x   - 320x  - 2032x  - 4480x  + 336x  + 13104x  + 17388x
+--R         + 
+--R                3        2
+--R           9072x  + 1701x
+--R      *
+--R          +-------+ +-----+
+--R         \|- x - 1 \|x + 3
+--R     + 
+--R              10       8        7        6         5         4        3        2
+--R           16x   - 768x  - 1920x  + 2704x  + 12272x  + 12252x  + 2448x  - 2781x
+--R         + 
+--R           - 1620x - 243
+--R      *
+--R          +-------------+
+--R          |   2
+--R         \|- x  - 4x - 3
+--R     + 
+--R            11       10       9        8         7         6         5        4
+--R       - 16x   - 128x   + 416x  + 7168x  + 27232x  + 45360x  + 33516x  + 3888x
+--R     + 
+--R              3        2
+--R       - 8991x  - 4860x  - 729x
+--R                                                    Type: Expression(Integer)
+--E 38
+
+)clear all
+
+--S 39 of 321
+t0:=x^3*(1+x)^3*(1+2*x)*sqrt(1-x^2-2*x^3-x^4)
+--R 
+--R
+--R                                     +-------------------+
+--R           7     6     5     4    3  |   4     3    2
+--R   (1)  (2x  + 7x  + 9x  + 5x  + x )\|- x  - 2x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 39
+
+--S 40 of 321
+r0a:=-1/15*(1-x^2-2*x^3-x^4)^(3/2)*(2+3*x^2+6*x^3+3*x^4)
+--R 
+--R
+--R                                                        +-------------------+
+--R           8      7      6      5     4     3    2      |   4     3    2
+--R        (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- x  - 2x  - x  + 1
+--R   (2)  ---------------------------------------------------------------------
+--R                                          15
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 321
+r0b:=-1/480*(15+8*(1/2+x)^2-16*(1/2+x)^4)^(3/2)-1/5120*(1-4*(1/2+x)^2)^2*_
+   (15+8*(1/2+x)^2-16*(1/2+x)^4)^(3/2)
+--R 
+--R
+--R   (3)
+--R                                                   +-------------------------+
+--R      8      7      6      5     4     3    2      |     4      3      2
+--R   (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- 16x  - 32x  - 16x  + 16
+--R   ---------------------------------------------------------------------------
+--R                                        60
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 321
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+--S 43 of 321
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)
+--R                                      +-------------------------+
+--R            7     6     5     4    3  |     4      3      2
+--R         (2x  + 7x  + 9x  + 5x  + x )\|- 16x  - 32x  - 16x  + 16
+--R      *
+--R          +-------------------+
+--R          |   4     3    2
+--R         \|- x  - 2x  - x  + 1
+--R     + 
+--R         11      10       9       8      7      5      4     3
+--R       8x   + 44x   + 100x  + 120x  + 72x  - 32x  - 20x  - 4x
+--R  /
+--R      +-------------------------+
+--R      |     4      3      2
+--R     \|- 16x  - 32x  - 16x  + 16
+--R                                                    Type: Expression(Integer)
+--E 43
+
+)clear all
+
+--S 44 of 321
+t0:=(1+2*x)*(x+x^2)^3*sqrt(1-(x+x^2)^2)
+--R 
+--R
+--R                                     +-------------------+
+--R           7     6     5     4    3  |   4     3    2
+--R   (1)  (2x  + 7x  + 9x  + 5x  + x )\|- x  - 2x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 321
+r0:=-1/15*(1-x^2-2*x^3-x^4)^(3/2)*(2+3*x^2+6*x^3+3*x^4)
+--R 
+--R
+--R                                                        +-------------------+
+--R           8      7      6      5     4     3    2      |   4     3    2
+--R        (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- x  - 2x  - x  + 1
+--R   (2)  ---------------------------------------------------------------------
+--R                                          15
+--R                                                    Type: Expression(Integer)
+--E 45
+
+--S 46 of 321
+r0b:=-1/480*(15+8*(1/2+x)^2-16*(1/2+x)^4)^(3/2)-1/5120*(1-4*(1/2+x)^2)^2*_
+   (15+8*(1/2+x)^2-16*(1/2+x)^4)^(3/2)
+--R 
+--R
+--R   (3)
+--R                                                   +-------------------------+
+--R      8      7      6      5     4     3    2      |     4      3      2
+--R   (3x  + 12x  + 18x  + 12x  + 2x  - 2x  - x  - 2)\|- 16x  - 32x  - 16x  + 16
+--R   ---------------------------------------------------------------------------
+--R                                        60
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 321
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R                                     +-------------------+
+--R           7     6     5     4    3  |   4     3    2
+--R   (4)  (2x  + 7x  + 9x  + 5x  + x )\|- x  - 2x  - x  + 1
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 321
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)
+--R                                      +-------------------------+
+--R            7     6     5     4    3  |     4      3      2
+--R         (2x  + 7x  + 9x  + 5x  + x )\|- 16x  - 32x  - 16x  + 16
+--R      *
+--R          +-------------------+
+--R          |   4     3    2
+--R         \|- x  - 2x  - x  + 1
+--R     + 
+--R         11      10       9       8      7      5      4     3
+--R       8x   + 44x   + 100x  + 120x  + 72x  - 32x  - 20x  - 4x
+--R  /
+--R      +-------------------------+
+--R      |     4      3      2
+--R     \|- 16x  - 32x  - 16x  + 16
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 321
+t0:=(3*x+3*x^2+x^3)/(1+4*x+6*x^2+4*x^3+x^4)
+--R 
+--R
+--R              3     2
+--R             x  + 3x  + 3x
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  + 4x  + 6x  + 4x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 49
+
+--S 50 of 321
+r0:=1/3/(1+x)^3+log(1+x)
+--R 
+--R
+--R           3     2
+--R        (3x  + 9x  + 9x + 3)log(x + 1) + 1
+--R   (2)  ----------------------------------
+--R                  3     2
+--R                3x  + 9x  + 9x + 3
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 321
+t0:=(-1+3*x-3*x^2+x^3)/(1+4*x+6*x^2+4*x^3+x^4)
+--R 
+--R
+--R            3     2
+--R           x  - 3x  + 3x - 1
+--R   (1)  -----------------------
+--R         4     3     2
+--R        x  + 4x  + 6x  + 4x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 52
+
+--S 53 of 321
+r0:=8/3/(1+x)^3+(-6)/(1+x)^2+6/(1+x)+log(1+x)
+--R 
+--R
+--R           3     2                          2
+--R        (3x  + 9x  + 9x + 3)log(x + 1) + 18x  + 18x + 8
+--R   (2)  -----------------------------------------------
+--R                         3     2
+--R                       3x  + 9x  + 9x + 3
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 321
+t0:=(8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                +---------------------+
+--R            4     3     2       |   4     3     2
+--R   (1)  (- x  + 4x  - 8x  + 8x)\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 321
+--r0:=1/7*(3-2*(-1+x)^2-(-1+x)^4)^(3/2)*(-1+x)+_
+--   16/5*elliptic_e(asin(1-x),-1/3)*sqrt(3)-_
+--   176/35*elliptic_f(asin(1-x),-1/3)*sqrt(3)+2/35*(13-3*(-1+x)^2)*_
+--   (-1+x)*sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 56
+
+--S 57 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 57
+
+)clear all
+
+--S 58 of 321
+t0:=(8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R         +---------------------+
+--R         |   4     3     2
+--R   (1)  \|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 321
+--r0:=2*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   4*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/3*(-1+x)*_
+--   sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 59
+
+--S 60 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 60
+
+)clear all
+
+--S 61 of 321
+t0:=1/(8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R         +---------------------+
+--R         |   4     3     2
+--R        \|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 321
+--r0:=-elliptic_f(asin(1-x),-1/3)/sqrt(3)
+--E 62
+
+--S 63 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 63
+
+)clear all
+
+--S 64 of 321
+t0:=1/(8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                1
+--R   (1)  - ---------------------------------------------
+--R                                +---------------------+
+--R            4     3     2       |   4     3     2
+--R          (x  - 4x  + 8x  - 8x)\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 321
+--r0:=1/8*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   1/4*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/24*(5+(-1+x)^2)*_
+--   (-1+x)/sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 65
+
+--S 66 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 66
+
+)clear all
+
+--S 67 of 321
+t0:=1/(8*x-8*x^2+4*x^3-x^4)^(5/2)
+--R 
+--R
+--R   (1)
+--R                                      1
+--R   -----------------------------------------------------------------------
+--R                                                   +---------------------+
+--R     8     7      6      5       4       3      2  |   4     3     2
+--R   (x  - 8x  + 32x  - 80x  + 128x  - 128x  + 64x )\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 321
+--r0:=1/72*(5+(-1+x)^2)*(-1+x)/(3-2*(-1+x)^2-(-1+x)^4)^(3/2)+_
+--   7/144*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   11/144*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/432*(26+7*(-1+x)^2)*_
+--   (-1+x)/sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 68
+
+--S 69 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 69
+
+)clear all
+
+--S 70 of 321
+t0:=((2-x)*x*(4-2*x+x^2))^(3/2)
+--R 
+--R
+--R                                +---------------------+
+--R            4     3     2       |   4     3     2
+--R   (1)  (- x  + 4x  - 8x  + 8x)\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 321
+--r0:=1/7*(3-2*(-1+x)^2-(-1+x)^4)^(3/2)*(-1+x)+_
+--   16/5*elliptic_e(asin(1-x),-1/3)*sqrt(3)-_
+--   176/35*elliptic_f(asin(1-x),-1/3)*sqrt(3)+2/35*(13-3*(-1+x)^2)*_
+--   (-1+x)*sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 71
+
+--S 72 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 72
+
+)clear all
+
+--S 73 of 321
+t0:=((2-x)*x*(4-2*x+x^2))^(1/2)
+--R 
+--R
+--R         +---------------------+
+--R         |   4     3     2
+--R   (1)  \|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 321
+--r0:=2*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   4*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/3*(-1+x)*_
+--   sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 74
+
+--S 75 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 75
+
+)clear all
+
+--S 76 of 321
+t0:=1/((2-x)*x*(4-2*x+x^2))^(1/2)
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R         +---------------------+
+--R         |   4     3     2
+--R        \|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 321
+--r0:=-elliptic_f(asin(1-x),-1/3)/sqrt(3)
+--E 77
+
+--S 78 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 78
+
+)clear all
+
+--S 79 of 321
+t0:=1/((2-x)*x*(4-2*x+x^2))^(3/2)
+--R 
+--R
+--R                                1
+--R   (1)  - ---------------------------------------------
+--R                                +---------------------+
+--R            4     3     2       |   4     3     2
+--R          (x  - 4x  + 8x  - 8x)\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 321
+--r0:=1/8*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   1/4*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/24*(5+(-1+x)^2)*_
+--   (-1+x)/sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 80
+
+--S 81 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 81
+
+)clear all
+
+--S 82 of 321
+t0:=1/((2-x)*x*(4-2*x+x^2))^(5/2)
+--R 
+--R
+--R   (1)
+--R                                      1
+--R   -----------------------------------------------------------------------
+--R                                                   +---------------------+
+--R     8     7      6      5       4       3      2  |   4     3     2
+--R   (x  - 8x  + 32x  - 80x  + 128x  - 128x  + 64x )\|- x  + 4x  - 8x  + 8x
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 321
+--r0:=1/72*(5+(-1+x)^2)*(-1+x)/(3-2*(-1+x)^2-(-1+x)^4)^(3/2)+_
+--   7/144*elliptic_e(asin(1-x),-1/3)/sqrt(3)-_
+--   11/144*elliptic_f(asin(1-x),-1/3)/sqrt(3)+1/432*_
+--   (26+7*(-1+x)^2)*(-1+x)/sqrt(3-2*(-1+x)^2-(-1+x)^4)
+--E 83
+
+--S 84 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 84
+
+)clear all
+
+--S 85 of 321
+t0:=(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^4
+--R 
+--R
+--R   (1)
+--R      8 16        7 15       2 6 14       3 5 13           6        4 4  12
+--R     d x   + 16c d x   + 112c d x   + 448c d x   + (16a c d  + 1120c d )x
+--R   + 
+--R            2 5        5 3  11          3 4        6 2  10
+--R     (192a c d  + 1792c d )x   + (960a c d  + 1792c d )x
+--R   + 
+--R             4 3        7   9       2 2 4          5 2       8  8
+--R     (2560a c d  + 1024c d)x  + (96a c d  + 3840a c d  + 256c )x
+--R   + 
+--R          2 3 3          6   7         2 4 2          7  6        2 5   5
+--R     (768a c d  + 3072a c d)x  + (2304a c d  + 1024a c )x  + 3072a c d x
+--R   + 
+--R          3 3 2        2 6  4        3 4   3        3 5 2       4 4
+--R     (256a c d  + 1536a c )x  + 1024a c d x  + 1024a c x  + 256a c
+--R                                                    Type: Polynomial(Integer)
+--E 85
+
+--S 86 of 321
+r0:=c^4*(c^3+4*a*d^2)^4*x/d^8-8/3*c^5*(c^3+4*a*d^2)^3*(c/d+x)^3/d^6+_
+   4/5*c^3*(c^3+4*a*d^2)^2*(7*c^3+4*a*d^2)*(c/d+x)^5/d^4-8/7*c^4*_
+   (c^3+4*a*d^2)*(7*c^3+12*a*d^2)*(c/d+x)^7/d^2+2/9*c^2*(35*c^6+_
+   120*a*c^3*d^2+48*a^2*d^4)*(c/d+x)^9-8/11*c^3*d^2*(7*c^3+12*a*d^2)*_
+   (c/d+x)^11+4/13*c*d^4*(7*c^3+4*a*d^2)*(c/d+x)^13-8/15*c^2*_
+   d^6*(c/d+x)^15+1/17*d^8*(c/d+x)^17
+--R 
+--R
+--R   (2)
+--R        1  17 17      16 16   112  2 15 15      3 14 14
+--R       -- d  x   + c d  x   + --- c d  x   + 32c d  x
+--R       17                      15
+--R     + 
+--R        16      15   1120  4 13  13         2 14   448  5 12  12
+--R       (-- a c d   + ---- c d  )x   + (16a c d   + --- c d  )x
+--R        13            13                            3
+--R     + 
+--R        960    3 13   1792  6 11  11          4 12   512  7 10  10
+--R       (--- a c d   + ---- c d  )x   + (256a c d   + --- c d  )x
+--R         11            11                             5
+--R     + 
+--R        32  2 2 13   1280    5 11   256  8 9  9       2 3 12         6 10  8
+--R       (-- a c d   + ---- a c d   + --- c d )x  + (96a c d   + 384a c d  )x
+--R         3             3             9
+--R     + 
+--R        2304  2 4 11   1024    7 9  7       2 5 10 6
+--R       (---- a c d   + ---- a c d )x  + 512a c d  x
+--R          7              7
+--R     + 
+--R        256  3 3 11   1536  2 6 9  5       3 4 10 4   1024  3 5 9 3       4 4 9
+--R       (--- a c d   + ---- a c d )x  + 256a c d  x  + ---- a c d x  + 256a c d x
+--R         5              5                               3
+--R     + 
+--R         1792  3 8 6   5984  2 11 4   31664    14 2    76627  17
+--R       - ---- a c d  - ---- a c  d  - ----- a c  d  - ------ c
+--R          15            105            3003           109395
+--R  /
+--R      9
+--R     d
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 86
+
+--S 87 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 321
+t0:=(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^3
+--R 
+--R
+--R   (1)
+--R      6 12        5 11      2 4 10       3 3 9           4       4 2  8
+--R     d x   + 12c d x   + 60c d x   + 160c d x  + (12a c d  + 240c d )x
+--R   + 
+--R           2 3       5   7          3 2      6  6         4   5
+--R     (96a c d  + 192c d)x  + (288a c d  + 64c )x  + 384a c d x
+--R   + 
+--R         2 2 2         5  4       2 3   3       2 4 2      3 3
+--R     (48a c d  + 192a c )x  + 192a c d x  + 192a c x  + 64a c
+--R                                                    Type: Polynomial(Integer)
+--E 88
+
+--S 89 of 321
+r0:=64*a^3*c^3*x+64*a^2*c^4*x^3+48*a^2*c^3*d*x^4+48/5*a*c^2*(4*c^3+a*d^2)*_
+   x^5+64*a*c^4*d*x^6+32/7*c^3*(2*c^3+9*a*d^2)*x^7+12*c^2*d*(2*c^3+a*d^2)*_
+   x^8+4/3*c*d^2*(20*c^3+a*d^2)*x^9+16*c^3*d^3*x^10+60/11*c^2*d^4*x^11+_
+   c*d^5*x^12+1/13*d^6*x^13
+--R 
+--R
+--R   (2)
+--R      1  6 13      5 12   60  2 4 11      3 3 10    4      4   80  4 2  9
+--R     -- d x   + c d x   + -- c d x   + 16c d x   + (- a c d  + -- c d )x
+--R     13                   11                        3           3
+--R   + 
+--R           2 3      5   8    288    3 2   64  6  7        4   6
+--R     (12a c d  + 24c d)x  + (--- a c d  + -- c )x  + 64a c d x
+--R                              7            7
+--R   + 
+--R      48  2 2 2   192    5  5      2 3   4      2 4 3      3 3
+--R     (-- a c d  + --- a c )x  + 48a c d x  + 64a c x  + 64a c x
+--R       5           5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 89
+
+--S 90 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 321
+t0:=(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^2
+--R 
+--R
+--R   (1)
+--R      4 8       3 7      2 2 6      3   5          2      4  4        2   3
+--R     d x  + 8c d x  + 24c d x  + 32c d x  + (8a c d  + 16c )x  + 32a c d x
+--R   + 
+--R          3 2      2 2
+--R     32a c x  + 16a c
+--R                                                    Type: Polynomial(Integer)
+--E 91
+
+--S 92 of 321
+r0:=16*a^2*c^2*x+32/3*a*c^3*x^3+8*a*c^2*d*x^4+8/5*c*(2*c^3+a*d^2)*x^5+_
+   16/3*c^3*d*x^6+24/7*c^2*d^2*x^7+c*d^3*x^8+1/9*d^4*x^9
+--R 
+--R
+--R   (2)
+--R     1  4 9      3 8   24  2 2 7   16  3   6    8      2   16  4  5       2   4
+--R     - d x  + c d x  + -- c d x  + -- c d x  + (- a c d  + -- c )x  + 8a c d x
+--R     9                  7           3           5           5
+--R   + 
+--R     32    3 3      2 2
+--R     -- a c x  + 16a c x
+--R      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 92
+
+--S 93 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 321
+t0:=4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4
+--R 
+--R
+--R         2 4         3     2 2
+--R   (1)  d x  + 4c d x  + 4c x  + 4a c
+--R                                                    Type: Polynomial(Integer)
+--E 94
+
+--S 95 of 321
+r0:=4*a*c*x+4/3*c^2*x^3+c*d*x^4+1/5*d^2*x^5
+--R 
+--R
+--R        1  2 5        4   4  2 3
+--R   (2)  - d x  + c d x  + - c x  + 4a c x
+--R        5                 3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 95
+
+--S 96 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 321
+t0:=1/(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R         2 4         3     2 2
+--R        d x  + 4c d x  + 4c x  + 4a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 97
+
+--S 98 of 321
+r0:=1/4*atanh(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)-2*d*sqrt(-a))))/(c^(3/4)*_
+   sqrt(-a)*sqrt(c^(3/2)-2*d*sqrt(-a)))-1/4*atanh(d*(c/d+x)/(c^(1/4)*_
+   sqrt(c^(3/2)+2*d*sqrt(-a))))/(c^(3/4)*sqrt(-a)*sqrt(c^(3/2)+2*d*sqrt(-a)))
+--R 
+--R
+--R   (2)
+--R        +----------------+
+--R        |  +-+      +---+               d x + c
+--R       \|c\|c  + 2d\|- a  atanh(-----------------------)
+--R                                     +----------------+
+--R                                4+-+ |  +-+      +---+
+--R                                \|c \|c\|c  - 2d\|- a
+--R     + 
+--R          +----------------+
+--R          |  +-+      +---+               d x + c
+--R       - \|c\|c  - 2d\|- a  atanh(-----------------------)
+--R                                       +----------------+
+--R                                  4+-+ |  +-+      +---+
+--R                                  \|c \|c\|c  + 2d\|- a
+--R  /
+--R                  +----------------+ +----------------+
+--R       +---+4+-+3 |  +-+      +---+  |  +-+      +---+
+--R     4\|- a \|c  \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 321
+t0:=1/(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        4 8       3 7      2 2 6      3   5          2      4  4        2   3
+--R       d x  + 8c d x  + 24c d x  + 32c d x  + (8a c d  + 16c )x  + 32a c d x
+--R     + 
+--R            3 2      2 2
+--R       32a c x  + 16a c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 100
+
+--S 101 of 321
+r0:=-1/16*(c/d+x)*(c^3-4*a*d^2-c*d^2*(c/d+x)^2)/(a*c*(c^3+4*a*d^2)*(c*_
+   (4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))-1/32*atanh(d*(c/d+x)/_
+   (c^(1/4)*sqrt(c^(3/2)-2*d*sqrt(-a))))*(c^3+6*a*d^2-c^(3/2)*d*sqrt(-a))/_
+   ((-a)^(3/2)*c^(7/4)*(c^3+4*a*d^2)*sqrt(c^(3/2)-2*d*sqrt(-a)))+_
+   1/32*atanh(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+2*d*sqrt(-a))))*(c^3+_
+   6*a*d^2+c^(3/2)*d*sqrt(-a))/((-a)^(3/2)*c^(7/4)*(c^3+4*a*d^2)*_
+   sqrt(c^(3/2)+2*d*sqrt(-a)))
+--R 
+--R
+--R   (2)
+--R                 3 4     2 2 3     3   2       2   +---+ +-+        4    3 2  4
+--R           (- c d x  - 4c d x  - 4c d x  - 4a c d)\|- a \|c  + (6a d  + c d )x
+--R         + 
+--R                   3     4   3         2 2     5  2      2   2       4
+--R           (24a c d  + 4c d)x  + (24a c d  + 4c )x  + 24a c d  + 4a c
+--R      *
+--R          +----------------+
+--R          |  +-+      +---+               d x + c
+--R         \|c\|c  + 2d\|- a  atanh(-----------------------)
+--R                                       +----------------+
+--R                                  4+-+ |  +-+      +---+
+--R                                  \|c \|c\|c  - 2d\|- a
+--R     + 
+--R                 3 4     2 2 3     3   2       2   +---+ +-+
+--R           (- c d x  - 4c d x  - 4c d x  - 4a c d)\|- a \|c
+--R         + 
+--R                  4    3 2  4             3     4   3           2 2     5  2
+--R           (- 6a d  - c d )x  + (- 24a c d  - 4c d)x  + (- 24a c d  - 4c )x
+--R         + 
+--R                2   2       4
+--R           - 24a c d  - 4a c
+--R      *
+--R          +----------------+
+--R          |  +-+      +---+               d x + c
+--R         \|c\|c  - 2d\|- a  atanh(-----------------------)
+--R                                       +----------------+
+--R                                  4+-+ |  +-+      +---+
+--R                                  \|c \|c\|c  + 2d\|- a
+--R     + 
+--R              2 3     2   2        2     3             +---+4+-+3
+--R         (2c d x  + 6c d x  + (8a d  + 4c )x + 8a c d)\|- a \|c
+--R      *
+--R          +----------------+ +----------------+
+--R          |  +-+      +---+  |  +-+      +---+
+--R         \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R  /
+--R              2   4        4 2  4        2 2 3         5   3
+--R         (128a c d  + 32a c d )x  + (512a c d  + 128a c d)x
+--R       + 
+--R              2 3 2         6  2       3 2 2       2 5
+--R         (512a c d  + 128a c )x  + 512a c d  + 128a c
+--R    *
+--R                   +----------------+ +----------------+
+--R        +---+4+-+3 |  +-+      +---+  |  +-+      +---+
+--R       \|- a \|c  \|c\|c  - 2d\|- a  \|c\|c  + 2d\|- a
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 321
+t0:=(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^(3/2)
+--R 
+--R
+--R                                        +-----------------------------+
+--R          2 4         3     2 2         | 2 4         3     2 2
+--R   (1)  (d x  + 4c d x  + 4c x  + 4a c)\|d x  + 4c d x  + 4c x  + 4a c
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 321
+--r0:=1/7*(c/d+x)*(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4)^(3/2)+_
+--   2/35*c*(c/d+x)*(7*c^3+20*a*d^2-3*c*d^2*(c/d+x)^2)*sqrt(c*(4*a+c^3/d^2)-_
+--   2*c^2*(c/d+x)^2+d^2*(c/d+x)^4)/d^2+16/35*c^(15/4)*(c^3+8*a*d^2)*_
+--   elliptic_e(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+2*d*sqrt(-a)))),_
+--   (c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*(c^(3/2)-2*d*sqrt(-a))*_
+--   sqrt(c^(3/2)+2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)-2*d*_
+--   sqrt(-a))*sqrt(c)))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+2*d*sqrt(-a))*_
+--   sqrt(c)))/(d^5*sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))+_
+--   16/35*c^(9/4)*elliptic_f(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+2*d*_
+--   sqrt(-a)))),(c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*(a*c^3*d+_
+--   20*a^2*d^3+2*c^(9/2)*sqrt(-a)+16*a*c^(3/2)*d^2*sqrt(-a))*sqrt(c^(3/2)+_
+--   2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)-2*d*sqrt(-a))*sqrt(c)))*_
+--   sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+2*d*sqrt(-a))*sqrt(c)))/(d^4*sqrt(c*_
+--   (4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))
+--E 104
+
+--S 105 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 105
+
+)clear all
+
+--S 106 of 321
+t0:=(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^(1/2)
+--R 
+--R
+--R         +-----------------------------+
+--R         | 2 4         3     2 2
+--R   (1)  \|d x  + 4c d x  + 4c x  + 4a c
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 321
+--r0:=1/3*(c/d+x)*sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4)+_
+--   2/3*c^(11/4)*elliptic_e(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+2*d*_
+--   sqrt(-a)))),(c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*(c^(3/2)-_
+--   2*d*sqrt(-a))*sqrt(c^(3/2)+2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/_
+--   ((c^(3/2)-2*d*sqrt(-a))*sqrt(c)))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+_
+--   2*d*sqrt(-a))*sqrt(c)))/(d^3*sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+_
+--   d^2*(c/d+x)^4))+4/3*c^(5/4)*elliptic_f(asin(d*(c/d+x)/(c^(1/4)*_
+--   sqrt(c^(3/2)+2*d*sqrt(-a)))),(c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-_
+--   2*d*sqrt(-a)))*sqrt(-a)*(c^(3/2)-2*d*sqrt(-a))*sqrt(c^(3/2)+_
+--   2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)-2*d*sqrt(-a))*sqrt(c)))*_
+--   sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+2*d*sqrt(-a))*sqrt(c)))/(d^2*_
+--   sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))
+--E 107
+
+--S 108 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 108
+
+)clear all
+
+--S 109 of 321
+t0:=1/(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^(1/2)
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R         +-----------------------------+
+--R         | 2 4         3     2 2
+--R        \|d x  + 4c d x  + 4c x  + 4a c
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 321
+--r0:=c^(1/4)*elliptic_f(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+_
+--   2*d*sqrt(-a)))),(c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*_
+--   sqrt(c^(3/2)+2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)-_
+--   2*d*sqrt(-a))*sqrt(c)))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+_
+--   2*d*sqrt(-a))*sqrt(c)))/(d*sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+_
+--   d^2*(c/d+x)^4))
+--E 110
+
+--S 111 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 111
+
+)clear all
+
+--S 112 of 321
+t0:=1/(4*a*c+4*c^2*x^2+4*c*d*x^3+d^2*x^4)^(3/2)
+--R 
+--R
+--R                                       1
+--R   (1)  ---------------------------------------------------------------
+--R                                        +-----------------------------+
+--R          2 4         3     2 2         | 2 4         3     2 2
+--R        (d x  + 4c d x  + 4c x  + 4a c)\|d x  + 4c d x  + 4c x  + 4a c
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 321
+--r0:=-1/8*(c/d+x)*(c^3-4*a*d^2-c*d^2*(c/d+x)^2)/(a*c*(c^3+4*a*d^2)*_
+--   sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))+1/8*c^(3/4)*_
+--   elliptic_e(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+2*d*sqrt(-a)))),_
+--   (c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*(c^(3/2)-2*d*sqrt(-a))*_
+--   sqrt(c^(3/2)+2*d*sqrt(-a))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)-2*d*_
+--   sqrt(-a))*sqrt(c)))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+2*d*sqrt(-a))*_
+--   sqrt(c)))/(a*d*(c^3+4*a*d^2)*sqrt(c*(4*a+c^3/d^2)-2*c^2*(c/d+x)^2+_
+--   d^2*(c/d+x)^4))-1/4*elliptic_f(asin(d*(c/d+x)/(c^(1/4)*sqrt(c^(3/2)+_
+--   2*d*sqrt(-a)))),(c^(3/2)+2*d*sqrt(-a))/(c^(3/2)-2*d*sqrt(-a)))*_
+--   (c^(3/2)-2*d*sqrt(-a))*sqrt(c^(3/2)+2*d*sqrt(-a))*sqrt(1-d^2*(c/d+_
+--   x)^2/((c^(3/2)-2*d*sqrt(-a))*sqrt(c)))*sqrt(1-d^2*(c/d+x)^2/((c^(3/2)+_
+--   2*d*sqrt(-a))*sqrt(c)))/(c^(3/4)*(c^3+4*a*d^2)*sqrt(-a)*sqrt(c*(4*a+_
+--   c^3/d^2)-2*c^2*(c/d+x)^2+d^2*(c/d+x)^4))
+--E 113
+
+--S 114 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 114
+
+)clear all
+
+--S 115 of 321
+t0:=(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^4
+--R 
+--R
+--R   (1)
+--R          12 16           11 15         2 10 14         3 9 13
+--R     4096e  x   + 16384d e  x   + 24576d e  x   + 14336d e x
+--R   + 
+--R              11        4 8  12              10        5 7  11
+--R     (16384a e   - 2048d e )x   + (49152a d e   - 6144d e )x
+--R   + 
+--R              2 9        6 6  10            3 8       7 5  9
+--R     (49152a d e  - 1664d e )x   + (10240a d e  + 768d e )x
+--R   + 
+--R            2 10           4 7       8 4  8
+--R     (24576a e   - 12288a d e  + 384d e )x
+--R   + 
+--R            2   9          5 6      9 3  7
+--R     (49152a d e  - 6144a d e  - 32d e )x
+--R   + 
+--R            2 2 8         6 5      10 2  6           2 3 7         7 4  5
+--R     (24576a d e  + 768a d e  - 32d  e )x  + (- 6144a d e  + 768a d e )x
+--R   + 
+--R            3 9        2 4 6    12  4          3   8        9 2  3       2 6 4 2
+--R     (16384a e  - 6144a d e  + d  )x  + (16384a d e  - 32a d e )x  + 384a d e x
+--R   + 
+--R            3 3 6         4 8
+--R     - 2048a d e x + 4096a e
+--R                                                    Type: Polynomial(Integer)
+--E 115
+
+--S 116 of 321
+r0:=1/1048576*(5*d^4+256*a*e^3)^4*x/e^4-1/8192*d^2*(5*d^4+256*a*e^3)^3*_
+   (1/4*d/e+x)^3/e^2+1/5120*(5*d^4+256*a*e^3)^2*(59*d^4+256*a*e^3)*_
+   (1/4*d/e+x)^5-9/224*d^2*e^2*(85*d^8+5632*a*d^4*e^3+65536*a^2*e^6)*_
+   (1/4*d/e+x)^7+1/24*e^4*(601*d^8+20992*a*d^4*e^3+65536*a^2*e^6)*_
+   (1/4*d/e+x)^9-72/11*d^2*e^6*(17*d^4+256*a*e^3)*(1/4*d/e+x)^11+_
+   64/13*e^8*(59*d^4+256*a*e^3)*(1/4*d/e+x)^13-2048/5*d^2*e^10*_
+   (1/4*d/e+x)^15+4096/17*e^12*(1/4*d/e+x)^17
+--R 
+--R
+--R   (2)
+--R       4096  17 17          16 16   8192  2 15 15        3 14 14
+--R       ---- e  x   + 1024d e  x   + ---- d e  x   + 1024d e  x
+--R        17                            5
+--R     + 
+--R        16384    16   2048  4 13  13             15       5 12  12
+--R       (----- a e   - ---- d e  )x   + (4096a d e   - 512d e  )x
+--R          13           13
+--R     + 
+--R        49152    2 14   1664  6 11  11           3 13   384  7 10  10
+--R       (----- a d e   - ---- d e  )x   + (1024a d e   + --- d e  )x
+--R          11             11                              5
+--R     + 
+--R        8192  2 15   4096    4 12   128  8 9  9
+--R       (---- a e   - ---- a d e   + --- d e )x
+--R          3            3             3
+--R     + 
+--R             2   14         5 11     9 8  8
+--R       (6144a d e   - 768a d e   - 4d e )x
+--R     + 
+--R        24576  2 2 13   768    6 10   32  10 7  7
+--R       (----- a d e   + --- a d e   - -- d  e )x
+--R          7              7             7
+--R     + 
+--R               2 3 12         7 9  6    16384  3 14   6144  2 4 11   1  12 5  5
+--R       (- 1024a d e   + 128a d e )x  + (----- a e   - ---- a d e   + - d  e )x
+--R                                          5             5            5
+--R     + 
+--R             3   13       9 7  4       2 6 9 3        3 3 11 2        4 13
+--R       (4096a d e   - 8a d e )x  + 128a d e x  - 1024a d e  x  + 4096a e  x
+--R     + 
+--R         144  3 5 9   3907  2 9 6    214607     13 3      99110183    17
+--R       - --- a d e  - ---- a d e  - -------- a d  e  - ------------- d
+--R          5           3360          12300288           1070617067520
+--R  /
+--R      5
+--R     e
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 116
+
+--S 117 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 321
+t0:=(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^3
+--R 
+--R
+--R   (1)
+--R         9 12          8 11        2 7 10       3 6 9           8       4 5  8
+--R     512e x   + 1536d e x   + 1536d e x   + 320d e x  + (1536a e  - 384d e )x
+--R   + 
+--R               7       5 4  7           2 6      6 3  6
+--R     (3072a d e  - 192d e )x  + (1536a d e  + 24d e )x
+--R   + 
+--R              3 5      7 2  5         2 7         4 4  4         2   6    9  3
+--R     (- 384a d e  + 24d e )x  + (1536a e  - 384a d e )x  + (1536a d e  - d )x
+--R   + 
+--R          6 2 2       2 3 4        3 6
+--R     24a d e x  - 192a d e x + 512a e
+--R                                                    Type: Polynomial(Integer)
+--E 118
+
+--S 119 of 321
+r0:=512*a^3*e^6*x-96*a^2*d^3*e^4*x^2+8*a*d^6*e^2*x^3-1/4*d*(d^8-_
+   1536*a^2*e^6)*x^4-384/5*a*e^4*(d^4-4*a*e^3)*x^5+4*d^3*e^2*(d^4-_
+   16*a*e^3)*x^6+24/7*d^2*e^3*(d^4+64*a*e^3)*x^7-24*d*e^4*(d^4-16*a*e^3)*_
+   x^8-128/3*e^5*(d^4-4*a*e^3)*x^9+32*d^3*e^6*x^10+1536/11*d^2*e^7*x^11+_
+   128*d*e^8*x^12+512/13*e^9*x^13
+--R 
+--R
+--R   (2)
+--R     512  9 13         8 12   1536  2 7 11      3 6 10    512    8   128  4 5  9
+--R     --- e x   + 128d e x   + ---- d e x   + 32d e x   + (--- a e  - --- d e )x
+--R      13                       11                          3          3
+--R   + 
+--R              7      5 4  8    1536    2 6   24  6 3  7           3 5     7 2  6
+--R     (384a d e  - 24d e )x  + (---- a d e  + -- d e )x  + (- 64a d e  + 4d e )x
+--R                                 7            7
+--R   + 
+--R      1536  2 7   384    4 4  5        2   6   1  9  4       6 2 3      2 3 4 2
+--R     (---- a e  - --- a d e )x  + (384a d e  - - d )x  + 8a d e x  - 96a d e x
+--R        5          5                           4
+--R   + 
+--R         3 6
+--R     512a e x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 119
+
+--S 120 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 321
+t0:=(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^2
+--R 
+--R
+--R   (1)
+--R        6 8         5 7      2 4 6      3 3 5          5      4 2  4
+--R     64e x  + 128d e x  + 64d e x  - 16d e x  + (128a e  - 16d e )x
+--R   + 
+--R             4 3    6 2        3 2       2 4
+--R     128a d e x  + d x  - 16a d e x + 64a e
+--R                                                    Type: Polynomial(Integer)
+--E 121
+
+--S 122 of 321
+r0:=64*a^2*e^4*x-8*a*d^3*e^2*x^2+1/3*d^6*x^3+32*a*d*e^4*x^4-_
+   16/5*e^2*(d^4-8*a*e^3)*x^5-8/3*d^3*e^3*x^6+64/7*d^2*e^4*x^7+_
+   16*d*e^5*x^8+64/9*e^6*x^9
+--R 
+--R
+--R   (2)
+--R     64  6 9        5 8   64  2 4 7   8  3 3 6    128    5   16  4 2  5
+--R     -- e x  + 16d e x  + -- d e x  - - d e x  + (--- a e  - -- d e )x
+--R      9                    7          3            5          5
+--R   + 
+--R            4 4   1  6 3       3 2 2      2 4
+--R     32a d e x  + - d x  - 8a d e x  + 64a e x
+--R                  3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 122
+
+--S 123 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 321
+t0:=8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4
+--R 
+--R
+--R          3 4       2 3    3        2
+--R   (1)  8e x  + 8d e x  - d x + 8a e
+--R                                                    Type: Polynomial(Integer)
+--E 124
+
+--S 125 of 321
+r0:=8*a*e^2*x-1/2*d^3*x^2+2*d*e^2*x^4+8/5*e^3*x^5
+--R 
+--R
+--R        8  3 5       2 4   1  3 2       2
+--R   (2)  - e x  + 2d e x  - - d x  + 8a e x
+--R        5                  2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 125
+
+--S 126 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 321
+t0:=1/(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R          3 4       2 3    3        2
+--R        8e x  + 8d e x  - d x + 8a e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 127
+
+--S 128 of 321
+r0:=2*atanh(4*e*(1/4*d/e+x)/sqrt(3*d^2-2*sqrt(d^4-64*a*e^3)))/_
+   (sqrt(d^4-64*a*e^3)*sqrt(3*d^2-2*sqrt(d^4-64*a*e^3)))-_
+   2*atanh(4*e*(1/4*d/e+x)/sqrt(3*d^2+2*sqrt(d^4-64*a*e^3)))/_
+   (sqrt(d^4-64*a*e^3)*sqrt(3*d^2+2*sqrt(d^4-64*a*e^3)))
+--R 
+--R
+--R   (2)
+--R         +-----------------------+
+--R         |  +-------------+
+--R         |  |       3    4      2                 4e x + d
+--R       2\|2\|- 64a e  + d   + 3d  atanh(----------------------------)
+--R                                         +-------------------------+
+--R                                         |    +-------------+
+--R                                         |    |       3    4      2
+--R                                        \|- 2\|- 64a e  + d   + 3d
+--R     + 
+--R           +-------------------------+
+--R           |    +-------------+
+--R           |    |       3    4      2                4e x + d
+--R       - 2\|- 2\|- 64a e  + d   + 3d  atanh(--------------------------)
+--R                                             +-----------------------+
+--R                                             |  +-------------+
+--R                                             |  |       3    4      2
+--R                                            \|2\|- 64a e  + d   + 3d
+--R  /
+--R                      +-------------------------+ +-----------------------+
+--R      +-------------+ |    +-------------+        |  +-------------+
+--R      |       3    4  |    |       3    4      2  |  |       3    4      2
+--R     \|- 64a e  + d  \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 321
+t0:=1/(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          6 8         5 7      2 4 6      3 3 5          5      4 2  4
+--R       64e x  + 128d e x  + 64d e x  - 16d e x  + (128a e  - 16d e )x
+--R     + 
+--R               4 3    6 2        3 2       2 4
+--R       128a d e x  + d x  - 16a d e x + 64a e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 130
+
+--S 131 of 321
+r0:=64*e*(1/4*d/e+x)*(13*d^4-256*a*e^3-48*d^2*e^2*(1/4*d/e+x)^2)/_
+   ((5*d^8-64*a*d^4*e^3-16384*a^2*e^6)*(5*d^4/e+256*a*e^2-96*d^2*_
+   e*(1/4*d/e+x)^2+256*e^3*(1/4*d/e+x)^4))-24*e*atanh(4*e*(1/4*d/e+x)/_
+   sqrt(3*d^2-2*sqrt(d^4-64*a*e^3)))*(d^4+128*a*e^3-d^2*sqrt(d^4-_
+   64*a*e^3))/((d^4-64*a*e^3)^(3/2)*(5*d^4+256*a*e^3)*sqrt(3*d^2-_
+   2*sqrt(d^4-64*a*e^3)))+24*e*atanh(4*e*(1/4*d/e+x)/sqrt(3*d^2+_
+   2*sqrt(d^4-64*a*e^3)))*(d^4+128*a*e^3+d^2*sqrt(d^4-64*a*e^3))/_
+   ((d^4-64*a*e^3)^(3/2)*(5*d^4+256*a*e^3)*sqrt(3*d^2+2*sqrt(d^4-64*a*e^3)))
+--R 
+--R
+--R   (2)
+--R                                                           +-------------+
+--R                  2 4 4       3 3 3      5            2 3  |       3    4
+--R           (- 192d e x  - 192d e x  + 24d e x - 192a d e )\|- 64a e  + d
+--R         + 
+--R                    7       4 4  4              6       5 3  3
+--R           (24576a e  + 192d e )x  + (24576a d e  + 192d e )x
+--R         + 
+--R                     3 4      7            2 6         4 3
+--R           (- 3072a d e  - 24d e)x + 24576a e  + 192a d e
+--R      *
+--R          +-----------------------+
+--R          |  +-------------+
+--R          |  |       3    4      2                 4e x + d
+--R         \|2\|- 64a e  + d   + 3d  atanh(----------------------------)
+--R                                          +-------------------------+
+--R                                          |    +-------------+
+--R                                          |    |       3    4      2
+--R                                         \|- 2\|- 64a e  + d   + 3d
+--R     + 
+--R                                                           +-------------+
+--R                  2 4 4       3 3 3      5            2 3  |       3    4
+--R           (- 192d e x  - 192d e x  + 24d e x - 192a d e )\|- 64a e  + d
+--R         + 
+--R                      7       4 4  4                6       5 3  3
+--R           (- 24576a e  - 192d e )x  + (- 24576a d e  - 192d e )x
+--R         + 
+--R                   3 4      7            2 6         4 3
+--R           (3072a d e  + 24d e)x - 24576a e  - 192a d e
+--R      *
+--R          +-------------------------+
+--R          |    +-------------+
+--R          |    |       3    4      2                4e x + d
+--R         \|- 2\|- 64a e  + d   + 3d  atanh(--------------------------)
+--R                                            +-----------------------+
+--R                                            |  +-------------+
+--R                                            |  |       3    4      2
+--R                                           \|2\|- 64a e  + d   + 3d
+--R     + 
+--R             2 3 3      3 2 2          4     4              3     5
+--R         (96d e x  + 72d e x  + (512a e  - 8d e)x + 128a d e  - 5d )
+--R      *
+--R                          +-------------------------+ +-----------------------+
+--R          +-------------+ |    +-------------+        |  +-------------+
+--R          |       3    4  |    |       3    4      2  |  |       3    4      2
+--R         \|- 64a e  + d  \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R  /
+--R                 2 9         4 6      8 3  4
+--R         (131072a e  + 512a d e  - 40d e )x
+--R       + 
+--R                 2   8         5 5      9 2  3
+--R         (131072a d e  + 512a d e  - 40d e )x
+--R       + 
+--R                  2 3 6        7 3     11            3 8       2 4 5        8 2
+--R         (- 16384a d e  - 64a d e  + 5d  )x + 131072a e  + 512a d e  - 40a d e
+--R    *
+--R                        +-------------------------+ +-----------------------+
+--R        +-------------+ |    +-------------+        |  +-------------+
+--R        |       3    4  |    |       3    4      2  |  |       3    4      2
+--R       \|- 64a e  + d  \|- 2\|- 64a e  + d   + 3d  \|2\|- 64a e  + d   + 3d
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 321
+t0:=(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^(1/2)
+--R 
+--R
+--R         +-----------------------------+
+--R         |  3 4       2 3    3        2
+--R   (1)  \|8e x  + 8d e x  - d x + 8a e
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 321
+--r0:=1/12*(1/4*d/e+x)*sqrt(5*d^4/e+256*a*e^2-96*d^2*e*(1/4*d/e+x)^2+_
+--   256*e^3*(1/4*d/e+x)^4)/sqrt(2)+1/8*d^2*elliptic_e(asin(4*e*(1/4*d/e+x)/_
+--   sqrt(3*d^2+2*sqrt(d^4-64*a*e^3))),(3*d^2+2*sqrt(d^4-64*a*e^3))/(3*d^2-_
+--   2*sqrt(d^4-64*a*e^3)))*(3*d^2-2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*_
+--   (1/4*d/e+x)^2/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(3*d^2+2*sqrt(d^4-_
+--   64*a*e^3))*sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2+2*sqrt(d^4-64*a*e^3)))/_
+--   (e^2*sqrt(2)*sqrt(5*d^4/e+256*a*e^2-96*d^2*e*(1/4*d/e+x)^2+256*e^3*_
+--   (1/4*d/e+x)^4))-1/12*elliptic_f(asin(4*e*(1/4*d/e+x)/sqrt(3*d^2+_
+--   2*sqrt(d^4-64*a*e^3))),(3*d^2+2*sqrt(d^4-64*a*e^3))/(3*d^2-_
+--   2*sqrt(d^4-64*a*e^3)))*(2*d^4-128*a*e^3-3*d^2*sqrt(d^4-64*a*e^3))*_
+--   sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(3*d^2+_
+--   2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2+2*sqrt(d^4-_
+--   64*a*e^3)))/(e^2*sqrt(2)*sqrt(5*d^4/e+256*a*e^2-96*d^2*e*(1/4*d/e+x)^2+_
+--   256*e^3*(1/4*d/e+x)^4))
+--E 134
+
+--S 135 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 135
+
+)clear all
+
+--S 136 of 321
+t0:=1/(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^(1/2)
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R         +-----------------------------+
+--R         |  3 4       2 3    3        2
+--R        \|8e x  + 8d e x  - d x + 8a e
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 321
+--r0:=elliptic_f(asin(4*e*(1/4*d/e+x)/sqrt(3*d^2+2*sqrt(d^4-64*a*e^3))),_
+--   (3*d^2+2*sqrt(d^4-64*a*e^3))/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(2)*_
+--   sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(3*d^2+_
+--   2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2+2*sqrt(d^4-_
+--   64*a*e^3)))/(e*sqrt(5*d^4/e+256*a*e^2-96*d^2*e*(1/4*d/e+x)^2+_
+--   256*e^3*(1/4*d/e+x)^4))
+--E 137
+
+--S 138 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 138
+
+)clear all
+
+--S 139 of 321
+t0:=1/(8*a*e^2-d^3*x+8*d*e^2*x^3+8*e^3*x^4)^(3/2)
+--R 
+--R
+--R                                       1
+--R   (1)  ---------------------------------------------------------------
+--R                                        +-----------------------------+
+--R           3 4       2 3    3        2  |  3 4       2 3    3        2
+--R        (8e x  + 8d e x  - d x + 8a e )\|8e x  + 8d e x  - d x + 8a e
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 321
+--r0:=16*e*(1/4*d/e+x)*(13*d^4-256*a*e^3-48*d^2*e^2*(1/4*d/e+x)^2)*_
+--   sqrt(2)/((5*d^8-64*a*d^4*e^3-16384*a^2*e^6)*sqrt(5*d^4/e+256*a*e^2-_
+--   96*d^2*e*(1/4*d/e+x)^2+256*e^3*(1/4*d/e+x)^4))-12*d^2*_
+--   elliptic_e(asin(4*e*(1/4*d/e+x)/sqrt(3*d^2+2*sqrt(d^4-64*a*e^3))),_
+--   (3*d^2+2*sqrt(d^4-64*a*e^3))/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(2)*_
+--   (3*d^2-2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2-2*_
+--   sqrt(d^4-64*a*e^3)))*sqrt(3*d^2+2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*_
+--   (1/4*d/e+x)^2/(3*d^2+2*sqrt(d^4-64*a*e^3)))/((d^4-64*a*e^3)*(5*d^4+_
+--   256*a*e^3)*sqrt(5*d^4/e+256*a*e^2-96*d^2*e*(1/4*d/e+x)^2+256*e^3*_
+--   (1/4*d/e+x)^4))+8*elliptic_f(asin(4*e*(1/4*d/e+x)/sqrt(3*d^2+2*_
+--   sqrt(d^4-64*a*e^3))),(3*d^2+2*sqrt(d^4-64*a*e^3))/(3*d^2-2*sqrt(d^4-_
+--   64*a*e^3)))*sqrt(2)*(2*d^4-128*a*e^3-3*d^2*sqrt(d^4-64*a*e^3))*_
+--   sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2-2*sqrt(d^4-64*a*e^3)))*sqrt(3*d^2+_
+--   2*sqrt(d^4-64*a*e^3))*sqrt(1-16*e^2*(1/4*d/e+x)^2/(3*d^2+2*sqrt(d^4-_
+--   64*a*e^3)))/((d^4-64*a*e^3)*(5*d^4+256*a*e^3)*sqrt(5*d^4/e+256*a*e^2-_
+--   96*d^2*e*(1/4*d/e+x)^2+256*e^3*(1/4*d/e+x)^4))
+--E 140
+
+--S 141 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 141
+
+)clear all
+
+--S 142 of 321
+t0:=(a+8*x-8*x^2+4*x^3-x^4)^4
+--R 
+--R
+--R   (1)
+--R      16      15       14       13                 12                11
+--R     x   - 16x   + 128x   - 672x   + (- 4a + 2560)x   + (48a - 7424)x
+--R   + 
+--R                      10                   9      2                  8
+--R     (- 288a + 16768)x   + (1120a - 29696)x  + (6a  - 3072a + 40960)x
+--R   + 
+--R           2                  7        2                  6
+--R     (- 48a  + 6144a - 43008)x  + (192a  - 8960a + 32768)x
+--R   + 
+--R            2                  5        3       2                 4
+--R     (- 480a  + 9216a - 16384)x  + (- 4a  + 768a  - 6144a + 4096)x
+--R   + 
+--R         3       2          3         3       2  2      3     4
+--R     (16a  - 768a  + 2048a)x  + (- 32a  + 384a )x  + 32a x + a
+--R                                                    Type: Polynomial(Integer)
+--E 142
+
+--S 143 of 321
+r0:=-8/3*(3+a)^3*(-1+x)^3+4/5*(3-a)*(3+a)^2*(-1+x)^5+8/7*(3+a)*(5+3*a)*_
+   (-1+x)^7-2/9*(37+6*a-3*a^2)*(-1+x)^9-8/11*(5+3*a)*(-1+x)^11+4/13*(3-a)*_
+   (-1+x)^13+8/15*(-1+x)^15+1/17*(-1+x)^17+(3+a)^4*x
+--R 
+--R
+--R   (2)
+--R      1  17    16   128  15      14       4     2560  13         1856  12
+--R     -- x   - x   + --- x   - 48x   + (- -- a + ----)x   + (4a - ----)x
+--R     17              15                  13      13                3
+--R   + 
+--R        288     16768  11           14848  10    2  2   1024     40960  9
+--R     (- --- a + -----)x   + (112a - -----)x   + (- a  - ---- a + -----)x
+--R         11       11                  5          3        3        9
+--R   + 
+--R          2                8    192  2           32768  7
+--R     (- 6a  + 768a - 5376)x  + (--- a  - 1280a + -----)x
+--R                                 7                 7
+--R   + 
+--R           2           8192  6      4  3   768  2   6144     4096  5
+--R     (- 80a  + 1536a - ----)x  + (- - a  + --- a  - ---- a + ----)x
+--R                         3          5       5         5        5
+--R   + 
+--R        3       2         4      32  3       2  3      3 2    4    52  3
+--R     (4a  - 192a  + 512a)x  + (- -- a  + 128a )x  + 16a x  + a x + -- a
+--R                                  3                                15
+--R   + 
+--R     2342  2   112876     33387733
+--R     ---- a  + ------ a + --------
+--R      105       2145       765765
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 143
+
+--S 144 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 321
+t0:=(a+8*x-8*x^2+4*x^3-x^4)^3
+--R 
+--R
+--R   (1)
+--R        12      11      10       9              8                  7
+--R     - x   + 12x   - 72x   + 280x  + (3a - 768)x  + (- 24a + 1536)x
+--R   + 
+--R                  6                   5        2                4
+--R     (96a - 2240)x  + (- 240a + 2304)x  + (- 3a  + 384a - 1536)x
+--R   + 
+--R         2               3         2         2      2     3
+--R     (12a  - 384a + 512)x  + (- 24a  + 192a)x  + 24a x + a
+--R                                                    Type: Polynomial(Integer)
+--E 145
+
+--S 146 of 321
+r0:=a^3*x+12*a^2*x^2+8*(8-a)*a*x^3+(128-96*a+3*a^2)*x^4-3/5*(512-128*a+a^2)*_
+   x^5+8*(48-5*a)*x^6-32/7*(70-3*a)*x^7+3*(64-a)*x^8-1/3*(256-a)*x^9+_
+   28*x^10-72/11*x^11+x^12-1/13*x^13
+--R 
+--R
+--R   (2)
+--R        1  13    12   72  11      10    1     256  9                8
+--R     - -- x   + x   - -- x   + 28x   + (- a - ---)x  + (- 3a + 192)x
+--R       13             11                3      3
+--R   + 
+--R      96          7                 6      3  2   384     1536  5
+--R     (-- a - 320)x  + (- 40a + 384)x  + (- - a  + --- a - ----)x
+--R       7                                   5       5        5
+--R   + 
+--R        2              4        2        3      2 2    3
+--R     (3a  - 96a + 128)x  + (- 8a  + 64a)x  + 12a x  + a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 146
+
+--S 147 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 321
+t0:=(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R      8     7      6      5                4              3                2
+--R     x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R   + 
+--R              2
+--R     16a x + a
+--R                                                    Type: Polynomial(Integer)
+--E 148
+
+--S 149 of 321
+r0:=a^2*x+8*a*x^2+16/3*(4-a)*x^3-2*(16-a)*x^4+2/5*(64-a)*x^5-40/3*x^6+_
+   32/7*x^7-x^8+1/9*x^9
+--R 
+--R
+--R   (2)
+--R     1  9    8   32  7   40  6      2     128  5             4      16     64  3
+--R     - x  - x  + -- x  - -- x  + (- - a + ---)x  + (2a - 32)x  + (- -- a + --)x
+--R     9            7       3         5      5                         3      3
+--R   + 
+--R         2    2
+--R     8a x  + a x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 149
+
+--S 150 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 321
+t0:=a+8*x-8*x^2+4*x^3-x^4
+--R 
+--R
+--R           4     3     2
+--R   (1)  - x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Polynomial(Integer)
+--E 151
+
+--S 152 of 321
+r0:=a*x+4*x^2-8/3*x^3+x^4-1/5*x^5
+--R 
+--R
+--R          1  5    4   8  3     2
+--R   (2)  - - x  + x  - - x  + 4x  + a x
+--R          5           3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 152
+
+--S 153 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 321
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)
+--R 
+--R
+--R                     1
+--R   (1)  - -----------------------
+--R           4     3     2
+--R          x  - 4x  + 8x  - 8x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 154
+
+--S 155 of 321
+r0:=-1/2*atan((-1+x)/sqrt(1-sqrt(4+a)))/(sqrt(4+a)*sqrt(1-sqrt(4+a)))+_
+   1/2*atan((-1+x)/sqrt(1+sqrt(4+a)))/(sqrt(4+a)*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R          +------------+
+--R          | +-----+                x - 1
+--R       - \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R        +--------------+
+--R        |   +-----+               x - 1
+--R       \|- \|a + 4  + 1 atan(---------------)
+--R                              +------------+
+--R                              | +-----+
+--R                             \|\|a + 4  + 1
+--R  /
+--R               +--------------+ +------------+
+--R       +-----+ |   +-----+      | +-----+
+--R     2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 321
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        8     7      6      5                4              3                2
+--R       x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R     + 
+--R                2
+--R       16a x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 157
+
+--S 158 of 321
+r0:=1/4*(5+a+(-1+x)^2)*(-1+x)/((12+7*a+a^2)*(3+a-2*(-1+x)^2-(-1+x)^4))-_
+   1/8*atan((-1+x)/sqrt(1-sqrt(4+a)))*(10+3*a+sqrt(4+a))/((3+a)*(4+a)^(3/2)*_
+   sqrt(1-sqrt(4+a)))+1/8*atan((-1+x)/sqrt(1+sqrt(4+a)))*(10+3*a-_
+   sqrt(4+a))/((3+a)*(4+a)^(3/2)*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R               4     3     2           +-----+               4              3
+--R           (- x  + 4x  - 8x  + 8x + a)\|a + 4  + (- 3a - 10)x  + (12a + 40)x
+--R         + 
+--R                        2                   2
+--R           (- 24a - 80)x  + (24a + 80)x + 3a  + 10a
+--R      *
+--R          +------------+
+--R          | +-----+                x - 1
+--R         \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R               4     3     2           +-----+             4                3
+--R           (- x  + 4x  - 8x  + 8x + a)\|a + 4  + (3a + 10)x  + (- 12a - 40)x
+--R         + 
+--R                      2                     2
+--R           (24a + 80)x  + (- 24a - 80)x - 3a  - 10a
+--R      *
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R         \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R                                                        +--------------+
+--R              3     2                           +-----+ |   +-----+
+--R         (- 2x  + 6x  + (- 2a - 16)x + 2a + 12)\|a + 4 \|- \|a + 4  + 1
+--R      *
+--R          +------------+
+--R          | +-----+
+--R         \|\|a + 4  + 1
+--R  /
+--R            2             4         2               3       2               2
+--R         (8a  + 56a + 96)x  + (- 32a  - 224a - 384)x  + (64a  + 448a + 768)x
+--R       + 
+--R               2                    3      2
+--R         (- 64a  - 448a - 768)x - 8a  - 56a  - 96a
+--R    *
+--R                +--------------+ +------------+
+--R        +-----+ |   +-----+      | +-----+
+--R       \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 321
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)^3
+--R 
+--R
+--R   (1)
+--R   -
+--R        1
+--R     /
+--R           12      11      10       9                8                7
+--R          x   - 12x   + 72x   - 280x  + (- 3a + 768)x  + (24a - 1536)x
+--R        + 
+--R                         6                 5      2                4
+--R          (- 96a + 2240)x  + (240a - 2304)x  + (3a  - 384a + 1536)x
+--R        + 
+--R                2               3       2         2      2     3
+--R          (- 12a  + 384a - 512)x  + (24a  - 192a)x  - 24a x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 160
+
+--S 161 of 321
+r0:=1/8*(5+a+(-1+x)^2)*(-1+x)/((12+7*a+a^2)*(3+a-2*(-1+x)^2-(-1+x)^4)^2)+_
+   1/32*((6+a)*(25+7*a)+6*(7+2*a)*(-1+x)^2)*(-1+x)/((3+a)^2*(4+a)^2*_
+   (3+a-2*(-1+x)^2-(-1+x)^4))-3/64*atan((-1+x)/sqrt(1-sqrt(4+a)))*_
+   (80+7*a^2+14*sqrt(4+a)+a*(47+4*sqrt(4+a)))/((3+a)^2*(4+a)^(5/2)*_
+   sqrt(1-sqrt(4+a)))-3/64*atan((-1+x)/sqrt(1+sqrt(4+a)))*(14+4*a+_
+   (-80-47*a-7*a^2)/sqrt(4+a))/((3+a)^2*(4+a)^2*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R                            8               7                   6
+--R               (- 12a - 42)x  + (96a + 336)x  + (- 384a - 1344)x
+--R             + 
+--R                             5       2                 4
+--R               (960a + 3360)x  + (24a  - 1452a - 5376)x
+--R             + 
+--R                     2                 3        2               2
+--R               (- 96a  + 1200a + 5376)x  + (192a  - 96a - 2688)x
+--R             + 
+--R                      2               3      2
+--R               (- 192a  - 672a)x - 12a  - 42a
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R                 2               8        2                 7
+--R           (- 21a  - 141a - 240)x  + (168a  + 1128a + 1920)x
+--R         + 
+--R                  2                 6         2                   5
+--R           (- 672a  - 4512a - 7680)x  + (1680a  + 11280a + 19200)x
+--R         + 
+--R               3        2                   4
+--R           (42a  - 2406a  - 17568a - 30720)x
+--R         + 
+--R                  3        2                   3
+--R           (- 168a  + 1560a  + 16128a + 30720)x
+--R         + 
+--R                3       2                  2          3        2
+--R           (336a  + 912a  - 5184a - 15360)x  + (- 336a  - 2256a  - 3840a)x
+--R         + 
+--R                4       3       2
+--R           - 21a  - 141a  - 240a
+--R      *
+--R          +------------+
+--R          | +-----+                x - 1
+--R         \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R                            8               7                   6
+--R               (- 12a - 42)x  + (96a + 336)x  + (- 384a - 1344)x
+--R             + 
+--R                             5       2                 4
+--R               (960a + 3360)x  + (24a  - 1452a - 5376)x
+--R             + 
+--R                     2                 3        2               2
+--R               (- 96a  + 1200a + 5376)x  + (192a  - 96a - 2688)x
+--R             + 
+--R                      2               3      2
+--R               (- 192a  - 672a)x - 12a  - 42a
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R               2               8          2                 7
+--R           (21a  + 141a + 240)x  + (- 168a  - 1128a - 1920)x
+--R         + 
+--R                2                 6           2                   5
+--R           (672a  + 4512a + 7680)x  + (- 1680a  - 11280a - 19200)x
+--R         + 
+--R                 3        2                   4
+--R           (- 42a  + 2406a  + 17568a + 30720)x
+--R         + 
+--R                3        2                   3
+--R           (168a  - 1560a  - 16128a - 30720)x
+--R         + 
+--R                  3       2                  2        3        2
+--R           (- 336a  - 912a  + 5184a + 15360)x  + (336a  + 2256a  + 3840a)x
+--R         + 
+--R              4       3       2
+--R           21a  + 141a  + 240a
+--R      *
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R         \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R                        7                6         2                5
+--R           (- 24a - 84)x  + (168a + 588)x  + (- 14a  - 686a - 2232)x
+--R         + 
+--R               2                 4          2                 3
+--R           (70a  + 1750a + 5280)x  + (- 136a  - 2716a - 7872)x
+--R         + 
+--R                2                 2       3       2                      3
+--R           (128a  + 2492a + 7200)x  + (22a  + 214a  - 168a - 2304)x - 22a
+--R         + 
+--R                 2
+--R           - 262a  - 816a - 576
+--R      *
+--R                  +--------------+ +------------+
+--R          +-----+ |   +-----+      | +-----+
+--R         \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R             4       3        2                  8
+--R         (64a  + 896a  + 4672a  + 10752a + 9216)x
+--R       + 
+--R                4        3         2                   7
+--R         (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R       + 
+--R               4         3          2                     6
+--R         (2048a  + 28672a  + 149504a  + 344064a + 294912)x
+--R       + 
+--R                 4         3          2                     5
+--R         (- 5120a  - 71680a  - 373760a  - 860160a - 737280)x
+--R       + 
+--R                5        4          3          2                       4
+--R         (- 128a  + 6400a  + 105344a  + 576512a  + 1357824a + 1179648)x
+--R       + 
+--R              5        4         3          2                       3
+--R         (512a  - 1024a  - 77312a  - 512000a  - 1302528a - 1179648)x
+--R       + 
+--R                 5         4         3          2                     2
+--R         (- 1024a  - 10240a  - 17408a  + 126976a  + 540672a + 589824)x
+--R       + 
+--R               5         4         3          2                  6       5
+--R         (1024a  + 14336a  + 74752a  + 172032a  + 147456a)x + 64a  + 896a
+--R       + 
+--R              4         3        2
+--R         4672a  + 10752a  + 9216a
+--R    *
+--R                +--------------+ +------------+
+--R        +-----+ |   +-----+      | +-----+
+--R       \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 321
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)^4
+--R 
+--R
+--R   (1)
+--R      17      16       15       14                 13                12
+--R     x   - 16x   + 128x   - 672x   + (- 4a + 2560)x   + (48a - 7424)x
+--R   + 
+--R                      11                   10      2                  9
+--R     (- 288a + 16768)x   + (1120a - 29696)x   + (6a  - 3072a + 40960)x
+--R   + 
+--R           2                  8        2                  7
+--R     (- 48a  + 6144a - 43008)x  + (192a  - 8960a + 32768)x
+--R   + 
+--R            2                  6        3       2                 5
+--R     (- 480a  + 9216a - 16384)x  + (- 4a  + 768a  - 6144a + 4096)x
+--R   + 
+--R         3       2          4         3       2  3      3 2    4
+--R     (16a  - 768a  + 2048a)x  + (- 32a  + 384a )x  + 32a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 163
+
+--S 164 of 321
+r0:=1/2*a^4*x^2+32/3*a^3*x^3+8*(12-a)*a^2*x^4+16/5*a*(128-48*a+a^2)*x^5+_
+   2/3*(1024-1536*a+192*a^2-a^3)*x^6-32/7*(512-288*a+15*a^2)*x^7+_
+   8*(128-3*a)*(4-a)*x^8-16/3*(896-128*a+a^2)*x^9+1/5*(20480-1536*a+_
+   3*a^2)*x^10-32/11*(928-35*a)*x^11+8/3*(524-9*a)*x^12-16/13*_
+   (464-3*a)*x^13+2/7*(640-a)*x^14-224/5*x^15+8*x^16-16/17*x^17+1/18*x^18
+--R 
+--R
+--R   (2)
+--R      1  18   16  17     16   224  15      2     1280  14    48     7424  13
+--R     -- x   - -- x   + 8x   - --- x   + (- - a + ----)x   + (-- a - ----)x
+--R     18       17               5           7       7         13      13
+--R   + 
+--R              4192  12    1120     29696  11    3  2   1536           10
+--R     (- 24a + ----)x   + (---- a - -----)x   + (- a  - ---- a + 4096)x
+--R                3          11        11         5        5
+--R   + 
+--R        16  2   2048     14336  9       2                 8
+--R     (- -- a  + ---- a - -----)x  + (24a  - 1120a + 4096)x
+--R         3        3        3
+--R   + 
+--R        480  2   9216     16384  7      2  3       2           2048  6
+--R     (- --- a  + ---- a - -----)x  + (- - a  + 128a  - 1024a + ----)x
+--R         7         7        7           3                        3
+--R   + 
+--R      16  3   768  2   2048    5        3      2  4   32  3 3   1  4 2
+--R     (-- a  - --- a  + ---- a)x  + (- 8a  + 96a )x  + -- a x  + - a x
+--R       5       5         5                             3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 164
+
+--S 165 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 321
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)^3
+--R 
+--R
+--R   (1)
+--R        13      12      11       10              9                  8
+--R     - x   + 12x   - 72x   + 280x   + (3a - 768)x  + (- 24a + 1536)x
+--R   + 
+--R                  7                   6        2                5
+--R     (96a - 2240)x  + (- 240a + 2304)x  + (- 3a  + 384a - 1536)x
+--R   + 
+--R         2               4         2         3      2 2    3
+--R     (12a  - 384a + 512)x  + (- 24a  + 192a)x  + 24a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 166
+
+--S 167 of 321
+r0:=1/2*a^3*x^2+8*a^2*x^3+6*(8-a)*a*x^4+4/5*(128-96*a+3*a^2)*x^5-_
+   1/2*(512-128*a+a^2)*x^6+48/7*(48-5*a)*x^7-4*(70-3*a)*x^8+8/3*(64-a)*x^9-_
+   3/10*(256-a)*x^10+280/11*x^11-6*x^12+12/13*x^13-1/14*x^14
+--R 
+--R
+--R   (2)
+--R        1  14   12  13     12   280  11     3     384  10      8     512  9
+--R     - -- x   + -- x   - 6x   + --- x   + (-- a - ---)x   + (- - a + ---)x
+--R       14       13               11        10      5           3      3
+--R   + 
+--R                 8      240     2304  7      1  2              6
+--R     (12a - 280)x  + (- --- a + ----)x  + (- - a  + 64a - 256)x
+--R                         7        7          2
+--R   + 
+--R      12  2   384     512  5        2        4     2 3   1  3 2
+--R     (-- a  - --- a + ---)x  + (- 6a  + 48a)x  + 8a x  + - a x
+--R       5       5       5                                 2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 167
+
+--S 168 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 321
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R      9     8      7      6                5              4                3
+--R     x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R   + 
+--R          2    2
+--R     16a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 169
+
+--S 170 of 321
+r0:=1/2*a^2*x^2+16/3*a*x^3+4*(4-a)*x^4-8/5*(16-a)*x^5+1/3*(64-a)*x^6-_
+   80/7*x^7+4*x^8-8/9*x^9+1/10*x^10
+--R 
+--R
+--R   (2)
+--R      1  10   8  9     8   80  7      1     64  6    8     128  5
+--R     -- x   - - x  + 4x  - -- x  + (- - a + --)x  + (- a - ---)x
+--R     10       9             7         3      3       5      5
+--R   + 
+--R                 4   16    3   1  2 2
+--R     (- 4a + 16)x  + -- a x  + - a x
+--R                      3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 170
+
+--S 171 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 321
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)
+--R 
+--R
+--R           5     4     3     2
+--R   (1)  - x  + 4x  - 8x  + 8x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 172
+
+--S 173 of 321
+r0:=1/2*a*x^2+8/3*x^3-2*x^4+4/5*x^5-1/6*x^6
+--R 
+--R
+--R          1  6   4  5     4   8  3   1    2
+--R   (2)  - - x  + - x  - 2x  + - x  + - a x
+--R          6      5            3      2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 173
+
+--S 174 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 321
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)
+--R 
+--R
+--R                     x
+--R   (1)  - -----------------------
+--R           4     3     2
+--R          x  - 4x  + 8x  - 8x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 175
+
+--S 176 of 321
+r0:=1/2*atanh((1+(-1+x)^2)/sqrt(4+a))/sqrt(4+a)-1/2*atan((-1+x)/_
+   sqrt(1-sqrt(4+a)))/(sqrt(4+a)*sqrt(1-sqrt(4+a)))+1/2*atan((-1+x)/_
+   sqrt(1+sqrt(4+a)))/(sqrt(4+a)*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R          +------------+
+--R          | +-----+                x - 1
+--R       - \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R        +--------------+
+--R        |   +-----+               x - 1
+--R       \|- \|a + 4  + 1 atan(---------------)
+--R                              +------------+
+--R                              | +-----+
+--R                             \|\|a + 4  + 1
+--R     + 
+--R              2           +--------------+ +------------+
+--R             x  - 2x + 2  |   +-----+      | +-----+
+--R       atanh(-----------)\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                +-----+
+--R               \|a + 4
+--R  /
+--R               +--------------+ +------------+
+--R       +-----+ |   +-----+      | +-----+
+--R     2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 321
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R     x
+--R  /
+--R        8     7      6      5                4              3                2
+--R       x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R     + 
+--R                2
+--R       16a x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 178
+
+--S 179 of 321
+r0:=1/4*(1+(-1+x)^2)/((4+a)*(3+a-2*(-1+x)^2-(-1+x)^4))+1/4*(5+a+(-1+x)^2)*_
+   (-1+x)/((12+7*a+a^2)*(3+a-2*(-1+x)^2-(-1+x)^4))+1/4*atanh((1+(-1+x)^2)/_
+   sqrt(4+a))/(4+a)^(3/2)-1/8*atan((-1+x)/sqrt(1-sqrt(4+a)))*(10+3*a+_
+   sqrt(4+a))/((3+a)*(4+a)^(3/2)*sqrt(1-sqrt(4+a)))+1/8*atan((-1+x)/_
+   sqrt(1+sqrt(4+a)))*(10+3*a-sqrt(4+a))/((3+a)*(4+a)^(3/2)*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R               4     3     2           +-----+               4              3
+--R           (- x  + 4x  - 8x  + 8x + a)\|a + 4  + (- 3a - 10)x  + (12a + 40)x
+--R         + 
+--R                        2                   2
+--R           (- 24a - 80)x  + (24a + 80)x + 3a  + 10a
+--R      *
+--R          +------------+
+--R          | +-----+                x - 1
+--R         \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R               4     3     2           +-----+             4                3
+--R           (- x  + 4x  - 8x  + 8x + a)\|a + 4  + (3a + 10)x  + (- 12a - 40)x
+--R         + 
+--R                      2                     2
+--R           (24a + 80)x  + (- 24a - 80)x - 3a  - 10a
+--R      *
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R         \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R                        4               3              2                     2
+--R               (2a + 6)x  + (- 8a - 24)x  + (16a + 48)x  + (- 16a - 48)x - 2a
+--R             + 
+--R               - 6a
+--R          *
+--R                    2
+--R                   x  - 2x + 2
+--R             atanh(-----------)
+--R                      +-----+
+--R                     \|a + 4
+--R         + 
+--R                3       2                   +-----+
+--R           (- 2x  - 2a x  + (2a - 4)x - 2a)\|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R            2             4         2               3       2               2
+--R         (8a  + 56a + 96)x  + (- 32a  - 224a - 384)x  + (64a  + 448a + 768)x
+--R       + 
+--R               2                    3      2
+--R         (- 64a  - 448a - 768)x - 8a  - 56a  - 96a
+--R    *
+--R                +--------------+ +------------+
+--R        +-----+ |   +-----+      | +-----+
+--R       \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 321
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)^3
+--R 
+--R
+--R   (1)
+--R   -
+--R        x
+--R     /
+--R           12      11      10       9                8                7
+--R          x   - 12x   + 72x   - 280x  + (- 3a + 768)x  + (24a - 1536)x
+--R        + 
+--R                         6                 5      2                4
+--R          (- 96a + 2240)x  + (240a - 2304)x  + (3a  - 384a + 1536)x
+--R        + 
+--R                2               3       2         2      2     3
+--R          (- 12a  + 384a - 512)x  + (24a  - 192a)x  - 24a x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 181
+
+--S 182 of 321
+r0:=1/8*(1+(-1+x)^2)/((4+a)*(3+a-2*(-1+x)^2-(-1+x)^4)^2)+3/16*(1+(-1+x)^2)/_
+   ((4+a)^2*(3+a-2*(-1+x)^2-(-1+x)^4))+1/8*(5+a+(-1+x)^2)*(-1+x)/_
+   ((12+7*a+a^2)*(3+a-2*(-1+x)^2-(-1+x)^4)^2)+1/32*((6+a)*(25+7*a)+_
+   6*(7+2*a)*(-1+x)^2)*(-1+x)/((3+a)^2*(4+a)^2*(3+a-2*(-1+x)^2-(-1+x)^4))+_
+   3/16*atanh((1+(-1+x)^2)/sqrt(4+a))/(4+a)^(5/2)-3/64*atan((-1+x)/_
+   sqrt(1-sqrt(4+a)))*(80+7*a^2+14*sqrt(4+a)+a*(47+4*sqrt(4+a)))/((3+a)^2*_
+   (4+a)^(5/2)*sqrt(1-sqrt(4+a)))-3/64*atan((-1+x)/sqrt(1+sqrt(4+a)))*_
+   (14+4*a+(-80-47*a-7*a^2)/sqrt(4+a))/((3+a)^2*(4+a)^2*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R                            8               7                   6
+--R               (- 12a - 42)x  + (96a + 336)x  + (- 384a - 1344)x
+--R             + 
+--R                             5       2                 4
+--R               (960a + 3360)x  + (24a  - 1452a - 5376)x
+--R             + 
+--R                     2                 3        2               2
+--R               (- 96a  + 1200a + 5376)x  + (192a  - 96a - 2688)x
+--R             + 
+--R                      2               3      2
+--R               (- 192a  - 672a)x - 12a  - 42a
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R                 2               8        2                 7
+--R           (- 21a  - 141a - 240)x  + (168a  + 1128a + 1920)x
+--R         + 
+--R                  2                 6         2                   5
+--R           (- 672a  - 4512a - 7680)x  + (1680a  + 11280a + 19200)x
+--R         + 
+--R               3        2                   4
+--R           (42a  - 2406a  - 17568a - 30720)x
+--R         + 
+--R                  3        2                   3
+--R           (- 168a  + 1560a  + 16128a + 30720)x
+--R         + 
+--R                3       2                  2          3        2
+--R           (336a  + 912a  - 5184a - 15360)x  + (- 336a  - 2256a  - 3840a)x
+--R         + 
+--R                4       3       2
+--R           - 21a  - 141a  - 240a
+--R      *
+--R          +------------+
+--R          | +-----+                x - 1
+--R         \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R                            8               7                   6
+--R               (- 12a - 42)x  + (96a + 336)x  + (- 384a - 1344)x
+--R             + 
+--R                             5       2                 4
+--R               (960a + 3360)x  + (24a  - 1452a - 5376)x
+--R             + 
+--R                     2                 3        2               2
+--R               (- 96a  + 1200a + 5376)x  + (192a  - 96a - 2688)x
+--R             + 
+--R                      2               3      2
+--R               (- 192a  - 672a)x - 12a  - 42a
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R               2               8          2                 7
+--R           (21a  + 141a + 240)x  + (- 168a  - 1128a - 1920)x
+--R         + 
+--R                2                 6           2                   5
+--R           (672a  + 4512a + 7680)x  + (- 1680a  - 11280a - 19200)x
+--R         + 
+--R                 3        2                   4
+--R           (- 42a  + 2406a  + 17568a + 30720)x
+--R         + 
+--R                3        2                   3
+--R           (168a  - 1560a  - 16128a - 30720)x
+--R         + 
+--R                  3       2                  2        3        2
+--R           (- 336a  - 912a  + 5184a + 15360)x  + (336a  + 2256a  + 3840a)x
+--R         + 
+--R              4       3       2
+--R           21a  + 141a  + 240a
+--R      *
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R         \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R                   2              8         2               7
+--R               (12a  + 72a + 108)x  + (- 96a  - 576a - 864)x
+--R             + 
+--R                    2                 6          2                 5
+--R               (384a  + 2304a + 3456)x  + (- 960a  - 5760a - 8640)x
+--R             + 
+--R                     3        2                  4
+--R               (- 24a  + 1392a  + 9000a + 13824)x
+--R             + 
+--R                   3       2                  3
+--R               (96a  - 960a  - 8352a - 13824)x
+--R             + 
+--R                      3       2                 2        3        2
+--R               (- 192a  - 384a  + 2880a + 6912)x  + (192a  + 1152a  + 1728a)x
+--R             + 
+--R                  4      3       2
+--R               12a  + 72a  + 108a
+--R          *
+--R                    2
+--R                   x  - 2x + 2
+--R             atanh(-----------)
+--R                      +-----+
+--R                     \|a + 4
+--R         + 
+--R                            7         2              6       2                5
+--R               (- 24a - 84)x  + (- 12a  + 96a + 480)x  + (58a  - 254a - 1584)x
+--R             + 
+--R                      2                4        2                3
+--R               (- 146a  + 454a + 3336)x  + (248a  - 412a - 4416)x
+--R             + 
+--R                   3       2                2         3       2
+--R               (20a  - 104a  + 560a + 4032)x  + (- 18a  + 102a  + 240a - 1152)x
+--R             + 
+--R                  3      2
+--R               18a  + 42a  - 72a
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R             4       3        2                  8
+--R         (64a  + 896a  + 4672a  + 10752a + 9216)x
+--R       + 
+--R                4        3         2                   7
+--R         (- 512a  - 7168a  - 37376a  - 86016a - 73728)x
+--R       + 
+--R               4         3          2                     6
+--R         (2048a  + 28672a  + 149504a  + 344064a + 294912)x
+--R       + 
+--R                 4         3          2                     5
+--R         (- 5120a  - 71680a  - 373760a  - 860160a - 737280)x
+--R       + 
+--R                5        4          3          2                       4
+--R         (- 128a  + 6400a  + 105344a  + 576512a  + 1357824a + 1179648)x
+--R       + 
+--R              5        4         3          2                       3
+--R         (512a  - 1024a  - 77312a  - 512000a  - 1302528a - 1179648)x
+--R       + 
+--R                 5         4         3          2                     2
+--R         (- 1024a  - 10240a  - 17408a  + 126976a  + 540672a + 589824)x
+--R       + 
+--R               5         4         3          2                  6       5
+--R         (1024a  + 14336a  + 74752a  + 172032a  + 147456a)x + 64a  + 896a
+--R       + 
+--R              4         3        2
+--R         4672a  + 10752a  + 9216a
+--R    *
+--R                +--------------+ +------------+
+--R        +-----+ |   +-----+      | +-----+
+--R       \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 321
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)^4
+--R 
+--R
+--R   (1)
+--R      18      17       16       15                 14                13
+--R     x   - 16x   + 128x   - 672x   + (- 4a + 2560)x   + (48a - 7424)x
+--R   + 
+--R                      12                   11      2                  10
+--R     (- 288a + 16768)x   + (1120a - 29696)x   + (6a  - 3072a + 40960)x
+--R   + 
+--R           2                  9        2                  8
+--R     (- 48a  + 6144a - 43008)x  + (192a  - 8960a + 32768)x
+--R   + 
+--R            2                  7        3       2                 6
+--R     (- 480a  + 9216a - 16384)x  + (- 4a  + 768a  - 6144a + 4096)x
+--R   + 
+--R         3       2          5         3       2  4      3 3    4 2
+--R     (16a  - 768a  + 2048a)x  + (- 32a  + 384a )x  + 32a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 184
+
+--S 185 of 321
+r0:=1/3*a^4*x^3+8*a^3*x^4+32/5*(12-a)*a^2*x^5+8/3*a*(128-48*a+a^2)*x^6+_
+   4/7*(1024-1536*a+192*a^2-a^3)*x^7-4*(512-288*a+15*a^2)*x^8+64/9*_
+   (128-3*a)*(4-a)*x^9-24/5*(896-128*a+a^2)*x^10+2/11*(20480-1536*a+3*a^2)*_
+   x^11-8/3*(928-35*a)*x^12+32/13*(524-9*a)*x^13-8/7*(464-3*a)*x^14+_
+   4/15*(640-a)*x^15-42*x^16+128/17*x^17-8/9*x^18+1/19*x^19
+--R 
+--R
+--R   (2)
+--R      1  19   8  18   128  17      16       4     512  15    24     3712  14
+--R     -- x   - - x   + --- x   - 42x   + (- -- a + ---)x   + (-- a - ----)x
+--R     19       9        17                  15      3          7       7
+--R   + 
+--R        288     16768  13    280     7424  12     6  2   3072     40960  11
+--R     (- --- a + -----)x   + (--- a - ----)x   + (-- a  - ---- a + -----)x
+--R         13       13          3        3         11       11        11
+--R   + 
+--R        24  2   3072     21504  10    64  2   8960     32768  9
+--R     (- -- a  + ---- a - -----)x   + (-- a  - ---- a + -----)x
+--R         5        5        5           3        9        9
+--R   + 
+--R           2                 8      4  3   768  2   6144     4096  7
+--R     (- 60a  + 1152a - 2048)x  + (- - a  + --- a  - ---- a + ----)x
+--R                                    7       7         7        7
+--R   + 
+--R      8  3       2   1024    6      32  3   384  2  5     3 4   1  4 3
+--R     (- a  - 128a  + ---- a)x  + (- -- a  + --- a )x  + 8a x  + - a x
+--R      3                3             5       5                  3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 185
+
+--S 186 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 321
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)^3
+--R 
+--R
+--R   (1)
+--R        14      13      12       11              10                  9
+--R     - x   + 12x   - 72x   + 280x   + (3a - 768)x   + (- 24a + 1536)x
+--R   + 
+--R                  8                   7        2                6
+--R     (96a - 2240)x  + (- 240a + 2304)x  + (- 3a  + 384a - 1536)x
+--R   + 
+--R         2               5         2         4      2 3    3 2
+--R     (12a  - 384a + 512)x  + (- 24a  + 192a)x  + 24a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 187
+
+--S 188 of 321
+r0:=1/3*a^3*x^3+6*a^2*x^4+24/5*(8-a)*a*x^5+2/3*(128-96*a+3*a^2)*x^6-_
+   3/7*(512-128*a+a^2)*x^7+6*(48-5*a)*x^8-32/9*(70-3*a)*x^9+12/5*(64-a)*_
+   x^10-3/11*(256-a)*x^11+70/3*x^12-72/13*x^13+6/7*x^14-1/15*x^15
+--R 
+--R
+--R   (2)
+--R        1  15   6  14   72  13   70  12     3     768  11      12     768  10
+--R     - -- x   + - x   - -- x   + -- x   + (-- a - ---)x   + (- -- a + ---)x
+--R       15       7       13        3        11      11           5      5
+--R   + 
+--R      32     2240  9                 8      3  2   384     1536  7
+--R     (-- a - ----)x  + (- 30a + 288)x  + (- - a  + --- a - ----)x
+--R       3       9                            7       7        7
+--R   + 
+--R        2         256  6      24  2   192    5     2 4   1  3 3
+--R     (2a  - 64a + ---)x  + (- -- a  + --- a)x  + 6a x  + - a x
+--R                   3           5       5                 3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 188
+
+--S 189 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 321
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R      10     9      8      7                6              5                4
+--R     x   - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R   + 
+--R          3    2 2
+--R     16a x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 190
+
+--S 191 of 321
+r0:=1/3*a^2*x^3+4*a*x^4+16/5*(4-a)*x^5-4/3*(16-a)*x^6+2/7*(64-a)*x^7-10*x^8+_
+   32/9*x^9-4/5*x^10+1/11*x^11
+--R 
+--R
+--R   (2)
+--R      1  11   4  10   32  9      8      2     128  7    4     64  6
+--R     -- x   - - x   + -- x  - 10x  + (- - a + ---)x  + (- a - --)x
+--R     11       5        9                7      7        3      3
+--R   + 
+--R        16     64  5       4   1  2 3
+--R     (- -- a + --)x  + 4a x  + - a x
+--R         5      5              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 191
+
+--S 192 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 321
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)
+--R 
+--R
+--R           6     5     4     3      2
+--R   (1)  - x  + 4x  - 8x  + 8x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 193
+
+--S 194 of 321
+r0:=1/3*a*x^3+2*x^4-8/5*x^5+2/3*x^6-1/7*x^7
+--R 
+--R
+--R          1  7   2  6   8  5     4   1    3
+--R   (2)  - - x  + - x  - - x  + 2x  + - a x
+--R          7      3      5            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 194
+
+--S 195 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 321
+t0:=x^2/(a+8*x-8*x^2+4*x^3-x^4)
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  - -----------------------
+--R           4     3     2
+--R          x  - 4x  + 8x  - 8x - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 196
+
+--S 197 of 321
+r0:=atanh((1+(-1+x)^2)/sqrt(4+a))/sqrt(4+a)-1/2*atan((-1+x)/_
+   sqrt(1-sqrt(4+a)))/sqrt(1-sqrt(4+a))-1/2*atan((-1+x)/sqrt(1+sqrt(4+a)))/_
+   sqrt(1+sqrt(4+a))
+--R 
+--R
+--R   (2)
+--R                  +------------+
+--R          +-----+ | +-----+                x - 1
+--R       - \|a + 4 \|\|a + 4  + 1 atan(-----------------)
+--R                                      +--------------+
+--R                                      |   +-----+
+--R                                     \|- \|a + 4  + 1
+--R     + 
+--R                  +--------------+
+--R          +-----+ |   +-----+               x - 1
+--R       - \|a + 4 \|- \|a + 4  + 1 atan(---------------)
+--R                                        +------------+
+--R                                        | +-----+
+--R                                       \|\|a + 4  + 1
+--R     + 
+--R               2           +--------------+ +------------+
+--R              x  - 2x + 2  |   +-----+      | +-----+
+--R       2atanh(-----------)\|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                 +-----+
+--R                \|a + 4
+--R  /
+--R               +--------------+ +------------+
+--R       +-----+ |   +-----+      | +-----+
+--R     2\|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 321
+t0:=x^2/(a+8*x-8*x^2+4*x^3-x^4)^2
+--R 
+--R
+--R   (1)
+--R      2
+--R     x
+--R  /
+--R        8     7      6      5                4              3                2
+--R       x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R     + 
+--R                2
+--R       16a x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 199
+
+--S 200 of 321
+r0:=1/2*(1+(-1+x)^2)/((4+a)*(3+a-2*(-1+x)^2-(-1+x)^4))+1/4*(2+(-1+x)^2)*_
+   (-1+x)/((3+a)*(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*atanh((1+(-1+x)^2)/_
+   sqrt(4+a))/(4+a)^(3/2)-1/8*atan((-1+x)/sqrt(1-sqrt(4+a)))*(1+_
+   sqrt(4+a))/((3+a)*sqrt(4+a)*sqrt(1-sqrt(4+a)))+1/8*atan((-1+x)/_
+   sqrt(1+sqrt(4+a)))*(1-sqrt(4+a))/((3+a)*sqrt(4+a)*sqrt(1+sqrt(4+a)))
+--R 
+--R
+--R   (2)
+--R                        4             3               2                 2
+--R             ((- a - 4)x  + (4a + 16)x  + (- 8a - 32)x  + (8a + 32)x + a  + 4a)
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R                     4             3               2                 2
+--R           (- a - 4)x  + (4a + 16)x  + (- 8a - 32)x  + (8a + 32)x + a  + 4a
+--R      *
+--R          +------------+
+--R          | +-----+                x - 1
+--R         \|\|a + 4  + 1 atan(-----------------)
+--R                              +--------------+
+--R                              |   +-----+
+--R                             \|- \|a + 4  + 1
+--R     + 
+--R                        4             3               2                 2
+--R             ((- a - 4)x  + (4a + 16)x  + (- 8a - 32)x  + (8a + 32)x + a  + 4a)
+--R          *
+--R              +-----+
+--R             \|a + 4
+--R         + 
+--R                   4               3             2                   2
+--R           (a + 4)x  + (- 4a - 16)x  + (8a + 32)x  + (- 8a - 32)x - a  - 4a
+--R      *
+--R          +--------------+
+--R          |   +-----+               x - 1
+--R         \|- \|a + 4  + 1 atan(---------------)
+--R                                +------------+
+--R                                | +-----+
+--R                               \|\|a + 4  + 1
+--R     + 
+--R                         4                3              2                     2
+--R               (4a + 12)x  + (- 16a - 48)x  + (32a + 96)x  + (- 32a - 96)x - 4a
+--R             + 
+--R               - 12a
+--R          *
+--R                    2
+--R                   x  - 2x + 2
+--R             atanh(-----------)
+--R                      +-----+
+--R                     \|a + 4
+--R         + 
+--R                       3             2                      +-----+
+--R           ((- 2a - 8)x  + (2a + 12)x  + (- 2a - 16)x - 2a)\|a + 4
+--R      *
+--R          +--------------+ +------------+
+--R          |   +-----+      | +-----+
+--R         \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R  /
+--R            2             4         2               3       2               2
+--R         (8a  + 56a + 96)x  + (- 32a  - 224a - 384)x  + (64a  + 448a + 768)x
+--R       + 
+--R               2                    3      2
+--R         (- 64a  - 448a - 768)x - 8a  - 56a  - 96a
+--R    *
+--R                +--------------+ +------------+
+--R        +-----+ |   +-----+      | +-----+
+--R       \|a + 4 \|- \|a + 4  + 1 \|\|a + 4  + 1
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 321
+t0:=(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                    +-------------------------+
+--R            4     3     2           |   4     3     2
+--R   (1)  (- x  + 4x  - 8x  + 8x + a)\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 321
+--r0:=1/7*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2)*(-1+x)+2/35*(13+5*a-3*(-1+x)^2)*_
+--   (-1+x)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4)-16/35*(7+2*a)*_
+--   elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*_
+--   (1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+4/35*_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*_
+--   (76+5*a^2+28*sqrt(4+a)+a*(39+8*sqrt(4+a)))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 203
+
+--S 204 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 204
+
+)clear all
+
+--S 205 of 321
+t0:=(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R         +-------------------------+
+--R         |   4     3     2
+--R   (1)  \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 321
+--r0:=1/3*(-1+x)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4)-2/3*elliptic_e(asin((-1+x)/_
+--   sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+2/3*_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*_
+--   (4+a+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 206
+
+--S 207 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 207
+
+)clear all
+
+--S 208 of 321
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R         +-------------------------+
+--R         |   4     3     2
+--R        \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 321
+--r0:=elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+_
+--   sqrt(4+a)))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 209
+
+--S 210 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 210
+
+)clear all
+
+--S 211 of 321
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                    1
+--R   (1)  - -----------------------------------------------------
+--R                                    +-------------------------+
+--R            4     3     2           |   4     3     2
+--R          (x  - 4x  + 8x  - 8x - a)\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 321
+--r0:=1/2*(5+a+(-1+x)^2)*(-1+x)/((12+7*a+a^2)*sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4))-1/2*elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   ((3+a)*(4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*elliptic_f(asin((-1+x)/_
+--   sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(4+a+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/((3+a)*(4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 212
+
+--S 213 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 213
+
+)clear all
+
+--S 214 of 321
+t0:=1/(a+8*x-8*x^2+4*x^3-x^4)^(5/2)
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R          8     7      6      5                4              3                2
+--R         x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R       + 
+--R                  2
+--R         16a x + a
+--R    *
+--R        +-------------------------+
+--R        |   4     3     2
+--R       \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 321
+--r0:=1/6*(5+a+(-1+x)^2)*(-1+x)/((12+7*a+a^2)*(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)^(3/2))+1/12*(104+47*a+5*a^2+4*(7+2*a)*(-1+x)^2)*(-1+x)/_
+--   ((3+a)^2*(4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))-1/3*(7+2*a)*_
+--   elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*_
+--   (1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/((3+a)^2*(4+a)^2*sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4))+1/12*elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(76+5*a^2+28*sqrt(4+a)+a*(39+8*sqrt(4+a)))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/((3+a)^2*(4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 215
+
+--S 216 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 216
+
+)clear all
+
+--S 217 of 321
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                       +-------------------------+
+--R            5     4     3     2        |   4     3     2
+--R   (1)  (- x  + 4x  - 8x  + 8x  + a x)\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 321
+--r0:=1/8*(1+(-1+x)^2)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2)+1/7*(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)^(3/2)*(-1+x)+3/16*(4+a)^2*atan((1+(-1+x)^2)/sqrt(3+a-2*_
+--   (-1+x)^2-(-1+x)^4))+3/16*(4+a)*(1+(-1+x)^2)*sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)+2/35*(13+5*a-3*(-1+x)^2)*(-1+x)*sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)-16/35*(7+2*a)*elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+4/35*elliptic_f(asin((-1+x)/_
+--   sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(76+5*a^2+_
+--   28*sqrt(4+a)+a*(39+8*sqrt(4+a)))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)
+--E 218
+
+--S 219 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 219
+
+)clear all
+
+--S 220 of 321
+t0:=x*(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R          +-------------------------+
+--R          |   4     3     2
+--R   (1)  x\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 321
+--r0:=1/4*(4+a)*atan((1+(-1+x)^2)/sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+_
+--   1/4*(1+(-1+x)^2)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+1/3*(-1+x)*sqrt(3+a-_
+--   2*(-1+x)^2-(-1+x)^4)-2/3*elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-_
+--   sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+2/3*elliptic_f(asin((-1+x)/sqrt(-1+_
+--   sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(4+a+sqrt(4+a))*sqrt(1+_
+--   (-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+_
+--   sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 221
+
+--S 222 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 222
+
+)clear all
+
+--S 223 of 321
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R                      x
+--R   (1)  ----------------------------
+--R         +-------------------------+
+--R         |   4     3     2
+--R        \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 321
+--r0:=1/2*atan((1+(-1+x)^2)/sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 224
+
+--S 225 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 225
+
+)clear all
+
+--S 226 of 321
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                    x
+--R   (1)  - -----------------------------------------------------
+--R                                    +-------------------------+
+--R            4     3     2           |   4     3     2
+--R          (x  - 4x  + 8x  - 8x - a)\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 321
+--r0:=1/2*(1+(-1+x)^2)/((4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*(5+a+_
+--   (-1+x)^2)*(-1+x)/((12+7*a+a^2)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))-_
+--   1/2*elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/_
+--   (1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/((3+a)*(4+a)*_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*elliptic_f(asin((-1+x)/_
+--   sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(4+a+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/((3+a)*(4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 227
+
+--S 228 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 228
+
+)clear all
+
+--S 229 of 321
+t0:=x/(a+8*x-8*x^2+4*x^3-x^4)^(5/2)
+--R 
+--R
+--R   (1)
+--R     x
+--R  /
+--R          8     7      6      5                4              3                2
+--R         x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R       + 
+--R                  2
+--R         16a x + a
+--R    *
+--R        +-------------------------+
+--R        |   4     3     2
+--R       \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 321
+--r0:=1/6*(1+(-1+x)^2)/((4+a)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2))+1/6*(5+_
+--   a+(-1+x)^2)*(-1+x)/((12+7*a+a^2)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2))+_
+--   1/3*(1+(-1+x)^2)/((4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/12*(104+_
+--   47*a+5*a^2+4*(7+2*a)*(-1+x)^2)*(-1+x)/((3+a)^2*(4+a)^2*sqrt(3+a-_
+--   2*(-1+x)^2-(-1+x)^4))-1/3*(7+2*a)*elliptic_e(asin((-1+x)/sqrt(-1+_
+--   sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+_
+--   (-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+_
+--   sqrt(4+a)))/((3+a)^2*(4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/12*_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+_
+--   sqrt(4+a)))*(76+5*a^2+28*sqrt(4+a)+a*(39+8*sqrt(4+a)))*sqrt(1+_
+--   (-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+_
+--   sqrt(4+a)))/((3+a)^2*(4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 230
+
+--S 231 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 231
+
+)clear all
+
+--S 232 of 321
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                        +-------------------------+
+--R            6     5     4     3      2  |   4     3     2
+--R   (1)  (- x  + 4x  - 8x  + 8x  + a x )\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 321
+--r0:=1/4*(1+(-1+x)^2)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2)+1/63*(15+7*(-1+x)^2)*_
+--   (3+a-2*(-1+x)^2-(-1+x)^4)^(3/2)*(-1+x)+3/8*(4+a)^2*atan((1+(-1+x)^2)/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+3/8*(4+a)*(1+(-1+x)^2)*sqrt(3+a-2*_
+--   (-1+x)^2-(-1+x)^4)+2/315*(2*(80+27*a)+3*(20+7*a)*(-1+x)^2)*(-1+x)*_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+4/315*(140+111*a+21*a^2)*_
+--   elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/_
+--   (1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)+4/315*elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(160+88*a+12*a^2-(140+111*a+21*a^2)*_
+--   sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 233
+
+--S 234 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 234
+
+)clear all
+
+--S 235 of 321
+t0:=x^2*(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R           +-------------------------+
+--R         2 |   4     3     2
+--R   (1)  x \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 321
+--r0:=1/2*(4+a)*atan((1+(-1+x)^2)/sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+_
+--   1/2*(1+(-1+x)^2)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+1/15*(7+3*(-1+x)^2)*_
+--   (-1+x)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4)+2/15*(8+3*a)*_
+--   elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+_
+--   sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)+2/15*elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(4+a-(8+3*a)*sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 236
+
+--S 237 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 237
+
+)clear all
+
+--S 238 of 321
+t0:=x^2/(a+8*x-8*x^2+4*x^3-x^4)^(1/2)
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ----------------------------
+--R         +-------------------------+
+--R         |   4     3     2
+--R        \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 321
+--r0:=atan((1+(-1+x)^2)/sqrt(3+a-2*(-1+x)^2-(-1+x)^4))-_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/_
+--   (1+sqrt(4+a)))*sqrt(4+a)*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4)+elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/_
+--   (1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4)
+--E 239
+
+--S 240 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 240
+
+)clear all
+
+--S 241 of 321
+t0:=x^2/(a+8*x-8*x^2+4*x^3-x^4)^(3/2)
+--R 
+--R
+--R                                     2
+--R                                    x
+--R   (1)  - -----------------------------------------------------
+--R                                    +-------------------------+
+--R            4     3     2           |   4     3     2
+--R          (x  - 4x  + 8x  - 8x - a)\|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 321
+--r0:=(1+(-1+x)^2)/((4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*(2+(-1+x)^2)*_
+--   (-1+x)/((3+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))-1/2*_
+--   elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/_
+--   (1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*_
+--   sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/((3+a)*_
+--   sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/2*elliptic_f(asin((-1+x)/_
+--   sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*_
+--   sqrt(1+(-1+x)^2/(1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1+sqrt(4+a)))/((3+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 242
+
+--S 243 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 243
+
+)clear all
+
+--S 244 of 321
+t0:=x^2/(a+8*x-8*x^2+4*x^3-x^4)^(5/2)
+--R 
+--R
+--R   (1)
+--R      2
+--R     x
+--R  /
+--R          8     7      6      5                4              3                2
+--R         x  - 8x  + 32x  - 80x  + (- 2a + 128)x  + (8a - 128)x  + (- 16a + 64)x
+--R       + 
+--R                  2
+--R         16a x + a
+--R    *
+--R        +-------------------------+
+--R        |   4     3     2
+--R       \|- x  + 4x  - 8x  + 8x + a
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 321
+--r0:=1/3*(1+(-1+x)^2)/((4+a)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2))+_
+--   1/6*(2+(-1+x)^2)*(-1+x)/((3+a)*(3+a-2*(-1+x)^2-(-1+x)^4)^(3/2))+_
+--   2/3*(1+(-1+x)^2)/((4+a)^2*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/12*(29+_
+--   7*a+(13+3*a)*(-1+x)^2)*(-1+x)/((3+a)^2*(4+a)*sqrt(3+a-2*(-1+x)^2-_
+--   (-1+x)^4))-1/12*(13+3*a)*elliptic_e(asin((-1+x)/sqrt(-1+sqrt(4+a))),_
+--   (1-sqrt(4+a))/(1+sqrt(4+a)))*(1+sqrt(4+a))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   ((3+a)^2*(4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))+1/12*_
+--   elliptic_f(asin((-1+x)/sqrt(-1+sqrt(4+a))),(1-sqrt(4+a))/(1+_
+--   sqrt(4+a)))*(16+13*sqrt(4+a)+a*(4+3*sqrt(4+a)))*sqrt(1+(-1+x)^2/_
+--   (1-sqrt(4+a)))*sqrt(-1+sqrt(4+a))*sqrt(1+(-1+x)^2/(1+sqrt(4+a)))/_
+--   ((3+a)^2*(4+a)*sqrt(3+a-2*(-1+x)^2-(-1+x)^4))
+--E 245
+
+--S 246 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 246
+
+)clear all
+
+--S 247 of 321
+t0:=(8+8*x-x^3+8*x^4)^4
+--R 
+--R
+--R   (1)
+--R          16        15       14         13         12        11         10
+--R     4096x   - 2048x   + 384x   + 16352x   + 10241x   - 5376x   + 25312x
+--R   + 
+--R           9         8         7         6         5         4         3
+--R     42976x  + 12672x  + 11008x  + 47488x  + 43008x  + 14336x  + 14336x
+--R   + 
+--R           2
+--R     24576x  + 16384x + 4096
+--R                                                    Type: Polynomial(Integer)
+--E 247
+
+--S 248 of 321
+r0:=4096*x+8192*x^2+8192*x^3+3584*x^4+14336/5*x^5+7168*x^6+6784*x^7+_
+   1376*x^8+1408*x^9+21488/5*x^10+25312/11*x^11-448*x^12+10241/13*x^13+_
+   1168*x^14+128/5*x^15-128*x^16+4096/17*x^17
+--R 
+--R
+--R   (2)
+--R     4096  17       16   128  15        14   10241  13       12   25312  11
+--R     ---- x   - 128x   + --- x   + 1168x   + ----- x   - 448x   + ----- x
+--R      17                  5                    13                   11
+--R   + 
+--R     21488  10        9        8        7        6   14336  5        4        3
+--R     ----- x   + 1408x  + 1376x  + 6784x  + 7168x  + ----- x  + 3584x  + 8192x
+--R       5                                               5
+--R   + 
+--R          2
+--R     8192x  + 4096x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 248
+
+--S 249 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 321
+t0:=(8+8*x-x^3+8*x^4)^3
+--R 
+--R
+--R   (1)
+--R         12       11      10        9        8       7        6        5
+--R     512x   - 192x   + 24x   + 1535x  + 1152x  - 360x  + 1560x  + 2880x
+--R   + 
+--R          4       3        2
+--R     1152x  + 320x  + 1536x  + 1536x + 512
+--R                                                    Type: Polynomial(Integer)
+--E 250
+
+--S 251 of 321
+r0:=512*x+768*x^2+512*x^3+80*x^4+1152/5*x^5+480*x^6+1560/7*x^7-45*x^8+_
+   128*x^9+307/2*x^10+24/11*x^11-16*x^12+512/13*x^13
+--R 
+--R
+--R   (2)
+--R     512  13      12   24  11   307  10       9      8   1560  7       6
+--R     --- x   - 16x   + -- x   + --- x   + 128x  - 45x  + ---- x  + 480x
+--R      13               11        2                         7
+--R   + 
+--R     1152  5      4       3       2
+--R     ---- x  + 80x  + 512x  + 768x  + 512x
+--R       5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 251
+
+--S 252 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 321
+t0:=(8+8*x-x^3+8*x^4)^2
+--R 
+--R
+--R           8      7    6       5       4      3      2
+--R   (1)  64x  - 16x  + x  + 128x  + 112x  - 16x  + 64x  + 128x + 64
+--R                                                    Type: Polynomial(Integer)
+--E 253
+
+--S 254 of 321
+r0:=64*x+64*x^2+64/3*x^3-4*x^4+112/5*x^5+64/3*x^6+1/7*x^7-2*x^8+64/9*x^9
+--R 
+--R
+--R        64  9     8   1  7   64  6   112  5     4   64  3      2
+--R   (2)  -- x  - 2x  + - x  + -- x  + --- x  - 4x  + -- x  + 64x  + 64x
+--R         9            7       3       5              3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 254
+
+--S 255 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 321
+t0:=8+8*x-x^3+8*x^4
+--R 
+--R
+--R          4    3
+--R   (1)  8x  - x  + 8x + 8
+--R                                                    Type: Polynomial(Integer)
+--E 256
+
+--S 257 of 321
+r0:=8*x+4*x^2-1/4*x^4+8/5*x^5
+--R 
+--R
+--R        8  5   1  4     2
+--R   (2)  - x  - - x  + 4x  + 8x
+--R        5      4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 257
+
+--S 258 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 321
+t0:=1/(8+8*x-x^3+8*x^4)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R          4    3
+--R        8x  - x  + 8x + 8
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 259
+
+--S 260 of 321
+r0:=-1/12*atan(1/6*(3-(1+4/x)^2)/sqrt(7))/sqrt(7)-1/24*log((1+4/x)^2+_
+   3*sqrt(29)-(1+4/x)*sqrt(6*(1+sqrt(29))))*sqrt(1/1218*(-109+_
+   67*sqrt(29)))+1/24*log((1+4/x)^2+3*sqrt(29)+(1+4/x)*sqrt(6*(1+_
+   sqrt(29))))*sqrt(1/1218*(-109+67*sqrt(29)))+1/12*atan((-2*(1+4/x)+_
+   sqrt(6*(1+sqrt(29))))/sqrt(6*(-1+sqrt(29))))*sqrt(1/1218*(109+67*_
+   sqrt(29)))-1/12*atan((2*(1+4/x)+sqrt(6*(1+sqrt(29))))/sqrt(6*(-1+_
+   sqrt(29))))*sqrt(1/1218*(109+67*sqrt(29)))
+--R 
+--R
+--R   (2)
+--R                                         +----------+
+--R            +-------------+      2       |  +--+          2 +--+    2
+--R        +-+ |   +--+           (x  + 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R       \|7 \|67\|29  - 109 log(------------------------------------------------)
+--R                                                       2
+--R                                                      x
+--R     + 
+--R       -
+--R                 +-------------+
+--R             +-+ |   +--+
+--R            \|7 \|67\|29  - 109
+--R         *
+--R                            +----------+
+--R                    2       |  +--+          2 +--+    2
+--R                (- x  - 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R            log(--------------------------------------------------)
+--R                                         2
+--R                                        x
+--R     + 
+--R       -
+--R                  +-------------+
+--R              +-+ |   +--+
+--R            2\|7 \|67\|29  + 109
+--R         *
+--R            atan
+--R                                +----------+ +----------+
+--R                      +--+      |  +--+      |  +--+
+--R                   (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R                 + 
+--R                                            +----------+
+--R                             +--+           |  +--+
+--R                   ((2x + 8)\|29  + 2x + 8)\|6\|29  - 6
+--R              /
+--R                 168x
+--R     + 
+--R               +-------------+
+--R           +-+ |   +--+
+--R         2\|7 \|67\|29  + 109
+--R      *
+--R         atan
+--R                             +----------+ +----------+
+--R                   +--+      |  +--+      |  +--+
+--R                (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R              + 
+--R                                           +----------+
+--R                            +--+           |  +--+
+--R                ((- 2x - 8)\|29  - 2x - 8)\|6\|29  - 6
+--R           /
+--R              168x
+--R     + 
+--R                        2           +-+
+--R           +----+     (x  - 4x - 8)\|7
+--R       - 2\|1218 atan(-----------------)
+--R                                2
+--R                             21x
+--R  /
+--R        +-+ +----+
+--R     24\|7 \|1218
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                            +----------+
+--R                2           +--+      2              +----+ |  +--+
+--R         ((- 23x  - 4x - 8)\|29  - 51x  - 60x - 120)\|1218 \|6\|29  - 6
+--R      *
+--R          +-------------+
+--R          |   +--+
+--R         \|67\|29  + 109
+--R     + 
+--R                                                          +----------+
+--R              2           +--+      2              +----+ |  +--+
+--R         ((22x  - 4x - 8)\|29  + 36x  - 60x - 120)\|1218 \|6\|29  + 6
+--R      *
+--R          +-------------+
+--R          |   +--+
+--R         \|67\|29  - 109
+--R     + 
+--R             2                   +--+          2
+--R       (7308x  + 29232x + 58464)\|29  + 109620x  + 438480x + 876960
+--R  /
+--R               4         3                     +--+           4          3
+--R       (467712x  - 58464x  + 467712x + 467712)\|29  + 7015680x  - 876960x
+--R     + 
+--R       7015680x + 7015680
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 321
+t0:=1/(8+8*x-x^3+8*x^4)^2
+--R 
+--R
+--R                                     1
+--R   (1)  ----------------------------------------------------------
+--R           8      7    6       5       4      3      2
+--R        64x  - 16x  + x  + 128x  + 112x  - 16x  + 64x  + 128x + 64
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 262
+
+--S 263 of 321
+r0:=1/336*(-207+34*(1+4/x)^2)/(261-6*(1+4/x)^2+(1+4/x)^4)+3/16*(1+4/x)/_
+   (261-6*(1+4/x)^2+(1+4/x)^4)+1/43848*(4671-2243*(1+4/x)^2)*(1+4/x)/_
+   (261-6*(1+4/x)^2+(1+4/x)^4)-3/16*(1+4/x)^2/(261-6*(1+4/x)^2+(1+4/x)^4)+_
+   1/16*(1+4/x)^3/(261-6*(1+4/x)^2+(1+4/x)^4)-17/1008*atan(1/6*(3-_
+   (1+4/x)^2)/sqrt(7))/sqrt(7)-1/175392*log((1+4/x)^2+3*sqrt(29)-_
+   (1+4/x)*sqrt(6*(1+sqrt(29))))*sqrt(1/1218*(-180983329+45923327*_
+   sqrt(29)))+1/175392*log((1+4/x)^2+3*sqrt(29)+(1+4/x)*sqrt(6*(1+_
+   sqrt(29))))*sqrt(1/1218*(-180983329+45923327*sqrt(29)))+1/87696*_
+   atan((-2*(1+4/x)+sqrt(6*(1+sqrt(29))))/sqrt(6*(-1+sqrt(29))))*_
+   sqrt(1/1218*(180983329+45923327*sqrt(29)))-1/87696*atan((2*(1+4/x)+_
+   sqrt(6*(1+sqrt(29))))/sqrt(6*(-1+sqrt(29))))*sqrt(1/1218*_
+   (180983329+45923327*sqrt(29)))
+--R 
+--R
+--R   (2)
+--R                                 +-------------------------+
+--R            4    3           +-+ |         +--+
+--R         (8x  - x  + 8x + 8)\|7 \|45923327\|29  - 180983329
+--R      *
+--R                       +----------+
+--R               2       |  +--+          2 +--+    2
+--R             (x  + 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R         log(------------------------------------------------)
+--R                                     2
+--R                                    x
+--R     + 
+--R                                   +-------------------------+
+--R              4    3           +-+ |         +--+
+--R         (- 8x  + x  - 8x - 8)\|7 \|45923327\|29  - 180983329
+--R      *
+--R                         +----------+
+--R                 2       |  +--+          2 +--+    2
+--R             (- x  - 4x)\|6\|29  + 6  + 3x \|29  + x  + 8x + 16
+--R         log(--------------------------------------------------)
+--R                                      2
+--R                                     x
+--R     + 
+--R                                       +-------------------------+
+--R               4     3             +-+ |         +--+
+--R         (- 16x  + 2x  - 16x - 16)\|7 \|45923327\|29  + 180983329
+--R      *
+--R         atan
+--R                             +----------+ +----------+
+--R                   +--+      |  +--+      |  +--+
+--R                (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R              + 
+--R                                         +----------+
+--R                          +--+           |  +--+
+--R                ((2x + 8)\|29  + 2x + 8)\|6\|29  - 6
+--R           /
+--R              168x
+--R     + 
+--R                                     +-------------------------+
+--R             4     3             +-+ |         +--+
+--R         (16x  - 2x  + 16x + 16)\|7 \|45923327\|29  + 180983329
+--R      *
+--R         atan
+--R                             +----------+ +----------+
+--R                   +--+      |  +--+      |  +--+
+--R                (x\|29  + x)\|6\|29  - 6 \|6\|29  + 6
+--R              + 
+--R                                           +----------+
+--R                            +--+           |  +--+
+--R                ((- 2x - 8)\|29  - 2x - 8)\|6\|29  - 6
+--R           /
+--R              168x
+--R     + 
+--R                                                          2           +-+
+--R                4        3                   +----+     (x  - 4x - 8)\|7
+--R       (- 23664x  + 2958x  - 23664x - 23664)\|1218 atan(-----------------)
+--R                                                                  2
+--R                                                               21x
+--R     + 
+--R               4        3        2          +-+ +----+
+--R       (- 2176x  + 3408x  - 4584x  + 3980x)\|7 \|1218
+--R  /
+--R              4          3                       +-+ +----+
+--R     (1403136x  - 175392x  + 1403136x + 1403136)\|7 \|1218
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                            +----------+
+--R                2           +--+      2              +----+ |  +--+
+--R         ((- 23x  - 4x - 8)\|29  - 51x  - 60x - 120)\|1218 \|6\|29  - 6
+--R      *
+--R          +-------------------------+
+--R          |         +--+
+--R         \|45923327\|29  + 180983329
+--R     + 
+--R                                                          +----------+
+--R              2           +--+      2              +----+ |  +--+
+--R         ((22x  - 4x - 8)\|29  + 36x  - 60x - 120)\|1218 \|6\|29  + 6
+--R      *
+--R          +-------------------------+
+--R          |         +--+
+--R         \|45923327\|29  - 180983329
+--R     + 
+--R                 2                         +--+             2
+--R       (18447828x  + 21855792x + 43711584)\|29  + 276717420x  + 327836880x
+--R     + 
+--R       655673760
+--R  /
+--R                   4             3                             +--+
+--R       (3418039296x  - 427254912x  + 3418039296x + 3418039296)\|29
+--R     + 
+--R                   4              3
+--R       51270589440x  - 6408823680x  + 51270589440x + 51270589440
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 321
+t0:=1/(8+8*x-x^3+8*x^4)^(1/2)
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-----------------+
+--R         |  4    3
+--R        \|8x  - x  + 8x + 8
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 321
+--r0:=-x^2*elliptic_f(asin((1+4/x)/sqrt(3*(1-2*%i*sqrt(7)))),_
+--   (%i+2*sqrt(7))/(%i-2*sqrt(7)))*sqrt(3-(1+4/x)^2/(1-2*%i*sqrt(7)))*_
+--   sqrt(3-(1+4/x)^2/(1+2*%i*sqrt(7)))*sqrt(2/3*(1-2*%i*sqrt(7)))/_
+--   sqrt((261-6*(1+4/x)^2+(1+4/x)^4)*x^4)
+--E 266
+
+--S 267 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 267
+
+)clear all
+
+--S 268 of 321
+t0:=(1+4*x+4*x^2+4*x^4)^4
+--R 
+--R
+--R   (1)
+--R         16        14        13        12        11        10        9        8
+--R     256x   + 1024x   + 1024x   + 1792x   + 3072x   + 3328x   + 3840x  + 4192x
+--R   + 
+--R          7        6        5        4       3       2
+--R     3584x  + 2752x  + 1984x  + 1136x  + 448x  + 112x  + 16x + 1
+--R                                                    Type: Polynomial(Integer)
+--E 268
+
+--S 269 of 321
+r0:=x+8*x^2+112/3*x^3+112*x^4+1136/5*x^5+992/3*x^6+2752/7*x^7+448*x^8+_
+   4192/9*x^9+384*x^10+3328/11*x^11+256*x^12+1792/13*x^13+512/7*x^14+_
+   1024/15*x^15+256/17*x^17
+--R 
+--R
+--R   (2)
+--R     256  17   1024  15   512  14   1792  13       12   3328  11       10
+--R     --- x   + ---- x   + --- x   + ---- x   + 256x   + ---- x   + 384x
+--R      17        15         7         13                  11
+--R   + 
+--R     4192  9       8   2752  7   992  6   1136  5       4   112  3     2
+--R     ---- x  + 448x  + ---- x  + --- x  + ---- x  + 112x  + --- x  + 8x  + x
+--R       9                 7        3         5                3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 269
+
+--S 270 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 321
+t0:=(1+4*x+4*x^2+4*x^4)^3
+--R 
+--R
+--R   (1)
+--R        12       10       9       8       7       6       5       4       3
+--R     64x   + 192x   + 192x  + 240x  + 384x  + 352x  + 288x  + 252x  + 160x
+--R   + 
+--R        2
+--R     60x  + 12x + 1
+--R                                                    Type: Polynomial(Integer)
+--E 271
+
+--S 272 of 321
+r0:=x+6*x^2+20*x^3+40*x^4+252/5*x^5+48*x^6+352/7*x^7+48*x^8+80/3*x^9+_
+   96/5*x^10+192/11*x^11+64/13*x^13
+--R 
+--R
+--R   (2)
+--R     64  13   192  11   96  10   80  9      8   352  7      6   252  5      4
+--R     -- x   + --- x   + -- x   + -- x  + 48x  + --- x  + 48x  + --- x  + 40x
+--R     13        11        5        3              7               5
+--R   + 
+--R        3     2
+--R     20x  + 6x  + x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 272
+
+--S 273 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 321
+t0:=(1+4*x+4*x^2+4*x^4)^2
+--R 
+--R
+--R           8      6      5      4      3      2
+--R   (1)  16x  + 32x  + 32x  + 24x  + 32x  + 24x  + 8x + 1
+--R                                                    Type: Polynomial(Integer)
+--E 274
+
+--S 275 of 321
+r0:=x+4*x^2+8*x^3+8*x^4+24/5*x^5+16/3*x^6+32/7*x^7+16/9*x^9
+--R 
+--R
+--R        16  9   32  7   16  6   24  5     4     3     2
+--R   (2)  -- x  + -- x  + -- x  + -- x  + 8x  + 8x  + 4x  + x
+--R         9       7       3       5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 275
+
+--S 276 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 321
+t0:=1+4*x+4*x^2+4*x^4
+--R 
+--R
+--R          4     2
+--R   (1)  4x  + 4x  + 4x + 1
+--R                                                    Type: Polynomial(Integer)
+--E 277
+
+--S 278 of 321
+r0:=x+2*x^2+4/3*x^3+4/5*x^5
+--R 
+--R
+--R        4  5   4  3     2
+--R   (2)  - x  + - x  + 2x  + x
+--R        5      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 278
+
+--S 279 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 321
+t0:=1/(1+4*x+4*x^2+4*x^4)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R          4     2
+--R        4x  + 4x  + 4x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 280
+
+--S 281 of 321
+r0:=-1/2*atan(1/2-1/2*(1+1/x)^2)+1/4*atan((-2*(1+1/x)+sqrt(2*(1+sqrt(5))))/_
+   sqrt(2*(-1+sqrt(5))))*(1+sqrt(5))^(3/2)/sqrt(10)-1/4*atan((2*(1+1/x)+_
+   sqrt(2*(1+sqrt(5))))/sqrt(2*(-1+sqrt(5))))*(1+sqrt(5))^(3/2)/sqrt(10)-_
+   1/4*log((1+1/x)^2+sqrt(5)-(1+1/x)*sqrt(2*(1+sqrt(5))))*sqrt(1/5*_
+   (-2+sqrt(5)))+1/4*log((1+1/x)^2+sqrt(5)+(1+1/x)*sqrt(2*(1+sqrt(5))))*_
+   sqrt(1/5*(-2+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                    +---------+
+--R             +--------+      2      |  +-+         2 +-+    2
+--R        +--+ | +-+         (x  + x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R       \|10 \|\|5  - 2 log(-------------------------------------------)
+--R                                                 2
+--R                                                x
+--R     + 
+--R                                        +---------+
+--R               +--------+        2      |  +-+         2 +-+    2
+--R          +--+ | +-+         (- x  - x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R       - \|10 \|\|5  - 2 log(---------------------------------------------)
+--R                                                    2
+--R                                                   x
+--R     + 
+--R                      +--------+
+--R             +-+      | +-+
+--R         (- \|5  - 5)\|\|5  + 1
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                        +---------+
+--R                          +-+           |  +-+
+--R                ((2x + 2)\|5  + 2x + 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R                    +--------+
+--R           +-+      | +-+
+--R         (\|5  + 5)\|\|5  + 1
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                          +---------+
+--R                            +-+           |  +-+
+--R                ((- 2x - 2)\|5  - 2x - 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R         +-+ +--+     2x + 1
+--R       2\|5 \|10 atan(------)
+--R                          2
+--R                        2x
+--R  /
+--R       +-+ +--+
+--R     4\|5 \|10
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                             +--------+ +---------+
+--R           2           +-+      2            | +-+      |  +-+
+--R       ((2x  - 6x - 3)\|5  + 10x  - 10x - 5)\|\|5  - 2 \|2\|5  + 2
+--R     + 
+--R                                                  +--------+ +---------+
+--R             2           +-+     2           +--+ | +-+      |  +-+
+--R       ((- 3x  - 2x - 1)\|5  - 7x  - 4x - 2)\|10 \|\|5  + 1 \|2\|5  - 2
+--R     + 
+--R           2             +-+      2
+--R       (20x  + 20x + 10)\|5  + 60x  + 60x + 30
+--R  /
+--R         4      2             +-+       4       2
+--R     (40x  + 40x  + 40x + 10)\|5  + 120x  + 120x  + 120x + 30
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 321
+t0:=1/(1+4*x+4*x^2+4*x^4)^2
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R           8      6      5      4      3      2
+--R        16x  + 32x  + 32x  + 24x  + 32x  + 24x  + 8x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 283
+
+--S 284 of 321
+r0:=1/2*(-17+7*(1+1/x)^2)/(5-2*(1+1/x)^2+(1+1/x)^4)+13/3*(1+1/x)/(5-_
+   2*(1+1/x)^2+(1+1/x)^4)+1/30*(47-81*(1+1/x)^2)*(1+1/x)/(5-2*(1+1/x)^2+_
+   (1+1/x)^4)-3*(1+1/x)^2/(5-2*(1+1/x)^2+(1+1/x)^4)+(1+1/x)^3/(5-2*_
+   (1+1/x)^2+(1+1/x)^4)-7/4*atan(1/2-1/2*(1+1/x)^2)+1/40*log((1+1/x)^2+_
+   sqrt(5)-(1+1/x)*sqrt(2*(1+sqrt(5))))*sqrt(1/10*(-5959+2665*sqrt(5)))-_
+   1/40*log((1+1/x)^2+sqrt(5)+(1+1/x)*sqrt(2*(1+sqrt(5))))*sqrt(1/10*_
+   (-5959+2665*sqrt(5)))+1/20*atan((-2*(1+1/x)+sqrt(2*(1+sqrt(5))))/_
+   sqrt(2*(-1+sqrt(5))))*sqrt(1/10*(5959+2665*sqrt(5)))-1/20*atan((2*_
+   (1+1/x)+sqrt(2*(1+sqrt(5))))/sqrt(2*(-1+sqrt(5))))*sqrt(1/10*(5959+_
+   2665*sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                +---------------+
+--R              4     2           |     +-+
+--R         (- 4x  - 4x  - 4x - 1)\|2665\|5  - 5959
+--R      *
+--R                      +---------+
+--R               2      |  +-+         2 +-+    2
+--R             (x  + x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R         log(-------------------------------------------)
+--R                                   2
+--R                                  x
+--R     + 
+--R                              +---------------+
+--R            4     2           |     +-+
+--R         (4x  + 4x  + 4x + 1)\|2665\|5  - 5959
+--R      *
+--R                        +---------+
+--R                 2      |  +-+         2 +-+    2
+--R             (- x  - x)\|2\|5  + 2  + x \|5  + x  + 2x + 1
+--R         log(---------------------------------------------)
+--R                                    2
+--R                                   x
+--R     + 
+--R                                +---------------+
+--R              4     2           |     +-+
+--R         (- 8x  - 8x  - 8x - 2)\|2665\|5  + 5959
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                        +---------+
+--R                          +-+           |  +-+
+--R                ((2x + 2)\|5  + 2x + 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R                              +---------------+
+--R            4     2           |     +-+
+--R         (8x  + 8x  + 8x + 2)\|2665\|5  + 5959
+--R      *
+--R         atan
+--R                            +---------+ +---------+
+--R                   +-+      |  +-+      |  +-+
+--R                (x\|5  + x)\|2\|5  - 2 \|2\|5  + 2
+--R              + 
+--R                                          +---------+
+--R                            +-+           |  +-+
+--R                ((- 2x - 2)\|5  - 2x - 2)\|2\|5  - 2
+--R           /
+--R              8x
+--R     + 
+--R            4       2              +--+     2x + 1
+--R       (280x  + 280x  + 280x + 70)\|10 atan(------)
+--R                                                2
+--R                                              2x
+--R     + 
+--R              4      3       2        +--+
+--R       (- 152x  + 72x  - 184x  - 68x)\|10
+--R  /
+--R          4       2              +--+
+--R     (160x  + 160x  + 160x + 40)\|10
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                  +---------+ +---------------+
+--R             2           +-+     2           +--+ |  +-+      |     +-+
+--R       ((- 4x  - 2x - 1)\|5  - 8x  - 6x - 3)\|10 \|2\|5  - 2 \|2665\|5  + 5959
+--R     + 
+--R                                                  +---------+ +---------------+
+--R             2           +-+     2           +--+ |  +-+      |     +-+
+--R       ((- 2x  + 2x + 1)\|5  - 2x  + 6x + 3)\|10 \|2\|5  + 2 \|2665\|5  - 5959
+--R     + 
+--R             2                +-+        2
+--R       (1760x  + 1080x + 540)\|5  + 5280x  + 3240x + 1620
+--R  /
+--R          4       2               +-+        4        2
+--R     (800x  + 800x  + 800x + 200)\|5  + 2400x  + 2400x  + 2400x + 600
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 321
+t0:=1/(1+4*x+4*x^2+4*x^4)^(1/2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         +------------------+
+--R         |  4     2
+--R        \|4x  + 4x  + 4x + 1
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 321
+--r0:=-x^2*elliptic_f(asin((1+1/x)*sqrt(1/5-2/5*%i)),-3/5+4/5*%i)*sqrt(5)*_
+--   sqrt(1+(-1/5-2/5*%i)*(1+1/x)^2)*sqrt(1+(-1/5+2/5*%i)*(1+1/x)^2)/_
+--   (sqrt(1-2*%i)*sqrt((5-2*(1+1/x)^2+(1+1/x)^4)*x^4))
+--E 287
+
+--S 288 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 288
+
+)clear all
+
+--S 289 of 321
+t0:=1/(1+4*x+4*x^2+4*x^4)^(3/2)
+--R 
+--R
+--R                            1
+--R   (1)  -----------------------------------------
+--R                             +------------------+
+--R           4     2           |  4     2
+--R        (4x  + 4x  + 4x + 1)\|4x  + 4x  + 4x + 1
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 321
+--r0:=-(3-(1+1/x)^2)*x^2/sqrt((5-2*(1+1/x)^2+(1+1/x)^4)*x^4)+(1+1/x)*x^2/_
+--   sqrt((5-2*(1+1/x)^2+(1+1/x)^4)*x^4)+3/10*(1-3*(1+1/x)^2)*(1+1/x)*x^2/_
+--   sqrt((5-2*(1+1/x)^2+(1+1/x)^4)*x^4)-9/2*x^2*elliptic_e(asin((1+1/x)*_
+--   sqrt(1/5-2/5*%i)),-3/5+4/5*%i)*sqrt(1/5-2/5*%i)*sqrt(1+(-1/5-2/5*%i)*_
+--   (1+1/x)^2)*sqrt(1+(-1/5+2/5*%i)*(1+1/x)^2)/sqrt((5-2*(1+1/x)^2+_
+--   (1+1/x)^4)*x^4)+(3-3*%i)*x^2*elliptic_f(asin((1+1/x)*sqrt(1/5-2/5*%i)),_
+--   -3/5+4/5*%i)*sqrt(1/5-2/5*%i)*sqrt(1+(-1/5-2/5*%i)*(1+1/x)^2)*_
+--   sqrt(1+(-1/5+2/5*%i)*(1+1/x)^2)/sqrt((5-2*(1+1/x)^2+(1+1/x)^4)*x^4)
+--E 290
+
+--S 291 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 291
+
+)clear all
+
+--S 292 of 321
+t0:=(8+24*x+8*x^2-15*x^3+8*x^4)^4
+--R 
+--R
+--R   (1)
+--R          16         15          14          13         12          11
+--R     4096x   - 30720x   + 102784x   - 151008x   - 12095x   + 373536x
+--R   + 
+--R              10          9          8          7          6          5
+--R     - 331040x   - 339168x  + 641152x  + 291072x  - 566912x  - 184320x
+--R   + 
+--R            4          3          2
+--R     538624x  + 559104x  + 237568x  + 49152x + 4096
+--R                                                    Type: Polynomial(Integer)
+--E 292
+
+--S 293 of 321
+r0:=4096*x+24576*x^2+237568/3*x^3+139776*x^4+538624/5*x^5-30720*x^6-_
+   566912/7*x^7+36384*x^8+641152/9*x^9-169584/5*x^10-331040/11*x^11+_
+   31128*x^12-12095/13*x^13-75504/7*x^14+102784/15*x^15-1920*x^16+_
+   4096/17*x^17
+--R 
+--R
+--R   (2)
+--R     4096  17        16   102784  15   75504  14   12095  13         12
+--R     ---- x   - 1920x   + ------ x   - ----- x   - ----- x   + 31128x
+--R      17                    15           7           13
+--R   + 
+--R       331040  11   169584  10   641152  9         8   566912  7         6
+--R     - ------ x   - ------ x   + ------ x  + 36384x  - ------ x  - 30720x
+--R         11            5            9                     7
+--R   + 
+--R     538624  5          4   237568  3         2
+--R     ------ x  + 139776x  + ------ x  + 24576x  + 4096x
+--R        5                      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 293
+
+--S 294 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 321
+t0:=(8+24*x+8*x^2-15*x^3+8*x^4)^3
+--R 
+--R
+--R   (1)
+--R         12        11        10        9        8         7        6         5
+--R     512x   - 2880x   + 6936x   - 4527x  - 8808x  + 16776x  + 5528x  - 17856x
+--R   + 
+--R           4         3         2
+--R     - 384x  + 20160x  + 15360x  + 4608x + 512
+--R                                                    Type: Polynomial(Integer)
+--E 295
+
+--S 296 of 321
+r0:=512*x+2304*x^2+5120*x^3+5040*x^4-384/5*x^5-2976*x^6+5528/7*x^7+_
+   2097*x^8-2936/3*x^9-4527/10*x^10+6936/11*x^11-240*x^12+512/13*x^13
+--R 
+--R
+--R   (2)
+--R     512  13       12   6936  11   4527  10   2936  9        8   5528  7
+--R     --- x   - 240x   + ---- x   - ---- x   - ---- x  + 2097x  + ---- x
+--R      13                 11         10          3                  7
+--R   + 
+--R            6   384  5        4        3        2
+--R     - 2976x  - --- x  + 5040x  + 5120x  + 2304x  + 512x
+--R                 5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 296
+
+--S 297 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 321
+t0:=(8+24*x+8*x^2-15*x^3+8*x^4)^2
+--R 
+--R
+--R           8       7       6       5       4       3       2
+--R   (1)  64x  - 240x  + 353x  + 144x  - 528x  + 144x  + 704x  + 384x + 64
+--R                                                    Type: Polynomial(Integer)
+--E 298
+
+--S 299 of 321
+r0:=64*x+192*x^2+704/3*x^3+36*x^4-528/5*x^5+24*x^6+353/7*x^7-30*x^8+64/9*x^9
+--R 
+--R
+--R        64  9      8   353  7      6   528  5      4   704  3       2
+--R   (2)  -- x  - 30x  + --- x  + 24x  - --- x  + 36x  + --- x  + 192x  + 64x
+--R         9              7               5               3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 299
+
+--S 300 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 321
+t0:=8+24*x+8*x^2-15*x^3+8*x^4
+--R 
+--R
+--R          4      3     2
+--R   (1)  8x  - 15x  + 8x  + 24x + 8
+--R                                                    Type: Polynomial(Integer)
+--E 301
+
+--S 302 of 321
+r0:=8*x+12*x^2+8/3*x^3-15/4*x^4+8/5*x^5
+--R 
+--R
+--R        8  5   15  4   8  3      2
+--R   (2)  - x  - -- x  + - x  + 12x  + 8x
+--R        5       4      3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 302
+
+--S 303 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 321
+t0:=1/(8+24*x+8*x^2-15*x^3+8*x^4)
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R          4      3     2
+--R        8x  - 15x  + 8x  + 24x + 8
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 304
+
+--S 305 of 321
+r0:=-1/4*atan(1/2*(19-(3+4/x)^2)/sqrt(39))*sqrt(3/13)-1/8*log((3+4/x)^2+_
+   sqrt(517)-(3+4/x)*sqrt(2*(19+sqrt(517))))*sqrt(1/40326*(-5167+235*_
+   sqrt(517)))+1/8*log((3+4/x)^2+sqrt(517)+(3+4/x)*sqrt(2*(19+sqrt(517))))*_
+   sqrt(1/40326*(-5167+235*sqrt(517)))+1/4*atan((-2*(3+4/x)+sqrt(2*_
+   (19+sqrt(517))))/sqrt(2*(-19+sqrt(517))))*sqrt(1/40326*(5167+235*_
+   sqrt(517)))-1/4*atan((2*(3+4/x)+sqrt(2*(19+sqrt(517))))/sqrt(2*_
+   (-19+sqrt(517))))*sqrt(1/40326*(5167+235*sqrt(517)))
+--R 
+--R
+--R   (2)
+--R               +----------------+
+--R          +--+ |    +---+
+--R         \|13 \|235\|517  - 5167
+--R      *
+--R                        +------------+
+--R                2       |  +---+          2 +---+     2
+--R             (3x  + 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R         log(-----------------------------------------------------)
+--R                                        2
+--R                                       x
+--R     + 
+--R       -
+--R                  +----------------+
+--R             +--+ |    +---+
+--R            \|13 \|235\|517  - 5167
+--R         *
+--R                             +------------+
+--R                     2       |  +---+          2 +---+     2
+--R                (- 3x  - 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R            log(-------------------------------------------------------)
+--R                                            2
+--R                                           x
+--R     + 
+--R       -
+--R                   +----------------+
+--R              +--+ |    +---+
+--R            2\|13 \|235\|517  + 5167
+--R         *
+--R            atan
+--R                                   +------------+ +------------+
+--R                      +---+        |  +---+       |  +---+
+--R                   (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R                 + 
+--R                                                 +------------+
+--R                             +---+               |  +---+
+--R                   ((6x + 8)\|517  + 114x + 152)\|2\|517  - 38
+--R              /
+--R                 312x
+--R     + 
+--R                +----------------+
+--R           +--+ |    +---+
+--R         2\|13 \|235\|517  + 5167
+--R      *
+--R         atan
+--R                                +------------+ +------------+
+--R                   +---+        |  +---+       |  +---+
+--R                (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R              + 
+--R                                                +------------+
+--R                            +---+               |  +---+
+--R                ((- 6x - 8)\|517  - 114x - 152)\|2\|517  - 38
+--R           /
+--R              312x
+--R     + 
+--R                              2            +--+
+--R           +-+ +-----+     (5x  - 12x - 8)\|39
+--R       - 2\|3 \|40326 atan(--------------------)
+--R                                      2
+--R                                   39x
+--R  /
+--R       +--+ +-----+
+--R     8\|13 \|40326
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                 2               +---+        2                 +-----+
+--R         ((- 305x  - 228x - 152)\|517  - 6887x  - 5268x - 3512)\|40326
+--R      *
+--R          +------------+ +----------------+
+--R          |  +---+       |    +---+
+--R         \|2\|517  - 38 \|235\|517  + 5167
+--R     + 
+--R               2               +---+        2                 +-----+
+--R         ((134x  - 228x - 152)\|517  + 2936x  - 5268x - 3512)\|40326
+--R      *
+--R          +------------+ +----------------+
+--R          |  +---+       |    +---+
+--R         \|2\|517  + 38 \|235\|517  - 5167
+--R     + 
+--R                2            +-+ +--+ +--+             +---+
+--R       ((353628x  + 471504x)\|3 \|13 \|39  + 12259104)\|517
+--R     + 
+--R                2              +-+ +--+ +--+
+--R       (8170668x  + 10894224x)\|3 \|13 \|39  + 283249824
+--R  /
+--R                 4             3            2                          +---+
+--R       (98072832x  - 183886560x  + 98072832x  + 294218496x + 98072832)\|517
+--R     + 
+--R                  4              3              2
+--R       2265998592x  - 4248747360x  + 2265998592x  + 6797995776x + 2265998592
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 321
+t0:=1/(8+24*x+8*x^2-15*x^3+8*x^4)^2
+--R 
+--R
+--R                                        1
+--R   (1)  ----------------------------------------------------------------
+--R           8       7       6       5       4       3       2
+--R        64x  - 240x  + 353x  + 144x  - 528x  + 144x  + 704x  + 384x + 64
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 307
+
+--S 308 of 321
+r0:=-3/208*(3359-146*(3+4/x)^2)/(517-38*(3+4/x)^2+(3+4/x)^4)+97/48*(3+4/x)/_
+   (517-38*(3+4/x)^2+(3+4/x)^4)+1/161304*(1337997-74897*(3+4/x)^2)*(3+4/x)/_
+   (517-38*(3+4/x)^2+(3+4/x)^4)-9/16*(3+4/x)^2/(517-38*(3+4/x)^2+(3+4/x)^4)+_
+   1/16*(3+4/x)^3/(517-38*(3+4/x)^2+(3+4/x)^4)-73/208*atan(1/2*(19-_
+   (3+4/x)^2)/sqrt(39))*sqrt(3/13)-1/645216*log((3+4/x)^2+sqrt(517)-_
+   (3+4/x)*sqrt(2*(19+sqrt(517))))*sqrt(1/40326*(-59644114671451+_
+   2623170438295*sqrt(517)))+1/645216*log((3+4/x)^2+sqrt(517)+(3+4/x)*_
+   sqrt(2*(19+sqrt(517))))*sqrt(1/40326*(-59644114671451+2623170438295*_
+   sqrt(517)))+1/322608*atan((-2*(3+4/x)+sqrt(2*(19+sqrt(517))))/_
+   sqrt(2*(-19+sqrt(517))))*sqrt(1/40326*(59644114671451+2623170438295*_
+   sqrt(517)))-1/322608*atan((2*(3+4/x)+sqrt(2*(19+sqrt(517))))/_
+   sqrt(2*(-19+sqrt(517))))*sqrt(1/40326*(59644114671451+2623170438295*_
+   sqrt(517)))
+--R 
+--R
+--R   (2)
+--R            4      3     2            +--+
+--R         (8x  - 15x  + 8x  + 24x + 8)\|13
+--R      *
+--R          +------------------------------------+
+--R          |              +---+
+--R         \|2623170438295\|517  - 59644114671451
+--R      *
+--R                        +------------+
+--R                2       |  +---+          2 +---+     2
+--R             (3x  + 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R         log(-----------------------------------------------------)
+--R                                        2
+--R                                       x
+--R     + 
+--R              4      3     2            +--+
+--R         (- 8x  + 15x  - 8x  - 24x - 8)\|13
+--R      *
+--R          +------------------------------------+
+--R          |              +---+
+--R         \|2623170438295\|517  - 59644114671451
+--R      *
+--R                          +------------+
+--R                  2       |  +---+          2 +---+     2
+--R             (- 3x  - 4x)\|2\|517  + 38  + x \|517  + 9x  + 24x + 16
+--R         log(-------------------------------------------------------)
+--R                                         2
+--R                                        x
+--R     + 
+--R               4      3      2             +--+
+--R         (- 16x  + 30x  - 16x  - 48x - 16)\|13
+--R      *
+--R          +------------------------------------+
+--R          |              +---+
+--R         \|2623170438295\|517  + 59644114671451
+--R      *
+--R         atan
+--R                                +------------+ +------------+
+--R                   +---+        |  +---+       |  +---+
+--R                (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R              + 
+--R                                              +------------+
+--R                          +---+               |  +---+
+--R                ((6x + 8)\|517  + 114x + 152)\|2\|517  - 38
+--R           /
+--R              312x
+--R     + 
+--R             4      3      2             +--+
+--R         (16x  - 30x  + 16x  + 48x + 16)\|13
+--R      *
+--R          +------------------------------------+
+--R          |              +---+
+--R         \|2623170438295\|517  + 59644114671451
+--R      *
+--R         atan
+--R                                +------------+ +------------+
+--R                   +---+        |  +---+       |  +---+
+--R                (x\|517  + 19x)\|2\|517  - 38 \|2\|517  + 38
+--R              + 
+--R                                                +------------+
+--R                            +---+               |  +---+
+--R                ((- 6x - 8)\|517  - 114x - 152)\|2\|517  - 38
+--R           /
+--R              312x
+--R     + 
+--R                    4           3           2                       +-+ +-----+
+--R         (- 1811568x  + 3396690x  - 1811568x  - 5434704x - 1811568)\|3 \|40326
+--R      *
+--R                 2            +--+
+--R              (5x  - 12x - 8)\|39
+--R         atan(--------------------)
+--R                         2
+--R                      39x
+--R     + 
+--R                 4          3          2            +--+ +-----+
+--R       (- 291552x  + 703780x  - 668808x  - 518524x)\|13 \|40326
+--R  /
+--R              4           3           2                        +--+ +-----+
+--R     (5161728x  - 9678240x  + 5161728x  + 15485184x + 5161728)\|13 \|40326
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 321
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                 2               +---+        2                 +-----+
+--R         ((- 305x  - 228x - 152)\|517  - 6887x  - 5268x - 3512)\|40326
+--R      *
+--R          +------------+ +------------------------------------+
+--R          |  +---+       |              +---+
+--R         \|2\|517  - 38 \|2623170438295\|517  + 59644114671451
+--R     + 
+--R               2               +---+        2                 +-----+
+--R         ((134x  - 228x - 152)\|517  + 2936x  - 5268x - 3512)\|40326
+--R      *
+--R          +------------+ +------------------------------------+
+--R          |  +---+       |              +---+
+--R         \|2\|517  + 38 \|2623170438295\|517  - 59644114671451
+--R     + 
+--R                        2                 +-+ +--+ +--+                2
+--R           (40038823044x  + 53385097392x)\|3 \|13 \|39  + 240768802560x
+--R         + 
+--R           - 704763629856x + 918170112288
+--R      *
+--R          +---+
+--R         \|517
+--R     + 
+--R                     2                   +-+ +--+ +--+                 2
+--R       (925107542964x  + 1233476723952x)\|3 \|13 \|39  + 5563026543360x
+--R     + 
+--R       - 16283749131936x + 21214562068128
+--R  /
+--R                         4                  3                 2
+--R           7909770046464x  - 14830818837120x  + 7909770046464x
+--R         + 
+--R           23729310139392x + 7909770046464
+--R      *
+--R          +---+
+--R         \|517
+--R     + 
+--R                       4                   3                   2
+--R       182757318441984x  - 342669972078720x  + 182757318441984x
+--R     + 
+--R       548271955325952x + 182757318441984
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 321
+t0:=1/(8+24*x+8*x^2-15*x^3+8*x^4)^(1/2)
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R         +--------------------------+
+--R         |  4      3     2
+--R        \|8x  - 15x  + 8x  + 24x + 8
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 321
+--r0:=-x^2*elliptic_f(asin((3+4/x)/sqrt(19-2*%i*sqrt(39))),_
+--   (19*%i+2*sqrt(39))/(19*%i-2*sqrt(39)))*sqrt(1-(3+4/x)^2/(19-2*%i*_
+--   sqrt(39)))*sqrt(1-(3+4/x)^2/(19+2*%i*sqrt(39)))*sqrt(2*(19-2*%i*_
+--   sqrt(39)))/sqrt((517-38*(3+4/x)^2+(3+4/x)^4)*x^4)
+--E 311
+
+--S 312 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 312
+
+)clear all
+
+--S 313 of 321
+t0:=1/(8+24*x+8*x^2-15*x^3+8*x^4)^(3/2)
+--R 
+--R
+--R                                    1
+--R   (1)  ---------------------------------------------------------
+--R                                     +--------------------------+
+--R           4      3     2            |  4      3     2
+--R        (8x  - 15x  + 8x  + 24x + 8)\|8x  - 15x  + 8x  + 24x + 8
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 321
+--r0:=-1/26*(172-7*(3+4/x)^2)*x^2/(sqrt(2)*sqrt((517-38*(3+4/x)^2+_
+--   (3+4/x)^4)*x^4))+1/4*(3+4/x)*x^2/(sqrt(2)*sqrt((517-38*(3+4/x)^2+_
+--   (3+4/x)^4)*x^4))+1/80652*(81629-4910*(3+4/x)^2)*(3+4/x)*x^2/(sqrt(2)*_
+--   sqrt((517-38*(3+4/x)^2+(3+4/x)^4)*x^4))+1/2068*x^2*_
+--   elliptic_f(asin((3+4/x)/sqrt(19-2*%i*sqrt(39))),(19*%i+2*sqrt(39))/_
+--   (19*%i-2*sqrt(39)))*(9820*%i-299*sqrt(39))*sqrt(1-(3+4/x)^2/(19-2*%i*_
+--   sqrt(39)))*sqrt(1-(3+4/x)^2/(19+2*%i*sqrt(39)))*sqrt(1/78*(19-2*%i*_
+--   sqrt(39)))/sqrt((517-38*(3+4/x)^2+(3+4/x)^4)*x^4)-2455/40326*x^2*_
+--   elliptic_e(asin((3+4/x)/sqrt(19-2*%i*sqrt(39))),(19*%i+2*sqrt(39))/_
+--   (19*%i-2*sqrt(39)))*(19+2*%i*sqrt(39))*sqrt(1-(3+4/x)^2/(19-2*%i*_
+--   sqrt(39)))*sqrt(1-(3+4/x)^2/(19+2*%i*sqrt(39)))*sqrt(1/2*(19-2*%i*_
+--   sqrt(39)))/sqrt((517-38*(3+4/x)^2+(3+4/x)^4)*x^4)
+--E 314
+
+--S 315 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 315
+
+)clear all
+
+--S 316 of 321
+t0:=1/(9-6*x-44*x^2+15*x^3+3*x^4)^(1/2)
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R         +--------------------------+
+--R         |  4      3      2
+--R        \|3x  + 15x  - 44x  - 6x + 9
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 321
+--r0:=2*x^2*elliptic_f(asin((1+(-6)/x)/sqrt(91-6*sqrt(213))),_
+--   1/613*(15949-1092*sqrt(213)))*sqrt(1-(1+(-6)/x)^2/(91-6*sqrt(213)))*_
+--   sqrt(91-6*sqrt(213))*sqrt(1-(1+(-6)/x)^2/(91+6*sqrt(213)))/_
+--   sqrt((613-182*(1+(-6)/x)^2+(-1+6/x)^4)*x^4)
+--E 317
+
+--S 318 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 318
+
+)clear all
+
+--S 319 of 321
+t0:=1/(9-6*x-44*x^2+15*x^3+3*x^4)^(3/2)
+--R 
+--R
+--R                                    1
+--R   (1)  ---------------------------------------------------------
+--R                                     +--------------------------+
+--R           4      3      2           |  4      3      2
+--R        (3x  + 15x  - 44x  - 6x + 9)\|3x  + 15x  - 44x  - 6x + 9
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 321
+--r0:=-4/17253*(176-23*(1+(-6)/x)^2)*x^2/sqrt((613-182*(1+(-6)/x)^2+_
+--   (-1+6/x)^4)*x^4)-2/9*(1+(-6)/x)*x^2/sqrt((613-182*(1+(-6)/x)^2+_
+--   (-1+6/x)^4)*x^4)+2/10576089*(1265923-7444*(1+(-6)/x)^2)*(1+(-6)/x)*_
+--   x^2/sqrt((613-182*(1+(-6)/x)^2+(-1+6/x)^4)*x^4)-14888/17253*x^2*_
+--   elliptic_e(asin((1+(-6)/x)/sqrt(91-6*sqrt(213))),1/613*(15949-1092*_
+--   sqrt(213)))*sqrt(1-(1+(-6)/x)^2/(91-6*sqrt(213)))*sqrt(1/613*(91+6*_
+--   sqrt(213)))*sqrt(1-(1+(-6)/x)^2/(91+6*sqrt(213)))/sqrt((613-182*(1+_
+--   (-6)/x)^2+(-1+6/x)^4)*x^4)+2/27*x^2*elliptic_f(asin((1+(-6)/x)/_
+--   sqrt(91-6*sqrt(213))),1/613*(15949-1092*sqrt(213)))*_
+--   sqrt(1-(1+(-6)/x)^2/(91-6*sqrt(213)))*sqrt(1/130569*(2551963+_
+--   133098*sqrt(213)))*sqrt(1-(1+(-6)/x)^2/(91+6*sqrt(213)))/sqrt((613-_
+--   182*(1+(-6)/x)^2+(-1+6/x)^4)*x^4)
+--E 320
+
+--S 321 of 321
+--d0:=normalize(t0-D(r0,x))
+--E 321
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder21.input.pamphlet b/src/input/richder21.input.pamphlet
new file mode 100644
index 0000000..3b822d6
--- /dev/null
+++ b/src/input/richder21.input.pamphlet
@@ -0,0 +1,1977 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder21.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Piecewise constant extraction problems.input
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder21.output
+)spool richder21.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 149
+t0:=x^m*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R           +-------+
+--R         m |b x - a
+--R        x  |-------
+--R          \|   x
+--R   (1)  ------------
+--R         +---------+
+--R        \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 149
+r0:=2*x^(1+m)*sqrt(b-a/x)/((1+2*m)*sqrt(a-b*x))
+--R 
+--R
+--R                  +-------+
+--R            m + 1 |b x - a
+--R          2x      |-------
+--R                 \|   x
+--R   (2)  --------------------
+--R                 +---------+
+--R        (2m + 1)\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 149
+t0:=x^2*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R           +-------+
+--R         2 |b x - a
+--R        x  |-------
+--R          \|   x
+--R   (1)  ------------
+--R         +---------+
+--R        \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 149
+r0:=2/5*x^3*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R            +-------+
+--R          3 |b x - a
+--R        2x  |-------
+--R           \|   x
+--R   (2)  -------------
+--R          +---------+
+--R        5\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 149
+t0:=x*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R           +-------+
+--R           |b x - a
+--R         x |-------
+--R          \|   x
+--R   (1)  ------------
+--R         +---------+
+--R        \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 149
+r0:=2/3*x^2*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R            +-------+
+--R          2 |b x - a
+--R        2x  |-------
+--R           \|   x
+--R   (2)  -------------
+--R          +---------+
+--R        3\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 149
+t0:=sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R          +-------+
+--R          |b x - a
+--R          |-------
+--R         \|   x
+--R   (1)  ------------
+--R         +---------+
+--R        \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 149
+r0:=2*x*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R           +-------+
+--R           |b x - a
+--R        2x |-------
+--R          \|   x
+--R   (2)  ------------
+--R         +---------+
+--R        \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 149
+t0:=sqrt(b-a/x)/(x*sqrt(a-b*x))
+--R 
+--R
+--R           +-------+
+--R           |b x - a
+--R           |-------
+--R          \|   x
+--R   (1)  -------------
+--R          +---------+
+--R        x\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 149
+r0:=-2*sqrt(b-a/x)/sqrt(a-b*x)
+--R 
+--R
+--R              +-------+
+--R              |b x - a
+--R           2  |-------
+--R             \|   x
+--R   (2)  - ------------
+--R           +---------+
+--R          \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 149
+t0:=sqrt(b-a/x)/(x^2*sqrt(a-b*x))
+--R 
+--R
+--R           +-------+
+--R           |b x - a
+--R           |-------
+--R          \|   x
+--R   (1)  --------------
+--R         2 +---------+
+--R        x \|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 149
+r0:=-2/3*sqrt(b-a/x)/(x*sqrt(a-b*x))
+--R 
+--R
+--R               +-------+
+--R               |b x - a
+--R            2  |-------
+--R              \|   x
+--R   (2)  - --------------
+--R             +---------+
+--R          3x\|- b x + a
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 149
+t0:=(a+b/x)^m*(c+d*x)^n
+--R 
+--R
+--R         a x + b m         n
+--R   (1)  (-------) (d x + c)
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 149
+--r0:=(a+b/x)^m*x*(c+d*x)^n*AppellF1(1-m,-m,-n,2-m,-a*x/b,-d*x/c)/((1-m)*((b+a*x)/b)^m*((c+d*x)/c)^n)
+--E 20
+
+--S 21 of 149
+--d0:=normalize(t0-D(r0,x))
+--E 21
+
+)clear all
+
+--S 22 of 149
+t0:=(a+b/x)^m*(c+d*x)^2
+--R 
+--R
+--R          2 2             2  a x + b m
+--R   (1)  (d x  + 2c d x + c )(-------)
+--R                                x
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 149
+--r0:=1/6*(6*a^2*c^2-6*a*b*c*d*(1-m)+b^2*d^2*(2-3*m+m^2))*(a+b/x)^(1+m)*x/a^3+1/6*d*(6*a*c-b*d*(2-m))*(a+b/x)^(1+m)*x^2/a^2+1/3*d^2*(a+b/x)^(1+m)*x^3/a+1/6*b*m*(6*a^2*c^2-6*a*b*c*d*(1-m)+b^2*d^2*(2-3*m+m^2))*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,(a+b/x)/a)/(a^4*(1+m))
+--E 23
+
+--S 24 of 149
+--d0:=normalize(t0-D(r0,x))
+--E 24
+
+)clear all
+
+--S 25 of 149
+t0:=(a+b/x)^m*(c+d*x)
+--R 
+--R
+--R                  a x + b m
+--R   (1)  (d x + c)(-------)
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 149
+--r0:=1/2*(2*a*c-b*d*(1-m))*(a+b/x)^(1+m)*x/a^2+1/2*d*(a+b/x)^(1+m)*x^2/a+1/2*b*(2*a*c-b*d*(1-m))*m*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,(a+b/x)/a)/(a^3*(1+m))
+--E 26
+
+--S 27 of 149
+--d0:=normalize(t0-D(r0,x))
+--E 27
+
+)clear all
+
+--S 28 of 149
+t0:=(a+b/x)^m
+--R 
+--R
+--R         a x + b m
+--R   (1)  (-------)
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 149
+--r0:=(a+b/x)^(1+m)*x/a+b*m*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,(a+b/x)/a)/(a^2*(1+m))
+--E 29
+
+--S 30 of 149
+--d0:=normalize(t0-D(r0,x))
+--E 30
+
+)clear all
+
+--S 31 of 149
+t0:=(a+b/x)^m/(c+d*x)
+--R 
+--R
+--R         a x + b m
+--R        (-------)
+--R            x
+--R   (1)  ----------
+--R          d x + c
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 149
+--r0:=(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,(a+b/x)/a)/(a*d*(1+m))-c*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,c*(a+b/x)/(a*c-b*d))/(d*(a*c-b*d)*(1+m))
+--E 32
+
+--S 33 of 149
+--d0:=normalize(t0-D(r0,x))
+--E 33
+
+)clear all
+
+--S 34 of 149
+t0:=(a+b/x)^m/(c+d*x)^2
+--R 
+--R
+--R             a x + b m
+--R            (-------)
+--R                x
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 149
+--r0:=(a+b/x)^(1+m)/((a*c-b*d)*(d+c/x))+b*m*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,c*(a+b/x)/(a*c-b*d))/((a*c-b*d)^2*(1+m))
+--E 35
+
+--S 36 of 149
+--d0:=normalize(t0-D(r0,x))
+--E 36
+
+)clear all
+
+--S 37 of 149
+t0:=(a+b/x)^m/(c+d*x)^3
+--R 
+--R
+--R                  a x + b m
+--R                 (-------)
+--R                     x
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 149
+--r0:=-1/2*d*(a+b/x)^(1+m)/(c*(a*c-b*d)*(d+c/x)^2)+1/2*(2*a*c-b*d*(1+m))*(a+b/x)^(1+m)/(c*(a*c-b*d)^2*(d+c/x))+1/2*b*m*(2*a*c-b*d*(1+m))*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,c*(a+b/x)/(a*c-b*d))/(c*(a*c-b*d)^3*(1+m))
+--E 38
+
+--S 39 of 149
+--d0:=normalize(t0-D(r0,x))
+--E 39
+
+)clear all
+
+--S 40 of 149
+t0:=(a+b/x)^m/(c+d*x)^4
+--R 
+--R
+--R                       a x + b m
+--R                      (-------)
+--R                          x
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        d x  + 4c d x  + 6c d x  + 4c d x + c
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 149
+--r0:=1/3*d^2*(a+b/x)^(1+m)/(c^2*(a*c-b*d)*(d+c/x)^3)-1/6*d*(6*a*c-b*d*(4+m))*(a+b/x)^(1+m)/(c^2*(a*c-b*d)^2*(d+c/x)^2)+1/6*(6*a^2*c^2-6*a*b*c*d*(1+m)+b^2*d^2*(2+3*m+m^2))*(a+b/x)^(1+m)/(c^2*(a*c-b*d)^3*(d+c/x))+1/6*b*m*(6*a^2*c^2-6*a*b*c*d*(1+m)+b^2*d^2*(2+3*m+m^2))*(a+b/x)^(1+m)*hypergeometric(1,1+m,2+m,c*(a+b/x)/(a*c-b*d))/(c^2*(a*c-b*d)^4*(1+m))
+--E 41
+
+--S 42 of 149
+--d0:=normalize(t0-D(r0,x))
+--E 42
+
+)clear all
+
+--S 43 of 149
+t0:=x^m*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R         m |b x  - a
+--R        x  |--------
+--R           |    2
+--R          \|   x
+--R   (1)  -------------
+--R         +----------+
+--R         |     2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 149
+r0:=x^(1+m)*sqrt(b-a/x^2)/(m*sqrt(a-b*x^2))
+--R 
+--R
+--R               +--------+
+--R               |   2
+--R         m + 1 |b x  - a
+--R        x      |--------
+--R               |    2
+--R              \|   x
+--R   (2)  -----------------
+--R            +----------+
+--R            |     2
+--R          m\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 149
+t0:=x^2*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R         2 |b x  - a
+--R        x  |--------
+--R           |    2
+--R          \|   x
+--R   (1)  -------------
+--R         +----------+
+--R         |     2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 149
+r0:=1/2*x^3*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R          3 |b x  - a
+--R         x  |--------
+--R            |    2
+--R           \|   x
+--R   (2)  --------------
+--R          +----------+
+--R          |     2
+--R        2\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 149
+t0:=x*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R           |b x  - a
+--R         x |--------
+--R           |    2
+--R          \|   x
+--R   (1)  -------------
+--R         +----------+
+--R         |     2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 149
+r0:=x^2*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R         2 |b x  - a
+--R        x  |--------
+--R           |    2
+--R          \|   x
+--R   (2)  -------------
+--R         +----------+
+--R         |     2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 149
+t0:=sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R          +--------+
+--R          |   2
+--R          |b x  - a
+--R          |--------
+--R          |    2
+--R         \|   x
+--R   (1)  -------------
+--R         +----------+
+--R         |     2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 149
+r0:=x*log(x)*sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R                 +--------+
+--R                 |   2
+--R                 |b x  - a
+--R        x log(x) |--------
+--R                 |    2
+--R                \|   x
+--R   (2)  -------------------
+--R            +----------+
+--R            |     2
+--R           \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 149
+t0:=sqrt(b-a/x^2)/(x*sqrt(a-b*x^2))
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R           |b x  - a
+--R           |--------
+--R           |    2
+--R          \|   x
+--R   (1)  --------------
+--R          +----------+
+--R          |     2
+--R        x\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 149
+r0:=-sqrt(b-a/x^2)/sqrt(a-b*x^2)
+--R 
+--R
+--R            +--------+
+--R            |   2
+--R            |b x  - a
+--R            |--------
+--R            |    2
+--R           \|   x
+--R   (2)  - -------------
+--R           +----------+
+--R           |     2
+--R          \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 149
+t0:=sqrt(b-a/x^2)/(x^2*sqrt(a-b*x^2))
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R           |b x  - a
+--R           |--------
+--R           |    2
+--R          \|   x
+--R   (1)  ---------------
+--R           +----------+
+--R         2 |     2
+--R        x \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 149
+r0:=-1/2*sqrt(b-a/x^2)/(x*sqrt(a-b*x^2))
+--R 
+--R
+--R             +--------+
+--R             |   2
+--R             |b x  - a
+--R             |--------
+--R             |    2
+--R            \|   x
+--R   (2)  - ---------------
+--R             +----------+
+--R             |     2
+--R          2x\|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 149
+t0:=(a+b*x^2)^(5/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R                              +--------+
+--R          2 4         2    2  |   2
+--R        (b x  + 2a b x  + a )\|b x  + a
+--R   (1)  --------------------------------
+--R                  +-----------+
+--R                  |   2 4    2
+--R                 \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 149
+r0:=-1/4*x*(a-b*x^2)*(a+b*x^2)^(3/2)/sqrt(a^2-b^2*x^4)-9/8*a*x*(a-b*x^2)*_
+   sqrt(a+b*x^2)/sqrt(a^2-b^2*x^4)+19/8*a^2*atan(x*sqrt(b)/sqrt(a-b*x^2))*_
+   sqrt(a-b*x^2)*sqrt(a+b*x^2)/(sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            +----------+ +--------+           +-+
+--R          2 |     2      |   2              x\|b
+--R       19a \|- b x  + a \|b x  + a atan(-------------)
+--R                                         +----------+
+--R                                         |     2
+--R                                        \|- b x  + a
+--R     + 
+--R                                     +--------+
+--R          2 5         3      2   +-+ |   2
+--R       (2b x  + 9a b x  - 11a x)\|b \|b x  + a
+--R  /
+--R       +-----------+
+--R       |   2 4    2  +-+
+--R     8\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 149
+t0:=(a+b*x^2)^(3/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R                   +--------+
+--R            2      |   2
+--R        (b x  + a)\|b x  + a
+--R   (1)  ---------------------
+--R             +-----------+
+--R             |   2 4    2
+--R            \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 149
+r0:=-1/2*x*(a-b*x^2)*sqrt(a+b*x^2)/sqrt(a^2-b^2*x^4)+3/2*a*atan(x*_
+   sqrt(b)/sqrt(a-b*x^2))*sqrt(a-b*x^2)*sqrt(a+b*x^2)/(sqrt(b)*_
+   sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R      +----------+ +--------+           +-+                         +--------+
+--R      |     2      |   2              x\|b             3        +-+ |   2
+--R   3a\|- b x  + a \|b x  + a atan(-------------) + (b x  - a x)\|b \|b x  + a
+--R                                   +----------+
+--R                                   |     2
+--R                                  \|- b x  + a
+--R   ---------------------------------------------------------------------------
+--R                                 +-----------+
+--R                                 |   2 4    2  +-+
+--R                               2\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 149
+t0:=(a+b*x^2)^(1/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R           +--------+
+--R           |   2
+--R          \|b x  + a
+--R   (1)  --------------
+--R         +-----------+
+--R         |   2 4    2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 149
+r0:=atan(x*sqrt(b)/sqrt(a-b*x^2))*sqrt(a-b*x^2)*sqrt(a+b*x^2)/_
+   (sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R         +----------+ +--------+           +-+
+--R         |     2      |   2              x\|b
+--R        \|- b x  + a \|b x  + a atan(-------------)
+--R                                      +----------+
+--R                                      |     2
+--R                                     \|- b x  + a
+--R   (2)  -------------------------------------------
+--R                      +-----------+
+--R                      |   2 4    2  +-+
+--R                     \|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 149
+t0:=1/((a+b*x^2)^(1/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R         +-----------+ +--------+
+--R         |   2 4    2  |   2
+--R        \|- b x  + a  \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 149
+r0:=atan(x*sqrt(2)*sqrt(b)/sqrt(a-b*x^2))*sqrt(a-b*x^2)*sqrt(a+b*x^2)/_
+   (a*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R         +----------+ +--------+         +-+ +-+
+--R         |     2      |   2            x\|2 \|b
+--R        \|- b x  + a \|b x  + a atan(-------------)
+--R                                      +----------+
+--R                                      |     2
+--R                                     \|- b x  + a
+--R   (2)  -------------------------------------------
+--R                        +-----------+
+--R                    +-+ |   2 4    2  +-+
+--R                  a\|2 \|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 149
+t0:=1/((a+b*x^2)^(3/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                         1
+--R   (1)  -----------------------------------
+--R                   +-----------+ +--------+
+--R            2      |   2 4    2  |   2
+--R        (b x  + a)\|- b x  + a  \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 149
+r0:=1/4*x*(a-b*x^2)/(a^2*sqrt(a+b*x^2)*sqrt(a^2-b^2*x^4))+_
+   3/4*atan(x*sqrt(2)*sqrt(b)/sqrt(a-b*x^2))*sqrt(a-b*x^2)*_
+   sqrt(a+b*x^2)/(a^2*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                     +----------+         +-+ +-+
+--R             2       |     2            x\|2 \|b             3        +-+ +-+
+--R        (3b x  + 3a)\|- b x  + a atan(-------------) + (- b x  + a x)\|2 \|b
+--R                                       +----------+
+--R                                       |     2
+--R                                      \|- b x  + a
+--R   (2)  ---------------------------------------------------------------------
+--R                                 +-----------+     +--------+
+--R                           2 +-+ |   2 4    2  +-+ |   2
+--R                         4a \|2 \|- b x  + a  \|b \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 149
+t0:=1/((a+b*x^2)^(5/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                               1
+--R   (1)  ----------------------------------------------
+--R                              +-----------+ +--------+
+--R          2 4         2    2  |   2 4    2  |   2
+--R        (b x  + 2a b x  + a )\|- b x  + a  \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 149
+r0:=1/8*x*(a-b*x^2)/(a^2*(a+b*x^2)^(3/2)*sqrt(a^2-b^2*x^4))+_
+    9/32*x*(a-b*x^2)/(a^3*sqrt(a+b*x^2)*sqrt(a^2-b^2*x^4))+_
+    19/32*atan(x*sqrt(2)*sqrt(b)/sqrt(a-b*x^2))*sqrt(a-b*x^2)*_
+    sqrt(a+b*x^2)/(a^3*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                  +----------+         +-+ +-+
+--R           2 4          2      2  |     2            x\|2 \|b
+--R       (19b x  + 38a b x  + 19a )\|- b x  + a atan(-------------)
+--R                                                    +----------+
+--R                                                    |     2
+--R                                                   \|- b x  + a
+--R     + 
+--R            2 5         3      2   +-+ +-+
+--R       (- 9b x  - 4a b x  + 13a x)\|2 \|b
+--R  /
+--R                           +-----------+     +--------+
+--R         3   2      4  +-+ |   2 4    2  +-+ |   2
+--R     (32a b x  + 32a )\|2 \|- b x  + a  \|b \|b x  + a
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 149
+t0:=(a-b*x^2)^(5/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R                              +----------+
+--R          2 4         2    2  |     2
+--R        (b x  - 2a b x  + a )\|- b x  + a
+--R   (1)  ----------------------------------
+--R                   +-----------+
+--R                   |   2 4    2
+--R                  \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 149
+r0:=-1/4*x*(a-b*x^2)^(3/2)*(a+b*x^2)/sqrt(a^2-b^2*x^4)-9/8*a*x*(a+b*x^2)*_
+   sqrt(a-b*x^2)/sqrt(a^2-b^2*x^4)+19/8*a^2*atanh(x*sqrt(b)/sqrt(a+b*x^2))*_
+   sqrt(a-b*x^2)*sqrt(a+b*x^2)/(sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R            +----------+ +--------+           +-+
+--R          2 |     2      |   2              x\|b
+--R       19a \|- b x  + a \|b x  + a atanh(-----------)
+--R                                          +--------+
+--R                                          |   2
+--R                                         \|b x  + a
+--R     + 
+--R                                 +----------+
+--R          2 5         3      2   |     2      +-+
+--R       (2b x  - 9a b x  - 11a x)\|- b x  + a \|b
+--R  /
+--R       +-----------+
+--R       |   2 4    2  +-+
+--R     8\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 149
+t0:=(a-b*x^2)^(3/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R                     +----------+
+--R              2      |     2
+--R        (- b x  + a)\|- b x  + a
+--R   (1)  -------------------------
+--R               +-----------+
+--R               |   2 4    2
+--R              \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 149
+r0:=-1/2*x*(a+b*x^2)*sqrt(a-b*x^2)/sqrt(a^2-b^2*x^4)+_
+     3/2*a*atanh(x*sqrt(b)/sqrt(a+b*x^2))*sqrt(a-b*x^2)*_
+     sqrt(a+b*x^2)/(sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R          +----------+ +--------+           +-+
+--R          |     2      |   2              x\|b
+--R       3a\|- b x  + a \|b x  + a atanh(-----------)
+--R                                        +--------+
+--R                                        |   2
+--R                                       \|b x  + a
+--R     + 
+--R                      +----------+
+--R             3        |     2      +-+
+--R       (- b x  - a x)\|- b x  + a \|b
+--R  /
+--R       +-----------+
+--R       |   2 4    2  +-+
+--R     2\|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 149
+t0:=(a-b*x^2)^(1/2)/sqrt(a^2-b^2*x^4)
+--R 
+--R
+--R          +----------+
+--R          |     2
+--R         \|- b x  + a
+--R   (1)  --------------
+--R         +-----------+
+--R         |   2 4    2
+--R        \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 149
+r0:=atanh(x*sqrt(b)/sqrt(a+b*x^2))*sqrt(a-b*x^2)*sqrt(a+b*x^2)/(sqrt(b)*_
+    sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R         +----------+ +--------+           +-+
+--R         |     2      |   2              x\|b
+--R        \|- b x  + a \|b x  + a atanh(-----------)
+--R                                       +--------+
+--R                                       |   2
+--R                                      \|b x  + a
+--R   (2)  ------------------------------------------
+--R                     +-----------+
+--R                     |   2 4    2  +-+
+--R                    \|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 149
+t0:=1/((a-b*x^2)^(1/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R         +-----------+ +----------+
+--R         |   2 4    2  |     2
+--R        \|- b x  + a  \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 149
+r0:=atanh(x*sqrt(2)*sqrt(b)/sqrt(a+b*x^2))*sqrt(a-b*x^2)*_
+    sqrt(a+b*x^2)/(a*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R         +----------+ +--------+         +-+ +-+
+--R         |     2      |   2            x\|2 \|b
+--R        \|- b x  + a \|b x  + a atanh(-----------)
+--R                                       +--------+
+--R                                       |   2
+--R                                      \|b x  + a
+--R   (2)  ------------------------------------------
+--R                        +-----------+
+--R                    +-+ |   2 4    2  +-+
+--R                  a\|2 \|- b x  + a  \|b
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 149
+t0:=1/((a-b*x^2)^(3/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                            1
+--R   (1)  - -------------------------------------
+--R                     +-----------+ +----------+
+--R              2      |   2 4    2  |     2
+--R          (b x  - a)\|- b x  + a  \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 149
+r0:=1/4*x*(a+b*x^2)/(a^2*sqrt(a-b*x^2)*sqrt(a^2-b^2*x^4))+_
+    3/4*atanh(x*sqrt(2)*sqrt(b)/sqrt(a+b*x^2))*sqrt(a-b*x^2)*_
+    sqrt(a+b*x^2)/(a^2*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                       +--------+         +-+ +-+
+--R               2       |   2            x\|2 \|b          3        +-+ +-+
+--R        (- 3b x  + 3a)\|b x  + a atanh(-----------) + (b x  + a x)\|2 \|b
+--R                                        +--------+
+--R                                        |   2
+--R                                       \|b x  + a
+--R   (2)  ------------------------------------------------------------------
+--R                              +-----------+ +----------+
+--R                        2 +-+ |   2 4    2  |     2      +-+
+--R                      4a \|2 \|- b x  + a  \|- b x  + a \|b
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 149
+t0:=1/((a-b*x^2)^(5/2)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R                                1
+--R   (1)  ------------------------------------------------
+--R                              +-----------+ +----------+
+--R          2 4         2    2  |   2 4    2  |     2
+--R        (b x  - 2a b x  + a )\|- b x  + a  \|- b x  + a
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 149
+r0:=1/8*x*(a+b*x^2)/(a^2*(a-b*x^2)^(3/2)*sqrt(a^2-b^2*x^4))+_
+    9/32*x*(a+b*x^2)/(a^3*sqrt(a-b*x^2)*sqrt(a^2-b^2*x^4))+_
+    19/32*atanh(x*sqrt(2)*sqrt(b)/sqrt(a+b*x^2))*sqrt(a-b*x^2)*_
+    sqrt(a+b*x^2)/(a^3*sqrt(2)*sqrt(b)*sqrt(a^2-b^2*x^4))
+--R 
+--R
+--R   (2)
+--R                                    +--------+         +-+ +-+
+--R             2 4          2      2  |   2            x\|2 \|b
+--R       (- 19b x  + 38a b x  - 19a )\|b x  + a atanh(-----------)
+--R                                                     +--------+
+--R                                                     |   2
+--R                                                    \|b x  + a
+--R     + 
+--R          2 5         3      2   +-+ +-+
+--R       (9b x  - 4a b x  - 13a x)\|2 \|b
+--R  /
+--R                           +-----------+ +----------+
+--R         3   2      4  +-+ |   2 4    2  |     2      +-+
+--R     (32a b x  - 32a )\|2 \|- b x  + a  \|- b x  + a \|b
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 149
+t0:=sqrt(x^2/(-1+x^2))/(1+x^2)
+--R 
+--R
+--R         +------+
+--R         |   2
+--R         |  x
+--R         |------
+--R         | 2
+--R        \|x  - 1
+--R   (1)  ---------
+--R           2
+--R          x  + 1
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 149
+r0:=atan(sqrt(-1+x^2)/sqrt(2))*sqrt(-x^2/(1-x^2))*sqrt(-1+x^2)/(x*sqrt(2))
+--R 
+--R
+--R         +------+               +------+
+--R         |   2    +------+      | 2
+--R         |  x     | 2          \|x  - 1
+--R         |------ \|x  - 1 atan(---------)
+--R         | 2                       +-+
+--R        \|x  - 1                  \|2
+--R   (2)  ---------------------------------
+--R                        +-+
+--R                      x\|2
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 149
+t0:=sqrt(x^2/(-1+a+(1+a)*x^2))/(1+x^2)
+--R 
+--R
+--R         +-----------------+
+--R         |         2
+--R         |        x
+--R         |-----------------
+--R         |        2
+--R        \|(a + 1)x  + a - 1
+--R   (1)  --------------------
+--R                2
+--R               x  + 1
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 149
+r0:=atan(sqrt(-1+a+(1+a)*x^2)/sqrt(2))*sqrt(-x^2/(1-a-(1+a)*x^2))*_
+    sqrt(-1+a+(1+a)*x^2)/(x*sqrt(2))
+--R 
+--R
+--R         +-----------------+                          +-----------------+
+--R         |         2         +-----------------+      |        2
+--R         |        x          |        2              \|(a + 1)x  + a - 1
+--R         |----------------- \|(a + 1)x  + a - 1 atan(--------------------)
+--R         |        2                                           +-+
+--R        \|(a + 1)x  + a - 1                                  \|2
+--R   (2)  ------------------------------------------------------------------
+--R                                         +-+
+--R                                       x\|2
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 149
+t0:=1/((1+x)*(-1+x^2))^(2/3)
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         +---------------+2
+--R        3| 3    2
+--R        \|x  + x  - x - 1
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 149
+r0:=-3/2*(1-x^2)/(-(1+x)*(1-x^2))^(2/3)
+--R 
+--R
+--R                 2
+--R               3x  - 3
+--R   (2)  --------------------
+--R          +---------------+2
+--R         3| 3    2
+--R        2\|x  + x  - x - 1
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 149
+t0:=(-1+x^2)/((1+x^2)*sqrt(x*(1+x^2)))
+--R 
+--R
+--R               2
+--R              x  - 1
+--R   (1)  -----------------
+--R                 +------+
+--R          2      | 3
+--R        (x  + 1)\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 149
+r0:=-2*x/sqrt(x*(1+x^2))
+--R 
+--R
+--R              2x
+--R   (2)  - ---------
+--R           +------+
+--R           | 3
+--R          \|x  + x
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 149
+t0:=(-1+x^2)/((1+x^2)*sqrt(x+x^3))
+--R 
+--R
+--R               2
+--R              x  - 1
+--R   (1)  -----------------
+--R                 +------+
+--R          2      | 3
+--R        (x  + 1)\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 149
+r0:=-2*x/sqrt(x+x^3)
+--R 
+--R
+--R              2x
+--R   (2)  - ---------
+--R           +------+
+--R           | 3
+--R          \|x  + x
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 149
+t0:=sqrt((-1+x^2)^2/(x*(1+x^2)))/(1+x^2)
+--R 
+--R
+--R         +------------+
+--R         | 4     2
+--R         |x  - 2x  + 1
+--R         |------------
+--R         |    3
+--R        \|   x  + x
+--R   (1)  ---------------
+--R              2
+--R             x  + 1
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 149
+r0:=2*x*sqrt((1-x^2)^2/(x*(1+x^2)))/(1-x^2)
+--R 
+--R
+--R             +------------+
+--R             | 4     2
+--R             |x  - 2x  + 1
+--R          2x |------------
+--R             |    3
+--R            \|   x  + x
+--R   (2)  - -----------------
+--R                 2
+--R                x  - 1
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 149
+t0:=sqrt((-1+x^2)^2/(x+x^3))/(1+x^2)
+--R 
+--R
+--R         +------------+
+--R         | 4     2
+--R         |x  - 2x  + 1
+--R         |------------
+--R         |    3
+--R        \|   x  + x
+--R   (1)  ---------------
+--R              2
+--R             x  + 1
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 149
+r0:=2*x*sqrt((1-x^2)^2/(x+x^3))/(1-x^2)
+--R 
+--R
+--R             +------------+
+--R             | 4     2
+--R             |x  - 2x  + 1
+--R          2x |------------
+--R             |    3
+--R            \|   x  + x
+--R   (2)  - -----------------
+--R                 2
+--R                x  - 1
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 149
+t0:=1/(sqrt(a+b/x^2)*sqrt(c+d*x^2))
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         +--------+
+--R         |   2      +--------+
+--R         |a x  + b  |   2
+--R         |-------- \|d x  + c
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 149
+r0:=atanh(sqrt(d)*sqrt(b+a*x^2)/(sqrt(a)*sqrt(c+d*x^2)))*_
+    sqrt(b+a*x^2)/(x*sqrt(a)*sqrt(d)*sqrt(a+b/x^2))
+--R 
+--R
+--R                              +--------+
+--R         +--------+       +-+ |   2
+--R         |   2           \|d \|a x  + b
+--R        \|a x  + b atanh(---------------)
+--R                              +--------+
+--R                          +-+ |   2
+--R                         \|a \|d x  + c
+--R   (2)  ---------------------------------
+--R                     +--------+
+--R                     |   2
+--R                 +-+ |a x  + b  +-+
+--R               x\|a  |-------- \|d
+--R                     |    2
+--R                    \|   x
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 149
+t0:=sqrt(-2*x^2+x^4)/((-1+x^2)*(2+x^2))
+--R 
+--R
+--R         +--------+
+--R         | 4     2
+--R        \|x  - 2x
+--R   (1)  -----------
+--R         4    2
+--R        x  + x  - 2
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 149
+r0:=2/3*atan(1/2*sqrt(-2+x^2))*sqrt(-2*x^2+x^4)/(x*sqrt(-2+x^2))-_
+    1/3*atan(sqrt(-2+x^2))*sqrt(-2*x^2+x^4)/(x*sqrt(-2+x^2))
+--R 
+--R
+--R                                                         +------+
+--R           +--------+      +------+      +--------+      | 2
+--R           | 4     2       | 2           | 4     2      \|x  - 2
+--R        - \|x  - 2x  atan(\|x  - 2 ) + 2\|x  - 2x  atan(---------)
+--R                                                            2
+--R   (2)  ----------------------------------------------------------
+--R                                   +------+
+--R                                   | 2
+--R                                3x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 149
+t0:=sqrt(1+(-1)/(-1+x^2)^2)/(2-x^2)
+--R 
+--R
+--R           +------------+
+--R           |   4     2
+--R           |  x  - 2x
+--R           |------------
+--R           | 4     2
+--R          \|x  - 2x  + 1
+--R   (1)  - ---------------
+--R                2
+--R               x  - 2
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 149
+r0a:=(1-x^2)*atan(sqrt(-2+x^2))*sqrt(1+(-1)/(1-x^2)^2)/(x*sqrt(-2+x^2))
+--R 
+--R
+--R                   +------------+
+--R                   |   4     2         +------+
+--R            2      |  x  - 2x          | 2
+--R        (- x  + 1) |------------ atan(\|x  - 2 )
+--R                   | 4     2
+--R                  \|x  - 2x  + 1
+--R   (2)  ----------------------------------------
+--R                         +------+
+--R                         | 2
+--R                       x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 149
+r0b:=(1-x^2)*atan(sqrt(-2+x^2))*sqrt(-2*x^2+x^4)*sqrt(1+(-1)/(1-x^2)^2)/_
+     (x*sqrt(-2+x^2)*sqrt(-1+(-1+x^2)^2))
+--R 
+--R
+--R                   +------------+
+--R                   |   4     2         +------+
+--R            2      |  x  - 2x          | 2
+--R        (- x  + 1) |------------ atan(\|x  - 2 )
+--R                   | 4     2
+--R                  \|x  - 2x  + 1
+--R   (3)  ----------------------------------------
+--R                         +------+
+--R                         | 2
+--R                       x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 126
+
+--S 127 of 149
+d0a:=normalize(t0-D(r0a,x))
+--R 
+--R
+--R   (4)  0
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 149
+d0b:=normalize(t0-D(r0b,x))
+--R 
+--R
+--R   (5)  0
+--R                                                    Type: Expression(Integer)
+--E 128
+
+)clear all
+
+--S 129 of 149
+t0:=sqrt((-2*x^2+x^4)/(-1+x^2)^2)/(2+x^2)
+--R 
+--R
+--R         +------------+
+--R         |   4     2
+--R         |  x  - 2x
+--R         |------------
+--R         | 4     2
+--R        \|x  - 2x  + 1
+--R   (1)  ---------------
+--R              2
+--R             x  + 2
+--R                                                    Type: Expression(Integer)
+--E 129
+
+--S 130 of 149
+r0:=-2/3*(1-x^2)*atan(1/2*sqrt(-2+x^2))*sqrt((-2*x^2+x^4)/(1-x^2)^2)/_
+     (x*sqrt(-2+x^2))+1/3*(1-x^2)*atan(sqrt(-2+x^2))*sqrt((-2*x^2+x^4)/_
+     (1-x^2)^2)/(x*sqrt(-2+x^2))
+--R 
+--R
+--R   (2)
+--R                  +------------+
+--R                  |   4     2         +------+
+--R           2      |  x  - 2x          | 2
+--R       (- x  + 1) |------------ atan(\|x  - 2 )
+--R                  | 4     2
+--R                 \|x  - 2x  + 1
+--R     + 
+--R                 +------------+      +------+
+--R                 |   4     2         | 2
+--R          2      |  x  - 2x         \|x  - 2
+--R       (2x  - 2) |------------ atan(---------)
+--R                 | 4     2              2
+--R                \|x  - 2x  + 1
+--R  /
+--R        +------+
+--R        | 2
+--R     3x\|x  - 2
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 131
+
+)clear all
+
+--S 132 of 149
+t0:=(1+2*x/(1+x^2))^(5/2)
+--R 
+--R
+--R                                  +-----------+
+--R                                  | 2
+--R          4     3     2           |x  + 2x + 1
+--R        (x  + 4x  + 6x  + 4x + 1) |-----------
+--R                                  |    2
+--R                                 \|   x  + 1
+--R   (1)  ---------------------------------------
+--R                       4     2
+--R                      x  + 2x  + 1
+--R                                                    Type: Expression(Integer)
+--E 132
+
+--S 133 of 149
+r0:=-1/3*(1-x)*(1+x^2)*(1+2*x/(1+x^2))^(5/2)/(1+x)+2/3*(1+3*x)*(1+x^2)^2*_
+     (1+2*x/(1+x^2))^(5/2)/(1+x)^2-(1+x^2)^3*(1+2*x/(1+x^2))^(5/2)/(1+x)^5-_
+     3*(1+x^2)^3*(1+2*x/(1+x^2))^(5/2)/(1+x)^4-2*(1+x^2)^3*_
+     (1+2*x/(1+x^2))^(5/2)/(1+x)^3+5*(1+x^2)^(5/2)*(1+2*x/(1+x^2))^(5/2)*_
+     asinh(x)/(1+x)^5
+--R 
+--R
+--R   (2)
+--R                           +-----------+
+--R                           | 2           +------+
+--R           2               |x  + 2x + 1  | 2
+--R       (15x  + 15)asinh(x) |----------- \|x  + 1
+--R                           |    2
+--R                          \|   x  + 1
+--R     + 
+--R                                     +-----------+
+--R                                     | 2
+--R          4     3      2             |x  + 2x + 1
+--R       (3x  - 8x  - 18x  - 12x - 17) |-----------
+--R                                     |    2
+--R                                    \|   x  + 1
+--R  /
+--R       3     2
+--R     3x  + 3x  + 3x + 3
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 134
+
+)clear all
+
+--S 135 of 149
+t0:=(1+2*x/(1+x^2))^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R                      | 2
+--R          2           |x  + 2x + 1
+--R        (x  + 2x + 1) |-----------
+--R                      |    2
+--R                     \|   x  + 1
+--R   (1)  ---------------------------
+--R                    2
+--R                   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 135
+
+--S 136 of 149
+r0:=-(1-x)*(1+x^2)*(1+2*x/(1+x^2))^(3/2)/(1+x)+(1+x^2)^2*_
+     (1+2*x/(1+x^2))^(3/2)/(1+x)^3-(1+x^2)^2*(1+2*x/(1+x^2))^(3/2)/(1+x)^2+_
+     3*(1+x^2)^(3/2)*(1+2*x/(1+x^2))^(3/2)*asinh(x)/(1+x)^3
+--R 
+--R
+--R                  +-----------+                          +-----------+
+--R                  | 2           +------+                 | 2
+--R                  |x  + 2x + 1  | 2          2           |x  + 2x + 1
+--R        3asinh(x) |----------- \|x  + 1  + (x  - 2x - 1) |-----------
+--R                  |    2                                 |    2
+--R                 \|   x  + 1                            \|   x  + 1
+--R   (2)  --------------------------------------------------------------
+--R                                     x + 1
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 137
+
+)clear all
+
+--S 138 of 149
+t0:=(1+2*x/(1+x^2))^(1/2)
+--R 
+--R
+--R         +-----------+
+--R         | 2
+--R         |x  + 2x + 1
+--R   (1)   |-----------
+--R         |    2
+--R        \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 138
+
+--S 139 of 149
+r0:=(1+x^2)*sqrt(1+2*x/(1+x^2))/(1+x)+asinh(x)*sqrt(1+x^2)*_
+    sqrt(1+2*x/(1+x^2))/(1+x)
+--R 
+--R
+--R                 +-----------+                     +-----------+
+--R                 | 2           +------+            | 2
+--R                 |x  + 2x + 1  | 2          2      |x  + 2x + 1
+--R        asinh(x) |----------- \|x  + 1  + (x  + 1) |-----------
+--R                 |    2                            |    2
+--R                \|   x  + 1                       \|   x  + 1
+--R   (2)  --------------------------------------------------------
+--R                                  x + 1
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 140
+
+)clear all
+
+--S 141 of 149
+t0:=1/(1+2*x/(1+x^2))^(1/2)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         | 2
+--R         |x  + 2x + 1
+--R         |-----------
+--R         |    2
+--R        \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 141
+
+--S 142 of 149
+r0:=(1+x)/sqrt(1+2*x/(1+x^2))-(1+x)*asinh(x)/(sqrt(1+x^2)*_
+    sqrt(1+2*x/(1+x^2)))-(1+x)*atanh((1-x)/(sqrt(2)*sqrt(1+x^2)))*_
+    sqrt(2)/(sqrt(1+x^2)*sqrt(1+2*x/(1+x^2)))
+--R 
+--R
+--R                                                  +------+
+--R                +-+          x - 1                | 2
+--R        (x + 1)\|2 atanh(-------------) + (x + 1)\|x  + 1  + (- x - 1)asinh(x)
+--R                              +------+
+--R                          +-+ | 2
+--R                         \|2 \|x  + 1
+--R   (2)  ----------------------------------------------------------------------
+--R                                 +-----------+
+--R                                 | 2           +------+
+--R                                 |x  + 2x + 1  | 2
+--R                                 |----------- \|x  + 1
+--R                                 |    2
+--R                                \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 143
+
+)clear all
+
+--S 144 of 149
+t0:=1/(1+2*x/(1+x^2))^(3/2)
+--R 
+--R
+--R                    2
+--R                   x  + 1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R                      | 2
+--R          2           |x  + 2x + 1
+--R        (x  + 2x + 1) |-----------
+--R                      |    2
+--R                     \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 144
+
+--S 145 of 149
+r0:=1/2*(-1-x)/(1+2*x/(1+x^2))^(3/2)+3/2*(1+x)^2*(2+x)/((1+x^2)*_
+    (1+2*x/(1+x^2))^(3/2))-3*(1+x)^3*asinh(x)/((1+x^2)^(3/2)*_
+    (1+2*x/(1+x^2))^(3/2))-9/2*(1+x)^3*atanh((1-x)/(sqrt(2)*_
+    sqrt(1+x^2)))/((1+x^2)^(3/2)*(1+2*x/(1+x^2))^(3/2)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                                                                +------+
+--R          2                     x - 1           2           +-+ | 2
+--R       (9x  + 18x + 9)atanh(-------------) + (2x  + 9x + 5)\|2 \|x  + 1
+--R                                 +------+
+--R                             +-+ | 2
+--R                            \|2 \|x  + 1
+--R     + 
+--R            2            +-+
+--R       (- 6x  - 12x - 6)\|2 asinh(x)
+--R  /
+--R                  +-----------+
+--R                  | 2           +------+
+--R              +-+ |x  + 2x + 1  | 2
+--R     (2x + 2)\|2  |----------- \|x  + 1
+--R                  |    2
+--R                 \|   x  + 1
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 146
+
+)clear all
+
+--S 147 of 149
+t0:=sqrt(1+2*x/(1+x^2))/(1+x^2)
+--R 
+--R
+--R         +-----------+
+--R         | 2
+--R         |x  + 2x + 1
+--R         |-----------
+--R         |    2
+--R        \|   x  + 1
+--R   (1)  --------------
+--R             2
+--R            x  + 1
+--R                                                    Type: Expression(Integer)
+--E 147
+
+--S 148 of 149
+r0:=-(1-x)*sqrt(1+2*x/(1+x^2))/(1+x)
+--R 
+--R
+--R                +-----------+
+--R                | 2
+--R                |x  + 2x + 1
+--R        (x - 1) |-----------
+--R                |    2
+--R               \|   x  + 1
+--R   (2)  ---------------------
+--R                x + 1
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 149
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 149
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder22a.input.pamphlet b/src/input/richder22a.input.pamphlet
new file mode 100644
index 0000000..81ced61
--- /dev/null
+++ b/src/input/richder22a.input.pamphlet
@@ -0,0 +1,2947 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder22a.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Algebraic function problems.input
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder22a.output
+)spool richder22a.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 605
+t0:=x^2/(sqrt(a+b*x)+sqrt(c+b*x))
+--E 1
+
+--S 2 of 605
+r0:=2/3*a^2*(a+b*x)^(3/2)/(b^3*(a-c))-4/5*a*(a+b*x)^(5/2)/(b^3*(a-c))+_
+   2/7*(a+b*x)^(7/2)/(b^3*(a-c))-2/3*c^2*(c+b*x)^(3/2)/(b^3*(a-c))+_
+   4/5*c*(c+b*x)^(5/2)/(b^3*(a-c))-2/7*(c+b*x)^(7/2)/(b^3*(a-c))
+--E 2
+
+--S 3 of 605
+d0:=normalize(t0-D(r0,x))
+--E 3
+
+)clear all
+
+--S 4 of 605
+t0:=x/(sqrt(a+b*x)+sqrt(c+b*x))
+--E 4
+
+--S 5 of 605
+r0:=-2/3*a*(a+b*x)^(3/2)/(b^2*(a-c))+2/5*(a+b*x)^(5/2)/(b^2*(a-c))+_
+   2/3*c*(c+b*x)^(3/2)/(b^2*(a-c))-2/5*(c+b*x)^(5/2)/(b^2*(a-c))
+--E 5
+
+--S 6 of 605
+d0:=normalize(t0-D(r0,x))
+--E 6
+
+)clear all
+
+--S 7 of 605
+t0:=1/(sqrt(a+b*x)+sqrt(c+b*x))
+--E 7
+
+--S 8 of 605
+r0:=2/3*(a+b*x)^(3/2)/(b*(a-c))-2/3*(c+b*x)^(3/2)/(b*(a-c))
+--E 8
+
+--S 9 of 605
+d0:=normalize(t0-D(r0,x))
+--E 9
+
+)clear all
+
+--S 10 of 605
+t0:=1/(x*(sqrt(a+b*x)+sqrt(c+b*x)))
+--E 10
+
+--S 11 of 605
+r0:=-2*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(a-c)+2*atanh(sqrt(c+b*x)/sqrt(c))*_
+   sqrt(c)/(a-c)+2*sqrt(a+b*x)/(a-c)-2*sqrt(c+b*x)/(a-c)
+--E 11
+
+--S 12 of 605
+d0:=normalize(t0-D(r0,x))
+--E 12
+
+)clear all
+
+--S 13 of 605
+t0:=1/(x^2*(sqrt(a+b*x)+sqrt(c+b*x)))
+--E 13
+
+--S 14 of 605
+r0:=-b*atanh(sqrt(a+b*x)/sqrt(a))/((a-c)*sqrt(a))+b*atanh(sqrt(c+b*x)/_
+   sqrt(c))/((a-c)*sqrt(c))-sqrt(a+b*x)/((a-c)*x)+sqrt(c+b*x)/((a-c)*x)
+--E 14
+
+--S 15 of 605
+d0:=normalize(t0-D(r0,x))
+--E 15
+
+)clear all
+
+--S 16 of 605
+t0:=x^2/(sqrt(a+b*x)+sqrt(c+b*x))^2
+--E 16
+
+--S 17 of 605
+r0:=1/3*(a+c)*x^3/(a-c)^2+1/2*b*x^4/(a-c)^2+5/12*(a+c)*(a+b*x)^(3/2)*_
+   (c+b*x)^(3/2)/(b^3*(a-c)^2)-1/2*x*(a+b*x)^(3/2)*(c+b*x)^(3/2)/_
+   (b^2*(a-c)^2)-1/32*(4*a*c-5*(a+c)^2)*atanh(sqrt(a+b*x)/sqrt(c+b*x))/b^3+_
+   1/16*(4*a*c-5*(a+c)^2)*(a+b*x)^(3/2)*sqrt(c+b*x)/(b^3*(a-c)^2)-_
+   1/32*(4*a*c-5*(a+c)^2)*sqrt(a+b*x)*sqrt(c+b*x)/(b^3*(a-c))
+--E 17
+
+--S 18 of 605
+d0:=normalize(t0-D(r0,x))
+--E 18
+
+)clear all
+
+--S 19 of 605
+t0:=x/(sqrt(a+b*x)+sqrt(c+b*x))^2
+--E 19
+
+--S 20 of 605
+r0:=1/2*(a+c)*x^2/(a-c)^2+2/3*b*x^3/(a-c)^2-2/3*(a+b*x)^(3/2)*(c+b*x)^(3/2)/_
+   (b^2*(a-c)^2)-1/4*(a+c)*atanh(sqrt(a+b*x)/sqrt(c+b*x))/b^2+_
+   1/2*(a+c)*(a+b*x)^(3/2)*sqrt(c+b*x)/(b^2*(a-c)^2)-1/4*(a+c)*_
+   sqrt(a+b*x)*sqrt(c+b*x)/(b^2*(a-c))
+--E 20
+
+--S 21 of 605
+d0:=normalize(t0-D(r0,x))
+--E 21
+
+)clear all
+
+--S 22 of 605
+t0:=1/(sqrt(a+b*x)+sqrt(c+b*x))^2
+--E 22
+
+--S 23 of 605
+r0a:=1/2*atanh(sqrt(a+b*x)/sqrt(c+b*x))/b+1/8*(a-c)^2/(b*(sqrt(a+b*x)+sqrt(c+b*x))^4)
+--E 23
+
+--S 24 of 605
+r0b:=(a+c)*x/(a-c)^2+b*x^2/(a-c)^2+1/2*atanh(sqrt(a+b*x)/sqrt(c+b*x))/b-(a+b*x)^(3/2)*sqrt(c+b*x)/(b*(a-c)^2)+1/2*sqrt(a+b*x)*sqrt(c+b*x)/(b*(a-c))
+--E 24
+
+--S 25 of 605
+d0a:=normalize(t0-D(r0a,x))
+--E 25
+
+--S 26 of 605
+d0b:=normalize(t0-D(r0b,x))
+--E 26
+
+)clear all
+
+--S 27 of 605
+t0:=1/(x*(sqrt(a+b*x)+sqrt(c+b*x))^2)
+--E 27
+
+--S 28 of 605
+r0:=2*b*x/(a-c)^2-2*(a+c)*atanh(sqrt(a+b*x)/sqrt(c+b*x))/(a-c)^2+(a+c)*_
+   log(x)/(a-c)^2+4*atanh(sqrt(c)*sqrt(a+b*x)/(sqrt(a)*sqrt(c+b*x)))*_
+   sqrt(a)*sqrt(c)/(a-c)^2-2*sqrt(a+b*x)*sqrt(c+b*x)/(a-c)^2
+--E 28
+
+--S 29 of 605
+d0:=normalize(t0-D(r0,x))
+--E 29
+
+)clear all
+
+--S 30 of 605
+t0:=1/(x^2*(sqrt(a+b*x)+sqrt(c+b*x))^2)
+--E 30
+
+--S 31 of 605
+r0:=(-a-c)/((a-c)^2*x)-4*b*atanh(sqrt(a+b*x)/sqrt(c+b*x))/(a-c)^2+_
+   2*b*log(x)/(a-c)^2+2*b*(a+c)*atanh(sqrt(c)*sqrt(a+b*x)/(sqrt(a)*_
+   sqrt(c+b*x)))/((a-c)^2*sqrt(a)*sqrt(c))+2*sqrt(a+b*x)*sqrt(c+b*x)/_
+   ((a-c)^2*x)
+--E 31
+
+--S 32 of 605
+d0:=normalize(t0-D(r0,x))
+--E 32
+
+)clear all
+
+--S 33 of 605
+t0:=x^2/(sqrt(a+b*x)+sqrt(c+b*x))^3
+--E 33
+
+--S 34 of 605
+r0:=-8/3*a^3*(a+b*x)^(3/2)/(b^3*(a-c)^3)+2/3*a^2*(a+3*c)*(a+b*x)^(3/2)/_
+   (b^3*(a-c)^3)+24/5*a^2*(a+b*x)^(5/2)/(b^3*(a-c)^3)-4/5*a*(a+3*c)*_
+   (a+b*x)^(5/2)/(b^3*(a-c)^3)-24/7*a*(a+b*x)^(7/2)/(b^3*(a-c)^3)+_
+   2/7*(a+3*c)*(a+b*x)^(7/2)/(b^3*(a-c)^3)+8/9*(a+b*x)^(9/2)/(b^3*_
+   (a-c)^3)+8/3*c^3*(c+b*x)^(3/2)/(b^3*(a-c)^3)-2/3*c^2*(3*a+c)*_
+   (c+b*x)^(3/2)/(b^3*(a-c)^3)-24/5*c^2*(c+b*x)^(5/2)/(b^3*(a-c)^3)+_
+   4/5*c*(3*a+c)*(c+b*x)^(5/2)/(b^3*(a-c)^3)+24/7*c*(c+b*x)^(7/2)/_
+   (b^3*(a-c)^3)-2/7*(3*a+c)*(c+b*x)^(7/2)/(b^3*(a-c)^3)-_
+   8/9*(c+b*x)^(9/2)/(b^3*(a-c)^3)
+--E 34
+
+--S 35 of 605
+d0:=normalize(t0-D(r0,x))
+--E 35
+
+)clear all
+
+--S 36 of 605
+t0:=x/(sqrt(a+b*x)+sqrt(c+b*x))^3
+--E 36
+
+--S 37 of 605
+r0:=8/3*a^2*(a+b*x)^(3/2)/(b^2*(a-c)^3)-2/3*a*(a+3*c)*(a+b*x)^(3/2)/(b^2*_
+   (a-c)^3)-16/5*a*(a+b*x)^(5/2)/(b^2*(a-c)^3)+2/5*(a+3*c)*(a+b*x)^(5/2)/_
+   (b^2*(a-c)^3)+8/7*(a+b*x)^(7/2)/(b^2*(a-c)^3)-8/3*c^2*(c+b*x)^(3/2)/_
+   (b^2*(a-c)^3)+2/3*c*(3*a+c)*(c+b*x)^(3/2)/(b^2*(a-c)^3)+16/5*c*_
+   (c+b*x)^(5/2)/(b^2*(a-c)^3)-2/5*(3*a+c)*(c+b*x)^(5/2)/(b^2*(a-c)^3)-_
+   8/7*(c+b*x)^(7/2)/(b^2*(a-c)^3)
+--E 37
+
+--S 38 of 605
+d0:=normalize(t0-D(r0,x))
+--E 38
+
+)clear all
+
+--S 39 of 605
+t0:=1/(sqrt(a+b*x)+sqrt(c+b*x))^3
+--E 39
+
+--S 40 of 605
+r0a:=1/10*(a-c)^2/(b*(sqrt(a+b*x)+sqrt(c+b*x))^5)+(-1/2)/(b*(sqrt(a+b*x)+sqrt(c+b*x)))
+--E 40
+
+--S 41 of 605
+r0b:=-8/3*a*(a+b*x)^(3/2)/(b*(a-c)^3)+2/3*(a+3*c)*(a+b*x)^(3/2)/(b*(a-c)^3)+8/5*(a+b*x)^(5/2)/(b*(a-c)^3)+8/3*c*(c+b*x)^(3/2)/(b*(a-c)^3)-2/3*(3*a+c)*(c+b*x)^(3/2)/(b*(a-c)^3)-8/5*(c+b*x)^(5/2)/(b*(a-c)^3)
+--E 41
+
+--S 42 of 605
+d0a:=normalize(t0-D(r0a,x))
+--E 42
+
+--S 43 of 605
+d0b:=normalize(t0-D(r0b,x))
+--E 43
+
+)clear all
+
+--S 44 of 605
+t0:=1/(x*(sqrt(a+b*x)+sqrt(c+b*x))^3)
+--E 44
+
+--S 45 of 605
+r0:=8/3*(a+b*x)^(3/2)/(a-c)^3-8/3*(c+b*x)^(3/2)/(a-c)^3-2*(a+3*c)*_
+   atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(a-c)^3+2*(3*a+c)*atanh(sqrt(c+b*x)/_
+   sqrt(c))*sqrt(c)/(a-c)^3+2*(a+3*c)*sqrt(a+b*x)/(a-c)^3-2*(3*a+c)*_
+   sqrt(c+b*x)/(a-c)^3
+--E 45
+
+--S 46 of 605
+d0:=normalize(t0-D(r0,x))
+--E 46
+
+)clear all
+
+--S 47 of 605
+t0:=1/(x^2*(sqrt(a+b*x)+sqrt(c+b*x))^3)
+--E 47
+
+--S 48 of 605
+r0a:=-3*b*(3*a+c)*atanh(sqrt(a+b*x)/sqrt(a))/((a-c)^3*sqrt(a))-3*b*(a+3*c)*atanh(sqrt(c+b*x)/sqrt(c))/((-a+c)^3*sqrt(c))+8*b*sqrt(a+b*x)/(a-c)^3-(a+3*c)*sqrt(a+b*x)/((a-c)^3*x)-8*b*sqrt(c+b*x)/(a-c)^3+(3*a+c)*sqrt(c+b*x)/((a-c)^3*x)
+--E 48
+
+--S 49 of 605
+r0b:=-b*(a+3*c)*atanh(sqrt(a+b*x)/sqrt(a))/((a-c)^3*sqrt(a))-8*b*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(a-c)^3+b*(3*a+c)*atanh(sqrt(c+b*x)/sqrt(c))/((a-c)^3*sqrt(c))+8*b*atanh(sqrt(c+b*x)/sqrt(c))*sqrt(c)/(a-c)^3+8*b*sqrt(a+b*x)/(a-c)^3-(a+3*c)*sqrt(a+b*x)/((a-c)^3*x)-8*b*sqrt(c+b*x)/(a-c)^3+(3*a+c)*sqrt(c+b*x)/((a-c)^3*x)
+--E 49
+
+--S 50 of 605
+d0a:=normalize(D(r0a,x))
+--E 50
+
+--S 51 of 605
+d0b:=normalize(D(r0b,x))
+--E 51
+
+)clear all
+
+--S 52 of 605
+t0:=x^3/(sqrt(a+b*x)+sqrt(a+c*x))
+--E 52
+
+--S 53 of 605
+r0:=2/3*a^2*(a+b*x)^(3/2)/(b^3*(b-c))-4/5*a*(a+b*x)^(5/2)/(b^3*(b-c))+_
+   2/7*(a+b*x)^(7/2)/(b^3*(b-c))-2/3*a^2*(a+c*x)^(3/2)/((b-c)*c^3)+_
+   4/5*a*(a+c*x)^(5/2)/((b-c)*c^3)-2/7*(a+c*x)^(7/2)/((b-c)*c^3)
+--E 53
+
+--S 54 of 605
+d0:=normalize(t0-D(r0,x))
+--E 54
+
+)clear all
+
+--S 55 of 605
+t0:=x^2/(sqrt(a+b*x)+sqrt(a+c*x))
+--E 55
+
+--S 56 of 605
+r0:=-2/3*a*(a+b*x)^(3/2)/(b^2*(b-c))+2/5*(a+b*x)^(5/2)/(b^2*(b-c))+_
+   2/3*a*(a+c*x)^(3/2)/((b-c)*c^2)-2/5*(a+c*x)^(5/2)/((b-c)*c^2)
+--E 56
+
+--S 57 of 605
+d0:=normalize(t0-D(r0,x))
+--E 57
+
+)clear all
+
+--S 58 of 605
+t0:=x/(sqrt(a+b*x)+sqrt(a+c*x))
+--E 58
+
+--S 59 of 605
+r0:=2/3*(a+b*x)^(3/2)/(b*(b-c))-2/3*(a+c*x)^(3/2)/((b-c)*c)
+--E 59
+
+--S 60 of 605
+d0:=normalize(t0-D(r0,x))
+--E 60
+
+)clear all
+
+--S 61 of 605
+t0:=1/(sqrt(a+b*x)+sqrt(a+c*x))
+--E 61
+
+--S 62 of 605
+r0:=-2*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(b-c)+2*atanh(sqrt(a+c*x)/sqrt(a))*_
+   sqrt(a)/(b-c)+2*sqrt(a+b*x)/(b-c)-2*sqrt(a+c*x)/(b-c)
+--E 62
+
+--S 63 of 605
+d0:=normalize(t0-D(r0,x))
+--E 63
+
+)clear all
+
+--S 64 of 605
+t0:=1/(x*(sqrt(a+b*x)+sqrt(a+c*x)))
+--E 64
+
+--S 65 of 605
+r0:=-b*atanh(sqrt(a+b*x)/sqrt(a))/((b-c)*sqrt(a))+_
+   c*atanh(sqrt(a+c*x)/sqrt(a))/((b-c)*sqrt(a))-sqrt(a+b*x)/((b-c)*x)+_
+   sqrt(a+c*x)/((b-c)*x)
+--E 65
+
+--S 66 of 605
+d0:=normalize(t0-D(r0,x))
+--E 66
+
+)clear all
+
+--S 67 of 605
+t0:=1/(x^2*(sqrt(a+b*x)+sqrt(a+c*x)))
+--E 67
+
+--S 68 of 605
+r0:=1/4*b^2*atanh(sqrt(a+b*x)/sqrt(a))/(a^(3/2)*(b-c))-1/4*c^2*_
+   atanh(sqrt(a+c*x)/sqrt(a))/(a^(3/2)*(b-c))-1/2*sqrt(a+b*x)/((b-c)*x^2)-_
+   1/4*b*sqrt(a+b*x)/(a*(b-c)*x)+1/2*sqrt(a+c*x)/((b-c)*x^2)+_
+   1/4*c*sqrt(a+c*x)/(a*(b-c)*x)
+--E 68
+
+--S 69 of 605
+d0:=normalize(t0-D(r0,x))
+--E 69
+
+)clear all
+
+--S 70 of 605
+t0:=x^3/(sqrt(a+b*x)+sqrt(a+c*x))^2
+--E 70
+
+--S 71 of 605
+r0:=a*x^2/(b-c)^2+1/3*(b+c)*x^3/(b-c)^2-2/3*(a+b*x)^(3/2)*(a+c*x)^(3/2)/_
+   (b*(b-c)^2*c)-1/4*a^3*(b+c)*atanh(sqrt(c)*sqrt(a+b*x)/(sqrt(b)*_
+   sqrt(a+c*x)))/(b^(5/2)*c^(5/2))+1/2*a*(b+c)*(a+b*x)^(3/2)*_
+   sqrt(a+c*x)/(b^2*(b-c)^2*c)+1/4*a^2*(b+c)*sqrt(a+b*x)*_
+   sqrt(a+c*x)/(b^2*(b-c)*c^2)
+--E 71
+
+--S 72 of 605
+d0:=normalize(t0-D(r0,x))
+--E 72
+
+)clear all
+
+--S 73 of 605
+t0:=x^2/(sqrt(a+b*x)+sqrt(a+c*x))^2
+--E 73
+
+--S 74 of 605
+r0:=2*a*x/(b-c)^2+1/2*(b+c)*x^2/(b-c)^2+1/2*a^2*atanh(sqrt(c)*sqrt(a+b*x)/_
+   (sqrt(b)*sqrt(a+c*x)))/(b^(3/2)*c^(3/2))-(a+b*x)^(3/2)*sqrt(a+c*x)/_
+   (b*(b-c)^2)-1/2*a*sqrt(a+b*x)*sqrt(a+c*x)/(b*(b-c)*c)
+--E 74
+
+--S 75 of 605
+d0:=normalize(t0-D(r0,x))
+--E 75
+
+)clear all
+
+--S 76 of 605
+t0:=x/(sqrt(a+b*x)+sqrt(a+c*x))^2
+--E 76
+
+--S 77 of 605
+r0:=(b+c)*x/(b-c)^2+4*a*atanh(sqrt(a+b*x)/sqrt(a+c*x))/(b-c)^2+_
+   2*a*log(x)/(b-c)^2-2*a*(b+c)*atanh(sqrt(c)*sqrt(a+b*x)/(sqrt(b)*_
+   sqrt(a+c*x)))/((b-c)^2*sqrt(b)*sqrt(c))-2*sqrt(a+b*x)*sqrt(a+c*x)/(b-c)^2
+--E 77
+
+--S 78 of 605
+d0:=normalize(t0-D(r0,x))
+--E 78
+
+)clear all
+
+--S 79 of 605
+t0:=1/(sqrt(a+b*x)+sqrt(a+c*x))^2
+--E 79
+
+--S 80 of 605
+r0:=-2*a/((b-c)^2*x)+2*(b+c)*atanh(sqrt(a+b*x)/sqrt(a+c*x))/(b-c)^2+_
+   (b+c)*log(x)/(b-c)^2-4*atanh(sqrt(c)*sqrt(a+b*x)/(sqrt(b)*_
+   sqrt(a+c*x)))*sqrt(b)*sqrt(c)/(b-c)^2+2*sqrt(a+b*x)*sqrt(a+c*x)/_
+   ((b-c)^2*x)
+--E 80
+
+--S 81 of 605
+d0:=normalize(t0-D(r0,x))
+--E 81
+
+)clear all
+
+--S 82 of 605
+t0:=1/(x*(sqrt(a+b*x)+sqrt(a+c*x))^2)
+--E 82
+
+--S 83 of 605
+r0:=-a/((b-c)^2*x^2)+(-b-c)/((b-c)^2*x)-1/2*atanh(sqrt(a+b*x)/sqrt(a+c*x))/a+_
+   (a+c*x)^(3/2)*sqrt(a+b*x)/(a*(b-c)^2*x^2)+1/2*sqrt(a+b*x)*_
+   sqrt(a+c*x)/(a*(b-c)*x)
+--E 83
+
+--S 84 of 605
+d0:=normalize(t0-D(r0,x))
+--E 84
+
+)clear all
+
+--S 85 of 605
+t0:=1/(x^2*(sqrt(a+b*x)+sqrt(a+c*x))^2)
+--E 85
+
+--S 86 of 605
+r0:=-2/3*a/((b-c)^2*x^3)+1/2*(-b-c)/((b-c)^2*x^2)+1/4*(b+c)*_
+   atanh(sqrt(a+b*x)/sqrt(a+c*x))/a^2+2/3*sqrt(a+b*x)*sqrt(a+c*x)/_
+   ((b-c)^2*x^3)+1/6*(b+c)*sqrt(a+b*x)*sqrt(a+c*x)/(a*(b-c)^2*x^2)-_
+   1/12*(3*b^2-2*b*c+3*c^2)*sqrt(a+b*x)*sqrt(a+c*x)/(a^2*(b-c)^2*x)
+--E 86
+
+--S 87 of 605
+d0:=normalize(t0-D(r0,x))
+--E 87
+
+)clear all
+
+--S 88 of 605
+t0:=x^4/(sqrt(a+b*x)+sqrt(a+c*x))^3
+--E 88
+
+--S 89 of 605
+r0:=-8/3*a^2*(a+b*x)^(3/2)/(b^2*(b-c)^3)+2/3*a^2*(b+3*c)*(a+b*x)^(3/2)/_
+   (b^3*(b-c)^3)+8/5*a*(a+b*x)^(5/2)/(b^2*(b-c)^3)-4/5*a*(b+3*c)*_
+   (a+b*x)^(5/2)/(b^3*(b-c)^3)+2/7*(b+3*c)*(a+b*x)^(7/2)/(b^3*(b-c)^3)+_
+   8/3*a^2*(a+c*x)^(3/2)/((b-c)^3*c^2)-2/3*a^2*(3*b+c)*(a+c*x)^(3/2)/_
+   ((b-c)^3*c^3)-8/5*a*(a+c*x)^(5/2)/((b-c)^3*c^2)+4/5*a*(3*b+c)*_
+   (a+c*x)^(5/2)/((b-c)^3*c^3)-2/7*(3*b+c)*(a+c*x)^(7/2)/((b-c)^3*c^3)
+--E 89
+
+--S 90 of 605
+d0:=normalize(t0-D(r0,x))
+--E 90
+
+)clear all
+
+--S 91 of 605
+t0:=x^3/(sqrt(a+b*x)+sqrt(a+c*x))^3
+--E 91
+
+--S 92 of 605
+r0:=8/3*a*(a+b*x)^(3/2)/(b*(b-c)^3)-2/3*a*(b+3*c)*(a+b*x)^(3/2)/(b^2*_
+   (b-c)^3)+2/5*(b+3*c)*(a+b*x)^(5/2)/(b^2*(b-c)^3)-8/3*a*_
+   (a+c*x)^(3/2)/((b-c)^3*c)+2/3*a*(3*b+c)*(a+c*x)^(3/2)/((b-c)^3*c^2)-_
+   2/5*(3*b+c)*(a+c*x)^(5/2)/((b-c)^3*c^2)
+--E 92
+
+--S 93 of 605
+d0:=normalize(t0-D(r0,x))
+--E 93
+
+)clear all
+
+--S 94 of 605
+t0:=x^2/(sqrt(a+b*x)+sqrt(a+c*x))^3
+--E 94
+
+--S 95 of 605
+r0:=2/3*(b+3*c)*(a+b*x)^(3/2)/(b*(b-c)^3)-2/3*(3*b+c)*(a+c*x)^(3/2)/_
+   ((b-c)^3*c)-8*a^(3/2)*atanh(sqrt(a+b*x)/sqrt(a))/(b-c)^3+8*a^(3/2)*_
+   atanh(sqrt(a+c*x)/sqrt(a))/(b-c)^3+8*a*sqrt(a+b*x)/(b-c)^3-_
+   8*a*sqrt(a+c*x)/(b-c)^3
+--E 95
+
+--S 96 of 605
+d0:=normalize(t0-D(r0,x))
+--E 96
+
+)clear all
+
+--S 97 of 605
+t0:=x/(sqrt(a+b*x)+sqrt(a+c*x))^3
+--E 97
+
+--S 98 of 605
+r0a:=-6*(b+c)*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(b-c)^3+6*(b+c)*atanh(sqrt(a+c*x)/sqrt(a))*sqrt(a)/(b-c)^3+2*(b+3*c)*sqrt(a+b*x)/(b-c)^3-4*a*sqrt(a+b*x)/((b-c)^3*x)-2*(3*b+c)*sqrt(a+c*x)/(b-c)^3+4*a*sqrt(a+c*x)/((b-c)^3*x)
+--E 98
+
+--S 99 of 605
+r0b:=-4*b*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(b-c)^3-2*(b+3*c)*atanh(sqrt(a+b*x)/sqrt(a))*sqrt(a)/(b-c)^3+4*c*atanh(sqrt(a+c*x)/sqrt(a))*sqrt(a)/(b-c)^3+2*(3*b+c)*atanh(sqrt(a+c*x)/sqrt(a))*sqrt(a)/(b-c)^3+2*(b+3*c)*sqrt(a+b*x)/(b-c)^3-4*a*sqrt(a+b*x)/((b-c)^3*x)-2*(3*b+c)*sqrt(a+c*x)/(b-c)^3+4*a*sqrt(a+c*x)/((b-c)^3*x)
+--E 99
+
+--S 100 of 605
+d0a:=normalize(t0-D(r0a,x))
+--E 100
+
+--S 101 of 605
+d0b:=normalize(t0-D(r0b,x))
+--E 101
+
+)clear all
+
+--S 102 of 605
+t0:=1/(sqrt(a+b*x)+sqrt(a+c*x))^3
+--E 102
+
+--S 103 of 605
+r0a:=-3*b*c*atanh(sqrt(a+b*x)/sqrt(a))/((b-c)^3*sqrt(a))+3*b*c*atanh(sqrt(a+c*x)/sqrt(a))/((b-c)^3*sqrt(a))-2*a*sqrt(a+b*x)/((b-c)^3*x^2)-(2*b+3*c)*sqrt(a+b*x)/((b-c)^3*x)+2*a*sqrt(a+c*x)/((b-c)^3*x^2)+(3*b+2*c)*sqrt(a+c*x)/((b-c)^3*x)
+--E 103
+
+--S 104 of 605
+r0b:=b^2*atanh(sqrt(a+b*x)/sqrt(a))/((b-c)^3*sqrt(a))-b*(b+3*c)*atanh(sqrt(a+b*x)/sqrt(a))/((b-c)^3*sqrt(a))-c^2*atanh(sqrt(a+c*x)/sqrt(a))/((b-c)^3*sqrt(a))+c*(3*b+c)*atanh(sqrt(a+c*x)/sqrt(a))/((b-c)^3*sqrt(a))-2*a*sqrt(a+b*x)/((b-c)^3*x^2)-b*sqrt(a+b*x)/((b-c)^3*x)-(b+3*c)*sqrt(a+b*x)/((b-c)^3*x)+2*a*sqrt(a+c*x)/((b-c)^3*x^2)+c*sqrt(a+c*x)/((b-c)^3*x)+(3*b+c)*sqrt(a+c*x)/((b-c)^3*x)
+--E 104
+
+--S 105 of 605
+d0a:=normalize(t0-D(r0a,x))
+--E 105
+
+--S 106 of 605
+d0b:=normalize(t0-D(r0b,x))
+--E 106
+
+)clear all
+
+--S 107 of 605
+t0:=x^3*(sqrt(1-x)+sqrt(1+x))^2
+--E 107
+
+--S 108 of 605
+r0:=1/2*x^4-2/3*(1-x^2)^(3/2)+2/5*(1-x^2)^(5/2)
+--E 108
+
+--S 109 of 605
+d0:=normalize(t0-D(r0,x))
+--E 109
+
+)clear all
+
+--S 110 of 605
+t0:=x^2*(sqrt(1-x)+sqrt(1+x))^2
+--E 110
+
+--S 111 of 605
+r0:=2/3*x^3+1/4*asin(x)-1/4*x*sqrt(1-x^2)+1/2*x^3*sqrt(1-x^2)
+--E 111
+
+--S 112 of 605
+d0:=normalize(t0-D(r0,x))
+--E 112
+
+)clear all
+
+--S 113 of 605
+t0:=x*(sqrt(1-x)+sqrt(1+x))^2
+--E 113
+
+--S 114 of 605
+r0:=x^2-2/3*(1-x^2)^(3/2)
+--E 114
+
+--S 115 of 605
+d0:=normalize(t0-D(r0,x))
+--E 115
+
+)clear all
+
+--S 116 of 605
+t0:=(sqrt(1-x)+sqrt(1+x))^2
+--E 116
+
+--S 117 of 605
+r0:=2*x+asin(x)+x*sqrt(1-x^2)
+--E 117
+
+--S 118 of 605
+d0:=normalize(t0-D(r0,x))
+--E 118
+
+)clear all
+
+--S 119 of 605
+t0:=(sqrt(1-x)+sqrt(1+x))^2/x
+--E 119
+
+--S 120 of 605
+r0:=-2*atanh(sqrt(1-x^2))+2*log(x)+2*sqrt(1-x^2)
+--E 120
+
+--S 121 of 605
+d0:=normalize(t0-D(r0,x))
+--E 121
+
+)clear all
+
+--S 122 of 605
+t0:=(sqrt(1-x)+sqrt(1+x))^2/x^2
+--E 122
+
+--S 123 of 605
+r0:=(-2)/x-2*asin(x)-2*sqrt(1-x^2)/x
+--E 123
+
+--S 124 of 605
+d0:=normalize(t0-D(r0,x))
+--E 124
+
+)clear all
+
+--S 125 of 605
+t0:=(sqrt(1-x)+sqrt(1+x))^2/x^3
+--E 125
+
+--S 126 of 605
+r0:=(-1)/x^2+atanh(sqrt(1-x^2))-sqrt(1-x^2)/x^2
+--E 126
+
+--S 127 of 605
+d0:=normalize(t0-D(r0,x))
+--E 127
+
+)clear all
+
+--S 128 of 605
+t0:=sqrt(1-x)*(sqrt(1-x)+sqrt(1+x))
+--E 128
+
+--S 129 of 605
+r0:=x-1/2*x^2+1/2*asin(x)+1/2*x*sqrt(1-x^2)
+--E 129
+
+--S 130 of 605
+d0:=normalize(t0-D(r0,x))
+--E 130
+
+)clear all
+
+--S 131 of 605
+t0:=x^3*(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))
+--E 131
+
+--S 132 of 605
+r0:=-1/2*x^4+2/3*(1-x^2)^(3/2)-2/5*(1-x^2)^(5/2)
+--E 132
+
+--S 133 of 605
+d0:=normalize(t0-D(r0,x))
+--E 133
+
+)clear all
+
+--S 134 of 605
+t0:=x^2*(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))
+--E 134
+
+--S 135 of 605
+r0:=-2/3*x^3-1/4*asin(x)+1/4*x*sqrt(1-x^2)-1/2*x^3*sqrt(1-x^2)
+--E 135
+
+--S 136 of 605
+d0:=normalize(t0-D(r0,x))
+--E 136
+
+)clear all
+
+--S 137 of 605
+t0:=x*(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))
+--E 137
+
+--S 138 of 605
+r0:=-x^2+2/3*(1-x^2)^(3/2)
+--E 138
+
+--S 139 of 605
+d0:=normalize(t0-D(r0,x))
+--E 139
+
+)clear all
+
+--S 140 of 605
+t0:=(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))
+--E 140
+
+--S 141 of 605
+r0:=-2*x-asin(x)-x*sqrt(1-x^2)
+--E 141
+
+--S 142 of 605
+d0:=normalize(t0-D(r0,x))
+--E 142
+
+)clear all
+
+--S 143 of 605
+t0:=(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))/x
+--E 143
+
+--S 144 of 605
+r0:=2*atanh(sqrt(1-x^2))-2*log(x)-2*sqrt(1-x^2)
+--E 144
+
+--S 145 of 605
+d0:=normalize(t0-D(r0,x))
+--E 145
+
+)clear all
+
+--S 146 of 605
+t0:=(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))/x^2
+--E 146
+
+--S 147 of 605
+r0:=2/x+2*asin(x)+2*sqrt(1-x^2)/x
+--E 147
+
+--S 148 of 605
+d0:=normalize(t0-D(r0,x))
+--E 148
+
+)clear all
+
+--S 149 of 605
+t0:=(-sqrt(1-x)-sqrt(1+x))*(sqrt(1-x)+sqrt(1+x))/x^3
+--E 149
+
+--S 150 of 605
+r0:=1/x^2-atanh(sqrt(1-x^2))+sqrt(1-x^2)/x^2
+--E 150
+
+--S 151 of 605
+d0:=normalize(t0-D(r0,x))
+--E 151
+
+)clear all
+
+--S 152 of 605
+t0:=(sqrt(1-x)+sqrt(1+x))/(-sqrt(1-x)+sqrt(1+x))
+--E 152
+
+--S 153 of 605
+r0:=-atanh(sqrt(1-x^2))+log(x)+sqrt(1-x^2)
+--E 153
+
+--S 154 of 605
+d0:=normalize(t0-D(r0,x))
+--E 154
+
+)clear all
+
+--S 155 of 605
+t0:=(-sqrt(-1+x)+sqrt(1+x))/(sqrt(-1+x)+sqrt(1+x))
+--E 155
+
+--S 156 of 605
+r0a:=1/2*x^2+1/2*acosh(x)-1/2*x*sqrt(-1+x)*sqrt(1+x)
+--E 156
+
+--S 157 of 605
+r0b:=1/2*x^2+1/2*acosh(x)-1/2*(-1+x)^(3/2)*sqrt(1+x)-1/2*sqrt(-1+x)*sqrt(1+x)
+--E 157
+
+--S 158 of 605
+d0a:=normalize(t0-D(r0a,x))
+--E 158
+
+--S 159 of 605
+d0b:=normalize(t0-D(r0b,x))
+--E 159
+
+)clear all
+
+--S 160 of 605
+t0:=x^m*sqrt(a*x^n)
+--E 160
+
+--S 161 of 605
+r0:=2*x^(1+m)*sqrt(a*x^n)/(2+2*m+n)
+--E 161
+
+--S 162 of 605
+d0:=normalize(t0-D(r0,x))
+--E 162
+
+)clear all
+
+--S 163 of 605
+t0:=x^(-1-1/2*n)*sqrt(a*x^n)
+--E 163
+
+--S 164 of 605
+r0:=log(x)*sqrt(a*x^n)/x^(1/2*n)
+--E 164
+
+--S 165 of 605
+d0:=normalize(t0-D(r0,x))
+--E 165
+
+)clear all
+
+--S 166 of 605
+t0:=x^2*sqrt(a*x^n)
+--E 166
+
+--S 167 of 605
+r0:=2*x^3*sqrt(a*x^n)/(6+n)
+--E 167
+
+--S 168 of 605
+d0:=normalize(t0-D(r0,x))
+--E 168
+
+)clear all
+
+--S 169 of 605
+t0:=x*sqrt(a*x^n)
+--E 169
+
+--S 170 of 605
+r0:=2*x^2*sqrt(a*x^n)/(4+n)
+--E 170
+
+--S 171 of 605
+d0:=normalize(t0-D(r0,x))
+--E 171
+
+)clear all
+
+--S 172 of 605
+t0:=sqrt(a*x^n)
+--E 172
+
+--S 173 of 605
+r0:=2*x*sqrt(a*x^n)/(2+n)
+--E 173
+
+--S 174 of 605
+d0:=normalize(t0-D(r0,x))
+--E 174
+
+)clear all
+
+--S 175 of 605
+t0:=sqrt(a*x^n)/x
+--E 175
+
+--S 176 of 605
+r0:=2*sqrt(a*x^n)/n
+--E 176
+
+--S 177 of 605
+d0:=normalize(t0-D(r0,x))
+--E 177
+
+)clear all
+
+--S 178 of 605
+t0:=sqrt(a*x^n)/x^2
+--E 178
+
+--S 179 of 605
+r0:=-2*sqrt(a*x^n)/((2-n)*x)
+--E 179
+
+--S 180 of 605
+d0:=normalize(t0-D(r0,x))
+--E 180
+
+)clear all
+
+--S 181 of 605
+t0:=sqrt(a*x^n)/x^3
+--E 181
+
+--S 182 of 605
+r0:=-2*sqrt(a*x^n)/((4-n)*x^2)
+--E 182
+
+--S 183 of 605
+d0:=normalize(t0-D(r0,x))
+--E 183
+
+)clear all
+
+--S 184 of 605
+t0:=x^m*(a*x^n)^(3/2)
+--E 184
+
+--S 185 of 605
+r0:=2*a*x^(1+m+n)*sqrt(a*x^n)/(2+2*m+3*n)
+--E 185
+
+--S 186 of 605
+d0:=normalize(t0-D(r0,x))
+--E 186
+
+)clear all
+
+--S 187 of 605
+t0:=x^(-1-3/2*n)*(a*x^n)^(3/2)
+--E 187
+
+--S 188 of 605
+r0:=a*log(x)*sqrt(a*x^n)/x^(1/2*n)
+--E 188
+
+--S 189 of 605
+d0:=normalize(t0-D(r0,x))
+--E 189
+
+)clear all
+
+--S 190 of 605
+t0:=x^2*(a*x^n)^(3/2)
+--E 190
+
+--S 191 of 605
+r0:=2/3*a*x^(3+n)*sqrt(a*x^n)/(2+n)
+--E 191
+
+--S 192 of 605
+d0:=normalize(t0-D(r0,x))
+--E 192
+
+)clear all
+
+--S 193 of 605
+t0:=x*(a*x^n)^(3/2)
+--E 193
+
+--S 194 of 605
+r0:=2*a*x^(2+n)*sqrt(a*x^n)/(4+3*n)
+--E 194
+
+--S 195 of 605
+d0:=normalize(t0-D(r0,x))
+--E 195
+
+)clear all
+
+--S 196 of 605
+t0:=(a*x^n)^(3/2)
+--E 196
+
+--S 197 of 605
+r0:=2*a*x^(1+n)*sqrt(a*x^n)/(2+3*n)
+--E 197
+
+--S 198 of 605
+d0:=normalize(t0-D(r0,x))
+--E 198
+
+)clear all
+
+--S 199 of 605
+t0:=(a*x^n)^(3/2)/x
+--E 199
+
+--S 200 of 605
+r0:=2/3*a*x^n*sqrt(a*x^n)/n
+--E 200
+
+--S 201 of 605
+d0:=normalize(t0-D(r0,x))
+--E 201
+
+)clear all
+
+--S 202 of 605
+t0:=(a*x^n)^(3/2)/x^2
+--E 202
+
+--S 203 of 605
+r0:=-2*a*x^(-1+n)*sqrt(a*x^n)/(2-3*n)
+--E 203
+
+--S 204 of 605
+d0:=normalize(t0-D(r0,x))
+--E 204
+
+)clear all
+
+--S 205 of 605
+t0:=(a*x^n)^(3/2)/x^3
+--E 205
+
+--S 206 of 605
+r0:=-2*a*x^(-2+n)*sqrt(a*x^n)/(4-3*n)
+--E 206
+
+--S 207 of 605
+d0:=normalize(t0-D(r0,x))
+--E 207
+
+)clear all
+
+--S 208 of 605
+t0:=sqrt(a*x^3)
+--E 208
+
+--S 209 of 605
+r0:=2/5*x*sqrt(a*x^3)
+--E 209
+
+--S 210 of 605
+d0:=normalize(t0-D(r0,x))
+--E 210
+
+)clear all
+
+--S 211 of 605
+t0:=sqrt(a*x^2)
+--E 211
+
+--S 212 of 605
+r0:=1/2*x*sqrt(a*x^2)
+--E 212
+
+--S 213 of 605
+d0:=normalize(t0-D(r0,x))
+--E 213
+
+)clear all
+
+--S 214 of 605
+t0:=sqrt(a*x)
+--E 214
+
+--S 215 of 605
+r0:=2/3*(a*x)^(3/2)/a
+--E 215
+
+--S 216 of 605
+d0:=normalize(t0-D(r0,x))
+--E 216
+
+)clear all
+
+--S 217 of 605
+t0:=sqrt(a/x)
+--E 217
+
+--S 218 of 605
+r0:=2*x*sqrt(a/x)
+--E 218
+
+--S 219 of 605
+d0:=normalize(t0-D(r0,x))
+--E 219
+
+)clear all
+
+--S 220 of 605
+t0:=sqrt(a/x^2)
+--E 220
+
+--S 221 of 605
+r0:=x*log(x)*sqrt(a/x^2)
+--E 221
+
+--S 222 of 605
+d0:=normalize(t0-D(r0,x))
+--E 222
+
+)clear all
+
+--S 223 of 605
+t0:=sqrt(a/x^3)
+--E 223
+
+--S 224 of 605
+r0:=-2*x*sqrt(a/x^3)
+--E 224
+
+--S 225 of 605
+d0:=normalize(t0-D(r0,x))
+--E 225
+
+)clear all
+
+--S 226 of 605
+t0:=(a*x^3)^(3/2)
+--E 226
+
+--S 227 of 605
+r0:=2/11*a*x^4*sqrt(a*x^3)
+--E 227
+
+--S 228 of 605
+d0:=normalize(t0-D(r0,x))
+--E 228
+
+)clear all
+
+--S 229 of 605
+t0:=(a*x^2)^(3/2)
+--E 229
+
+--S 230 of 605
+r0:=1/4*a*x^3*sqrt(a*x^2)
+--E 230
+
+--S 231 of 605
+d0:=normalize(t0-D(r0,x))
+--E 231
+
+)clear all
+
+--S 232 of 605
+t0:=(a*x)^(3/2)
+--E 232
+
+--S 233 of 605
+r0:=2/5*(a*x)^(5/2)/a
+--E 233
+
+--S 234 of 605
+d0:=normalize(t0-D(r0,x))
+--E 234
+
+)clear all
+
+--S 235 of 605
+t0:=(a/x)^(3/2)
+--E 235
+
+--S 236 of 605
+r0:=-2*a*sqrt(a/x)
+--E 236
+
+--S 237 of 605
+d0:=normalize(t0-D(r0,x))
+--E 237
+
+)clear all
+
+--S 238 of 605
+t0:=(a/x^2)^(3/2)
+--E 238
+
+--S 239 of 605
+r0:=-1/2*a*sqrt(a/x^2)/x
+--E 239
+
+--S 240 of 605
+d0:=normalize(t0-D(r0,x))
+--E 240
+
+)clear all
+
+--S 241 of 605
+t0:=(a/x^3)^(3/2)
+--E 241
+
+--S 242 of 605
+r0:=-2/7*a*sqrt(a/x^3)/x^2
+--E 242
+
+--S 243 of 605
+d0:=normalize(t0-D(r0,x))
+--E 243
+
+)clear all
+
+--S 244 of 605
+t0:=x^m/sqrt(a*x^n)
+--E 244
+
+--S 245 of 605
+r0:=2*x^(1+m)/((2+2*m-n)*sqrt(a*x^n))
+--E 245
+
+--S 246 of 605
+d0:=normalize(t0-D(r0,x))
+--E 246
+
+)clear all
+
+--S 247 of 605
+t0:=x^(-1+1/2*n)/sqrt(a*x^n)
+--E 247
+
+--S 248 of 605
+r0:=x^(1/2*n)*log(x)/sqrt(a*x^n)
+--E 248
+
+--S 249 of 605
+d0:=normalize(t0-D(r0,x))
+--E 249
+
+)clear all
+
+--S 250 of 605
+t0:=x^2/sqrt(a*x^n)
+--E 250
+
+--S 251 of 605
+r0:=2*x^3/((6-n)*sqrt(a*x^n))
+--E 251
+
+--S 252 of 605
+d0:=normalize(t0-D(r0,x))
+--E 252
+
+)clear all
+
+--S 253 of 605
+t0:=x/sqrt(a*x^n)
+--E 253
+
+--S 254 of 605
+r0:=2*x^2/((4-n)*sqrt(a*x^n))
+--E 254
+
+--S 255 of 605
+d0:=normalize(t0-D(r0,x))
+--E 255
+
+)clear all
+
+--S 256 of 605
+t0:=1/sqrt(a*x^n)
+--E 256
+
+--S 257 of 605
+r0:=2*x/((2-n)*sqrt(a*x^n))
+--E 257
+
+--S 258 of 605
+d0:=normalize(t0-D(r0,x))
+--E 258
+
+)clear all
+
+--S 259 of 605
+t0:=sqrt(a*x^n)/x
+--E 259
+
+--S 260 of 605
+r0:=2*sqrt(a*x^n)/n
+--E 260
+
+--S 261 of 605
+d0:=normalize(t0-D(r0,x))
+--E 261
+
+)clear all
+
+--S 262 of 605
+t0:=sqrt(a*x^n)/x^2
+--E 262
+
+--S 263 of 605
+r0:=-2*sqrt(a*x^n)/((2-n)*x)
+--E 263
+
+--S 264 of 605
+d0:=normalize(t0-D(r0,x))
+--E 264
+
+)clear all
+
+--S 265 of 605
+t0:=sqrt(a*x^n)/x^3
+--E 265
+
+--S 266 of 605
+r0:=-2*sqrt(a*x^n)/((4-n)*x^2)
+--E 266
+
+--S 267 of 605
+d0:=normalize(t0-D(r0,x))
+--E 267
+
+)clear all
+
+--S 268 of 605
+t0:=x^m/(a*x^n)^(3/2)
+--E 268
+
+--S 269 of 605
+r0:=2*x^(1+m-n)/(a*(2+2*m-3*n)*sqrt(a*x^n))
+--E 269
+
+--S 270 of 605
+d0:=normalize(t0-D(r0,x))
+--E 270
+
+)clear all
+
+--S 271 of 605
+t0:=x^(-1+3/2*n)/(a*x^n)^(3/2)
+--E 271
+
+--S 272 of 605
+r0:=x^(1/2*n)*log(x)/(a*sqrt(a*x^n))
+--E 272
+
+--S 273 of 605
+d0:=normalize(t0-D(r0,x))
+--E 273
+
+)clear all
+
+--S 274 of 605
+t0:=x^2/(a*x^n)^(3/2)
+--E 274
+
+--S 275 of 605
+r0:=2/3*x^(3-n)/(a*(2-n)*sqrt(a*x^n))
+--E 275
+
+--S 276 of 605
+d0:=normalize(t0-D(r0,x))
+--E 276
+
+)clear all
+
+--S 277 of 605
+t0:=x/(a*x^n)^(3/2)
+--E 277
+
+--S 278 of 605
+r0:=2*x^(2-n)/(a*(4-3*n)*sqrt(a*x^n))
+--E 278
+
+--S 279 of 605
+d0:=normalize(t0-D(r0,x))
+--E 279
+
+)clear all
+
+--S 280 of 605
+t0:=1/(a*x^n)^(3/2)
+--E 280
+
+--S 281 of 605
+r0:=2*x^(1-n)/(a*(2-3*n)*sqrt(a*x^n))
+--E 281
+
+--S 282 of 605
+d0:=normalize(t0-D(r0,x))
+--E 282
+
+)clear all
+
+--S 283 of 605
+t0:=(a*x^n)^(3/2)/x
+--E 283
+
+--S 284 of 605
+r0:=2/3*a*x^n*sqrt(a*x^n)/n
+--E 284
+
+--S 285 of 605
+d0:=normalize(t0-D(r0,x))
+--E 285
+
+)clear all
+
+--S 286 of 605
+t0:=(a*x^n)^(3/2)/x^2
+--E 286
+
+--S 287 of 605
+r0:=-2*a*x^(-1+n)*sqrt(a*x^n)/(2-3*n)
+--E 287
+
+--S 288 of 605
+d0:=normalize(t0-D(r0,x))
+--E 288
+
+)clear all
+
+--S 289 of 605
+t0:=(a*x^n)^(3/2)/x^3
+--E 289
+
+--S 290 of 605
+r0:=-2*a*x^(-2+n)*sqrt(a*x^n)/(4-3*n)
+--E 290
+
+--S 291 of 605
+d0:=normalize(t0-D(r0,x))
+--E 291
+
+)clear all
+
+--S 292 of 605
+t0:=1/sqrt(a*x^3)
+--E 292
+
+--S 293 of 605
+r0:=-2*x/sqrt(a*x^3)
+--E 293
+
+--S 294 of 605
+d0:=normalize(t0-D(r0,x))
+--E 294
+
+)clear all
+
+--S 295 of 605
+t0:=1/sqrt(a*x^2)
+--E 295
+
+--S 296 of 605
+r0:=x*log(x)/sqrt(a*x^2)
+--E 296
+
+--S 297 of 605
+d0:=normalize(t0-D(r0,x))
+--E 297
+
+)clear all
+
+--S 298 of 605
+t0:=1/sqrt(a*x)
+--E 298
+
+--S 299 of 605
+r0:=2*sqrt(a*x)/a
+--E 299
+
+--S 300 of 605
+d0:=normalize(t0-D(r0,x))
+--E 300
+
+)clear all
+
+--S 301 of 605
+t0:=1/sqrt(a/x)
+--E 301
+
+--S 302 of 605
+r0:=2/3*x/sqrt(a/x)
+--E 302
+
+--S 303 of 605
+d0:=normalize(t0-D(r0,x))
+--E 303
+
+)clear all
+
+--S 304 of 605
+t0:=1/sqrt(a/x^2)
+--E 304
+
+--S 305 of 605
+r0:=1/2*x/sqrt(a/x^2)
+--E 305
+
+--S 306 of 605
+d0:=normalize(t0-D(r0,x))
+--E 306
+
+)clear all
+
+--S 307 of 605
+t0:=1/sqrt(a/x^3)
+--E 307
+
+--S 308 of 605
+r0:=2/5*x/sqrt(a/x^3)
+--E 308
+
+--S 309 of 605
+d0:=normalize(t0-D(r0,x))
+--E 309
+
+)clear all
+
+--S 310 of 605
+t0:=1/(a*x^3)^(3/2)
+--E 310
+
+--S 311 of 605
+r0:=(-2/7)/(a*x^2*sqrt(a*x^3))
+--E 311
+
+--S 312 of 605
+d0:=normalize(t0-D(r0,x))
+--E 312
+
+)clear all
+
+--S 313 of 605
+t0:=1/(a*x^2)^(3/2)
+--E 313
+
+--S 314 of 605
+r0:=(-1/2)/(a*x*sqrt(a*x^2))
+--E 314
+
+--S 315 of 605
+d0:=normalize(t0-D(r0,x))
+--E 315
+
+)clear all
+
+--S 316 of 605
+t0:=1/(a*x)^(3/2)
+--E 316
+
+--S 317 of 605
+r0:=(-2)/(a*sqrt(a*x))
+--E 317
+
+--S 318 of 605
+d0:=normalize(t0-D(r0,x))
+--E 318
+
+)clear all
+
+--S 319 of 605
+t0:=1/(a/x)^(3/2)
+--E 319
+
+--S 320 of 605
+r0:=2/5*x^2/(a*sqrt(a/x))
+--E 320
+
+--S 321 of 605
+d0:=normalize(t0-D(r0,x))
+--E 321
+
+)clear all
+
+--S 322 of 605
+t0:=1/(a/x^2)^(3/2)
+--E 322
+
+--S 323 of 605
+r0:=1/4*x^3/(a*sqrt(a/x^2))
+--E 323
+
+--S 324 of 605
+d0:=normalize(t0-D(r0,x))
+--E 324
+
+)clear all
+
+--S 325 of 605
+t0:=1/(a/x^3)^(3/2)
+--E 325
+
+--S 326 of 605
+r0:=2/11*x^4/(a*sqrt(a/x^3))
+--E 326
+
+--S 327 of 605
+d0:=normalize(t0-D(r0,x))
+--E 327
+
+)clear all
+
+--S 328 of 605
+t0:=(a*x^n)^(1/3)
+--E 328
+
+--S 329 of 605
+r0:=3*x*(a*x^n)^(1/3)/(3+n)
+--E 329
+
+--S 330 of 605
+d0:=normalize(t0-D(r0,x))
+--E 330
+
+)clear all
+
+--S 331 of 605
+t0:=(a*x^3)^(1/3)
+--E 331
+
+--S 332 of 605
+r0:=1/2*x*(a*x^3)^(1/3)
+--E 332
+
+--S 333 of 605
+d0:=normalize(t0-D(r0,x))
+--E 333
+
+)clear all
+
+--S 334 of 605
+t0:=(a*x^2)^(1/3)
+--E 334
+
+--S 335 of 605
+r0:=3/5*x*(a*x^2)^(1/3)
+--E 335
+
+--S 336 of 605
+d0:=normalize(t0-D(r0,x))
+--E 336
+
+)clear all
+
+--S 337 of 605
+t0:=(a*x)^(1/3)
+--E 337
+
+--S 338 of 605
+r0:=3/4*(a*x)^(4/3)/a
+--E 338
+
+--S 339 of 605
+d0:=normalize(t0-D(r0,x))
+--E 339
+
+)clear all
+
+--S 340 of 605
+t0:=(a/x)^(1/3)
+--E 340
+
+--S 341 of 605
+r0:=3/2*(a/x)^(1/3)*x
+--E 341
+
+--S 342 of 605
+d0:=normalize(t0-D(r0,x))
+--E 342
+
+)clear all
+
+--S 343 of 605
+t0:=(a/x^2)^(1/3)
+--E 343
+
+--S 344 of 605
+r0:=3*(a/x^2)^(1/3)*x
+--E 344
+
+--S 345 of 605
+d0:=normalize(t0-D(r0,x))
+--E 345
+
+)clear all
+
+--S 346 of 605
+t0:=(a/x^3)^(1/3)
+--E 346
+
+--S 347 of 605
+r0:=(a/x^3)^(1/3)*x*log(x)
+--E 347
+
+--S 348 of 605
+d0:=normalize(t0-D(r0,x))
+--E 348
+
+)clear all
+
+--S 349 of 605
+t0:=(a*x^n)^(2/3)
+--E 349
+
+--S 350 of 605
+r0:=3*x*(a*x^n)^(2/3)/(3+2*n)
+--E 350
+
+--S 351 of 605
+d0:=normalize(t0-D(r0,x))
+--E 351
+
+)clear all
+
+--S 352 of 605
+t0:=(a*x^3)^(2/3)
+--E 352
+
+--S 353 of 605
+r0:=1/3*x*(a*x^3)^(2/3)
+--E 353
+
+--S 354 of 605
+d0:=normalize(t0-D(r0,x))
+--E 354
+
+)clear all
+
+--S 355 of 605
+t0:=(a*x^2)^(2/3)
+--E 355
+
+--S 356 of 605
+r0:=3/7*x*(a*x^2)^(2/3)
+--E 356
+
+--S 357 of 605
+d0:=normalize(t0-D(r0,x))
+--E 357
+
+)clear all
+
+--S 358 of 605
+t0:=(a*x)^(2/3)
+--E 358
+
+--S 359 of 605
+r0:=3/5*(a*x)^(5/3)/a
+--E 359
+
+--S 360 of 605
+d0:=normalize(t0-D(r0,x))
+--E 360
+
+)clear all
+
+--S 361 of 605
+t0:=(a/x)^(2/3)
+--E 361
+
+--S 362 of 605
+r0:=3*(a/x)^(2/3)*x
+--E 362
+
+--S 363 of 605
+d0:=normalize(t0-D(r0,x))
+--E 363
+
+)clear all
+
+--S 364 of 605
+t0:=(a/x^2)^(2/3)
+--E 364
+
+--S 365 of 605
+r0:=-3*(a/x^2)^(2/3)*x
+--E 365
+
+--S 366 of 605
+d0:=normalize(t0-D(r0,x))
+--E 366
+
+)clear all
+
+--S 367 of 605
+t0:=(a/x^3)^(2/3)
+--E 367
+
+--S 368 of 605
+r0:=-(a/x^3)^(2/3)*x
+--E 368
+
+--S 369 of 605
+d0:=normalize(t0-D(r0,x))
+--E 369
+
+)clear all
+
+--S 370 of 605
+t0:=1/(a*x^n)^(1/3)
+--E 370
+
+--S 371 of 605
+r0:=3*x/((3-n)*(a*x^n)^(1/3))
+--E 371
+
+--S 372 of 605
+d0:=normalize(t0-D(r0,x))
+--E 372
+
+)clear all
+
+--S 373 of 605
+t0:=1/(a*x^3)^(1/3)
+--E 373
+
+--S 374 of 605
+r0:=x*log(x)/(a*x^3)^(1/3)
+--E 374
+
+--S 375 of 605
+d0:=normalize(t0-D(r0,x))
+--E 375
+
+)clear all
+
+--S 376 of 605
+t0:=1/(a*x^2)^(1/3)
+--E 376
+
+--S 377 of 605
+r0:=3*x/(a*x^2)^(1/3)
+--E 377
+
+--S 378 of 605
+d0:=normalize(t0-D(r0,x))
+--E 378
+
+)clear all
+
+--S 379 of 605
+t0:=1/(a*x)^(1/3)
+--E 379
+
+--S 380 of 605
+r0:=3/2*(a*x)^(2/3)/a
+--E 380
+
+--S 381 of 605
+d0:=normalize(t0-D(r0,x))
+--E 381
+
+)clear all
+
+--S 382 of 605
+t0:=1/(a/x)^(1/3)
+--E 382
+
+--S 383 of 605
+r0:=3/4*x/(a/x)^(1/3)
+--E 383
+
+--S 384 of 605
+d0:=normalize(t0-D(r0,x))
+--E 384
+
+)clear all
+
+--S 385 of 605
+t0:=1/(a/x^2)^(1/3)
+--E 385
+
+--S 386 of 605
+r0:=3/5*x/(a/x^2)^(1/3)
+--E 386
+
+--S 387 of 605
+d0:=normalize(t0-D(r0,x))
+--E 387
+
+)clear all
+
+--S 388 of 605
+t0:=1/(a/x^3)^(1/3)
+--E 388
+
+--S 389 of 605
+r0:=1/2*x/(a/x^3)^(1/3)
+--E 389
+
+--S 390 of 605
+d0:=normalize(t0-D(r0,x))
+--E 390
+
+)clear all
+
+--S 391 of 605
+t0:=1/(a*x^n)^(2/3)
+--E 391
+
+--S 392 of 605
+r0:=3*x/((3-2*n)*(a*x^n)^(2/3))
+--E 392
+
+--S 393 of 605
+d0:=normalize(t0-D(r0,x))
+--E 393
+
+)clear all
+
+--S 394 of 605
+t0:=1/(a*x^3)^(2/3)
+--E 394
+
+--S 395 of 605
+r0:=-x/(a*x^3)^(2/3)
+--E 395
+
+--S 396 of 605
+d0:=normalize(t0-D(r0,x))
+--E 396
+
+)clear all
+
+--S 397 of 605
+t0:=1/(a*x^2)^(2/3)
+--E 397
+
+--S 398 of 605
+r0:=-3*x/(a*x^2)^(2/3)
+--E 398
+
+--S 399 of 605
+d0:=normalize(t0-D(r0,x))
+--E 399
+
+)clear all
+
+--S 400 of 605
+t0:=1/(a*x)^(2/3)
+--E 400
+
+--S 401 of 605
+r0:=3*(a*x)^(1/3)/a
+--E 401
+
+--S 402 of 605
+d0:=normalize(t0-D(r0,x))
+--E 402
+
+)clear all
+
+--S 403 of 605
+t0:=1/(a/x)^(2/3)
+--E 403
+
+--S 404 of 605
+r0:=3/5*x/(a/x)^(2/3)
+--E 404
+
+--S 405 of 605
+d0:=normalize(t0-D(r0,x))
+--E 405
+
+)clear all
+
+--S 406 of 605
+t0:=1/(a/x^2)^(2/3)
+--E 406
+
+--S 407 of 605
+r0:=3/7*x/(a/x^2)^(2/3)
+--E 407
+
+--S 408 of 605
+d0:=normalize(t0-D(r0,x))
+--E 408
+
+)clear all
+
+--S 409 of 605
+t0:=1/(a/x^3)^(2/3)
+--E 409
+
+--S 410 of 605
+r0:=1/3*x/(a/x^3)^(2/3)
+--E 410
+
+--S 411 of 605
+d0:=normalize(t0-D(r0,x))
+--E 411
+
+)clear all
+
+--S 412 of 605
+t0:=x^m*(a*x^n)^p
+--E 412
+
+--S 413 of 605
+r0:=x^(1+m)*(a*x^n)^p/(1+m+n*p)
+--E 413
+
+--S 414 of 605
+d0:=normalize(t0-D(r0,x))
+--E 414
+
+)clear all
+
+--S 415 of 605
+t0:=x^m/(a*x^n)^((1+m)/n)
+--E 415
+
+--S 416 of 605
+r0:=x^(1+m)*log(x)/(a*x^n)^((1+m)/n)
+--E 416
+
+--S 417 of 605
+d0:=normalize(t0-D(r0,x))
+--E 417
+
+)clear all
+
+--S 418 of 605
+t0:=x^(-1-n*p)*(a*x^n)^p
+--E 418
+
+--S 419 of 605
+r0:=(a*x^n)^p*log(x)/x^(n*p)
+--E 419
+
+--S 420 of 605
+d0:=normalize(t0-D(r0,x))
+--E 420
+
+)clear all
+
+--S 421 of 605
+t0:=x^2*(a*x^n)^p
+--E 421
+
+--S 422 of 605
+r0:=x^3*(a*x^n)^p/(3+n*p)
+--E 422
+
+--S 423 of 605
+d0:=normalize(t0-D(r0,x))
+--E 423
+
+)clear all
+
+--S 424 of 605
+t0:=x*(a*x^n)^p
+--E 424
+
+--S 425 of 605
+r0:=x^2*(a*x^n)^p/(2+n*p)
+--E 425
+
+--S 426 of 605
+d0:=normalize(t0-D(r0,x))
+--E 426
+
+)clear all
+
+--S 427 of 605
+t0:=(a*x^n)^p
+--E 427
+
+--S 428 of 605
+r0:=x*(a*x^n)^p/(1+n*p)
+--E 428
+
+--S 429 of 605
+d0:=normalize(t0-D(r0,x))
+--E 429
+
+)clear all
+
+--S 430 of 605
+t0:=(a*x^n)^p/x
+--E 430
+
+--S 431 of 605
+r0:=(a*x^n)^p/(n*p)
+--E 431
+
+--S 432 of 605
+d0:=normalize(t0-D(r0,x))
+--E 432
+
+)clear all
+
+--S 433 of 605
+t0:=(a*x^n)^p/x^2
+--E 433
+
+--S 434 of 605
+r0:=-(a*x^n)^p/((1-n*p)*x)
+--E 434
+
+--S 435 of 605
+d0:=normalize(t0-D(r0,x))
+--E 435
+
+)clear all
+
+--S 436 of 605
+t0:=x^m/(a*x^n)^(1/n)
+--E 436
+
+--S 437 of 605
+r0:=x^(1+m)/(m*(a*x^n)^(1/n))
+--E 437
+
+--S 438 of 605
+d0:=normalize(t0-D(r0,x))
+--E 438
+
+)clear all
+
+--S 439 of 605
+t0:=x^2/(a*x^n)^(1/n)
+--E 439
+
+--S 440 of 605
+r0:=1/2*x^3/(a*x^n)^(1/n)
+--E 440
+
+--S 441 of 605
+d0:=normalize(t0-D(r0,x))
+--E 441
+
+)clear all
+
+--S 442 of 605
+t0:=x/(a*x^n)^(1/n)
+--E 442
+
+--S 443 of 605
+r0:=x^2/(a*x^n)^(1/n)
+--E 443
+
+--S 444 of 605
+d0:=normalize(t0-D(r0,x))
+--E 444
+
+)clear all
+
+--S 445 of 605
+t0:=1/(a*x^n)^(1/n)
+--E 445
+
+--S 446 of 605
+r0:=x*log(x)/(a*x^n)^(1/n)
+--E 446
+
+--S 447 of 605
+d0:=normalize(t0-D(r0,x))
+--E 447
+
+)clear all
+
+--S 448 of 605
+t0:=1/(x*(a*x^n)^(1/n))
+--E 448
+
+--S 449 of 605
+r0:=(-1)/(a*x^n)^(1/n)
+--E 449
+
+--S 450 of 605
+d0:=normalize(t0-D(r0,x))
+--E 450
+
+)clear all
+
+--S 451 of 605
+t0:=1/(x^2*(a*x^n)^(1/n))
+--E 451
+
+--S 452 of 605
+r0:=(-1/2)/(x*(a*x^n)^(1/n))
+--E 452
+
+--S 453 of 605
+d0:=normalize(t0-D(r0,x))
+--E 453
+
+)clear all
+
+--S 454 of 605
+t0:=(a+b*(c*x^n)^(1/n))^p
+--E 454
+
+--S 455 of 605
+r0:=x*(a+b*(c*x^n)^(1/n))^(1+p)/(b*(1+p)*(c*x^n)^(1/n))
+--E 455
+
+--S 456 of 605
+d0:=normalize(t0-D(r0,x))
+--E 456
+
+)clear all
+
+--S 457 of 605
+t0:=(a+b*(c*x^n)^(1/n))^3
+--E 457
+
+--S 458 of 605
+r0:=1/4*x*(a+b*(c*x^n)^(1/n))^4/(b*(c*x^n)^(1/n))
+--E 458
+
+--S 459 of 605
+d0:=normalize(t0-D(r0,x))
+--E 459
+
+)clear all
+
+--S 460 of 605
+t0:=(a+b*(c*x^n)^(1/n))^2
+--E 460
+
+--S 461 of 605
+r0:=1/3*x*(a+b*(c*x^n)^(1/n))^3/(b*(c*x^n)^(1/n))
+--E 461
+
+--S 462 of 605
+d0:=normalize(t0-D(r0,x))
+--E 462
+
+)clear all
+
+--S 463 of 605
+t0:=a+b*(c*x^n)^(1/n)
+--E 463
+
+--S 464 of 605
+r0:=a*x+1/2*b*x*(c*x^n)^(1/n)
+--E 464
+
+--S 465 of 605
+d0:=normalize(t0-D(r0,x))
+--E 465
+
+)clear all
+
+--S 466 of 605
+t0:=1/(a+b*(c*x^n)^(1/n))
+--E 466
+
+--S 467 of 605
+r0:=x*log(a+b*(c*x^n)^(1/n))/(b*(c*x^n)^(1/n))
+--E 467
+
+--S 468 of 605
+d0:=normalize(t0-D(r0,x))
+--E 468
+
+)clear all
+
+--S 469 of 605
+t0:=1/(a+b*(c*x^n)^(1/n))^2
+--E 469
+
+--S 470 of 605
+r0a:=x/(a^2+a*b*(c*x^n)^(1/n))
+--E 470
+
+--S 471 of 605
+r0b:=-x/(b*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n)))
+--E 471
+
+--S 472 of 605
+d0a:=normalize(t0-D(r0a,x))
+--E 472
+
+--S 473 of 605
+d0b:=normalize(t0-D(r0b,x))
+--E 473
+
+)clear all
+
+--S 474 of 605
+t0:=1/(a+b*(c*x^n)^(1/n))^3
+--E 474
+
+--S 475 of 605
+r0:=-1/2*x/(b*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^2)
+--E 475
+
+--S 476 of 605
+d0:=normalize(t0-D(r0,x))
+--E 476
+
+)clear all
+
+--S 477 of 605
+t0:=(a+b*(c*x^n)^(2/n))^3
+--E 477
+
+--S 478 of 605
+r0:=a^3*x+a^2*b*x*(c*x^n)^(2/n)+3/5*a*b^2*x*(c*x^n)^(4/n)+_
+   1/7*b^3*x*(c*x^n)^(6/n)
+--E 478
+
+--S 479 of 605
+d0:=normalize(t0-D(r0,x))
+--E 479
+
+)clear all
+
+--S 480 of 605
+t0:=(a+b*(c*x^n)^(2/n))^2
+--E 480
+
+--S 481 of 605
+r0:=a^2*x+2/3*a*b*x*(c*x^n)^(2/n)+1/5*b^2*x*(c*x^n)^(4/n)
+--E 481
+
+--S 482 of 605
+d0:=normalize(t0-D(r0,x))
+--E 482
+
+)clear all
+
+--S 483 of 605
+t0:=a+b*(c*x^n)^(2/n)
+--E 483
+
+--S 484 of 605
+r0:=a*x+1/3*b*x*(c*x^n)^(2/n)
+--E 484
+
+--S 485 of 605
+d0:=normalize(t0-D(r0,x))
+--E 485
+
+)clear all
+
+--S 486 of 605
+t0:=1/(a+b*(c*x^n)^(2/n))
+--E 486
+
+--S 487 of 605
+r0:=x*atan((c*x^n)^(1/n)*sqrt(b)/sqrt(a))/((c*x^n)^(1/n)*sqrt(a)*sqrt(b))
+--E 487
+
+--S 488 of 605
+d0:=t0-D(r0,x)
+--E 488
+
+)clear all
+
+--S 489 of 605
+t0:=1/(a+b*(c*x^n)^(2/n))^2
+--E 489
+
+--S 490 of 605
+r0:=1/2*x/(a*(a+b*(c*x^n)^(2/n)))+1/2*x*atan((c*x^n)^(1/n)*_
+   sqrt(b)/sqrt(a))/(a^(3/2)*(c*x^n)^(1/n)*sqrt(b))
+--E 490
+
+--S 491 of 605
+d0:=t0-D(r0,x)
+--E 491
+
+)clear all
+
+--S 492 of 605
+t0:=1/(a+b*(c*x^n)^(2/n))^3
+--E 492
+
+--S 493 of 605
+r0:=1/4*x/(a*(a+b*(c*x^n)^(2/n))^2)+3/8*x/(a^2*(a+b*(c*x^n)^(2/n)))+_
+   3/8*x*atan((c*x^n)^(1/n)*sqrt(b)/sqrt(a))/(a^(5/2)*(c*x^n)^(1/n)*sqrt(b))
+--E 493
+
+--S 494 of 605
+d0:=t0-D(r0,x)
+--E 494
+
+)clear all
+
+--S 495 of 605
+t0:=(a+b*(c*x^n)^(3/n))^3
+--E 495
+
+--S 496 of 605
+r0:=a^3*x+3/4*a^2*b*x*(c*x^n)^(3/n)+3/7*a*b^2*x*(c*x^n)^(6/n)+_
+   1/10*b^3*x*(c*x^n)^(9/n)
+--E 496
+
+--S 497 of 605
+d0:=normalize(t0-D(r0,x))
+--E 497
+
+)clear all
+
+--S 498 of 605
+t0:=(a+b*(c*x^n)^(3/n))^2
+--E 498
+
+--S 499 of 605
+r0:=a^2*x+1/2*a*b*x*(c*x^n)^(3/n)+1/7*b^2*x*(c*x^n)^(6/n)
+--E 499
+
+--S 500 of 605
+d0:=normalize(t0-D(r0,x))
+--E 500
+
+)clear all
+
+--S 501 of 605
+t0:=a+b*(c*x^n)^(3/n)
+--E 501
+
+--S 502 of 605
+r0:=a*x+1/4*b*x*(c*x^n)^(3/n)
+--E 502
+
+--S 503 of 605
+d0:=normalize(t0-D(r0,x))
+--E 503
+
+)clear all
+
+--S 504 of 605
+t0:=1/(a+b*(c*x^n)^(3/n))
+--E 504
+
+--S 505 of 605
+r0:=1/3*x*log(a^(1/3)+b^(1/3)*(c*x^n)^(1/n))/(a^(2/3)*b^(1/3)*(c*x^n)^(1/n))-_
+   1/6*x*log(a^(2/3)-a^(1/3)*b^(1/3)*(c*x^n)^(1/n)+b^(2/3)*(c*x^n)^(2/n))/_
+   (a^(2/3)*b^(1/3)*(c*x^n)^(1/n))-x*atan((a^(1/3)-2*b^(1/3)*_
+   (c*x^n)^(1/n))/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(1/3)*(c*x^n)^(1/n)*sqrt(3))
+--E 505
+
+--S 506 of 605
+d0:=normalize(t0-D(r0,x))
+--E 506
+
+)clear all
+
+--S 507 of 605
+t0:=1/(a+b*(c*x^n)^(3/n))^2
+--E 507
+
+--S 508 of 605
+r0:=1/3*x/(a*(a+b*(c*x^n)^(3/n)))+2/9*x*log(a^(1/3)+b^(1/3)*(c*x^n)^(1/n))/_
+   (a^(5/3)*b^(1/3)*(c*x^n)^(1/n))-1/9*x*log(a^(2/3)-a^(1/3)*b^(1/3)*_
+   (c*x^n)^(1/n)+b^(2/3)*(c*x^n)^(2/n))/(a^(5/3)*b^(1/3)*(c*x^n)^(1/n))-_
+   2/3*x*atan((a^(1/3)-2*b^(1/3)*(c*x^n)^(1/n))/(a^(1/3)*sqrt(3)))/_
+   (a^(5/3)*b^(1/3)*(c*x^n)^(1/n)*sqrt(3))
+--E 508
+
+--S 509 of 605
+d0:=normalize(t0-D(r0,x))
+--E 509
+
+)clear all
+
+--S 510 of 605
+t0:=1/(a+b*(c*x^n)^(3/n))^3
+--E 510
+
+--S 511 of 605
+r0:=1/6*x/(a*(a+b*(c*x^n)^(3/n))^2)+5/18*x/(a^2*(a+b*(c*x^n)^(3/n)))+_
+   5/27*x*log(a^(1/3)+b^(1/3)*(c*x^n)^(1/n))/(a^(8/3)*b^(1/3)*_
+   (c*x^n)^(1/n))-5/54*x*log(a^(2/3)-a^(1/3)*b^(1/3)*(c*x^n)^(1/n)+_
+   b^(2/3)*(c*x^n)^(2/n))/(a^(8/3)*b^(1/3)*(c*x^n)^(1/n))-5/9*x*_
+   atan((a^(1/3)-2*b^(1/3)*(c*x^n)^(1/n))/(a^(1/3)*sqrt(3)))/(a^(8/3)*_
+   b^(1/3)*(c*x^n)^(1/n)*sqrt(3))
+--E 511
+
+--S 512 of 605
+d0:=normalize(t0-D(r0,x))
+--E 512
+
+)clear all
+
+--S 513 of 605
+t0:=1/(1+(x^3)^(2/3))
+--E 513
+
+--S 514 of 605
+r0:=x*atan((x^3)^(1/3))/(x^3)^(1/3)
+--E 514
+
+--S 515 of 605
+d0:=normalize(t0-D(r0,x))
+--E 515
+
+)clear all
+
+--S 516 of 605
+t0:=1/(1+(x^2)^(3/2))
+--E 516
+
+--S 517 of 605
+r0:=-1/6*x*log(1+x^2-sqrt(x^2))/sqrt(x^2)+1/3*x*log(1+sqrt(x^2))/sqrt(x^2)-_
+   x*atan((1-2*sqrt(x^2))/sqrt(3))/(sqrt(3)*sqrt(x^2))
+--E 517
+
+--S 518 of 605
+d0:=normalize(t0-D(r0,x))
+--E 518
+
+)clear all
+
+--S 519 of 605
+t0:=1/(1+4*sqrt(x^4))
+--E 519
+
+--S 520 of 605
+r0:=1/2*x*atan(2*(x^4)^(1/4))/(x^4)^(1/4)
+--E 520
+
+--S 521 of 605
+d0:=normalize(t0-D(r0,x))
+--E 521
+
+)clear all
+
+--S 522 of 605
+t0:=1/(1-4*sqrt(x^4))
+--E 522
+
+--S 523 of 605
+r0:=1/2*x*atanh(2*(x^4)^(1/4))/(x^4)^(1/4)
+--E 523
+
+--S 524 of 605
+d0:=normalize(t0-D(r0,x))
+--E 524
+
+)clear all
+
+--S 525 of 605
+t0:=1/(1+4*(x^6)^(1/3))
+--E 525
+
+--S 526 of 605
+r0:=1/2*x*atan(2*(x^6)^(1/6))/(x^6)^(1/6)
+--E 526
+
+--S 527 of 605
+d0:=normalize(t0-D(r0,x))
+--E 527
+
+)clear all
+
+--S 528 of 605
+t0:=1/(1-4*(x^6)^(1/3))
+--E 528
+
+--S 529 of 605
+r0:=1/2*x*atanh(2*(x^6)^(1/6))/(x^6)^(1/6)
+--E 529
+
+--S 530 of 605
+d0:=normalize(t0-D(r0,x))
+--E 530
+
+)clear all
+
+--S 531 of 605
+t0:=1/(1+4*(x^(2*n))^(1/n))
+--E 531
+
+--S 532 of 605
+r0:=1/2*x*atan(2*(x^(2*n))^(1/2/n))/(x^(2*n))^(1/2/n)
+--E 532
+
+--S 533 of 605
+d0:=normalize(t0-D(r0,x))
+--E 533
+
+)clear all
+
+--S 534 of 605
+t0:=1/(1-4*(x^(2*n))^(1/n))
+--E 534
+
+--S 535 of 605
+r0:=1/2*x*atanh(2*(x^(2*n))^(1/2/n))/(x^(2*n))^(1/2/n)
+--E 535
+
+--S 536 of 605
+d0:=normalize(t0-D(r0,x))
+--E 536
+
+)clear all
+
+--S 537 of 605
+t0:=x^3/(a+b*(c*x^n)^(1/n))
+--E 537
+
+--S 538 of 605
+r0:=a^2*x^4/(b^3*(c*x^n)^(3/n))-1/2*a*x^4/(b^2*(c*x^n)^(2/n))+_
+   1/3*x^4/(b*(c*x^n)^(1/n))-a^3*x^4*log(a+b*(c*x^n)^(1/n))/(b^4*(c*x^n)^(4/n))
+--E 538
+
+--S 539 of 605
+d0:=normalize(t0-D(r0,x))
+--E 539
+
+)clear all
+
+--S 540 of 605
+t0:=x^2/(a+b*(c*x^n)^(1/n))
+--E 540
+
+--S 541 of 605
+r0:=-a*x^3/(b^2*(c*x^n)^(2/n))+1/2*x^3/(b*(c*x^n)^(1/n))+_
+   a^2*x^3*log(a+b*(c*x^n)^(1/n))/(b^3*(c*x^n)^(3/n))
+--E 541
+
+--S 542 of 605
+d0:=normalize(t0-D(r0,x))
+--E 542
+
+)clear all
+
+--S 543 of 605
+t0:=x/(a+b*(c*x^n)^(1/n))
+--E 543
+
+--S 544 of 605
+r0:=x^2/(b*(c*x^n)^(1/n))-a*x^2*log(a+b*(c*x^n)^(1/n))/(b^2*(c*x^n)^(2/n))
+--E 544
+
+--S 545 of 605
+d0:=normalize(t0-D(r0,x))
+--E 545
+
+)clear all
+
+--S 546 of 605
+t0:=1/(a+b*(c*x^n)^(1/n))
+--E 546
+
+--S 547 of 605
+r0:=x*log(a+b*(c*x^n)^(1/n))/(b*(c*x^n)^(1/n))
+--E 547
+
+--S 548 of 605
+d0:=normalize(t0-D(r0,x))
+--E 548
+
+)clear all
+
+--S 549 of 605
+t0:=1/(x*(a+b*(c*x^n)^(1/n)))
+--E 549
+
+--S 550 of 605
+r0:=log(x)/a-log(a+b*(c*x^n)^(1/n))/a
+--E 550
+
+--S 551 of 605
+d0:=normalize(t0-D(r0,x))
+--E 551
+
+)clear all
+
+--S 552 of 605
+t0:=1/(x^2*(a+b*(c*x^n)^(1/n)))
+--E 552
+
+--S 553 of 605
+r0:=(-1)/(a*x)-b*(c*x^n)^(1/n)*log(x)/(a^2*x)+b*(c*x^n)^(1/n)*_
+   log(a+b*(c*x^n)^(1/n))/(a^2*x)
+--E 553
+
+--S 554 of 605
+d0:=normalize(t0-D(r0,x))
+--E 554
+
+)clear all
+
+--S 555 of 605
+t0:=1/(x^3*(a+b*(c*x^n)^(1/n)))
+--E 555
+
+--S 556 of 605
+r0:=(-1/2)/(a*x^2)+b*(c*x^n)^(1/n)/(a^2*x^2)+b^2*(c*x^n)^(2/n)*log(x)/_
+   (a^3*x^2)-b^2*(c*x^n)^(2/n)*log(a+b*(c*x^n)^(1/n))/(a^3*x^2)
+--E 556
+
+--S 557 of 605
+d0:=normalize(t0-D(r0,x))
+--E 557
+
+)clear all
+
+--S 558 of 605
+t0:=x^3/(a+b*(c*x^n)^(1/n))^2
+--E 558
+
+--S 559 of 605
+r0:=-2*a*x^4/(b^3*(c*x^n)^(3/n))+1/2*x^4/(b^2*(c*x^n)^(2/n))+a^3*x^4/(b^4*_
+   (c*x^n)^(4/n)*(a+b*(c*x^n)^(1/n)))+3*a^2*x^4*log(a+b*(c*x^n)^(1/n))/_
+   (b^4*(c*x^n)^(4/n))
+--E 559
+
+--S 560 of 605
+d0:=normalize(t0-D(r0,x))
+--E 560
+
+)clear all
+
+--S 561 of 605
+t0:=x^2/(a+b*(c*x^n)^(1/n))^2
+--E 561
+
+--S 562 of 605
+r0:=x^3/(b^2*(c*x^n)^(2/n))-a^2*x^3/(b^3*(c*x^n)^(3/n)*(a+b*(c*x^n)^(1/n)))-_
+   2*a*x^3*log(a+b*(c*x^n)^(1/n))/(b^3*(c*x^n)^(3/n))
+--E 562
+
+--S 563 of 605
+d0:=normalize(t0-D(r0,x))
+--E 563
+
+)clear all
+
+--S 564 of 605
+t0:=x/(a+b*(c*x^n)^(1/n))^2
+--E 564
+
+--S 565 of 605
+r0:=a*x^2/(b^2*(c*x^n)^(2/n)*(a+b*(c*x^n)^(1/n)))+x^2*log(a+b*(c*x^n)^(1/n))/_
+   (b^2*(c*x^n)^(2/n))
+--E 565
+
+--S 566 of 605
+d0:=normalize(t0-D(r0,x))
+--E 566
+
+)clear all
+
+--S 567 of 605
+t0:=1/(a+b*(c*x^n)^(1/n))^2
+--E 567
+
+--S 568 of 605
+r0:=-x/(b*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n)))
+--E 568
+
+--S 569 of 605
+d0:=normalize(t0-D(r0,x))
+--E 569
+
+)clear all
+
+--S 570 of 605
+t0:=1/(x*(a+b*(c*x^n)^(1/n))^2)
+--E 570
+
+--S 571 of 605
+r0:=1/(a*(a+b*(c*x^n)^(1/n)))+log(x)/a^2-log(a+b*(c*x^n)^(1/n))/a^2
+--E 571
+
+--S 572 of 605
+d0:=normalize(t0-D(r0,x))
+--E 572
+
+)clear all
+
+--S 573 of 605
+t0:=1/(x^2*(a+b*(c*x^n)^(1/n))^2)
+--E 573
+
+--S 574 of 605
+r0:=(-1)/(a^2*x)-b*(c*x^n)^(1/n)/(a^2*x*(a+b*(c*x^n)^(1/n)))-_
+   2*b*(c*x^n)^(1/n)*log(x)/(a^3*x)+2*b*(c*x^n)^(1/n)*_
+   log(a+b*(c*x^n)^(1/n))/(a^3*x)
+--E 574
+
+--S 575 of 605
+d0:=normalize(t0-D(r0,x))
+--E 575
+
+)clear all
+
+--S 576 of 605
+t0:=1/(x^3*(a+b*(c*x^n)^(1/n))^2)
+--E 576
+
+--S 577 of 605
+r0:=(-1/2)/(a^2*x^2)+2*b*(c*x^n)^(1/n)/(a^3*x^2)+b^2*(c*x^n)^(2/n)/_
+   (a^3*x^2*(a+b*(c*x^n)^(1/n)))+3*b^2*(c*x^n)^(2/n)*log(x)/(a^4*x^2)-_
+   3*b^2*(c*x^n)^(2/n)*log(a+b*(c*x^n)^(1/n))/(a^4*x^2)
+--E 577
+
+--S 578 of 605
+d0:=normalize(t0-D(r0,x))
+--E 578
+
+)clear all
+
+--S 579 of 605
+t0:=x^3*(a+b*(c*x^n)^(1/n))^p
+--E 579
+
+--S 580 of 605
+r0:=-a^3*x^4*(a+b*(c*x^n)^(1/n))^(1+p)/(b^4*(1+p)*(c*x^n)^(4/n))+_
+   3*a^2*x^4*(a+b*(c*x^n)^(1/n))^(2+p)/(b^4*(2+p)*(c*x^n)^(4/n))-_
+   3*a*x^4*(a+b*(c*x^n)^(1/n))^(3+p)/(b^4*(3+p)*(c*x^n)^(4/n))+_
+   x^4*(a+b*(c*x^n)^(1/n))^(4+p)/(b^4*(4+p)*(c*x^n)^(4/n))
+--E 580
+
+--S 581 of 605
+d0:=normalize(t0-D(r0,x))
+--E 581
+
+)clear all
+
+--S 582 of 605
+t0:=x^2*(a+b*(c*x^n)^(1/n))^p
+--E 582
+
+--S 583 of 605
+r0:=a^2*x^3*(a+b*(c*x^n)^(1/n))^(1+p)/(b^3*(1+p)*(c*x^n)^(3/n))-_
+   2*a*x^3*(a+b*(c*x^n)^(1/n))^(2+p)/(b^3*(2+p)*(c*x^n)^(3/n))+_
+   x^3*(a+b*(c*x^n)^(1/n))^(3+p)/(b^3*(3+p)*(c*x^n)^(3/n))
+--E 583
+
+--S 584 of 605
+d0:=normalize(t0-D(r0,x))
+--E 584
+
+)clear all
+
+--S 585 of 605
+t0:=x*(a+b*(c*x^n)^(1/n))^p
+--E 585
+
+--S 586 of 605
+r0:=-a*x^2*(a+b*(c*x^n)^(1/n))^(1+p)/(b^2*(1+p)*(c*x^n)^(2/n))+_
+   x^2*(a+b*(c*x^n)^(1/n))^(2+p)/(b^2*(2+p)*(c*x^n)^(2/n))
+--E 586
+
+--S 587 of 605
+d0:=normalize(t0-D(r0,x))
+--E 587
+
+)clear all
+
+--S 588 of 605
+t0:=(a+b*(c*x^n)^(1/n))^p
+--E 588
+
+--S 589 of 605
+r0:=x*(a+b*(c*x^n)^(1/n))^(1+p)/(b*(1+p)*(c*x^n)^(1/n))
+--E 589
+
+--S 590 of 605
+d0:=normalize(t0-D(r0,x))
+--E 590
+
+)clear all
+
+--S 591 of 605
+t0:=(a+b*(c*x^n)^(1/n))^p/x
+--E 591
+
+--S 592 of 605
+--r0:=-(a+b*(c*x^n)^(1/n))^(1+p)*_
+-- hypergeometric(1,1+p,2+p,(a+b*(c*x^n)^(1/n))/a)/(a*(1+p))
+--E 592
+
+--S 593 of 605
+--d0:=normalize(t0-D(r0,x))
+--E 593
+
+)clear all
+
+--S 594 of 605
+t0:=x/(1+(x^n)^(1/n))^2
+--E 594
+
+--S 595 of 605
+r0:=x^2/((x^n)^(2/n)*(1+(x^n)^(1/n)))+x^2*log(1+(x^n)^(1/n))/(x^n)^(2/n)
+--E 595
+
+--S 596 of 605
+d0:=normalize(t0-D(r0,x))
+--E 596
+
+)clear all
+
+--S 597 of 605
+t0:=x^m*(a*(b*x^n)^p)^q
+--E 597
+
+--S 598 of 605
+r0:=x^(1+m)*(a*(b*x^n)^p)^q/(1+m+n*p*q)
+--E 598
+
+--S 599 of 605
+d0:=normalize(t0-D(r0,x))
+--E 599
+
+)clear all
+
+--S 600 of 605
+t0:=x^2*(a*(b*x^n)^p)^q
+--E 600
+
+--S 601 of 605
+r0:=x^3*(a*(b*x^n)^p)^q/(3+n*p*q)
+--E 601
+
+--S 602 of 605
+d0:=normalize(t0-D(r0,x))
+--E 602
+
+)clear all
+
+--S 603 of 605
+t0:=x*(a*(b*x^n)^p)^q
+--E 603
+
+--S 604 of 605
+r0:=x^2*(a*(b*x^n)^p)^q/(2+n*p*q)
+--E 604
+
+--S 605 of 605
+d0:=normalize(t0-D(r0,x))
+--E 605
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder22b.input.pamphlet b/src/input/richder22b.input.pamphlet
new file mode 100644
index 0000000..c77e584
--- /dev/null
+++ b/src/input/richder22b.input.pamphlet
@@ -0,0 +1,6988 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder22b.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Algebraic function problems.input
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder22b.output
+)spool richder22b.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 600
+t0:=(a*(b*x^n)^p)^q
+--R 
+--R
+--R               n p q
+--R   (1)  (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 600
+r0:=x*(a*(b*x^n)^p)^q/(1+n*p*q)
+--R 
+--R
+--R                 n p q
+--R        x (a (b x ) )
+--R   (2)  --------------
+--R           n p q + 1
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 600
+t0:=(a*(b*x^n)^p)^q/x
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (1)  ------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 600
+r0:=(a*(b*x^n)^p)^q/(n*p*q)
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (2)  ------------
+--R            n p q
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 600
+t0:=(a*(b*x^n)^p)^q/x^2
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (1)  ------------
+--R              2
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 600
+r0:=-(a*(b*x^n)^p)^q/((1-n*p*q)*x)
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (2)  ------------
+--R        (n p q - 1)x
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 600
+t0:=(a*(b*x^n)^p)^q/x^3
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (1)  ------------
+--R              3
+--R             x
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 600
+r0:=-(a*(b*x^n)^p)^q/((2-n*p*q)*x^2)
+--R 
+--R
+--R                n p q
+--R         (a (b x ) )
+--R   (2)  -------------
+--R                    2
+--R        (n p q - 2)x
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 600
+t0:=x^2/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R                    1
+--R                   ---
+--R               m n m n
+--R        (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 600
+r0:=1/2*x^3/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R                3
+--R               x
+--R   (2)  ---------------
+--R                     1
+--R                    ---
+--R                m n m n
+--R        2(a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 600
+t0:=x/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R                    1
+--R                   ---
+--R               m n m n
+--R        (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 600
+r0:=x^2/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R               2
+--R              x
+--R   (2)  --------------
+--R                    1
+--R                   ---
+--R               m n m n
+--R        (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 600
+t0:=1/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R                    1
+--R                   ---
+--R               m n m n
+--R        (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 600
+r0:=x*log(x)/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R           x log(x)
+--R   (2)  --------------
+--R                    1
+--R                   ---
+--R               m n m n
+--R        (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 600
+t0:=1/(x*(a*(b*x^m)^n)^(1/(m*n)))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R                      1
+--R                     ---
+--R                 m n m n
+--R        x (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 600
+r0:=(-1)/(a*(b*x^m)^n)^(1/(m*n))
+--R 
+--R
+--R                 1
+--R   (2)  - --------------
+--R                      1
+--R                     ---
+--R                 m n m n
+--R          (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 600
+t0:=1/(x^2*(a*(b*x^m)^n)^(1/(m*n)))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R                      1
+--R                     ---
+--R         2       m n m n
+--R        x (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 600
+r0:=(-1/2)/(x*(a*(b*x^m)^n)^(1/(m*n)))
+--R 
+--R
+--R                  1
+--R   (2)  - -----------------
+--R                         1
+--R                        ---
+--R                    m n m n
+--R          2x (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 600
+t0:=x^(2-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q + 2       n p q
+--R   (1)  x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 600
+r0:=1/3*x^(3-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q + 3       n p q
+--R        x           (a (b x ) )
+--R   (2)  ------------------------
+--R                    3
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 600
+t0:=x^(1-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q + 1       n p q
+--R   (1)  x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 600
+r0:=1/2*x^(2-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q + 2       n p q
+--R        x           (a (b x ) )
+--R   (2)  ------------------------
+--R                    2
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 600
+t0:=(a*(b*x^n)^p)^q/x^(n*p*q)
+--R 
+--R
+--R               n p q
+--R        (a (b x ) )
+--R   (1)  ------------
+--R            n p q
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 600
+r0:=x^(1-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q + 1       n p q
+--R   (2)  x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 600
+t0:=x^(-1-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q - 1       n p q
+--R   (1)  x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 600
+r0:=(a*(b*x^n)^p)^q*log(x)/x^(n*p*q)
+--R 
+--R
+--R                     n p q
+--R        log(x)(a (b x ) )
+--R   (2)  ------------------
+--R               n p q
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 600
+t0:=x^(-2-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R         - n p q - 2       n p q
+--R   (1)  x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 600
+r0:=-x^(-1-n*p*q)*(a*(b*x^n)^p)^q
+--R 
+--R
+--R           - n p q - 1       n p q
+--R   (2)  - x           (a (b x ) )
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 600
+t0:=x^2*(a+b*x)^n*sqrt(c*x^2)
+--R 
+--R
+--R                     +----+
+--R         2         n |   2
+--R   (1)  x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 600
+r0:=-a^3*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^4*(1+n)*x)+3*a^2*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^4*(2+n)*x)-3*a*(a+b*x)^(3+n)*sqrt(c*x^2)/(b^4*(3+n)*x)+_
+   (a+b*x)^(4+n)*sqrt(c*x^2)/(b^4*(4+n)*x)
+--R 
+--R
+--R   (2)
+--R           3     2                    n + 4
+--R         (n  + 6n  + 11n + 6)(b x + a)
+--R       + 
+--R                3        2                        n + 3
+--R         (- 3a n  - 21a n  - 42a n - 24a)(b x + a)
+--R       + 
+--R            2 3      2 2      2       2          n + 2
+--R         (3a n  + 24a n  + 57a n + 36a )(b x + a)
+--R       + 
+--R             3 3     3 2      3       3          n + 1
+--R         (- a n  - 9a n  - 26a n - 24a )(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       4 4      4 3      4 2      4       4
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )x
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 600
+t0:=x*(a+b*x)^n*sqrt(c*x^2)
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R   (1)  x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 600
+r0:=a^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^3*(1+n)*x)-2*a*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^3*(2+n)*x)+(a+b*x)^(3+n)*sqrt(c*x^2)/(b^3*(3+n)*x)
+--R 
+--R
+--R   (2)
+--R           2                   n + 3          2                      n + 2
+--R         (n  + 3n + 2)(b x + a)      + (- 2a n  - 8a n - 6a)(b x + a)
+--R       + 
+--R           2 2     2      2          n + 1
+--R         (a n  + 5a n + 6a )(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       3 3     3 2      3      3
+--R     (b n  + 6b n  + 11b n + 6b )x
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 600
+t0:=(a+b*x)^n*sqrt(c*x^2)
+--R 
+--R
+--R                   +----+
+--R                 n |   2
+--R   (1)  (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 600
+r0:=-a*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^2*(1+n)*x)+(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^2*(2+n)*x)
+--R 
+--R
+--R                                                             +----+
+--R                         n + 2                        n + 1  |   2
+--R        ((n + 1)(b x + a)      + (- a n - 2a)(b x + a)     )\|c x
+--R   (2)  -----------------------------------------------------------
+--R                              2 2     2      2
+--R                            (b n  + 3b n + 2b )x
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 600
+t0:=(a+b*x)^n*sqrt(c*x^2)/x
+--R 
+--R
+--R                   +----+
+--R                 n |   2
+--R        (b x + a) \|c x
+--R   (1)  -----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 600
+r0:=(a+b*x)^(1+n)*sqrt(c*x^2)/(b*(1+n)*x)
+--R 
+--R
+--R                       +----+
+--R                 n + 1 |   2
+--R        (b x + a)     \|c x
+--R   (2)  ---------------------
+--R              (b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 600
+t0:=(a+b*x)^n*sqrt(c*x^2)/x^2
+--R 
+--R
+--R                   +----+
+--R                 n |   2
+--R        (b x + a) \|c x
+--R   (1)  -----------------
+--R                 2
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 600
+--r0:=-(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a*(1+n)*x)
+--E 56
+
+--S 57 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 57
+
+)clear all
+
+--S 58 of 600
+t0:=(a+b*x)^n*sqrt(c*x^2)/x^3
+--R 
+--R
+--R                   +----+
+--R                 n |   2
+--R        (b x + a) \|c x
+--R   (1)  -----------------
+--R                 3
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 600
+--r0:=-(a+b*x)^(1+n)*sqrt(c*x^2)/(a*x^2)-b*n*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a^2*(1+n)*x)
+--E 59
+
+--S 60 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 60
+
+)clear all
+
+--S 61 of 600
+t0:=(a+b*x)^n*sqrt(c*x^2)/x^4
+--R 
+--R
+--R                   +----+
+--R                 n |   2
+--R        (b x + a) \|c x
+--R   (1)  -----------------
+--R                 4
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 600
+--r0:=-1/2*(a+b*x)^(1+n)*sqrt(c*x^2)/(a*x^3)+1/2*b*(1-n)*(a+b*x)^(1+n)*_
+--   sqrt(c*x^2)/(a^2*x^2)+1/2*b^2*(1-n)*n*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a^3*(1+n)*x)
+--E 62
+
+--S 63 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 63
+
+)clear all
+
+--S 64 of 600
+t0:=x*(c*x^2)^(3/2)*(a+b*x)^n
+--R 
+--R
+--R                       +----+
+--R           3         n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 600
+r0:=a^4*c*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^5*(1+n)*x)-4*a^3*c*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^5*(2+n)*x)+6*a^2*c*(a+b*x)^(3+n)*sqrt(c*x^2)/(b^5*_
+   (3+n)*x)-4*a*c*(a+b*x)^(4+n)*sqrt(c*x^2)/(b^5*(4+n)*x)+_
+   c*(a+b*x)^(5+n)*sqrt(c*x^2)/(b^5*(5+n)*x)
+--R 
+--R
+--R   (2)
+--R             4        3        2                        n + 5
+--R         (c n  + 10c n  + 35c n  + 50c n + 24c)(b x + a)
+--R       + 
+--R                  4          3           2                              n + 4
+--R         (- 4a c n  - 44a c n  - 164a c n  - 244a c n - 120a c)(b x + a)
+--R       + 
+--R            2   4      2   3       2   2       2          2           n + 3
+--R         (6a c n  + 72a c n  + 294a c n  + 468a c n + 240a c)(b x + a)
+--R       + 
+--R              3   4      3   3       3   2       3          3           n + 2
+--R         (- 4a c n  - 52a c n  - 236a c n  - 428a c n - 240a c)(b x + a)
+--R       + 
+--R           4   4      4   3      4   2       4          4           n + 1
+--R         (a c n  + 14a c n  + 71a c n  + 154a c n + 120a c)(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       5 5      5 4      5 3       5 2       5        5
+--R     (b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b )x
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^n
+--R 
+--R
+--R                       +----+
+--R           2         n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 600
+r0:=-a^3*c*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^4*(1+n)*x)+3*a^2*c*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^4*(2+n)*x)-3*a*c*(a+b*x)^(3+n)*sqrt(c*x^2)/(b^4*(3+n)*x)+_
+   c*(a+b*x)^(4+n)*sqrt(c*x^2)/(b^4*(4+n)*x)
+--R 
+--R
+--R   (2)
+--R             3       2                       n + 4
+--R         (c n  + 6c n  + 11c n + 6c)(b x + a)
+--R       + 
+--R                  3          2                            n + 3
+--R         (- 3a c n  - 21a c n  - 42a c n - 24a c)(b x + a)
+--R       + 
+--R            2   3      2   2      2         2           n + 2
+--R         (3a c n  + 24a c n  + 57a c n + 36a c)(b x + a)
+--R       + 
+--R             3   3     3   2      3         3           n + 1
+--R         (- a c n  - 9a c n  - 26a c n - 24a c)(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       4 4      4 3      4 2      4       4
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )x
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x
+--R 
+--R
+--R                       +----+
+--R                     n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 600
+r0:=a^2*c*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^3*(1+n)*x)-2*a*c*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^3*(2+n)*x)+c*(a+b*x)^(3+n)*sqrt(c*x^2)/(b^3*(3+n)*x)
+--R 
+--R
+--R   (2)
+--R             2                      n + 3
+--R         (c n  + 3c n + 2c)(b x + a)
+--R       + 
+--R                  2                          n + 2
+--R         (- 2a c n  - 8a c n - 6a c)(b x + a)
+--R       + 
+--R           2   2     2        2           n + 1
+--R         (a c n  + 5a c n + 6a c)(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       3 3     3 2      3      3
+--R     (b n  + 6b n  + 11b n + 6b )x
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x^2
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R   (1)  c (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 600
+r0:=-a*c*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^2*(1+n)*x)+c*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^2*(2+n)*x)
+--R 
+--R
+--R                                                                   +----+
+--R                           n + 2                            n + 1  |   2
+--R        ((c n + c)(b x + a)      + (- a c n - 2a c)(b x + a)     )\|c x
+--R   (2)  -----------------------------------------------------------------
+--R                                 2 2     2      2
+--R                               (b n  + 3b n + 2b )x
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x^3
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 600
+r0:=c*(a+b*x)^(1+n)*sqrt(c*x^2)/(b*(1+n)*x)
+--R 
+--R
+--R                         +----+
+--R                   n + 1 |   2
+--R        c (b x + a)     \|c x
+--R   (2)  -----------------------
+--R               (b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x^4
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 600
+--r0:=-c*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a*(1+n)*x)
+--E 80
+
+--S 81 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 81
+
+)clear all
+
+--S 82 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x^5
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 600
+--r0:=-c*(a+b*x)^(1+n)*sqrt(c*x^2)/(a*x^2)-b*c*n*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a^2*(1+n)*x)
+--E 83
+
+--S 84 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 84
+
+)clear all
+
+--S 85 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^n/x^6
+--R 
+--R
+--R                     +----+
+--R                   n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                  4
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 600
+--r0:=-1/2*c*(a+b*x)^(1+n)*sqrt(c*x^2)/(a*x^3)+1/2*b*c*(1-n)*(a+b*x)^(1+n)*_
+--   sqrt(c*x^2)/(a^2*x^2)+1/2*b^2*c*(1-n)*n*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a^3*(1+n)*x)
+--E 86
+
+--S 87 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 87
+
+)clear all
+
+--S 88 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^n
+--R 
+--R
+--R                       +----+
+--R         2 4         n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 600
+r0:=-a^5*c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^6*(1+n)*x)+5*a^4*c^2*_
+   (a+b*x)^(2+n)*sqrt(c*x^2)/(b^6*(2+n)*x)-10*a^3*c^2*(a+b*x)^(3+n)*_
+   sqrt(c*x^2)/(b^6*(3+n)*x)+10*a^2*c^2*(a+b*x)^(4+n)*sqrt(c*x^2)/_
+   (b^6*(4+n)*x)-5*a*c^2*(a+b*x)^(5+n)*sqrt(c*x^2)/(b^6*(5+n)*x)+_
+   c^2*(a+b*x)^(6+n)*sqrt(c*x^2)/(b^6*(6+n)*x)
+--R 
+--R
+--R   (2)
+--R           2 5      2 4      2 3       2 2       2        2          n + 6
+--R         (c n  + 15c n  + 85c n  + 225c n  + 274c n + 120c )(b x + a)
+--R       + 
+--R                  2 5        2 4         2 3          2 2          2          2
+--R           (- 5a c n  - 80a c n  - 475a c n  - 1300a c n  - 1620a c n - 720a c )
+--R        *
+--R                    n + 5
+--R           (b x + a)
+--R       + 
+--R                  2 2 5       2 2 4        2 2 3        2 2 2        2 2
+--R               10a c n  + 170a c n  + 1070a c n  + 3070a c n  + 3960a c n
+--R             + 
+--R                    2 2
+--R               1800a c
+--R        *
+--R                    n + 4
+--R           (b x + a)
+--R       + 
+--R                  3 2 5       3 2 4        3 2 3        3 2 2        3 2
+--R             - 10a c n  - 180a c n  - 1210a c n  - 3720a c n  - 5080a c n
+--R           + 
+--R                    3 2
+--R             - 2400a c
+--R        *
+--R                    n + 3
+--R           (b x + a)
+--R       + 
+--R              4 2 5      4 2 4       4 2 3        4 2 2        4 2         4 2
+--R           (5a c n  + 95a c n  + 685a c n  + 2305a c n  + 3510a c n + 1800a c )
+--R        *
+--R                    n + 2
+--R           (b x + a)
+--R       + 
+--R               5 2 5      5 2 4       5 2 3       5 2 2        5 2        5 2
+--R           (- a c n  - 20a c n  - 155a c n  - 580a c n  - 1044a c n - 720a c )
+--R        *
+--R                    n + 1
+--R           (b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       6 6      6 5       6 4       6 3        6 2        6        6
+--R     (b n  + 21b n  + 175b n  + 735b n  + 1624b n  + 1764b n + 720b )x
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x
+--R 
+--R
+--R                       +----+
+--R         2 3         n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 600
+r0:=a^4*c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^5*(1+n)*x)-4*a^3*c^2*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^5*(2+n)*x)+6*a^2*c^2*(a+b*x)^(3+n)*sqrt(c*x^2)/_
+   (b^5*(3+n)*x)-4*a*c^2*(a+b*x)^(4+n)*sqrt(c*x^2)/(b^5*(4+n)*x)+_
+   c^2*(a+b*x)^(5+n)*sqrt(c*x^2)/(b^5*(5+n)*x)
+--R 
+--R
+--R   (2)
+--R           2 4      2 3      2 2      2       2          n + 5
+--R         (c n  + 10c n  + 35c n  + 50c n + 24c )(b x + a)
+--R       + 
+--R                2 4        2 3         2 2         2          2          n + 4
+--R         (- 4a c n  - 44a c n  - 164a c n  - 244a c n - 120a c )(b x + a)
+--R       + 
+--R            2 2 4      2 2 3       2 2 2       2 2        2 2          n + 3
+--R         (6a c n  + 72a c n  + 294a c n  + 468a c n + 240a c )(b x + a)
+--R       + 
+--R              3 2 4      3 2 3       3 2 2       3 2        3 2          n + 2
+--R         (- 4a c n  - 52a c n  - 236a c n  - 428a c n - 240a c )(b x + a)
+--R       + 
+--R           4 2 4      4 2 3      4 2 2       4 2        4 2          n + 1
+--R         (a c n  + 14a c n  + 71a c n  + 154a c n + 120a c )(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       5 5      5 4      5 3       5 2       5        5
+--R     (b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b )x
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^2
+--R 
+--R
+--R                       +----+
+--R         2 2         n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 600
+r0:=-a^3*c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^4*(1+n)*x)+3*a^2*c^2*_
+   (a+b*x)^(2+n)*sqrt(c*x^2)/(b^4*(2+n)*x)-3*a*c^2*(a+b*x)^(3+n)*_
+   sqrt(c*x^2)/(b^4*(3+n)*x)+c^2*(a+b*x)^(4+n)*sqrt(c*x^2)/(b^4*(4+n)*x)
+--R 
+--R
+--R   (2)
+--R           2 3     2 2      2      2          n + 4
+--R         (c n  + 6c n  + 11c n + 6c )(b x + a)
+--R       + 
+--R                2 3        2 2        2         2          n + 3
+--R         (- 3a c n  - 21a c n  - 42a c n - 24a c )(b x + a)
+--R       + 
+--R            2 2 3      2 2 2      2 2       2 2          n + 2
+--R         (3a c n  + 24a c n  + 57a c n + 36a c )(b x + a)
+--R       + 
+--R             3 2 3     3 2 2      3 2       3 2          n + 1
+--R         (- a c n  - 9a c n  - 26a c n - 24a c )(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       4 4      4 3      4 2      4       4
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )x
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^3
+--R 
+--R
+--R                       +----+
+--R         2           n |   2
+--R   (1)  c x (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 600
+r0:=a^2*c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^3*(1+n)*x)-2*a*c^2*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^3*(2+n)*x)+c^2*(a+b*x)^(3+n)*sqrt(c*x^2)/(b^3*(3+n)*x)
+--R 
+--R
+--R   (2)
+--R           2 2     2      2          n + 3
+--R         (c n  + 3c n + 2c )(b x + a)
+--R       + 
+--R                2 2       2        2          n + 2
+--R         (- 2a c n  - 8a c n - 6a c )(b x + a)
+--R       + 
+--R           2 2 2     2 2      2 2          n + 1
+--R         (a c n  + 5a c n + 6a c )(b x + a)
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       3 3     3 2      3      3
+--R     (b n  + 6b n  + 11b n + 6b )x
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^4
+--R 
+--R
+--R                     +----+
+--R         2         n |   2
+--R   (1)  c (b x + a) \|c x
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 600
+r0:=-a*c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b^2*(1+n)*x)+c^2*(a+b*x)^(2+n)*_
+   sqrt(c*x^2)/(b^2*(2+n)*x)
+--R 
+--R
+--R                                                                     +----+
+--R           2     2          n + 2         2        2          n + 1  |   2
+--R        ((c n + c )(b x + a)      + (- a c n - 2a c )(b x + a)     )\|c x
+--R   (2)  -------------------------------------------------------------------
+--R                                  2 2     2      2
+--R                                (b n  + 3b n + 2b )x
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^5
+--R 
+--R
+--R                     +----+
+--R         2         n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 600
+r0:=c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(b*(1+n)*x)
+--R 
+--R
+--R                         +----+
+--R         2         n + 1 |   2
+--R        c (b x + a)     \|c x
+--R   (2)  -----------------------
+--R               (b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^6
+--R 
+--R
+--R                     +----+
+--R         2         n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 600
+--r0:=-c^2*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a*(1+n)*x)
+--E 107
+
+--S 108 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 108
+
+)clear all
+
+--S 109 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^n/x^7
+--R 
+--R
+--R                     +----+
+--R         2         n |   2
+--R        c (b x + a) \|c x
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 600
+--r0:=-c^2*(a+b*x)^(1+n)*sqrt(c*x^2)/(a*x^2)-b*c^2*n*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)*sqrt(c*x^2)/(a^2*(1+n)*x)
+--E 110
+
+--S 111 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 111
+
+)clear all
+
+--S 112 of 600
+t0:=x^4*(a+b*x)^n/sqrt(c*x^2)
+--R 
+--R
+--R         4         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R           \|c x
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 600
+r0:=-a^3*x*(a+b*x)^(1+n)/(b^4*(1+n)*sqrt(c*x^2))+3*a^2*x*(a+b*x)^(2+n)/_
+   (b^4*(2+n)*sqrt(c*x^2))-3*a*x*(a+b*x)^(3+n)/(b^4*(3+n)*sqrt(c*x^2))+_
+   x*(a+b*x)^(4+n)/(b^4*(4+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         3     2                      n + 4
+--R       (n  + 6n  + 11n + 6)x (b x + a)
+--R     + 
+--R              3        2                          n + 3
+--R       (- 3a n  - 21a n  - 42a n - 24a)x (b x + a)
+--R     + 
+--R          2 3      2 2      2       2            n + 2
+--R       (3a n  + 24a n  + 57a n + 36a )x (b x + a)
+--R     + 
+--R           3 3     3 2      3       3            n + 1
+--R       (- a n  - 9a n  - 26a n - 24a )x (b x + a)
+--R  /
+--R                                             +----+
+--R       4 4      4 3      4 2      4       4  |   2
+--R     (b n  + 10b n  + 35b n  + 50b n + 24b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 600
+t0:=x^3*(a+b*x)^n/sqrt(c*x^2)
+--R 
+--R
+--R         3         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R           \|c x
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 600
+r0:=a^2*x*(a+b*x)^(1+n)/(b^3*(1+n)*sqrt(c*x^2))-2*a*x*(a+b*x)^(2+n)/_
+   (b^3*(2+n)*sqrt(c*x^2))+x*(a+b*x)^(3+n)/(b^3*(3+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         2                     n + 3          2                        n + 2
+--R       (n  + 3n + 2)x (b x + a)      + (- 2a n  - 8a n - 6a)x (b x + a)
+--R     + 
+--R         2 2     2      2            n + 1
+--R       (a n  + 5a n + 6a )x (b x + a)
+--R  /
+--R                                  +----+
+--R       3 3     3 2      3      3  |   2
+--R     (b n  + 6b n  + 11b n + 6b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 600
+t0:=x^2*(a+b*x)^n/sqrt(c*x^2)
+--R 
+--R
+--R         2         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R           \|c x
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 600
+r0:=-a*x*(a+b*x)^(1+n)/(b^2*(1+n)*sqrt(c*x^2))+x*(a+b*x)^(2+n)/_
+   (b^2*(2+n)*sqrt(c*x^2))
+--R 
+--R
+--R                          n + 2                          n + 1
+--R        (n + 1)x (b x + a)      + (- a n - 2a)x (b x + a)
+--R   (2)  ------------------------------------------------------
+--R                                          +----+
+--R                        2 2     2      2  |   2
+--R                      (b n  + 3b n + 2b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 600
+t0:=x*(a+b*x)^n/sqrt(c*x^2)
+--R 
+--R
+--R                   n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R           \|c x
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 600
+r0:=x*(a+b*x)^(1+n)/(b*(1+n)*sqrt(c*x^2))
+--R 
+--R
+--R                   n + 1
+--R        x (b x + a)
+--R   (2)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b n + b)\|c x
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 600
+t0:=(a+b*x)^n/sqrt(c*x^2)
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R           +----+
+--R           |   2
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 600
+--r0:=-x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*(1+n)*sqrt(c*x^2))
+--E 125
+
+--S 126 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 126
+
+)clear all
+
+--S 127 of 600
+t0:=(a+b*x)^n/(x*sqrt(c*x^2))
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R           +----+
+--R           |   2
+--R         x\|c x
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 600
+--r0:=-(a+b*x)^(1+n)/(a*sqrt(c*x^2))-b*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^2*(1+n)*sqrt(c*x^2))
+--E 128
+
+--S 129 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 129
+
+)clear all
+
+--S 130 of 600
+t0:=(a+b*x)^n/(x^2*sqrt(c*x^2))
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R            +----+
+--R          2 |   2
+--R         x \|c x
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 600
+--r0:=1/2*b*(1-n)*(a+b*x)^(1+n)/(a^2*sqrt(c*x^2))-1/2*(a+b*x)^(1+n)/_
+--   (a*x*sqrt(c*x^2))+1/2*b^2*(1-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^3*(1+n)*sqrt(c*x^2))
+--E 131
+
+--S 132 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 132
+
+)clear all
+
+--S 133 of 600
+t0:=(a+b*x)^n/(x^3*sqrt(c*x^2))
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R            +----+
+--R          3 |   2
+--R         x \|c x
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 600
+--r0:=-1/6*b^2*(1-n)*(2-n)*(a+b*x)^(1+n)/(a^3*sqrt(c*x^2))-_
+--   1/3*(a+b*x)^(1+n)/(a*x^2*sqrt(c*x^2))+1/6*b*(2-n)*(a+b*x)^(1+n)/_
+--   (a^2*x*sqrt(c*x^2))-1/6*b^3*(1-n)*(2-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^4*(1+n)*sqrt(c*x^2))
+--E 134
+
+--S 135 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 135
+
+)clear all
+
+--S 136 of 600
+t0:=x^6*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R         4         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 600
+r0:=-a^3*x*(a+b*x)^(1+n)/(b^4*c*(1+n)*sqrt(c*x^2))+3*a^2*x*(a+b*x)^(2+n)/_
+   (b^4*c*(2+n)*sqrt(c*x^2))-3*a*x*(a+b*x)^(3+n)/(b^4*c*(3+n)*sqrt(c*x^2))+_
+   x*(a+b*x)^(4+n)/(b^4*c*(4+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         3     2                      n + 4
+--R       (n  + 6n  + 11n + 6)x (b x + a)
+--R     + 
+--R              3        2                          n + 3
+--R       (- 3a n  - 21a n  - 42a n - 24a)x (b x + a)
+--R     + 
+--R          2 3      2 2      2       2            n + 2
+--R       (3a n  + 24a n  + 57a n + 36a )x (b x + a)
+--R     + 
+--R           3 3     3 2      3       3            n + 1
+--R       (- a n  - 9a n  - 26a n - 24a )x (b x + a)
+--R  /
+--R                                                      +----+
+--R       4   4      4   3      4   2      4         4   |   2
+--R     (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 600
+t0:=x^5*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R         3         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 600
+r0:=a^2*x*(a+b*x)^(1+n)/(b^3*c*(1+n)*sqrt(c*x^2))-2*a*x*(a+b*x)^(2+n)/_
+   (b^3*c*(2+n)*sqrt(c*x^2))+x*(a+b*x)^(3+n)/(b^3*c*(3+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         2                     n + 3          2                        n + 2
+--R       (n  + 3n + 2)x (b x + a)      + (- 2a n  - 8a n - 6a)x (b x + a)
+--R     + 
+--R         2 2     2      2            n + 1
+--R       (a n  + 5a n + 6a )x (b x + a)
+--R  /
+--R                                         +----+
+--R       3   3     3   2      3        3   |   2
+--R     (b c n  + 6b c n  + 11b c n + 6b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 600
+t0:=x^4*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R         2         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 600
+r0:=-a*x*(a+b*x)^(1+n)/(b^2*c*(1+n)*sqrt(c*x^2))+x*(a+b*x)^(2+n)/_
+   (b^2*c*(2+n)*sqrt(c*x^2))
+--R 
+--R
+--R                          n + 2                          n + 1
+--R        (n + 1)x (b x + a)      + (- a n - 2a)x (b x + a)
+--R   (2)  ------------------------------------------------------
+--R                                             +----+
+--R                      2   2     2        2   |   2
+--R                    (b c n  + 3b c n + 2b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 600
+t0:=x^3*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R                   n
+--R        x (b x + a)
+--R   (1)  ------------
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 600
+r0:=x*(a+b*x)^(1+n)/(b*c*(1+n)*sqrt(c*x^2))
+--R 
+--R
+--R                     n + 1
+--R          x (b x + a)
+--R   (2)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c n + b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 600
+t0:=x^2*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R           +----+
+--R           |   2
+--R         c\|c x
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 600
+--r0:=-x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*c*(1+n)*sqrt(c*x^2))
+--E 149
+
+--S 150 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 150
+
+)clear all
+
+--S 151 of 600
+t0:=x*(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R            +----+
+--R            |   2
+--R        c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 600
+--r0:=-(a+b*x)^(1+n)/(a*c*sqrt(c*x^2))-b*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^2*c*(1+n)*sqrt(c*x^2))
+--E 152
+
+--S 153 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 153
+
+)clear all
+
+--S 154 of 600
+t0:=(a+b*x)^n/(c*x^2)^(3/2)
+--R 
+--R
+--R                  n
+--R         (b x + a)
+--R   (1)  -----------
+--R             +----+
+--R           2 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 600
+--r0:=1/2*b*(1-n)*(a+b*x)^(1+n)/(a^2*c*sqrt(c*x^2))-1/2*(a+b*x)^(1+n)/_
+--   (a*c*x*sqrt(c*x^2))+1/2*b^2*(1-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^3*c*(1+n)*sqrt(c*x^2))
+--E 155
+
+--S 156 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 156
+
+)clear all
+
+--S 157 of 600
+t0:=(a+b*x)^n/(x*(c*x^2)^(3/2))
+--R 
+--R
+--R                  n
+--R         (b x + a)
+--R   (1)  -----------
+--R             +----+
+--R           3 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 600
+--r0:=-1/6*b^2*(1-n)*(2-n)*(a+b*x)^(1+n)/(a^3*c*sqrt(c*x^2))-_
+--   1/3*(a+b*x)^(1+n)/(a*c*x^2*sqrt(c*x^2))+1/6*b*(2-n)*(a+b*x)^(1+n)/_
+--   (a^2*c*x*sqrt(c*x^2))-1/6*b^3*(1-n)*(2-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^4*c*(1+n)*sqrt(c*x^2))
+--E 158
+
+--S 159 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 159
+
+)clear all
+
+--S 160 of 600
+t0:=x^8*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R         4         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R             +----+
+--R           2 |   2
+--R          c \|c x
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 600
+r0:=-a^3*x*(a+b*x)^(1+n)/(b^4*c^2*(1+n)*sqrt(c*x^2))+3*a^2*x*_
+   (a+b*x)^(2+n)/(b^4*c^2*(2+n)*sqrt(c*x^2))-3*a*x*(a+b*x)^(3+n)/_
+   (b^4*c^2*(3+n)*sqrt(c*x^2))+x*(a+b*x)^(4+n)/(b^4*c^2*(4+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         3     2                      n + 4
+--R       (n  + 6n  + 11n + 6)x (b x + a)
+--R     + 
+--R              3        2                          n + 3
+--R       (- 3a n  - 21a n  - 42a n - 24a)x (b x + a)
+--R     + 
+--R          2 3      2 2      2       2            n + 2
+--R       (3a n  + 24a n  + 57a n + 36a )x (b x + a)
+--R     + 
+--R           3 3     3 2      3       3            n + 1
+--R       (- a n  - 9a n  - 26a n - 24a )x (b x + a)
+--R  /
+--R                                                       +----+
+--R       4 2 4      4 2 3      4 2 2      4 2       4 2  |   2
+--R     (b c n  + 10b c n  + 35b c n  + 50b c n + 24b c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 600
+t0:=x^7*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R         3         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R             +----+
+--R           2 |   2
+--R          c \|c x
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 600
+r0:=a^2*x*(a+b*x)^(1+n)/(b^3*c^2*(1+n)*sqrt(c*x^2))-2*a*x*(a+b*x)^(2+n)/_
+   (b^3*c^2*(2+n)*sqrt(c*x^2))+x*(a+b*x)^(3+n)/(b^3*c^2*(3+n)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         2                     n + 3          2                        n + 2
+--R       (n  + 3n + 2)x (b x + a)      + (- 2a n  - 8a n - 6a)x (b x + a)
+--R     + 
+--R         2 2     2      2            n + 1
+--R       (a n  + 5a n + 6a )x (b x + a)
+--R  /
+--R                                          +----+
+--R       3 2 3     3 2 2      3 2      3 2  |   2
+--R     (b c n  + 6b c n  + 11b c n + 6b c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 600
+t0:=x^6*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R         2         n
+--R        x (b x + a)
+--R   (1)  ------------
+--R             +----+
+--R           2 |   2
+--R          c \|c x
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 600
+r0:=-a*x*(a+b*x)^(1+n)/(b^2*c^2*(1+n)*sqrt(c*x^2))+x*(a+b*x)^(2+n)/_
+   (b^2*c^2*(2+n)*sqrt(c*x^2))
+--R 
+--R
+--R                          n + 2                          n + 1
+--R        (n + 1)x (b x + a)      + (- a n - 2a)x (b x + a)
+--R   (2)  ------------------------------------------------------
+--R                                             +----+
+--R                     2 2 2     2 2      2 2  |   2
+--R                   (b c n  + 3b c n + 2b c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 600
+t0:=x^5*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R                   n
+--R        x (b x + a)
+--R   (1)  ------------
+--R             +----+
+--R           2 |   2
+--R          c \|c x
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 600
+r0:=x*(a+b*x)^(1+n)/(b*c^2*(1+n)*sqrt(c*x^2))
+--R 
+--R
+--R                      n + 1
+--R           x (b x + a)
+--R   (2)  ---------------------
+--R                       +----+
+--R            2       2  |   2
+--R        (b c n + b c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 600
+t0:=x^4*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R            +----+
+--R          2 |   2
+--R         c \|c x
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 600
+--r0:=-x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*c^2*(1+n)*sqrt(c*x^2))
+--E 173
+
+--S 174 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 174
+
+)clear all
+
+--S 175 of 600
+t0:=x^3*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R                 n
+--R        (b x + a)
+--R   (1)  ----------
+--R            +----+
+--R         2  |   2
+--R        c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 600
+--r0:=-(a+b*x)^(1+n)/(a*c^2*sqrt(c*x^2))-b*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^2*c^2*(1+n)*sqrt(c*x^2))
+--E 176
+
+--S 177 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 177
+
+)clear all
+
+--S 178 of 600
+t0:=x^2*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R                  n
+--R         (b x + a)
+--R   (1)  -----------
+--R             +----+
+--R         2 2 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 600
+--r0:=1/2*b*(1-n)*(a+b*x)^(1+n)/(a^2*c^2*sqrt(c*x^2))-1/2*(a+b*x)^(1+n)/_
+--   (a*c^2*x*sqrt(c*x^2))+1/2*b^2*(1-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^3*c^2*(1+n)*sqrt(c*x^2))
+--E 179
+
+--S 180 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 180
+
+)clear all
+
+--S 181 of 600
+t0:=x*(a+b*x)^n/(c*x^2)^(5/2)
+--R 
+--R
+--R                  n
+--R         (b x + a)
+--R   (1)  -----------
+--R             +----+
+--R         2 3 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 600
+--r0:=-1/6*b^2*(1-n)*(2-n)*(a+b*x)^(1+n)/(a^3*c^2*sqrt(c*x^2))-_
+--   1/3*(a+b*x)^(1+n)/(a*c^2*x^2*sqrt(c*x^2))+1/6*b*(2-n)*(a+b*x)^(1+n)/_
+--   (a^2*c^2*x*sqrt(c*x^2))-1/6*b^3*(1-n)*(2-n)*n*x*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a^4*c^2*(1+n)*sqrt(c*x^2))
+--E 182
+
+--S 183 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 183
+
+)clear all
+
+--S 184 of 600
+t0:=x^m*(a+b*x)*sqrt(c*x^2)
+--R 
+--R
+--R                    +----+
+--R                  m |   2
+--R   (1)  (b x + a)x \|c x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 600
+r0:=a*x^(1+m)*sqrt(c*x^2)/(2+m)+b*x^(2+m)*sqrt(c*x^2)/(3+m)
+--R 
+--R
+--R                                              +----+
+--R                    m + 2              m + 1  |   2
+--R        ((b m + 2b)x      + (a m + 3a)x     )\|c x
+--R   (2)  --------------------------------------------
+--R                          2
+--R                         m  + 5m + 6
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 600
+t0:=x^3*(a+b*x)*sqrt(c*x^2)
+--R 
+--R
+--R                      +----+
+--R            4      3  |   2
+--R   (1)  (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 600
+r0:=1/5*a*x^4*sqrt(c*x^2)+1/6*b*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                        +----+
+--R             5       4  |   2
+--R        (5b x  + 6a x )\|c x
+--R   (2)  ----------------------
+--R                  30
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 600
+t0:=x^2*(a+b*x)*sqrt(c*x^2)
+--R 
+--R
+--R                      +----+
+--R            3      2  |   2
+--R   (1)  (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 600
+r0:=1/4*a*x^3*sqrt(c*x^2)+1/5*b*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                        +----+
+--R             4       3  |   2
+--R        (4b x  + 5a x )\|c x
+--R   (2)  ----------------------
+--R                  20
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 600
+t0:=x*(a+b*x)*sqrt(c*x^2)
+--R 
+--R
+--R                     +----+
+--R            2        |   2
+--R   (1)  (b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 600
+r0:=1/3*a*x^2*sqrt(c*x^2)+1/4*b*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                        +----+
+--R             3       2  |   2
+--R        (3b x  + 4a x )\|c x
+--R   (2)  ----------------------
+--R                  12
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 600
+t0:=(a+b*x)*sqrt(c*x^2)
+--R 
+--R
+--R                  +----+
+--R                  |   2
+--R   (1)  (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 600
+r0:=1/2*a*x*sqrt(c*x^2)+1/3*b*x^2*sqrt(c*x^2)
+--R 
+--R
+--R                       +----+
+--R             2         |   2
+--R        (2b x  + 3a x)\|c x
+--R   (2)  ---------------------
+--R                  6
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 600
+t0:=(a+b*x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R   (1)  ----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 600
+r0:=a*sqrt(c*x^2)+1/2*b*x*sqrt(c*x^2)
+--R 
+--R
+--R                   +----+
+--R                   |   2
+--R        (b x + 2a)\|c x
+--R   (2)  -----------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 600
+t0:=(a+b*x)*sqrt(c*x^2)/x^2
+--R 
+--R
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R   (1)  ----------------
+--R                2
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 600
+r0:=b*sqrt(c*x^2)+a*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                         +----+
+--R                         |   2
+--R        (a log(x) + b x)\|c x
+--R   (2)  -----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 600
+t0:=(a+b*x)*sqrt(c*x^2)/x^3
+--R 
+--R
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R   (1)  ----------------
+--R                3
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 600
+r0:=-a*sqrt(c*x^2)/x^2+b*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                         +----+
+--R                         |   2
+--R        (b x log(x) - a)\|c x
+--R   (2)  -----------------------
+--R                    2
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 600
+t0:=(a+b*x)*sqrt(c*x^2)/x^4
+--R 
+--R
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R   (1)  ----------------
+--R                4
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 600
+r0:=-1/2*a*sqrt(c*x^2)/x^3-b*sqrt(c*x^2)/x^2
+--R 
+--R
+--R                     +----+
+--R                     |   2
+--R        (- 2b x - a)\|c x
+--R   (2)  -------------------
+--R                  3
+--R                2x
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 600
+t0:=x^m*(c*x^2)^(3/2)*(a+b*x)
+--R 
+--R
+--R                            +----+
+--R              3        2  m |   2
+--R   (1)  (b c x  + a c x )x \|c x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 600
+r0:=a*c*x^(3+m)*sqrt(c*x^2)/(4+m)+b*c*x^(4+m)*sqrt(c*x^2)/(5+m)
+--R 
+--R
+--R                                                      +----+
+--R                        m + 4                  m + 3  |   2
+--R        ((b c m + 4b c)x      + (a c m + 5a c)x     )\|c x
+--R   (2)  ----------------------------------------------------
+--R                             2
+--R                            m  + 9m + 20
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 600
+t0:=x^3*(c*x^2)^(3/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R              6        5  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 600
+r0:=1/7*a*c*x^6*sqrt(c*x^2)+1/8*b*c*x^7*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R               7         6  |   2
+--R        (7b c x  + 8a c x )\|c x
+--R   (2)  --------------------------
+--R                    56
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 600
+t0:=x^2*(c*x^2)^(3/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R              5        4  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 600
+r0:=1/6*a*c*x^5*sqrt(c*x^2)+1/7*b*c*x^6*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R               6         5  |   2
+--R        (6b c x  + 7a c x )\|c x
+--R   (2)  --------------------------
+--R                    42
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 600
+t0:=x*(c*x^2)^(3/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R              4        3  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 600
+r0:=1/5*a*c*x^4*sqrt(c*x^2)+1/6*b*c*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R               5         4  |   2
+--R        (5b c x  + 6a c x )\|c x
+--R   (2)  --------------------------
+--R                    30
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R              3        2  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 600
+r0:=1/4*a*c*x^3*sqrt(c*x^2)+1/5*b*c*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R               4         3  |   2
+--R        (4b c x  + 5a c x )\|c x
+--R   (2)  --------------------------
+--R                    20
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)/x
+--R 
+--R
+--R                         +----+
+--R              2          |   2
+--R   (1)  (b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 600
+r0:=1/3*a*c*x^2*sqrt(c*x^2)+1/4*b*c*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R               3         2  |   2
+--R        (3b c x  + 4a c x )\|c x
+--R   (2)  --------------------------
+--R                    12
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)/x^2
+--R 
+--R
+--R                      +----+
+--R                      |   2
+--R   (1)  (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 600
+r0:=1/2*a*c*x*sqrt(c*x^2)+1/3*b*c*x^2*sqrt(c*x^2)
+--R 
+--R
+--R                           +----+
+--R               2           |   2
+--R        (2b c x  + 3a c x)\|c x
+--R   (2)  -------------------------
+--R                    6
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)/x^3
+--R 
+--R
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R   (1)  --------------------
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 600
+r0:=a*c*sqrt(c*x^2)+1/2*b*c*x*sqrt(c*x^2)
+--R 
+--R
+--R                       +----+
+--R                       |   2
+--R        (b c x + 2a c)\|c x
+--R   (2)  ---------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)/x^4
+--R 
+--R
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R   (1)  --------------------
+--R                  2
+--R                 x
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 600
+r0:=b*c*sqrt(c*x^2)+a*c*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                             +----+
+--R                             |   2
+--R        (a c log(x) + b c x)\|c x
+--R   (2)  ---------------------------
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 600
+t0:=x^m*(c*x^2)^(5/2)*(a+b*x)
+--R 
+--R
+--R                            +----+
+--R            2 5      2 4  m |   2
+--R   (1)  (b c x  + a c x )x \|c x
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 600
+r0:=a*c^2*x^(5+m)*sqrt(c*x^2)/(6+m)+b*c^2*x^(6+m)*sqrt(c*x^2)/(7+m)
+--R 
+--R
+--R                                                        +----+
+--R             2        2  m + 6       2        2  m + 5  |   2
+--R        ((b c m + 6b c )x      + (a c m + 7a c )x     )\|c x
+--R   (2)  ------------------------------------------------------
+--R                              2
+--R                             m  + 13m + 42
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 600
+t0:=x^3*(c*x^2)^(5/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R            2 8      2 7  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 600
+r0:=1/9*a*c^2*x^8*sqrt(c*x^2)+1/10*b*c^2*x^9*sqrt(c*x^2)
+--R 
+--R
+--R                             +----+
+--R             2 9        2 8  |   2
+--R        (9b c x  + 10a c x )\|c x
+--R   (2)  ---------------------------
+--R                     90
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 600
+t0:=x^2*(c*x^2)^(5/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R            2 7      2 6  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 600
+r0:=1/8*a*c^2*x^7*sqrt(c*x^2)+1/9*b*c^2*x^8*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 8       2 7  |   2
+--R        (8b c x  + 9a c x )\|c x
+--R   (2)  --------------------------
+--R                    72
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 600
+t0:=x*(c*x^2)^(5/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R            2 6      2 5  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 600
+r0:=1/7*a*c^2*x^6*sqrt(c*x^2)+1/8*b*c^2*x^7*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 7       2 6  |   2
+--R        (7b c x  + 8a c x )\|c x
+--R   (2)  --------------------------
+--R                    56
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)
+--R 
+--R
+--R                          +----+
+--R            2 5      2 4  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 600
+r0:=1/6*a*c^2*x^5*sqrt(c*x^2)+1/7*b*c^2*x^6*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 6       2 5  |   2
+--R        (6b c x  + 7a c x )\|c x
+--R   (2)  --------------------------
+--R                    42
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)/x
+--R 
+--R
+--R                          +----+
+--R            2 4      2 3  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 600
+r0:=1/5*a*c^2*x^4*sqrt(c*x^2)+1/6*b*c^2*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 5       2 4  |   2
+--R        (5b c x  + 6a c x )\|c x
+--R   (2)  --------------------------
+--R                    30
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)/x^2
+--R 
+--R
+--R                          +----+
+--R            2 3      2 2  |   2
+--R   (1)  (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 600
+r0:=1/4*a*c^2*x^3*sqrt(c*x^2)+1/5*b*c^2*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 4       2 3  |   2
+--R        (4b c x  + 5a c x )\|c x
+--R   (2)  --------------------------
+--R                    20
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)/x^3
+--R 
+--R
+--R                         +----+
+--R            2 2      2   |   2
+--R   (1)  (b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 600
+r0:=1/3*a*c^2*x^2*sqrt(c*x^2)+1/4*b*c^2*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                            +----+
+--R             2 3       2 2  |   2
+--R        (3b c x  + 4a c x )\|c x
+--R   (2)  --------------------------
+--R                    12
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)/x^4
+--R 
+--R
+--R                       +----+
+--R            2       2  |   2
+--R   (1)  (b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 600
+r0:=1/2*a*c^2*x*sqrt(c*x^2)+1/3*b*c^2*x^2*sqrt(c*x^2)
+--R 
+--R
+--R                           +----+
+--R             2 2       2   |   2
+--R        (2b c x  + 3a c x)\|c x
+--R   (2)  -------------------------
+--R                    6
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 600
+t0:=x^m*(a+b*x)/sqrt(c*x^2)
+--R 
+--R
+--R                  m
+--R        (b x + a)x
+--R   (1)  -----------
+--R           +----+
+--R           |   2
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 600
+r0:=a*x^(1+m)/(m*sqrt(c*x^2))+b*x^(2+m)/((1+m)*sqrt(c*x^2))
+--R 
+--R
+--R             m + 2             m + 1
+--R        b m x      + (a m + a)x
+--R   (2)  ----------------------------
+--R                        +----+
+--R                 2      |   2
+--R               (m  + m)\|c x
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 600
+t0:=x^3*(a+b*x)/sqrt(c*x^2)
+--R 
+--R
+--R           4      3
+--R        b x  + a x
+--R   (1)  -----------
+--R           +----+
+--R           |   2
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 600
+r0:=1/3*a*x^4/sqrt(c*x^2)+1/4*b*x^5/sqrt(c*x^2)
+--R 
+--R
+--R            5       4
+--R        3b x  + 4a x
+--R   (2)  -------------
+--R             +----+
+--R             |   2
+--R          12\|c x
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 600
+t0:=x^2*(a+b*x)/sqrt(c*x^2)
+--R 
+--R
+--R           3      2
+--R        b x  + a x
+--R   (1)  -----------
+--R           +----+
+--R           |   2
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 600
+r0:=1/2*a*x^3/sqrt(c*x^2)+1/3*b*x^4/sqrt(c*x^2)
+--R 
+--R
+--R            4       3
+--R        2b x  + 3a x
+--R   (2)  -------------
+--R             +----+
+--R             |   2
+--R           6\|c x
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 600
+t0:=x*(a+b*x)/sqrt(c*x^2)
+--R 
+--R
+--R           2
+--R        b x  + a x
+--R   (1)  ----------
+--R           +----+
+--R           |   2
+--R          \|c x
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 600
+r0:=a*x^2/sqrt(c*x^2)+1/2*b*x^3/sqrt(c*x^2)
+--R 
+--R
+--R           3       2
+--R        b x  + 2a x
+--R   (2)  ------------
+--R            +----+
+--R            |   2
+--R          2\|c x
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 600
+t0:=(a+b*x)/sqrt(c*x^2)
+--R 
+--R
+--R        b x + a
+--R   (1)  -------
+--R         +----+
+--R         |   2
+--R        \|c x
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 600
+r0:=b*x^2/sqrt(c*x^2)+a*x*log(x)/sqrt(c*x^2)
+--R 
+--R
+--R                        2
+--R        a x log(x) + b x
+--R   (2)  -----------------
+--R              +----+
+--R              |   2
+--R             \|c x
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 600
+t0:=(a+b*x)/(x*sqrt(c*x^2))
+--R 
+--R
+--R         b x + a
+--R   (1)  --------
+--R          +----+
+--R          |   2
+--R        x\|c x
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 600
+r0:=-a/sqrt(c*x^2)+b*x*log(x)/sqrt(c*x^2)
+--R 
+--R
+--R        b x log(x) - a
+--R   (2)  --------------
+--R             +----+
+--R             |   2
+--R            \|c x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 600
+t0:=(a+b*x)/(x^2*sqrt(c*x^2))
+--R 
+--R
+--R         b x + a
+--R   (1)  ---------
+--R           +----+
+--R         2 |   2
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 600
+r0:=-b/sqrt(c*x^2)-1/2*a/(x*sqrt(c*x^2))
+--R 
+--R
+--R        - 2b x - a
+--R   (2)  ----------
+--R            +----+
+--R            |   2
+--R         2x\|c x
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 600
+t0:=(a+b*x)/(x^3*sqrt(c*x^2))
+--R 
+--R
+--R         b x + a
+--R   (1)  ---------
+--R           +----+
+--R         3 |   2
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 600
+r0:=-1/3*a/(x^2*sqrt(c*x^2))-1/2*b/(x*sqrt(c*x^2))
+--R 
+--R
+--R        - 3b x - 2a
+--R   (2)  -----------
+--R             +----+
+--R           2 |   2
+--R         6x \|c x
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 600
+t0:=(a+b*x)/(x^4*sqrt(c*x^2))
+--R 
+--R
+--R         b x + a
+--R   (1)  ---------
+--R           +----+
+--R         4 |   2
+--R        x \|c x
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 600
+r0:=-1/4*a/(x^3*sqrt(c*x^2))-1/3*b/(x^2*sqrt(c*x^2))
+--R 
+--R
+--R        - 4b x - 3a
+--R   (2)  -----------
+--R             +----+
+--R           3 |   2
+--R        12x \|c x
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 600
+t0:=x^m*(a+b*x)/(c*x^2)^(3/2)
+--R 
+--R
+--R                  m
+--R        (b x + a)x
+--R   (1)  -----------
+--R             +----+
+--R           2 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 600
+r0:=-a*x^(-1+m)/(c*(2-m)*sqrt(c*x^2))-b*x^m/(c*(1-m)*sqrt(c*x^2))
+--R 
+--R
+--R                   m             m - 1
+--R        (b m - 2b)x  + (a m - a)x
+--R   (2)  ------------------------------
+--R                              +----+
+--R               2              |   2
+--R           (c m  - 3c m + 2c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 600
+t0:=x^3*(a+b*x)/(c*x^2)^(3/2)
+--R 
+--R
+--R           2
+--R        b x  + a x
+--R   (1)  ----------
+--R           +----+
+--R           |   2
+--R         c\|c x
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 600
+r0:=a*x^2/(c*sqrt(c*x^2))+1/2*b*x^3/(c*sqrt(c*x^2))
+--R 
+--R
+--R           3       2
+--R        b x  + 2a x
+--R   (2)  ------------
+--R             +----+
+--R             |   2
+--R          2c\|c x
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 600
+t0:=x^2*(a+b*x)/(c*x^2)^(3/2)
+--R 
+--R
+--R         b x + a
+--R   (1)  --------
+--R          +----+
+--R          |   2
+--R        c\|c x
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 600
+r0:=b*x^2/(c*sqrt(c*x^2))+a*x*log(x)/(c*sqrt(c*x^2))
+--R 
+--R
+--R                        2
+--R        a x log(x) + b x
+--R   (2)  -----------------
+--R               +----+
+--R               |   2
+--R             c\|c x
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 600
+t0:=x*(a+b*x)/(c*x^2)^(3/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  ----------
+--R            +----+
+--R            |   2
+--R        c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 600
+r0:=-a/(c*sqrt(c*x^2))+b*x*log(x)/(c*sqrt(c*x^2))
+--R 
+--R
+--R        b x log(x) - a
+--R   (2)  --------------
+--R             +----+
+--R             |   2
+--R           c\|c x
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 600
+t0:=(a+b*x)/(c*x^2)^(3/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R           2 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 600
+r0:=-b/(c*sqrt(c*x^2))-1/2*a/(c*x*sqrt(c*x^2))
+--R 
+--R
+--R         - 2b x - a
+--R   (2)  -----------
+--R             +----+
+--R             |   2
+--R        2c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 600
+t0:=(a+b*x)/(x*(c*x^2)^(3/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R           3 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 600
+r0:=-1/3*a/(c*x^2*sqrt(c*x^2))-1/2*b/(c*x*sqrt(c*x^2))
+--R 
+--R
+--R         - 3b x - 2a
+--R   (2)  ------------
+--R              +----+
+--R            2 |   2
+--R        6c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 600
+t0:=(a+b*x)/(x^2*(c*x^2)^(3/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R           4 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 600
+r0:=-1/4*a/(c*x^3*sqrt(c*x^2))-1/3*b/(c*x^2*sqrt(c*x^2))
+--R 
+--R
+--R         - 4b x - 3a
+--R   (2)  -------------
+--R               +----+
+--R             3 |   2
+--R        12c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 600
+t0:=(a+b*x)/(x^3*(c*x^2)^(3/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R           5 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 600
+r0:=-1/5*a/(c*x^4*sqrt(c*x^2))-1/4*b/(c*x^3*sqrt(c*x^2))
+--R 
+--R
+--R         - 5b x - 4a
+--R   (2)  -------------
+--R               +----+
+--R             4 |   2
+--R        20c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 600
+t0:=(a+b*x)/(x^4*(c*x^2)^(3/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R           6 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 600
+r0:=-1/6*a/(c*x^5*sqrt(c*x^2))-1/5*b/(c*x^4*sqrt(c*x^2))
+--R 
+--R
+--R         - 6b x - 5a
+--R   (2)  -------------
+--R               +----+
+--R             5 |   2
+--R        30c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 600
+t0:=x^m*(a+b*x)/(c*x^2)^(5/2)
+--R 
+--R
+--R                  m
+--R        (b x + a)x
+--R   (1)  -----------
+--R             +----+
+--R         2 4 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 600
+r0:=-a*x^(-3+m)/(c^2*(4-m)*sqrt(c*x^2))-b*x^(-2+m)/(c^2*(3-m)*sqrt(c*x^2))
+--R 
+--R
+--R                   m - 2              m - 3
+--R        (b m - 4b)x      + (a m - 3a)x
+--R   (2)  -----------------------------------
+--R                                 +----+
+--R              2 2     2       2  |   2
+--R            (c m  - 7c m + 12c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 600
+t0:=x^3*(a+b*x)/(c*x^2)^(5/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  ----------
+--R            +----+
+--R         2  |   2
+--R        c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 600
+r0:=-a/(c^2*sqrt(c*x^2))+b*x*log(x)/(c^2*sqrt(c*x^2))
+--R 
+--R
+--R        b x log(x) - a
+--R   (2)  --------------
+--R              +----+
+--R            2 |   2
+--R           c \|c x
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+)clear all
+
+--S 325 of 600
+t0:=x^2*(a+b*x)/(c*x^2)^(5/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 2 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 600
+r0:=-b/(c^2*sqrt(c*x^2))-1/2*a/(c^2*x*sqrt(c*x^2))
+--R 
+--R
+--R         - 2b x - a
+--R   (2)  -----------
+--R             +----+
+--R          2  |   2
+--R        2c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 600
+t0:=x*(a+b*x)/(c*x^2)^(5/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 3 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 600
+r0:=-1/3*a/(c^2*x^2*sqrt(c*x^2))-1/2*b/(c^2*x*sqrt(c*x^2))
+--R 
+--R
+--R         - 3b x - 2a
+--R   (2)  ------------
+--R              +----+
+--R          2 2 |   2
+--R        6c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 600
+t0:=(a+b*x)/(c*x^2)^(5/2)
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 4 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 600
+r0:=-1/4*a/(c^2*x^3*sqrt(c*x^2))-1/3*b/(c^2*x^2*sqrt(c*x^2))
+--R 
+--R
+--R         - 4b x - 3a
+--R   (2)  -------------
+--R               +----+
+--R           2 3 |   2
+--R        12c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 600
+t0:=(a+b*x)/(x*(c*x^2)^(5/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 5 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 600
+r0:=-1/5*a/(c^2*x^4*sqrt(c*x^2))-1/4*b/(c^2*x^3*sqrt(c*x^2))
+--R 
+--R
+--R         - 5b x - 4a
+--R   (2)  -------------
+--R               +----+
+--R           2 4 |   2
+--R        20c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 600
+t0:=(a+b*x)/(x^2*(c*x^2)^(5/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 6 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 600
+r0:=-1/6*a/(c^2*x^5*sqrt(c*x^2))-1/5*b/(c^2*x^4*sqrt(c*x^2))
+--R 
+--R
+--R         - 6b x - 5a
+--R   (2)  -------------
+--R               +----+
+--R           2 5 |   2
+--R        30c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 600
+t0:=(a+b*x)/(x^3*(c*x^2)^(5/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 7 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 600
+r0:=-1/7*a/(c^2*x^6*sqrt(c*x^2))-1/6*b/(c^2*x^5*sqrt(c*x^2))
+--R 
+--R
+--R         - 7b x - 6a
+--R   (2)  -------------
+--R               +----+
+--R           2 6 |   2
+--R        42c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 600
+t0:=(a+b*x)/(x^4*(c*x^2)^(5/2))
+--R 
+--R
+--R          b x + a
+--R   (1)  -----------
+--R             +----+
+--R         2 8 |   2
+--R        c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 600
+r0:=-1/8*a/(c^2*x^7*sqrt(c*x^2))-1/7*b/(c^2*x^6*sqrt(c*x^2))
+--R 
+--R
+--R         - 8b x - 7a
+--R   (2)  -------------
+--R               +----+
+--R           2 7 |   2
+--R        56c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 600
+t0:=x^m*(a+b*x)^2*sqrt(c*x^2)
+--R 
+--R
+--R                               +----+
+--R          2 2             2  m |   2
+--R   (1)  (b x  + 2a b x + a )x \|c x
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 600
+r0:=a^2*x^(1+m)*sqrt(c*x^2)/(2+m)+2*a*b*x^(2+m)*sqrt(c*x^2)/(3+m)+_
+   b^2*x^(3+m)*sqrt(c*x^2)/(4+m)
+--R 
+--R
+--R   (2)
+--R           2 2     2      2  m + 3          2                    m + 2
+--R         (b m  + 5b m + 6b )x      + (2a b m  + 12a b m + 16a b)x
+--R       + 
+--R           2 2     2       2  m + 1
+--R         (a m  + 7a m + 12a )x
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R      3     2
+--R     m  + 9m  + 26m + 24
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 600
+t0:=x^3*(a+b*x)^2*sqrt(c*x^2)
+--R 
+--R
+--R                                +----+
+--R          2 5         4    2 3  |   2
+--R   (1)  (b x  + 2a b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 600
+r0:=1/5*a^2*x^4*sqrt(c*x^2)+1/3*a*b*x^5*sqrt(c*x^2)+1/7*b^2*x^6*sqrt(c*x^2)
+--R 
+--R
+--R                                     +----+
+--R            2 6          5      2 4  |   2
+--R        (15b x  + 35a b x  + 21a x )\|c x
+--R   (2)  -----------------------------------
+--R                        105
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 600
+t0:=x^2*(a+b*x)^2*sqrt(c*x^2)
+--R 
+--R
+--R                                +----+
+--R          2 4         3    2 2  |   2
+--R   (1)  (b x  + 2a b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 600
+r0:=1/4*a^2*x^3*sqrt(c*x^2)+2/5*a*b*x^4*sqrt(c*x^2)+1/6*b^2*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                                     +----+
+--R            2 5          4      2 3  |   2
+--R        (10b x  + 24a b x  + 15a x )\|c x
+--R   (2)  -----------------------------------
+--R                         60
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 600
+t0:=x*(a+b*x)^2*sqrt(c*x^2)
+--R 
+--R
+--R                               +----+
+--R          2 3         2    2   |   2
+--R   (1)  (b x  + 2a b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 600
+r0:=1/3*a^2*x^2*sqrt(c*x^2)+1/2*a*b*x^3*sqrt(c*x^2)+1/5*b^2*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                                    +----+
+--R           2 4          3      2 2  |   2
+--R        (6b x  + 15a b x  + 10a x )\|c x
+--R   (2)  ----------------------------------
+--R                        30
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 600
+t0:=(a+b*x)^2*sqrt(c*x^2)
+--R 
+--R
+--R                             +----+
+--R          2 2             2  |   2
+--R   (1)  (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 600
+r0:=1/2*a^2*x*sqrt(c*x^2)+2/3*a*b*x^2*sqrt(c*x^2)+1/4*b^2*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                                 +----+
+--R           2 3         2     2   |   2
+--R        (3b x  + 8a b x  + 6a x)\|c x
+--R   (2)  -------------------------------
+--R                       12
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 600
+t0:=(a+b*x)^2*sqrt(c*x^2)/x
+--R 
+--R
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R   (1)  ---------------------------
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 600
+r0:=1/3*(a+b*x)^3*sqrt(c*x^2)/(b*x)
+--R 
+--R
+--R                                       +----+
+--R          3 3       2 2     2       3  |   2
+--R        (b x  + 3a b x  + 3a b x + a )\|c x
+--R   (2)  -------------------------------------
+--R                         3b x
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 600
+t0:=(a+b*x)^2*sqrt(c*x^2)/x^2
+--R 
+--R
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R   (1)  ---------------------------
+--R                      2
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 600
+r0:=2*a*b*sqrt(c*x^2)+1/2*b^2*x*sqrt(c*x^2)+a^2*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                                    +----+
+--R           2          2 2           |   2
+--R        (2a log(x) + b x  + 4a b x)\|c x
+--R   (2)  ----------------------------------
+--R                        2x
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 600
+t0:=(a+b*x)^2*sqrt(c*x^2)/x^3
+--R 
+--R
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R   (1)  ---------------------------
+--R                      3
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 600
+r0:=b^2*sqrt(c*x^2)-a^2*sqrt(c*x^2)/x^2+2*a*b*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                                    +----+
+--R                          2 2    2  |   2
+--R        (2a b x log(x) + b x  - a )\|c x
+--R   (2)  ----------------------------------
+--R                         2
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 600
+t0:=(a+b*x)^2*sqrt(c*x^2)/x^4
+--R 
+--R
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R   (1)  ---------------------------
+--R                      4
+--R                     x
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 600
+r0:=-1/2*a^2*sqrt(c*x^2)/x^3-2*a*b*sqrt(c*x^2)/x^2+b^2*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                                    +----+
+--R           2 2                   2  |   2
+--R        (2b x log(x) - 4a b x - a )\|c x
+--R   (2)  ----------------------------------
+--R                          3
+--R                        2x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 600
+t0:=x^m*(c*x^2)^(3/2)*(a+b*x)^2
+--R 
+--R
+--R                                        +----+
+--R          2   4           3    2   2  m |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )x \|c x
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 600
+r0:=a^2*c*x^(3+m)*sqrt(c*x^2)/(4+m)+2*a*b*c*x^(4+m)*sqrt(c*x^2)/(5+m)+_
+   b^2*c*x^(5+m)*sqrt(c*x^2)/(6+m)
+--R 
+--R
+--R   (2)
+--R           2   2     2         2   m + 5
+--R         (b c m  + 9b c m + 20b c)x
+--R       + 
+--R                  2                        m + 4
+--R         (2a b c m  + 20a b c m + 48a b c)x
+--R       + 
+--R           2   2      2         2   m + 3
+--R         (a c m  + 11a c m + 30a c)x
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R      3      2
+--R     m  + 15m  + 74m + 120
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 600
+t0:=x^3*(c*x^2)^(3/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2   7           6    2   5  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 600
+r0:=1/7*a^2*c*x^6*sqrt(c*x^2)+1/4*a*b*c*x^7*sqrt(c*x^2)+_
+   1/9*b^2*c*x^8*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2   8            7      2   6  |   2
+--R        (28b c x  + 63a b c x  + 36a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           252
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 600
+t0:=x^2*(c*x^2)^(3/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2   6           5    2   4  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 600
+r0:=1/6*a^2*c*x^5*sqrt(c*x^2)+2/7*a*b*c*x^6*sqrt(c*x^2)+_
+   1/8*b^2*c*x^7*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2   7            6      2   5  |   2
+--R        (21b c x  + 48a b c x  + 28a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           168
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 600
+t0:=x*(c*x^2)^(3/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2   5           4    2   3  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 600
+r0:=1/5*a^2*c*x^4*sqrt(c*x^2)+1/3*a*b*c*x^5*sqrt(c*x^2)+_
+   1/7*b^2*c*x^6*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2   6            5      2   4  |   2
+--R        (15b c x  + 35a b c x  + 21a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           105
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2   4           3    2   2  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 600
+r0:=1/4*a^2*c*x^3*sqrt(c*x^2)+2/5*a*b*c*x^4*sqrt(c*x^2)+_
+   1/6*b^2*c*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2   5            4      2   3  |   2
+--R        (10b c x  + 24a b c x  + 15a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                            60
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^2/x
+--R 
+--R
+--R                                     +----+
+--R          2   3           2    2     |   2
+--R   (1)  (b c x  + 2a b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 600
+r0:=1/3*a^2*c*x^2*sqrt(c*x^2)+1/2*a*b*c*x^3*sqrt(c*x^2)+_
+   1/5*b^2*c*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                                          +----+
+--R           2   4            3      2   2  |   2
+--R        (6b c x  + 15a b c x  + 10a c x )\|c x
+--R   (2)  ----------------------------------------
+--R                           30
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^2/x^2
+--R 
+--R
+--R                                  +----+
+--R          2   2               2   |   2
+--R   (1)  (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 600
+r0:=1/2*a^2*c*x*sqrt(c*x^2)+2/3*a*b*c*x^2*sqrt(c*x^2)+1/4*b^2*c*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                                       +----+
+--R           2   3           2     2     |   2
+--R        (3b c x  + 8a b c x  + 6a c x)\|c x
+--R   (2)  -------------------------------------
+--R                          12
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^2/x^3
+--R 
+--R
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R   (1)  --------------------------------
+--R                        x
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 600
+r0:=1/3*c*(a+b*x)^3*sqrt(c*x^2)/(b*x)
+--R 
+--R
+--R                                              +----+
+--R          3   3       2   2     2         3   |   2
+--R        (b c x  + 3a b c x  + 3a b c x + a c)\|c x
+--R   (2)  --------------------------------------------
+--R                            3b x
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 600
+t0:=(c*x^2)^(3/2)*(a+b*x)^2/x^4
+--R 
+--R
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R   (1)  --------------------------------
+--R                        2
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 600
+r0:=2*a*b*c*sqrt(c*x^2)+1/2*b^2*c*x*sqrt(c*x^2)+a^2*c*log(x)*sqrt(c*x^2)/x
+--R 
+--R
+--R                                          +----+
+--R           2            2   2             |   2
+--R        (2a c log(x) + b c x  + 4a b c x)\|c x
+--R   (2)  ----------------------------------------
+--R                           2x
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 600
+t0:=x^m*(c*x^2)^(5/2)*(a+b*x)^2
+--R 
+--R
+--R                                        +----+
+--R          2 2 6         2 5    2 2 4  m |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )x \|c x
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 600
+r0:=a^2*c^2*x^(5+m)*sqrt(c*x^2)/(6+m)+2*a*b*c^2*x^(6+m)*sqrt(c*x^2)/(7+m)+_
+   b^2*c^2*x^(7+m)*sqrt(c*x^2)/(8+m)
+--R 
+--R
+--R   (2)
+--R           2 2 2      2 2       2 2  m + 7
+--R         (b c m  + 13b c m + 42b c )x
+--R       + 
+--R                2 2          2           2  m + 6
+--R         (2a b c m  + 28a b c m + 96a b c )x
+--R       + 
+--R           2 2 2      2 2       2 2  m + 5
+--R         (a c m  + 15a c m + 56a c )x
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R      3      2
+--R     m  + 21m  + 146m + 336
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 600
+t0:=x^3*(c*x^2)^(5/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2 2 9         2 8    2 2 7  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 600
+r0:=1/9*a^2*c^2*x^8*sqrt(c*x^2)+1/5*a*b*c^2*x^9*sqrt(c*x^2)+_
+   1/11*b^2*c^2*x^10*sqrt(c*x^2)
+--R 
+--R
+--R                                            +----+
+--R            2 2 10          2 9      2 2 8  |   2
+--R        (45b c x   + 99a b c x  + 55a c x )\|c x
+--R   (2)  ------------------------------------------
+--R                            495
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 600
+t0:=x^2*(c*x^2)^(5/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2 2 8         2 7    2 2 6  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 600
+r0:=1/8*a^2*c^2*x^7*sqrt(c*x^2)+2/9*a*b*c^2*x^8*sqrt(c*x^2)+_
+   1/10*b^2*c^2*x^9*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2 2 9          2 8      2 2 7  |   2
+--R        (36b c x  + 80a b c x  + 45a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           360
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 600
+t0:=x*(c*x^2)^(5/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2 2 7         2 6    2 2 5  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 600
+r0:=1/7*a^2*c^2*x^6*sqrt(c*x^2)+1/4*a*b*c^2*x^7*sqrt(c*x^2)+_
+   1/9*b^2*c^2*x^8*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2 2 8          2 7      2 2 6  |   2
+--R        (28b c x  + 63a b c x  + 36a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           252
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^2
+--R 
+--R
+--R                                      +----+
+--R          2 2 6         2 5    2 2 4  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 600
+r0:=1/6*a^2*c^2*x^5*sqrt(c*x^2)+2/7*a*b*c^2*x^6*sqrt(c*x^2)+_
+   1/8*b^2*c^2*x^7*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2 2 7          2 6      2 2 5  |   2
+--R        (21b c x  + 48a b c x  + 28a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           168
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^2/x
+--R 
+--R
+--R                                      +----+
+--R          2 2 5         2 4    2 2 3  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 600
+r0:=1/5*a^2*c^2*x^4*sqrt(c*x^2)+1/3*a*b*c^2*x^5*sqrt(c*x^2)+_
+   1/7*b^2*c^2*x^6*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2 2 6          2 5      2 2 4  |   2
+--R        (15b c x  + 35a b c x  + 21a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                           105
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^2/x^2
+--R 
+--R
+--R                                      +----+
+--R          2 2 4         2 3    2 2 2  |   2
+--R   (1)  (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 600
+r0:=1/4*a^2*c^2*x^3*sqrt(c*x^2)+2/5*a*b*c^2*x^4*sqrt(c*x^2)+_
+   1/6*b^2*c^2*x^5*sqrt(c*x^2)
+--R 
+--R
+--R                                           +----+
+--R            2 2 5          2 4      2 2 3  |   2
+--R        (10b c x  + 24a b c x  + 15a c x )\|c x
+--R   (2)  -----------------------------------------
+--R                            60
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^2/x^3
+--R 
+--R
+--R                                     +----+
+--R          2 2 3         2 2    2 2   |   2
+--R   (1)  (b c x  + 2a b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 600
+r0:=1/3*a^2*c^2*x^2*sqrt(c*x^2)+1/2*a*b*c^2*x^3*sqrt(c*x^2)+_
+   1/5*b^2*c^2*x^4*sqrt(c*x^2)
+--R 
+--R
+--R                                          +----+
+--R           2 2 4          2 3      2 2 2  |   2
+--R        (6b c x  + 15a b c x  + 10a c x )\|c x
+--R   (2)  ----------------------------------------
+--R                           30
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 600
+t0:=(c*x^2)^(5/2)*(a+b*x)^2/x^4
+--R 
+--R
+--R                                   +----+
+--R          2 2 2         2     2 2  |   2
+--R   (1)  (b c x  + 2a b c x + a c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 600
+r0:=1/2*a^2*c^2*x*sqrt(c*x^2)+2/3*a*b*c^2*x^2*sqrt(c*x^2)+_
+   1/4*b^2*c^2*x^3*sqrt(c*x^2)
+--R 
+--R
+--R                                       +----+
+--R           2 2 3         2 2     2 2   |   2
+--R        (3b c x  + 8a b c x  + 6a c x)\|c x
+--R   (2)  -------------------------------------
+--R                          12
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 600
+t0:=x^m*(a+b*x)^2/sqrt(c*x^2)
+--R 
+--R
+--R          2 2             2  m
+--R        (b x  + 2a b x + a )x
+--R   (1)  ----------------------
+--R                 +----+
+--R                 |   2
+--R                \|c x
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 600
+r0:=a^2*x^(1+m)/(m*sqrt(c*x^2))+2*a*b*x^(2+m)/((1+m)*sqrt(c*x^2))+_
+   b^2*x^(3+m)/((2+m)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R     2 2    2   m + 3          2           m + 2     2 2     2      2  m + 1
+--R   (b m  + b m)x      + (2a b m  + 4a b m)x      + (a m  + 3a m + 2a )x
+--R   -------------------------------------------------------------------------
+--R                                             +----+
+--R                               3     2       |   2
+--R                             (m  + 3m  + 2m)\|c x
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 600
+t0:=x^3*(a+b*x)^2/sqrt(c*x^2)
+--R 
+--R
+--R         2 5         4    2 3
+--R        b x  + 2a b x  + a x
+--R   (1)  ---------------------
+--R                +----+
+--R                |   2
+--R               \|c x
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 600
+r0:=1/3*a^2*x^4/sqrt(c*x^2)+1/2*a*b*x^5/sqrt(c*x^2)+1/5*b^2*x^6/sqrt(c*x^2)
+--R 
+--R
+--R          2 6          5      2 4
+--R        6b x  + 15a b x  + 10a x
+--R   (2)  -------------------------
+--R                   +----+
+--R                   |   2
+--R                30\|c x
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 600
+t0:=x^2*(a+b*x)^2/sqrt(c*x^2)
+--R 
+--R
+--R         2 4         3    2 2
+--R        b x  + 2a b x  + a x
+--R   (1)  ---------------------
+--R                +----+
+--R                |   2
+--R               \|c x
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 600
+r0:=1/2*a^2*x^3/sqrt(c*x^2)+2/3*a*b*x^4/sqrt(c*x^2)+1/4*b^2*x^5/sqrt(c*x^2)
+--R 
+--R
+--R          2 5         4     2 3
+--R        3b x  + 8a b x  + 6a x
+--R   (2)  -----------------------
+--R                  +----+
+--R                  |   2
+--R               12\|c x
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 600
+t0:=x*(a+b*x)^2/sqrt(c*x^2)
+--R 
+--R
+--R         2 3         2    2
+--R        b x  + 2a b x  + a x
+--R   (1)  --------------------
+--R                +----+
+--R                |   2
+--R               \|c x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 600
+r0:=1/3*x*(a+b*x)^3/(b*sqrt(c*x^2))
+--R 
+--R
+--R         3 4       2 3     2   2    3
+--R        b x  + 3a b x  + 3a b x  + a x
+--R   (2)  ------------------------------
+--R                      +----+
+--R                      |   2
+--R                   3b\|c x
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 600
+t0:=(a+b*x)^2/sqrt(c*x^2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R               +----+
+--R               |   2
+--R              \|c x
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 600
+r0:=2*a*b*x^2/sqrt(c*x^2)+1/2*b^2*x^3/sqrt(c*x^2)+a^2*x*log(x)/sqrt(c*x^2)
+--R 
+--R
+--R          2            2 3         2
+--R        2a x log(x) + b x  + 4a b x
+--R   (2)  ----------------------------
+--R                    +----+
+--R                    |   2
+--R                  2\|c x
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 600
+t0:=(a+b*x)^2/(x*sqrt(c*x^2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R               +----+
+--R               |   2
+--R             x\|c x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 600
+r0:=-a^2/sqrt(c*x^2)+b^2*x^2/sqrt(c*x^2)+2*a*b*x*log(x)/sqrt(c*x^2)
+--R 
+--R
+--R                         2 2    2
+--R        2a b x log(x) + b x  - a
+--R   (2)  -------------------------
+--R                  +----+
+--R                  |   2
+--R                 \|c x
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 444
+
+)clear all
+
+--S 445 of 600
+t0:=(a+b*x)^2/(x^2*sqrt(c*x^2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                +----+
+--R              2 |   2
+--R             x \|c x
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 600
+r0:=-2*a*b/sqrt(c*x^2)-1/2*a^2/(x*sqrt(c*x^2))+b^2*x*log(x)/sqrt(c*x^2)
+--R 
+--R
+--R          2 2                   2
+--R        2b x log(x) - 4a b x - a
+--R   (2)  -------------------------
+--R                   +----+
+--R                   |   2
+--R                2x\|c x
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 600
+t0:=(a+b*x)^2/(x^3*sqrt(c*x^2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                +----+
+--R              3 |   2
+--R             x \|c x
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 600
+r0:=-1/3*(a+b*x)^3/(a*x^2*sqrt(c*x^2))
+--R 
+--R
+--R           3 3       2 2     2       3
+--R        - b x  - 3a b x  - 3a b x - a
+--R   (2)  ------------------------------
+--R                       +----+
+--R                     2 |   2
+--R                 3a x \|c x
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 600
+t0:=(a+b*x)^2/(x^4*sqrt(c*x^2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                +----+
+--R              4 |   2
+--R             x \|c x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 600
+r0:=-1/4*a^2/(x^3*sqrt(c*x^2))-2/3*a*b/(x^2*sqrt(c*x^2))-_
+   1/2*b^2/(x*sqrt(c*x^2))
+--R 
+--R
+--R            2 2              2
+--R        - 6b x  - 8a b x - 3a
+--R   (2)  ----------------------
+--R                   +----+
+--R                 3 |   2
+--R              12x \|c x
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 600
+t0:=x^m*(a+b*x)^2/(c*x^2)^(3/2)
+--R 
+--R
+--R          2 2             2  m
+--R        (b x  + 2a b x + a )x
+--R   (1)  ----------------------
+--R                   +----+
+--R                 2 |   2
+--R              c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 600
+r0:=-a^2*x^(-1+m)/(c*(2-m)*sqrt(c*x^2))-2*a*b*x^m/(c*(1-m)*_
+   sqrt(c*x^2))+b^2*x^(1+m)/(c*m*sqrt(c*x^2))
+--R 
+--R
+--R          2 2     2      2  m + 1          2           m     2 2    2   m - 1
+--R        (b m  - 3b m + 2b )x      + (2a b m  - 4a b m)x  + (a m  - a m)x
+--R   (2)  ---------------------------------------------------------------------
+--R                                                   +----+
+--R                                 3       2         |   2
+--R                             (c m  - 3c m  + 2c m)\|c x
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 600
+t0:=x^3*(a+b*x)^2/(c*x^2)^(3/2)
+--R 
+--R
+--R         2 3         2    2
+--R        b x  + 2a b x  + a x
+--R   (1)  --------------------
+--R                +----+
+--R                |   2
+--R              c\|c x
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 600
+r0:=1/3*x*(a+b*x)^3/(b*c*sqrt(c*x^2))
+--R 
+--R
+--R         3 4       2 3     2   2    3
+--R        b x  + 3a b x  + 3a b x  + a x
+--R   (2)  ------------------------------
+--R                       +----+
+--R                       |   2
+--R                  3b c\|c x
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 600
+t0:=x^2*(a+b*x)^2/(c*x^2)^(3/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R               +----+
+--R               |   2
+--R             c\|c x
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 600
+r0:=2*a*b*x^2/(c*sqrt(c*x^2))+1/2*b^2*x^3/(c*sqrt(c*x^2))+_
+   a^2*x*log(x)/(c*sqrt(c*x^2))
+--R 
+--R
+--R          2            2 3         2
+--R        2a x log(x) + b x  + 4a b x
+--R   (2)  ----------------------------
+--R                     +----+
+--R                     |   2
+--R                  2c\|c x
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 600
+t0:=x*(a+b*x)^2/(c*x^2)^(3/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                +----+
+--R                |   2
+--R            c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 600
+r0:=-a^2/(c*sqrt(c*x^2))+b^2*x^2/(c*sqrt(c*x^2))+2*a*b*x*log(x)/(c*sqrt(c*x^2))
+--R 
+--R
+--R                         2 2    2
+--R        2a b x log(x) + b x  - a
+--R   (2)  -------------------------
+--R                   +----+
+--R                   |   2
+--R                 c\|c x
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 600
+t0:=(a+b*x)^2/(c*x^2)^(3/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R               2 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 600
+r0:=-2*a*b/(c*sqrt(c*x^2))-1/2*a^2/(c*x*sqrt(c*x^2))+_
+   b^2*x*log(x)/(c*sqrt(c*x^2))
+--R 
+--R
+--R          2 2                   2
+--R        2b x log(x) - 4a b x - a
+--R   (2)  -------------------------
+--R                    +----+
+--R                    |   2
+--R               2c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 600
+t0:=(a+b*x)^2/(x*(c*x^2)^(3/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R               3 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 600
+r0:=-1/3*(a+b*x)^3/(a*c*x^2*sqrt(c*x^2))
+--R 
+--R
+--R           3 3       2 2     2       3
+--R        - b x  - 3a b x  - 3a b x - a
+--R   (2)  ------------------------------
+--R                        +----+
+--R                      2 |   2
+--R                3a c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 600
+t0:=(a+b*x)^2/(x^2*(c*x^2)^(3/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R               4 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 600
+r0:=-1/4*a^2/(c*x^3*sqrt(c*x^2))-2/3*a*b/(c*x^2*sqrt(c*x^2))-_
+   1/2*b^2/(c*x*sqrt(c*x^2))
+--R 
+--R
+--R            2 2              2
+--R        - 6b x  - 8a b x - 3a
+--R   (2)  ----------------------
+--R                    +----+
+--R                  3 |   2
+--R             12c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 600
+t0:=(a+b*x)^2/(x^3*(c*x^2)^(3/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R               5 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 600
+r0:=-1/5*a^2/(c*x^4*sqrt(c*x^2))-1/2*a*b/(c*x^3*sqrt(c*x^2))-_
+   1/3*b^2/(c*x^2*sqrt(c*x^2))
+--R 
+--R
+--R             2 2               2
+--R        - 10b x  - 15a b x - 6a
+--R   (2)  ------------------------
+--R                     +----+
+--R                   4 |   2
+--R              30c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 600
+t0:=(a+b*x)^2/(x^4*(c*x^2)^(3/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R               6 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 600
+r0:=-1/6*a^2/(c*x^5*sqrt(c*x^2))-2/5*a*b/(c*x^4*sqrt(c*x^2))-_
+   1/4*b^2/(c*x^3*sqrt(c*x^2))
+--R 
+--R
+--R             2 2                2
+--R        - 15b x  - 24a b x - 10a
+--R   (2)  -------------------------
+--R                     +----+
+--R                   5 |   2
+--R              60c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 600
+t0:=x^m*(a+b*x)^2/(c*x^2)^(5/2)
+--R 
+--R
+--R          2 2             2  m
+--R        (b x  + 2a b x + a )x
+--R   (1)  ----------------------
+--R                   +----+
+--R               2 4 |   2
+--R              c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 600
+r0:=-a^2*x^(-3+m)/(c^2*(4-m)*sqrt(c*x^2))-2*a*b*x^(-2+m)/(c^2*(3-m)*_
+   sqrt(c*x^2))-b^2*x^(-1+m)/(c^2*(2-m)*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         2 2     2       2  m - 1          2                    m - 2
+--R       (b m  - 7b m + 12b )x      + (2a b m  - 12a b m + 16a b)x
+--R     + 
+--R         2 2     2      2  m - 3
+--R       (a m  - 5a m + 6a )x
+--R  /
+--R                                   +----+
+--R       2 3     2 2      2       2  |   2
+--R     (c m  - 9c m  + 26c m - 24c )\|c x
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+)clear all
+
+--S 484 of 600
+t0:=x^3*(a+b*x)^2/(c*x^2)^(5/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                +----+
+--R             2  |   2
+--R            c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 600
+r0:=-a^2/(c^2*sqrt(c*x^2))+b^2*x^2/(c^2*sqrt(c*x^2))+_
+   2*a*b*x*log(x)/(c^2*sqrt(c*x^2))
+--R 
+--R
+--R                         2 2    2
+--R        2a b x log(x) + b x  - a
+--R   (2)  -------------------------
+--R                   +----+
+--R                 2 |   2
+--R                c \|c x
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 600
+t0:=x^2*(a+b*x)^2/(c*x^2)^(5/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 2 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 600
+r0:=-2*a*b/(c^2*sqrt(c*x^2))-1/2*a^2/(c^2*x*sqrt(c*x^2))+_
+   b^2*x*log(x)/(c^2*sqrt(c*x^2))
+--R 
+--R
+--R          2 2                   2
+--R        2b x log(x) - 4a b x - a
+--R   (2)  -------------------------
+--R                    +----+
+--R                 2  |   2
+--R               2c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 600
+t0:=x*(a+b*x)^2/(c*x^2)^(5/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 3 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 600
+r0:=-1/3*(a+b*x)^3/(a*c^2*x^2*sqrt(c*x^2))
+--R 
+--R
+--R           3 3       2 2     2       3
+--R        - b x  - 3a b x  - 3a b x - a
+--R   (2)  ------------------------------
+--R                        +----+
+--R                    2 2 |   2
+--R                3a c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 600
+t0:=(a+b*x)^2/(c*x^2)^(5/2)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 4 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 600
+r0:=-1/4*a^2/(c^2*x^3*sqrt(c*x^2))-2/3*a*b/(c^2*x^2*sqrt(c*x^2))-_
+   1/2*b^2/(c^2*x*sqrt(c*x^2))
+--R 
+--R
+--R            2 2              2
+--R        - 6b x  - 8a b x - 3a
+--R   (2)  ----------------------
+--R                    +----+
+--R                2 3 |   2
+--R             12c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 600
+t0:=(a+b*x)^2/(x*(c*x^2)^(5/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 5 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 600
+r0:=-1/5*a^2/(c^2*x^4*sqrt(c*x^2))-1/2*a*b/(c^2*x^3*sqrt(c*x^2))-_
+   1/3*b^2/(c^2*x^2*sqrt(c*x^2))
+--R 
+--R
+--R             2 2               2
+--R        - 10b x  - 15a b x - 6a
+--R   (2)  ------------------------
+--R                     +----+
+--R                 2 4 |   2
+--R              30c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 600
+t0:=(a+b*x)^2/(x^2*(c*x^2)^(5/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 6 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 600
+r0:=-1/6*a^2/(c^2*x^5*sqrt(c*x^2))-2/5*a*b/(c^2*x^4*sqrt(c*x^2))-_
+   1/4*b^2/(c^2*x^3*sqrt(c*x^2))
+--R 
+--R
+--R             2 2                2
+--R        - 15b x  - 24a b x - 10a
+--R   (2)  -------------------------
+--R                     +----+
+--R                 2 5 |   2
+--R              60c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 600
+t0:=(a+b*x)^2/(x^3*(c*x^2)^(5/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 7 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 600
+r0:=-1/7*a^2/(c^2*x^6*sqrt(c*x^2))-1/3*a*b/(c^2*x^5*sqrt(c*x^2))-_
+   1/5*b^2/(c^2*x^4*sqrt(c*x^2))
+--R 
+--R
+--R             2 2                2
+--R        - 21b x  - 35a b x - 15a
+--R   (2)  -------------------------
+--R                      +----+
+--R                  2 6 |   2
+--R              105c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 600
+t0:=(a+b*x)^2/(x^4*(c*x^2)^(5/2))
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                 +----+
+--R             2 8 |   2
+--R            c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 600
+r0:=-1/8*a^2/(c^2*x^7*sqrt(c*x^2))-2/7*a*b/(c^2*x^6*sqrt(c*x^2))-_
+   1/6*b^2/(c^2*x^5*sqrt(c*x^2))
+--R 
+--R
+--R             2 2                2
+--R        - 28b x  - 48a b x - 21a
+--R   (2)  -------------------------
+--R                      +----+
+--R                  2 7 |   2
+--R              168c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 600
+t0:=x^3*sqrt(c*x^2)/(a+b*x)
+--R 
+--R
+--R           +----+
+--R         3 |   2
+--R        x \|c x
+--R   (1)  ---------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 600
+r0:=-a^3*sqrt(c*x^2)/b^4+1/2*a^2*x*sqrt(c*x^2)/b^3-1/3*a*x^2*_
+   sqrt(c*x^2)/b^2+1/4*x^3*sqrt(c*x^2)/b+a^4*log(a+b*x)*sqrt(c*x^2)/(b^5*x)
+--R 
+--R
+--R                                                                 +----+
+--R            4                 4 4       3 3     2 2 2      3     |   2
+--R        (12a log(b x + a) + 3b x  - 4a b x  + 6a b x  - 12a b x)\|c x
+--R   (2)  ---------------------------------------------------------------
+--R                                        5
+--R                                     12b x
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 600
+t0:=x^2*sqrt(c*x^2)/(a+b*x)
+--R 
+--R
+--R           +----+
+--R         2 |   2
+--R        x \|c x
+--R   (1)  ---------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 600
+r0:=a^2*sqrt(c*x^2)/b^3-1/2*a*x*sqrt(c*x^2)/b^2+1/3*x^2*sqrt(c*x^2)/b-_
+   a^3*log(a+b*x)*sqrt(c*x^2)/(b^4*x)
+--R 
+--R
+--R                                                       +----+
+--R             3                 3 3       2 2     2     |   2
+--R        (- 6a log(b x + a) + 2b x  - 3a b x  + 6a b x)\|c x
+--R   (2)  -----------------------------------------------------
+--R                                   4
+--R                                 6b x
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 513
+
+)clear all
+
+--S 514 of 600
+t0:=x*sqrt(c*x^2)/(a+b*x)
+--R 
+--R
+--R          +----+
+--R          |   2
+--R        x\|c x
+--R   (1)  --------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 600
+r0:=-a*sqrt(c*x^2)/b^2+1/2*x*sqrt(c*x^2)/b+a^2*log(a+b*x)*sqrt(c*x^2)/(b^3*x)
+--R 
+--R
+--R                                          +----+
+--R           2                2 2           |   2
+--R        (2a log(b x + a) + b x  - 2a b x)\|c x
+--R   (2)  ----------------------------------------
+--R                            3
+--R                          2b x
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 600
+t0:=sqrt(c*x^2)/(a+b*x)
+--R 
+--R
+--R         +----+
+--R         |   2
+--R        \|c x
+--R   (1)  -------
+--R        b x + a
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 600
+r0:=sqrt(c*x^2)/b-a*log(a+b*x)*sqrt(c*x^2)/(b^2*x)
+--R 
+--R
+--R                                 +----+
+--R                                 |   2
+--R        (- a log(b x + a) + b x)\|c x
+--R   (2)  -------------------------------
+--R                       2
+--R                      b x
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 519
+
+)clear all
+
+--S 520 of 600
+t0:=sqrt(c*x^2)/(x*(a+b*x))
+--R 
+--R
+--R           +----+
+--R           |   2
+--R          \|c x
+--R   (1)  ----------
+--R           2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 600
+r0:=log(a+b*x)*sqrt(c*x^2)/(b*x)
+--R 
+--R
+--R                     +----+
+--R                     |   2
+--R        log(b x + a)\|c x
+--R   (2)  -------------------
+--R                b x
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 600
+t0:=sqrt(c*x^2)/(x^2*(a+b*x))
+--R 
+--R
+--R           +----+
+--R           |   2
+--R          \|c x
+--R   (1)  -----------
+--R           3      2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 600
+r0:=log(x)*sqrt(c*x^2)/(a*x)-log(a+b*x)*sqrt(c*x^2)/(a*x)
+--R 
+--R
+--R                                  +----+
+--R                                  |   2
+--R        (- log(b x + a) + log(x))\|c x
+--R   (2)  --------------------------------
+--R                       a x
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 600
+t0:=sqrt(c*x^2)/(x^3*(a+b*x))
+--R 
+--R
+--R           +----+
+--R           |   2
+--R          \|c x
+--R   (1)  -----------
+--R           4      3
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 600
+r0:=-sqrt(c*x^2)/(a*x^2)-b*log(x)*sqrt(c*x^2)/(a^2*x)+_
+   b*log(a+b*x)*sqrt(c*x^2)/(a^2*x)
+--R 
+--R
+--R                                            +----+
+--R                                            |   2
+--R        (b x log(b x + a) - b x log(x) - a)\|c x
+--R   (2)  ------------------------------------------
+--R                            2 2
+--R                           a x
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 600
+t0:=sqrt(c*x^2)/(x^4*(a+b*x))
+--R 
+--R
+--R           +----+
+--R           |   2
+--R          \|c x
+--R   (1)  -----------
+--R           5      4
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 600
+r0:=-1/2*sqrt(c*x^2)/(a*x^3)+b*sqrt(c*x^2)/(a^2*x^2)+b^2*log(x)*_
+   sqrt(c*x^2)/(a^3*x)-b^2*log(a+b*x)*sqrt(c*x^2)/(a^3*x)
+--R 
+--R
+--R                                                          +----+
+--R             2 2                 2 2                   2  |   2
+--R        (- 2b x log(b x + a) + 2b x log(x) + 2a b x - a )\|c x
+--R   (2)  --------------------------------------------------------
+--R                                    3 3
+--R                                  2a x
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 531
+
+)clear all
+
+--S 532 of 600
+t0:=x*(c*x^2)^(3/2)/(a+b*x)
+--R 
+--R
+--R             +----+
+--R           3 |   2
+--R        c x \|c x
+--R   (1)  -----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 600
+r0:=-a^3*c*sqrt(c*x^2)/b^4+1/2*a^2*c*x*sqrt(c*x^2)/b^3-1/3*a*c*x^2*_
+   sqrt(c*x^2)/b^2+1/4*c*x^3*sqrt(c*x^2)/b+a^4*c*log(a+b*x)*_
+   sqrt(c*x^2)/(b^5*x)
+--R 
+--R
+--R   (2)
+--R                                                                      +----+
+--R       4                   4   4       3   3     2 2   2      3       |   2
+--R   (12a c log(b x + a) + 3b c x  - 4a b c x  + 6a b c x  - 12a b c x)\|c x
+--R   -------------------------------------------------------------------------
+--R                                        5
+--R                                     12b x
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 534
+
+)clear all
+
+--S 535 of 600
+t0:=(c*x^2)^(3/2)/(a+b*x)
+--R 
+--R
+--R             +----+
+--R           2 |   2
+--R        c x \|c x
+--R   (1)  -----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 600
+r0:=a^2*c*sqrt(c*x^2)/b^3-1/2*a*c*x*sqrt(c*x^2)/b^2+_
+   1/3*c*x^2*sqrt(c*x^2)/b-a^3*c*log(a+b*x)*sqrt(c*x^2)/(b^4*x)
+--R 
+--R
+--R                                                               +----+
+--R             3                   3   3       2   2     2       |   2
+--R        (- 6a c log(b x + a) + 2b c x  - 3a b c x  + 6a b c x)\|c x
+--R   (2)  -------------------------------------------------------------
+--R                                       4
+--R                                     6b x
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 537
+
+)clear all
+
+--S 538 of 600
+t0:=(c*x^2)^(3/2)/(x*(a+b*x))
+--R 
+--R
+--R            +----+
+--R            |   2
+--R        c x\|c x
+--R   (1)  ----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 600
+r0:=-a*c*sqrt(c*x^2)/b^2+1/2*c*x*sqrt(c*x^2)/b+_
+   a^2*c*log(a+b*x)*sqrt(c*x^2)/(b^3*x)
+--R 
+--R
+--R                                                +----+
+--R           2                  2   2             |   2
+--R        (2a c log(b x + a) + b c x  - 2a b c x)\|c x
+--R   (2)  ----------------------------------------------
+--R                               3
+--R                             2b x
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 600
+t0:=(c*x^2)^(3/2)/(x^2*(a+b*x))
+--R 
+--R
+--R          +----+
+--R          |   2
+--R        c\|c x
+--R   (1)  --------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 600
+r0:=c*sqrt(c*x^2)/b-a*c*log(a+b*x)*sqrt(c*x^2)/(b^2*x)
+--R 
+--R
+--R                                     +----+
+--R                                     |   2
+--R        (- a c log(b x + a) + b c x)\|c x
+--R   (2)  -----------------------------------
+--R                         2
+--R                        b x
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 543
+
+)clear all
+
+--S 544 of 600
+t0:=(c*x^2)^(3/2)/(x^3*(a+b*x))
+--R 
+--R
+--R           +----+
+--R           |   2
+--R         c\|c x
+--R   (1)  ----------
+--R           2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 600
+r0:=c*log(a+b*x)*sqrt(c*x^2)/(b*x)
+--R 
+--R
+--R                       +----+
+--R                       |   2
+--R        c log(b x + a)\|c x
+--R   (2)  ---------------------
+--R                 b x
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 546
+
+)clear all
+
+--S 547 of 600
+t0:=(c*x^2)^(3/2)/(x^4*(a+b*x))
+--R 
+--R
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R   (1)  -----------
+--R           3      2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 600
+r0:=c*log(x)*sqrt(c*x^2)/(a*x)-c*log(a+b*x)*sqrt(c*x^2)/(a*x)
+--R 
+--R
+--R                                      +----+
+--R                                      |   2
+--R        (- c log(b x + a) + c log(x))\|c x
+--R   (2)  ------------------------------------
+--R                         a x
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 549
+
+)clear all
+
+--S 550 of 600
+t0:=(c*x^2)^(3/2)/(x^5*(a+b*x))
+--R 
+--R
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R   (1)  -----------
+--R           4      3
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 600
+r0:=-c*sqrt(c*x^2)/(a*x^2)-b*c*log(x)*sqrt(c*x^2)/(a^2*x)+_
+   b*c*log(a+b*x)*sqrt(c*x^2)/(a^2*x)
+--R 
+--R
+--R                                                  +----+
+--R                                                  |   2
+--R        (b c x log(b x + a) - b c x log(x) - a c)\|c x
+--R   (2)  ------------------------------------------------
+--R                               2 2
+--R                              a x
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 600
+t0:=(c*x^2)^(3/2)/(x^6*(a+b*x))
+--R 
+--R
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R   (1)  -----------
+--R           5      4
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 600
+r0:=-1/2*c*sqrt(c*x^2)/(a*x^3)+b*c*sqrt(c*x^2)/(a^2*x^2)+b^2*c*log(x)*_
+   sqrt(c*x^2)/(a^3*x)-b^2*c*log(a+b*x)*sqrt(c*x^2)/(a^3*x)
+--R 
+--R
+--R                                                                 +----+
+--R             2   2                 2   2                     2   |   2
+--R        (- 2b c x log(b x + a) + 2b c x log(x) + 2a b c x - a c)\|c x
+--R   (2)  ---------------------------------------------------------------
+--R                                       3 3
+--R                                     2a x
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 600
+t0:=(c*x^2)^(3/2)/(x^7*(a+b*x))
+--R 
+--R
+--R            +----+
+--R            |   2
+--R          c\|c x
+--R   (1)  -----------
+--R           6      5
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 600
+r0:=-1/3*c*sqrt(c*x^2)/(a*x^4)+1/2*b*c*sqrt(c*x^2)/(a^2*x^3)-_
+   b^2*c*sqrt(c*x^2)/(a^3*x^2)-b^3*c*log(x)*sqrt(c*x^2)/(a^4*x)+_
+   b^3*c*log(a+b*x)*sqrt(c*x^2)/(a^4*x)
+--R 
+--R
+--R   (2)
+--R                                                                       +----+
+--R      3   3                 3   3             2   2     2          3   |   2
+--R   (6b c x log(b x + a) - 6b c x log(x) - 6a b c x  + 3a b c x - 2a c)\|c x
+--R   --------------------------------------------------------------------------
+--R                                        4 4
+--R                                      6a x
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 558
+
+)clear all
+
+--S 559 of 600
+t0:=(c*x^2)^(5/2)/(a+b*x)
+--R 
+--R
+--R             +----+
+--R         2 4 |   2
+--R        c x \|c x
+--R   (1)  -----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 600
+r0:=a^4*c^2*sqrt(c*x^2)/b^5-1/2*a^3*c^2*x*sqrt(c*x^2)/b^4+1/3*a^2*c^2*x^2*_
+   sqrt(c*x^2)/b^3-1/4*a*c^2*x^3*sqrt(c*x^2)/b^2+1/5*c^2*x^4*sqrt(c*x^2)/b-_
+   a^5*c^2*log(a+b*x)*sqrt(c*x^2)/(b^6*x)
+--R 
+--R
+--R   (2)
+--R              5 2                  5 2 5        4 2 4      2 3 2 3      3 2 2 2
+--R         - 60a c log(b x + a) + 12b c x  - 15a b c x  + 20a b c x  - 30a b c x
+--R       + 
+--R            4   2
+--R         60a b c x
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R        6
+--R     60b x
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 600
+t0:=(c*x^2)^(5/2)/(x*(a+b*x))
+--R 
+--R
+--R             +----+
+--R         2 3 |   2
+--R        c x \|c x
+--R   (1)  -----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 600
+r0:=-a^3*c^2*sqrt(c*x^2)/b^4+1/2*a^2*c^2*x*sqrt(c*x^2)/b^3-_
+   1/3*a*c^2*x^2*sqrt(c*x^2)/b^2+1/4*c^2*x^3*sqrt(c*x^2)/b+a^4*c^2*_
+   log(a+b*x)*sqrt(c*x^2)/(b^5*x)
+--R 
+--R
+--R   (2)
+--R                                                                      +----+
+--R       4 2                 4 2 4       3 2 3     2 2 2 2      3   2   |   2
+--R   (12a c log(b x + a) + 3b c x  - 4a b c x  + 6a b c x  - 12a b c x)\|c x
+--R   -------------------------------------------------------------------------
+--R                                        5
+--R                                     12b x
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 600
+t0:=(c*x^2)^(5/2)/(x^2*(a+b*x))
+--R 
+--R
+--R             +----+
+--R         2 2 |   2
+--R        c x \|c x
+--R   (1)  -----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 600
+r0:=a^2*c^2*sqrt(c*x^2)/b^3-1/2*a*c^2*x*sqrt(c*x^2)/b^2+1/3*c^2*x^2*_
+   sqrt(c*x^2)/b-a^3*c^2*log(a+b*x)*sqrt(c*x^2)/(b^4*x)
+--R 
+--R
+--R                                                               +----+
+--R             3 2                 3 2 3       2 2 2     2   2   |   2
+--R        (- 6a c log(b x + a) + 2b c x  - 3a b c x  + 6a b c x)\|c x
+--R   (2)  -------------------------------------------------------------
+--R                                       4
+--R                                     6b x
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 567
+
+)clear all
+
+--S 568 of 600
+t0:=(c*x^2)^(5/2)/(x^3*(a+b*x))
+--R 
+--R
+--R            +----+
+--R         2  |   2
+--R        c x\|c x
+--R   (1)  ----------
+--R          b x + a
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 600
+r0:=-a*c^2*sqrt(c*x^2)/b^2+1/2*c^2*x*sqrt(c*x^2)/b+a^2*c^2*log(a+b*x)*_
+   sqrt(c*x^2)/(b^3*x)
+--R 
+--R
+--R                                                +----+
+--R           2 2                2 2 2         2   |   2
+--R        (2a c log(b x + a) + b c x  - 2a b c x)\|c x
+--R   (2)  ----------------------------------------------
+--R                               3
+--R                             2b x
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 600
+t0:=(c*x^2)^(5/2)/(x^4*(a+b*x))
+--R 
+--R
+--R           +----+
+--R         2 |   2
+--R        c \|c x
+--R   (1)  ---------
+--R         b x + a
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 600
+r0:=c^2*sqrt(c*x^2)/b-a*c^2*log(a+b*x)*sqrt(c*x^2)/(b^2*x)
+--R 
+--R
+--R                                     +----+
+--R              2                  2   |   2
+--R        (- a c log(b x + a) + b c x)\|c x
+--R   (2)  -----------------------------------
+--R                         2
+--R                        b x
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+)clear all
+
+--S 574 of 600
+t0:=(c*x^2)^(5/2)/(x^5*(a+b*x))
+--R 
+--R
+--R            +----+
+--R          2 |   2
+--R         c \|c x
+--R   (1)  ----------
+--R           2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 600
+r0:=c^2*log(a+b*x)*sqrt(c*x^2)/(b*x)
+--R 
+--R
+--R                       +----+
+--R         2             |   2
+--R        c log(b x + a)\|c x
+--R   (2)  ---------------------
+--R                 b x
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 600
+t0:=(c*x^2)^(5/2)/(x^6*(a+b*x))
+--R 
+--R
+--R            +----+
+--R          2 |   2
+--R         c \|c x
+--R   (1)  -----------
+--R           3      2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 600
+r0:=c^2*log(x)*sqrt(c*x^2)/(a*x)-c^2*log(a+b*x)*sqrt(c*x^2)/(a*x)
+--R 
+--R
+--R                                      +----+
+--R            2                2        |   2
+--R        (- c log(b x + a) + c log(x))\|c x
+--R   (2)  ------------------------------------
+--R                         a x
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 579
+
+)clear all
+
+--S 580 of 600
+t0:=(c*x^2)^(5/2)/(x^7*(a+b*x))
+--R 
+--R
+--R            +----+
+--R          2 |   2
+--R         c \|c x
+--R   (1)  -----------
+--R           4      3
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 600
+r0:=-c^2*sqrt(c*x^2)/(a*x^2)-b*c^2*log(x)*sqrt(c*x^2)/(a^2*x)+_
+   b*c^2*log(a+b*x)*sqrt(c*x^2)/(a^2*x)
+--R 
+--R
+--R                                                   +----+
+--R            2                    2              2  |   2
+--R        (b c x log(b x + a) - b c x log(x) - a c )\|c x
+--R   (2)  -------------------------------------------------
+--R                                2 2
+--R                               a x
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 600
+t0:=x^4/((a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                4
+--R               x
+--R   (1)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 600
+r0:=a^2*x^2/(b^3*sqrt(c*x^2))-1/2*a*x^3/(b^2*sqrt(c*x^2))+_
+   1/3*x^4/(b*sqrt(c*x^2))-a^3*x*log(a+b*x)/(b^4*sqrt(c*x^2))
+--R 
+--R
+--R            3                   3 4       2 3     2   2
+--R        - 6a x log(b x + a) + 2b x  - 3a b x  + 6a b x
+--R   (2)  -----------------------------------------------
+--R                               +----+
+--R                             4 |   2
+--R                           6b \|c x
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 600
+t0:=x^3/((a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 600
+r0:=-a*x^2/(b^2*sqrt(c*x^2))+1/2*x^3/(b*sqrt(c*x^2))+_
+   a^2*x*log(a+b*x)/(b^3*sqrt(c*x^2))
+--R 
+--R
+--R          2                  2 3         2
+--R        2a x log(b x + a) + b x  - 2a b x
+--R   (2)  ----------------------------------
+--R                        +----+
+--R                      3 |   2
+--R                    2b \|c x
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 588
+
+)clear all
+
+--S 589 of 600
+t0:=x^2/((a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 600
+r0:=x^2/(b*sqrt(c*x^2))-a*x*log(a+b*x)/(b^2*sqrt(c*x^2))
+--R 
+--R
+--R                                2
+--R        - a x log(b x + a) + b x
+--R   (2)  -------------------------
+--R                   +----+
+--R                 2 |   2
+--R                b \|c x
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 591
+
+)clear all
+
+--S 592 of 600
+t0:=x/((a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                x
+--R   (1)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 600
+r0:=x*log(a+b*x)/(b*sqrt(c*x^2))
+--R 
+--R
+--R        x log(b x + a)
+--R   (2)  --------------
+--R             +----+
+--R             |   2
+--R           b\|c x
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 594
+
+)clear all
+
+--S 595 of 600
+t0:=1/((a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R                  +----+
+--R                  |   2
+--R        (b x + a)\|c x
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 600
+r0:=x*log(x)/(a*sqrt(c*x^2))-x*log(a+b*x)/(a*sqrt(c*x^2))
+--R 
+--R
+--R        - x log(b x + a) + x log(x)
+--R   (2)  ---------------------------
+--R                    +----+
+--R                    |   2
+--R                  a\|c x
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 597
+
+)clear all
+
+--S 598 of 600
+t0:=1/(x*(a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R                     +----+
+--R            2        |   2
+--R        (b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 600
+r0:=(-1)/(a*sqrt(c*x^2))-b*x*log(x)/(a^2*sqrt(c*x^2))+_
+   b*x*log(a+b*x)/(a^2*sqrt(c*x^2))
+--R 
+--R
+--R        b x log(b x + a) - b x log(x) - a
+--R   (2)  ---------------------------------
+--R                       +----+
+--R                     2 |   2
+--R                    a \|c x
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder22c.input.pamphlet b/src/input/richder22c.input.pamphlet
new file mode 100644
index 0000000..40bc5ee
--- /dev/null
+++ b/src/input/richder22c.input.pamphlet
@@ -0,0 +1,7857 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder22c.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Algebraic function problems.input
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder22c.output
+)spool richder22c.output
+)set message test on
+)set message auto off
+)clear all
+
+
+--S 1 of 600
+t0:=1/(x^2*(a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                      +----+
+--R            3      2  |   2
+--R        (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 600
+r0:=b/(a^2*sqrt(c*x^2))+(-1/2)/(a*x*sqrt(c*x^2))+b^2*x*log(x)/(a^3*_
+   sqrt(c*x^2))-b^2*x*log(a+b*x)/(a^3*sqrt(c*x^2))
+--R 
+--R
+--R            2 2                 2 2                   2
+--R        - 2b x log(b x + a) + 2b x log(x) + 2a b x - a
+--R   (2)  -----------------------------------------------
+--R                               +----+
+--R                            3  |   2
+--R                          2a x\|c x
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 600
+t0:=1/(x^3*(a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                      +----+
+--R            4      3  |   2
+--R        (b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 600
+r0:=-b^2/(a^3*sqrt(c*x^2))+(-1/3)/(a*x^2*sqrt(c*x^2))+_
+   1/2*b/(a^2*x*sqrt(c*x^2))-b^3*x*log(x)/(a^4*sqrt(c*x^2))+_
+   b^3*x*log(a+b*x)/(a^4*sqrt(c*x^2))
+--R 
+--R
+--R          3 3                 3 3             2 2     2        3
+--R        6b x log(b x + a) - 6b x log(x) - 6a b x  + 3a b x - 2a
+--R   (2)  --------------------------------------------------------
+--R                                    +----+
+--R                                4 2 |   2
+--R                              6a x \|c x
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 600
+t0:=x^6/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                  4
+--R                 x
+--R   (1)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 600
+r0:=a^2*x^2/(b^3*c*sqrt(c*x^2))-1/2*a*x^3/(b^2*c*sqrt(c*x^2))+_
+   1/3*x^4/(b*c*sqrt(c*x^2))-a^3*x*log(a+b*x)/(b^4*c*sqrt(c*x^2))
+--R 
+--R
+--R            3                   3 4       2 3     2   2
+--R        - 6a x log(b x + a) + 2b x  - 3a b x  + 6a b x
+--R   (2)  -----------------------------------------------
+--R                               +----+
+--R                            4  |   2
+--R                          6b c\|c x
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 600
+t0:=x^5/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 600
+r0:=-a*x^2/(b^2*c*sqrt(c*x^2))+1/2*x^3/(b*c*sqrt(c*x^2))+_
+   a^2*x*log(a+b*x)/(b^3*c*sqrt(c*x^2))
+--R 
+--R
+--R          2                  2 3         2
+--R        2a x log(b x + a) + b x  - 2a b x
+--R   (2)  ----------------------------------
+--R                         +----+
+--R                      3  |   2
+--R                    2b c\|c x
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 600
+t0:=x^4/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                  2
+--R                 x
+--R   (1)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 600
+r0:=x^2/(b*c*sqrt(c*x^2))-a*x*log(a+b*x)/(b^2*c*sqrt(c*x^2))
+--R 
+--R
+--R                                2
+--R        - a x log(b x + a) + b x
+--R   (2)  -------------------------
+--R                    +----+
+--R                 2  |   2
+--R                b c\|c x
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 600
+t0:=x^3/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                  x
+--R   (1)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 600
+r0:=x*log(a+b*x)/(b*c*sqrt(c*x^2))
+--R 
+--R
+--R        x log(b x + a)
+--R   (2)  --------------
+--R              +----+
+--R              |   2
+--R          b c\|c x
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 600
+t0:=x^2/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R                      +----+
+--R                      |   2
+--R        (b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 600
+r0:=x*log(x)/(a*c*sqrt(c*x^2))-x*log(a+b*x)/(a*c*sqrt(c*x^2))
+--R 
+--R
+--R        - x log(b x + a) + x log(x)
+--R   (2)  ---------------------------
+--R                     +----+
+--R                     |   2
+--R                 a c\|c x
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 600
+t0:=x/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R                         +----+
+--R              2          |   2
+--R        (b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 600
+r0:=(-1)/(a*c*sqrt(c*x^2))-b*x*log(x)/(a^2*c*sqrt(c*x^2))+_
+   b*x*log(a+b*x)/(a^2*c*sqrt(c*x^2))
+--R 
+--R
+--R        b x log(b x + a) - b x log(x) - a
+--R   (2)  ---------------------------------
+--R                        +----+
+--R                     2  |   2
+--R                    a c\|c x
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 600
+t0:=1/((c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R                          +----+
+--R              3        2  |   2
+--R        (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 600
+r0:=b/(a^2*c*sqrt(c*x^2))+(-1/2)/(a*c*x*sqrt(c*x^2))+_
+   b^2*x*log(x)/(a^3*c*sqrt(c*x^2))-b^2*x*log(a+b*x)/(a^3*c*sqrt(c*x^2))
+--R 
+--R
+--R            2 2                 2 2                   2
+--R        - 2b x log(b x + a) + 2b x log(x) + 2a b x - a
+--R   (2)  -----------------------------------------------
+--R                                +----+
+--R                           3    |   2
+--R                         2a c x\|c x
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 600
+t0:=1/(x*(c*x^2)^(3/2)*(a+b*x))
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R                          +----+
+--R              4        3  |   2
+--R        (b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 600
+r0:=-b^2/(a^3*c*sqrt(c*x^2))+(-1/3)/(a*c*x^2*sqrt(c*x^2))+_
+   1/2*b/(a^2*c*x*sqrt(c*x^2))-b^3*x*log(x)/(a^4*c*sqrt(c*x^2))+_
+   b^3*x*log(a+b*x)/(a^4*c*sqrt(c*x^2))
+--R 
+--R
+--R          3 3                 3 3             2 2     2        3
+--R        6b x log(b x + a) - 6b x log(x) - 6a b x  + 3a b x - 2a
+--R   (2)  --------------------------------------------------------
+--R                                     +----+
+--R                               4   2 |   2
+--R                             6a c x \|c x
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 600
+t0:=x^3*sqrt(c*x^2)/(a+b*x)^2
+--R 
+--R
+--R                +----+
+--R              3 |   2
+--R             x \|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 600
+r0:=3*a^2*sqrt(c*x^2)/b^4-a*x*sqrt(c*x^2)/b^3+1/3*x^2*sqrt(c*x^2)/b^2-_
+   a^4*sqrt(c*x^2)/(b^5*x*(a+b*x))-4*a^3*log(a+b*x)*sqrt(c*x^2)/(b^5*x)
+--R 
+--R
+--R   (2)
+--R                 3         4                 4 4       3 3     2 2 2     3
+--R           (- 12a b x - 12a )log(b x + a) + b x  - 2a b x  + 6a b x  + 9a b x
+--R         + 
+--R               4
+--R           - 3a
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       6 2       5
+--R     3b x  + 3a b x
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 600
+t0:=x^2*sqrt(c*x^2)/(a+b*x)^2
+--R 
+--R
+--R                +----+
+--R              2 |   2
+--R             x \|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 600
+r0:=-2*a*sqrt(c*x^2)/b^3+1/2*x*sqrt(c*x^2)/b^2+a^3*sqrt(c*x^2)/_
+   (b^4*x*(a+b*x))+3*a^2*log(a+b*x)*sqrt(c*x^2)/(b^4*x)
+--R 
+--R
+--R                                                                     +----+
+--R            2        3                 3 3       2 2     2        3  |   2
+--R        ((6a b x + 6a )log(b x + a) + b x  - 3a b x  - 4a b x + 2a )\|c x
+--R   (2)  -------------------------------------------------------------------
+--R                                     5 2       4
+--R                                   2b x  + 2a b x
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 600
+t0:=x*sqrt(c*x^2)/(a+b*x)^2
+--R 
+--R
+--R               +----+
+--R               |   2
+--R             x\|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 600
+r0:=sqrt(c*x^2)/b^2-a^2*sqrt(c*x^2)/(b^3*x*(a+b*x))-_
+   2*a*log(a+b*x)*sqrt(c*x^2)/(b^3*x)
+--R 
+--R
+--R                                                           +----+
+--R                       2                 2 2            2  |   2
+--R        ((- 2a b x - 2a )log(b x + a) + b x  + a b x - a )\|c x
+--R   (2)  ---------------------------------------------------------
+--R                                4 2      3
+--R                               b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 600
+t0:=sqrt(c*x^2)/(a+b*x)^2
+--R 
+--R
+--R               +----+
+--R               |   2
+--R              \|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 600
+r0:=a*sqrt(c*x^2)/(b^2*x*(a+b*x))+log(a+b*x)*sqrt(c*x^2)/(b^2*x)
+--R 
+--R
+--R                                    +----+
+--R                                    |   2
+--R        ((b x + a)log(b x + a) + a)\|c x
+--R   (2)  ----------------------------------
+--R                    3 2      2
+--R                   b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 600
+t0:=sqrt(c*x^2)/(x*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R               \|c x
+--R   (1)  --------------------
+--R         2 3         2    2
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 600
+r0:=-sqrt(c*x^2)/(b*x*(a+b*x))
+--R 
+--R
+--R              +----+
+--R              |   2
+--R             \|c x
+--R   (2)  - ------------
+--R           2 2
+--R          b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 600
+t0:=sqrt(c*x^2)/(x^2*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R               \|c x
+--R   (1)  ---------------------
+--R         2 4         3    2 2
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 600
+r0:=sqrt(c*x^2)/(a*x*(a+b*x))+log(x)*sqrt(c*x^2)/(a^2*x)-_
+   log(a+b*x)*sqrt(c*x^2)/(a^2*x)
+--R 
+--R
+--R                                                        +----+
+--R                                                        |   2
+--R        ((- b x - a)log(b x + a) + (b x + a)log(x) + a)\|c x
+--R   (2)  ------------------------------------------------------
+--R                              2   2    3
+--R                             a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 600
+t0:=sqrt(c*x^2)/(x^3*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R               \|c x
+--R   (1)  ---------------------
+--R         2 5         4    2 3
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 600
+r0:=-sqrt(c*x^2)/(a^2*x^2)-b*sqrt(c*x^2)/(a^2*x*(a+b*x))-_
+   2*b*log(x)*sqrt(c*x^2)/(a^3*x)+2*b*log(a+b*x)*sqrt(c*x^2)/(a^3*x)
+--R 
+--R
+--R   (2)
+--R           2 2                              2 2                             2
+--R       ((2b x  + 2a b x)log(b x + a) + (- 2b x  - 2a b x)log(x) - 2a b x - a )
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R      3   3    4 2
+--R     a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 600
+t0:=sqrt(c*x^2)/(x^4*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R               \|c x
+--R   (1)  ---------------------
+--R         2 6         5    2 4
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 600
+r0:=-1/2*sqrt(c*x^2)/(a^2*x^3)+2*b*sqrt(c*x^2)/(a^3*x^2)+b^2*sqrt(c*x^2)/_
+   (a^3*x*(a+b*x))+3*b^2*log(x)*sqrt(c*x^2)/(a^4*x)-3*b^2*log(a+b*x)*_
+   sqrt(c*x^2)/(a^4*x)
+--R 
+--R
+--R   (2)
+--R              3 3       2 2                   3 3       2 2              2 2
+--R         (- 6b x  - 6a b x )log(b x + a) + (6b x  + 6a b x )log(x) + 6a b x
+--R       + 
+--R           2       3
+--R         3a b x - a
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       4   4     5 3
+--R     2a b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 600
+t0:=x*(c*x^2)^(3/2)/(a+b*x)^2
+--R 
+--R
+--R                 +----+
+--R               3 |   2
+--R            c x \|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 600
+r0:=3*a^2*c*sqrt(c*x^2)/b^4-a*c*x*sqrt(c*x^2)/b^3+1/3*c*x^2*sqrt(c*x^2)/b^2-_
+   a^4*c*sqrt(c*x^2)/(b^5*x*(a+b*x))-4*a^3*c*log(a+b*x)*sqrt(c*x^2)/(b^5*x)
+--R 
+--R
+--R   (2)
+--R               3           4                  4   4       3   3     2 2   2
+--R         (- 12a b c x - 12a c)log(b x + a) + b c x  - 2a b c x  + 6a b c x
+--R       + 
+--R           3          4
+--R         9a b c x - 3a c
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       6 2       5
+--R     3b x  + 3a b x
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 600
+t0:=(c*x^2)^(3/2)/(a+b*x)^2
+--R 
+--R
+--R                 +----+
+--R               2 |   2
+--R            c x \|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 600
+r0:=-2*a*c*sqrt(c*x^2)/b^3+1/2*c*x*sqrt(c*x^2)/b^2+a^3*c*sqrt(c*x^2)/_
+   (b^4*x*(a+b*x))+3*a^2*c*log(a+b*x)*sqrt(c*x^2)/(b^4*x)
+--R 
+--R
+--R   (2)
+--R                                                                          +----+
+--R       2          3                  3   3       2   2     2          3   |   2
+--R   ((6a b c x + 6a c)log(b x + a) + b c x  - 3a b c x  - 4a b c x + 2a c)\|c x
+--R   -----------------------------------------------------------------------------
+--R                                     5 2       4
+--R                                   2b x  + 2a b x
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 600
+t0:=(c*x^2)^(3/2)/(x*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R            c x\|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 600
+r0:=c*sqrt(c*x^2)/b^2-a^2*c*sqrt(c*x^2)/(b^3*x*(a+b*x))-_
+   2*a*c*log(a+b*x)*sqrt(c*x^2)/(b^3*x)
+--R 
+--R
+--R                                                                   +----+
+--R                         2                  2   2              2   |   2
+--R        ((- 2a b c x - 2a c)log(b x + a) + b c x  + a b c x - a c)\|c x
+--R   (2)  -----------------------------------------------------------------
+--R                                    4 2      3
+--R                                   b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 600
+t0:=(c*x^2)^(3/2)/(x^2*(a+b*x)^2)
+--R 
+--R
+--R               +----+
+--R               |   2
+--R             c\|c x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 600
+r0:=a*c*sqrt(c*x^2)/(b^2*x*(a+b*x))+c*log(a+b*x)*sqrt(c*x^2)/(b^2*x)
+--R 
+--R
+--R                                          +----+
+--R                                          |   2
+--R        ((b c x + a c)log(b x + a) + a c)\|c x
+--R   (2)  ----------------------------------------
+--R                       3 2      2
+--R                      b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 600
+t0:=(c*x^2)^(3/2)/(x^3*(a+b*x)^2)
+--R 
+--R
+--R                +----+
+--R                |   2
+--R              c\|c x
+--R   (1)  --------------------
+--R         2 3         2    2
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 600
+r0:=-c*sqrt(c*x^2)/(b*x*(a+b*x))
+--R 
+--R
+--R              +----+
+--R              |   2
+--R            c\|c x
+--R   (2)  - ------------
+--R           2 2
+--R          b x  + a b x
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 600
+t0:=(c*x^2)^(3/2)/(x^4*(a+b*x)^2)
+--R 
+--R
+--R                 +----+
+--R                 |   2
+--R               c\|c x
+--R   (1)  ---------------------
+--R         2 4         3    2 2
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 600
+r0:=c*sqrt(c*x^2)/(a*x*(a+b*x))+c*log(x)*sqrt(c*x^2)/(a^2*x)-_
+   c*log(a+b*x)*sqrt(c*x^2)/(a^2*x)
+--R 
+--R
+--R                                                                  +----+
+--R                                                                  |   2
+--R        ((- b c x - a c)log(b x + a) + (b c x + a c)log(x) + a c)\|c x
+--R   (2)  ----------------------------------------------------------------
+--R                                   2   2    3
+--R                                  a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 600
+t0:=(c*x^2)^(3/2)/(x^5*(a+b*x)^2)
+--R 
+--R
+--R                 +----+
+--R                 |   2
+--R               c\|c x
+--R   (1)  ---------------------
+--R         2 5         4    2 3
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 600
+r0:=-c*sqrt(c*x^2)/(a^2*x^2)-b*c*sqrt(c*x^2)/(a^2*x*(a+b*x))-_
+   2*b*c*log(x)*sqrt(c*x^2)/(a^3*x)+2*b*c*log(a+b*x)*sqrt(c*x^2)/(a^3*x)
+--R 
+--R
+--R   (2)
+--R            2   2                                2   2
+--R         (2b c x  + 2a b c x)log(b x + a) + (- 2b c x  - 2a b c x)log(x)
+--R       + 
+--R                       2
+--R         - 2a b c x - a c
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R      3   3    4 2
+--R     a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 600
+t0:=(c*x^2)^(3/2)/(x^6*(a+b*x)^2)
+--R 
+--R
+--R                 +----+
+--R                 |   2
+--R               c\|c x
+--R   (1)  ---------------------
+--R         2 6         5    2 4
+--R        b x  + 2a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 600
+r0:=-1/2*c*sqrt(c*x^2)/(a^2*x^3)+2*b*c*sqrt(c*x^2)/(a^3*x^2)+_
+   b^2*c*sqrt(c*x^2)/(a^3*x*(a+b*x))+3*b^2*c*log(x)*sqrt(c*x^2)/(a^4*x)-_
+   3*b^2*c*log(a+b*x)*sqrt(c*x^2)/(a^4*x)
+--R 
+--R
+--R   (2)
+--R              3   3       2   2                   3   3       2   2
+--R         (- 6b c x  - 6a b c x )log(b x + a) + (6b c x  + 6a b c x )log(x)
+--R       + 
+--R             2   2     2         3
+--R         6a b c x  + 3a b c x - a c
+--R    *
+--R        +----+
+--R        |   2
+--R       \|c x
+--R  /
+--R       4   4     5 3
+--R     2a b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 600
+t0:=x^5/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                      5
+--R                     x
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 600
+r0:=3*a^2*x^2/(b^4*sqrt(c*x^2))-a*x^3/(b^3*sqrt(c*x^2))+_
+   1/3*x^4/(b^2*sqrt(c*x^2))-a^4*x/(b^5*(a+b*x)*sqrt(c*x^2))-_
+   4*a^3*x*log(a+b*x)/(b^5*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R         3   2      4                  4 5       3 4     2 2 3     3   2     4
+--R   (- 12a b x  - 12a x)log(b x + a) + b x  - 2a b x  + 6a b x  + 9a b x  - 3a x
+--R   ----------------------------------------------------------------------------
+--R                                              +----+
+--R                                  6        5  |   2
+--R                               (3b x + 3a b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 600
+t0:=x^4/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                      4
+--R                     x
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 600
+r0:=-2*a*x^2/(b^3*sqrt(c*x^2))+1/2*x^3/(b^2*sqrt(c*x^2))+_
+   a^3*x/(b^4*(a+b*x)*sqrt(c*x^2))+3*a^2*x*log(a+b*x)/(b^4*sqrt(c*x^2))
+--R 
+--R
+--R           2   2     3                  3 4       2 3     2   2     3
+--R        (6a b x  + 6a x)log(b x + a) + b x  - 3a b x  - 4a b x  + 2a x
+--R   (2)  --------------------------------------------------------------
+--R                                            +----+
+--R                                5        4  |   2
+--R                             (2b x + 2a b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 600
+t0:=x^3/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                      3
+--R                     x
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 600
+r0:=x^2/(b^2*sqrt(c*x^2))-a^2*x/(b^3*(a+b*x)*sqrt(c*x^2))-_
+   2*a*x*log(a+b*x)/(b^3*sqrt(c*x^2))
+--R 
+--R
+--R                 2     2                  2 3        2    2
+--R        (- 2a b x  - 2a x)log(b x + a) + b x  + a b x  - a x
+--R   (2)  ----------------------------------------------------
+--R                                      +----+
+--R                           4       3  |   2
+--R                         (b x + a b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 600
+t0:=x^2/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 600
+r0:=a*x/(b^2*(a+b*x)*sqrt(c*x^2))+x*log(a+b*x)/(b^2*sqrt(c*x^2))
+--R 
+--R
+--R            2
+--R        (b x  + a x)log(b x + a) + a x
+--R   (2)  ------------------------------
+--R                           +----+
+--R                3       2  |   2
+--R              (b x + a b )\|c x
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 600
+t0:=x/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                     x
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 600
+r0:=-x/(b*(a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                   x
+--R   (2)  - ------------------
+--R                      +----+
+--R            2         |   2
+--R          (b x + a b)\|c x
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 600
+t0:=1/((a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                             +----+
+--R          2 2             2  |   2
+--R        (b x  + 2a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 600
+r0:=x/(a*(a+b*x)*sqrt(c*x^2))+x*log(x)/(a^2*sqrt(c*x^2))-_
+   x*log(a+b*x)/(a^2*sqrt(c*x^2))
+--R 
+--R
+--R              2                          2
+--R        (- b x  - a x)log(b x + a) + (b x  + a x)log(x) + a x
+--R   (2)  -----------------------------------------------------
+--R                                      +----+
+--R                           2       3  |   2
+--R                         (a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 600
+t0:=1/(x*(a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R                               +----+
+--R          2 3         2    2   |   2
+--R        (b x  + 2a b x  + a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 600
+r0:=(-1)/(a^2*sqrt(c*x^2))-b*x/(a^2*(a+b*x)*sqrt(c*x^2))-_
+   2*b*x*log(x)/(a^3*sqrt(c*x^2))+2*b*x*log(a+b*x)/(a^3*sqrt(c*x^2))
+--R 
+--R
+--R           2 2                              2 2                             2
+--R        (2b x  + 2a b x)log(b x + a) + (- 2b x  - 2a b x)log(x) - 2a b x - a
+--R   (2)  ---------------------------------------------------------------------
+--R                                              +----+
+--R                                   3       4  |   2
+--R                                 (a b x + a )\|c x
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 600
+t0:=1/(x^2*(a+b*x)^2*sqrt(c*x^2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                                +----+
+--R          2 4         3    2 2  |   2
+--R        (b x  + 2a b x  + a x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 600
+r0:=2*b/(a^3*sqrt(c*x^2))+(-1/2)/(a^2*x*sqrt(c*x^2))+b^2*x/(a^3*(a+b*x)*_
+   sqrt(c*x^2))+3*b^2*x*log(x)/(a^4*sqrt(c*x^2))-_
+   3*b^2*x*log(a+b*x)/(a^4*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R            3 3       2 2                   3 3       2 2              2 2
+--R       (- 6b x  - 6a b x )log(b x + a) + (6b x  + 6a b x )log(x) + 6a b x
+--R     + 
+--R         2       3
+--R       3a b x - a
+--R  /
+--R                      +----+
+--R        4   2     5   |   2
+--R     (2a b x  + 2a x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 600
+t0:=x^5/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                        3
+--R                       x
+--R   (1)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 600
+r0:=x^2/(b^2*c*sqrt(c*x^2))-a^2*x/(b^3*c*(a+b*x)*sqrt(c*x^2))-_
+   2*a*x*log(a+b*x)/(b^3*c*sqrt(c*x^2))
+--R 
+--R
+--R                 2     2                  2 3        2    2
+--R        (- 2a b x  - 2a x)log(b x + a) + b x  + a b x  - a x
+--R   (2)  ----------------------------------------------------
+--R                                       +----+
+--R                         4         3   |   2
+--R                       (b c x + a b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 600
+t0:=x^4/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                        2
+--R                       x
+--R   (1)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 600
+r0:=a*x/(b^2*c*(a+b*x)*sqrt(c*x^2))+x*log(a+b*x)/(b^2*c*sqrt(c*x^2))
+--R 
+--R
+--R            2
+--R        (b x  + a x)log(b x + a) + a x
+--R   (2)  ------------------------------
+--R                            +----+
+--R              3         2   |   2
+--R            (b c x + a b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 600
+t0:=x^3/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                        x
+--R   (1)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 600
+r0:=-x/(b*c*(a+b*x)*sqrt(c*x^2))
+--R 
+--R
+--R                     x
+--R   (2)  - ----------------------
+--R                          +----+
+--R            2             |   2
+--R          (b c x + a b c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 600
+t0:=x^2/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R                                  +----+
+--R          2   2               2   |   2
+--R        (b c x  + 2a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 600
+r0:=x/(a*c*(a+b*x)*sqrt(c*x^2))+x*log(x)/(a^2*c*sqrt(c*x^2))-_
+   x*log(a+b*x)/(a^2*c*sqrt(c*x^2))
+--R 
+--R
+--R              2                          2
+--R        (- b x  - a x)log(b x + a) + (b x  + a x)log(x) + a x
+--R   (2)  -----------------------------------------------------
+--R                                        +----+
+--R                          2         3   |   2
+--R                        (a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 600
+t0:=x/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                         1
+--R   (1)  -----------------------------------
+--R                                     +----+
+--R          2   3           2    2     |   2
+--R        (b c x  + 2a b c x  + a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 600
+r0:=(-1)/(a^2*c*sqrt(c*x^2))-b*x/(a^2*c*(a+b*x)*sqrt(c*x^2))-_
+   2*b*x*log(x)/(a^3*c*sqrt(c*x^2))+2*b*x*log(a+b*x)/(a^3*c*sqrt(c*x^2))
+--R 
+--R
+--R           2 2                              2 2                             2
+--R        (2b x  + 2a b x)log(b x + a) + (- 2b x  - 2a b x)log(x) - 2a b x - a
+--R   (2)  ---------------------------------------------------------------------
+--R                                                +----+
+--R                                  3         4   |   2
+--R                                (a b c x + a c)\|c x
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 600
+t0:=1/((c*x^2)^(3/2)*(a+b*x)^2)
+--R 
+--R
+--R                          1
+--R   (1)  ------------------------------------
+--R                                      +----+
+--R          2   4           3    2   2  |   2
+--R        (b c x  + 2a b c x  + a c x )\|c x
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 600
+r0:=2*b/(a^3*c*sqrt(c*x^2))+(-1/2)/(a^2*c*x*sqrt(c*x^2))+_
+   b^2*x/(a^3*c*(a+b*x)*sqrt(c*x^2))+3*b^2*x*log(x)/(a^4*c*sqrt(c*x^2))-_
+   3*b^2*x*log(a+b*x)/(a^4*c*sqrt(c*x^2))
+--R 
+--R
+--R   (2)
+--R            3 3       2 2                   3 3       2 2              2 2
+--R       (- 6b x  - 6a b x )log(b x + a) + (6b x  + 6a b x )log(x) + 6a b x
+--R     + 
+--R         2       3
+--R       3a b x - a
+--R  /
+--R                          +----+
+--R        4     2     5     |   2
+--R     (2a b c x  + 2a c x)\|c x
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 600
+t0:=x^m*(c*x^2)^p*(a+b*x)^(-2-m-2*p)
+--R 
+--R
+--R         m         - 2p - m - 2    2 p
+--R   (1)  x (b x + a)            (c x )
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 600
+r0:=x^(1+m)*(c*x^2)^p*(a+b*x)^(-1-m-2*p)/(a*(1+m+2*p))
+--R 
+--R
+--R         m + 1         - 2p - m - 1    2 p
+--R        x     (b x + a)            (c x )
+--R   (2)  ----------------------------------
+--R                  2a p + a m + a
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 600
+t0:=x^3*(c*x^2)^p*(a+b*x)^(-5-2*p)
+--R 
+--R
+--R         3         - 2p - 5    2 p
+--R   (1)  x (b x + a)        (c x )
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 600
+r0:=1/2*x^4*(c*x^2)^p/(a*(2+p)*(a+b*x)^(2*(2+p)))
+--R 
+--R
+--R                  4    2 p
+--R                 x (c x )
+--R   (2)  --------------------------
+--R                            2p + 4
+--R        (2a p + 4a)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 600
+t0:=x^2*(c*x^2)^p*(a+b*x)^(-4-2*p)
+--R 
+--R
+--R         2         - 2p - 4    2 p
+--R   (1)  x (b x + a)        (c x )
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 600
+r0:=x^3*(c*x^2)^p*(a+b*x)^(-3-2*p)/(a*(3+2*p))
+--R 
+--R
+--R         3         - 2p - 3    2 p
+--R        x (b x + a)        (c x )
+--R   (2)  --------------------------
+--R                 2a p + 3a
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 600
+t0:=x*(c*x^2)^p*(a+b*x)^(-3-2*p)
+--R 
+--R
+--R                   - 2p - 3    2 p
+--R   (1)  x (b x + a)        (c x )
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 600
+r0:=1/2*x^2*(c*x^2)^p/(a*(1+p)*(a+b*x)^(2*(1+p)))
+--R 
+--R
+--R                  2    2 p
+--R                 x (c x )
+--R   (2)  --------------------------
+--R                            2p + 2
+--R        (2a p + 2a)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 600
+t0:=(c*x^2)^p*(a+b*x)^(-2-2*p)
+--R 
+--R
+--R                 - 2p - 2    2 p
+--R   (1)  (b x + a)        (c x )
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 600
+r0:=x*(c*x^2)^p*(a+b*x)^(-1-2*p)/(a*(1+2*p))
+--R 
+--R
+--R                   - 2p - 1    2 p
+--R        x (b x + a)        (c x )
+--R   (2)  --------------------------
+--R                 2a p + a
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 600
+t0:=(c*x^2)^p*(a+b*x)^(-1-2*p)/x
+--R 
+--R
+--R                 - 2p - 1    2 p
+--R        (b x + a)        (c x )
+--R   (1)  ------------------------
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 600
+r0:=1/2*(c*x^2)^p/(a*p*(a+b*x)^(2*p))
+--R 
+--R
+--R                 2 p
+--R             (c x )
+--R   (2)  ----------------
+--R                      2p
+--R        2a p (b x + a)
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 600
+t0:=(c*x^2)^p/(x^2*(a+b*x)^(2*p))
+--R 
+--R
+--R               2 p
+--R           (c x )
+--R   (1)  -------------
+--R         2         2p
+--R        x (b x + a)
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 600
+r0:=-(c*x^2)^p*(a+b*x)^(1-2*p)/(a*(1-2*p)*x)
+--R 
+--R
+--R                 - 2p + 1    2 p
+--R        (b x + a)        (c x )
+--R   (2)  ------------------------
+--R               (2a p - a)x
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 600
+t0:=(c*x^2)^p*(a+b*x)^(1-2*p)/x^3
+--R 
+--R
+--R                 - 2p + 1    2 p
+--R        (b x + a)        (c x )
+--R   (1)  ------------------------
+--R                    3
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 600
+r0:=-1/2*(c*x^2)^p*(a+b*x)^(2-2*p)/(a*(1-p)*x^2)
+--R 
+--R
+--R                 - 2p + 2    2 p
+--R        (b x + a)        (c x )
+--R   (2)  ------------------------
+--R                          2
+--R              (2a p - 2a)x
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 600
+t0:=(c*x^2)^p*(a+b*x)^(2-2*p)/x^4
+--R 
+--R
+--R                 - 2p + 2    2 p
+--R        (b x + a)        (c x )
+--R   (1)  ------------------------
+--R                    4
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 600
+r0:=-(c*x^2)^p*(a+b*x)^(3-2*p)/(a*(3-2*p)*x^3)
+--R 
+--R
+--R                 - 2p + 3    2 p
+--R        (b x + a)        (c x )
+--R   (2)  ------------------------
+--R                          3
+--R              (2a p - 3a)x
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 600
+t0:=sqrt(a*x^23)/sqrt(1+x^5)
+--R 
+--R
+--R          +-----+
+--R          |   23
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 5
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 600
+r0:=3/20*asinh(x^(5/2))*sqrt(a*x^23)/x^(23/2)-3/20*sqrt(a*x^23)*_
+   sqrt(1+x^5)/x^9+1/10*sqrt(a*x^23)*sqrt(1+x^5)/x^4
+--R 
+--R
+--R          +-----+                                +------+ +-----+
+--R          |   23        2 +-+       7     2  +-+ | 5      |   23
+--R        3\|a x   asinh(x \|x ) + (2x  - 3x )\|x \|x  + 1 \|a x
+--R   (2)  ---------------------------------------------------------
+--R                                   11 +-+
+--R                                20x  \|x
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 600
+t0:=sqrt(a*x^13)/sqrt(1+x^5)
+--R 
+--R
+--R          +-----+
+--R          |   13
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 5
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 600
+r0:=-1/5*asinh(x^(5/2))*sqrt(a*x^13)/x^(13/2)+1/5*sqrt(a*x^13)*sqrt(1+x^5)/x^4
+--R 
+--R
+--R           +-----+                       +------+ +-----+
+--R           |   13        2 +-+     2 +-+ | 5      |   13
+--R        - \|a x   asinh(x \|x ) + x \|x \|x  + 1 \|a x
+--R   (2)  -------------------------------------------------
+--R                               6 +-+
+--R                             5x \|x
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 600
+t0:=sqrt(a*x^3)/sqrt(1+x^5)
+--R 
+--R
+--R          +----+
+--R          |   3
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 5
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 600
+r0:=2/5*asinh(x^(5/2))*sqrt(a*x^3)/x^(3/2)
+--R 
+--R
+--R          +----+
+--R          |   3        2 +-+
+--R        2\|a x  asinh(x \|x )
+--R   (2)  ---------------------
+--R                   +-+
+--R                5x\|x
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 600
+t0:=sqrt(a/x^7)/sqrt(1+x^5)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 7
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 5
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 600
+r0:=-2/5*x*sqrt(a/x^7)*sqrt(1+x^5)
+--R 
+--R
+--R             +--+ +------+
+--R             | a  | 5
+--R          2x |-- \|x  + 1
+--R             | 7
+--R            \|x
+--R   (2)  - ----------------
+--R                  5
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 600
+t0:=sqrt(a/x^17)/sqrt(1+x^5)
+--R 
+--R
+--R           +---+
+--R           | a
+--R           |---
+--R           | 17
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 5
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 600
+r0:=-2/15*x*sqrt(a/x^17)*sqrt(1+x^5)+4/15*x^6*sqrt(a/x^17)*sqrt(1+x^5)
+--R 
+--R
+--R                   +---+ +------+
+--R           6       | a   | 5
+--R        (4x  - 2x) |--- \|x  + 1
+--R                   | 17
+--R                  \|x
+--R   (2)  -------------------------
+--R                    15
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 600
+t0:=sqrt(a*x^6)/(x*(1-x^4))
+--R 
+--R
+--R           +----+
+--R           |   6
+--R          \|a x
+--R   (1)  - -------
+--R            5
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 600
+r0:=-1/2*atan(x)*sqrt(a*x^6)/x^3+1/2*atanh(x)*sqrt(a*x^6)/x^3
+--R 
+--R
+--R                             +----+
+--R                             |   6
+--R        (atanh(x) - atan(x))\|a x
+--R   (2)  ---------------------------
+--R                      3
+--R                    2x
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 600
+t0:=sqrt(a*x^6)/(x-x^5)
+--R 
+--R
+--R           +----+
+--R           |   6
+--R          \|a x
+--R   (1)  - -------
+--R            5
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 600
+r0:=-1/2*atan(x)*sqrt(a*x^6)/x^3+1/2*atanh(x)*sqrt(a*x^6)/x^3
+--R 
+--R
+--R                             +----+
+--R                             |   6
+--R        (atanh(x) - atan(x))\|a x
+--R   (2)  ---------------------------
+--R                      3
+--R                    2x
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 600
+t0:=(a*x^6)^(3/2)/(x*(1-x^4))
+--R 
+--R
+--R               +----+
+--R             5 |   6
+--R          a x \|a x
+--R   (1)  - -----------
+--R              4
+--R             x  - 1
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 600
+r0:=-a*sqrt(a*x^6)/x^2-1/5*a*x^2*sqrt(a*x^6)+1/2*a*atan(x)*sqrt(a*x^6)/x^3+_
+   1/2*a*atanh(x)*sqrt(a*x^6)/x^3
+--R 
+--R
+--R                                                   +----+
+--R                                        5          |   6
+--R        (5a atanh(x) + 5a atan(x) - 2a x  - 10a x)\|a x
+--R   (2)  -------------------------------------------------
+--R                                  3
+--R                               10x
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 600
+t0:=1/(1-x^4)-sqrt(a*x^6)/(x*(1-x^4))
+--R 
+--R
+--R         +----+
+--R         |   6
+--R        \|a x   - x
+--R   (1)  -----------
+--R            5
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 600
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(a*x^6)/x^3-1/2*atanh(x)*_
+   sqrt(a*x^6)/x^3
+--R 
+--R
+--R                               +----+
+--R                               |   6     3            3
+--R        (- atanh(x) + atan(x))\|a x   + x atanh(x) + x atan(x)
+--R   (2)  ------------------------------------------------------
+--R                                    3
+--R                                  2x
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 600
+t0:=1/(1-x^4)-sqrt(a*x^6)/(x-x^5)
+--R 
+--R
+--R         +----+
+--R         |   6
+--R        \|a x   - x
+--R   (1)  -----------
+--R            5
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 600
+r0:=1/2*atan(x)+1/2*atanh(x)+1/2*atan(x)*sqrt(a*x^6)/x^3-_
+   1/2*atanh(x)*sqrt(a*x^6)/x^3
+--R 
+--R
+--R                               +----+
+--R                               |   6     3            3
+--R        (- atanh(x) + atan(x))\|a x   + x atanh(x) + x atan(x)
+--R   (2)  ------------------------------------------------------
+--R                                    3
+--R                                  2x
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 600
+t0:=sqrt(a*x^3)/(x-x^3)
+--R 
+--R
+--R           +----+
+--R           |   3
+--R          \|a x
+--R   (1)  - -------
+--R            3
+--R           x  - x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 600
+r0:=-atan(sqrt(x))*sqrt(a*x^3)/x^(3/2)+atanh(sqrt(x))*sqrt(a*x^3)/x^(3/2)
+--R 
+--R
+--R         +----+               +----+
+--R         |   3        +-+     |   3       +-+
+--R        \|a x  atanh(\|x ) - \|a x  atan(\|x )
+--R   (2)  --------------------------------------
+--R                           +-+
+--R                         x\|x
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 600
+t0:=sqrt(a*x^4)/sqrt(1+x^2)
+--R 
+--R
+--R          +----+
+--R          |   4
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 600
+r0:=-1/2*asinh(x)*sqrt(a*x^4)/x^2+1/2*sqrt(a*x^4)*sqrt(1+x^2)/x
+--R 
+--R
+--R           +------+             +----+
+--R           | 2                  |   4
+--R        (x\|x  + 1  - asinh(x))\|a x
+--R   (2)  ------------------------------
+--R                        2
+--R                      2x
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 600
+t0:=sqrt(a*x^3)/sqrt(1+x^2)
+--R 
+--R
+--R          +----+
+--R          |   3
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 600
+--r0:=2/3*(-1)^(3/4)*elliptic_f(asin((-1)^(1/4)*sqrt(x)),-1)*_
+--   sqrt(a*x^3)/x^(3/2)+2/3*sqrt(a*x^3)*sqrt(1+x^2)/x
+--E 185
+
+--S 186 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 186
+
+)clear all
+
+--S 187 of 600
+t0:=sqrt(a*x^2)/sqrt(1+x^2)
+--R 
+--R
+--R          +----+
+--R          |   2
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 600
+r0:=sqrt(a*x^2)*sqrt(1+x^2)/x
+--R 
+--R
+--R         +------+ +----+
+--R         | 2      |   2
+--R        \|x  + 1 \|a x
+--R   (2)  ----------------
+--R                x
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 600
+t0:=sqrt(a*x)/sqrt(1+x^2)
+--R 
+--R
+--R           +---+
+--R          \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 600
+--r0:=-2*(-1)^(1/4)*elliptic_e(asin((-1)^(1/4)*sqrt(x)),-1)*_
+--   sqrt(a*x)/sqrt(x)+2*(-1)^(1/4)*elliptic_f(asin((-1)^(1/4)*sqrt(x)),-1)*_
+--   sqrt(a*x)/sqrt(x)
+--E 191
+
+--S 192 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 192
+
+)clear all
+
+--S 193 of 600
+t0:=sqrt(a/x)/sqrt(1+x^2)
+--R 
+--R
+--R            +-+
+--R            |a
+--R            |-
+--R           \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 600
+--r0:=-2*(-1)^(3/4)*elliptic_f(asin((-1)^(1/4)*sqrt(x)),-1)*sqrt(a/x)*sqrt(x)
+--E 194
+
+--S 195 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 195
+
+)clear all
+
+--S 196 of 600
+t0:=sqrt(a/x^2)/sqrt(1+x^2)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 2
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 600
+r0:=-x*atanh(sqrt(1+x^2))*sqrt(a/x^2)
+--R 
+--R
+--R            +--+       +------+
+--R            | a        | 2
+--R   (2)  - x |-- atanh(\|x  + 1 )
+--R            | 2
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 600
+t0:=sqrt(a/x^3)/sqrt(1+x^2)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 3
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 600
+--r0:=-2*(-1)^(1/4)*x^(3/2)*elliptic_e(asin((-1)^(1/4)*sqrt(x)),-1)*_
+--   sqrt(a/x^3)+2*(-1)^(1/4)*x^(3/2)*elliptic_f(asin((-1)^(1/4)*_
+--   sqrt(x)),-1)*sqrt(a/x^3)-2*x*sqrt(a/x^3)*sqrt(1+x^2)
+--E 200
+
+--S 201 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 201
+
+)clear all
+
+--S 202 of 600
+t0:=sqrt(a/x^4)/sqrt(1+x^2)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 4
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 2
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 600
+r0:=-x*sqrt(a/x^4)*sqrt(1+x^2)
+--R 
+--R
+--R            +--+ +------+
+--R            | a  | 2
+--R   (2)  - x |-- \|x  + 1
+--R            | 4
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 600
+t0:=sqrt(a*x^4)/sqrt(1+x^3)
+--R 
+--R
+--R          +----+
+--R          |   4
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 600
+r0:=2/3*sqrt(a*x^4)*sqrt(1+x^3)/x^2
+--R 
+--R
+--R          +------+ +----+
+--R          | 3      |   4
+--R        2\|x  + 1 \|a x
+--R   (2)  -----------------
+--R                 2
+--R               3x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 600
+t0:=sqrt(a*x^3)/sqrt(1+x^3)
+--R 
+--R
+--R          +----+
+--R          |   3
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 600
+--r0:=2/5*x*hypergeometric(1/2,5/6,11/6,-x^3)*sqrt(a*x^3)
+--E 209
+
+--S 210 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 210
+
+)clear all
+
+--S 211 of 600
+t0:=sqrt(a*x^2)/sqrt(1+x^3)
+--R 
+--R
+--R          +----+
+--R          |   2
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 600
+--r0:=(1/2+1/2*%i)*(1+x)*elliptic_e(%i*asinh((1/2+1/2*%i)*sqrt(1-2*x+%i*_
+--   sqrt(3))/3^(1/4)),-2*sqrt(3)/(3*%i-sqrt(3)))*sqrt(a*x^2)*sqrt(%i*_
+--   (1-2*x-%i*sqrt(3)))*sqrt(1-2*x+%i*sqrt(3))/(x*sqrt(1+x^3)*_
+--   sqrt((1+x)/(3+%i*sqrt(3))))+(-1-%i)*elliptic_f(%i*asinh((1/2+1/2*%i)*_
+--   sqrt(1-2*x+%i*sqrt(3))/3^(1/4)),-2*sqrt(3)/(3*%i-sqrt(3)))*_
+--   sqrt(a*x^2)*sqrt(%i*(1-2*x-%i*sqrt(3)))*sqrt((1+x)/(3+%i*sqrt(3)))*_
+--   sqrt(1-2*x+%i*sqrt(3))/(x*sqrt(1+x^3))
+--E 212
+
+--S 213 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 213
+
+)clear all
+
+--S 214 of 600
+t0:=sqrt(a*x)/sqrt(1+x^3)
+--R 
+--R
+--R           +---+
+--R          \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 600
+r0:=2/3*asinh(x^(3/2))*sqrt(a*x)/sqrt(x)
+--R 
+--R
+--R          +---+        +-+
+--R        2\|a x asinh(x\|x )
+--R   (2)  -------------------
+--R                 +-+
+--R               3\|x
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 600
+t0:=sqrt(a/x)/sqrt(1+x^3)
+--R 
+--R
+--R            +-+
+--R            |a
+--R            |-
+--R           \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 600
+--r0:=x*(1+x)*elliptic_f(acos((1+x*(1-sqrt(3)))/(1+x*(1+sqrt(3)))),1/4*_
+--   (2+sqrt(3)))*sqrt(a/x)*sqrt((1-x+x^2)/(1+x*(1+sqrt(3)))^2)/(3^(1/4)*_
+--   sqrt(1+x^3)*sqrt(x*(1+x)/(1+x*(1+sqrt(3)))^2))
+--E 218
+
+--S 219 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 219
+
+)clear all
+
+--S 220 of 600
+t0:=sqrt(a/x^2)/sqrt(1+x^3)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 2
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 600
+r0:=-2/3*x*atanh(sqrt(1+x^3))*sqrt(a/x^2)
+--R 
+--R
+--R             +--+       +------+
+--R             | a        | 3
+--R          2x |-- atanh(\|x  + 1 )
+--R             | 2
+--R            \|x
+--R   (2)  - -----------------------
+--R                     3
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 600
+t0:=sqrt(a/x^3)/sqrt(1+x^3)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 3
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 600
+--r0:=4/5*x^4*hypergeometric(1/2,5/6,11/6,-x^3)*sqrt(a/x^3)-_
+--   2*x*sqrt(a/x^3)*sqrt(1+x^3)
+--E 224
+
+--S 225 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 225
+
+)clear all
+
+--S 226 of 600
+t0:=sqrt(a/x^4)/sqrt(1+x^3)
+--R 
+--R
+--R           +--+
+--R           | a
+--R           |--
+--R           | 4
+--R          \|x
+--R   (1)  ---------
+--R         +------+
+--R         | 3
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 600
+--r0:=-x*sqrt(a/x^4)*sqrt(1+x^3)+(1/4+1/4*%i)*x^2*(1+x)*elliptic_e(%i*_
+--   asinh((1/2+1/2*%i)*sqrt(1-2*x+%i*sqrt(3))/3^(1/4)),-2*sqrt(3)/(3*%i-_
+--   sqrt(3)))*sqrt(a/x^4)*sqrt(%i*(1-2*x-%i*sqrt(3)))*sqrt(1-2*x+%i*_
+--   sqrt(3))/(sqrt(1+x^3)*sqrt((1+x)/(3+%i*sqrt(3))))+(-1/2-1/2*%i)*_
+--   x^2*elliptic_f(%i*asinh((1/2+1/2*%i)*sqrt(1-2*x+%i*sqrt(3))/3^(1/4)),_
+--   -2*sqrt(3)/(3*%i-sqrt(3)))*sqrt(a/x^4)*sqrt(%i*(1-2*x-%i*sqrt(3)))*_
+--   sqrt((1+x)/(3+%i*sqrt(3)))*sqrt(1-2*x+%i*sqrt(3))/sqrt(1+x^3)
+--E 227
+
+--S 228 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 228
+
+)clear all
+
+--S 229 of 600
+t0:=sqrt(a*x^(2*n))/sqrt(1+x^n)
+--R 
+--R
+--R          +-----+
+--R          |   2n
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | n
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 600
+--r0:=-2*x^(1-n)*hypergeometric(1/2,1/n,1+1/n,-x^n)*sqrt(a*x^(2*n))/(2+n)+_
+--   2*x^(1-n)*sqrt(a*x^(2*n))*sqrt(1+x^n)/(2+n)
+--E 230
+
+--S 231 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 231
+
+)clear all
+
+--S 232 of 600
+t0:=sqrt(a*x^n)/sqrt(1+x^n)
+--R 
+--R
+--R          +----+
+--R          |   n
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | n
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 600
+--r0:=2*x*hypergeometric(1/2,1/2*(1+2/n),1/2*(3+2/n),-x^n)*sqrt(a*x^n)/(2+n)
+--E 233
+
+--S 234 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 234
+
+)clear all
+
+--S 235 of 600
+t0:=sqrt(a*x^(1/2*n))/sqrt(1+x^n)
+--R 
+--R
+--R          +----+
+--R          |   n
+--R          |   -
+--R          |   2
+--R         \|a x
+--R   (1)  ---------
+--R         +------+
+--R         | n
+--R        \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 600
+--r0:=4*x*hypergeometric(1/2,1/4*(1+4/n),1/4*(5+4/n),-x^n)*_
+--   sqrt(a*x^(1/2*n))/(4+n)
+--E 236
+
+--S 237 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 237
+
+)clear all
+
+--S 238 of 600
+t0:=sqrt(a*x^(2*n))/sqrt(1+x^n)+2*sqrt(a*x^(2*n))/((2+n)*x^n*sqrt(1+x^n))
+--R 
+--R
+--R                        +-----+
+--R                 n      |   2n
+--R        ((n + 2)x  + 2)\|a x
+--R   (1)  -----------------------
+--R                     +------+
+--R                   n | n
+--R           (n + 2)x \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 600
+r0:=2*x^(1-n)*sqrt(a*x^(2*n))*sqrt(1+x^n)/(2+n)
+--R 
+--R
+--R                  +------+ +-----+
+--R          - n + 1 | n      |   2n
+--R        2x       \|x  + 1 \|a x
+--R   (2)  --------------------------
+--R                   n + 2
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 600
+t0:=sqrt(a*x)/(sqrt(d+e*x)*sqrt(e+f*x))
+--R 
+--R
+--R                +---+
+--R               \|a x
+--R   (1)  --------------------
+--R         +-------+ +-------+
+--R        \|e x + d \|f x + e
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 600
+--r0:=2*elliptic_e(asin(sqrt(f)*sqrt(d+e*x)/sqrt(-e^2+d*f)),1-e^2/(d*f))*_
+--   sqrt(-e^2+d*f)*sqrt(a*x)*sqrt(e*(e+f*x)/(e^2-d*f))/(e*sqrt(f)*_
+--   sqrt(-e*x/d)*sqrt(e+f*x))
+--E 242
+
+--S 243 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 243
+
+)clear all
+
+--S 244 of 600
+t0:=(a*x^m)^r
+--R 
+--R
+--R            m r
+--R   (1)  (a x )
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 600
+r0:=x*(a*x^m)^r/(1+m*r)
+--R 
+--R
+--R              m r
+--R        x (a x )
+--R   (2)  ---------
+--R         m r + 1
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 600
+t0:=(a*x^m)^r*(b*x^n)^s
+--R 
+--R
+--R            m r    n s
+--R   (1)  (a x ) (b x )
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 600
+r0:=x*(a*x^m)^r*(b*x^n)^s/(1+m*r+n*s)
+--R 
+--R
+--R              m r    n s
+--R        x (a x ) (b x )
+--R   (2)  ----------------
+--R          n s + m r + 1
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 600
+t0:=(a*x^m)^r*(b*x^n)^s*(c*x^p)^t
+--R 
+--R
+--R            m r    n s    p t
+--R   (1)  (a x ) (b x ) (c x )
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 600
+r0:=x*(a*x^m)^r*(b*x^n)^s*(c*x^p)^t/(1+m*r+n*s+p*t)
+--R 
+--R
+--R              m r    n s    p t
+--R        x (a x ) (b x ) (c x )
+--R   (2)  -----------------------
+--R          p t + n s + m r + 1
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 600
+t0:=(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^p
+--R 
+--R
+--R              1         1     p
+--R              -         -
+--R            n n       n n
+--R   (1)  (c x ) (b (c x )  + a)
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 600
+r0:=-a*x*(a+b*(c*x^n)^(1/n))^(1+p)/(b^2*(1+p)*(c*x^n)^(1/n))+_
+   x*(a+b*(c*x^n)^(1/n))^(2+p)/(b^2*(2+p)*(c*x^n)^(1/n))
+--R 
+--R
+--R                          1     p + 2                          1     p + 1
+--R                          -                                    -
+--R                        n n                                  n n
+--R        (p + 1)x (b (c x )  + a)      + (- a p - 2a)x (b (c x )  + a)
+--R   (2)  ------------------------------------------------------------------
+--R                                                     1
+--R                                                     -
+--R                              2 2     2      2     n n
+--R                            (b p  + 3b p + 2b )(c x )
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 600
+t0:=(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^3
+--R 
+--R
+--R                 1 4               1 3               1 2           1
+--R                 -                 -                 -             -
+--R         3     n n         2     n n       2       n n      3    n n
+--R   (1)  b ((c x ) )  + 3a b ((c x ) )  + 3a b ((c x ) )  + a (c x )
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 600
+r0:=-1/4*a*x*(a+b*(c*x^n)^(1/n))^4/(b^2*(c*x^n)^(1/n))+_
+   1/5*x*(a+b*(c*x^n)^(1/n))^5/(b^2*(c*x^n)^(1/n))
+--R 
+--R
+--R   (2)
+--R                   1 5                  1 4                  1 3
+--R                   -                    -                    -
+--R         5       n n          4       n n        2 3       n n
+--R       4b x ((c x ) )  + 15a b x ((c x ) )  + 20a b x ((c x ) )
+--R     + 
+--R                      1 2
+--R                      -
+--R          3 2       n n      5
+--R       10a b x ((c x ) )  - a x
+--R  /
+--R               1
+--R               -
+--R        2    n n
+--R     20b (c x )
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 600
+t0:=(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^2
+--R 
+--R
+--R                 1 3               1 2           1
+--R                 -                 -             -
+--R         2     n n               n n      2    n n
+--R   (1)  b ((c x ) )  + 2a b ((c x ) )  + a (c x )
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 600
+r0:=1/2*a^2*x*(c*x^n)^(1/n)+2/3*a*b*x*(c*x^n)^(2/n)+1/4*b^2*x*(c*x^n)^(3/n)
+--R 
+--R
+--R                   3                2              1
+--R                   -                -              -
+--R          2      n n              n n     2      n n
+--R        3b x (c x )  + 8a b x (c x )  + 6a x (c x )
+--R   (2)  --------------------------------------------
+--R                             12
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 600
+t0:=(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))
+--R 
+--R
+--R                 1 2           1
+--R                 -             -
+--R               n n           n n
+--R   (1)  b ((c x ) )  + a (c x )
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 600
+r0:=1/2*a*x*(c*x^n)^(1/n)+1/3*b*x*(c*x^n)^(2/n)
+--R 
+--R
+--R                   2              1
+--R                   -              -
+--R                 n n            n n
+--R        2b x (c x )  + 3a x (c x )
+--R   (2)  ---------------------------
+--R                     6
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 600
+t0:=(c*x^n)^(1/n)/(a+b*(c*x^n)^(1/n))
+--R 
+--R
+--R                 1
+--R                 -
+--R               n n
+--R           (c x )
+--R   (1)  -------------
+--R                1
+--R                -
+--R              n n
+--R        b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 600
+r0:=x/b-a*x*log(a+b*(c*x^n)^(1/n))/(b^2*(c*x^n)^(1/n))
+--R 
+--R
+--R                          1                  1
+--R                          -                  -
+--R                        n n                n n
+--R        - a x log(b (c x )  + a) + b x (c x )
+--R   (2)  --------------------------------------
+--R                               1
+--R                               -
+--R                        2    n n
+--R                       b (c x )
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 600
+t0:=(c*x^n)^(1/n)/(a+b*(c*x^n)^(1/n))^2
+--R 
+--R
+--R                           1
+--R                           -
+--R                         n n
+--R                     (c x )
+--R   (1)  --------------------------------
+--R                 1 2              1
+--R                 -                -
+--R         2     n n              n n    2
+--R        b ((c x ) )  + 2a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 600
+r0:=a*x/(b^2*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n)))+_
+   x*log(a+b*(c*x^n)^(1/n))/(b^2*(c*x^n)^(1/n))
+--R 
+--R
+--R                   1                   1
+--R                   -                   -
+--R                 n n                 n n
+--R        (b x (c x )  + a x)log(b (c x )  + a) + a x
+--R   (2)  -------------------------------------------
+--R                          1 2             1
+--R                          -               -
+--R                  3     n n        2    n n
+--R                 b ((c x ) )  + a b (c x )
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 600
+t0:=(c*x^n)^(1/n)/(a+b*(c*x^n)^(1/n))^3
+--R 
+--R
+--R                                    1
+--R                                    -
+--R                                  n n
+--R                              (c x )
+--R   (1)  --------------------------------------------------
+--R                 1 3               1 2              1
+--R                 -                 -                -
+--R         3     n n         2     n n       2      n n    3
+--R        b ((c x ) )  + 3a b ((c x ) )  + 3a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 600
+r0:=1/2*x*(c*x^n)^(1/n)/(a*(a+b*(c*x^n)^(1/n))^2)
+--R 
+--R
+--R                              1
+--R                              -
+--R                            n n
+--R                      x (c x )
+--R   (2)  ------------------------------------
+--R                    1 2              1
+--R                    -                -
+--R            2     n n       2      n n     3
+--R        2a b ((c x ) )  + 4a b (c x )  + 2a
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 600
+t0:=(c*x^n)^(1/n)/(a+b*(c*x^n)^(1/n))^4
+--R 
+--R
+--R                                             1
+--R                                             -
+--R                                           n n
+--R                                       (c x )
+--R   (1)  --------------------------------------------------------------------
+--R                 1 4               1 3               1 2              1
+--R                 -                 -                 -                -
+--R         4     n n         3     n n       2 2     n n       3      n n    4
+--R        b ((c x ) )  + 4a b ((c x ) )  + 6a b ((c x ) )  + 4a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 600
+r0:=1/3*a*x/(b^2*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^3)-_
+   1/2*x/(b^2*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^2)
+--R 
+--R
+--R                                            1
+--R                                            -
+--R                                          n n
+--R                               - 3b x (c x )  - a x
+--R   (2)  ------------------------------------------------------------------
+--R                  1 4                1 3                1 2              1
+--R                  -                  -                  -                -
+--R          5     n n          4     n n        2 3     n n       3 2    n n
+--R        6b ((c x ) )  + 18a b ((c x ) )  + 18a b ((c x ) )  + 6a b (c x )
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 600
+t0:=(c*x^n)^(1/n)/(a+b*(c*x^n)^(1/n))^5
+--R 
+--R
+--R   (1)
+--R           1
+--R           -
+--R         n n
+--R     (c x )
+--R  /
+--R                1 5               1 4                1 3                1 2
+--R                -                 -                  -                  -
+--R        5     n n         4     n n        2 3     n n        3 2     n n
+--R       b ((c x ) )  + 5a b ((c x ) )  + 10a b ((c x ) )  + 10a b ((c x ) )
+--R     + 
+--R                  1
+--R                  -
+--R         4      n n    5
+--R       5a b (c x )  + a
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 600
+r0:=1/4*a*x/(b^2*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^4)-_
+   1/3*x/(b^2*(c*x^n)^(1/n)*(a+b*(c*x^n)^(1/n))^3)
+--R 
+--R
+--R   (2)
+--R                  1
+--R                  -
+--R                n n
+--R     - 4b x (c x )  - a x
+--R  /
+--R                  1 5                1 4                1 3                1 2
+--R                  -                  -                  -                  -
+--R          6     n n          5     n n        2 4     n n        3 3     n n
+--R       12b ((c x ) )  + 48a b ((c x ) )  + 72a b ((c x ) )  + 48a b ((c x ) )
+--R     + 
+--R                   1
+--R                   -
+--R          4 2    n n
+--R       12a b (c x )
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 600
+t0:=x^4*(A+B*x+C*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           6      5      4
+--R        C x  + B x  + A x
+--R   (1)  ------------------
+--R             4      2
+--R          c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 280
+
+--S 281 of 600
+r0:=(A*c-b*C)*x/c^2+1/2*B*x^2/c+1/3*C*x^3/c-1/4*b*B*log(a+b*x^2+c*x^4)/c^2-_
+   1/2*B*(b^2-2*a*c)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-_
+   4*a*c))-atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(A*b*c-_
+   b^2*C+a*c*C+(-A*c*(b^2-2*a*c)+b*(b^2-3*a*c)*C)/sqrt(b^2-4*a*c))/_
+   (c^(5/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*(A*b*c-b^2*C+a*c*C+(A*c*(b^2-2*a*c)-_
+   b*(b^2-3*a*c)*C)/sqrt(b^2-4*a*c))/(c^(5/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                         +-----------+
+--R                                      2  |          2           2
+--R           ((- 12A b - 12C a)c + 12C b )\|- 4a c + b   - 24A a c
+--R         + 
+--R                 2                    3
+--R           (12A b  + 36C a b)c - 12C b
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                                         +-----------+
+--R                                      2  |          2           2
+--R           ((- 12A b - 12C a)c + 12C b )\|- 4a c + b   + 24A a c
+--R         + 
+--R                   2                    3
+--R           (- 12A b  - 36C a b)c + 12C b
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                                 2
+--R                          2  +-+ +-+         2c x  + b
+--R           (12B a c - 6B b )\|2 \|c atanh(--------------)
+--R                                           +-----------+
+--R                                           |          2
+--R                                          \|- 4a c + b
+--R         + 
+--R                      +-+       4      2
+--R               - 3B b\|2 log(c x  + b x  + a)
+--R             + 
+--R                      3         2                     +-+
+--R               (4C c x  + 6B c x  + (12A c - 12C b)x)\|2
+--R          *
+--R              +-----------+
+--R              |          2  +-+
+--R             \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                                +--------------------+ +------------------+
+--R              +-----------+     |   +-----------+      | +-----------+
+--R        2 +-+ |          2  +-+ |   |          2       | |          2
+--R     12c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 600
+t0:=x^3*(A+B*x+C*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           5      4      3
+--R        C x  + B x  + A x
+--R   (1)  ------------------
+--R             4      2
+--R          c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 283
+
+--S 284 of 600
+r0:=B*x/c+1/2*C*x^2/c+1/4*(A*c-b*C)*log(a+b*x^2+c*x^4)/c^2+1/2*(A*b*c-_
+   b^2*C+2*a*c*C)*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/(c^2*sqrt(b^2-_
+   4*a*c))-B*atan(x*sqrt(2)*sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(b+_
+   (-b^2+2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-_
+   sqrt(b^2-4*a*c)))-B*atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*_
+   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                     +------------------+
+--R                   +-----------+                     | +-----------+
+--R                   |          2          2       2   | |          2
+--R         (- 4B b c\|- 4a c + b   - 8B a c  + 4B b c)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                   +-----------+                     |   +-----------+
+--R                   |          2          2       2   |   |          2
+--R         (- 4B b c\|- 4a c + b   + 8B a c  - 4B b c)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                                        2
+--R                                 2  +-+ +-+         2c x  + b
+--R           ((2A b + 4C a)c - 2C b )\|2 \|c atanh(--------------)
+--R                                                  +-----------+
+--R                                                  |          2
+--R                                                 \|- 4a c + b
+--R         + 
+--R                          +-+       4      2               2           +-+
+--R             ((A c - C b)\|2 log(c x  + b x  + a) + (2C c x  + 4B c x)\|2 )
+--R          *
+--R              +-----------+
+--R              |          2  +-+
+--R             \|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                               +--------------------+ +------------------+
+--R             +-----------+     |   +-----------+      | +-----------+
+--R       2 +-+ |          2  +-+ |   |          2       | |          2
+--R     4c \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 600
+t0:=x^2*(A+B*x+C*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           4      3      2
+--R        C x  + B x  + A x
+--R   (1)  ------------------
+--R             4      2
+--R          c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 286
+
+--S 287 of 600
+r0:=C*x/c+1/4*B*log(a+b*x^2+c*x^4)/c+1/2*b*B*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(c*sqrt(b^2-4*a*c))+atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*(A*c-b*C+(-A*b*c+(b^2-2*a*c)*C)/_
+   sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))+_
+   atan(x*sqrt(2)*sqrt(c)/sqrt(b+sqrt(b^2-4*a*c)))*(A*c-b*C+_
+   (A*b*c-b^2*C+2*a*c*C)/sqrt(b^2-4*a*c))/(c^(3/2)*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                        +-----------+
+--R                        |          2                           2
+--R         ((4A c - 4C b)\|- 4a c + b   + (- 4A b - 8C a)c + 4C b )
+--R      *
+--R          +------------------+
+--R          | +-----------+                   +-+ +-+
+--R          | |          2                  x\|2 \|c
+--R         \|\|- 4a c + b   + b atan(-----------------------)
+--R                                    +--------------------+
+--R                                    |   +-----------+
+--R                                    |   |          2
+--R                                   \|- \|- 4a c + b   + b
+--R     + 
+--R                        +-----------+
+--R                        |          2                         2
+--R         ((4A c - 4C b)\|- 4a c + b   + (4A b + 8C a)c - 4C b )
+--R      *
+--R          +--------------------+
+--R          |   +-----------+                  +-+ +-+
+--R          |   |          2                 x\|2 \|c
+--R         \|- \|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                    2
+--R                +-+ +-+         2c x  + b
+--R           2B b\|2 \|c atanh(--------------)
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R         + 
+--R                                                  +-----------+
+--R              +-+       4      2             +-+  |          2  +-+
+--R           (B\|2 log(c x  + b x  + a) + 4C x\|2 )\|- 4a c + b  \|c
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                              +--------------------+ +------------------+
+--R            +-----------+     |   +-----------+      | +-----------+
+--R        +-+ |          2  +-+ |   |          2       | |          2
+--R     4c\|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 600
+t0:=x*(A+B*x+C*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R           3      2
+--R        C x  + B x  + A x
+--R   (1)  -----------------
+--R            4      2
+--R         c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 289
+
+--S 290 of 600
+r0:=1/4*C*log(a+b*x^2+c*x^4)/c-1/2*(2*A*c-b*C)*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(c*sqrt(b^2-4*a*c))-B*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(b-sqrt(b^2-4*a*c))/(sqrt(2)*_
+   sqrt(c)*sqrt(b^2-4*a*c))+B*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(b+sqrt(b^2-4*a*c))/(sqrt(2)*sqrt(c)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R              +--------------------+
+--R              |   +-----------+                   +-+ +-+
+--R              |   |          2                  x\|2 \|c
+--R       - 4B c\|- \|- 4a c + b   + b atan(-----------------------)
+--R                                          +--------------------+
+--R                                          |   +-----------+
+--R                                          |   |          2
+--R                                         \|- \|- 4a c + b   + b
+--R     + 
+--R            +------------------+
+--R            | +-----------+                  +-+ +-+
+--R            | |          2                 x\|2 \|c
+--R       4B c\|\|- 4a c + b   + b atan(---------------------)
+--R                                      +------------------+
+--R                                      | +-----------+
+--R                                      | |          2
+--R                                     \|\|- 4a c + b   + b
+--R     + 
+--R                                           2
+--R                       +-+ +-+         2c x  + b
+--R       (- 4A c + 2C b)\|2 \|c atanh(--------------)
+--R                                     +-----------+
+--R                                     |          2
+--R                                    \|- 4a c + b
+--R     + 
+--R                                 +-----------+
+--R         +-+       4      2      |          2  +-+
+--R       C\|2 log(c x  + b x  + a)\|- 4a c + b  \|c
+--R  /
+--R            +-----------+
+--R        +-+ |          2  +-+
+--R     4c\|2 \|- 4a c + b  \|c
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 600
+t0:=(A+B*x+C*x^2)/(a+b*x^2+c*x^4)
+--R 
+--R
+--R            2
+--R         C x  + B x + A
+--R   (1)  ---------------
+--R           4      2
+--R        c x  + b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 292
+
+--S 293 of 600
+r0:=-B*atanh((b+2*c*x^2)/sqrt(b^2-4*a*c))/sqrt(b^2-4*a*c)+atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*(C+(2*A*c-b*C)/sqrt(b^2-4*a*c))/_
+   (sqrt(2)*sqrt(c)*sqrt(b-sqrt(b^2-4*a*c)))+atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*(C+(-2*A*c+b*C)/sqrt(b^2-4*a*c))/_
+   (sqrt(2)*sqrt(c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                        +------------------+
+--R            +-----------+               | +-----------+
+--R            |          2                | |          2
+--R         (C\|- 4a c + b   + 2A c - C b)\|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                        +--------------------+
+--R            +-----------+               |   +-----------+
+--R            |          2                |   |          2
+--R         (C\|- 4a c + b   - 2A c + C b)\|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R       -
+--R                                           +--------------------+
+--R                                  2        |   +-----------+
+--R              +-+ +-+         2c x  + b    |   |          2
+--R            B\|2 \|c atanh(--------------)\|- \|- 4a c + b   + b
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R         *
+--R             +------------------+
+--R             | +-----------+
+--R             | |          2
+--R            \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R          +-----------+     |   +-----------+      | +-----------+
+--R      +-+ |          2  +-+ |   |          2       | |          2
+--R     \|2 \|- 4a c + b  \|c \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 600
+t0:=(A+B*x+C*x^2)/(x*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          C x  + B x + A
+--R   (1)  -----------------
+--R           5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 295
+
+--S 296 of 600
+r0:=A*log(x)/a-1/4*A*log(a+b*x^2+c*x^4)/a+1/2*(A*b-2*a*C)*atanh((b+_
+   2*c*x^2)/sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))+B*atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*_
+   sqrt(b-sqrt(b^2-4*a*c)))-B*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(2)*sqrt(c)/(sqrt(b^2-4*a*c)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                    +------------------+
+--R                    | +-----------+                   +-+ +-+
+--R            +-+ +-+ | |          2                  x\|2 \|c
+--R       4B a\|2 \|c \|\|- 4a c + b   + b atan(-----------------------)
+--R                                              +--------------------+
+--R                                              |   +-----------+
+--R                                              |   |          2
+--R                                             \|- \|- 4a c + b   + b
+--R     + 
+--R                      +--------------------+
+--R                      |   +-----------+                  +-+ +-+
+--R              +-+ +-+ |   |          2                 x\|2 \|c
+--R       - 4B a\|2 \|c \|- \|- 4a c + b   + b atan(---------------------)
+--R                                                  +------------------+
+--R                                                  | +-----------+
+--R                                                  | |          2
+--R                                                 \|\|- 4a c + b   + b
+--R     + 
+--R                                     2
+--R                                 2c x  + b
+--R           (2A b - 4C a)atanh(--------------)
+--R                               +-----------+
+--R                               |          2
+--R                              \|- 4a c + b
+--R         + 
+--R                                                  +-----------+
+--R                       4      2                   |          2
+--R           (- A log(c x  + b x  + a) + 4A log(x))\|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                      +--------------------+ +------------------+
+--R        +-----------+ |   +-----------+      | +-----------+
+--R        |          2  |   |          2       | |          2
+--R     4a\|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 600
+t0:=(A+B*x+C*x^2)/(x^2*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          C x  + B x + A
+--R   (1)  ------------------
+--R           6      4      2
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 298
+
+--S 299 of 600
+r0:=-A/(a*x)+B*log(x)/a-1/4*B*log(a+b*x^2+c*x^4)/a+1/2*b*B*atanh((b+_
+   2*c*x^2)/sqrt(b^2-4*a*c))/(a*sqrt(b^2-4*a*c))-atan(x*sqrt(2)*_
+   sqrt(c)/sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(A+(A*b-2*a*C)/sqrt(b^2-_
+   4*a*c))/(a*sqrt(2)*sqrt(b-sqrt(b^2-4*a*c)))-atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b+sqrt(b^2-4*a*c)))*sqrt(c)*(A+(-A*b+2*a*C)/sqrt(b^2-4*a*c))/_
+   (a*sqrt(2)*sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                       +------------------+
+--R                 +-----------+                         | +-----------+
+--R                 |          2                      +-+ | |          2
+--R         (- 4A x\|- 4a c + b   + (- 4A b + 8C a)x)\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                     +--------------------+
+--R                 +-----------+                       |   +-----------+
+--R                 |          2                    +-+ |   |          2
+--R         (- 4A x\|- 4a c + b   + (4A b - 8C a)x)\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                  2
+--R                  +-+         2c x  + b
+--R           2B b x\|2 atanh(--------------)
+--R                            +-----------+
+--R                            |          2
+--R                           \|- 4a c + b
+--R         + 
+--R                                                                   +-----------+
+--R                +-+       4      2             +-+            +-+  |          2
+--R         (- B x\|2 log(c x  + b x  + a) + 4B x\|2 log(x) - 4A\|2 )\|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                            +--------------------+ +------------------+
+--R              +-----------+ |   +-----------+      | +-----------+
+--R          +-+ |          2  |   |          2       | |          2
+--R     4a x\|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 600
+t0:=(A+B*x+C*x^2)/(x^3*(a+b*x^2+c*x^4))
+--R 
+--R
+--R             2
+--R          C x  + B x + A
+--R   (1)  ------------------
+--R           7      5      3
+--R        c x  + b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 301
+
+--S 302 of 600
+r0:=-1/2*A/(a*x^2)-B/(a*x)-(A*b-a*C)*log(x)/a^2+1/4*(A*b-a*C)*_
+   log(a+b*x^2+c*x^4)/a^2-1/2*(A*(b^2-2*a*c)-a*b*C)*atanh((b+2*c*x^2)/_
+   sqrt(b^2-4*a*c))/(a^2*sqrt(b^2-4*a*c))-B*atan(x*sqrt(2)*sqrt(c)/_
+   sqrt(b-sqrt(b^2-4*a*c)))*sqrt(c)*(1+b/sqrt(b^2-4*a*c))/(a*sqrt(2)*_
+   sqrt(b-sqrt(b^2-4*a*c)))-B*atan(x*sqrt(2)*sqrt(c)/sqrt(b+_
+   sqrt(b^2-4*a*c)))*sqrt(c)*(1-b/sqrt(b^2-4*a*c))/(a*sqrt(2)*_
+   sqrt(b+sqrt(b^2-4*a*c)))
+--R 
+--R
+--R   (2)
+--R                                                   +------------------+
+--R                    +-----------+                  | +-----------+
+--R                  2 |          2            2  +-+ | |          2
+--R         (- 4B a x \|- 4a c + b   - 4B a b x )\|c \|\|- 4a c + b   + b
+--R      *
+--R                       +-+ +-+
+--R                     x\|2 \|c
+--R         atan(-----------------------)
+--R               +--------------------+
+--R               |   +-----------+
+--R               |   |          2
+--R              \|- \|- 4a c + b   + b
+--R     + 
+--R                                                   +--------------------+
+--R                    +-----------+                  |   +-----------+
+--R                  2 |          2            2  +-+ |   |          2
+--R         (- 4B a x \|- 4a c + b   + 4B a b x )\|c \|- \|- 4a c + b   + b
+--R      *
+--R                      +-+ +-+
+--R                    x\|2 \|c
+--R         atan(---------------------)
+--R               +------------------+
+--R               | +-----------+
+--R               | |          2
+--R              \|\|- 4a c + b   + b
+--R     + 
+--R                                                       2
+--R                         2           2 +-+         2c x  + b
+--R           (4A a c - 2A b  + 2C a b)x \|2 atanh(--------------)
+--R                                                 +-----------+
+--R                                                 |          2
+--R                                                \|- 4a c + b
+--R         + 
+--R                           2 +-+       4      2
+--R               (A b - C a)x \|2 log(c x  + b x  + a)
+--R             + 
+--R                               2 +-+                           +-+
+--R               (- 4A b + 4C a)x \|2 log(x) + (- 4B a x - 2A a)\|2
+--R          *
+--R              +-----------+
+--R              |          2
+--R             \|- 4a c + b
+--R      *
+--R          +--------------------+ +------------------+
+--R          |   +-----------+      | +-----------+
+--R          |   |          2       | |          2
+--R         \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R  /
+--R                             +--------------------+ +------------------+
+--R               +-----------+ |   +-----------+      | +-----------+
+--R       2 2 +-+ |          2  |   |          2       | |          2
+--R     4a x \|2 \|- 4a c + b  \|- \|- 4a c + b   + b \|\|- 4a c + b   + b
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 600
+t0:=(e-2*f*x^2)/(e^2+4*d*f*x^2+4*e*f*x^2+4*f^2*x^4)
+--R 
+--R
+--R                      2
+--R                - 2f x  + e
+--R   (1)  --------------------------
+--R          2 4               2    2
+--R        4f x  + (4e + 4d)f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 304
+
+--S 305 of 600
+r0:=1/2*atan((-2*f*x+sqrt(d+2*e)*sqrt(-f))/(sqrt(d)*sqrt(f)))/_
+   (sqrt(d)*sqrt(f))-1/2*atan((2*f*x+sqrt(d+2*e)*sqrt(-f))/_
+   (sqrt(d)*sqrt(f)))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                +---+ +------+                 +---+ +------+
+--R               \|- f \|2e + d  + 2f x         \|- f \|2e + d  - 2f x
+--R        - atan(----------------------) + atan(----------------------)
+--R                       +-+ +-+                        +-+ +-+
+--R                      \|d \|f                        \|d \|f
+--R   (2)  -------------------------------------------------------------
+--R                                    +-+ +-+
+--R                                  2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 600
+t0:=(e-2*f*x^2)/(e^2-4*d*f*x^2+4*e*f*x^2+4*f^2*x^4)
+--R 
+--R
+--R                      2
+--R                - 2f x  + e
+--R   (1)  --------------------------
+--R          2 4               2    2
+--R        4f x  + (4e - 4d)f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 307
+
+--S 308 of 600
+r0:=-1/2*atanh((sqrt(d-2*e)-2*x*sqrt(f))/sqrt(d))/(sqrt(d)*sqrt(f))+_
+   1/2*atanh((sqrt(d-2*e)+2*x*sqrt(f))/sqrt(d))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                 +-+    +--------+             +-+    +--------+
+--R              2x\|f  + \|- 2e + d           2x\|f  - \|- 2e + d
+--R        atanh(--------------------) + atanh(--------------------)
+--R                       +-+                           +-+
+--R                      \|d                           \|d
+--R   (2)  ---------------------------------------------------------
+--R                                  +-+ +-+
+--R                                2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 600
+t0:=(e-4*f*x^3)/(e^2+4*d*f*x^2+4*e*f*x^3+4*f^2*x^6)
+--R 
+--R
+--R                        3
+--R                  - 4f x  + e
+--R   (1)  ------------------------------
+--R          2 6         3         2    2
+--R        4f x  + 4e f x  + 4d f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 310
+
+--S 311 of 600
+r0:=1/2*atan(2*x*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                +-+ +-+
+--R             2x\|d \|f
+--R        atan(----------)
+--R                  3
+--R              2f x  + e
+--R   (2)  ----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 600
+t0:=(e-4*f*x^3)/(e^2-4*d*f*x^2+4*e*f*x^3+4*f^2*x^6)
+--R 
+--R
+--R                        3
+--R                  - 4f x  + e
+--R   (1)  ------------------------------
+--R          2 6         3         2    2
+--R        4f x  + 4e f x  - 4d f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 313
+
+--S 314 of 600
+r0:=1/2*atanh(2*x*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                 +-+ +-+
+--R              2x\|d \|f
+--R        atanh(----------)
+--R                   3
+--R               2f x  + e
+--R   (2)  -----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 600
+t0:=(e-2*f*(-1+n)*x^n)/(e^2+4*d*f*x^2+4*e*f*x^n+4*f^2*x^(2*n))
+--R 
+--R
+--R                            n
+--R              (- 2f n + 2f)x  + e
+--R   (1)  -------------------------------
+--R          2 2n         n         2    2
+--R        4f x   + 4e f x  + 4d f x  + e
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 600
+r0:=1/2*atan(2*x*sqrt(d)*sqrt(f)/(e+2*f*x^n))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                +-+ +-+
+--R             2x\|d \|f
+--R        atan(----------)
+--R                  n
+--R              2f x  + e
+--R   (2)  ----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 600
+t0:=(e-2*f*(-1+n)*x^n)/(e^2-4*d*f*x^2+4*e*f*x^n+4*f^2*x^(2*n))
+--R 
+--R
+--R                            n
+--R              (- 2f n + 2f)x  + e
+--R   (1)  -------------------------------
+--R          2 2n         n         2    2
+--R        4f x   + 4e f x  - 4d f x  + e
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 600
+r0:=1/2*atanh(2*x*sqrt(d)*sqrt(f)/(e+2*f*x^n))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                 +-+ +-+
+--R              2x\|d \|f
+--R        atanh(----------)
+--R                   n
+--R               2f x  + e
+--R   (2)  -----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 600
+t0:=x/(e^2+4*e*f*x^2+4*d*f*x^4+4*f^2*x^4)
+--R 
+--R
+--R                      x
+--R   (1)  -----------------------------
+--R           2         4         2    2
+--R        (4f  + 4d f)x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 322
+
+--S 323 of 600
+r0:=1/4*atan((e+2*(d+f)*x^2)*sqrt(f)/(e*sqrt(d)))/(e*sqrt(d)*sqrt(f))
+--R 
+--R
+--R                        2      +-+
+--R             ((2f + 2d)x  + e)\|f
+--R        atan(---------------------)
+--R                       +-+
+--R                     e\|d
+--R   (2)  ---------------------------
+--R                    +-+ +-+
+--R                 4e\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+)clear all
+
+--S 325 of 600
+t0:=x/(e^2+4*e*f*x^2-4*d*f*x^4+4*f^2*x^4)
+--R 
+--R
+--R                      x
+--R   (1)  -----------------------------
+--R           2         4         2    2
+--R        (4f  - 4d f)x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 325
+
+--S 326 of 600
+r0:=-1/4*atanh((e-2*(d-f)*x^2)*sqrt(f)/(e*sqrt(d)))/(e*sqrt(d)*sqrt(f))
+--R 
+--R
+--R                           2      +-+
+--R                ((2f - 2d)x  + e)\|f
+--R          atanh(---------------------)
+--R                          +-+
+--R                        e\|d
+--R   (2)  - ----------------------------
+--R                      +-+ +-+
+--R                   4e\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 600
+t0:=x^2*(3*e+2*f*x^2)/(e^2+4*e*f*x^2+4*f^2*x^4+4*d*f*x^6)
+--R 
+--R
+--R                     4       2
+--R                 2f x  + 3e x
+--R   (1)  ------------------------------
+--R              6     2 4         2    2
+--R        4d f x  + 4f x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 328
+
+--S 329 of 600
+r0:=1/2*atan(2*x^3*sqrt(d)*sqrt(f)/(e+2*f*x^2))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R               3 +-+ +-+
+--R             2x \|d \|f
+--R        atan(-----------)
+--R                  2
+--R              2f x  + e
+--R   (2)  -----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 600
+t0:=x^2*(3*e+2*f*x^2)/(e^2+4*e*f*x^2+4*f^2*x^4-4*d*f*x^6)
+--R 
+--R
+--R                      4       2
+--R                - 2f x  - 3e x
+--R   (1)  ------------------------------
+--R              6     2 4         2    2
+--R        4d f x  - 4f x  - 4e f x  - e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 331
+
+--S 332 of 600
+r0:=1/2*atanh(2*x^3*sqrt(d)*sqrt(f)/(e+2*f*x^2))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                3 +-+ +-+
+--R              2x \|d \|f
+--R        atanh(-----------)
+--R                   2
+--R               2f x  + e
+--R   (2)  ------------------
+--R               +-+ +-+
+--R             2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 600
+t0:=x^m*(e*(1+m)+2*f*(-1+m)*x^2)/(e^2+4*e*f*x^2+4*f^2*x^4+4*d*f*x^(2+2*m))
+--R 
+--R
+--R                         2            m
+--R            ((2f m - 2f)x  + e m + e)x
+--R   (1)  -----------------------------------
+--R              2m + 2     2 4         2    2
+--R        4d f x       + 4f x  + 4e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 600
+r0:=1/2*atan(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^2))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R               m + 1 +-+ +-+
+--R             2x     \|d \|f
+--R        atan(---------------)
+--R                    2
+--R                2f x  + e
+--R   (2)  ---------------------
+--R                +-+ +-+
+--R              2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 600
+t0:=x^m*(e*(1+m)+2*f*(-1+m)*x^2)/(e^2+4*e*f*x^2+4*f^2*x^4-4*d*f*x^(2+2*m))
+--R 
+--R
+--R                          2            m
+--R           ((- 2f m + 2f)x  - e m - e)x
+--R   (1)  -----------------------------------
+--R              2m + 2     2 4         2    2
+--R        4d f x       - 4f x  - 4e f x  - e
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 600
+r0:=1/2*atanh(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^2))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                m + 1 +-+ +-+
+--R              2x     \|d \|f
+--R        atanh(---------------)
+--R                     2
+--R                 2f x  + e
+--R   (2)  ----------------------
+--R                 +-+ +-+
+--R               2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 600
+t0:=x*(2*e-2*f*x^3)/(e^2+4*e*f*x^3+4*d*f*x^4+4*f^2*x^6)
+--R 
+--R
+--R                      4
+--R                - 2f x  + 2e x
+--R   (1)  ------------------------------
+--R          2 6         4         3    2
+--R        4f x  + 4d f x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 340
+
+--S 341 of 600
+r0:=1/2*atan(2*x^2*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R               2 +-+ +-+
+--R             2x \|d \|f
+--R        atan(-----------)
+--R                  3
+--R              2f x  + e
+--R   (2)  -----------------
+--R              +-+ +-+
+--R            2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 600
+t0:=x*(2*e-2*f*x^3)/(e^2+4*e*f*x^3-4*d*f*x^4+4*f^2*x^6)
+--R 
+--R
+--R                      4
+--R                - 2f x  + 2e x
+--R   (1)  ------------------------------
+--R          2 6         4         3    2
+--R        4f x  - 4d f x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 343
+
+--S 344 of 600
+r0:=1/2*atanh(2*x^2*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                2 +-+ +-+
+--R              2x \|d \|f
+--R        atanh(-----------)
+--R                   3
+--R               2f x  + e
+--R   (2)  ------------------
+--R               +-+ +-+
+--R             2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 600
+t0:=x^2/(e^2+4*e*f*x^3+4*d*f*x^6+4*f^2*x^6)
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R           2         6         3    2
+--R        (4f  + 4d f)x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 346
+
+--S 347 of 600
+r0:=1/6*atan((e+2*(d+f)*x^3)*sqrt(f)/(e*sqrt(d)))/(e*sqrt(d)*sqrt(f))
+--R 
+--R
+--R                        3      +-+
+--R             ((2f + 2d)x  + e)\|f
+--R        atan(---------------------)
+--R                       +-+
+--R                     e\|d
+--R   (2)  ---------------------------
+--R                    +-+ +-+
+--R                 6e\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 600
+t0:=x^2/(e^2+4*e*f*x^3-4*d*f*x^6+4*f^2*x^6)
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R           2         6         3    2
+--R        (4f  - 4d f)x  + 4e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 349
+
+--S 350 of 600
+r0:=-1/6*atanh((e-2*(d-f)*x^3)*sqrt(f)/(e*sqrt(d)))/(e*sqrt(d)*sqrt(f))
+--R 
+--R
+--R                           3      +-+
+--R                ((2f - 2d)x  + e)\|f
+--R          atanh(---------------------)
+--R                          +-+
+--R                        e\|d
+--R   (2)  - ----------------------------
+--R                      +-+ +-+
+--R                   6e\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 600
+t0:=x^m*(e*(1+m)+2*f*(-2+m)*x^3)/(e^2+4*e*f*x^3+4*f^2*x^6+4*d*f*x^(2+2*m))
+--R 
+--R
+--R                         3            m
+--R            ((2f m - 4f)x  + e m + e)x
+--R   (1)  -----------------------------------
+--R              2m + 2     2 6         3    2
+--R        4d f x       + 4f x  + 4e f x  + e
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 600
+r0:=1/2*atan(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R               m + 1 +-+ +-+
+--R             2x     \|d \|f
+--R        atan(---------------)
+--R                    3
+--R                2f x  + e
+--R   (2)  ---------------------
+--R                +-+ +-+
+--R              2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 600
+t0:=x^m*(e*(1+m)+2*f*(-2+m)*x^3)/(e^2+4*e*f*x^3+4*f^2*x^6-4*d*f*x^(2+2*m))
+--R 
+--R
+--R                          3            m
+--R           ((- 2f m + 4f)x  - e m - e)x
+--R   (1)  -----------------------------------
+--R              2m + 2     2 6         3    2
+--R        4d f x       - 4f x  - 4e f x  - e
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 600
+r0:=1/2*atanh(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^3))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                m + 1 +-+ +-+
+--R              2x     \|d \|f
+--R        atanh(---------------)
+--R                     3
+--R                 2f x  + e
+--R   (2)  ----------------------
+--R                 +-+ +-+
+--R               2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 600
+t0:=x^m*(e*(1+m)+2*f*(1+m-n)*x^n)/(e^2+4*d*f*x^(2+2*m)+4*e*f*x^n+4*f^2*x^(2*n))
+--R 
+--R
+--R                             m n             m
+--R        (- 2f n + 2f m + 2f)x x  + (e m + e)x
+--R   (1)  --------------------------------------
+--R           2 2n         n         2m + 2    2
+--R         4f x   + 4e f x  + 4d f x       + e
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 600
+r0:=1/2*atan(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^n))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R               m + 1 +-+ +-+
+--R             2x     \|d \|f
+--R        atan(---------------)
+--R                    n
+--R                2f x  + e
+--R   (2)  ---------------------
+--R                +-+ +-+
+--R              2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 600
+t0:=x^m*(e*(1+m)+2*f*(1+m-n)*x^n)/(e^2-4*d*f*x^(2+2*m)+4*e*f*x^n+4*f^2*x^(2*n))
+--R 
+--R
+--R                             m n             m
+--R        (- 2f n + 2f m + 2f)x x  + (e m + e)x
+--R   (1)  --------------------------------------
+--R           2 2n         n         2m + 2    2
+--R         4f x   + 4e f x  - 4d f x       + e
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 600
+r0:=1/2*atanh(2*x^(1+m)*sqrt(d)*sqrt(f)/(e+2*f*x^n))/(sqrt(d)*sqrt(f))
+--R 
+--R
+--R                m + 1 +-+ +-+
+--R              2x     \|d \|f
+--R        atanh(---------------)
+--R                     n
+--R                 2f x  + e
+--R   (2)  ----------------------
+--R                 +-+ +-+
+--R               2\|d \|f
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 600
+t0:=(A+B*x+C*x^2+D*x^3)/(a+b*x+c*x^2+b*x^3+a*x^4)
+--R 
+--R
+--R               3      2
+--R            D x  + C x  + B x + A
+--R   (1)  ----------------------------
+--R           4      3      2
+--R        a x  + b x  + c x  + b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 364
+
+--S 365 of 600
+r0:=-1/4*log(2*a+2*a*x^2+x*(b-sqrt(8*a^2+b^2-4*a*c)))*(2*a*(A-C)+_
+   D*(b-sqrt(8*a^2+b^2-4*a*c)))/(a*sqrt(8*a^2+b^2-4*a*c))+_
+   1/4*log(2*a+2*a*x^2+x*(b+sqrt(8*a^2+b^2-4*a*c)))*(2*a*(A-C)+_
+   D*(b+sqrt(8*a^2+b^2-4*a*c)))/(a*sqrt(8*a^2+b^2-4*a*c))+atan((b+4*a*x-_
+   sqrt(8*a^2+b^2-4*a*c))/(sqrt(2)*sqrt(4*a^2+2*a*c-b*(b-sqrt(8*a^2+b^2-_
+   4*a*c)))))*(4*a^2*B+b*D*(b-sqrt(8*a^2+b^2-4*a*c))-a*(b*C+2*c*D+_
+   A*(b-sqrt(8*a^2+b^2-4*a*c))-C*sqrt(8*a^2+b^2-4*a*c)))/(a*sqrt(2)*_
+   sqrt(8*a^2+b^2-4*a*c)*sqrt(4*a^2+2*a*c-b*(b-sqrt(8*a^2+b^2-4*a*c))))-_
+   atan((b+4*a*x+sqrt(8*a^2+b^2-4*a*c))/(sqrt(2)*sqrt(4*a^2+2*a*c-_
+   b*(b+sqrt(8*a^2+b^2-4*a*c)))))*(4*a^2*B+b*D*(b+sqrt(8*a^2+b^2-4*a*c))-_
+   a*(b*C+2*c*D+C*sqrt(8*a^2+b^2-4*a*c)+A*(b+sqrt(8*a^2+b^2-4*a*c))))/_
+   (a*sqrt(2)*sqrt(8*a^2+b^2-4*a*c)*sqrt(4*a^2+2*a*c-_
+   b*(b+sqrt(8*a^2+b^2-4*a*c))))
+--R 
+--R
+--R   (2)
+--R                                 +-----------------+
+--R                                 |          2     2                 2
+--R           (- 4D b + (4C + 4A)a)\|- 4a c + b  + 8a   + 8D a c - 4D b
+--R         + 
+--R                               2
+--R           (4C + 4A)a b - 16B a
+--R      *
+--R          +---------------------------------------+
+--R          |  +-----------------+
+--R          |  |          2     2            2     2
+--R         \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R                        +-----------------+
+--R                        |          2     2
+--R                       \|- 4a c + b  + 8a   + 4a x + b
+--R         atan(------------------------------------------------)
+--R                   +-----------------------------------------+
+--R                   |    +-----------------+
+--R               +-+ |    |          2     2            2     2
+--R              \|2 \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R     + 
+--R                                 +-----------------+
+--R                                 |          2     2                 2
+--R           (4D b + (- 4C - 4A)a)\|- 4a c + b  + 8a   + 8D a c - 4D b
+--R         + 
+--R                               2
+--R           (4C + 4A)a b - 16B a
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------------+
+--R          |    |          2     2            2     2
+--R         \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R                       +-----------------+
+--R                       |          2     2
+--R                      \|- 4a c + b  + 8a   - 4a x - b
+--R         atan(----------------------------------------------)
+--R                   +---------------------------------------+
+--R                   |  +-----------------+
+--R               +-+ |  |          2     2            2     2
+--R              \|2 \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R     + 
+--R                    +-----------------+
+--R                +-+ |          2     2                         +-+
+--R             (D\|2 \|- 4a c + b  + 8a   + (D b + (- 2C + 2A)a)\|2 )
+--R          *
+--R                   +-----------------+
+--R                   |          2     2        2
+--R             log(x\|- 4a c + b  + 8a   + 2a x  + b x + 2a)
+--R         + 
+--R                    +-----------------+
+--R                +-+ |          2     2                         +-+
+--R             (D\|2 \|- 4a c + b  + 8a   + (- D b + (2C - 2A)a)\|2 )
+--R          *
+--R                     +-----------------+
+--R                     |          2     2        2
+--R             log(- x\|- 4a c + b  + 8a   + 2a x  + b x + 2a)
+--R      *
+--R          +-----------------------------------------+
+--R          |    +-----------------+
+--R          |    |          2     2            2     2
+--R         \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R      *
+--R          +---------------------------------------+
+--R          |  +-----------------+
+--R          |  |          2     2            2     2
+--R         \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R  /
+--R                                  +-----------------------------------------+
+--R              +-----------------+ |    +-----------------+
+--R          +-+ |          2     2  |    |          2     2            2     2
+--R       4a\|2 \|- 4a c + b  + 8a  \|- b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R    *
+--R        +---------------------------------------+
+--R        |  +-----------------+
+--R        |  |          2     2            2     2
+--R       \|b\|- 4a c + b  + 8a   + 2a c - b  + 4a
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 600
+t0:=x^4*(5+x+3*x^2+2*x^3)/(2+x+3*x^2+x^3+2*x^4)
+--R 
+--R
+--R           7     6    5     4
+--R         2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 3x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 367
+
+--S 368 of 600
+r0:=5/4*x-3/4*x^2+1/3*x^3+1/4*x^4+1/3*log(1+x+x^2)-13/48*log(2-x+2*x^2)+_
+   1/24*atan((1-4*x)/sqrt(15))*sqrt(5/3)-10/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R            +-+      2               +-+     2
+--R       - 13\|3 log(2x  - x + 2) + 16\|3 log(x  + x + 1)
+--R     + 
+--R                            +--+                     +-+
+--R           +-+     (4x - 1)\|15             (2x + 1)\|3
+--R       - 2\|5 atan(-------------) - 160atan(------------)
+--R                         15                       3
+--R     + 
+--R           4      3      2        +-+
+--R       (12x  + 16x  - 36x  + 60x)\|3
+--R  /
+--R        +-+
+--R     48\|3
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +-+ +-+ +--+
+--R        \|3 \|5 \|15  - 15
+--R   (3)  ------------------
+--R            2
+--R        288x  - 144x + 288
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 600
+t0:=x^3*(5+x+3*x^2+2*x^3)/(2+x+3*x^2+x^3+2*x^4)
+--R 
+--R
+--R           6     5    4     3
+--R         2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 3x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 370
+
+--S 371 of 600
+r0:=-3/2*x+1/2*x^2+1/3*x^3+2/3*log(1+x+x^2)-1/24*log(2-x+2*x^2)+_
+   5/12*atan((1-4*x)/sqrt(15))*sqrt(5/3)+8/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          +-+      2               +-+     2
+--R       - \|3 log(2x  - x + 2) + 16\|3 log(x  + x + 1)
+--R     + 
+--R                           +--+                    +-+
+--R          +-+     (4x - 1)\|15            (2x + 1)\|3        3      2        +-+
+--R     - 10\|5 atan(-------------) + 64atan(------------) + (8x  + 12x  - 36x)\|3
+--R                        15                      3
+--R  /
+--R        +-+
+--R     24\|3
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R          +-+ +-+ +--+
+--R        5\|3 \|5 \|15  - 75
+--R   (3)  -------------------
+--R             2
+--R         144x  - 72x + 144
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 600
+t0:=x^2*(5+x+3*x^2+2*x^3)/(2+x+3*x^2+x^3+2*x^4)
+--R 
+--R
+--R           5     4    3     2
+--R         2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 3x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 373
+
+--S 374 of 600
+r0:=x+1/2*x^2-log(1+x+x^2)+1/4*log(2-x+2*x^2)+1/6*atan((1-4*x)/sqrt(15))*_
+   sqrt(5/3)+2/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                          +--+
+--R         +-+      2               +-+     2              +-+     (4x - 1)\|15
+--R       3\|3 log(2x  - x + 2) - 12\|3 log(x  + x + 1) - 2\|5 atan(-------------)
+--R                                                                       15
+--R     + 
+--R                      +-+
+--R             (2x + 1)\|3        2        +-+
+--R       8atan(------------) + (6x  + 12x)\|3
+--R                   3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +-+ +-+ +--+
+--R        \|3 \|5 \|15  - 15
+--R   (3)  ------------------
+--R             2
+--R          72x  - 36x + 72
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 600
+t0:=x*(5+x+3*x^2+2*x^3)/(2+x+3*x^2+x^3+2*x^4)
+--R 
+--R
+--R            4     3    2
+--R          2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 3x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 376
+
+--S 377 of 600
+r0:=x+1/3*log(1+x+x^2)+1/6*log(2-x+2*x^2)-1/3*atan((1-4*x)/sqrt(15))*_
+   sqrt(5/3)-10/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                        +--+
+--R        +-+      2              +-+     2              +-+     (4x - 1)\|15
+--R       \|3 log(2x  - x + 2) + 2\|3 log(x  + x + 1) + 2\|5 atan(-------------)
+--R                                                                     15
+--R     + 
+--R                         +-+
+--R                (2x + 1)\|3        +-+
+--R       - 20atan(------------) + 6x\|3
+--R                      3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           +-+ +-+ +--+
+--R        - \|3 \|5 \|15  + 15
+--R   (3)  --------------------
+--R              2
+--R           36x  - 18x + 36
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 600
+t0:=(5+x+3*x^2+2*x^3)/(2+x+3*x^2+x^3+2*x^4)
+--R 
+--R
+--R             3     2
+--R           2x  + 3x  + x + 5
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 3x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 379
+
+--S 380 of 600
+r0:=2/3*log(1+x+x^2)-1/6*log(2-x+2*x^2)-1/3*atan((1-4*x)/sqrt(15))*_
+   sqrt(5/3)+8/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                          +--+
+--R          +-+      2              +-+     2              +-+     (4x - 1)\|15
+--R       - \|3 log(2x  - x + 2) + 4\|3 log(x  + x + 1) + 2\|5 atan(-------------)
+--R                                                                       15
+--R     + 
+--R                       +-+
+--R              (2x + 1)\|3
+--R       16atan(------------)
+--R                    3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           +-+ +-+ +--+
+--R        - \|3 \|5 \|15  + 15
+--R   (3)  --------------------
+--R              2
+--R           36x  - 18x + 36
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 600
+t0:=(5+x+3*x^2+2*x^3)/(x*(2+x+3*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  ------------------------
+--R          5    4     3    2
+--R        2x  + x  + 3x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 382
+
+--S 383 of 600
+r0:=5/2*log(x)-log(1+x+x^2)-1/4*log(2-x+2*x^2)+1/6*atan((1-4*x)/sqrt(15))*_
+   sqrt(5/3)+2/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R           +-+      2               +-+     2               +-+
+--R       - 3\|3 log(2x  - x + 2) - 12\|3 log(x  + x + 1) + 30\|3 log(x)
+--R     + 
+--R                            +--+                   +-+
+--R           +-+     (4x - 1)\|15           (2x + 1)\|3
+--R       - 2\|5 atan(-------------) + 8atan(------------)
+--R                         15                     3
+--R  /
+--R        +-+
+--R     12\|3
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +-+ +-+ +--+
+--R        \|3 \|5 \|15  - 15
+--R   (3)  ------------------
+--R             2
+--R          72x  - 36x + 72
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 600
+t0:=(5+x+3*x^2+2*x^3)/(x^2*(2+x+3*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  -------------------------
+--R          6    5     4    3     2
+--R        2x  + x  + 3x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 385
+
+--S 386 of 600
+r0:=(-5/2)/x-3/4*log(x)+1/3*log(1+x+x^2)+1/24*log(2-x+2*x^2)+_
+   5/12*atan((1-4*x)/sqrt(15))*sqrt(5/3)-10/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         +-+      2               +-+     2                +-+
+--R       x\|3 log(2x  - x + 2) + 8x\|3 log(x  + x + 1) - 18x\|3 log(x)
+--R     + 
+--R                              +--+                      +-+
+--R             +-+     (4x - 1)\|15              (2x + 1)\|3        +-+
+--R       - 10x\|5 atan(-------------) - 80x atan(------------) - 60\|3
+--R                           15                        3
+--R  /
+--R         +-+
+--R     24x\|3
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R          +-+ +-+ +--+
+--R        5\|3 \|5 \|15  - 75
+--R   (3)  -------------------
+--R             2
+--R         144x  - 72x + 144
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 600
+t0:=(5+x+3*x^2+2*x^3)/(x^3*(2+x+3*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  -------------------------
+--R          7    6     5    4     3
+--R        2x  + x  + 3x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 388
+
+--S 389 of 600
+r0:=(-5/4)/x^2+3/4/x-15/8*log(x)+2/3*log(1+x+x^2)+13/48*log(2-x+2*x^2)+_
+   1/24*atan((1-4*x)/sqrt(15))*sqrt(5/3)+8/3*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R          2 +-+      2               2 +-+     2               2 +-+
+--R       13x \|3 log(2x  - x + 2) + 32x \|3 log(x  + x + 1) - 90x \|3 log(x)
+--R     + 
+--R                              +--+                       +-+
+--R           2 +-+     (4x - 1)\|15         2     (2x + 1)\|3                +-+
+--R       - 2x \|5 atan(-------------) + 128x atan(------------) + (36x - 60)\|3
+--R                           15                         3
+--R  /
+--R        2 +-+
+--R     48x \|3
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R         +-+ +-+ +--+
+--R        \|3 \|5 \|15  - 15
+--R   (3)  ------------------
+--R            2
+--R        288x  - 144x + 288
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 600
+t0:=x^3*(5+x+3*x^2+2*x^3)/(2+x+5*x^2+x^3+2*x^4)
+--R 
+--R
+--R           6     5    4     3
+--R         2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 5x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 391
+
+--S 392 of 600
+r0:=1/28*x^2*(7-5*%i*sqrt(7))+1/42*x^3*(7-5*%i*sqrt(7))+1/28*x^2*_
+   (7+5*%i*sqrt(7))+1/42*x^3*(7+5*%i*sqrt(7))-1/28*x*(35-9*%i*sqrt(7))-_
+   1/28*x*(35+9*%i*sqrt(7))+3/112*log(4+4*x^2+x*(1-%i*sqrt(7)))*(7-_
+   11*%i*sqrt(7))+3/112*log(4+4*x^2+x*(1+%i*sqrt(7)))*(7+11*%i*sqrt(7))-_
+   11/4*atan((1+8*x+%i*sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*(9*%i-5*sqrt(7))/_
+   sqrt(14*(35-%i*sqrt(7)))+11/4*atan((1+8*x-%i*sqrt(7))/sqrt(2*_
+   (35+%i*sqrt(7))))*(9*%i+5*sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--R 
+--R
+--R   (2)
+--R                           +--------------+         +-+
+--R             +-+           |     +-+             %i\|7  + 8x + 1
+--R       (4620\|7  - 8316%i)\|14%i\|7  + 490 atan(-----------------)
+--R                                                 +--------------+
+--R                                                 |      +-+
+--R                                                \|- 2%i\|7  + 70
+--R     + 
+--R                             +----------------+        +-+
+--R               +-+           |       +-+            %i\|7  - 8x - 1
+--R       (- 4620\|7  - 8316%i)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                     +------------+
+--R                                                     |    +-+
+--R                                                    \|2%i\|7  + 70
+--R     + 
+--R                 +-+               +-+     2
+--R           (99%i\|7  + 63)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R                 +-+                 +-+     2                3       2
+--R         (- 99%i\|7  + 63)log(- %i x\|7  + 4x  + x + 4) + 112x  + 168x  - 840x
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R         +----------------+ +--------------+
+--R         |       +-+        |     +-+
+--R     336\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 392
+
+--S 393 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                            +------------+
+--R                2            +-+         2                  |    +-+
+--R         ((- 23x  + 3x - 23)\|7  - 35%i x  - 49%i x - 35%i)\|2%i\|7  + 70
+--R      *
+--R          +--------------+
+--R          |     +-+
+--R         \|14%i\|7  + 490
+--R     + 
+--R                                                            +----------------+
+--R                2            +-+         2                  |       +-+
+--R         ((- 23x  + 3x - 23)\|7  + 35%i x  + 49%i x + 35%i)\|- 14%i\|7  + 490
+--R      *
+--R          +--------------+
+--R          |      +-+
+--R         \|- 2%i\|7  + 70
+--R     + 
+--R             2
+--R       21560x  - 4312x + 21560
+--R  /
+--R          4        3         2
+--R     6272x  + 3136x  + 15680x  + 3136x + 6272
+--R                                           Type: Expression(Complex(Integer))
+--E 393
+
+)clear all
+
+--S 394 of 600
+t0:=x^2*(5+x+3*x^2+2*x^3)/(2+x+5*x^2+x^3+2*x^4)
+--R 
+--R
+--R           5     4    3     2
+--R         2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 5x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 394
+
+--S 395 of 600
+r0:=1/14*x*(7-5*%i*sqrt(7))+1/28*x^2*(7-5*%i*sqrt(7))+1/14*x*_
+   (7+5*%i*sqrt(7))+1/28*x^2*(7+5*%i*sqrt(7))-1/56*log(4+4*x^2+x*_
+   (1+%i*sqrt(7)))*(35-9*%i*sqrt(7))-1/56*log(4+4*x^2+x*(1-%i*sqrt(7)))*_
+   (35+9*%i*sqrt(7))+1/2*atan((1+8*x+%i*sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*_
+   (53*%i-sqrt(7))/sqrt(14*(35-%i*sqrt(7)))-1/2*atan((1+8*x-%i*sqrt(7))/_
+   sqrt(2*(35+%i*sqrt(7))))*(53*%i+sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--R 
+--R
+--R   (2)
+--R                           +--------------+         +-+
+--R             +-+           |     +-+             %i\|7  + 8x + 1
+--R       (- 28\|7  + 1484%i)\|14%i\|7  + 490 atan(-----------------)
+--R                                                 +--------------+
+--R                                                 |      +-+
+--R                                                \|- 2%i\|7  + 70
+--R     + 
+--R                         +----------------+        +-+
+--R           +-+           |       +-+            %i\|7  - 8x - 1
+--R       (28\|7  + 1484%i)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                 +------------+
+--R                                                 |    +-+
+--R                                                \|2%i\|7  + 70
+--R     + 
+--R                +-+               +-+     2
+--R           (9%i\|7  - 35)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R                  +-+                 +-+     2               2
+--R           (- 9%i\|7  - 35)log(- %i x\|7  + 4x  + x + 4) + 28x  + 56x
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R        +----------------+ +--------------+
+--R        |       +-+        |     +-+
+--R     56\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 395
+
+--S 396 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                      +------------+
+--R            2           +-+         2                 |    +-+
+--R         ((x  - 5x + 1)\|7  + 21%i x  + 7%i x + 21%i)\|2%i\|7  + 70
+--R      *
+--R          +--------------+
+--R          |     +-+
+--R         \|14%i\|7  + 490
+--R     + 
+--R                                                      +----------------+
+--R            2           +-+         2                 |       +-+
+--R         ((x  - 5x + 1)\|7  - 21%i x  - 7%i x - 21%i)\|- 14%i\|7  + 490
+--R      *
+--R          +--------------+
+--R          |      +-+
+--R         \|- 2%i\|7  + 70
+--R     + 
+--R             2
+--R       - 392x  + 5096x - 392
+--R  /
+--R          4        3        2
+--R     3136x  + 1568x  + 7840x  + 1568x + 3136
+--R                                           Type: Expression(Complex(Integer))
+--E 396
+
+)clear all
+
+--S 397 of 600
+t0:=x*(5+x+3*x^2+2*x^3)/(2+x+5*x^2+x^3+2*x^4)
+--R 
+--R
+--R            4     3    2
+--R          2x  + 3x  + x  + 5x
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 5x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 397
+
+--S 398 of 600
+r0:=1/14*x*(7-5*%i*sqrt(7))+1/28*log(4+4*x^2+x*(1+%i*sqrt(7)))*(7-5*%i*_
+   sqrt(7))+1/14*x*(7+5*%i*sqrt(7))+1/28*log(4+4*x^2+x*(1-%i*sqrt(7)))*_
+   (7+5*%i*sqrt(7))+atan((1+8*x+%i*sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*_
+   (19*%i-7*sqrt(7))/sqrt(14*(35-%i*sqrt(7)))-atan((1+8*x-%i*sqrt(7))/_
+   sqrt(2*(35+%i*sqrt(7))))*(19*%i+7*sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--R 
+--R
+--R   (2)
+--R                           +--------------+         +-+
+--R              +-+          |     +-+             %i\|7  + 8x + 1
+--R       (- 196\|7  + 532%i)\|14%i\|7  + 490 atan(-----------------)
+--R                                                 +--------------+
+--R                                                 |      +-+
+--R                                                \|- 2%i\|7  + 70
+--R     + 
+--R                         +----------------+        +-+
+--R            +-+          |       +-+            %i\|7  - 8x - 1
+--R       (196\|7  + 532%i)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                 +------------+
+--R                                                 |    +-+
+--R                                                \|2%i\|7  + 70
+--R     + 
+--R                  +-+              +-+     2
+--R           (- 5%i\|7  + 7)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R                +-+                +-+     2
+--R           (5%i\|7  + 7)log(- %i x\|7  + 4x  + x + 4) + 28x
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R        +----------------+ +--------------+
+--R        |       +-+        |     +-+
+--R     28\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 398
+
+--S 399 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                    +------------+
+--R             2          +-+        2                |    +-+
+--R         ((3x  - x + 3)\|7  + 7%i x  + 7%i x + 7%i)\|2%i\|7  + 70
+--R      *
+--R          +--------------+
+--R          |     +-+
+--R         \|14%i\|7  + 490
+--R     + 
+--R                                                    +----------------+
+--R             2          +-+        2                |       +-+
+--R         ((3x  - x + 3)\|7  - 7%i x  - 7%i x - 7%i)\|- 14%i\|7  + 490
+--R      *
+--R          +--------------+
+--R          |      +-+
+--R         \|- 2%i\|7  + 70
+--R     + 
+--R              2
+--R       - 2744x  + 1176x - 2744
+--R  /
+--R          4       3        2
+--R     1568x  + 784x  + 3920x  + 784x + 1568
+--R                                           Type: Expression(Complex(Integer))
+--E 399
+
+)clear all
+
+--S 400 of 600
+t0:=(5+x+3*x^2+2*x^3)/(2+x+5*x^2+x^3+2*x^4)
+--R 
+--R
+--R             3     2
+--R           2x  + 3x  + x + 5
+--R   (1)  ----------------------
+--R          4    3     2
+--R        2x  + x  + 5x  + x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 400
+
+--S 401 of 600
+r0:=1/28*log(4+4*x^2+x*(1+%i*sqrt(7)))*(7-5*%i*sqrt(7))+1/28*log(4+4*x^2+_
+   x*(1-%i*sqrt(7)))*(7+5*%i*sqrt(7))-atan((1+8*x+%i*sqrt(7))/sqrt(2*_
+   (35-%i*sqrt(7))))*(19*%i-7*sqrt(7))/sqrt(14*(35-%i*sqrt(7)))+_
+   atan((1+8*x-%i*sqrt(7))/sqrt(2*(35+%i*sqrt(7))))*(19*%i+7*sqrt(7))/_
+   sqrt(14*(35+%i*sqrt(7)))
+--R 
+--R
+--R   (2)
+--R                         +--------------+         +-+
+--R            +-+          |     +-+             %i\|7  + 8x + 1
+--R       (196\|7  - 532%i)\|14%i\|7  + 490 atan(-----------------)
+--R                                               +--------------+
+--R                                               |      +-+
+--R                                              \|- 2%i\|7  + 70
+--R     + 
+--R                           +----------------+        +-+
+--R              +-+          |       +-+            %i\|7  - 8x - 1
+--R       (- 196\|7  - 532%i)\|- 14%i\|7  + 490 atan(---------------)
+--R                                                   +------------+
+--R                                                   |    +-+
+--R                                                  \|2%i\|7  + 70
+--R     + 
+--R                  +-+              +-+     2
+--R           (- 5%i\|7  + 7)log(%i x\|7  + 4x  + x + 4)
+--R         + 
+--R                +-+                +-+     2
+--R           (5%i\|7  + 7)log(- %i x\|7  + 4x  + x + 4)
+--R      *
+--R          +----------------+ +--------------+
+--R          |       +-+        |     +-+
+--R         \|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R  /
+--R        +----------------+ +--------------+
+--R        |       +-+        |     +-+
+--R     28\|- 14%i\|7  + 490 \|14%i\|7  + 490
+--R                                           Type: Expression(Complex(Integer))
+--E 401
+
+--S 402 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                                      +------------+
+--R               2          +-+        2                |    +-+
+--R         ((- 3x  + x - 3)\|7  - 7%i x  - 7%i x - 7%i)\|2%i\|7  + 70
+--R      *
+--R          +--------------+
+--R          |     +-+
+--R         \|14%i\|7  + 490
+--R     + 
+--R                                                      +----------------+
+--R               2          +-+        2                |       +-+
+--R         ((- 3x  + x - 3)\|7  + 7%i x  + 7%i x + 7%i)\|- 14%i\|7  + 490
+--R      *
+--R          +--------------+
+--R          |      +-+
+--R         \|- 2%i\|7  + 70
+--R     + 
+--R            2
+--R       2744x  - 1176x + 2744
+--R  /
+--R          4       3        2
+--R     1568x  + 784x  + 3920x  + 784x + 1568
+--R                                           Type: Expression(Complex(Integer))
+--E 402
+
+)clear all
+
+--S 403 of 600
+t0:=(5+x+3*x^2+2*x^3)/(x*(2+x+5*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  ------------------------
+--R          5    4     3    2
+--R        2x  + x  + 5x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 403
+
+--S 404 of 600
+--r0:=1/28*log(x)*(35-9*%i*sqrt(7))-1/56*log(4*%i+4*%i*x^2+x*(%i-sqrt(7)))*_
+--   (35-9*%i*sqrt(7))+1/28*log(x)*(35+9*%i*sqrt(7))-1/56*log(4*%i+_
+--   4*%i*x^2+x*(%i+sqrt(7)))*(35+9*%i*sqrt(7))-1/2*atanh((%i+8*%i*x-_
+--   sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*(53+%i*sqrt(7))/sqrt(14*(35-%i*_
+--   sqrt(7)))+1/2*atanh((%i+8*%i*x+sqrt(7))/sqrt(2*(35+%i*sqrt(7))))*_
+--   (53-%i*sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--E 404
+
+--S 405 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 405
+
+)clear all
+
+--S 406 of 600
+t0:=(5+x+3*x^2+2*x^3)/(x^2*(2+x+5*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  -------------------------
+--R          6    5     4    3     2
+--R        2x  + x  + 5x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 406
+
+--S 407 of 600
+--r0:=1/28*(-35+9*%i*sqrt(7))/x+1/28*(-35-9*%i*sqrt(7))/x-_
+--   3/56*log(x)*(7-11*%i*sqrt(7))+3/112*log(4*%i+4*%i*x^2+x*(%i+sqrt(7)))*_
+--   (7-11*%i*sqrt(7))-3/56*log(x)*(7+11*%i*sqrt(7))+3/112*log(4*%i+_
+--   4*%i*x^2+x*(%i-sqrt(7)))*(7+11*%i*sqrt(7))+11/4*atanh((%i+8*%i*x-_
+--   sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*(9+5*%i*sqrt(7))/sqrt(14*(35-_
+--   %i*sqrt(7)))-11/4*atanh((%i+8*%i*x+sqrt(7))/sqrt(2*(35+%i*sqrt(7))))*_
+--   (9-5*%i*sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--E 407
+
+--S 408 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 408
+
+)clear all
+
+--S 409 of 600
+t0:=(5+x+3*x^2+2*x^3)/(x^3*(2+x+5*x^2+x^3+2*x^4))
+--R 
+--R
+--R              3     2
+--R            2x  + 3x  + x + 5
+--R   (1)  -------------------------
+--R          7    6     5    4     3
+--R        2x  + x  + 5x  + x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 409
+
+--S 410 of 600
+--r0:=1/56*(-35+9*%i*sqrt(7))/x^2-1/16*log(x)*(35-9*%i*sqrt(7))+_
+--   1/32*log(4*%i+4*%i*x^2+x*(%i-sqrt(7)))*(35-9*%i*sqrt(7))+_
+--   1/56*(-35-9*%i*sqrt(7))/x^2-1/16*log(x)*(35+9*%i*sqrt(7))+_
+--   1/32*log(4*%i+4*%i*x^2+x*(%i+sqrt(7)))*(35+9*%i*sqrt(7))+_
+--   3/56*(7-11*%i*sqrt(7))/x+3/56*(7+11*%i*sqrt(7))/x+_
+--   1/8*atanh((%i+8*%i*x-sqrt(7))/sqrt(2*(35-%i*sqrt(7))))*(355-73*%i*_
+--   sqrt(7))/sqrt(14*(35-%i*sqrt(7)))-1/8*atanh((%i+8*%i*x+sqrt(7))/_
+--   sqrt(2*(35+%i*sqrt(7))))*(355+73*%i*sqrt(7))/sqrt(14*(35+%i*sqrt(7)))
+--E 410
+
+--S 411 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 411
+
+)clear all
+
+--S 412 of 600
+t0:=1/(4*x^(3/2)+sqrt(x))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R                 +-+
+--R        (4x + 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 600
+r0:=atan(2*sqrt(x))
+--R 
+--R
+--R               +-+
+--R   (2)  atan(2\|x )
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 600
+t0:=1/(-x^(5/2)+sqrt(x))
+--R 
+--R
+--R                1
+--R   (1)  - ------------
+--R            2      +-+
+--R          (x  - 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 600
+r0:=atan(sqrt(x))+atanh(sqrt(x))
+--R 
+--R
+--R               +-+          +-+
+--R   (2)  atanh(\|x ) + atan(\|x )
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 600
+t0:=1/(-x^(1/4)+sqrt(x))
+--R 
+--R
+--R               1
+--R   (1)  - -----------
+--R          4+-+    +-+
+--R          \|x  - \|x
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 600
+r0:=4*x^(1/4)+4*log(1-x^(1/4))+2*sqrt(x)
+--R 
+--R
+--R               4+-+         4+-+     +-+
+--R   (2)  4log(- \|x  + 1) + 4\|x  + 2\|x
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 600
+t0:=1/(x^(1/3)+sqrt(x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R        3+-+    +-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 600
+r0:=6*x^(1/6)-3*x^(1/3)-6*log(1+x^(1/6))+2*sqrt(x)
+--R 
+--R
+--R               6+-+         6+-+    3+-+     +-+
+--R   (2)  - 6log(\|x  + 1) + 6\|x  - 3\|x  + 2\|x
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 600
+t0:=1/(x^(1/4)+sqrt(x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R        4+-+    +-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 600
+r0:=-4*x^(1/4)+4*log(1+x^(1/4))+2*sqrt(x)
+--R 
+--R
+--R             4+-+         4+-+     +-+
+--R   (2)  4log(\|x  + 1) - 4\|x  + 2\|x
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 600
+t0:=1/(-x^(1/3)+x^(2/3))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R        3+-+2   3+-+
+--R        \|x   - \|x
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 600
+r0:=3*x^(1/3)+3*log(1-x^(1/3))
+--R 
+--R
+--R               3+-+         3+-+
+--R   (2)  3log(- \|x  + 1) + 3\|x
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 600
+t0:=1/(1/x^(1/4)+sqrt(x))
+--R 
+--R
+--R            4+-+
+--R            \|x
+--R   (1)  ------------
+--R         +-+4+-+
+--R        \|x \|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 600
+r0:=4/3*log(1+x^(1/4))-2/3*log(1-x^(1/4)+sqrt(x))+_
+   4*atan((1-2*x^(1/4))/sqrt(3))/sqrt(3)+2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R                                                                  4+-+
+--R         +-+    4+-+          +-+      4+-+    +-+               2\|x  - 1
+--R       4\|3 log(\|x  + 1) - 2\|3 log(- \|x  + \|x  + 1) - 12atan(---------)
+--R                                                                     +-+
+--R                                                                    \|3
+--R     + 
+--R         +-+ +-+
+--R       6\|3 \|x
+--R  /
+--R       +-+
+--R     3\|3
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 600
+t0:=1/(x^(1/4)+x^(1/3))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R        4+-+   3+-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 600
+r0:=-12*x^(1/12)+6*x^(1/6)-4*x^(1/4)+3*x^(1/3)-12/5*x^(5/12)-_
+   12/7*x^(7/12)+3/2*x^(2/3)+12*log(1+x^(1/12))+2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R              12+-+           12+-+7      12+-+5      12+-+      6+-+      4+-+
+--R       840log( \|x  + 1) - 120 \|x   - 168 \|x   - 840 \|x  + 420\|x  - 280\|x
+--R     + 
+--R          3+-+2      3+-+       +-+
+--R       105\|x   + 210\|x  + 140\|x
+--R  /
+--R     70
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 600
+t0:=1/(1/x^(1/3)+1/x^(1/4))
+--R 
+--R
+--R          3+-+4+-+
+--R          \|x \|x
+--R   (1)  -----------
+--R        4+-+   3+-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 600
+r0:=12*x^(1/12)-6*x^(1/6)+4*x^(1/4)-3*x^(1/3)+12/5*x^(5/12)+12/7*x^(7/12)-_
+   3/2*x^(2/3)+4/3*x^(3/4)-6/5*x^(5/6)+12/11*x^(11/12)-x+_
+   12/13*x^(13/12)-6/7*x^(7/6)+4/5*x^(5/4)-12*log(1+x^(1/12))-2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R                   12+-+             12+-+11        12+-+7        12+-+5
+--R       - 360360log( \|x  + 1) + 32760 \|x    + 51480 \|x   + 72072 \|x
+--R     + 
+--R                        12+-+        6+-+5                      6+-+
+--R       (27720x + 360360) \|x  - 36036\|x   + (- 25740x - 180180)\|x
+--R     + 
+--R            4+-+3                    4+-+        3+-+2        3+-+         +-+
+--R       40040\|x   + (24024x + 120120)\|x  - 45045\|x   - 90090\|x  - 60060\|x
+--R     + 
+--R       - 30030x
+--R  /
+--R     30030
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 600
+t0:=1/((-1)/x^(1/3)+sqrt(x))
+--R 
+--R
+--R            3+-+
+--R            \|x
+--R   (1)  ------------
+--R         +-+3+-+
+--R        \|x \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 600
+r0:=6/5*log(1-x^(1/6))-3/10*log(2+2*x^(1/3)+x^(1/6)*(1+sqrt(5)))*_
+   (1-sqrt(5))-3/10*log(2+2*x^(1/3)+x^(1/6)*(1-sqrt(5)))*(1+sqrt(5))+_
+   2*sqrt(x)+6*atan((1+4*x^(1/6)-sqrt(5))/sqrt(2*(5+sqrt(5))))*_
+   sqrt(2/5/(5+sqrt(5)))-3/5*atan(1/2*(1+4*x^(1/6)+sqrt(5))*_
+   sqrt(1/10*(5+sqrt(5))))*sqrt(2*(5+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R          +-+ +-+     +-+       +-+     6+-+    3+-+
+--R       (3\|2 \|5  - 3\|2 )log((\|5  + 1)\|x  + 2\|x  + 2)
+--R     + 
+--R          +-+      6+-+
+--R       12\|2 log(- \|x  + 1)
+--R     + 
+--R            +-+ +-+     +-+         +-+     6+-+    3+-+
+--R       (- 3\|2 \|5  - 3\|2 )log((- \|5  + 1)\|x  + 2\|x  + 2)
+--R     + 
+--R                                                   +--------+
+--R               +----------+       6+-+    +-+      | +-+
+--R           +-+ |  +-+           (4\|x  + \|5  + 1)\|\|5  + 5
+--R       - 6\|2 \|2\|5  + 10 atan(-----------------------------)
+--R                                              +--+
+--R                                            2\|10
+--R     + 
+--R          +----------+      6+-+    +-+
+--R          |   +-+          4\|x  - \|5  + 1       +-+ +-+
+--R       12\|- \|5  + 5 atan(----------------) + 20\|2 \|x
+--R                              +----------+
+--R                              |  +-+
+--R                             \|2\|5  + 10
+--R  /
+--R        +-+
+--R     10\|2
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                  +--+6+-+5     +--+6+-+3       +-+           +--+6+-+2
+--R               2x\|10 \|x   + 2\|10 \|x   + (- \|5  - 4x + 1)\|10 \|x
+--R             + 
+--R                   +-+     2           +--+6+-+       2 +-+    2       +--+
+--R               (2x\|5  + 2x  - 2x + 2)\|10 \|x  + (- x \|5  + x  - 4x)\|10
+--R          *
+--R              +--------+
+--R              | +-+
+--R             \|\|5  + 5
+--R         + 
+--R                                  +----------+
+--R                +-+ +-+      +-+  |   +-+     6+-+5
+--R           (- x\|2 \|5  - 5x\|2 )\|- \|5  + 5 \|x
+--R         + 
+--R                                +----------+
+--R               +-+ +-+     +-+  |   +-+     6+-+3
+--R           (- \|2 \|5  - 5\|2 )\|- \|5  + 5 \|x
+--R         + 
+--R                                              +----------+
+--R                     +-+ +-+             +-+  |   +-+     6+-+2
+--R           ((2x - 3)\|2 \|5  + (10x - 5)\|2 )\|- \|5  + 5 \|x
+--R         + 
+--R                                                             +----------+
+--R                2           +-+ +-+        2            +-+  |   +-+     6+-+
+--R           ((- x  + 6x - 1)\|2 \|5  + (- 5x  + 10x - 5)\|2 )\|- \|5  + 5 \|x
+--R         + 
+--R                                                      +----------+
+--R                 2       +-+ +-+        2        +-+  |   +-+
+--R           ((- 3x  + 2x)\|2 \|5  + (- 5x  + 10x)\|2 )\|- \|5  + 5
+--R      *
+--R          +----------+
+--R          |  +-+
+--R         \|2\|5  + 10
+--R     + 
+--R           +-+       6+-+2          +-+        6+-+      2 +-+       2
+--R       (20\|5  + 100)\|x   + (- 40x\|5  - 200x)\|x  + 20x \|5  + 100x
+--R  /
+--R            2        +-+       2        6+-+5
+--R       ((40x  - 80x)\|5  + 200x  - 400x)\|x
+--R     + 
+--R            2        +-+       2        6+-+4
+--R       ((40x  + 40x)\|5  + 200x  + 200x)\|x
+--R     + 
+--R              2        +-+       2        6+-+3
+--R       ((- 80x  + 40x)\|5  - 400x  + 200x)\|x
+--R     + 
+--R            3      2        +-+       3       2        6+-+2
+--R       ((40x  - 80x  + 40x)\|5  + 200x  - 400x  + 200x)\|x
+--R     + 
+--R            3      2        +-+       3       2        6+-+
+--R       ((40x  - 80x  + 40x)\|5  + 200x  - 400x  + 200x)\|x
+--R     + 
+--R           3      2        +-+       3       2
+--R       (40x  - 80x  + 40x)\|5  + 200x  - 400x  + 200x
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 600
+t0:=sqrt(x)/(x+x^2)
+--R 
+--R
+--R          +-+
+--R         \|x
+--R   (1)  ------
+--R         2
+--R        x  + x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 600
+r0:=2*atan(sqrt(x))
+--R 
+--R
+--R               +-+
+--R   (2)  2atan(\|x )
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 444
+
+)clear all
+
+--S 445 of 600
+t0:=x/(x+4*sqrt(x))
+--R 
+--R
+--R            x
+--R   (1)  ---------
+--R          +-+
+--R        4\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 600
+r0:=x+32*log(4+sqrt(x))-8*sqrt(x)
+--R 
+--R
+--R               +-+          +-+
+--R   (2)  32log(\|x  + 4) - 8\|x  + x
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 600
+t0:=sqrt(x)/(x^(1/3)+x)
+--R 
+--R
+--R           +-+
+--R          \|x
+--R   (1)  --------
+--R        3+-+
+--R        \|x  + x
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 600
+r0:=3*atan(1-x^(1/6)*sqrt(2))/sqrt(2)-3*atan(1+x^(1/6)*sqrt(2))/sqrt(2)-_
+   3/2*log(1+x^(1/3)-x^(1/6)*sqrt(2))/sqrt(2)+3/2*log(1+x^(1/3)+_
+   x^(1/6)*sqrt(2))/sqrt(2)+2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R             +-+6+-+   3+-+                +-+6+-+   3+-+
+--R       3log(\|2 \|x  + \|x  + 1) - 3log(- \|2 \|x  + \|x  + 1)
+--R     + 
+--R                +-+6+-+               +-+6+-+          +-+ +-+
+--R       - 6atan(\|2 \|x  + 1) - 6atan(\|2 \|x  - 1) + 4\|2 \|x
+--R  /
+--R       +-+
+--R     2\|2
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 600
+t0:=x^(1/3)/(x^(1/4)+sqrt(x))
+--R 
+--R
+--R            3+-+
+--R            \|x
+--R   (1)  -----------
+--R        4+-+    +-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 600
+r0:=-12*x^(1/12)+3*x^(1/3)-12/7*x^(7/12)+6/5*x^(5/6)+4*log(1+x^(1/12))-_
+   2*log(1-x^(1/12)+x^(1/6))-4*atan((1-2*x^(1/12))/sqrt(3))*sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                    12+-+
+--R              12+-+                12+-+   6+-+            +-+     2 \|x  - 1
+--R       140log( \|x  + 1) - 70log(-  \|x  + \|x  + 1) + 140\|3 atan(----------)
+--R                                                                       +-+
+--R                                                                      \|3
+--R     + 
+--R           12+-+7      12+-+     6+-+5      3+-+
+--R       - 60 \|x   - 420 \|x  + 42\|x   + 105\|x
+--R  /
+--R     35
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 600
+t0:=sqrt(x)/(x^(1/4)+x^(1/3))
+--R 
+--R
+--R             +-+
+--R            \|x
+--R   (1)  -----------
+--R        4+-+   3+-+
+--R        \|x  + \|x
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 600
+r0:=-12*x^(1/12)+6*x^(1/6)-4*x^(1/4)+3*x^(1/3)-12/5*x^(5/12)-12/7*x^(7/12)+_
+   3/2*x^(2/3)-4/3*x^(3/4)+6/5*x^(5/6)-12/11*x^(11/12)+x-_
+   12/13*x^(13/12)+6/7*x^(7/6)+12*log(1+x^(1/12))+2*sqrt(x)
+--R 
+--R
+--R   (2)
+--R                 12+-+             12+-+11        12+-+7        12+-+5
+--R       360360log( \|x  + 1) - 32760 \|x    - 51480 \|x   - 72072 \|x
+--R     + 
+--R                          12+-+        6+-+5                    6+-+
+--R       (- 27720x - 360360) \|x  + 36036\|x   + (25740x + 180180)\|x
+--R     + 
+--R              4+-+3         4+-+        3+-+2        3+-+         +-+
+--R       - 40040\|x   - 120120\|x  + 45045\|x   + 90090\|x  + 60060\|x  + 30030x
+--R  /
+--R     30030
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 600
+t0:=sqrt(x)/((-1)/x^(1/3)+sqrt(x))
+--R 
+--R
+--R           +-+3+-+
+--R          \|x \|x
+--R   (1)  ------------
+--R         +-+3+-+
+--R        \|x \|x  - 1
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 600
+r0:=6*x^(1/6)+x+6/5*log(1-x^(1/6))-3/10*log(2+2*x^(1/3)+x^(1/6)*_
+   (1-sqrt(5)))*(1-sqrt(5))-3/10*log(2+2*x^(1/3)+x^(1/6)*(1+sqrt(5)))*_
+   (1+sqrt(5))-3/5*atan(1/2*(1+4*x^(1/6)+sqrt(5))*sqrt(1/10*_
+   (5+sqrt(5))))*sqrt(2*(5-sqrt(5)))-3/5*atan((1+4*x^(1/6)-sqrt(5))/_
+   sqrt(2*(5+sqrt(5))))*sqrt(2*(5+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R            +-+           +-+     6+-+    3+-+                6+-+
+--R       (- 3\|5  - 3)log((\|5  + 1)\|x  + 2\|x  + 2) + 12log(- \|x  + 1)
+--R     + 
+--R          +-+             +-+     6+-+    3+-+
+--R       (3\|5  - 3)log((- \|5  + 1)\|x  + 2\|x  + 2)
+--R     + 
+--R                                                 +--------+
+--R           +------------+       6+-+    +-+      | +-+
+--R           |    +-+           (4\|x  + \|5  + 1)\|\|5  + 5
+--R       - 6\|- 2\|5  + 10 atan(-----------------------------)
+--R                                            +--+
+--R                                          2\|10
+--R     + 
+--R           +----------+      6+-+    +-+
+--R           |  +-+           4\|x  - \|5  + 1      6+-+
+--R       - 6\|2\|5  + 10 atan(----------------) + 60\|x  + 10x
+--R                               +----------+
+--R                               |  +-+
+--R                              \|2\|5  + 10
+--R  /
+--R     10
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                    +------------+
+--R               +--+ |    +-+      6+-+5
+--R           - 2\|10 \|- 2\|5  + 10 \|x
+--R         + 
+--R                                +------------+
+--R             +-+           +--+ |    +-+      6+-+4
+--R           (\|5  + 4x - 1)\|10 \|- 2\|5  + 10 \|x
+--R         + 
+--R                                          +------------+
+--R                 +-+     2           +--+ |    +-+      6+-+3
+--R           (- 2x\|5  - 2x  + 2x - 2)\|10 \|- 2\|5  + 10 \|x
+--R         + 
+--R                                   +------------+
+--R             2 +-+    2       +--+ |    +-+      6+-+2
+--R           (x \|5  - x  + 4x)\|10 \|- 2\|5  + 10 \|x
+--R         + 
+--R                      +------------+
+--R               2 +--+ |    +-+      6+-+
+--R           - 2x \|10 \|- 2\|5  + 10 \|x
+--R      *
+--R          +--------+
+--R          | +-+
+--R         \|\|5  + 5
+--R     + 
+--R         6+-+5         +-+            6+-+4        +-+      2            6+-+3
+--R       40\|x   + (- 20\|5  - 80x + 20)\|x   + (40x\|5  + 40x  - 40x + 40)\|x
+--R     + 
+--R             2 +-+      2       6+-+2      2 6+-+
+--R       (- 20x \|5  + 20x  - 80x)\|x   + 40x  \|x
+--R  /
+--R            2        +-+       2        6+-+5
+--R       ((80x  - 40x)\|5  + 400x  - 200x)\|x
+--R     + 
+--R              3      2        +-+       3       2        6+-+4
+--R       ((- 40x  + 80x  - 40x)\|5  - 200x  + 400x  - 200x)\|x
+--R     + 
+--R              3      2        +-+       3       2        6+-+3
+--R       ((- 40x  + 80x  - 40x)\|5  - 200x  + 400x  - 200x)\|x
+--R     + 
+--R              3      2        +-+       3       2        6+-+2
+--R       ((- 40x  + 80x  - 40x)\|5  - 200x  + 400x  - 200x)\|x
+--R     + 
+--R              3      2  +-+       3       2 6+-+         3      2  +-+       3
+--R       ((- 40x  + 80x )\|5  - 200x  + 400x )\|x  + (- 40x  - 40x )\|5  - 200x
+--R     + 
+--R             2
+--R       - 200x
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 600
+t0:=(-x+x^3)/(6+2*x)
+--R 
+--R
+--R         3
+--R        x  - x
+--R   (1)  ------
+--R        2x + 6
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 460
+
+--S 461 of 600
+r0:=4*x-3/4*x^2+1/6*x^3-12*log(3+x)
+--R 
+--R
+--R                            3     2
+--R        - 144log(x + 3) + 2x  - 9x  + 48x
+--R   (2)  ---------------------------------
+--R                        12
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 600
+t0:=(x+x^3)/(-1+x)
+--R 
+--R
+--R         3
+--R        x  + x
+--R   (1)  ------
+--R         x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 463
+
+--S 464 of 600
+r0:=2*x+1/2*x^2+1/3*x^3+2*log(1-x)
+--R 
+--R
+--R                           3     2
+--R        12log(- x + 1) + 2x  + 3x  + 12x
+--R   (2)  --------------------------------
+--R                        6
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 600
+t0:=(-x+4*x^3)/(5+x^2)^2
+--R 
+--R
+--R              3
+--R            4x  - x
+--R   (1)  --------------
+--R         4      2
+--R        x  + 10x  + 25
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 466
+
+--S 467 of 600
+r0:=21/2/(5+x^2)+2*log(5+x^2)
+--R 
+--R
+--R           2           2
+--R        (4x  + 20)log(x  + 5) + 21
+--R   (2)  --------------------------
+--R                   2
+--R                 2x  + 10
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 600
+t0:=(-x^2+2*x^4)/(1+2*x^2)
+--R 
+--R
+--R          4    2
+--R        2x  - x
+--R   (1)  --------
+--R           2
+--R         2x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 469
+
+--S 470 of 600
+r0:=-x+1/3*x^3+atan(x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R                +-+      3       +-+
+--R        3atan(x\|2 ) + (x  - 3x)\|2
+--R   (2)  ----------------------------
+--R                      +-+
+--R                    3\|2
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 600
+t0:=(x^3+x^4)/(1+x^2)
+--R 
+--R
+--R         4    3
+--R        x  + x
+--R   (1)  -------
+--R          2
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 472
+
+--S 473 of 600
+r0:=-x+1/2*x^2+1/3*x^3+atan(x)-1/2*log(1+x^2)
+--R 
+--R
+--R                2                     3     2
+--R        - 3log(x  + 1) + 6atan(x) + 2x  + 3x  - 6x
+--R   (2)  ------------------------------------------
+--R                             6
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 600
+t0:=(-2+4*x)/(-x+x^3)
+--R 
+--R
+--R        4x - 2
+--R   (1)  ------
+--R         3
+--R        x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 475
+
+--S 476 of 600
+r0:=log(1-x)+2*log(x)-3*log(1+x)
+--R 
+--R
+--R   (2)  - 3log(x + 1) + 2log(x) + log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 600
+t0:=(4+x)/(4*x+x^3)
+--R 
+--R
+--R         x + 4
+--R   (1)  -------
+--R         3
+--R        x  + 4x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 478
+
+--S 479 of 600
+r0:=1/2*atan(1/2*x)+log(x)-1/2*log(4+x^2)
+--R 
+--R
+--R               2                       x
+--R        - log(x  + 4) + 2log(x) + atan(-)
+--R                                       2
+--R   (2)  ---------------------------------
+--R                        2
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 600
+t0:=(-x+2*x^3)/(1-x^2+x^4)
+--R 
+--R
+--R            3
+--R          2x  - x
+--R   (1)  -----------
+--R         4    2
+--R        x  - x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 481
+
+--S 482 of 600
+r0:=1/2*log(1-x^2+x^4)
+--R 
+--R
+--R             4    2
+--R        log(x  - x  + 1)
+--R   (2)  ----------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+)clear all
+
+--S 484 of 600
+t0:=(-3+x)/(2*x+3*x^2+x^3)
+--R 
+--R
+--R            x - 3
+--R   (1)  -------------
+--R         3     2
+--R        x  + 3x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 484
+
+--S 485 of 600
+r0:=-3/2*log(x)+4*log(1+x)-5/2*log(2+x)
+--R 
+--R
+--R        - 5log(x + 2) + 8log(x + 1) - 3log(x)
+--R   (2)  -------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 600
+t0:=(2+4*x)/(x^2+2*x^3+x^4)
+--R 
+--R
+--R            4x + 2
+--R   (1)  -------------
+--R         4     3    2
+--R        x  + 2x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 487
+
+--S 488 of 600
+r0:=(-2)/(x*(1+x))
+--R 
+--R
+--R             2
+--R   (2)  - ------
+--R           2
+--R          x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 488
+
+--S 489 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 600
+t0:=(1+x)/(-6*x+x^2+x^3)
+--R 
+--R
+--R            x + 1
+--R   (1)  ------------
+--R         3    2
+--R        x  + x  - 6x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 490
+
+--S 491 of 600
+r0:=3/10*log(2-x)-1/6*log(x)-2/15*log(3+x)
+--R 
+--R
+--R        - 4log(x + 3) - 5log(x) + 9log(- x + 2)
+--R   (2)  ---------------------------------------
+--R                           30
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 600
+t0:=(4*x^2+x^3)/(x+x^3)
+--R 
+--R
+--R         2
+--R        x  + 4x
+--R   (1)  -------
+--R          2
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 493
+
+--S 494 of 600
+r0:=x-atan(x)+2*log(1+x^2)
+--R 
+--R
+--R              2
+--R   (2)  2log(x  + 1) - atan(x) + x
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 600
+t0:=(x+2*x^3)/(x^2+x^4)^3
+--R 
+--R
+--R                 2
+--R               2x  + 1
+--R   (1)  --------------------
+--R         11     9     7    5
+--R        x   + 3x  + 3x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 496
+
+--S 497 of 600
+r0:=(-1/4)/(x^4*(1+x^2)^2)
+--R 
+--R
+--R                1
+--R                -
+--R                4
+--R   (2)  - -------------
+--R           8     6    4
+--R          x  + 2x  + x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 497
+
+--S 498 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 600
+t0:=(a*x^2+b*x^3)/(c*x^2+d*x^3)
+--R 
+--R
+--R        b x + a
+--R   (1)  -------
+--R        d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 499
+
+--S 500 of 600
+r0:=b*x/d-(b*c-a*d)*log(c+d*x)/d^2
+--R 
+--R
+--R        (a d - b c)log(d x + c) + b d x
+--R   (2)  -------------------------------
+--R                        2
+--R                       d
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 600
+t0:=(x+x^2)/(-2*x-x^2+x^3)
+--R 
+--R
+--R          1
+--R   (1)  -----
+--R        x - 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 502
+
+--S 503 of 600
+r0:=log(2-x)
+--R 
+--R
+--R   (2)  log(- x + 2)
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 600
+t0:=x^3/(c+(a+b*x)^2)
+--R 
+--R
+--R                   3
+--R                  x
+--R   (1)  ----------------------
+--R         2 2                 2
+--R        b x  + 2a b x + c + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 505
+
+--S 506 of 600
+r0:=-3*a*x/b^3+1/2*(a+b*x)^2/b^4+1/2*(3*a^2-c)*log(c+(a+b*x)^2)/b^4-_
+   a*(a^2-3*c)*atan((a+b*x)/sqrt(c))/(b^4*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                 3      b x + a
+--R       (6a c - 2a )atan(-------)
+--R                           +-+
+--R                          \|c
+--R     + 
+--R                 2      2 2                 2     2 2             2  +-+
+--R       ((- c + 3a )log(b x  + 2a b x + c + a ) + b x  - 4a b x + a )\|c
+--R  /
+--R       4 +-+
+--R     2b \|c
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 600
+t0:=x^2/(c+(a+b*x)^2)
+--R 
+--R
+--R                   2
+--R                  x
+--R   (1)  ----------------------
+--R         2 2                 2
+--R        b x  + 2a b x + c + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 508
+
+--S 509 of 600
+r0:=x/b^2-a*log(c+(a+b*x)^2)/b^3+(a^2-c)*atan((a+b*x)/sqrt(c))/(b^3*sqrt(c))
+--R 
+--R
+--R                2      b x + a              2 2                 2         +-+
+--R        (- c + a )atan(-------) + (- a log(b x  + 2a b x + c + a ) + b x)\|c
+--R                          +-+
+--R                         \|c
+--R   (2)  ---------------------------------------------------------------------
+--R                                         3 +-+
+--R                                        b \|c
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 600
+t0:=x/(c+(a+b*x)^2)
+--R 
+--R
+--R                   x
+--R   (1)  ----------------------
+--R         2 2                 2
+--R        b x  + 2a b x + c + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 511
+
+--S 512 of 600
+r0:=1/2*log(c+(a+b*x)^2)/b^2-a*atan((a+b*x)/sqrt(c))/(b^2*sqrt(c))
+--R 
+--R
+--R                  b x + a         2 2                 2  +-+
+--R        - 2a atan(-------) + log(b x  + 2a b x + c + a )\|c
+--R                     +-+
+--R                    \|c
+--R   (2)  ----------------------------------------------------
+--R                                 2 +-+
+--R                               2b \|c
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 513
+
+)clear all
+
+--S 514 of 600
+t0:=1/(c+(a+b*x)^2)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         2 2                 2
+--R        b x  + 2a b x + c + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 514
+
+--S 515 of 600
+r0:=atan((a+b*x)/sqrt(c))/(b*sqrt(c))
+--R 
+--R
+--R             b x + a
+--R        atan(-------)
+--R                +-+
+--R               \|c
+--R   (2)  -------------
+--R              +-+
+--R            b\|c
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 600
+t0:=1/(x*(c+(a+b*x)^2))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R         2 3         2         2
+--R        b x  + 2a b x  + (c + a )x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 517
+
+--S 518 of 600
+r0:=log(x)/(a^2+c)-1/2*log(c+(a+b*x)^2)/(a^2+c)-a*atan((a+b*x)/sqrt(c))/_
+   ((a^2+c)*sqrt(c))
+--R 
+--R
+--R                  b x + a            2 2                 2             +-+
+--R        - 2a atan(-------) + (- log(b x  + 2a b x + c + a ) + 2log(x))\|c
+--R                     +-+
+--R                    \|c
+--R   (2)  ------------------------------------------------------------------
+--R                                          2  +-+
+--R                                  (2c + 2a )\|c
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 519
+
+)clear all
+
+--S 520 of 600
+t0:=1/(x^2*(c+(a+b*x)^2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R         2 4         3         2  2
+--R        b x  + 2a b x  + (c + a )x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 520
+
+--S 521 of 600
+r0:=(-1)/((a^2+c)*x)-2*a*b*log(x)/(a^2+c)^2+a*b*log(c+(a+b*x)^2)/(a^2+c)^2+_
+   b*(a^2-c)*atan((a+b*x)/sqrt(c))/((a^2+c)^2*sqrt(c))
+--R 
+--R
+--R   (2)
+--R                 2         b x + a
+--R       (- b c + a b)x atan(-------)
+--R                              +-+
+--R                             \|c
+--R     + 
+--R                   2 2                 2                         2  +-+
+--R       (a b x log(b x  + 2a b x + c + a ) - 2a b x log(x) - c - a )\|c
+--R  /
+--R       2     2     4   +-+
+--R     (c  + 2a c + a )x\|c
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 600
+t0:=1/(x^3*(c+(a+b*x)^2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R         2 5         4         2  3
+--R        b x  + 2a b x  + (c + a )x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 523
+
+--S 524 of 600
+r0:=(-1/2)/((a^2+c)*x^2)+2*a*b/((a^2+c)^2*x)+b^2*(3*a^2-c)*log(x)/(a^2+c)^3-_
+   1/2*b^2*(3*a^2-c)*log(c+(a+b*x)^2)/(a^2+c)^3-a*b^2*(a^2-3*c)*_
+   atan((a+b*x)/sqrt(c))/((a^2+c)^3*sqrt(c))
+--R 
+--R
+--R   (2)
+--R            2      3 2  2     b x + a
+--R       (6a b c - 2a b )x atan(-------)
+--R                                 +-+
+--R                                \|c
+--R     + 
+--R             2      2 2  2     2 2                 2         2      2 2  2
+--R           (b c - 3a b )x log(b x  + 2a b x + c + a ) + (- 2b c + 6a b )x log(x)
+--R         + 
+--R                       3       2     2     4
+--R           (4a b c + 4a b)x - c  - 2a c - a
+--R      *
+--R          +-+
+--R         \|c
+--R  /
+--R        3     2 2     4      6  2 +-+
+--R     (2c  + 6a c  + 6a c + 2a )x \|c
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 600
+t0:=1/(a+b*(c+d*x)^2)
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R           2 2                 2
+--R        b d x  + 2b c d x + b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 526
+
+--S 527 of 600
+r0:=atan((c+d*x)*sqrt(b)/sqrt(a))/(d*sqrt(a)*sqrt(b))
+--R 
+--R
+--R                       +-+
+--R             (d x + c)\|b
+--R        atan(-------------)
+--R                   +-+
+--R                  \|a
+--R   (2)  -------------------
+--R               +-+ +-+
+--R             d\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 600
+t0:=1/(a+b*(c+d*x)^2)^2
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        2 4 4     2   3 3      2 2         2 2      2 3                 2 4
+--R       b d x  + 4b c d x  + (6b c  + 2a b)d x  + (4b c  + 4a b c)d x + b c
+--R     + 
+--R             2    2
+--R       2a b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 529
+
+--S 530 of 600
+r0:=1/2*(c+d*x)/(a*d*(a+b*(c+d*x)^2))+1/2*atan((c+d*x)*sqrt(b)/sqrt(a))/_
+   (a^(3/2)*d*sqrt(b))
+--R 
+--R
+--R                                                     +-+
+--R            2 2                 2          (d x + c)\|b               +-+ +-+
+--R        (b d x  + 2b c d x + b c  + a)atan(-------------) + (d x + c)\|a \|b
+--R                                                 +-+
+--R                                                \|a
+--R   (2)  ---------------------------------------------------------------------
+--R                        3 2           2           2     2    +-+ +-+
+--R                 (2a b d x  + 4a b c d x + (2a b c  + 2a )d)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 531
+
+)clear all
+
+--S 532 of 600
+t0:=1/(a+b*(c+d*x)^2)^3
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        3 6 6     3   5 5       3 2       2  4 4       3 3        2   3 3
+--R       b d x  + 6b c d x  + (15b c  + 3a b )d x  + (20b c  + 12a b c)d x
+--R     + 
+--R           3 4        2 2     2   2 2      3 5        2 3     2           3 6
+--R       (15b c  + 18a b c  + 3a b)d x  + (6b c  + 12a b c  + 6a b c)d x + b c
+--R     + 
+--R           2 4     2   2    3
+--R       3a b c  + 3a b c  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 532
+
+--S 533 of 600
+r0:=1/4*(c+d*x)/(a*d*(a+b*(c+d*x)^2)^2)+3/8*(c+d*x)/(a^2*d*(a+b*(c+d*x)^2))+_
+   3/8*atan((c+d*x)*sqrt(b)/sqrt(a))/(a^(5/2)*d*sqrt(b))
+--R 
+--R
+--R   (2)
+--R             2 4 4      2   3 3       2 2         2 2       2 3
+--R           3b d x  + 12b c d x  + (18b c  + 6a b)d x  + (12b c  + 12a b c)d x
+--R         + 
+--R             2 4         2     2
+--R           3b c  + 6a b c  + 3a
+--R      *
+--R                        +-+
+--R              (d x + c)\|b
+--R         atan(-------------)
+--R                    +-+
+--R                   \|a
+--R     + 
+--R            3 3         2 2        2                3         +-+ +-+
+--R       (3b d x  + 9b c d x  + (9b c  + 5a)d x + 3b c  + 5a c)\|a \|b
+--R  /
+--R           2 2 5 4      2 2   4 3       2 2 2      3   3 2
+--R         8a b d x  + 32a b c d x  + (48a b c  + 16a b)d x
+--R       + 
+--R             2 2 3      3     2       2 2 4      3   2     4
+--R         (32a b c  + 32a b c)d x + (8a b c  + 16a b c  + 8a )d
+--R    *
+--R        +-+ +-+
+--R       \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 534
+
+)clear all
+
+--S 535 of 600
+t0:=1/(b*(c+d*x)^2+sqrt(-a))
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R         +---+      2 2                 2
+--R        \|- a  + b d x  + 2b c d x + b c
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 600
+r0:=atan((c+d*x)*sqrt(b)/(-a)^(1/4))/((-a)^(1/4)*d*sqrt(b))
+--R 
+--R
+--R                       +-+
+--R             (d x + c)\|b
+--R        atan(-------------)
+--R                 4+---+
+--R                 \|- a
+--R   (2)  -------------------
+--R             4+---+ +-+
+--R            d\|- a \|b
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 537
+
+)clear all
+
+--S 538 of 600
+t0:=1/(1+(c+d*x)^2)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         2 2             2
+--R        d x  + 2c d x + c  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 538
+
+--S 539 of 600
+r0:=atan(c+d*x)/d
+--R 
+--R
+--R        atan(d x + c)
+--R   (2)  -------------
+--R              d
+--R                                                    Type: Expression(Integer)
+--E 539
+
+--S 540 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 540
+
+)clear all
+
+--S 541 of 600
+t0:=1/(1+(c+d*x)^2)^2
+--R 
+--R
+--R                                      1
+--R   (1)  -------------------------------------------------------------
+--R         4 4       3 3      2      2 2      3             4     2
+--R        d x  + 4c d x  + (6c  + 2)d x  + (4c  + 4c)d x + c  + 2c  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 541
+
+--S 542 of 600
+r0:=1/2*(c+d*x)/(d*(1+(c+d*x)^2))+1/2*atan(c+d*x)/d
+--R 
+--R
+--R          2 2             2
+--R        (d x  + 2c d x + c  + 1)atan(d x + c) + d x + c
+--R   (2)  -----------------------------------------------
+--R                    3 2       2       2
+--R                  2d x  + 4c d x + (2c  + 2)d
+--R                                                    Type: Expression(Integer)
+--E 542
+
+--S 543 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 543
+
+)clear all
+
+--S 544 of 600
+t0:=1/(1+(c+d*x)^2)^3
+--R 
+--R
+--R   (1)
+--R     1
+--R  /
+--R        6 6       5 5       2      4 4       3        3 3
+--R       d x  + 6c d x  + (15c  + 3)d x  + (20c  + 12c)d x
+--R     + 
+--R           4      2      2 2      5      3             6     4     2
+--R       (15c  + 18c  + 3)d x  + (6c  + 12c  + 6c)d x + c  + 3c  + 3c  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 544
+
+--S 545 of 600
+r0:=1/4*(c+d*x)/(d*(1+(c+d*x)^2)^2)+3/8*(c+d*x)/(d*(1+(c+d*x)^2))+_
+   3/8*atan(c+d*x)/d
+--R 
+--R
+--R   (2)
+--R            4 4        3 3       2      2 2       3               4     2
+--R         (3d x  + 12c d x  + (18c  + 6)d x  + (12c  + 12c)d x + 3c  + 6c  + 3)
+--R      *
+--R         atan(d x + c)
+--R     + 
+--R         3 3       2 2      2             3
+--R       3d x  + 9c d x  + (9c  + 5)d x + 3c  + 5c
+--R  /
+--R       5 4        4 3       2       3 2       3        2       4      2
+--R     8d x  + 32c d x  + (48c  + 16)d x  + (32c  + 32c)d x + (8c  + 16c  + 8)d
+--R                                                    Type: Expression(Integer)
+--E 545
+
+--S 546 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 546
+
+)clear all
+
+--S 547 of 600
+t0:=1/(1-(c+d*x)^2)
+--R 
+--R
+--R                     1
+--R   (1)  - ----------------------
+--R           2 2             2
+--R          d x  + 2c d x + c  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 547
+
+--S 548 of 600
+r0:=atanh(c+d*x)/d
+--R 
+--R
+--R        atanh(d x + c)
+--R   (2)  --------------
+--R               d
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 549
+
+)clear all
+
+--S 550 of 600
+t0:=1/(1-(c+d*x)^2)^2
+--R 
+--R
+--R                                      1
+--R   (1)  -------------------------------------------------------------
+--R         4 4       3 3      2      2 2      3             4     2
+--R        d x  + 4c d x  + (6c  - 2)d x  + (4c  - 4c)d x + c  - 2c  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 550
+
+--S 551 of 600
+r0:=1/2*(c+d*x)/(d*(1-(c+d*x)^2))+1/2*atanh(c+d*x)/d
+--R 
+--R
+--R          2 2             2
+--R        (d x  + 2c d x + c  - 1)atanh(d x + c) - d x - c
+--R   (2)  ------------------------------------------------
+--R                     3 2       2       2
+--R                   2d x  + 4c d x + (2c  - 2)d
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 600
+t0:=1/(1-(c+d*x)^2)^3
+--R 
+--R
+--R   (1)
+--R   -
+--R        1
+--R     /
+--R           6 6       5 5       2      4 4       3        3 3
+--R          d x  + 6c d x  + (15c  - 3)d x  + (20c  - 12c)d x
+--R        + 
+--R              4      2      2 2      5      3             6     4     2
+--R          (15c  - 18c  + 3)d x  + (6c  - 12c  + 6c)d x + c  - 3c  + 3c  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 553
+
+--S 554 of 600
+r0:=1/4*(c+d*x)/(d*(1-(c+d*x)^2)^2)+3/8*(c+d*x)/(d*(1-(c+d*x)^2))+_
+   3/8*atanh(c+d*x)/d
+--R 
+--R
+--R   (2)
+--R            4 4        3 3       2      2 2       3               4     2
+--R         (3d x  + 12c d x  + (18c  - 6)d x  + (12c  - 12c)d x + 3c  - 6c  + 3)
+--R      *
+--R         atanh(d x + c)
+--R     + 
+--R           3 3       2 2        2             3
+--R       - 3d x  - 9c d x  + (- 9c  + 5)d x - 3c  + 5c
+--R  /
+--R       5 4        4 3       2       3 2       3        2       4      2
+--R     8d x  + 32c d x  + (48c  - 16)d x  + (32c  - 32c)d x + (8c  - 16c  + 8)d
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 600
+t0:=1/(1-(1+x)^2)
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R           2
+--R          x  + 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 556
+
+--S 557 of 600
+r0:=atanh(1+x)
+--R 
+--R
+--R   (2)  atanh(x + 1)
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 558
+
+)clear all
+
+--S 559 of 600
+t0:=1/(1-(1+x)^2)^2
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         4     3     2
+--R        x  + 4x  + 4x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 559
+
+--S 560 of 600
+r0:=1/2*(1+x)/(1-(1+x)^2)+1/2*atanh(1+x)
+--R 
+--R
+--R          2
+--R        (x  + 2x)atanh(x + 1) - x - 1
+--R   (2)  -----------------------------
+--R                     2
+--R                   2x  + 4x
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 600
+t0:=1/(1-(1+x)^2)^3
+--R 
+--R
+--R                    1
+--R   (1)  - ---------------------
+--R           6     5      4     3
+--R          x  + 6x  + 12x  + 8x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 562
+
+--S 563 of 600
+r0:=1/4*(1+x)/(1-(1+x)^2)^2+3/8*(1+x)/(1-(1+x)^2)+3/8*atanh(1+x)
+--R 
+--R
+--R           4      3      2                  3     2
+--R        (3x  + 12x  + 12x )atanh(x + 1) - 3x  - 9x  - 4x + 2
+--R   (2)  ----------------------------------------------------
+--R                            4      3      2
+--R                          8x  + 32x  + 32x
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 600
+t0:=(1+(a+b*x)^2)^2/x
+--R 
+--R
+--R         4 4       3 3      2      2 2      3             4     2
+--R        b x  + 4a b x  + (6a  + 2)b x  + (4a  + 4a)b x + a  + 2a  + 1
+--R   (1)  -------------------------------------------------------------
+--R                                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 565
+
+--S 566 of 600
+r0:=a*(2+a^2)*b*x+1/2*(2+a^2)*(a+b*x)^2+1/3*a*(a+b*x)^3+1/4*(a+b*x)^4+_
+   (1+a^2)^2*log(x)
+--R 
+--R
+--R   (2)
+--R           4      2                 4 4        3 3       2       2 2
+--R       (12a  + 24a  + 12)log(x) + 3b x  + 16a b x  + (36a  + 12)b x
+--R     + 
+--R           3                4      2
+--R       (48a  + 48a)b x + 13a  + 12a
+--R  /
+--R     12
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 567
+
+)clear all
+
+--S 568 of 600
+t0:=x^2/(1+(-1+x)^2)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  -----------
+--R         2
+--R        x  - 2x + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 568
+
+--S 569 of 600
+r0:=x+log(1+(-1+x)^2)
+--R 
+--R
+--R             2
+--R   (2)  log(x  - 2x + 2) + x
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 600
+t0:=x^2/sqrt(1-(1+x)^2)
+--R 
+--R
+--R              2
+--R             x
+--R   (1)  ------------
+--R         +---------+
+--R         |   2
+--R        \|- x  - 2x
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 600
+r0:=3/2*asin(1+x)+3/2*sqrt(1-(1+x)^2)-1/2*x*sqrt(1-(1+x)^2)
+--R 
+--R
+--R                  +---------+
+--R                  |   2
+--R        (- x + 3)\|- x  - 2x  + 3asin(x + 1)
+--R   (2)  ------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+)clear all
+
+--S 574 of 600
+t0:=x^2/sqrt(1-(a+b*x)^2)
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R         +------------------------+
+--R         |   2 2             2
+--R        \|- b x  - 2a b x - a  + 1
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 600
+r0:=1/2*(1+2*a^2)*asin(a+b*x)/b^3+3/2*a*sqrt(1-(a+b*x)^2)/b^3-_
+   1/2*x*sqrt(1-(a+b*x)^2)/b^2
+--R 
+--R
+--R                     +------------------------+
+--R                     |   2 2             2           2
+--R        (- b x + 3a)\|- b x  - 2a b x - a  + 1  + (2a  + 1)asin(b x + a)
+--R   (2)  ----------------------------------------------------------------
+--R                                         3
+--R                                       2b
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 600
+t0:=x^2/sqrt(1+(a+b*x)^2)
+--R 
+--R
+--R                     2
+--R                    x
+--R   (1)  -------------------------
+--R         +----------------------+
+--R         | 2 2             2
+--R        \|b x  + 2a b x + a  + 1
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 600
+r0:=-1/2*(1-2*a^2)*asinh(a+b*x)/b^3-3/2*a*sqrt(1+(a+b*x)^2)/b^3+_
+   1/2*x*sqrt(1+(a+b*x)^2)/b^2
+--R 
+--R
+--R                   +----------------------+
+--R                   | 2 2             2           2
+--R        (b x - 3a)\|b x  + 2a b x + a  + 1  + (2a  - 1)asinh(b x + a)
+--R   (2)  -------------------------------------------------------------
+--R                                       3
+--R                                     2b
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 579
+
+)clear all
+
+--S 580 of 600
+--t0:=f((a+b*x)/x)
+--E 580
+
+--S 581 of 600
+--r0:=Int(f(b+a/x),x)
+--E 581
+
+--S 582 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 582
+
+)clear all
+
+--S 583 of 600
+--t0:=f((a+b*x^2)/x^2)
+--E 583
+
+--S 584 of 600
+--r0:=Int(f(b+a/x^2),x)
+--E 584
+
+--S 585 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 585
+
+)clear all
+
+--S 586 of 600
+--t0:=f(x/(a+b*x))
+--E 586
+
+--S 587 of 600
+--r0:=Int(f(x/(a+b*x)),x)
+--E 587
+
+--S 588 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 588
+
+)clear all
+
+--S 589 of 600
+--t0:=f(x^2/(a+b*x^2))
+--E 589
+
+--S 590 of 600
+--r0:=Int(f(x^2/(a+b*x^2)),x)
+--E 590
+
+--S 591 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 591
+
+)clear all
+
+--S 592 of 600
+--t0:=f(x^2/(a+b*x)^2)
+--E 592
+
+--S 593 of 600
+--r0:=Int(f(x^2/(a+b*x)^2),x)
+--E 593
+
+--S 594 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 594
+
+)clear all
+
+--S 595 of 600
+--t0:=f(x^4/(a+b*x^2)^2)
+--E 595
+
+--S 596 of 600
+--r0:=Int(f(x^4/(a+b*x^2)^2),x)
+--E 596
+
+--S 597 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 597
+
+)clear all
+
+--S 598 of 600
+t0:=sqrt(x-sqrt(-4+x^2))
+--R 
+--R
+--R         +---------------+
+--R         |   +------+
+--R         |   | 2
+--R   (1)  \|- \|x  - 4  + x
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 600
+r0:=2/3*(2*x+sqrt(-4+x^2))*sqrt(x-sqrt(-4+x^2))
+--R 
+--R
+--R                          +---------------+
+--R           +------+       |   +------+
+--R           | 2            |   | 2
+--R        (2\|x  - 4  + 4x)\|- \|x  - 4  + x
+--R   (2)  -----------------------------------
+--R                         3
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 600
+
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder22d.input.pamphlet b/src/input/richder22d.input.pamphlet
new file mode 100644
index 0000000..987448b
--- /dev/null
+++ b/src/input/richder22d.input.pamphlet
@@ -0,0 +1,3234 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder22d.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Algebraic function problems.input
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder22d.output
+)spool richder22d.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 801
+t0:=sqrt(1+sqrt(1-x^2))
+--E 1
+
+--S 2 of 801
+r0:=2/3*(1+x^2-sqrt(1-x^2))*sqrt(1+sqrt(1-x^2))/x
+--E 2
+
+--S 3 of 801
+a0:=integrate(t0,x)
+--E 3
+
+--S 4 of 801
+m0:=a0-r0
+--E 4
+
+--S 5 of 801
+d0:=normalize(D(m0,x))
+--E 5
+
+--S 6 of 801
+t0:=sqrt(a*x+b*sqrt(c+a^2*x^2/b^2))
+--E 6
+
+--S 7 of 801
+r0:=2/3*(2*a*x-b*sqrt(c+a^2*x^2/b^2))*sqrt(a*x+b*sqrt(c+a^2*x^2/b^2))/a
+--E 7
+
+--S 8 of 801
+a0:=integrate(t0,x)
+--E 8
+
+--S 9 of 801
+m0:=a0-r0
+--E 9
+
+--S 10 of 801
+d0:=normalize(D(m0,x))
+--E 10
+
+--S 11 of 801
+t0:=sqrt(a+b*sqrt(a^2/b^2+c*x^2))
+--E 11
+
+--S 12 of 801
+r0:=-2/3*(a^2/b^2-c*x^2-a*sqrt(a^2/b^2+c*x^2)/b)*sqrt(a+b*sqrt(a^2/b^2+c*x^2))/(c*x)
+--E 12
+
+--S 13 of 801
+a0:=integrate(t0,x)
+--E 13
+
+--S 14 of 801
+m0:=a0-r0
+--E 14
+
+--S 15 of 801
+d0:=normalize(D(m0,x))
+--E 15
+
+--S 16 of 801
+t0:=sqrt(b*x^2+sqrt(a+b^2*x^4))/sqrt(a+b^2*x^4)
+--E 16
+
+--S 17 of 801
+r0:=atanh(x*sqrt(2)*sqrt(b)/sqrt(b*x^2+sqrt(a+b^2*x^4)))/(sqrt(2)*sqrt(b))
+--E 17
+
+--S 18 of 801
+a0:=integrate(t0,x)
+--E 18
+
+--S 19 of 801
+m0:=a0-r0
+--E 19
+
+--S 20 of 801
+d0:=normalize(D(m0,x))
+--E 20
+
+--S 21 of 801
+t0:=sqrt(-b*x^2+sqrt(a+b^2*x^4))/sqrt(a+b^2*x^4)
+--E 21
+
+--S 22 of 801
+r0:=atan(x*sqrt(2)*sqrt(b)/sqrt(-b*x^2+sqrt(a+b^2*x^4)))/(sqrt(2)*sqrt(b))
+--E 22
+
+--S 23 of 801
+a0:=integrate(t0,x)
+--E 23
+
+--S 24 of 801
+m0:=a0-r0
+--E 24
+
+--S 25 of 801
+d0:=normalize(D(m0,x))
+--E 25
+
+--S 26 of 801
+t0:=sqrt(2*x^2+sqrt(3+4*x^4))/((c+d*x)*sqrt(3+4*x^4))
+--E 26
+
+--S 27 of 801
+--r0:=(1/2-1/2*%i)*atan((2*%i*c*x+d*sqrt(3))/(sqrt(-2*%i*x^2+sqrt(3))*sqrt(2*%i*c^2-d^2*sqrt(3))))/sqrt(2*%i*c^2-d^2*sqrt(3))+(-1/2-1/2*%i)*atanh((-2*%i*c*x+d*sqrt(3))/(sqrt(2*%i*x^2+sqrt(3))*sqrt(2*%i*c^2+d^2*sqrt(3))))/sqrt(2*%i*c^2+d^2*sqrt(3))
+--E 27
+
+--S 28 of 801
+--a0:=integrate(t0,x)
+--E 28
+
+--S 29 of 801
+--m0:=a0-r0
+--E 29
+
+--S 30 of 801
+--d0:=normalize(D(m0,x))
+--E 30
+
+--S 31 of 801
+t0:=sqrt(2*x^2+sqrt(3+4*x^4))/((c+d*x)^2*sqrt(3+4*x^4))
+--E 31
+
+--S 32 of 801
+--r0:=(1+%i)*c*atan((2*%i*c*x+d*sqrt(3))/(sqrt(-2*%i*x^2+sqrt(3))*sqrt(2*%i*c^2-d^2*sqrt(3))))/(2*%i*c^2-d^2*sqrt(3))^(3/2)+(1-%i)*c*atanh((-2*%i*c*x+d*sqrt(3))/(sqrt(2*%i*x^2+sqrt(3))*sqrt(2*%i*c^2+d^2*sqrt(3))))/(2*%i*c^2+d^2*sqrt(3))^(3/2)+(1/2-1/2*%i)*d*sqrt(-2*%i*x^2+sqrt(3))/((c+d*x)*(2*%i*c^2-d^2*sqrt(3)))+(-1/2-1/2*%i)*d*sqrt(2*%i*x^2+sqrt(3))/((c+d*x)*(2*%i*c^2+d^2*sqrt(3)))
+--E 32
+
+--S 33 of 801
+--a0:=integrate(t0,x)
+--E 33
+
+--S 34 of 801
+--m0:=a0-r0
+--E 34
+
+--S 35 of 801
+--d0:=normalize(D(m0,x))
+--E 35
+
+--S 36 of 801
+t0:=sqrt(1+sqrt(1+x^2))
+--E 36
+
+--S 37 of 801
+r0:=-2/3*(1-x^2-sqrt(1+x^2))*sqrt(1+sqrt(1+x^2))/x
+--E 37
+
+--S 38 of 801
+a0:=integrate(t0,x)
+--E 38
+
+--S 39 of 801
+m0:=a0-r0
+--E 39
+
+--S 40 of 801
+d0:=normalize(D(m0,x))
+--E 40
+
+--S 41 of 801
+t0:=sqrt(5+sqrt(25+x^2))
+--E 41
+
+--S 42 of 801
+r0:=-2/3*(25-x^2-5*sqrt(25+x^2))*sqrt(5+sqrt(25+x^2))/x
+--E 42
+
+--S 43 of 801
+a0:=integrate(t0,x)
+--E 43
+
+--S 44 of 801
+m0:=a0-r0
+--E 44
+
+--S 45 of 801
+d0:=normalize(D(m0,x))
+--E 45
+
+--S 46 of 801
+t0:=sqrt(1+sqrt(1-x^2))
+--E 46
+
+--S 47 of 801
+r0:=2/3*(1+x^2-sqrt(1-x^2))*sqrt(1+sqrt(1-x^2))/x
+--E 47
+
+--S 48 of 801
+a0:=integrate(t0,x)
+--E 48
+
+--S 49 of 801
+m0:=a0-r0
+--E 49
+
+--S 50 of 801
+d0:=normalize(D(m0,x))
+--E 50
+
+--S 51 of 801
+t0:=sqrt(x-sqrt(-4+x^2))
+--E 51
+
+--S 52 of 801
+r0:=2/3*(2*x+sqrt(-4+x^2))*sqrt(x-sqrt(-4+x^2))
+--E 52
+
+--S 53 of 801
+a0:=integrate(t0,x)
+--E 53
+
+--S 54 of 801
+m0:=a0-r0
+--E 54
+
+--S 55 of 801
+d0:=normalize(D(m0,x))
+--E 55
+
+--S 56 of 801
+t0:=(1-5*x^2)/(x^3*(1+x^2))
+--E 56
+
+--S 57 of 801
+r0:=(-1/2)/x^2+6*atanh(1+2*x^2)
+--E 57
+
+--S 58 of 801
+a0:=integrate(t0,x)
+--E 58
+
+--S 59 of 801
+m0:=a0-r0
+--E 59
+
+--S 60 of 801
+d0:=normalize(D(m0,x))
+--E 60
+
+--S 61 of 801
+t0:=2*x/((-1+x)*(5+x^2))
+--E 61
+
+--S 62 of 801
+r0:=1/3*log(1-x)-1/6*log(5+x^2)+1/3*atan(x/sqrt(5))*sqrt(5)
+--E 62
+
+--S 63 of 801
+a0:=integrate(t0,x)
+--E 63
+
+--S 64 of 801
+m0:=a0-r0
+--E 64
+
+--S 65 of 801
+d0:=normalize(D(m0,x))
+--E 65
+
+--S 66 of 801
+t0:=(2+x^2)/(2+x)
+--E 66
+
+--S 67 of 801
+r0:=-2*x+1/2*x^2+6*log(2+x)
+--E 67
+
+--S 68 of 801
+a0:=integrate(t0,x)
+--E 68
+
+--S 69 of 801
+m0:=a0-r0
+--E 69
+
+--S 70 of 801
+d0:=normalize(D(m0,x))
+--E 70
+
+--S 71 of 801
+t0:=1/((-3+x)*(4+x^2))
+--E 71
+
+--S 72 of 801
+r0:=-3/26*atan(1/2*x)+1/13*log(3-x)-1/26*log(4+x^2)
+--E 72
+
+--S 73 of 801
+a0:=integrate(t0,x)
+--E 73
+
+--S 74 of 801
+m0:=a0-r0
+--E 74
+
+--S 75 of 801
+d0:=normalize(D(m0,x))
+--E 75
+
+--S 76 of 801
+t0:=(-2+3*x^6)/(x*(5+2*x^6))
+--E 76
+
+--S 77 of 801
+r0:=-2/5*log(x)+19/60*log(5+2*x^6)
+--E 77
+
+--S 78 of 801
+a0:=integrate(t0,x)
+--E 78
+
+--S 79 of 801
+m0:=a0-r0
+--E 79
+
+--S 80 of 801
+d0:=normalize(D(m0,x))
+--E 80
+
+--S 81 of 801
+t0:=(3+2*x)/((-2+x)*(5+x))
+--E 81
+
+--S 82 of 801
+r0:=log(2-x)+log(5+x)
+--E 82
+
+--S 83 of 801
+a0:=integrate(t0,x)
+--E 83
+
+--S 84 of 801
+m0:=a0-r0
+--E 84
+
+--S 85 of 801
+d0:=normalize(D(m0,x))
+--E 85
+
+--S 86 of 801
+t0:=x^4/(4+5*x^2+x^4)
+--E 86
+
+--S 87 of 801
+r0:=x-8/3*atan(1/2*x)+1/3*atan(x)
+--E 87
+
+--S 88 of 801
+a0:=integrate(t0,x)
+--E 88
+
+--S 89 of 801
+m0:=a0-r0
+--E 89
+
+--S 90 of 801
+d0:=normalize(D(m0,x))
+--E 90
+
+--S 91 of 801
+t0:=1/((1+x)*(2+x)^2*(3+x)^3)
+--E 91
+
+--S 92 of 801
+r0:=1/(2+x)+1/4/(3+x)^2+5/4/(3+x)+1/8*log(1+x)+2*log(2+x)-17/8*log(3+x)
+--E 92
+
+--S 93 of 801
+a0:=integrate(t0,x)
+--E 93
+
+--S 94 of 801
+m0:=a0-r0
+--E 94
+
+--S 95 of 801
+d0:=normalize(D(m0,x))
+--E 95
+
+--S 96 of 801
+t0:=x/(-1+x^2)
+--E 96
+
+--S 97 of 801
+r0:=1/2*log(1-x^2)
+--E 97
+
+--S 98 of 801
+a0:=integrate(t0,x)
+--E 98
+
+--S 99 of 801
+m0:=a0-r0
+--E 99
+
+--S 100 of 801
+d0:=normalize(D(m0,x))
+--E 100
+
+--S 101 of 801
+t0:=1/(-1+x^2)^2
+--E 101
+
+--S 102 of 801
+r0:=1/2*x/(1-x^2)+1/2*atanh(x)
+--E 102
+
+--S 103 of 801
+a0:=integrate(t0,x)
+--E 103
+
+--S 104 of 801
+m0:=a0-r0
+--E 104
+
+--S 105 of 801
+d0:=normalize(D(m0,x))
+--E 105
+
+--S 106 of 801
+t0:=x^2/(1+x^2)^2
+--E 106
+
+--S 107 of 801
+r0:=-1/2*x/(1+x^2)+1/2*atan(x)
+--E 107
+
+--S 108 of 801
+a0:=integrate(t0,x)
+--E 108
+
+--S 109 of 801
+m0:=a0-r0
+--E 109
+
+--S 110 of 801
+d0:=normalize(D(m0,x))
+--E 110
+
+--S 111 of 801
+t0:=1/(2+3*x)
+--E 111
+
+--S 112 of 801
+r0:=1/3*log(2+3*x)
+--E 112
+
+--S 113 of 801
+a0:=integrate(t0,x)
+--E 113
+
+--S 114 of 801
+m0:=a0-r0
+--E 114
+
+--S 115 of 801
+d0:=normalize(D(m0,x))
+--E 115
+
+--S 116 of 801
+t0:=1/(a^2+x^2)
+--E 116
+
+--S 117 of 801
+r0:=atan(x/a)/a
+--E 117
+
+--S 118 of 801
+a0:=integrate(t0,x)
+--E 118
+
+--S 119 of 801
+m0:=a0-r0
+--E 119
+
+--S 120 of 801
+d0:=normalize(D(m0,x))
+--E 120
+
+--S 121 of 801
+t0:=1/(a+b*x^2)
+--E 121
+
+--S 122 of 801
+r0:=atan(x*sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b))
+--E 122
+
+--S 123 of 801
+a0:=integrate(t0,x)
+--E 123
+
+--S 124 of 801
+m0a:=a0.1-r0
+--E 124
+
+--S 125 of 801
+d0a:=normalize(D(m0a,x))
+--E 125
+
+--S 126 of 801
+m0b:=a0.2-r0
+--E 126
+
+--S 127 of 801
+d0b:=normalize(D(m0b,x))
+--E 127
+
+--S 128 of 801
+t0:=1/(2-x+x^2)
+--E 128
+
+--S 129 of 801
+r0:=-2*atan((1-2*x)/sqrt(7))/sqrt(7)
+--E 129
+
+--S 130 of 801
+a0:=integrate(t0,x)
+--E 130
+
+--S 131 of 801
+m0:=a0-r0
+--E 131
+
+--S 132 of 801
+d0:=normalize(D(m0,x))
+--E 132
+
+--S 133 of 801
+t0:=x^2*(4-x^2)^2
+--E 133
+
+--S 134 of 801
+r0:=16/3*x^3-8/5*x^5+1/7*x^7
+--E 134
+
+--S 135 of 801
+a0:=integrate(t0,x)
+--E 135
+
+--S 136 of 801
+m0:=a0-r0
+--E 136
+
+--S 137 of 801
+d0:=normalize(D(m0,x))
+--E 137
+
+--S 138 of 801
+t0:=x*(1-x^3)^2
+--E 138
+
+--S 139 of 801
+r0:=1/2*x^2-2/5*x^5+1/8*x^8
+--E 139
+
+--S 140 of 801
+a0:=integrate(t0,x)
+--E 140
+
+--S 141 of 801
+m0:=a0-r0
+--E 141
+
+--S 142 of 801
+d0:=normalize(D(m0,x))
+--E 142
+
+--S 143 of 801
+t0:=(-4+5*x^2+x^3)/x^2
+--E 143
+
+--S 144 of 801
+r0:=4/x+5*x+1/2*x^2
+--E 144
+
+--S 145 of 801
+a0:=integrate(t0,x)
+--E 145
+
+--S 146 of 801
+m0:=a0-r0
+--E 146
+
+--S 147 of 801
+d0:=normalize(D(m0,x))
+--E 147
+
+--S 148 of 801
+t0:=(-1+x)/(3-4*x+3*x^2)
+--E 148
+
+--S 149 of 801
+r0:=1/6*log(3-4*x+3*x^2)+1/3*atan((2-3*x)/sqrt(5))/sqrt(5)
+--E 149
+
+--S 150 of 801
+a0:=integrate(t0,x)
+--E 150
+
+--S 151 of 801
+m0:=a0-r0
+--E 151
+
+--S 152 of 801
+d0:=normalize(D(m0,x))
+--E 152
+
+--S 153 of 801
+t0:=(2+x^3)^2
+--E 153
+
+--S 154 of 801
+r0:=4*x+x^4+1/7*x^7
+--E 154
+
+--S 155 of 801
+a0:=integrate(t0,x)
+--E 155
+
+--S 156 of 801
+m0:=a0-r0
+--E 156
+
+--S 157 of 801
+d0:=normalize(D(m0,x))
+--E 157
+
+--S 158 of 801
+t0:=(-4+x^2)/(2+x)
+--E 158
+
+--S 159 of 801
+r0:=-2*x+1/2*x^2
+--E 159
+
+--S 160 of 801
+a0:=integrate(t0,x)
+--E 160
+
+--S 161 of 801
+m0:=a0-r0
+--E 161
+
+--S 162 of 801
+d0:=normalize(D(m0,x))
+--E 162
+
+--S 163 of 801
+t0:=1/((2+x)*(1+x^2))
+--E 163
+
+--S 164 of 801
+r0:=2/5*atan(x)+1/5*log(2+x)-1/10*log(1+x^2)
+--E 164
+
+--S 165 of 801
+a0:=integrate(t0,x)
+--E 165
+
+--S 166 of 801
+m0:=a0-r0
+--E 166
+
+--S 167 of 801
+d0:=normalize(D(m0,x))
+--E 167
+
+--S 168 of 801
+t0:=1/((1+x)*(1+x^2))
+--E 168
+
+--S 169 of 801
+r0:=1/2*atan(x)+1/2*log(1+x)-1/4*log(1+x^2)
+--E 169
+
+--S 170 of 801
+a0:=integrate(t0,x)
+--E 170
+
+--S 171 of 801
+m0:=a0-r0
+--E 171
+
+--S 172 of 801
+d0:=normalize(D(m0,x))
+--E 172
+
+--S 173 of 801
+t0:=x/((1+x)*(1+x^2))
+--E 173
+
+--S 174 of 801
+r0:=1/2*atan(x)-1/2*log(1+x)+1/4*log(1+x^2)
+--E 174
+
+--S 175 of 801
+a0:=integrate(t0,x)
+--E 175
+
+--S 176 of 801
+m0:=a0-r0
+--E 176
+
+--S 177 of 801
+d0:=normalize(D(m0,x))
+--E 177
+
+--S 178 of 801
+t0:=(2*x+x^2)/(1+x)^2
+--E 178
+
+--S 179 of 801
+r0:=(2+x)^2/(1+x)
+--E 179
+
+--S 180 of 801
+a0:=integrate(t0,x)
+--E 180
+
+--S 181 of 801
+m0:=a0-r0
+--E 181
+
+--S 182 of 801
+d0:=normalize(D(m0,x))
+--E 182
+
+--S 183 of 801
+t0:=(-10+x^2)/(4+9*x^2+2*x^4)
+--E 183
+
+--S 184 of 801
+r0:=atan(1/2*x)-3*atan(x*sqrt(2))/sqrt(2)
+--E 184
+
+--S 185 of 801
+a0:=integrate(t0,x)
+--E 185
+
+--S 186 of 801
+m0:=a0-r0
+--E 186
+
+--S 187 of 801
+d0:=normalize(D(m0,x))
+--E 187
+
+--S 188 of 801
+t0:=(31+5*x)/(11-4*x+3*x^2)
+--E 188
+
+--S 189 of 801
+r0:=5/6*log(11-4*x+3*x^2)-103/3*atan((2-3*x)/sqrt(29))/sqrt(29)
+--E 189
+
+--S 190 of 801
+a0:=integrate(t0,x)
+--E 190
+
+--S 191 of 801
+m0:=a0-r0
+--E 191
+
+--S 192 of 801
+d0:=normalize(D(m0,x))
+--E 192
+
+--S 193 of 801
+t0:=(3+x^2)/(-3+x^2)
+--E 193
+
+--S 194 of 801
+r0:=x-2*atanh(x/sqrt(3))*sqrt(3)
+--E 194
+
+--S 195 of 801
+a0:=integrate(t0,x)
+--E 195
+
+--S 196 of 801
+m0:=a0-r0
+--E 196
+
+--S 197 of 801
+d0:=normalize(D(m0,x))
+--E 197
+
+--S 198 of 801
+t0:=(-1+x^2)/(1+x^2)
+--E 198
+
+--S 199 of 801
+r0:=x-2*atan(x)
+--E 199
+
+--S 200 of 801
+a0:=integrate(t0,x)
+--E 200
+
+--S 201 of 801
+m0:=a0-r0
+--E 201
+
+--S 202 of 801
+d0:=normalize(D(m0,x))
+--E 202
+
+--S 203 of 801
+t0:=(-2+x^2+x^3)/x^4
+--E 203
+
+--S 204 of 801
+r0:=2/3/x^3+(-1)/x+log(x)
+--E 204
+
+--S 205 of 801
+a0:=integrate(t0,x)
+--E 205
+
+--S 206 of 801
+m0:=a0-r0
+--E 206
+
+--S 207 of 801
+d0:=normalize(D(m0,x))
+--E 207
+
+--S 208 of 801
+t0:=(1+x+x^3)/x^2
+--E 208
+
+--S 209 of 801
+r0:=(-1)/x+1/2*x^2+log(x)
+--E 209
+
+--S 210 of 801
+a0:=integrate(t0,x)
+--E 210
+
+--S 211 of 801
+m0:=a0-r0
+--E 211
+
+--S 212 of 801
+d0:=normalize(D(m0,x))
+--E 212
+
+--S 213 of 801
+t0:=(-2+x^2)/(x*(2+x^2))
+--E 213
+
+--S 214 of 801
+r0:=-log(x)+log(2+x^2)
+--E 214
+
+--S 215 of 801
+a0:=integrate(t0,x)
+--E 215
+
+--S 216 of 801
+m0:=a0-r0
+--E 216
+
+--S 217 of 801
+d0:=normalize(D(m0,x))
+--E 217
+
+--S 218 of 801
+t0:=(-3+x)*(-7+4*x^2)
+--E 218
+
+--S 219 of 801
+r0:=21*x-7/2*x^2-4*x^3+x^4
+--E 219
+
+--S 220 of 801
+a0:=integrate(t0,x)
+--E 220
+
+--S 221 of 801
+m0:=a0-r0
+--E 221
+
+--S 222 of 801
+d0:=normalize(D(m0,x))
+--E 222
+
+--S 223 of 801
+t0:=(-2+7*x)^3
+--E 223
+
+--S 224 of 801
+r0:=1/28*(2-7*x)^4
+--E 224
+
+--S 225 of 801
+a0:=integrate(t0,x)
+--E 225
+
+--S 226 of 801
+m0:=a0-r0
+--E 226
+
+--S 227 of 801
+d0:=normalize(D(m0,x))
+--E 227
+
+--S 228 of 801
+t0:=(-7+4*x^2)/(3+2*x)
+--E 228
+
+--S 229 of 801
+r0:=-3*x+x^2+log(3+2*x)
+--E 229
+
+--S 230 of 801
+a0:=integrate(t0,x)
+--E 230
+
+--S 231 of 801
+m0:=a0-r0
+--E 231
+
+--S 232 of 801
+d0:=normalize(D(m0,x))
+--E 232
+
+--S 233 of 801
+t0:=(1+x)/((-1+x)*x^2)
+--E 233
+
+--S 234 of 801
+r0:=1/x+2*log(1-x)-2*log(x)
+--E 234
+
+--S 235 of 801
+a0:=integrate(t0,x)
+--E 235
+
+--S 236 of 801
+m0:=a0-r0
+--E 236
+
+--S 237 of 801
+d0:=normalize(D(m0,x))
+--E 237
+
+--S 238 of 801
+t0:=(4+4*x)/(x^2*(1+x^2))
+--E 238
+
+--S 239 of 801
+r0:=(-4)/x-4*atan(x)+4*log(x)-2*log(1+x^2)
+--E 239
+
+--S 240 of 801
+a0:=integrate(t0,x)
+--E 240
+
+--S 241 of 801
+m0:=a0-r0
+--E 241
+
+--S 242 of 801
+d0:=normalize(D(m0,x))
+--E 242
+
+--S 243 of 801
+t0:=(24+8*x)/(x*(-4+x^2))
+--E 243
+
+--S 244 of 801
+r0:=5*log(2-x)-6*log(x)+log(2+x)
+--E 244
+
+--S 245 of 801
+a0:=integrate(t0,x)
+--E 245
+
+--S 246 of 801
+m0:=a0-r0
+--E 246
+
+--S 247 of 801
+d0:=normalize(D(m0,x))
+--E 247
+
+--S 248 of 801
+t0:=1/(4*x^2+4*x^3+x^4)
+--E 248
+
+--S 249 of 801
+r0a:=(-1/4)/x+(-1/4)/(2+x)+1/2*atanh(1+x)
+--E 249
+
+--S 250 of 801
+r0b:=(-1/4)/x+(-1/4)/(2+x)-1/4*log(x)+1/4*log(2+x)
+--E 250
+
+--S 251 of 801
+a0:=integrate(t0,x)
+--E 251
+
+--S 252 of 801
+m0a:=a0-r0a
+--E 252
+
+--S 253 of 801
+d0a:=D(m0a,x)
+--E 253
+
+--S 254 of 801
+m0b:=a0-r0b
+--E 254
+
+--S 255 of 801
+d0b:=D(m0b,x)
+--E 255
+
+--S 256 of 801
+t0:=(1+x^2)/(1+x)
+--E 256
+
+--S 257 of 801
+r0:=-x+1/2*x^2+2*log(1+x)
+--E 257
+
+--S 258 of 801
+a0:=integrate(t0,x)
+--E 258
+
+--S 259 of 801
+m0:=a0-r0
+--E 259
+
+--S 260 of 801
+d0:=normalize(D(m0,x))
+--E 260
+
+--S 261 of 801
+t0:=(-1+3*x-3*x^2+x^3)/x^2
+--E 261
+
+--S 262 of 801
+r0:=1/x-3*x+1/2*x^2+3*log(x)
+--E 262
+
+--S 263 of 801
+a0:=integrate(t0,x)
+--E 263
+
+--S 264 of 801
+m0:=a0-r0
+--E 264
+
+--S 265 of 801
+d0:=normalize(D(m0,x))
+--E 265
+
+--S 266 of 801
+t0:=(x+1/2*(3-sqrt(37)))*(x+1/2*(3+sqrt(37)))
+--E 266
+
+--S 267 of 801
+r0:=-7*x+3/2*x^2+1/3*x^3
+--E 267
+
+--S 268 of 801
+a0:=integrate(t0,x)
+--E 268
+
+--S 269 of 801
+m0:=a0-r0
+--E 269
+
+--S 270 of 801
+d0:=normalize(D(m0,x))
+--E 270
+
+--S 271 of 801
+t0:=(-4+x)/((1+x^(1/3))*sqrt(x))
+--E 271
+
+--S 272 of 801
+r0:=-30*x^(1/6)-6/5*x^(5/6)+6/7*x^(7/6)+30*atan(x^(1/6))+2*sqrt(x)
+--E 272
+
+--S 273 of 801
+a0:=integrate(t0,x)
+--E 273
+
+--S 274 of 801
+m0:=a0-r0
+--E 274
+
+--S 275 of 801
+d0:=normalize(D(m0,x))
+--E 275
+
+--S 276 of 801
+t0:=(1+sqrt(x))/(x^(5/6)+x^(7/6))
+--E 276
+
+--S 277 of 801
+r0:=3*x^(1/3)+6*atan(x^(1/6))-3*log(1+x^(1/3))
+--E 277
+
+--S 278 of 801
+a0:=integrate(t0,x)
+--E 278
+
+--S 279 of 801
+m0:=a0-r0
+--E 279
+
+--S 280 of 801
+d0:=normalize(D(m0,x))
+--E 280
+
+--S 281 of 801
+t0:=(1+sqrt(x))/((1+x^(1/3))*sqrt(x))
+--E 281
+
+--S 282 of 801
+r0:=6*x^(1/6)-3*x^(1/3)+3/2*x^(2/3)-6*atan(x^(1/6))+3*log(1+x^(1/3))
+--E 282
+
+--S 283 of 801
+a0:=integrate(t0,x)
+--E 283
+
+--S 284 of 801
+m0:=a0-r0
+--E 284
+
+--S 285 of 801
+d0:=normalize(D(m0,x))
+--E 285
+
+--S 286 of 801
+t0:=sqrt(2+b/x^2)/(b+2*x^2)
+--E 286
+
+--S 287 of 801
+r0:=-asinh(sqrt(b)/(x*sqrt(2)))/sqrt(b)
+--E 287
+
+--S 288 of 801
+a0:=integrate(t0,x)
+--E 288
+
+--S 289 of 801
+m0:=a0-r0
+--E 289
+
+--S 290 of 801
+d0:=normalize(D(m0,x))
+--E 290
+
+--S 291 of 801
+t0:=sqrt(2-b/x^2)/(-b+2*x^2)
+--E 291
+
+--S 292 of 801
+r0:=-asin(sqrt(b)/(x*sqrt(2)))/sqrt(b)
+--E 292
+
+--S 293 of 801
+a0:=integrate(t0,x)
+--E 293
+
+--S 294 of 801
+m0:=a0-r0
+--E 294
+
+--S 295 of 801
+d0:=normalize(D(m0,x))
+--E 295
+
+--S 296 of 801
+t0:=1/(sqrt(x)+sqrt(1+x))
+--E 296
+
+--S 297 of 801
+r0:=-2/3*x^(3/2)+2/3*(1+x)^(3/2)
+--E 297
+
+--S 298 of 801
+a0:=integrate(t0,x)
+--E 298
+
+--S 299 of 801
+m0:=a0-r0
+--E 299
+
+--S 300 of 801
+d0:=normalize(D(m0,x))
+--E 300
+
+--S 301 of 801
+t0:=1/(sqrt(-1+x)+sqrt(1+x))
+--E 301
+
+--S 302 of 801
+r0:=-1/3*(-1+x)^(3/2)+1/3*(1+x)^(3/2)
+--E 302
+
+--S 303 of 801
+a0:=integrate(t0,x)
+--E 303
+
+--S 304 of 801
+m0:=a0-r0
+--E 304
+
+--S 305 of 801
+d0:=normalize(D(m0,x))
+--E 305
+
+--S 306 of 801
+t0:=(x^(1/6)+(x^3)^(1/5))/sqrt(x)
+--E 306
+
+--S 307 of 801
+r0:=3/2*x^(2/3)+10/11*(x^3)^(1/5)*sqrt(x)
+--E 307
+
+--S 308 of 801
+--a0:=integrate(t0,x)
+--E 308
+
+--S 309 of 801
+--m0:=a0-r0
+--E 309
+
+--S 310 of 801
+--d0:=normalize(D(m0,x))
+--E 310
+
+--S 311 of 801
+t0:=(2+x)/sqrt(4*x-x^2)
+--E 311
+
+--S 312 of 801
+r0:=-4*asin(1-1/2*x)-sqrt(4*x-x^2)
+--E 312
+
+--S 313 of 801
+a0:=integrate(t0,x)
+--E 313
+
+--S 314 of 801
+m0:=a0-r0
+--E 314
+
+--S 315 of 801
+d0:=normalize(D(m0,x))
+--E 315
+
+--S 316 of 801
+t0:=(3+x)/(6*x+x^2)^(1/3)
+--E 316
+
+--S 317 of 801
+r0:=3/4*(6*x+x^2)^(2/3)
+--E 317
+
+--S 318 of 801
+a0:=integrate(t0,x)
+--E 318
+
+--S 319 of 801
+m0:=a0-r0
+--E 319
+
+--S 320 of 801
+d0:=normalize(D(m0,x))
+--E 320
+
+--S 321 of 801
+t0:=(4+x)/(6*x-x^2)^(3/2)
+--E 321
+
+--S 322 of 801
+r0:=1/9*(-12+7*x)/sqrt(6*x-x^2)
+--E 322
+
+--S 323 of 801
+a0:=integrate(t0,x)
+--E 323
+
+--S 324 of 801
+m0:=a0-r0
+--E 324
+
+--S 325 of 801
+d0:=normalize(D(m0,x))
+--E 325
+
+--S 326 of 801
+t0:=1/((1+x)*sqrt(2*x+x^2))
+--E 326
+
+--S 327 of 801
+r0:=atan(sqrt(2*x+x^2))
+--E 327
+
+--S 328 of 801
+a0:=integrate(t0,x)
+--E 328
+
+--S 329 of 801
+m0:=a0-r0
+--E 329
+
+--S 330 of 801
+d0:=normalize(D(m0,x))
+--E 330
+
+--S 331 of 801
+t0:=1/((1+2*x)*sqrt(x+x^2))
+--E 331
+
+--S 332 of 801
+r0:=atan(2*sqrt(x+x^2))
+--E 332
+
+--S 333 of 801
+a0:=integrate(t0,x)
+--E 333
+
+--S 334 of 801
+m0:=a0-r0
+--E 334
+
+--S 335 of 801
+d0:=normalize(D(m0,x))
+--E 335
+
+--S 336 of 801
+t0:=(-1+x)/sqrt(2*x-x^2)
+--E 336
+
+--S 337 of 801
+r0:=-sqrt(2*x-x^2)
+--E 337
+
+--S 338 of 801
+a0:=integrate(t0,x)
+--E 338
+
+--S 339 of 801
+m0:=a0-r0
+--E 339
+
+--S 340 of 801
+d0:=normalize(D(m0,x))
+--E 340
+
+--S 341 of 801
+t0:=sqrt(x-x^2)/(1+x)
+--E 341
+
+--S 342 of 801
+r0:=-3/2*asin(1-2*x)+atan(1/2*(1-3*x)/(sqrt(2)*sqrt(x-x^2)))*sqrt(2)+sqrt(x-x^2)
+--E 342
+
+--S 343 of 801
+a0:=integrate(t0,x)
+--E 343
+
+--S 344 of 801
+m0:=a0-r0
+--E 344
+
+--S 345 of 801
+d0:=normalize(D(m0,x))
+--E 345
+
+--S 346 of 801
+t0:=sqrt(x^(1/4)+x)
+--E 346
+
+--S 347 of 801
+r0:=-1/3*atanh(sqrt(x)/sqrt(x^(1/4)+x))+1/3*x^(1/4)*sqrt(x^(1/4)+x)+2/3*x*sqrt(x^(1/4)+x)
+--E 347
+
+--S 348 of 801
+--a0:=integrate(t0,x)
+--E 348
+
+--S 349 of 801
+--m0:=a0-r0
+--E 349
+
+--S 350 of 801
+--d0:=normalize(D(m0,x))
+--E 350
+
+--S 351 of 801
+t0:=sqrt(x+x^(3/2))
+--E 351
+
+--S 352 of 801
+r0:=32/105*(x+x^(3/2))^(3/2)/x^(3/2)-16/35*(x+x^(3/2))^(3/2)/x+4/7*(x+x^(3/2))^(3/2)/sqrt(x)
+--E 352
+
+--S 353 of 801
+a0:=integrate(t0,x)
+--E 353
+
+--S 354 of 801
+m0:=a0-r0
+--E 354
+
+--S 355 of 801
+d0:=normalize(D(m0,x))
+--E 355
+
+--S 356 of 801
+t0:=x*sqrt(x+x^(3/2))
+--E 356
+
+--S 357 of 801
+r0:=-32/99*(x+x^(3/2))^(3/2)+512/3465*(x+x^(3/2))^(3/2)/x^(3/2)-256/1155*(x+x^(3/2))^(3/2)/x+64/231*(x+x^(3/2))^(3/2)/sqrt(x)+4/11*(x+x^(3/2))^(3/2)*sqrt(x)
+--E 357
+
+--S 358 of 801
+a0:=integrate(t0,x)
+--E 358
+
+--S 359 of 801
+m0:=a0-r0
+--E 359
+
+--S 360 of 801
+d0:=normalize(D(m0,x))
+--E 360
+
+--S 361 of 801
+t0:=(1-x^2)*sqrt(1/(2-x^2))
+--E 361
+
+--S 362 of 801
+r0:=1/2*x/sqrt(1/(2-x^2))
+--E 362
+
+--S 363 of 801
+a0:=integrate(t0,x)
+--E 363
+
+--S 364 of 801
+m0:=a0-r0
+--E 364
+
+--S 365 of 801
+d0:=normalize(D(m0,x))
+--E 365
+
+--S 366 of 801
+t0:=sqrt(x^2+x^3-x^4)
+--E 366
+
+--S 367 of 801
+r0:=-1/8*(1-2*x)*sqrt(x^2+x^3-x^4)/x-1/3*(1+x-x^2)*sqrt(x^2+x^3-x^4)/x-5/16*asin((1-2*x)/sqrt(5))*sqrt(x^2+x^3-x^4)/(x*sqrt(1+x-x^2))
+--E 367
+
+--S 368 of 801
+a0:=integrate(t0,x)
+--E 368
+
+--S 369 of 801
+m0:=a0-r0
+--E 369
+
+--S 370 of 801
+d0:=normalize(D(m0,x))
+--E 370
+
+--S 371 of 801
+t0:=1/sqrt((a^2+x^2)^3)
+--E 371
+
+--S 372 of 801
+r0:=x*(a^2+x^2)/(a^2*sqrt((a^2+x^2)^3))
+--E 372
+
+--S 373 of 801
+a0:=integrate(t0,x)
+--E 373
+
+--S 374 of 801
+m0:=a0-r0
+--E 374
+
+--S 375 of 801
+d0:=normalize(D(m0,x))
+--E 375
+
+--S 376 of 801
+t0:=sqrt(x)/(1+x+sqrt(x))
+--E 376
+
+--S 377 of 801
+r0:=-log(1+x+sqrt(x))-2*atan((1+2*sqrt(x))/sqrt(3))/sqrt(3)+2*sqrt(x)
+--E 377
+
+--S 378 of 801
+a0:=integrate(t0,x)
+--E 378
+
+--S 379 of 801
+m0:=a0-r0
+--E 379
+
+--S 380 of 801
+d0:=normalize(D(m0,x))
+--E 380
+
+--S 381 of 801
+t0:=x/(1+x+sqrt(x))
+--E 381
+
+--S 382 of 801
+r0:=x+4*atan((1+2*sqrt(x))/sqrt(3))/sqrt(3)-2*sqrt(x)
+--E 382
+
+--S 383 of 801
+a0:=integrate(t0,x)
+--E 383
+
+--S 384 of 801
+m0:=a0-r0
+--E 384
+
+--S 385 of 801
+d0:=normalize(D(m0,x))
+--E 385
+
+--S 386 of 801
+t0:=1/(sqrt(x)*(1+x+sqrt(x))^(7/2))
+--E 386
+
+--S 387 of 801
+r0:=4/15*(1+2*sqrt(x))/(1+x+sqrt(x))^(5/2)+64/135*(1+2*sqrt(x))/(1+x+sqrt(x))^(3/2)+512/405*(1+2*sqrt(x))/sqrt(1+x+sqrt(x))
+--E 387
+
+--S 388 of 801
+a0:=integrate(t0,x)
+--E 388
+
+--S 389 of 801
+m0:=a0-r0
+--E 389
+
+--S 390 of 801
+d0:=normalize(D(m0,x))
+--E 390
+
+--S 391 of 801
+t0:=(-1+x)/(1+sqrt(1+x^2))
+--E 391
+
+--S 392 of 801
+r0:=(-1)/x-asinh(x)-log(1+sqrt(1+x^2))+sqrt(1+x^2)+sqrt(1+x^2)/x
+--E 392
+
+--S 393 of 801
+a0:=integrate(t0,x)
+--E 393
+
+--S 394 of 801
+m0:=a0-r0
+--E 394
+
+--S 395 of 801
+d0:=normalize(D(m0,x))
+--E 395
+
+--S 396 of 801
+t0:=(-x+x^3)/sqrt(-2+x^2)
+--E 396
+
+--S 397 of 801
+r0:=1/3*(-2+x^2)^(3/2)+sqrt(-2+x^2)
+--E 397
+
+--S 398 of 801
+a0:=integrate(t0,x)
+--E 398
+
+--S 399 of 801
+m0:=a0-r0
+--E 399
+
+--S 400 of 801
+d0:=normalize(D(m0,x))
+--E 400
+
+--S 401 of 801
+t0:=(x-x^2)/sqrt(1-x^2)
+--E 401
+
+--S 402 of 801
+r0:=-1/2*asin(x)-1/2*sqrt(1-x^2)-1/2*(1-x)*sqrt(1-x^2)
+--E 402
+
+--S 403 of 801
+a0:=integrate(t0,x)
+--E 403
+
+--S 404 of 801
+m0:=a0-r0
+--E 404
+
+--S 405 of 801
+d0:=normalize(D(m0,x))
+--E 405
+
+--S 406 of 801
+t0:=1/((1+x)^(2/3)*(-1+x^2)^(2/3))
+--E 406
+
+--S 407 of 801
+r0:=3/2*(-1+x^2)^(1/3)/(1+x)^(2/3)
+--E 407
+
+--S 408 of 801
+a0:=integrate(t0,x)
+--E 408
+
+--S 409 of 801
+m0:=a0-r0
+--E 409
+
+--S 410 of 801
+d0:=normalize(D(m0,x))
+--E 410
+
+--S 411 of 801
+t0:=x*sqrt(1-x^2)/(1+x)
+--E 411
+
+--S 412 of 801
+r0:=-1/2*(1-x^2)^(3/2)/(1+x)-1/2*asin(x)-1/2*sqrt(1-x^2)
+--E 412
+
+--S 413 of 801
+a0:=integrate(t0,x)
+--E 413
+
+--S 414 of 801
+m0:=a0-r0
+--E 414
+
+--S 415 of 801
+d0:=normalize(D(m0,x))
+--E 415
+
+--S 416 of 801
+t0:=x*(1+x)^2/sqrt(1-x^2)
+--E 416
+
+--S 417 of 801
+r0:=asin(x)-sqrt(1-x^2)-1/3*(1+x)*sqrt(1-x^2)-1/3*(1+x)^2*sqrt(1-x^2)
+--E 417
+
+--S 418 of 801
+a0:=integrate(t0,x)
+--E 418
+
+--S 419 of 801
+m0:=a0-r0
+--E 419
+
+--S 420 of 801
+d0:=normalize(D(m0,x))
+--E 420
+
+--S 421 of 801
+t0:=(-1+x^4)/(1+x^4)^(3/2)
+--E 421
+
+--S 422 of 801
+r0:=-x/sqrt(1+x^4)
+--E 422
+
+--S 423 of 801
+a0:=integrate(t0,x)
+--E 423
+
+--S 424 of 801
+m0:=a0-r0
+--E 424
+
+--S 425 of 801
+d0:=normalize(D(m0,x))
+--E 425
+
+--S 426 of 801
+t0:=(1-x^6)^(2/3)+(1-x^6)^(2/3)/x^6
+--E 426
+
+--S 427 of 801
+r0:=-1/5*(1-x^6)^(2/3)/x^5+1/5*x*(1-x^6)^(2/3)
+--E 427
+
+--S 428 of 801
+a0:=integrate(t0,x)
+--E 428
+
+--S 429 of 801
+m0:=a0-r0
+--E 429
+
+--S 430 of 801
+d0:=normalize(D(m0,x))
+--E 430
+
+--S 431 of 801
+t0:=1/2*x^(-1+m)*(2*a*m+b*(2*m-n)*x^n)/(a+b*x^n)^(3/2)
+--E 431
+
+--S 432 of 801
+r0:=x^m/sqrt(a+b*x^n)
+--E 432
+
+--S 433 of 801
+a0:=integrate(t0,x)
+--E 433
+
+--S 434 of 801
+m0:=a0-r0
+--E 434
+
+--S 435 of 801
+d0:=normalize(D(m0,x))
+--E 435
+
+--S 436 of 801
+t0:=(4+3*x^2+2*x^3)/(1+x)^4
+--E 436
+
+--S 437 of 801
+r0:=(-5/3)/(1+x)^3+3/(1+x)+2*log(1+x)
+--E 437
+
+--S 438 of 801
+a0:=integrate(t0,x)
+--E 438
+
+--S 439 of 801
+m0:=a0-r0
+--E 439
+
+--S 440 of 801
+d0:=normalize(D(m0,x))
+--E 440
+
+--S 441 of 801
+t0:=x/((1+x)^2*(1+x^2))
+--E 441
+
+--S 442 of 801
+r0:=1/2/(1+x)+1/2*atan(x)
+--E 442
+
+--S 443 of 801
+a0:=integrate(t0,x)
+--E 443
+
+--S 444 of 801
+m0:=a0-r0
+--E 444
+
+--S 445 of 801
+d0:=normalize(D(m0,x))
+--E 445
+
+--S 446 of 801
+t0:=(7-2*x+3*x^2-x^3+x^4)/(2+x)
+--E 446
+
+--S 447 of 801
+r0:=-20*x+9/2*x^2-x^3+1/4*x^4+47*log(2+x)
+--E 447
+
+--S 448 of 801
+a0:=integrate(t0,x)
+--E 448
+
+--S 449 of 801
+m0:=a0-r0
+--E 449
+
+--S 450 of 801
+d0:=normalize(D(m0,x))
+--E 450
+
+--S 451 of 801
+t0:=(-1+x^3)/(-1+x)
+--E 451
+
+--S 452 of 801
+r0:=x+1/2*x^2+1/3*x^3
+--E 452
+
+--S 453 of 801
+a0:=integrate(t0,x)
+--E 453
+
+--S 454 of 801
+m0:=a0-r0
+--E 454
+
+--S 455 of 801
+d0:=normalize(D(m0,x))
+--E 455
+
+--S 456 of 801
+t0:=(2+2*x)/((-1+x)^3*(1+x^2))
+--E 456
+
+--S 457 of 801
+r0:=(-1)/(1-x)^2+1/(-1+x)+atan(x)
+--E 457
+
+--S 458 of 801
+a0:=integrate(t0,x)
+--E 458
+
+--S 459 of 801
+m0:=a0-r0
+--E 459
+
+--S 460 of 801
+d0:=normalize(D(m0,x))
+--E 460
+
+--S 461 of 801
+t0:=(x-2*x^3)/sqrt(2+3*x)
+--E 461
+
+--S 462 of 801
+r0:=-10/81*(2+3*x)^(3/2)+8/135*(2+3*x)^(5/2)-4/567*(2+3*x)^(7/2)-4/81*sqrt(2+3*x)
+--E 462
+
+--S 463 of 801
+a0:=integrate(t0,x)
+--E 463
+
+--S 464 of 801
+m0:=a0-r0
+--E 464
+
+--S 465 of 801
+d0:=normalize(D(m0,x))
+--E 465
+
+--S 466 of 801
+t0:=1/((1+x)^(1/4)+sqrt(1+x))
+--E 466
+
+--S 467 of 801
+r0:=-4*(1+x)^(1/4)+4*log(1+(1+x)^(1/4))+2*sqrt(1+x)
+--E 467
+
+--S 468 of 801
+a0:=integrate(t0,x)
+--E 468
+
+--S 469 of 801
+m0:=a0-r0
+--E 469
+
+--S 470 of 801
+d0:=normalize(D(m0,x))
+--E 470
+
+--S 471 of 801
+t0:=(1+2*x)/sqrt(x+x^2)
+--E 471
+
+--S 472 of 801
+r0:=2*sqrt(x+x^2)
+--E 472
+
+--S 473 of 801
+a0:=integrate(t0,x)
+--E 473
+
+--S 474 of 801
+m0:=a0-r0
+--E 474
+
+--S 475 of 801
+d0:=normalize(D(m0,x))
+--E 475
+
+--S 476 of 801
+t0:=1/2/((1+x)*sqrt(x))
+--E 476
+
+--S 477 of 801
+r0:=atan(sqrt(x))
+--E 477
+
+--S 478 of 801
+a0:=integrate(t0,x)
+--E 478
+
+--S 479 of 801
+m0:=a0-r0
+--E 479
+
+--S 480 of 801
+d0:=normalize(D(m0,x))
+--E 480
+
+--S 481 of 801
+t0:=1/(x*sqrt(6*x-x^2))
+--E 481
+
+--S 482 of 801
+r0:=-1/3*sqrt(6*x-x^2)/x
+--E 482
+
+--S 483 of 801
+a0:=integrate(t0,x)
+--E 483
+
+--S 484 of 801
+m0:=a0-r0
+--E 484
+
+--S 485 of 801
+d0:=normalize(D(m0,x))
+--E 485
+
+--S 486 of 801
+t0:=sqrt(x)*(1+sqrt(x))
+--E 486
+
+--S 487 of 801
+r0:=2/3*x^(3/2)+1/2*x^2
+--E 487
+
+--S 488 of 801
+a0:=integrate(t0,x)
+--E 488
+
+--S 489 of 801
+m0:=a0-r0
+--E 489
+
+--S 490 of 801
+d0:=normalize(D(m0,x))
+--E 490
+
+--S 491 of 801
+t0:=(1-sqrt(x))/x^(1/3)
+--E 491
+
+--S 492 of 801
+r0:=3/2*x^(2/3)-6/7*x^(7/6)
+--E 492
+
+--S 493 of 801
+a0:=integrate(t0,x)
+--E 493
+
+--S 494 of 801
+m0:=a0-r0
+--E 494
+
+--S 495 of 801
+d0:=normalize(D(m0,x))
+--E 495
+
+--S 496 of 801
+t0:=sqrt(x)/(1+x^(1/3))
+--E 496
+
+--S 497 of 801
+r0:=-6*x^(1/6)-6/5*x^(5/6)+6/7*x^(7/6)+6*atan(x^(1/6))+2*sqrt(x)
+--E 497
+
+--S 498 of 801
+a0:=integrate(t0,x)
+--E 498
+
+--S 499 of 801
+m0:=a0-r0
+--E 499
+
+--S 500 of 801
+d0:=normalize(D(m0,x))
+--E 500
+
+--S 501 of 801
+t0:=(1+sqrt(x))^(1/3)/x
+--E 501
+
+--S 502 of 801
+r0:=2*log(1-(1+sqrt(x))^(1/3))-log(1+(1+sqrt(x))^(1/3)+(1+sqrt(x))^(2/3))-2*atan((1+2*(1+sqrt(x))^(1/3))/sqrt(3))*sqrt(3)+6*(1+sqrt(x))^(1/3)
+--E 502
+
+--S 503 of 801
+a0:=integrate(t0,x)
+--E 503
+
+--S 504 of 801
+m0:=a0-r0
+--E 504
+
+--S 505 of 801
+d0:=normalize(D(m0,x))
+--E 505
+
+--S 506 of 801
+t0:=1-sqrt(x)
+--E 506
+
+--S 507 of 801
+r0:=x-2/3*x^(3/2)
+--E 507
+
+--S 508 of 801
+a0:=integrate(t0,x)
+--E 508
+
+--S 509 of 801
+m0:=a0-r0
+--E 509
+
+--S 510 of 801
+d0:=normalize(D(m0,x))
+--E 510
+
+--S 511 of 801
+t0:=1-x^(1/4)
+--E 511
+
+--S 512 of 801
+r0:=x-4/5*x^(5/4)
+--E 512
+
+--S 513 of 801
+a0:=integrate(t0,x)
+--E 513
+
+--S 514 of 801
+m0:=a0-r0
+--E 514
+
+--S 515 of 801
+d0:=normalize(D(m0,x))
+--E 515
+
+--S 516 of 801
+t0:=(1-sqrt(x))/(1+x^(1/4))
+--E 516
+
+--S 517 of 801
+r0:=x-4/5*x^(5/4)
+--E 517
+
+--S 518 of 801
+a0:=integrate(t0,x)
+--E 518
+
+--S 519 of 801
+m0:=a0-r0
+--E 519
+
+--S 520 of 801
+d0:=normalize(D(m0,x))
+--E 520
+
+--S 521 of 801
+t0:=1/sqrt((a+b*x)*(c+d*x))
+--E 521
+
+--S 522 of 801
+r0:=atanh(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)*sqrt(a*c+(b*c+a*d)*x+b*d*x^2)))/(sqrt(b)*sqrt(d))
+--E 522
+
+--S 523 of 801
+a0:=integrate(t0,x)
+--E 523
+
+--S 524 of 801
+m0a:=a0.1-r0
+--E 524
+
+--S 525 of 801
+d0a:=normalize(D(m0a,x))
+--E 525
+
+--S 526 of 801
+m0b:=a0.2-r0
+--E 526
+
+--S 527 of 801
+d0b:=normalize(D(m0b,x))
+--E 527
+
+--S 528 of 801
+t0:=1/sqrt((a+b*x)*(c-d*x))
+--E 528
+
+--S 529 of 801
+r0:=-atan(1/2*(b*c-a*d-2*b*d*x)/(sqrt(b)*sqrt(d)*sqrt(a*c+(b*c-a*d)*x-b*d*x^2)))/(sqrt(b)*sqrt(d))
+--E 529
+
+--S 530 of 801
+a0:=integrate(t0,x)
+--E 530
+
+--S 531 of 801
+m0a:=a0.1-r0
+--E 531
+
+--S 532 of 801
+d0a:=normalize(D(m0a,x))
+--E 532
+
+--S 533 of 801
+m0b:=a0.2-r0
+--E 533
+
+--S 534 of 801
+d0b:=normalize(D(m0b,x))
+--E 534
+
+--S 535 of 801
+t0:=1/((1-x^2)*sqrt(x))
+--E 535
+
+--S 536 of 801
+r0:=atan(sqrt(x))+atanh(sqrt(x))
+--E 536
+
+--S 537 of 801
+a0:=integrate(t0,x)
+--E 537
+
+--S 538 of 801
+m0:=a0-r0
+--E 538
+
+--S 539 of 801
+d0:=normalize(D(m0,x))
+--E 539
+
+--S 540 of 801
+t0:=sqrt(x)/(x-x^3)
+--E 540
+
+--S 541 of 801
+r0:=atan(sqrt(x))+atanh(sqrt(x))
+--E 541
+
+--S 542 of 801
+a0:=integrate(t0,x)
+--E 542
+
+--S 543 of 801
+m0:=a0-r0
+--E 543
+
+--S 544 of 801
+d0:=normalize(D(m0,x))
+--E 544
+
+--S 545 of 801
+t0:=x/(2+x^2-sqrt(3)+x*(1+sqrt(3)))
+--E 545
+
+--S 546 of 801
+r0:=1/2*log(2+x^2-sqrt(3)+x*(1+sqrt(3)))+atanh((1+2*x+sqrt(3))/sqrt(2*(-2+3*sqrt(3))))*sqrt(1/23*(13+8*sqrt(3)))
+--E 546
+
+--S 547 of 801
+a0:=integrate(t0,x)
+--E 547
+
+--S 548 of 801
+m0:=a0-r0
+--E 548
+
+--S 549 of 801
+d0:=normalize(D(m0,x))
+--E 549
+
+--S 550 of 801
+t0:=sqrt(x^2+x^3)
+--E 550
+
+--S 551 of 801
+r0:=-4/15*(x^2+x^3)^(3/2)/x^3+2/5*(x^2+x^3)^(3/2)/x^2
+--E 551
+
+--S 552 of 801
+a0:=integrate(t0,x)
+--E 552
+
+--S 553 of 801
+m0:=a0-r0
+--E 553
+
+--S 554 of 801
+d0:=normalize(D(m0,x))
+--E 554
+
+--S 555 of 801
+t0:=1/((1+x)*sqrt(2*x+x^2))
+--E 555
+
+--S 556 of 801
+r0:=atan(sqrt(2*x+x^2))
+--E 556
+
+--S 557 of 801
+a0:=integrate(t0,x)
+--E 557
+
+--S 558 of 801
+m0:=a0-r0
+--E 558
+
+--S 559 of 801
+d0:=normalize(D(m0,x))
+--E 559
+
+--S 560 of 801
+t0:=sqrt(x)*sqrt(1-x-sqrt(x))
+--E 560
+
+--S 561 of 801
+r0:=45/64*asin((1+2*sqrt(x))/sqrt(5))+5/12*(1-x-sqrt(x))^(3/2)-1/2*(1-x-sqrt(x))^(3/2)*sqrt(x)+9/32*(1+2*sqrt(x))*sqrt(1-x-sqrt(x))
+--E 561
+
+--S 562 of 801
+a0:=integrate(t0,x)
+--E 562
+
+--S 563 of 801
+m0:=a0-r0
+--E 563
+
+--S 564 of 801
+d0:=normalize(D(m0,x))
+--E 564
+
+--S 565 of 801
+t0:=(1+sqrt(-3+x))^(1/3)
+--E 565
+
+--S 566 of 801
+r0:=-3/2*(1+sqrt(-3+x))^(4/3)+6/7*(1+sqrt(-3+x))^(7/3)
+--E 566
+
+--S 567 of 801
+a0:=integrate(t0,x)
+--E 567
+
+--S 568 of 801
+m0:=a0-r0
+--E 568
+
+--S 569 of 801
+d0:=normalize(D(m0,x))
+--E 569
+
+--S 570 of 801
+t0:=1/sqrt(3+sqrt(-1+2*x))
+--E 570
+
+--S 571 of 801
+r0:=2/3*(3+sqrt(-1+2*x))^(3/2)-6*sqrt(3+sqrt(-1+2*x))
+--E 571
+
+--S 572 of 801
+a0:=integrate(t0,x)
+--E 572
+
+--S 573 of 801
+m0:=a0-r0
+--E 573
+
+--S 574 of 801
+d0:=normalize(D(m0,x))
+--E 574
+
+--S 575 of 801
+t0:=sqrt(1-x)/(1+sqrt(x))
+--E 575
+
+--S 576 of 801
+r0:=-asin(sqrt(x))-sqrt(1-x)-(1-x)^(3/2)/(1+sqrt(x))
+--E 576
+
+--S 577 of 801
+--a0:=integrate(t0,x)
+--E 577
+
+--S 578 of 801
+--m0:=a0-r0
+--E 578
+
+--S 579 of 801
+--d0:=normalize(D(m0,x))
+--E 579
+
+--S 580 of 801
+t0:=sqrt(1-x)/(1-sqrt(x))
+--E 580
+
+--S 581 of 801
+r0:=asin(sqrt(x))-sqrt(1-x)-(1-x)^(3/2)/(1-sqrt(x))
+--E 581
+
+--S 582 of 801
+--a0:=integrate(t0,x)
+--E 582
+
+--S 583 of 801
+--m0:=a0-r0
+--E 583
+
+--S 584 of 801
+--d0:=normalize(D(m0,x))
+--E 584
+
+--S 585 of 801
+t0:=x/(x-sqrt(1+x^2))
+--E 585
+
+--S 586 of 801
+r0:=-1/3*x^3-1/3*(1+x^2)^(3/2)
+--E 586
+
+--S 587 of 801
+a0:=integrate(t0,x)
+--E 587
+
+--S 588 of 801
+m0:=a0-r0
+--E 588
+
+--S 589 of 801
+d0:=normalize(D(m0,x))
+--E 589
+
+--S 590 of 801
+t0:=x/(x-sqrt(1-x^2))
+--E 590
+
+--S 591 of 801
+r0:=1/2*x-1/2*atanh(x*sqrt(2))/sqrt(2)-1/2*atanh(sqrt(2)*sqrt(1-x^2))/sqrt(2)+1/2*sqrt(1-x^2)
+--E 591
+
+--S 592 of 801
+a0:=integrate(t0,x)
+--E 592
+
+--S 593 of 801
+m0:=a0-r0
+--E 593
+
+--S 594 of 801
+d0:=normalize(D(m0,x))
+--E 594
+
+--S 595 of 801
+t0:=x/(x-sqrt(1+2*x^2))
+--E 595
+
+--S 596 of 801
+r0:=-x+atan(x)+atan(sqrt(1+2*x^2))-sqrt(1+2*x^2)
+--E 596
+
+--S 597 of 801
+a0:=integrate(t0,x)
+--E 597
+
+--S 598 of 801
+m0:=a0-r0
+--E 598
+
+--S 599 of 801
+d0:=normalize(D(m0,x))
+--E 599
+
+--S 600 of 801
+t0:=1/(sqrt(-1+x)*sqrt(1+x)*sqrt(-1+2*x^2))
+--E 600
+
+--S 601 of 801
+--r0:=-%i*elliptic_f(%i*acosh(x),2)
+--E 601
+
+--S 602 of 801
+--a0:=integrate(t0,x)
+--E 602
+
+--S 603 of 801
+--m0:=a0-r0
+--E 603
+
+--S 604 of 801
+--d0:=normalize(D(m0,x))
+--E 604
+
+--S 605 of 801
+t0:=x/sqrt(-71-96*x+10*x^2+x^4)
+--E 605
+
+--S 606 of 801
+r0:=-1/8*log(-10001-3124*x^2+1408*x^3-54*x^4+128*x^5-20*x^6-x^8+(781-528*x+27*x^2-80*x^3+15*x^4+x^6)*sqrt(-71-96*x+10*x^2+x^4))
+--E 606
+
+--S 607 of 801
+a0:=integrate(t0,x)
+--E 607
+
+--S 608 of 801
+m0:=a0-r0
+--E 608
+
+--S 609 of 801
+d0:=normalize(D(m0,x))
+--E 609
+
+--S 610 of 801
+t0:=sqrt(x)*sqrt(x+sqrt(x))
+--E 610
+
+--S 611 of 801
+r0:=-5/32*atanh(sqrt(x)/sqrt(x+sqrt(x)))+5/32*sqrt(x+sqrt(x))+1/12*x*sqrt(x+sqrt(x))+1/2*x^(3/2)*sqrt(x+sqrt(x))-5/48*sqrt(x)*sqrt(x+sqrt(x))
+--E 611
+
+--S 612 of 801
+a0:=integrate(t0,x)
+--E 612
+
+--S 613 of 801
+m0:=a0-r0
+--E 613
+
+--S 614 of 801
+d0:=normalize(D(m0,x))
+--E 614
+
+--S 615 of 801
+t0:=1/((1+x^4)*sqrt(-x^2+sqrt(1+x^4)))
+--E 615
+
+--S 616 of 801
+r0:=acot(sqrt(-x^2+sqrt(1+x^4))/x)
+--E 616
+
+--S 617 of 801
+a0:=integrate(t0,x)
+--E 617
+
+--S 618 of 801
+m0:=a0-r0
+--E 618
+
+--S 619 of 801
+d0:=normalize(D(m0,x))
+--E 619
+
+--S 620 of 801
+t0:=(1+x^(1/3))/(1+sqrt(x))
+--E 620
+
+--S 621 of 801
+r0:=-3*x^(1/3)+6/5*x^(5/6)-4*log(1+x^(1/6))-log(1-x^(1/6)+x^(1/3))-2*atan((1-2*x^(1/6))/sqrt(3))*sqrt(3)+2*sqrt(x)
+--E 621
+
+--S 622 of 801
+a0:=integrate(t0,x)
+--E 622
+
+--S 623 of 801
+m0:=a0-r0
+--E 623
+
+--S 624 of 801
+d0:=normalize(D(m0,x))
+--E 624
+
+--S 625 of 801
+t0:=(1+x^(1/3))/(1+x^(1/4))
+--E 625
+
+--S 626 of 801
+r0:=12*x^(1/12)+4*x^(1/4)-3*x^(1/3)+12/7*x^(7/12)+4/3*x^(3/4)-6/5*x^(5/6)+12/13*x^(13/12)-8*log(1+x^(1/12))-2*log(1-x^(1/12)+x^(1/6))+4*atan((1-2*x^(1/12))/sqrt(3))*sqrt(3)-2*sqrt(x)
+--E 626
+
+--S 627 of 801
+a0:=integrate(t0,x)
+--E 627
+
+--S 628 of 801
+m0:=a0-r0
+--E 628
+
+--S 629 of 801
+d0:=normalize(D(m0,x))
+--E 629
+
+--S 630 of 801
+t0:=x^2/(-1+x^2+sqrt(1-x^2))
+--E 630
+
+--S 631 of 801
+r0:=x+asin(x)
+--E 631
+
+--S 632 of 801
+a0:=integrate(t0,x)
+--E 632
+
+--S 633 of 801
+m0:=a0-r0
+--E 633
+
+--S 634 of 801
+d0:=normalize(D(m0,x))
+--E 634
+
+--S 635 of 801
+t0:=sqrt((1+x)/x)
+--E 635
+
+--S 636 of 801
+r0:=atanh(sqrt(1+1/x))+x*sqrt(1+1/x)
+--E 636
+
+--S 637 of 801
+a0:=integrate(t0,x)
+--E 637
+
+--S 638 of 801
+m0:=a0-r0
+--E 638
+
+--S 639 of 801
+d0:=normalize(D(m0,x))
+--E 639
+
+--S 640 of 801
+t0:=sqrt((1-x)/x)
+--E 640
+
+--S 641 of 801
+r0:=-atan(sqrt(-1+1/x))+x*sqrt(-1+1/x)
+--E 641
+
+--S 642 of 801
+a0:=integrate(t0,x)
+--E 642
+
+--S 643 of 801
+m0:=a0-r0
+--E 643
+
+--S 644 of 801
+d0:=normalize(D(m0,x))
+--E 644
+
+--S 645 of 801
+t0:=sqrt((-1+x)/x)
+--E 645
+
+--S 646 of 801
+r0a:=-asinh(sqrt(-1+x))+sqrt(-1+x)*sqrt(x)
+--E 646
+
+--S 647 of 801
+r0b:=-atanh(sqrt(1+(-1)/x))+x*sqrt(1+(-1)/x)
+--E 647
+
+--S 648 of 801
+a0:=integrate(t0,x)
+--E 648
+
+--S 649 of 801
+m0a:=a0-r0a
+--E 649
+
+--S 650 of 801
+d0a:=D(m0a,x)
+--E 650
+
+--S 651 of 801
+m0b:=a0-r0b
+--E 651
+
+--S 652 of 801
+d0b:=D(m0b,x)
+--E 652
+
+--S 653 of 801
+t0:=sqrt((1+x)/x)/x
+--E 653
+
+--S 654 of 801
+r0:=2*atanh(sqrt(1+1/x))-2*sqrt(1+1/x)
+--E 654
+
+--S 655 of 801
+a0:=integrate(t0,x)
+--E 655
+
+--S 656 of 801
+m0:=a0-r0
+--E 656
+
+--S 657 of 801
+d0:=normalize(D(m0,x))
+--E 657
+
+--S 658 of 801
+t0:=sqrt(x/(1+x))
+--E 658
+
+--S 659 of 801
+r0:=-asinh(sqrt(x))+sqrt(x)*sqrt(1+x)
+--E 659
+
+--S 660 of 801
+a0:=integrate(t0,x)
+--E 660
+
+--S 661 of 801
+m0:=a0-r0
+--E 661
+
+--S 662 of 801
+d0:=normalize(D(m0,x))
+--E 662
+
+--S 663 of 801
+t0:=1/sqrt((-1-x)/x)
+--E 663
+
+--S 664 of 801
+r0:=atan(sqrt(-1+(-1)/x))-x*sqrt(-1+(-1)/x)
+--E 664
+
+--S 665 of 801
+a0:=integrate(t0,x)
+--E 665
+
+--S 666 of 801
+m0:=a0-r0
+--E 666
+
+--S 667 of 801
+d0:=normalize(D(m0,x))
+--E 667
+
+--S 668 of 801
+t0:=sqrt((4-x)*x)
+--E 668
+
+--S 669 of 801
+r0:=-2*asin(1-1/2*x)-sqrt(4*x-x^2)+1/2*x*sqrt(4*x-x^2)
+--E 669
+
+--S 670 of 801
+a0:=integrate(t0,x)
+--E 670
+
+--S 671 of 801
+m0:=a0-r0
+--E 671
+
+--S 672 of 801
+d0:=normalize(D(m0,x))
+--E 672
+
+--S 673 of 801
+t0:=1/sqrt((1-x)*x)
+--E 673
+
+--S 674 of 801
+r0:=-asin(1-2*x)
+--E 674
+
+--S 675 of 801
+a0:=integrate(t0,x)
+--E 675
+
+--S 676 of 801
+m0:=a0-r0
+--E 676
+
+--S 677 of 801
+d0:=normalize(D(m0,x))
+--E 677
+
+--S 678 of 801
+t0:=x/(x*(2+x))^(3/2)
+--E 678
+
+--S 679 of 801
+r0:=x/sqrt(2*x+x^2)
+--E 679
+
+--S 680 of 801
+a0:=integrate(t0,x)
+--E 680
+
+--S 681 of 801
+m0:=a0-r0
+--E 681
+
+--S 682 of 801
+d0:=normalize(D(m0,x))
+--E 682
+
+--S 683 of 801
+t0:=1/(1-x^2+sqrt(5)+x^2*sqrt(5))
+--E 683
+
+--S 684 of 801
+r0:=1/2*atan(x*sqrt(2/(3+sqrt(5))))
+--E 684
+
+--S 685 of 801
+a0:=integrate(t0,x)
+--E 685
+
+--S 686 of 801
+m0:=a0-r0
+--E 686
+
+--S 687 of 801
+d0:=normalize(D(m0,x))
+--E 687
+
+--S 688 of 801
+t0:=1/(b*x+c*(d+e*x)^2)
+--E 688
+
+--S 689 of 801
+r0:=-2*atanh((b+2*c*d*e+2*c*e^2*x)/(sqrt(b)*sqrt(b+4*c*d*e)))/(sqrt(b)*sqrt(b+4*c*d*e))
+--E 689
+
+--S 690 of 801
+a0:=integrate(t0,x)
+--E 690
+
+--S 691 of 801
+m0a:=a0.1-r0
+--E 691
+
+--S 692 of 801
+d0a:=normalize(D(m0a,x))
+--E 692
+
+--S 693 of 801
+m0b:=a0.2-r0
+--E 693
+
+--S 694 of 801
+d0b:=normalize(D(m0b,x))
+--E 694
+
+--S 695 of 801
+t0:=1/(a+b*x+c*(d+e*x)^2)
+--E 695
+
+--S 696 of 801
+r0:=-2*atanh((b+2*c*d*e+2*c*e^2*x)/sqrt(b^2+4*b*c*d*e-4*a*c*e^2))/sqrt(b^2+4*b*c*d*e-4*a*c*e^2)
+--E 696
+
+--S 697 of 801
+a0:=integrate(t0,x)
+--E 697
+
+--S 698 of 801
+m0a:=a0.1-r0
+--E 698
+
+--S 699 of 801
+d0a:=normalize(D(m0a,x))
+--E 699
+
+--S 700 of 801
+m0b:=a0.2-r0
+--E 700
+
+--S 701 of 801
+d0b:=normalize(D(m0b,x))
+--E 701
+
+--S 702 of 801
+t0:=sqrt((b-x)*(-a+x))
+--E 702
+
+--S 703 of 801
+r0:=-1/8*(a-b)^2*atan(1/2*(a+b-2*x)/sqrt(-a*b+(a+b)*x-x^2))-1/4*(a+b-2*x)*sqrt(-a*b+(a+b)*x-x^2)
+--E 703
+
+--S 704 of 801
+a0:=integrate(t0,x)
+--E 704
+
+--S 705 of 801
+m0:=a0-r0
+--E 705
+
+--S 706 of 801
+d0:=normalize(D(m0,x))
+--E 706
+
+--S 707 of 801
+t0:=1/sqrt((b-x)*(-a+x))
+--E 707
+
+--S 708 of 801
+r0:=-atan(1/2*(a+b-2*x)/sqrt(-a*b+(a+b)*x-x^2))
+--E 708
+
+--S 709 of 801
+a0:=integrate(t0,x)
+--E 709
+
+--S 710 of 801
+m0:=a0-r0
+--E 710
+
+--S 711 of 801
+d0:=normalize(D(m0,x))
+--E 711
+
+--S 712 of 801
+t0:=sqrt((1-x^2)*(3+x^2))
+--E 712
+
+--S 713 of 801
+--r0:=-2*elliptic_e(asin(x),-1/3)/sqrt(3)+4*elliptic_f(asin(x),-1/3)/sqrt(3)+1/3*x*sqrt(3-2*x^2-x^4)
+--E 713
+
+--S 714 of 801
+--a0:=integrate(t0,x)
+--E 714
+
+--S 715 of 801
+--m0:=a0-r0
+--E 715
+
+--S 716 of 801
+--d0:=normalize(D(m0,x))
+--E 716
+
+--S 717 of 801
+t0:=1/sqrt((1-x^2)*(3+x^2))
+--E 717
+
+--S 718 of 801
+--r0:=elliptic_f(asin(x),-1/3)/sqrt(3)
+--E 718
+
+--S 719 of 801
+--a0:=integrate(t0,x)
+--E 719
+
+--S 720 of 801
+--m0:=a0-r0
+--E 720
+
+--S 721 of 801
+--d0:=normalize(D(m0,x))
+--E 721
+
+--S 722 of 801
+t0:=x^2/(1+(-1+x^2)^2)
+--E 722
+
+--S 723 of 801
+r0:=-1/2*atan((-2*x+sqrt(2*(1+sqrt(2))))/sqrt(2*(-1+sqrt(2))))*sqrt(1/2*(1+sqrt(2)))+1/2*atan((2*x+sqrt(2*(1+sqrt(2))))/sqrt(2*(-1+sqrt(2))))*sqrt(1/2*(1+sqrt(2)))+1/4*log(x^2+sqrt(2)-x*sqrt(2*(1+sqrt(2))))/sqrt(2*(1+sqrt(2)))-1/4*log(x^2+sqrt(2)+x*sqrt(2*(1+sqrt(2))))/sqrt(2*(1+sqrt(2)))
+--E 723
+
+--S 724 of 801
+a0:=integrate(t0,x)
+--E 724
+
+--S 725 of 801
+m0:=a0-r0
+--E 725
+
+--S 726 of 801
+d0:=normalize(D(m0,x))
+--E 726
+
+--S 727 of 801
+t0:=1/sqrt(a*x+b*x^2)
+--E 727
+
+--S 728 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 728
+
+--S 729 of 801
+a0:=integrate(t0,x)
+--E 729
+
+--S 730 of 801
+m0a:=a0.1-r0
+--E 730
+
+--S 731 of 801
+d0a:=normalize(D(m0a,x))
+--E 731
+
+--S 732 of 801
+m0b:=a0.2-r0
+--E 732
+
+--S 733 of 801
+d0b:=normalize(D(m0b,x))
+--E 733
+
+--S 734 of 801
+t0:=1/sqrt(x*(a+b*x))
+--E 734
+
+--S 735 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 735
+
+--S 736 of 801
+a0:=integrate(t0,x)
+--E 736
+
+--S 737 of 801
+m0a:=a0.1-r0
+--E 737
+
+--S 738 of 801
+d0a:=normalize(D(m0a,x))
+--E 738
+
+--S 739 of 801
+m0b:=a0.2-r0
+--E 739
+
+--S 740 of 801
+d0b:=normalize(D(m0b,x))
+--E 740
+
+--S 741 of 801
+t0:=1/sqrt((b+a/x)*x^2)
+--E 741
+
+--S 742 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 742
+
+--S 743 of 801
+a0:=integrate(t0,x)
+--E 743
+
+--S 744 of 801
+m0a:=a0.1-r0
+--E 744
+
+--S 745 of 801
+d0a:=normalize(D(m0a,x))
+--E 745
+
+--S 746 of 801
+m0b:=a0.2-r0
+--E 746
+
+--S 747 of 801
+d0b:=normalize(D(m0b,x))
+--E 747
+
+--S 748 of 801
+t0:=1/sqrt((a/x^2+b/x)*x^3)
+--E 748
+
+--S 749 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 749
+
+--S 750 of 801
+a0:=integrate(t0,x)
+--E 750
+
+--S 751 of 801
+m0a:=a0.1-r0
+--E 751
+
+--S 752 of 801
+d0a:=normalize(D(m0a,x))
+--E 752
+
+--S 753 of 801
+m0b:=a0.2-r0
+--E 753
+
+--S 754 of 801
+d0b:=normalize(D(m0b,x))
+--E 754
+
+--S 755 of 801
+t0:=1/sqrt((a*x^2+b*x^3)/x)
+--E 755
+
+--S 756 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 756
+
+--S 757 of 801
+a0:=integrate(t0,x)
+--E 757
+
+--S 758 of 801
+m0a:=a0.1-r0
+--E 758
+
+--S 759 of 801
+d0a:=normalize(D(m0a,x))
+--E 759
+
+--S 760 of 801
+m0b:=a0.2-r0
+--E 760
+
+--S 761 of 801
+d0b:=normalize(D(m0b,x))
+--E 761
+
+--S 762 of 801
+t0:=1/sqrt((a*x^3+b*x^4)/x^2)
+--E 762
+
+--S 763 of 801
+r0:=2*atanh(x*sqrt(b)/sqrt(a*x+b*x^2))/sqrt(b)
+--E 763
+
+--S 764 of 801
+a0:=integrate(t0,x)
+--E 764
+
+--S 765 of 801
+m0a:=a0.1-r0
+--E 765
+
+--S 766 of 801
+d0a:=normalize(D(m0a,x))
+--E 766
+
+--S 767 of 801
+m0b:=a0.2-r0
+--E 767
+
+--S 768 of 801
+d0b:=normalize(D(m0b,x))
+--E 768
+
+--S 769 of 801
+t0:=1/sqrt(a*c*x+b*c*x^2)
+--E 769
+
+--S 770 of 801
+r0:=2*atanh(x*sqrt(b)*sqrt(c)/sqrt(a*c*x+b*c*x^2))/(sqrt(b)*sqrt(c))
+--E 770
+
+--S 771 of 801
+a0:=integrate(t0,x)
+--E 771
+
+--S 772 of 801
+m0a:=a0.1-r0
+--E 772
+
+--S 773 of 801
+d0a:=normalize(D(m0a,x))
+--E 773
+
+--S 774 of 801
+m0b:=a0.2-r0
+--E 774
+
+--S 775 of 801
+d0b:=normalize(D(m0b,x))
+--E 775
+
+--S 776 of 801
+t0:=1/sqrt(c*(a*x+b*x^2))
+--E 776
+
+--S 777 of 801
+r0:=2*atanh(x*sqrt(b)*sqrt(c)/sqrt(a*c*x+b*c*x^2))/(sqrt(b)*sqrt(c))
+--E 777
+
+--S 778 of 801
+a0:=integrate(t0,x)
+--E 778
+
+--S 779 of 801
+m0a:=a0.1-r0
+--E 779
+
+--S 780 of 801
+d0a:=normalize(D(m0a,x))
+--E 780
+
+--S 781 of 801
+m0b:=a0.2-r0
+--E 781
+
+--S 782 of 801
+d0b:=normalize(D(m0b,x))
+--E 782
+
+--S 783 of 801
+t0:=1/sqrt(c*x*(a+b*x))
+--E 783
+
+--S 784 of 801
+r0:=2*atanh(x*sqrt(b)*sqrt(c)/sqrt(a*c*x+b*c*x^2))/(sqrt(b)*sqrt(c))
+--E 784
+
+--S 785 of 801
+a0:=integrate(t0,x)
+--E 785
+
+--S 786 of 801
+m0a:=a0.1-r0
+--E 786
+
+--S 787 of 801
+d0a:=normalize(D(m0a,x))
+--E 787
+
+--S 788 of 801
+m0b:=a0.2-r0
+--E 788
+
+--S 789 of 801
+d0b:=normalize(D(m0b,x))
+--E 789
+
+--S 790 of 801
+t0:=1/sqrt(c*(b+a/x)*x^2)
+--E 790
+
+--S 791 of 801
+r0:=2*atanh(x*sqrt(b)*sqrt(c)/sqrt(a*c*x+b*c*x^2))/(sqrt(b)*sqrt(c))
+--E 791
+
+--S 792 of 801
+a0:=integrate(t0,x)
+--E 792
+
+--S 793 of 801
+m0a:=a0.1-r0
+--E 793
+
+--S 794 of 801
+d0a:=normalize(D(m0a,x))
+--E 794
+
+--S 795 of 801
+m0b:=a0.2-r0
+--E 795
+
+--S 796 of 801
+d0b:=normalize(D(m0b,x))
+--E 796
+
+--S 797 of 801
+t0:=(a-c+b*x)/((1+x^2)*sqrt(a+b*x+c*x^2))
+--E 797
+
+--S 798 of 801
+r0:=-1/2*%i*atanh(1/2*(2*a-%i*b+(b-2*%i*c)*x)/(sqrt(a-%i*b-c)*sqrt(a+b*x+c*x^2)))*sqrt(a-%i*b-c)+1/2*%i*atanh(1/2*(2*a+%i*b+(b+2*%i*c)*x)/(sqrt(a+%i*b-c)*sqrt(a+b*x+c*x^2)))*sqrt(a+%i*b-c)
+--E 798
+
+--S 799 of 801
+a0:=integrate(t0,x)
+--E 799
+
+--S 800 of 801
+m0:=a0-r0
+--E 800
+
+--S 801 of 801
+d0:=D(m0,x)
+--E 801
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder23.input.pamphlet b/src/input/richder23.input.pamphlet
new file mode 100644
index 0000000..4f7f9f4
--- /dev/null
+++ b/src/input/richder23.input.pamphlet
@@ -0,0 +1,9984 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder23.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m Px (a+b x^n)^p.input|
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder23.output
+)spool richder23.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 567
+t0:=a/(d+e*x^3)
+--R 
+--R
+--R            a
+--R   (1)  --------
+--R           3
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1
+
+--S 2 of 567
+r0:=1/3*a*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*e^(1/3))-1/6*a*log(d^(2/3)-_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(2/3)*e^(1/3))-a*atan((d^(1/3)-_
+   2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+     3+-+   3+-+
+--R       - a\|3 log(x  \|e  - x\|d \|e  + \|d  ) + 2a\|3 log(x\|e  + \|d )
+--R     + 
+--R                 3+-+   3+-+
+--R               2x\|e  - \|d
+--R       6a atan(-------------)
+--R                   +-+3+-+
+--R                  \|3 \|d
+--R  /
+--R       +-+3+-+2 3+-+
+--R     6\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 567
+t0:=b*x/(d+e*x^3)
+--R 
+--R
+--R           b x
+--R   (1)  --------
+--R           3
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 4
+
+--S 5 of 567
+r0:=-1/3*b*log(d^(1/3)+e^(1/3)*x)/(d^(1/3)*e^(2/3))+1/6*b*log(d^(2/3)-_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(1/3)*e^(2/3))-b*atan((d^(1/3)-_
+   2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(1/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R         +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+     3+-+   3+-+
+--R       b\|3 log(x  \|e  - x\|d \|e  + \|d  ) - 2b\|3 log(x\|e  + \|d )
+--R     + 
+--R                 3+-+   3+-+
+--R               2x\|e  - \|d
+--R       6b atan(-------------)
+--R                   +-+3+-+
+--R                  \|3 \|d
+--R  /
+--R       +-+3+-+3+-+2
+--R     6\|3 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 567
+t0:=(a+b*x)/(d+e*x^3)
+--R 
+--R
+--R         b x + a
+--R   (1)  --------
+--R           3
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 7
+
+--S 8 of 567
+r0:=-1/3*(b*d^(1/3)-a*e^(1/3))*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*e^(2/3))-_
+   1/6*(a-b*d^(1/3)/e^(1/3))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(1/3))-(b*d^(1/3)+a*e^(1/3))*atan((d^(1/3)-2*e^(1/3)*x)/_
+   (d^(1/3)*sqrt(3)))/(d^(2/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- a\|3 \|e  + b\|3 \|d )log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R           +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (2a\|3 \|e  - 2b\|3 \|d )log(x\|e  + \|d )
+--R     + 
+--R                               3+-+   3+-+
+--R          3+-+     3+-+      2x\|e  - \|d
+--R       (6a\|e  + 6b\|d )atan(-------------)
+--R                                 +-+3+-+
+--R                                \|3 \|d
+--R  /
+--R       +-+3+-+2 3+-+2
+--R     6\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 567
+t0:=c*x^2/(d+e*x^3)
+--R 
+--R
+--R             2
+--R          c x
+--R   (1)  --------
+--R           3
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 10
+
+--S 11 of 567
+r0:=1/3*c*log(d+e*x^3)/e
+--R 
+--R
+--R                 3
+--R        c log(e x  + d)
+--R   (2)  ---------------
+--R               3e
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 567
+t0:=(a+c*x^2)/(d+e*x^3)
+--R 
+--R
+--R           2
+--R        c x  + a
+--R   (1)  --------
+--R           3
+--R        e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 13
+
+--S 14 of 567
+r0:=1/3*a*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*e^(1/3))-1/6*a*log(d^(2/3)-_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(2/3)*e^(1/3))+1/3*c*log(d+e*x^3)/e-_
+   a*atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R             +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+     3+-+   3+-+
+--R       - a e\|3 log(x  \|e  - x\|d \|e  + \|d  ) + 2a e\|3 log(x\|e  + \|d )
+--R     + 
+--R                   3+-+   3+-+
+--R                 2x\|e  - \|d        +-+       3     3+-+2 3+-+
+--R       6a e atan(-------------) + 2c\|3 log(e x  + d)\|d   \|e
+--R                     +-+3+-+
+--R                    \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 567
+t0:=(b*x+c*x^2)/(d+e*x^3)
+--R 
+--R
+--R           2
+--R        c x  + b x
+--R   (1)  ----------
+--R            3
+--R         e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 16
+
+--S 17 of 567
+r0:=-1/3*b*log(d^(1/3)+e^(1/3)*x)/(d^(1/3)*e^(2/3))+1/6*b*log(d^(2/3)-_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(1/3)*e^(2/3))+1/3*c*log(d+e*x^3)/e-_
+   b*atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(1/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+     3+-+   3+-+
+--R       b e\|3 log(x  \|e  - x\|d \|e  + \|d  ) - 2b e\|3 log(x\|e  + \|d )
+--R     + 
+--R                   3+-+   3+-+
+--R                 2x\|e  - \|d        +-+       3     3+-+3+-+2
+--R       6b e atan(-------------) + 2c\|3 log(e x  + d)\|d \|e
+--R                     +-+3+-+
+--R                    \|3 \|d
+--R  /
+--R        +-+3+-+3+-+2
+--R     6e\|3 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 567
+t0:=(a+b*x+c*x^2)/(d+e*x^3)
+--R 
+--R
+--R           2
+--R        c x  + b x + a
+--R   (1)  --------------
+--R              3
+--R           e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 19
+
+--S 20 of 567
+r0:=-1/3*(b*d^(1/3)-a*e^(1/3))*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*e^(2/3))-_
+   1/6*(a-b*d^(1/3)/e^(1/3))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(1/3))+1/3*c*log(d+e*x^3)/e-(b*d^(1/3)+a*e^(1/3))*_
+   atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              +-+3+-+       +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- a e\|3 \|e  + b e\|3 \|d )log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R             +-+3+-+        +-+3+-+      3+-+   3+-+
+--R       (2a e\|3 \|e  - 2b e\|3 \|d )log(x\|e  + \|d )
+--R     + 
+--R                                   3+-+   3+-+
+--R            3+-+       3+-+      2x\|e  - \|d        +-+       3     3+-+2 3+-+2
+--R       (6a e\|e  + 6b e\|d )atan(-------------) + 2c\|3 log(e x  + d)\|d   \|e
+--R                                     +-+3+-+
+--R                                    \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 567
+t0:=a/(d-e*x^3)
+--R 
+--R
+--R              a
+--R   (1)  - --------
+--R             3
+--R          e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 22
+
+--S 23 of 567
+r0:=-1/3*a*log(d^(1/3)-e^(1/3)*x)/(d^(2/3)*e^(1/3))+1/6*a*log(d^(2/3)+_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(2/3)*e^(1/3))+a*atan((d^(1/3)+_
+   2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R         +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+       3+-+   3+-+
+--R       a\|3 log(x  \|e  + x\|d \|e  + \|d  ) - 2a\|3 log(- x\|e  + \|d )
+--R     + 
+--R                 3+-+   3+-+
+--R               2x\|e  + \|d
+--R       6a atan(-------------)
+--R                   +-+3+-+
+--R                  \|3 \|d
+--R  /
+--R       +-+3+-+2 3+-+
+--R     6\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 567
+t0:=b*x/(d-e*x^3)
+--R 
+--R
+--R             b x
+--R   (1)  - --------
+--R             3
+--R          e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 25
+
+--S 26 of 567
+r0:=-1/3*b*log(d^(1/3)-e^(1/3)*x)/(d^(1/3)*e^(2/3))+1/6*b*log(d^(2/3)+_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(1/3)*e^(2/3))-b*atan((d^(1/3)+_
+   2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(1/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R         +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+       3+-+   3+-+
+--R       b\|3 log(x  \|e  + x\|d \|e  + \|d  ) - 2b\|3 log(- x\|e  + \|d )
+--R     + 
+--R                   3+-+   3+-+
+--R                 2x\|e  + \|d
+--R       - 6b atan(-------------)
+--R                     +-+3+-+
+--R                    \|3 \|d
+--R  /
+--R       +-+3+-+3+-+2
+--R     6\|3 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 567
+t0:=(a+b*x)/(d-e*x^3)
+--R 
+--R
+--R        - b x - a
+--R   (1)  ---------
+--R            3
+--R         e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 28
+
+--S 29 of 567
+r0:=-1/3*(b*d^(1/3)+a*e^(1/3))*log(d^(1/3)-e^(1/3)*x)/(d^(2/3)*e^(2/3))+_
+   1/6*(b*d^(1/3)+a*e^(1/3))*log(d^(2/3)+d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(2/3))-(b*d^(1/3)-a*e^(1/3))*atan((d^(1/3)+2*e^(1/3)*x)/_
+   (d^(1/3)*sqrt(3)))/(d^(2/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (a\|3 \|e  + b\|3 \|d )log(x  \|e  + x\|d \|e  + \|d  )
+--R     + 
+--R             +-+3+-+      +-+3+-+        3+-+   3+-+
+--R       (- 2a\|3 \|e  - 2b\|3 \|d )log(- x\|e  + \|d )
+--R     + 
+--R                               3+-+   3+-+
+--R          3+-+     3+-+      2x\|e  + \|d
+--R       (6a\|e  - 6b\|d )atan(-------------)
+--R                                 +-+3+-+
+--R                                \|3 \|d
+--R  /
+--R       +-+3+-+2 3+-+2
+--R     6\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 567
+t0:=c*x^2/(d-e*x^3)
+--R 
+--R
+--R               2
+--R            c x
+--R   (1)  - --------
+--R             3
+--R          e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 31
+
+--S 32 of 567
+r0:=-1/3*c*log(d-e*x^3)/e
+--R 
+--R
+--R                     3
+--R          c log(- e x  + d)
+--R   (2)  - -----------------
+--R                  3e
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 567
+t0:=(a+c*x^2)/(d-e*x^3)
+--R 
+--R
+--R             2
+--R        - c x  - a
+--R   (1)  ----------
+--R            3
+--R         e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 34
+
+--S 35 of 567
+r0:=-1/3*a*log(d^(1/3)-e^(1/3)*x)/(d^(2/3)*e^(1/3))+1/6*a*log(d^(2/3)+_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(2/3)*e^(1/3))-1/3*c*log(d-e*x^3)/e+_
+   a*atan((d^(1/3)+2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+       3+-+   3+-+
+--R       a e\|3 log(x  \|e  + x\|d \|e  + \|d  ) - 2a e\|3 log(- x\|e  + \|d )
+--R     + 
+--R                   3+-+   3+-+
+--R                 2x\|e  + \|d        +-+         3     3+-+2 3+-+
+--R       6a e atan(-------------) - 2c\|3 log(- e x  + d)\|d   \|e
+--R                     +-+3+-+
+--R                    \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 567
+t0:=(b*x+c*x^2)/(d-e*x^3)
+--R 
+--R
+--R             2
+--R        - c x  - b x
+--R   (1)  ------------
+--R             3
+--R          e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 37
+
+--S 38 of 567
+r0:=-1/3*b*log(d^(1/3)-e^(1/3)*x)/(d^(1/3)*e^(2/3))+1/6*b*log(d^(2/3)+_
+   d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/(d^(1/3)*e^(2/3))-1/3*c*log(d-e*x^3)/e-_
+   b*atan((d^(1/3)+2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(1/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2         +-+       3+-+   3+-+
+--R       b e\|3 log(x  \|e  + x\|d \|e  + \|d  ) - 2b e\|3 log(- x\|e  + \|d )
+--R     + 
+--R                     3+-+   3+-+
+--R                   2x\|e  + \|d        +-+         3     3+-+3+-+2
+--R       - 6b e atan(-------------) - 2c\|3 log(- e x  + d)\|d \|e
+--R                       +-+3+-+
+--R                      \|3 \|d
+--R  /
+--R        +-+3+-+3+-+2
+--R     6e\|3 \|d \|e
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 567
+t0:=(a+b*x+c*x^2)/(d-e*x^3)
+--R 
+--R
+--R             2
+--R        - c x  - b x - a
+--R   (1)  ----------------
+--R               3
+--R            e x  - d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 40
+
+--S 41 of 567
+r0:=-1/3*(b*d^(1/3)+a*e^(1/3))*log(d^(1/3)-e^(1/3)*x)/(d^(2/3)*e^(2/3))+_
+   1/6*(b*d^(1/3)+a*e^(1/3))*log(d^(2/3)+d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(2/3))-1/3*c*log(d-e*x^3)/e-(b*d^(1/3)-a*e^(1/3))*_
+   atan((d^(1/3)+2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +-+3+-+       +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (a e\|3 \|e  + b e\|3 \|d )log(x  \|e  + x\|d \|e  + \|d  )
+--R     + 
+--R               +-+3+-+        +-+3+-+        3+-+   3+-+
+--R       (- 2a e\|3 \|e  - 2b e\|3 \|d )log(- x\|e  + \|d )
+--R     + 
+--R                                 3+-+   3+-+
+--R          3+-+       3+-+      2x\|e  + \|d        +-+         3     3+-+2 3+-+2
+--R     (6a e\|e  - 6b e\|d )atan(-------------) - 2c\|3 log(- e x  + d)\|d   \|e
+--R                                   +-+3+-+
+--R                                  \|3 \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 567
+t0:=-C*x^2/(a+b*x^3)+(B*x+C*x^2)/(a+b*x^3)
+--R 
+--R
+--R           B x
+--R   (1)  --------
+--R           3
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 43
+
+--S 44 of 567
+r0:=-1/3*B*log(a^(1/3)+b^(1/3)*x)/(a^(1/3)*b^(2/3))+1/6*B*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(1/3)*b^(2/3))-B*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(1/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R         +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+     3+-+   3+-+
+--R       B\|3 log(x  \|b  - x\|a \|b  + \|a  ) - 2B\|3 log(x\|b  + \|a )
+--R     + 
+--R                 3+-+   3+-+
+--R               2x\|b  - \|a
+--R       6B atan(-------------)
+--R                   +-+3+-+
+--R                  \|3 \|a
+--R  /
+--R       +-+3+-+3+-+2
+--R     6\|3 \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 567
+t0:=-C*x^2/(a+b*x^3)+(A+C*x^2)/(a+b*x^3)
+--R 
+--R
+--R            A
+--R   (1)  --------
+--R           3
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 46
+
+--S 47 of 567
+r0:=1/3*A*log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*b^(1/3))-1/6*A*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(2/3)*b^(1/3))-A*atan((a^(1/3)-_
+   2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(1/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           +-+     2 3+-+2   3+-+3+-+   3+-+2       +-+     3+-+   3+-+
+--R       - A\|3 log(x  \|b  - x\|a \|b  + \|a  ) + 2A\|3 log(x\|b  + \|a )
+--R     + 
+--R                 3+-+   3+-+
+--R               2x\|b  - \|a
+--R       6A atan(-------------)
+--R                   +-+3+-+
+--R                  \|3 \|a
+--R  /
+--R       +-+3+-+2 3+-+
+--R     6\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 567
+t0:=-C*x^2/(a+b*x^3)+(A+B*x+C*x^2)/(a+b*x^3)
+--R 
+--R
+--R         B x + A
+--R   (1)  --------
+--R           3
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 49
+
+--S 50 of 567
+r0:=1/3*(A*b^(1/3)-a^(1/3)*B)*log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*b^(2/3))-_
+   1/6*(A-a^(1/3)*B/b^(1/3))*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(2/3)*b^(1/3))-(A*b^(1/3)+a^(1/3)*B)*atan((a^(1/3)-2*b^(1/3)*x)/_
+   (a^(1/3)*sqrt(3)))/(a^(2/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            +-+3+-+     +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- A\|3 \|b  + B\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R           +-+3+-+      +-+3+-+      3+-+   3+-+
+--R       (2A\|3 \|b  - 2B\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                               3+-+   3+-+
+--R          3+-+     3+-+      2x\|b  - \|a
+--R       (6A\|b  + 6B\|a )atan(-------------)
+--R                                 +-+3+-+
+--R                                \|3 \|a
+--R  /
+--R       +-+3+-+2 3+-+2
+--R     6\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 567
+t0:=(a+b*x)^2/(c+d*x^3)
+--R 
+--R
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R   (1)  ------------------
+--R                3
+--R             d x  + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 52
+
+--S 53 of 567
+r0:=-1/3*a*(2*b*c^(1/3)-a*d^(1/3))*log(c^(1/3)+d^(1/3)*x)/(c^(2/3)*d^(2/3))+_
+   1/6*a*(2*b*c^(1/3)-a*d^(1/3))*log(c^(2/3)-c^(1/3)*d^(1/3)*x+d^(2/3)*_
+   x^2)/(c^(2/3)*d^(2/3))+1/3*b^2*log(c+d*x^3)/d-a*(2*b*c^(1/3)+_
+   a*d^(1/3))*atan((c^(1/3)-2*d^(1/3)*x)/(c^(1/3)*sqrt(3)))/(c^(2/3)*_
+   d^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R           2  +-+3+-+          +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- a d\|3 \|d  + 2a b d\|3 \|c )log(x  \|d  - x\|c \|d  + \|c  )
+--R     + 
+--R          2  +-+3+-+          +-+3+-+      3+-+   3+-+
+--R       (2a d\|3 \|d  - 4a b d\|3 \|c )log(x\|d  + \|c )
+--R     + 
+--R                                      3+-+   3+-+
+--R          2 3+-+          3+-+      2x\|d  - \|c
+--R       (6a d\|d  + 12a b d\|c )atan(-------------)
+--R                                        +-+3+-+
+--R                                       \|3 \|c
+--R     + 
+--R         2 +-+       3     3+-+2 3+-+2
+--R       2b \|3 log(d x  + c)\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 567
+t0:=(a+b*x)^3/(c+d*x^3)
+--R 
+--R
+--R         3 3       2 2     2       3
+--R        b x  + 3a b x  + 3a b x + a
+--R   (1)  ----------------------------
+--R                     3
+--R                  d x  + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 55
+
+--S 56 of 567
+r0:=b^3*x/d-1/3*(b^3*c+3*a^2*b*c^(1/3)*d^(2/3)-a^3*d)*log(c^(1/3)+_
+   d^(1/3)*x)/(c^(2/3)*d^(4/3))+1/6*(b^3*c+3*a^2*b*c^(1/3)*d^(2/3)-_
+   a^3*d)*log(c^(2/3)-c^(1/3)*d^(1/3)*x+d^(2/3)*x^2)/(c^(2/3)*d^(4/3))+_
+   a*b^2*log(c+d*x^3)/d+(b^3*c-3*a^2*b*c^(1/3)*d^(2/3)-a^3*d)*_
+   atan((c^(1/3)-2*d^(1/3)*x)/(c^(1/3)*sqrt(3)))/(c^(2/3)*d^(4/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          2  +-+3+-+3+-+2       3     3   +-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (3a b\|3 \|c \|d   + (- a d + b c)\|3 )log(x  \|d  - x\|c \|d  + \|c  )
+--R     + 
+--R            2  +-+3+-+3+-+2      3      3   +-+      3+-+   3+-+
+--R       (- 6a b\|3 \|c \|d   + (2a d - 2b c)\|3 )log(x\|d  + \|c )
+--R     + 
+--R                                            3+-+   3+-+
+--R           2 3+-+3+-+2     3      3       2x\|d  - \|c
+--R       (18a b\|c \|d   + 6a d - 6b c)atan(-------------)
+--R                                              +-+3+-+
+--R                                             \|3 \|c
+--R     + 
+--R            2 +-+       3          3  +-+ 3+-+2 3+-+
+--R       (6a b \|3 log(d x  + c) + 6b x\|3 )\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 567
+t0:=(a+b*x)^4/(c+d*x^3)
+--R 
+--R
+--R         4 4       3 3     2 2 2     3       4
+--R        b x  + 4a b x  + 6a b x  + 4a b x + a
+--R   (1)  --------------------------------------
+--R                          3
+--R                       d x  + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 58
+
+--S 59 of 567
+r0:=4*a*b^3*x/d+1/2*b^4*x^2/d+1/3*(b*c^(1/3)*(b^3*c-4*a^3*d)-d^(1/3)*_
+   (4*a*b^3*c-a^4*d))*log(c^(1/3)+d^(1/3)*x)/(c^(2/3)*d^(5/3))-_
+   1/6*(b*c^(1/3)*(b^3*c-4*a^3*d)-d^(1/3)*(4*a*b^3*c-a^4*d))*log(c^(2/3)-_
+   c^(1/3)*d^(1/3)*x+d^(2/3)*x^2)/(c^(2/3)*d^(5/3))+2*a^2*b^2*_
+   log(c+d*x^3)/d+(b^4*c^(4/3)+4*a*b^3*c*d^(1/3)-4*a^3*b*c^(1/3)*d-_
+   a^4*d^(4/3))*atan((c^(1/3)-2*d^(1/3)*x)/(c^(1/3)*sqrt(3)))/_
+   (c^(2/3)*d^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              4        3   +-+3+-+      3       4   +-+3+-+
+--R         ((- a d + 4a b c)\|3 \|d  + (4a b d - b c)\|3 \|c )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|d  - x\|c \|d  + \|c  )
+--R     + 
+--R           4        3   +-+3+-+        3        4   +-+3+-+      3+-+   3+-+
+--R       ((2a d - 8a b c)\|3 \|d  + (- 8a b d + 2b c)\|3 \|c )log(x\|d  + \|c )
+--R     + 
+--R                                                           3+-+   3+-+
+--R           4         3  3+-+       3        4  3+-+      2x\|d  - \|c
+--R       ((6a d - 24a b c)\|d  + (24a b d - 6b c)\|c )atan(-------------)
+--R                                                             +-+3+-+
+--R                                                            \|3 \|c
+--R     + 
+--R           2 2 +-+       3           4 2        3   +-+ 3+-+2 3+-+2
+--R       (12a b \|3 log(d x  + c) + (3b x  + 24a b x)\|3 )\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 567
+t0:=(a+b*x)^2/(c-d*x^3)
+--R 
+--R
+--R           2 2             2
+--R        - b x  - 2a b x - a
+--R   (1)  --------------------
+--R                 3
+--R              d x  - c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 61
+
+--S 62 of 567
+r0:=-1/3*a*(2*b*c^(1/3)+a*d^(1/3))*log(c^(1/3)-d^(1/3)*x)/(c^(2/3)*d^(2/3))+_
+   1/6*a*(2*b*c^(1/3)+a*d^(1/3))*log(c^(2/3)+c^(1/3)*d^(1/3)*x+d^(2/3)*_
+   x^2)/(c^(2/3)*d^(2/3))-1/3*b^2*log(c-d*x^3)/d-a*(2*b*c^(1/3)-_
+   a*d^(1/3))*atan((c^(1/3)+2*d^(1/3)*x)/(c^(1/3)*sqrt(3)))/(c^(2/3)*_
+   d^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R         2  +-+3+-+          +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (a d\|3 \|d  + 2a b d\|3 \|c )log(x  \|d  + x\|c \|d  + \|c  )
+--R     + 
+--R            2  +-+3+-+          +-+3+-+        3+-+   3+-+
+--R       (- 2a d\|3 \|d  - 4a b d\|3 \|c )log(- x\|d  + \|c )
+--R     + 
+--R                                      3+-+   3+-+
+--R          2 3+-+          3+-+      2x\|d  + \|c
+--R       (6a d\|d  - 12a b d\|c )atan(-------------)
+--R                                        +-+3+-+
+--R                                       \|3 \|c
+--R     + 
+--R           2 +-+         3     3+-+2 3+-+2
+--R       - 2b \|3 log(- d x  + c)\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 567
+t0:=(a+b*x)^3/(c-d*x^3)
+--R 
+--R
+--R           3 3       2 2     2       3
+--R        - b x  - 3a b x  - 3a b x - a
+--R   (1)  ------------------------------
+--R                      3
+--R                   d x  - c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 64
+
+--S 65 of 567
+r0:=-b^3*x/d-1/3*(b^3*c+3*a^2*b*c^(1/3)*d^(2/3)+a^3*d)*log(c^(1/3)-_
+   d^(1/3)*x)/(c^(2/3)*d^(4/3))+1/6*(b^3*c+3*a^2*b*c^(1/3)*d^(2/3)+a^3*d)*_
+   log(c^(2/3)+c^(1/3)*d^(1/3)*x+d^(2/3)*x^2)/(c^(2/3)*d^(4/3))-a*b^2*_
+   log(c-d*x^3)/d+(b^3*c-3*a^2*b*c^(1/3)*d^(2/3)+a^3*d)*atan((c^(1/3)+_
+   2*d^(1/3)*x)/(c^(1/3)*sqrt(3)))/(c^(2/3)*d^(4/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          2  +-+3+-+3+-+2     3     3   +-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (3a b\|3 \|c \|d   + (a d + b c)\|3 )log(x  \|d  + x\|c \|d  + \|c  )
+--R     + 
+--R            2  +-+3+-+3+-+2        3      3   +-+        3+-+   3+-+
+--R       (- 6a b\|3 \|c \|d   + (- 2a d - 2b c)\|3 )log(- x\|d  + \|c )
+--R     + 
+--R                                              3+-+   3+-+
+--R             2 3+-+3+-+2     3      3       2x\|d  + \|c
+--R       (- 18a b\|c \|d   + 6a d + 6b c)atan(-------------)
+--R                                                +-+3+-+
+--R                                               \|3 \|c
+--R     + 
+--R              2 +-+         3          3  +-+ 3+-+2 3+-+
+--R       (- 6a b \|3 log(- d x  + c) - 6b x\|3 )\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 567
+t0:=(a+b*x)^4/(c-d*x^3)
+--R 
+--R
+--R           4 4       3 3     2 2 2     3       4
+--R        - b x  - 4a b x  - 6a b x  - 4a b x - a
+--R   (1)  ----------------------------------------
+--R                           3
+--R                        d x  - c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 67
+
+--S 68 of 567
+r0:=-4*a*b^3*x/d-1/2*b^4*x^2/d-1/3*(b*c^(1/3)*(b^3*c+4*a^3*d)+d^(1/3)*_
+   (4*a*b^3*c+a^4*d))*log(c^(1/3)-d^(1/3)*x)/(c^(2/3)*d^(5/3))+_
+   1/6*(b*c^(1/3)*(b^3*c+4*a^3*d)+d^(1/3)*(4*a*b^3*c+a^4*d))*_
+   log(c^(2/3)+c^(1/3)*d^(1/3)*x+d^(2/3)*x^2)/(c^(2/3)*d^(5/3))-_
+   2*a^2*b^2*log(c-d*x^3)/d-(b^4*c^(4/3)-4*a*b^3*c*d^(1/3)+_
+   4*a^3*b*c^(1/3)*d-a^4*d^(4/3))*atan((c^(1/3)+2*d^(1/3)*x)/_
+   (c^(1/3)*sqrt(3)))/(c^(2/3)*d^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R            4        3   +-+3+-+      3       4   +-+3+-+
+--R         ((a d + 4a b c)\|3 \|d  + (4a b d + b c)\|3 \|c )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|d  + x\|c \|d  + \|c  )
+--R     + 
+--R               4        3   +-+3+-+        3        4   +-+3+-+
+--R         ((- 2a d - 8a b c)\|3 \|d  + (- 8a b d - 2b c)\|3 \|c )
+--R      *
+--R                3+-+   3+-+
+--R         log(- x\|d  + \|c )
+--R     + 
+--R                                                             3+-+   3+-+
+--R           4         3  3+-+         3        4  3+-+      2x\|d  + \|c
+--R       ((6a d + 24a b c)\|d  + (- 24a b d - 6b c)\|c )atan(-------------)
+--R                                                               +-+3+-+
+--R                                                              \|3 \|c
+--R     + 
+--R             2 2 +-+         3             4 2        3   +-+ 3+-+2 3+-+2
+--R       (- 12a b \|3 log(- d x  + c) + (- 3b x  - 24a b x)\|3 )\|c   \|d
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6d\|3 \|c   \|d
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 567
+t0:=(a+b*x+c*x^2)^2/(d+e*x^3)
+--R 
+--R
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R   (1)  --------------------------------------------
+--R                             3
+--R                          e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 70
+
+--S 71 of 567
+r0:=2*b*c*x/e+1/2*c^2*x^2/e-1/3*(e^(1/3)*(2*b*c*d-a^2*e)-d^(1/3)*_
+   (c^2*d-2*a*b*e))*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*e^(5/3))+1/6*(e^(1/3)*_
+   (2*b*c*d-a^2*e)-d^(1/3)*(c^2*d-2*a*b*e))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+_
+   e^(2/3)*x^2)/(d^(2/3)*e^(5/3))+1/3*(b^2+2*a*c)*log(d+e*x^3)/e+_
+   (c^2*d^(4/3)+2*b*c*d*e^(1/3)-a*(2*b*d^(1/3)+a*e^(1/3))*e)*_
+   atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              2            +-+3+-+              2   +-+3+-+
+--R         ((- a e + 2b c d)\|3 \|e  + (2a b e - c d)\|3 \|d )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R           2            +-+3+-+                 2   +-+3+-+      3+-+   3+-+
+--R       ((2a e - 4b c d)\|3 \|e  + (- 4a b e + 2c d)\|3 \|d )log(x\|e  + \|d )
+--R     + 
+--R                                                           3+-+   3+-+
+--R           2            3+-+                2  3+-+      2x\|e  - \|d
+--R       ((6a e - 12b c d)\|e  + (12a b e - 6c d)\|d )atan(-------------)
+--R                                                             +-+3+-+
+--R                                                            \|3 \|d
+--R     + 
+--R                  2  +-+       3           2 2            +-+ 3+-+2 3+-+2
+--R       ((4a c + 2b )\|3 log(e x  + d) + (3c x  + 12b c x)\|3 )\|d   \|e
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6e\|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 567
+t0:=(a+b*x+c*x^2)^3/(d+e*x^3)
+--R 
+--R
+--R   (1)
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R  /
+--R        3
+--R     e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 73
+
+--S 74 of 567
+r0:=-(c^3*d-b^3*e-6*a*b*c*e)*x/e^2+3/2*c*(b^2+a*c)*x^2/e+b*c^2*x^3/e+_
+   1/4*c^3*x^4/e+1/3*(c^3*d^2-6*a*b*c*d*e-e*(b^3*d-a^3*e)+3*d^(1/3)*_
+   e^(2/3)*(b^2*c*d+a*c^2*d-a^2*b*e))*log(d^(1/3)+e^(1/3)*x)/(d^(2/3)*_
+   e^(7/3))-1/6*(c^3*d^2-6*a*b*c*d*e-e*(b^3*d-a^3*e)+3*d^(1/3)*e^(2/3)*_
+   (b^2*c*d+a*c^2*d-a^2*b*e))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(7/3))-(b*c^2*d-a*b^2*e-a^2*c*e)*log(d+e*x^3)/e^2-_
+   (c^3*d^2-3*b^2*c*d^(4/3)*e^(2/3)-3*a*c^2*d^(4/3)*e^(2/3)-b^3*d*e-_
+   6*a*b*c*d*e+3*a^2*b*d^(1/3)*e^(5/3)+a^3*e^2)*atan((d^(1/3)-_
+   2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(7/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              2             2     2     +-+3+-+3+-+2
+--R           (6a b e + (- 6a c  - 6b c)d)\|3 \|d \|e
+--R         + 
+--R                3 2                3         3 2  +-+
+--R           (- 2a e  + (12a b c + 2b )d e - 2c d )\|3
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R                 2            2      2     +-+3+-+3+-+2
+--R           (- 12a b e + (12a c  + 12b c)d)\|3 \|d \|e
+--R         + 
+--R              3 2                  3         3 2  +-+
+--R           (4a e  + (- 24a b c - 4b )d e + 4c d )\|3
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|e  + \|d )
+--R     + 
+--R               2              2      2    3+-+3+-+2      3 2
+--R           (36a b e + (- 36a c  - 36b c)d)\|d \|e   + 12a e
+--R         + 
+--R                           3          3 2
+--R           (- 72a b c - 12b )d e + 12c d
+--R      *
+--R                3+-+   3+-+
+--R              2x\|e  - \|d
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|d
+--R     + 
+--R                2         2          2   +-+       3
+--R           ((12a c + 12a b )e - 12b c d)\|3 log(e x  + d)
+--R         + 
+--R                 3   4        2   3         2      2     2
+--R               3c e x  + 12b c e x  + (18a c  + 18b c)e x
+--R             + 
+--R                              3        3
+--R               ((72a b c + 12b )e - 12c d)x
+--R          *
+--R              +-+
+--R             \|3
+--R      *
+--R         3+-+2 3+-+
+--R         \|d   \|e
+--R  /
+--R        2 +-+3+-+2 3+-+
+--R     12e \|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 567
+t0:=(a+b*x+c*x^2)^4/(d+e*x^3)
+--R 
+--R
+--R   (1)
+--R        4 8       3 7        3     2 2  6           2     3   5
+--R       c x  + 4b c x  + (4a c  + 6b c )x  + (12a b c  + 4b c)x
+--R     + 
+--R          2 2        2     4  4       2          3  3      3      2 2  2
+--R       (6a c  + 12a b c + b )x  + (12a b c + 4a b )x  + (4a c + 6a b )x
+--R     + 
+--R         3       4
+--R       4a b x + a
+--R  /
+--R        3
+--R     e x  + d
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 76
+
+--S 77 of 567
+r0:=-2*(3*b^2*c^2*d+2*a*c^3*d-2*a*b^3*e-6*a^2*b*c*e)*x/e^2-_
+   1/2*(4*b*c^3*d-b^4*e-12*a*b^2*c*e-6*a^2*c^2*e)*x^2/e^2-_
+   1/3*c*(c^3*d-4*b^3*e-12*a*b*c*e)*x^3/e^2+1/2*c^2*(3*b^2+2*a*c)*x^4/e+_
+   4/5*b*c^3*x^5/e+1/6*c^4*x^6/e+1/3*(e^(1/3)*(6*b^2*c^2*d^2+4*a*c^3*d^2-_
+   4*a*b^3*d*e-12*a^2*b*c*d*e+a^4*e^2)+d^(1/3)*(b^4*d*e+12*a*b^2*c*d*e+_
+   6*a^2*c^2*d*e-4*b*(c^3*d^2+a^3*e^2)))*log(d^(1/3)+e^(1/3)*x)/_
+   (d^(2/3)*e^(8/3))-1/6*(e^(1/3)*(6*b^2*c^2*d^2+4*a*c^3*d^2-4*a*b^3*d*e-_
+   12*a^2*b*c*d*e+a^4*e^2)+d^(1/3)*(b^4*d*e+12*a*b^2*c*d*e+6*a^2*c^2*d*e-_
+   4*b*(c^3*d^2+a^3*e^2)))*log(d^(2/3)-d^(1/3)*e^(1/3)*x+e^(2/3)*x^2)/_
+   (d^(2/3)*e^(8/3))+1/3*(c^4*d^2-12*a*b*c^2*d*e+6*a^2*b^2*e^2-4*c*e*_
+   (b^3*d-a^3*e))*log(d+e*x^3)/e^3-(b*d^(1/3)+a*e^(1/3))*(4*c^3*d^2+_
+   6*c^2*(b*d^(5/3)*e^(1/3)-a*d^(4/3)*e^(2/3))-12*a*b*c*d*e-_
+   e*(b^3*d+3*a*b^2*d^(2/3)*e^(1/3)-3*a^2*b*d^(1/3)*e^(2/3)-a^3*e))*_
+   atan((d^(1/3)-2*e^(1/3)*x)/(d^(1/3)*sqrt(3)))/(d^(2/3)*e^(8/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                4 3       2           3    2           3      2 2  2   +-+3+-+
+--R           (- 5a e  + (60a b c + 20a b )d e  + (- 20a c  - 30b c )d e)\|3 \|e
+--R         + 
+--R               3   3         2 2        2      4    2        3 2   +-+3+-+
+--R           (20a b e  + (- 30a c  - 60a b c - 5b )d e  + 20b c d e)\|3 \|d
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|e  - x\|d \|e  + \|d  )
+--R     + 
+--R               4 3          2           3    2         3      2 2  2   +-+3+-+
+--R           (10a e  + (- 120a b c - 40a b )d e  + (40a c  + 60b c )d e)\|3 \|e
+--R         + 
+--R                 3   3       2 2         2       4    2        3 2   +-+3+-+
+--R           (- 40a b e  + (60a c  + 120a b c + 10b )d e  - 40b c d e)\|3 \|d
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|e  + \|d )
+--R     + 
+--R               4 3          2            3    2          3       2 2  2  3+-+
+--R           (30a e  + (- 360a b c - 120a b )d e  + (120a c  + 180b c )d e)\|e
+--R         + 
+--R                3   3          2 2         2       4    2         3 2  3+-+
+--R           (120a b e  + (- 180a c  - 360a b c - 30b )d e  + 120b c d e)\|d
+--R      *
+--R                3+-+   3+-+
+--R              2x\|e  - \|d
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|d
+--R     + 
+--R                  3       2 2  2              2      3           4 2  +-+
+--R             ((40a c + 60a b )e  + (- 120a b c  - 40b c)d e + 10c d )\|3
+--R          *
+--R                    3
+--R             log(e x  + d)
+--R         + 
+--R                 4 2 6        3 2 5         3      2 2  2 4
+--R               5c e x  + 24b c e x  + (30a c  + 45b c )e x
+--R             + 
+--R                         2      3   2      4     3
+--R               ((120a b c  + 40b c)e  - 10c d e)x
+--R             + 
+--R                    2 2         2       4  2        3     2
+--R               ((90a c  + 180a b c + 15b )e  - 60b c d e)x
+--R             + 
+--R                     2            3  2            3       2 2
+--R               ((360a b c + 120a b )e  + (- 120a c  - 180b c )d e)x
+--R          *
+--R              +-+
+--R             \|3
+--R      *
+--R         3+-+2 3+-+2
+--R         \|d   \|e
+--R  /
+--R        3 +-+3+-+2 3+-+2
+--R     30e \|3 \|d   \|e
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 567
+t0:=(1+x)/(1+x^3)
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R         2
+--R        x  - x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 79
+
+--S 80 of 567
+r0:=-2*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                       +-+
+--R              (2x - 1)\|3
+--R        2atan(------------)
+--R                    3
+--R   (2)  -------------------
+--R                 +-+
+--R                \|3
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 567
+t0:=(1-x)/(1-x^3)
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R         2
+--R        x  + x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 82
+
+--S 83 of 567
+r0:=2*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                       +-+
+--R              (2x + 1)\|3
+--R        2atan(------------)
+--R                    3
+--R   (2)  -------------------
+--R                 +-+
+--R                \|3
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 567
+t0:=(1+x)/(1-x^3)
+--R 
+--R
+--R        - x - 1
+--R   (1)  -------
+--R          3
+--R         x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 85
+
+--S 86 of 567
+r0:=-2/3*log(1-x)+1/3*log(1+x+x^2)
+--R 
+--R
+--R             2
+--R        log(x  + x + 1) - 2log(- x + 1)
+--R   (2)  -------------------------------
+--R                       3
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 567
+t0:=(1-x)/(1+x^3)
+--R 
+--R
+--R        - x + 1
+--R   (1)  -------
+--R          3
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 88
+
+--S 89 of 567
+r0:=2/3*log(1+x)-1/3*log(1-x+x^2)
+--R 
+--R
+--R               2
+--R        - log(x  - x + 1) + 2log(x + 1)
+--R   (2)  -------------------------------
+--R                       3
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 567
+t0:=(3-x)/(1-x^3)
+--R 
+--R
+--R         x - 3
+--R   (1)  ------
+--R         3
+--R        x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 91
+
+--S 92 of 567
+r0:=-2/3*log(1-x)+1/3*log(1+x+x^2)+4*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                  +-+
+--R         +-+     2              +-+                      (2x + 1)\|3
+--R        \|3 log(x  + x + 1) - 2\|3 log(- x + 1) + 12atan(------------)
+--R                                                               3
+--R   (2)  --------------------------------------------------------------
+--R                                       +-+
+--R                                     3\|3
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 567
+t0:=(c+d*x)/(c^3+d^3*x^3)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         2 2            2
+--R        d x  - c d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 94
+
+--S 95 of 567
+r0:=-2*atan((c-2*d*x)/(c*sqrt(3)))/(c*d*sqrt(3))
+--R 
+--R
+--R                         +-+
+--R              (2d x - c)\|3
+--R        2atan(--------------)
+--R                    3c
+--R   (2)  ---------------------
+--R                   +-+
+--R               c d\|3
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 567
+t0:=(c-d*x)/(c^3-d^3*x^3)
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R         2 2            2
+--R        d x  + c d x + c
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 97
+
+--S 98 of 567
+r0:=2*atan((c+2*d*x)/(c*sqrt(3)))/(c*d*sqrt(3))
+--R 
+--R
+--R                         +-+
+--R              (2d x + c)\|3
+--R        2atan(--------------)
+--R                    3c
+--R   (2)  ---------------------
+--R                   +-+
+--R               c d\|3
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 567
+t0:=(1-x+3*x^2)/(-1+x^3)
+--R 
+--R
+--R          2
+--R        3x  - x + 1
+--R   (1)  -----------
+--R            3
+--R           x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 100
+
+--S 101 of 567
+r0:=log(1-x^3)-2*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                           +-+
+--R         +-+       3              (2x + 1)\|3
+--R        \|3 log(- x  + 1) - 2atan(------------)
+--R                                        3
+--R   (2)  ---------------------------------------
+--R                           +-+
+--R                          \|3
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 567
+t0:=(1+x+4*x^2)/(-1+x^3)
+--R 
+--R
+--R          2
+--R        4x  + x + 1
+--R   (1)  -----------
+--R            3
+--R           x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 103
+
+--S 104 of 567
+r0:=2*log(1-x)+log(1+x+x^2)
+--R 
+--R
+--R             2
+--R   (2)  log(x  + x + 1) + 2log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 567
+t0:=(-3+x^2)/(-1+x^3)
+--R 
+--R
+--R         2
+--R        x  - 3
+--R   (1)  ------
+--R         3
+--R        x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 106
+
+--S 107 of 567
+r0:=-2/3*log(1-x)+5/6*log(1+x+x^2)+atan((1+2*x)/sqrt(3))*sqrt(3)
+--R 
+--R
+--R                                                              +-+
+--R              2                              +-+     (2x + 1)\|3
+--R        5log(x  + x + 1) - 4log(- x + 1) + 6\|3 atan(------------)
+--R                                                           3
+--R   (2)  ----------------------------------------------------------
+--R                                     6
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 567
+t0:=(-1+x)/(1-x+x^2)
+--R 
+--R
+--R           x - 1
+--R   (1)  ----------
+--R         2
+--R        x  - x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 109
+
+--S 110 of 567
+r0:=1/2*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                             +-+
+--R         +-+     2                  (2x - 1)\|3
+--R        \|3 log(x  - x + 1) - 2atan(------------)
+--R                                          3
+--R   (2)  -----------------------------------------
+--R                            +-+
+--R                          2\|3
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 567
+t0:=(-1+x^2)/(1+x^3)
+--R 
+--R
+--R           x - 1
+--R   (1)  ----------
+--R         2
+--R        x  - x + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 112
+
+--S 113 of 567
+r0:=1/2*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                             +-+
+--R         +-+     2                  (2x - 1)\|3
+--R        \|3 log(x  - x + 1) - 2atan(------------)
+--R                                          3
+--R   (2)  -----------------------------------------
+--R                            +-+
+--R                          2\|3
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 567
+t0:=(-4+3*x)/(4-2*x+x^2)
+--R 
+--R
+--R           3x - 4
+--R   (1)  -----------
+--R         2
+--R        x  - 2x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 115
+
+--S 116 of 567
+r0:=3/2*log(4-2*x+x^2)+atan((1-x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                              +-+
+--R          +-+     2                   (x - 1)\|3
+--R        3\|3 log(x  - 2x + 4) - 2atan(-----------)
+--R                                           3
+--R   (2)  ------------------------------------------
+--R                             +-+
+--R                           2\|3
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 567
+t0:=(-8+2*x+3*x^2)/(8+x^3)
+--R 
+--R
+--R           3x - 4
+--R   (1)  -----------
+--R         2
+--R        x  - 2x + 4
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 118
+
+--S 119 of 567
+r0:=3/2*log(4-2*x+x^2)+atan((1-x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                              +-+
+--R          +-+     2                   (x - 1)\|3
+--R        3\|3 log(x  - 2x + 4) - 2atan(-----------)
+--R                                           3
+--R   (2)  ------------------------------------------
+--R                             +-+
+--R                           2\|3
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 567
+t0:=(a+a*x+c*x^2)/(1-x^3)
+--R 
+--R
+--R             2
+--R        - c x  - a x - a
+--R   (1)  ----------------
+--R              3
+--R             x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 121
+
+--S 122 of 567
+r0:=-1/3*(2*a+c)*log(1-x)+1/3*(a-c)*log(1+x+x^2)
+--R 
+--R
+--R                      2
+--R        (- c + a)log(x  + x + 1) + (- c - 2a)log(- x + 1)
+--R   (2)  -------------------------------------------------
+--R                                3
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 567
+t0:=(a+b*x+c*x^2)/(1-x^3)
+--R 
+--R
+--R             2
+--R        - c x  - b x - a
+--R   (1)  ----------------
+--R              3
+--R             x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 124
+
+--S 125 of 567
+r0:=-1/3*(a+b+c)*log(1-x)+1/6*(a+b-2*c)*log(1+x+x^2)+_
+   (a-b)*atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                      +-+     2                             +-+
+--R       (- 2c + b + a)\|3 log(x  + x + 1) + (- 2c - 2b - 2a)\|3 log(- x + 1)
+--R     + 
+--R                                +-+
+--R                       (2x + 1)\|3
+--R       (- 6b + 6a)atan(------------)
+--R                             3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 567
+t0:=x*(1+2*x)/(1+x^3)
+--R 
+--R
+--R          2
+--R        2x  + x
+--R   (1)  -------
+--R          3
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 127
+
+--S 128 of 567
+r0:=1/3*log(1+x)+5/6*log(1-x+x^2)-atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                +-+
+--R          +-+     2              +-+                   (2x - 1)\|3
+--R        5\|3 log(x  - x + 1) + 2\|3 log(x + 1) + 6atan(------------)
+--R                                                             3
+--R   (2)  ------------------------------------------------------------
+--R                                      +-+
+--R                                    6\|3
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 567
+t0:=(2*x^2+x^4)/(1+x^3)
+--R 
+--R
+--R         4     2
+--R        x  + 2x
+--R   (1)  --------
+--R          3
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 130
+
+--S 131 of 567
+r0:=1/2*x^2+log(1+x)+1/2*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                               +-+
+--R         +-+     2              +-+                   (2x - 1)\|3      2 +-+
+--R        \|3 log(x  - x + 1) + 2\|3 log(x + 1) - 2atan(------------) + x \|3
+--R                                                            3
+--R   (2)  --------------------------------------------------------------------
+--R                                          +-+
+--R                                        2\|3
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 567
+t0:=x*(1+2*x)/(-1+x^3)
+--R 
+--R
+--R          2
+--R        2x  + x
+--R   (1)  -------
+--R          3
+--R         x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 133
+
+--S 134 of 567
+r0:=log(1-x)+1/2*log(1+x+x^2)+atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                 +-+
+--R         +-+     2              +-+                     (2x + 1)\|3
+--R        \|3 log(x  + x + 1) + 2\|3 log(- x + 1) + 2atan(------------)
+--R                                                              3
+--R   (2)  -------------------------------------------------------------
+--R                                      +-+
+--R                                    2\|3
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 567
+t0:=(2*x^2+x^4)/(-1+x^3)
+--R 
+--R
+--R         4     2
+--R        x  + 2x
+--R   (1)  --------
+--R          3
+--R         x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 136
+
+--S 137 of 567
+r0:=1/2*x^2+log(1-x)+1/2*log(1+x+x^2)+atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                 +-+
+--R         +-+     2              +-+                     (2x + 1)\|3      2 +-+
+--R        \|3 log(x  + x + 1) + 2\|3 log(- x + 1) + 2atan(------------) + x \|3
+--R                                                              3
+--R   (2)  ----------------------------------------------------------------------
+--R                                           +-+
+--R                                         2\|3
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 567
+t0:=(1-x+4*x^3)/(1+x^3)
+--R 
+--R
+--R          3
+--R        4x  - x + 1
+--R   (1)  -----------
+--R            3
+--R           x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 139
+
+--S 140 of 567
+r0:=4*x-2/3*log(1+x)+1/3*log(1-x+x^2)+4*atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                +-+
+--R         +-+     2              +-+                    (2x - 1)\|3         +-+
+--R        \|3 log(x  - x + 1) - 2\|3 log(x + 1) - 12atan(------------) + 12x\|3
+--R                                                             3
+--R   (2)  ----------------------------------------------------------------------
+--R                                           +-+
+--R                                         3\|3
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 567
+t0:=(c+d*x+e*x^2)*(a+b*x^3)^p
+--R 
+--R
+--R            2               3     p
+--R   (1)  (e x  + d x + c)(b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 567
+--r0:=1/3*e*(a+b*x^3)^(1+p)/(b*(1+p))+c*x*(a+b*x^3)^p*_
+--   hypergeometric(1/3,-p,4/3,-b*x^3/a)/((a+b*x^3)/a)^p+_
+--   1/2*d*x^2*(a+b*x^3)^p*hypergeometric(2/3,-p,5/3,-b*x^3/a)/((a+b*x^3)/a)^p
+--E 143
+
+--S 144 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 144
+
+)clear all
+
+--S 145 of 567
+t0:=(c+d*x+e*x^2)*(a+b*x^3)^4
+--R 
+--R
+--R   (1)
+--R      4   14    4   13    4   12       3   11       3   10       3   9
+--R     b e x   + b d x   + b c x   + 4a b e x   + 4a b d x   + 4a b c x
+--R   + 
+--R       2 2   8     2 2   7     2 2   6     3     5     3     4     3     3
+--R     6a b e x  + 6a b d x  + 6a b c x  + 4a b e x  + 4a b d x  + 4a b c x
+--R   + 
+--R      4   2    4       4
+--R     a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 145
+
+--S 146 of 567
+r0:=a^4*c*x+1/2*a^4*d*x^2+a^3*b*c*x^4+4/5*a^3*b*d*x^5+6/7*a^2*b^2*c*x^7+_
+   3/4*a^2*b^2*d*x^8+2/5*a*b^3*c*x^10+4/11*a*b^3*d*x^11+1/13*b^4*c*x^13+_
+   1/14*b^4*d*x^14+1/15*e*(a+b*x^3)^5/b
+--R 
+--R
+--R   (2)
+--R        1  5   15    1  5   14    1  5   13   1    4   12    4    4   11
+--R       -- b e x   + -- b d x   + -- b c x   + - a b e x   + -- a b d x
+--R       15           14           13           3             11
+--R     + 
+--R       2    4   10   2  2 3   9   3  2 3   8   6  2 3   7   2  3 2   6
+--R       - a b c x   + - a b e x  + - a b d x  + - a b c x  + - a b e x
+--R       5             3            4            7            3
+--R     + 
+--R       4  3 2   5    3 2   4   1  4     3   1  4     2    4         1  5
+--R       - a b d x  + a b c x  + - a b e x  + - a b d x  + a b c x + -- a e
+--R       5                       3            2                      15
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 146
+
+--S 147 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 567
+t0:=(c+d*x+e*x^2)*(a+b*x^3)^3
+--R 
+--R
+--R   (1)
+--R      3   11    3   10    3   9       2   8       2   7       2   6     2     5
+--R     b e x   + b d x   + b c x  + 3a b e x  + 3a b d x  + 3a b c x  + 3a b e x
+--R   + 
+--R       2     4     2     3    3   2    3       3
+--R     3a b d x  + 3a b c x  + a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 148
+
+--S 149 of 567
+r0:=a^3*c*x+1/2*a^3*d*x^2+3/4*a^2*b*c*x^4+3/5*a^2*b*d*x^5+3/7*a*b^2*c*x^7+_
+   3/8*a*b^2*d*x^8+1/10*b^3*c*x^10+1/11*b^3*d*x^11+1/12*e*(a+b*x^3)^4/b
+--R 
+--R
+--R   (2)
+--R        1  4   12    1  4   11    1  4   10   1    3   9   3    3   8
+--R       -- b e x   + -- b d x   + -- b c x   + - a b e x  + - a b d x
+--R       12           11           10           3            8
+--R     + 
+--R       3    3   7   1  2 2   6   3  2 2   5   3  2 2   4   1  3     3
+--R       - a b c x  + - a b e x  + - a b d x  + - a b c x  + - a b e x
+--R       7            2            5            4            3
+--R     + 
+--R       1  3     2    3         1  4
+--R       - a b d x  + a b c x + -- a e
+--R       2                      12
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 149
+
+--S 150 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 567
+t0:=(c+d*x+e*x^2)*(a+b*x^3)^2
+--R 
+--R
+--R   (1)
+--R      2   8    2   7    2   6           5           4           3    2   2
+--R     b e x  + b d x  + b c x  + 2a b e x  + 2a b d x  + 2a b c x  + a e x
+--R   + 
+--R      2       2
+--R     a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 151
+
+--S 152 of 567
+r0:=a^2*c*x+1/2*a^2*d*x^2+1/2*a*b*c*x^4+2/5*a*b*d*x^5+1/7*b^2*c*x^7+_
+   1/8*b^2*d*x^8+1/9*e*(a+b*x^3)^3/b
+--R 
+--R
+--R   (2)
+--R       1  3   9   1  3   8   1  3   7   1    2   6   2    2   5   1    2   4
+--R       - b e x  + - b d x  + - b c x  + - a b e x  + - a b d x  + - a b c x
+--R       9          8          7          3            5            2
+--R     + 
+--R       1  2     3   1  2     2    2        1  3
+--R       - a b e x  + - a b d x  + a b c x + - a e
+--R       3            2                      9
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 152
+
+--S 153 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 567
+t0:=(c+d*x+e*x^2)*(a+b*x^3)
+--R 
+--R
+--R             5        4        3        2
+--R   (1)  b e x  + b d x  + b c x  + a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 154
+
+--S 155 of 567
+r0:=a*c*x+1/2*a*d*x^2+1/3*a*e*x^3+1/4*b*c*x^4+1/5*b*d*x^5+1/6*b*e*x^6
+--R 
+--R
+--R        1      6   1      5   1      4   1      3   1      2
+--R   (2)  - b e x  + - b d x  + - b c x  + - a e x  + - a d x  + a c x
+--R        6          5          4          3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 155
+
+--S 156 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 567
+t0:=(c+d*x+e*x^2)/(a+b*x^3)
+--R 
+--R
+--R           2
+--R        e x  + d x + c
+--R   (1)  --------------
+--R              3
+--R           b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 157
+
+--S 158 of 567
+r0:=1/3*(b^(1/3)*c-a^(1/3)*d)*log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*b^(2/3))-_
+   1/6*(c-a^(1/3)*d/b^(1/3))*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(2/3)*b^(1/3))+1/3*e*log(a+b*x^3)/b-(b^(1/3)*c+a^(1/3)*d)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(2/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R              +-+3+-+       +-+3+-+      2 3+-+2   3+-+3+-+   3+-+2
+--R       (- b c\|3 \|b  + b d\|3 \|a )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             +-+3+-+        +-+3+-+      3+-+   3+-+
+--R       (2b c\|3 \|b  - 2b d\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                   3+-+   3+-+
+--R            3+-+       3+-+      2x\|b  - \|a        +-+       3     3+-+2 3+-+2
+--R       (6b c\|b  + 6b d\|a )atan(-------------) + 2e\|3 log(b x  + a)\|a   \|b
+--R                                     +-+3+-+
+--R                                    \|3 \|a
+--R  /
+--R        +-+3+-+2 3+-+2
+--R     6b\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 567
+t0:=(c+d*x+e*x^2)/(a+b*x^3)^2
+--R 
+--R
+--R              2
+--R           e x  + d x + c
+--R   (1)  -------------------
+--R         2 6         3    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 160
+
+--S 161 of 567
+r0:=-1/3*e/(b*(a+b*x^3))+1/3*x*(c+d*x)/(a*(a+b*x^3))+1/9*(2*b^(1/3)*c-_
+   a^(1/3)*d)*log(a^(1/3)+b^(1/3)*x)/(a^(5/3)*b^(2/3))-1/18*(2*b^(1/3)*c-_
+   a^(1/3)*d)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(5/3)*b^(2/3))-_
+   1/3*(2*b^(1/3)*c+a^(1/3)*d)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(5/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R               2   3           +-+3+-+     2   3          +-+3+-+
+--R         ((- 2b c x  - 2a b c)\|3 \|b  + (b d x  + a b d)\|3 \|a )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             2   3           +-+3+-+        2   3           +-+3+-+
+--R         ((4b c x  + 4a b c)\|3 \|b  + (- 2b d x  - 2a b d)\|3 \|a )
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                                                                 3+-+   3+-+
+--R            2   3           3+-+      2   3          3+-+      2x\|b  - \|a
+--R       ((12b c x  + 12a b c)\|b  + (6b d x  + 6a b d)\|a )atan(-------------)
+--R                                                                   +-+3+-+
+--R                                                                  \|3 \|a
+--R     + 
+--R              2                  +-+3+-+2 3+-+2
+--R       (6b d x  + 6b c x - 6a e)\|3 \|a   \|b
+--R  /
+--R           2 3      2   +-+3+-+2 3+-+2
+--R     (18a b x  + 18a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 567
+t0:=(c+d*x+e*x^2)/(a+b*x^3)^3
+--R 
+--R
+--R                   2
+--R                e x  + d x + c
+--R   (1)  -----------------------------
+--R         3 9       2 6     2   3    3
+--R        b x  + 3a b x  + 3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 163
+
+--S 164 of 567
+r0:=-1/6*e/(b*(a+b*x^3)^2)+1/6*x*(c+d*x)/(a*(a+b*x^3)^2)+_
+   1/18*x*(5*c+4*d*x)/(a^2*(a+b*x^3))+1/27*(5*b^(1/3)*c-2*a^(1/3)*d)*_
+   log(a^(1/3)+b^(1/3)*x)/(a^(8/3)*b^(2/3))-1/54*(5*b^(1/3)*c-2*a^(1/3)*d)*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(8/3)*b^(2/3))-_
+   1/9*(5*b^(1/3)*c+2*a^(1/3)*d)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(8/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                3   6        2   3     2     +-+3+-+
+--R           (- 5b c x  - 10a b c x  - 5a b c)\|3 \|b
+--R         + 
+--R              3   6       2   3     2     +-+3+-+
+--R           (2b d x  + 4a b d x  + 2a b d)\|3 \|a
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               3   6        2   3      2     +-+3+-+
+--R           (10b c x  + 20a b c x  + 10a b c)\|3 \|b
+--R         + 
+--R                3   6       2   3     2     +-+3+-+
+--R           (- 4b d x  - 8a b d x  - 4a b d)\|3 \|a
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R               3   6        2   3      2    3+-+
+--R           (30b c x  + 60a b c x  + 30a b c)\|b
+--R         + 
+--R               3   6        2   3      2    3+-+
+--R           (12b d x  + 24a b d x  + 12a b d)\|a
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R           2   5      2   4            2                 2   +-+3+-+2 3+-+2
+--R       (12b d x  + 15b c x  + 21a b d x  + 24a b c x - 9a e)\|3 \|a   \|b
+--R  /
+--R         2 3 6       3 2 3      4   +-+3+-+2 3+-+2
+--R     (54a b x  + 108a b x  + 54a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 567
+t0:=(c+d*x+e*x^2)/(a+b*x^3)^4
+--R 
+--R
+--R                        2
+--R                     e x  + d x + c
+--R   (1)  ----------------------------------------
+--R         4 12       3 9     2 2 6     3   3    4
+--R        b x   + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 166
+
+--S 167 of 567
+r0:=-1/9*e/(b*(a+b*x^3)^3)+1/9*x*(c+d*x)/(a*(a+b*x^3)^3)+1/54*x*_
+   (8*c+7*d*x)/(a^2*(a+b*x^3)^2)+2/81*x*(10*c+7*d*x)/(a^3*(a+b*x^3))+_
+   2/243*(20*b^(1/3)*c-7*a^(1/3)*d)*log(a^(1/3)+b^(1/3)*x)/(a^(11/3)*_
+   b^(2/3))-1/243*(20*b^(1/3)*c-7*a^(1/3)*d)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+_
+   b^(2/3)*x^2)/(a^(11/3)*b^(2/3))-2/81*(20*b^(1/3)*c+7*a^(1/3)*d)*_
+   atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/(a^(11/3)*b^(2/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                 4   9         3   6       2 2   3      3     +-+3+-+
+--R           (- 40b c x  - 120a b c x  - 120a b c x  - 40a b c)\|3 \|b
+--R         + 
+--R               4   9        3   6      2 2   3      3     +-+3+-+
+--R           (14b d x  + 42a b d x  + 42a b d x  + 14a b d)\|3 \|a
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               4   9         3   6       2 2   3      3     +-+3+-+
+--R           (80b c x  + 240a b c x  + 240a b c x  + 80a b c)\|3 \|b
+--R         + 
+--R                 4   9        3   6      2 2   3      3     +-+3+-+
+--R           (- 28b d x  - 84a b d x  - 84a b d x  - 28a b d)\|3 \|a
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R                4   9         3   6       2 2   3       3    3+-+
+--R           (240b c x  + 720a b c x  + 720a b c x  + 240a b c)\|b
+--R         + 
+--R               4   9         3   6       2 2   3      3    3+-+
+--R           (84b d x  + 252a b d x  + 252a b d x  + 84a b d)\|a
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R              3   8       3   7         2   5         2   4       2     2
+--R           84b d x  + 120b c x  + 231a b d x  + 312a b c x  + 201a b d x
+--R         + 
+--R               2           3
+--R           246a b c x - 54a e
+--R      *
+--R          +-+3+-+2 3+-+2
+--R         \|3 \|a   \|b
+--R  /
+--R          3 4 9        4 3 6        5 2 3       6   +-+3+-+2 3+-+2
+--R     (486a b x  + 1458a b x  + 1458a b x  + 486a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 567
+t0:=x^2*(c+d*x+e*x^2)*(a+b*x^3)^p
+--R 
+--R
+--R            4      3      2     3     p
+--R   (1)  (e x  + d x  + c x )(b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 567
+--r0:=1/3*c*(a+b*x^3)^(1+p)/(b*(1+p))+d*x*(a+b*x^3)^(1+p)/(b*(4+3*p))+_
+--   e*x^2*(a+b*x^3)^(1+p)/(b*(5+3*p))-a*d*x*(a+b*x^3)^p*_
+--   hypergeometric(1/3,-p,4/3,-b*x^3/a)/(b*(4+3*p)*((a+b*x^3)/a)^p)-_
+--   a*e*x^2*(a+b*x^3)^p*hypergeometric(2/3,-p,5/3,-b*x^3/a)/(b*(5+3*p)*_
+--   ((a+b*x^3)/a)^p)
+--E 170
+
+--S 171 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 171
+
+)clear all
+
+--S 172 of 567
+t0:=x^2*(c+d*x+e*x^2)*(a+b*x^3)^4
+--R 
+--R
+--R   (1)
+--R      4   16    4   15    4   14       3   13       3   12       3   11
+--R     b e x   + b d x   + b c x   + 4a b e x   + 4a b d x   + 4a b c x
+--R   + 
+--R       2 2   10     2 2   9     2 2   8     3     7     3     6     3     5
+--R     6a b e x   + 6a b d x  + 6a b c x  + 4a b e x  + 4a b d x  + 4a b c x
+--R   + 
+--R      4   4    4   3    4   2
+--R     a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 172
+
+--S 173 of 567
+r0:=1/4*a^4*d*x^4+1/5*a^4*e*x^5+4/7*a^3*b*d*x^7+1/2*a^3*b*e*x^8+_
+   3/5*a^2*b^2*d*x^10+6/11*a^2*b^2*e*x^11+4/13*a*b^3*d*x^13+_
+   2/7*a*b^3*e*x^14+1/16*b^4*d*x^16+1/17*b^4*e*x^17+1/15*c*(a+b*x^3)^5/b
+--R 
+--R
+--R   (2)
+--R        1  5   17    1  5   16    1  5   15   2    4   14    4    4   13
+--R       -- b e x   + -- b d x   + -- b c x   + - a b e x   + -- a b d x
+--R       17           16           15           7             13
+--R     + 
+--R       1    4   12    6  2 3   11   3  2 3   10   2  2 3   9   1  3 2   8
+--R       - a b c x   + -- a b e x   + - a b d x   + - a b c x  + - a b e x
+--R       3             11             5             3            2
+--R     + 
+--R       4  3 2   7   2  3 2   6   1  4     5   1  4     4   1  4     3    1  5
+--R       - a b d x  + - a b c x  + - a b e x  + - a b d x  + - a b c x  + -- a c
+--R       7            3            5            4            3            15
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 173
+
+--S 174 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 567
+t0:=x^2*(c+d*x+e*x^2)*(a+b*x^3)^3
+--R 
+--R
+--R   (1)
+--R      3   13    3   12    3   11       2   10       2   9       2   8
+--R     b e x   + b d x   + b c x   + 3a b e x   + 3a b d x  + 3a b c x
+--R   + 
+--R       2     7     2     6     2     5    3   4    3   3    3   2
+--R     3a b e x  + 3a b d x  + 3a b c x  + a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 175
+
+--S 176 of 567
+r0:=1/4*a^3*d*x^4+1/5*a^3*e*x^5+3/7*a^2*b*d*x^7+3/8*a^2*b*e*x^8+_
+   3/10*a*b^2*d*x^10+3/11*a*b^2*e*x^11+1/13*b^3*d*x^13+1/14*b^3*e*x^14+_
+   1/12*c*(a+b*x^3)^4/b
+--R 
+--R
+--R   (2)
+--R        1  4   14    1  4   13    1  4   12    3    3   11    3    3   10
+--R       -- b e x   + -- b d x   + -- b c x   + -- a b e x   + -- a b d x
+--R       14           13           12           11             10
+--R     + 
+--R       1    3   9   3  2 2   8   3  2 2   7   1  2 2   6   1  3     5
+--R       - a b c x  + - a b e x  + - a b d x  + - a b c x  + - a b e x
+--R       3            8            7            2            5
+--R     + 
+--R       1  3     4   1  3     3    1  4
+--R       - a b d x  + - a b c x  + -- a c
+--R       4            3            12
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 176
+
+--S 177 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 567
+t0:=x^2*(c+d*x+e*x^2)*(a+b*x^3)^2
+--R 
+--R
+--R   (1)
+--R      2   10    2   9    2   8           7           6           5    2   4
+--R     b e x   + b d x  + b c x  + 2a b e x  + 2a b d x  + 2a b c x  + a e x
+--R   + 
+--R      2   3    2   2
+--R     a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 178
+
+--S 179 of 567
+r0:=1/4*a^2*d*x^4+1/5*a^2*e*x^5+2/7*a*b*d*x^7+1/4*a*b*e*x^8+1/10*b^2*d*x^10+_
+   1/11*b^2*e*x^11+1/9*c*(a+b*x^3)^3/b
+--R 
+--R
+--R   (2)
+--R        1  3   11    1  3   10   1  3   9   1    2   8   2    2   7   1    2   6
+--R       -- b e x   + -- b d x   + - b c x  + - a b e x  + - a b d x  + - a b c x
+--R       11           10           9          4            7            3
+--R     + 
+--R       1  2     5   1  2     4   1  2     3   1  3
+--R       - a b e x  + - a b d x  + - a b c x  + - a c
+--R       5            4            3            9
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 179
+
+--S 180 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 567
+t0:=x^2*(c+d*x+e*x^2)*(a+b*x^3)
+--R 
+--R
+--R             7        6        5        4        3        2
+--R   (1)  b e x  + b d x  + b c x  + a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 181
+
+--S 182 of 567
+r0:=1/3*a*c*x^3+1/4*a*d*x^4+1/5*a*e*x^5+1/6*b*c*x^6+1/7*b*d*x^7+1/8*b*e*x^8
+--R 
+--R
+--R        1      8   1      7   1      6   1      5   1      4   1      3
+--R   (2)  - b e x  + - b d x  + - b c x  + - a e x  + - a d x  + - a c x
+--R        8          7          6          5          4          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 182
+
+--S 183 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 567
+t0:=x^2*(c+d*x+e*x^2)/(a+b*x^3)
+--R 
+--R
+--R           4      3      2
+--R        e x  + d x  + c x
+--R   (1)  ------------------
+--R                3
+--R             b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 184
+
+--S 185 of 567
+r0:=d*x/b+1/2*e*x^2/b-1/3*a^(1/3)*(b^(1/3)*d-a^(1/3)*e)*log(a^(1/3)+_
+   b^(1/3)*x)/b^(5/3)+1/6*a^(1/3)*(d-a^(1/3)*e/b^(1/3))*log(a^(2/3)-_
+   a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/b^(4/3)+1/3*c*log(a+b*x^3)/b+a^(1/3)*_
+   (b^(1/3)*d+a^(1/3)*e)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*sqrt(3)))/_
+   (b^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R          +-+3+-+3+-+     +-+3+-+2      2 3+-+2   3+-+3+-+   3+-+2
+--R       (d\|3 \|a \|b  - e\|3 \|a  )log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R             +-+3+-+3+-+      +-+3+-+2      3+-+   3+-+
+--R       (- 2d\|3 \|a \|b  + 2e\|3 \|a  )log(x\|b  + \|a )
+--R     + 
+--R                                       3+-+   3+-+
+--R            3+-+3+-+      3+-+2      2x\|b  - \|a
+--R       (- 6d\|a \|b  - 6e \|a  )atan(-------------)
+--R                                         +-+3+-+
+--R                                        \|3 \|a
+--R     + 
+--R           +-+       3             2         +-+ 3+-+2
+--R       (2c\|3 log(b x  + a) + (3e x  + 6d x)\|3 )\|b
+--R  /
+--R        +-+3+-+2
+--R     6b\|3 \|b
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 567
+t0:=x^2*(c+d*x+e*x^2)/(a+b*x^3)^2
+--R 
+--R
+--R            4      3      2
+--R         e x  + d x  + c x
+--R   (1)  -------------------
+--R         2 6         3    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 187
+
+--S 188 of 567
+r0:=1/3*(-c-d*x-e*x^2)/(b*(a+b*x^3))+1/9*(b^(1/3)*d-2*a^(1/3)*e)*_
+   log(a^(1/3)+b^(1/3)*x)/(a^(2/3)*b^(5/3))-1/18*(d-2*a^(1/3)*e/b^(1/3))*_
+   log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(2/3)*b^(4/3))-_
+   1/3*(b^(1/3)*d+2*a^(1/3)*e)*atan((a^(1/3)-2*b^(1/3)*x)/(a^(1/3)*_
+   sqrt(3)))/(a^(2/3)*b^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                  3        +-+3+-+          3         +-+3+-+
+--R         ((- b d x  - a d)\|3 \|b  + (2b e x  + 2a e)\|3 \|a )
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               3         +-+3+-+            3         +-+3+-+      3+-+   3+-+
+--R       ((2b d x  + 2a d)\|3 \|b  + (- 4b e x  - 4a e)\|3 \|a )log(x\|b  + \|a )
+--R     + 
+--R                                                             3+-+   3+-+
+--R               3        3+-+           3         3+-+      2x\|b  - \|a
+--R       ((6b d x  + 6a d)\|b  + (12b e x  + 12a e)\|a )atan(-------------)
+--R                                                               +-+3+-+
+--R                                                              \|3 \|a
+--R     + 
+--R              2              +-+3+-+2 3+-+2
+--R       (- 6e x  - 6d x - 6c)\|3 \|a   \|b
+--R  /
+--R         2 3          +-+3+-+2 3+-+2
+--R     (18b x  + 18a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 567
+t0:=x^2*(c+d*x+e*x^2)/(a+b*x^3)^3
+--R 
+--R
+--R                 4      3      2
+--R              e x  + d x  + c x
+--R   (1)  -----------------------------
+--R         3 9       2 6     2   3    3
+--R        b x  + 3a b x  + 3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 190
+
+--S 191 of 567
+r0:=1/6*(-c-d*x-e*x^2)/(b*(a+b*x^3)^2)+1/18*x*(d+2*e*x)/(a*b*(a+b*x^3))+_
+   1/27*(b^(1/3)*d-a^(1/3)*e)*log(a^(1/3)+b^(1/3)*x)/(a^(5/3)*b^(5/3))-_
+   1/54*(d-a^(1/3)*e/b^(1/3))*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/_
+   (a^(5/3)*b^(4/3))-1/9*(b^(1/3)*d+a^(1/3)*e)*atan((a^(1/3)-2*b^(1/3)*x)/_
+   (a^(1/3)*sqrt(3)))/(a^(5/3)*b^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R               2   6           3    2   +-+3+-+
+--R           (- b d x  - 2a b d x  - a d)\|3 \|b
+--R         + 
+--R             2   6           3    2   +-+3+-+
+--R           (b e x  + 2a b e x  + a e)\|3 \|a
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R              2   6           3     2   +-+3+-+
+--R           (2b d x  + 4a b d x  + 2a d)\|3 \|b
+--R         + 
+--R                2   6           3     2   +-+3+-+
+--R           (- 2b e x  - 4a b e x  - 2a e)\|3 \|a
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R             2   6            3     2  3+-+      2   6            3     2  3+-+
+--R         ((6b d x  + 12a b d x  + 6a d)\|b  + (6b e x  + 12a b e x  + 6a e)\|a )
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R              5         4         2                  +-+3+-+2 3+-+2
+--R       (6b e x  + 3b d x  - 3a e x  - 6a d x - 9a c)\|3 \|a   \|b
+--R  /
+--R           3 6       2 2 3      3   +-+3+-+2 3+-+2
+--R     (54a b x  + 108a b x  + 54a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 567
+t0:=x^2*(c+d*x+e*x^2)/(a+b*x^3)^4
+--R 
+--R
+--R                      4      3      2
+--R                   e x  + d x  + c x
+--R   (1)  ----------------------------------------
+--R         4 12       3 9     2 2 6     3   3    4
+--R        b x   + 4a b x  + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 193
+
+--S 194 of 567
+r0:=1/9*(-c-d*x-e*x^2)/(b*(a+b*x^3)^3)+1/54*x*(d+2*e*x)/(a*b*(a+b*x^3)^2)+_
+   1/162*x*(5*d+8*e*x)/(a^2*b*(a+b*x^3))+1/243*(5*b^(1/3)*d-4*a^(1/3)*e)*_
+   log(a^(1/3)+b^(1/3)*x)/(a^(8/3)*b^(5/3))-1/486*(5*b^(1/3)*d-_
+   4*a^(1/3)*e)*log(a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(8/3)*_
+   b^(5/3))-1/81*(5*b^(1/3)*d+4*a^(1/3)*e)*atan((a^(1/3)-2*b^(1/3)*x)/_
+   (a^(1/3)*sqrt(3)))/(a^(8/3)*b^(5/3)*sqrt(3))
+--R 
+--R
+--R   (2)
+--R                3   9        2   6      2     3     3   +-+3+-+
+--R           (- 5b d x  - 15a b d x  - 15a b d x  - 5a d)\|3 \|b
+--R         + 
+--R              3   9        2   6      2     3     3   +-+3+-+
+--R           (4b e x  + 12a b e x  + 12a b e x  + 4a e)\|3 \|a
+--R      *
+--R              2 3+-+2   3+-+3+-+   3+-+2
+--R         log(x  \|b  - x\|a \|b  + \|a  )
+--R     + 
+--R               3   9        2   6      2     3      3   +-+3+-+
+--R           (10b d x  + 30a b d x  + 30a b d x  + 10a d)\|3 \|b
+--R         + 
+--R                3   9        2   6      2     3     3   +-+3+-+
+--R           (- 8b e x  - 24a b e x  - 24a b e x  - 8a e)\|3 \|a
+--R      *
+--R              3+-+   3+-+
+--R         log(x\|b  + \|a )
+--R     + 
+--R               3   9        2   6      2     3      3  3+-+
+--R           (30b d x  + 90a b d x  + 90a b d x  + 30a d)\|b
+--R         + 
+--R               3   9        2   6      2     3      3  3+-+
+--R           (24b e x  + 72a b e x  + 72a b e x  + 24a e)\|a
+--R      *
+--R                3+-+   3+-+
+--R              2x\|b  - \|a
+--R         atan(-------------)
+--R                  +-+3+-+
+--R                 \|3 \|a
+--R     + 
+--R              2   8      2   7            5            4      2   2      2
+--R           24b e x  + 15b d x  + 66a b e x  + 39a b d x  - 12a e x  - 30a d x
+--R         + 
+--R                2
+--R           - 54a c
+--R      *
+--R          +-+3+-+2 3+-+2
+--R         \|3 \|a   \|b
+--R  /
+--R          2 4 9        3 3 6        4 2 3       5   +-+3+-+2 3+-+2
+--R     (486a b x  + 1458a b x  + 1458a b x  + 486a b)\|3 \|a   \|b
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 567
+t0:=(1-x)*x^4/(1+x^3)
+--R 
+--R
+--R           5    4
+--R        - x  + x
+--R   (1)  ---------
+--R           3
+--R          x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 196
+
+--S 197 of 567
+r0:=1/2*x^2-1/3*x^3+2/3*log(1+x)+1/6*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                              +-+
+--R        +-+     2              +-+                   (2x - 1)\|3
+--R       \|3 log(x  - x + 1) + 4\|3 log(x + 1) - 6atan(------------)
+--R                                                           3
+--R     + 
+--R            3     2  +-+
+--R       (- 2x  + 3x )\|3
+--R  /
+--R       +-+
+--R     6\|3
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 567
+t0:=(1-x)*x^3/(1+x^3)
+--R 
+--R
+--R           4    3
+--R        - x  + x
+--R   (1)  ---------
+--R           3
+--R          x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 199
+
+--S 200 of 567
+r0:=x-1/2*x^2-2/3*log(1+x)+1/3*log(1-x+x^2)
+--R 
+--R
+--R              2                            2
+--R        2log(x  - x + 1) - 4log(x + 1) - 3x  + 6x
+--R   (2)  -----------------------------------------
+--R                            6
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 567
+t0:=(1-x)*x^2/(1+x^3)
+--R 
+--R
+--R           3    2
+--R        - x  + x
+--R   (1)  ---------
+--R           3
+--R          x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 202
+
+--S 203 of 567
+r0:=-x+2/3*log(1+x)+1/6*log(1-x+x^2)-atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                               +-+
+--R         +-+     2              +-+                   (2x - 1)\|3        +-+
+--R        \|3 log(x  - x + 1) + 4\|3 log(x + 1) + 6atan(------------) - 6x\|3
+--R                                                            3
+--R   (2)  --------------------------------------------------------------------
+--R                                          +-+
+--R                                        6\|3
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 567
+t0:=(1-x)*x/(1+x^3)
+--R 
+--R
+--R           2
+--R        - x  + x
+--R   (1)  --------
+--R          3
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 205
+
+--S 206 of 567
+r0:=-2/3*log(1+x)-1/6*log(1-x+x^2)-atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                                                                 +-+
+--R           +-+     2              +-+                   (2x - 1)\|3
+--R        - \|3 log(x  - x + 1) - 4\|3 log(x + 1) + 6atan(------------)
+--R                                                              3
+--R   (2)  -------------------------------------------------------------
+--R                                      +-+
+--R                                    6\|3
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 567
+t0:=(1-x)/(x*(1+x^3))
+--R 
+--R
+--R        - x + 1
+--R   (1)  -------
+--R          4
+--R         x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 208
+
+--S 209 of 567
+r0:=log(x)-2/3*log(1+x)-1/6*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                          +-+
+--R      +-+     2              +-+               +-+               (2x - 1)\|3
+--R   - \|3 log(x  - x + 1) - 4\|3 log(x + 1) + 6\|3 log(x) - 6atan(------------)
+--R                                                                       3
+--R   ---------------------------------------------------------------------------
+--R                                        +-+
+--R                                      6\|3
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 567
+t0:=(1-x)/(x^2*(1+x^3))
+--R 
+--R
+--R        - x + 1
+--R   (1)  -------
+--R         5    2
+--R        x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 211
+
+--S 212 of 567
+r0:=(-1)/x-log(x)+2/3*log(1+x)+1/6*log(1-x+x^2)+atan((1-2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R         +-+     2               +-+                +-+
+--R       x\|3 log(x  - x + 1) + 4x\|3 log(x + 1) - 6x\|3 log(x)
+--R     + 
+--R                          +-+
+--R                 (2x - 1)\|3       +-+
+--R       - 6x atan(------------) - 6\|3
+--R                       3
+--R  /
+--R        +-+
+--R     6x\|3
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 567
+t0:=(1-x)/(x^3*(1+x^3))
+--R 
+--R
+--R        - x + 1
+--R   (1)  -------
+--R         6    3
+--R        x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 214
+
+--S 215 of 567
+r0:=(-1/2)/x^2+1/x-2/3*log(1+x)+1/3*log(1-x+x^2)
+--R 
+--R
+--R          2     2              2
+--R        2x log(x  - x + 1) - 4x log(x + 1) + 6x - 3
+--R   (2)  -------------------------------------------
+--R                              2
+--R                            6x
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 567
+t0:=a*(e+f*x^4)^2
+--R 
+--R
+--R           2 8           4      2
+--R   (1)  a f x  + 2a e f x  + a e
+--R                                                    Type: Polynomial(Integer)
+--E 217
+
+--S 218 of 567
+r0:=a*e^2*x+2/5*a*e*f*x^5+1/9*a*f^2*x^9
+--R 
+--R
+--R        1    2 9   2        5      2
+--R   (2)  - a f x  + - a e f x  + a e x
+--R        9          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 218
+
+--S 219 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 567
+t0:=b*x*(e+f*x^4)^2
+--R 
+--R
+--R           2 9           5      2
+--R   (1)  b f x  + 2b e f x  + b e x
+--R                                                    Type: Polynomial(Integer)
+--E 220
+
+--S 221 of 567
+r0:=1/2*b*e^2*x^2+1/3*b*e*f*x^6+1/10*b*f^2*x^10
+--R 
+--R
+--R         1    2 10   1        6   1    2 2
+--R   (2)  -- b f x   + - b e f x  + - b e x
+--R        10           3            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 221
+
+--S 222 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 567
+t0:=(a+b*x)*(e+f*x^4)^2
+--R 
+--R
+--R           2 9      2 8           5           4      2       2
+--R   (1)  b f x  + a f x  + 2b e f x  + 2a e f x  + b e x + a e
+--R                                                    Type: Polynomial(Integer)
+--E 223
+
+--S 224 of 567
+r0:=a*e^2*x+1/2*b*e^2*x^2+2/5*a*e*f*x^5+1/3*b*e*f*x^6+1/9*a*f^2*x^9+_
+   1/10*b*f^2*x^10
+--R 
+--R
+--R         1    2 10   1    2 9   1        6   2        5   1    2 2      2
+--R   (2)  -- b f x   + - a f x  + - b e f x  + - a e f x  + - b e x  + a e x
+--R        10           9          3            5            2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 224
+
+--S 225 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 567
+t0:=c*x^2*(e+f*x^4)^2
+--R 
+--R
+--R           2 10           6      2 2
+--R   (1)  c f x   + 2c e f x  + c e x
+--R                                                    Type: Polynomial(Integer)
+--E 226
+
+--S 227 of 567
+r0:=1/3*c*e^2*x^3+2/7*c*e*f*x^7+1/11*c*f^2*x^11
+--R 
+--R
+--R         1    2 11   2        7   1    2 3
+--R   (2)  -- c f x   + - c e f x  + - c e x
+--R        11           7            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 227
+
+--S 228 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 567
+t0:=(a+c*x^2)*(e+f*x^4)^2
+--R 
+--R
+--R           2 10      2 8           6           4      2 2      2
+--R   (1)  c f x   + a f x  + 2c e f x  + 2a e f x  + c e x  + a e
+--R                                                    Type: Polynomial(Integer)
+--E 229
+
+--S 230 of 567
+r0:=a*e^2*x+1/3*c*e^2*x^3+2/5*a*e*f*x^5+2/7*c*e*f*x^7+1/9*a*f^2*x^9+_
+   1/11*c*f^2*x^11
+--R 
+--R
+--R         1    2 11   1    2 9   2        7   2        5   1    2 3      2
+--R   (2)  -- c f x   + - a f x  + - c e f x  + - a e f x  + - c e x  + a e x
+--R        11           9          7            5            3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 230
+
+--S 231 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 567
+t0:=(b*x+c*x^2)*(e+f*x^4)^2
+--R 
+--R
+--R           2 10      2 9           6           5      2 2      2
+--R   (1)  c f x   + b f x  + 2c e f x  + 2b e f x  + c e x  + b e x
+--R                                                    Type: Polynomial(Integer)
+--E 232
+
+--S 233 of 567
+r0:=1/2*b*e^2*x^2+1/3*c*e^2*x^3+1/3*b*e*f*x^6+2/7*c*e*f*x^7+1/10*b*f^2*x^10+_
+   1/11*c*f^2*x^11
+--R 
+--R
+--R   (2)
+--R    1    2 11    1    2 10   2        7   1        6   1    2 3   1    2 2
+--R   -- c f x   + -- b f x   + - c e f x  + - b e f x  + - c e x  + - b e x
+--R   11           10           7            3            3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 233
+
+--S 234 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 567
+t0:=(a+b*x+c*x^2)*(e+f*x^4)^2
+--R 
+--R
+--R   (1)
+--R        2 10      2 9      2 8           6           5           4      2 2
+--R     c f x   + b f x  + a f x  + 2c e f x  + 2b e f x  + 2a e f x  + c e x
+--R   + 
+--R        2       2
+--R     b e x + a e
+--R                                                    Type: Polynomial(Integer)
+--E 235
+
+--S 236 of 567
+r0:=a*e^2*x+1/2*b*e^2*x^2+1/3*c*e^2*x^3+2/5*a*e*f*x^5+1/3*b*e*f*x^6+_
+   2/7*c*e*f*x^7+1/9*a*f^2*x^9+1/10*b*f^2*x^10+1/11*c*f^2*x^11
+--R 
+--R
+--R   (2)
+--R      1    2 11    1    2 10   1    2 9   2        7   1        6   2        5
+--R     -- c f x   + -- b f x   + - a f x  + - c e f x  + - b e f x  + - a e f x
+--R     11           10           9          7            3            5
+--R   + 
+--R     1    2 3   1    2 2      2
+--R     - c e x  + - b e x  + a e x
+--R     3          2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 236
+
+--S 237 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 567
+t0:=d*x^3*(e+f*x^4)^2
+--R 
+--R
+--R           2 11           7      2 3
+--R   (1)  d f x   + 2d e f x  + d e x
+--R                                                    Type: Polynomial(Integer)
+--E 238
+
+--S 239 of 567
+r0:=1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R         1    3 12   1      2 8   1    2   4    1    3
+--R        -- d f x   + - d e f x  + - d e f x  + -- d e
+--R        12           4            4            12
+--R   (2)  ----------------------------------------------
+--R                               f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 239
+
+--S 240 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 567
+t0:=(a+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R           2 11      2 8           7           4      2 3      2
+--R   (1)  d f x   + a f x  + 2d e f x  + 2a e f x  + d e x  + a e
+--R                                                    Type: Polynomial(Integer)
+--E 241
+
+--S 242 of 567
+r0:=a*e^2*x+2/5*a*e*f*x^5+1/9*a*f^2*x^9+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12   1    3 9   1      2 8   2      2 5   1    2   4      2
+--R       -- d f x   + - a f x  + - d e f x  + - a e f x  + - d e f x  + a e f x
+--R       12           9          4            5            4
+--R     + 
+--R        1    3
+--R       -- d e
+--R       12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 242
+
+--S 243 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 567
+t0:=(b*x+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R           2 11      2 9           7           5      2 3      2
+--R   (1)  d f x   + b f x  + 2d e f x  + 2b e f x  + d e x  + b e x
+--R                                                    Type: Polynomial(Integer)
+--E 244
+
+--S 245 of 567
+r0:=1/2*b*e^2*x^2+1/3*b*e*f*x^6+1/10*b*f^2*x^10+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 10   1      2 8   1      2 6   1    2   4
+--R       -- d f x   + -- b f x   + - d e f x  + - b e f x  + - d e f x
+--R       12           10           4            3            4
+--R     + 
+--R       1    2   2    1    3
+--R       - b e f x  + -- d e
+--R       2            12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 245
+
+--S 246 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 567
+t0:=(a+b*x+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R   (1)
+--R        2 11      2 9      2 8           7           5           4      2 3
+--R     d f x   + b f x  + a f x  + 2d e f x  + 2b e f x  + 2a e f x  + d e x
+--R   + 
+--R        2       2
+--R     b e x + a e
+--R                                                    Type: Polynomial(Integer)
+--E 247
+
+--S 248 of 567
+r0:=a*e^2*x+1/2*b*e^2*x^2+2/5*a*e*f*x^5+1/3*b*e*f*x^6+1/9*a*f^2*x^9+_
+   1/10*b*f^2*x^10+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 10   1    3 9   1      2 8   1      2 6   2      2 5
+--R       -- d f x   + -- b f x   + - a f x  + - d e f x  + - b e f x  + - a e f x
+--R       12           10           9          4            3            5
+--R     + 
+--R       1    2   4   1    2   2      2       1    3
+--R       - d e f x  + - b e f x  + a e f x + -- d e
+--R       4            2                      12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 248
+
+--S 249 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 567
+t0:=(c*x^2+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R           2 11      2 10           7           6      2 3      2 2
+--R   (1)  d f x   + c f x   + 2d e f x  + 2c e f x  + d e x  + c e x
+--R                                                    Type: Polynomial(Integer)
+--E 250
+
+--S 251 of 567
+r0:=1/3*c*e^2*x^3+2/7*c*e*f*x^7+1/11*c*f^2*x^11+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 11   1      2 8   2      2 7   1    2   4
+--R       -- d f x   + -- c f x   + - d e f x  + - c e f x  + - d e f x
+--R       12           11           4            7            4
+--R     + 
+--R       1    2   3    1    3
+--R       - c e f x  + -- d e
+--R       3            12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 251
+
+--S 252 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 567
+t0:=(a+c*x^2+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R   (1)
+--R        2 11      2 10      2 8           7           6           4      2 3
+--R     d f x   + c f x   + a f x  + 2d e f x  + 2c e f x  + 2a e f x  + d e x
+--R   + 
+--R        2 2      2
+--R     c e x  + a e
+--R                                                    Type: Polynomial(Integer)
+--E 253
+
+--S 254 of 567
+r0:=a*e^2*x+1/3*c*e^2*x^3+2/5*a*e*f*x^5+2/7*c*e*f*x^7+1/9*a*f^2*x^9+_
+   1/11*c*f^2*x^11+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 11   1    3 9   1      2 8   2      2 7   2      2 5
+--R       -- d f x   + -- c f x   + - a f x  + - d e f x  + - c e f x  + - a e f x
+--R       12           11           9          4            7            5
+--R     + 
+--R       1    2   4   1    2   3      2       1    3
+--R       - d e f x  + - c e f x  + a e f x + -- d e
+--R       4            3                      12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 254
+
+--S 255 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 567
+t0:=(b*x+c*x^2+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R   (1)
+--R        2 11      2 10      2 9           7           6           5      2 3
+--R     d f x   + c f x   + b f x  + 2d e f x  + 2c e f x  + 2b e f x  + d e x
+--R   + 
+--R        2 2      2
+--R     c e x  + b e x
+--R                                                    Type: Polynomial(Integer)
+--E 256
+
+--S 257 of 567
+r0:=1/2*b*e^2*x^2+1/3*c*e^2*x^3+1/3*b*e*f*x^6+2/7*c*e*f*x^7+_
+   1/10*b*f^2*x^10+1/11*c*f^2*x^11+1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 11    1    3 10   1      2 8   2      2 7
+--R       -- d f x   + -- c f x   + -- b f x   + - d e f x  + - c e f x
+--R       12           11           10           4            7
+--R     + 
+--R       1      2 6   1    2   4   1    2   3   1    2   2    1    3
+--R       - b e f x  + - d e f x  + - c e f x  + - b e f x  + -- d e
+--R       3            4            3            2            12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 257
+
+--S 258 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 567
+t0:=(a+b*x+c*x^2+d*x^3)*(e+f*x^4)^2
+--R 
+--R
+--R   (1)
+--R        2 11      2 10      2 9      2 8           7           6           5
+--R     d f x   + c f x   + b f x  + a f x  + 2d e f x  + 2c e f x  + 2b e f x
+--R   + 
+--R             4      2 3      2 2      2       2
+--R     2a e f x  + d e x  + c e x  + b e x + a e
+--R                                                    Type: Polynomial(Integer)
+--E 259
+
+--S 260 of 567
+r0:=a*e^2*x+1/2*b*e^2*x^2+1/3*c*e^2*x^3+2/5*a*e*f*x^5+1/3*b*e*f*x^6+_
+   2/7*c*e*f*x^7+1/9*a*f^2*x^9+1/10*b*f^2*x^10+1/11*c*f^2*x^11+_
+   1/12*d*(e+f*x^4)^3/f
+--R 
+--R
+--R   (2)
+--R        1    3 12    1    3 11    1    3 10   1    3 9   1      2 8   2      2 7
+--R       -- d f x   + -- c f x   + -- b f x   + - a f x  + - d e f x  + - c e f x
+--R       12           11           10           9          4            7
+--R     + 
+--R       1      2 6   2      2 5   1    2   4   1    2   3   1    2   2      2
+--R       - b e f x  + - a e f x  + - d e f x  + - c e f x  + - b e f x  + a e f x
+--R       3            5            4            3            2
+--R     + 
+--R        1    3
+--R       -- d e
+--R       12
+--R  /
+--R     f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 260
+
+--S 261 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 567
+t0:=a/(e+f*x^4)
+--R 
+--R
+--R            a
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 262
+
+--S 263 of 567
+r0:=-1/2*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(3/4)*f^(1/4)*sqrt(2))+_
+   1/2*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(3/4)*f^(1/4)*sqrt(2))-_
+   1/4*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(3/4)*_
+   f^(1/4)*sqrt(2))+1/4*a*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R       a log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                            +-+4+-+   4+-+
+--R                   +-+4+-+4+-+    2 +-+    +-+            x\|2 \|f  + \|e
+--R       - a log(- x\|2 \|e \|f  + x \|f  + \|e ) + 2a atan(----------------)
+--R                                                                4+-+
+--R                                                                \|e
+--R     + 
+--R                 +-+4+-+   4+-+
+--R               x\|2 \|f  - \|e
+--R       2a atan(----------------)
+--R                     4+-+
+--R                     \|e
+--R  /
+--R       +-+4+-+3 4+-+
+--R     4\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 567
+t0:=b*x/(e+f*x^4)
+--R 
+--R
+--R           b x
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 265
+
+--S 266 of 567
+r0:=1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R                2 +-+
+--R               x \|f
+--R        b atan(------)
+--R                 +-+
+--R                \|e
+--R   (2)  --------------
+--R             +-+ +-+
+--R           2\|e \|f
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 567
+t0:=(a+b*x)/(e+f*x^4)
+--R 
+--R
+--R         b x + a
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 268
+
+--S 269 of 567
+r0:=-1/2*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(3/4)*f^(1/4)*sqrt(2))+_
+   1/2*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(3/4)*f^(1/4)*sqrt(2))-_
+   1/4*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(3/4)*_
+   f^(1/4)*sqrt(2))+1/4*a*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))+1/2*b*atan(x^2*sqrt(f)/_
+   sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R         +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       a\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       - a\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                        +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R          +-+ +-+     x\|2 \|f  + \|e        +-+ +-+     x\|2 \|f  - \|e
+--R       2a\|e \|f atan(----------------) + 2a\|e \|f atan(----------------)
+--R                            4+-+                               4+-+
+--R                            \|e                                \|e
+--R     + 
+--R                             2 +-+
+--R          +-+4+-+3 4+-+     x \|f
+--R       2b\|2 \|e   \|f atan(------)
+--R                              +-+
+--R                             \|e
+--R  /
+--R       +-+ +-+4+-+3 +-+4+-+
+--R     4\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 567
+t0:=c*x^2/(e+f*x^4)
+--R 
+--R
+--R             2
+--R          c x
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 271
+
+--S 272 of 567
+r0:=-1/2*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(1/4)*f^(3/4)*sqrt(2))+_
+   1/2*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(1/4)*f^(3/4)*sqrt(2))+_
+   1/4*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(1/4)*_
+   f^(3/4)*sqrt(2))-1/4*c*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R       - c log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                          +-+4+-+   4+-+
+--R                 +-+4+-+4+-+    2 +-+    +-+            x\|2 \|f  + \|e
+--R       c log(- x\|2 \|e \|f  + x \|f  + \|e ) + 2c atan(----------------)
+--R                                                              4+-+
+--R                                                              \|e
+--R     + 
+--R                 +-+4+-+   4+-+
+--R               x\|2 \|f  - \|e
+--R       2c atan(----------------)
+--R                     4+-+
+--R                     \|e
+--R  /
+--R       +-+4+-+4+-+3
+--R     4\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 567
+t0:=(a+c*x^2)/(e+f*x^4)
+--R 
+--R
+--R           2
+--R        c x  + a
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 274
+
+--S 275 of 567
+r0:=1/4*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-_
+   a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))-1/4*log(e^(1/4)*f^(1/4)*x*_
+   sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-a*sqrt(f))/(e^(3/4)*f^(3/4)*_
+   sqrt(2))-1/2*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+a*sqrt(f))/_
+   (e^(3/4)*f^(3/4)*sqrt(2))+1/2*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))*_
+   (c*sqrt(e)+a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R          +-+     +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (a\|f  - c\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R            +-+     +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- a\|f  + c\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|f  + \|e
+--R       (2a\|f  + 2c\|e )atan(----------------)
+--R                                   4+-+
+--R                                   \|e
+--R     + 
+--R                               +-+4+-+   4+-+
+--R           +-+      +-+      x\|2 \|f  - \|e
+--R       (2a\|f  + 2c\|e )atan(----------------)
+--R                                   4+-+
+--R                                   \|e
+--R  /
+--R       +-+4+-+3 4+-+3
+--R     4\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 567
+t0:=(b*x+c*x^2)/(e+f*x^4)
+--R 
+--R
+--R           2
+--R        c x  + b x
+--R   (1)  ----------
+--R            4
+--R         f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 277
+
+--S 278 of 567
+r0:=-1/2*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(1/4)*f^(3/4)*sqrt(2))+_
+   1/2*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/(e^(1/4)*f^(3/4)*sqrt(2))+_
+   1/4*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(1/4)*_
+   f^(3/4)*sqrt(2))-1/4*c*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))+1/2*b*atan(x^2*sqrt(f)/_
+   sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R           +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       - c\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R         +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       c\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                        +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R          +-+ +-+     x\|2 \|f  + \|e        +-+ +-+     x\|2 \|f  - \|e
+--R       2c\|e \|f atan(----------------) + 2c\|e \|f atan(----------------)
+--R                            4+-+                               4+-+
+--R                            \|e                                \|e
+--R     + 
+--R                            2 +-+
+--R          +-+4+-+4+-+3     x \|f
+--R       2b\|2 \|e \|f  atan(------)
+--R                             +-+
+--R                            \|e
+--R  /
+--R       +-+ +-+4+-+ +-+4+-+3
+--R     4\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 567
+t0:=(a+b*x+c*x^2)/(e+f*x^4)
+--R 
+--R
+--R           2
+--R        c x  + b x + a
+--R   (1)  --------------
+--R              4
+--R           f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 280
+
+--S 281 of 567
+r0:=1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))+1/4*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-a*sqrt(f))/_
+   (e^(3/4)*f^(3/4)*sqrt(2))-1/4*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))*(c*sqrt(e)-a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))-_
+   1/2*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+a*sqrt(f))/_
+   (e^(3/4)*f^(3/4)*sqrt(2))+1/2*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))*_
+   (c*sqrt(e)+a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              +-+       +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- c e\|f  + a f\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R            +-+       +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (c e\|f  - a f\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                   +-+4+-+   4+-+
+--R             +-+        +-+      x\|2 \|f  + \|e
+--R       (2c e\|f  + 2a f\|e )atan(----------------)
+--R                                       4+-+
+--R                                       \|e
+--R     + 
+--R                                 +-+4+-+   4+-+                           2 +-+
+--R           +-+        +-+      x\|2 \|f  - \|e        +-+4+-+3 4+-+3     x \|f
+--R     (2c e\|f  + 2a f\|e )atan(----------------) + 2b\|2 \|e   \|f  atan(------)
+--R                                     4+-+                                  +-+
+--R                                     \|e                                  \|e
+--R  /
+--R       +-+ +-+4+-+3 +-+4+-+3
+--R     4\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 567
+t0:=d*x^3/(e+f*x^4)
+--R 
+--R
+--R             3
+--R          d x
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 283
+
+--S 284 of 567
+r0:=1/4*d*log(e+f*x^4)/f
+--R 
+--R
+--R                 4
+--R        d log(f x  + e)
+--R   (2)  ---------------
+--R               4f
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 567
+t0:=(a+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3
+--R        d x  + a
+--R   (1)  --------
+--R           4
+--R        f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 286
+
+--S 287 of 567
+r0:=1/4*d*log(e+f*x^4)/f-1/2*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(3/4)*f^(1/4)*sqrt(2))+1/2*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(3/4)*f^(1/4)*sqrt(2))-1/4*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))+1/4*a*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R       a f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                                +-+4+-+   4+-+
+--R                     +-+4+-+4+-+    2 +-+    +-+              x\|2 \|f  + \|e
+--R       - a f log(- x\|2 \|e \|f  + x \|f  + \|e ) + 2a f atan(----------------)
+--R                                                                    4+-+
+--R                                                                    \|e
+--R     + 
+--R                   +-+4+-+   4+-+
+--R                 x\|2 \|f  - \|e       +-+       4     4+-+3 4+-+
+--R       2a f atan(----------------) + d\|2 log(f x  + e)\|e   \|f
+--R                       4+-+
+--R                       \|e
+--R  /
+--R        +-+4+-+3 4+-+
+--R     4f\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 567
+t0:=(b*x+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3
+--R        d x  + b x
+--R   (1)  ----------
+--R            4
+--R         f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 289
+
+--S 290 of 567
+r0:=1/4*d*log(e+f*x^4)/f+1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R                   2 +-+
+--R                  x \|f              4      +-+ +-+
+--R        2b f atan(------) + d log(f x  + e)\|e \|f
+--R                    +-+
+--R                   \|e
+--R   (2)  -------------------------------------------
+--R                            +-+ +-+
+--R                         4f\|e \|f
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 567
+t0:=(a+b*x+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3
+--R        d x  + b x + a
+--R   (1)  --------------
+--R              4
+--R           f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 292
+
+--S 293 of 567
+r0:=1/4*d*log(e+f*x^4)/f-1/2*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(3/4)*f^(1/4)*sqrt(2))+1/2*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(3/4)*f^(1/4)*sqrt(2))-1/4*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))+1/4*a*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(3/4)*f^(1/4)*sqrt(2))+_
+   1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R           +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       a f\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       - a f\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                          +-+4+-+   4+-+                       +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|f  + \|e          +-+ +-+     x\|2 \|f  - \|e
+--R       2a f\|e \|f atan(----------------) + 2a f\|e \|f atan(----------------)
+--R                              4+-+                                 4+-+
+--R                              \|e                                  \|e
+--R     + 
+--R                               2 +-+
+--R            +-+4+-+3 4+-+     x \|f      +-+       4      +-+4+-+3 +-+4+-+
+--R       2b f\|2 \|e   \|f atan(------ + d\|2 log(f x  + e)\|e \|e  \|f \|f
+--R                                +-+
+--R                               \|e
+--R  /
+--R        +-+ +-+4+-+3 +-+4+-+
+--R     4f\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 567
+t0:=(c*x^2+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x
+--R   (1)  -----------
+--R             4
+--R          f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 295
+
+--S 296 of 567
+r0:=1/4*d*log(e+f*x^4)/f-1/2*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(1/4)*f^(3/4)*sqrt(2))+1/2*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(1/4)*f^(3/4)*sqrt(2))+1/4*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))-1/4*c*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   +-+4+-+4+-+    2 +-+    +-+
+--R       - c f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                              +-+4+-+   4+-+
+--R                   +-+4+-+4+-+    2 +-+    +-+              x\|2 \|f  + \|e
+--R       c f log(- x\|2 \|e \|f  + x \|f  + \|e ) + 2c f atan(----------------)
+--R                                                                  4+-+
+--R                                                                  \|e
+--R     + 
+--R                   +-+4+-+   4+-+
+--R                 x\|2 \|f  - \|e       +-+       4     4+-+4+-+3
+--R       2c f atan(----------------) + d\|2 log(f x  + e)\|e \|f
+--R                       4+-+
+--R                       \|e
+--R  /
+--R        +-+4+-+4+-+3
+--R     4f\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 567
+t0:=(a+c*x^2+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + a
+--R   (1)  ---------------
+--R               4
+--R            f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 298
+
+--S 299 of 567
+r0:=1/4*d*log(e+f*x^4)/f+1/4*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+_
+   x^2*sqrt(f))*(c*sqrt(e)-a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))-_
+   1/4*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-_
+   a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))-1/2*atan(1-f^(1/4)*x*_
+   sqrt(2)/e^(1/4))*(c*sqrt(e)+a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))+_
+   1/2*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+a*sqrt(f))/_
+   (e^(3/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            +-+       +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (a f\|f  - c f\|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              +-+       +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- a f\|f  + c f\|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                   +-+4+-+   4+-+
+--R             +-+        +-+      x\|2 \|f  + \|e
+--R       (2a f\|f  + 2c f\|e )atan(----------------)
+--R                                       4+-+
+--R                                       \|e
+--R     + 
+--R                                 +-+4+-+   4+-+
+--R           +-+        +-+      x\|2 \|f  - \|e       +-+       4     4+-+3 4+-+3
+--R     (2a f\|f  + 2c f\|e )atan(----------------) + d\|2 log(f x  + e)\|e   \|f
+--R                                     4+-+
+--R                                     \|e
+--R  /
+--R        +-+4+-+3 4+-+3
+--R     4f\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 567
+t0:=(b*x+c*x^2+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + b x
+--R   (1)  -----------------
+--R                4
+--R             f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 301
+
+--S 302 of 567
+r0:=1/4*d*log(e+f*x^4)/f-1/2*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(1/4)*f^(3/4)*sqrt(2))+1/2*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(1/4)*f^(3/4)*sqrt(2))+1/4*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))-1/4*c*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(1/4)*f^(3/4)*sqrt(2))+_
+   1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R             +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       - c f\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       c f\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                          +-+4+-+   4+-+                       +-+4+-+   4+-+
+--R            +-+ +-+     x\|2 \|f  + \|e          +-+ +-+     x\|2 \|f  - \|e
+--R       2c f\|e \|f atan(----------------) + 2c f\|e \|f atan(----------------)
+--R                              4+-+                                 4+-+
+--R                              \|e                                  \|e
+--R     + 
+--R                              2 +-+
+--R            +-+4+-+4+-+3     x \|f       +-+       4      +-+4+-+ +-+4+-+3
+--R       2b f\|2 \|e \|f  atan(------) + d\|2 log(f x  + e)\|e \|e \|f \|f
+--R                               +-+
+--R                              \|e
+--R  /
+--R        +-+ +-+4+-+ +-+4+-+3
+--R     4f\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 567
+t0:=(a+b*x+c*x^2+d*x^3)/(e+f*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + b x + a
+--R   (1)  ---------------------
+--R                  4
+--R               f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 304
+
+--S 305 of 567
+r0:=1/4*d*log(e+f*x^4)/f+1/2*b*atan(x^2*sqrt(f)/sqrt(e))/(sqrt(e)*sqrt(f))+_
+   1/4*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-_
+   a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))-1/4*log(e^(1/4)*f^(1/4)*x*_
+   sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-a*sqrt(f))/(e^(3/4)*f^(3/4)*_
+   sqrt(2))-1/2*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+_
+   a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))+1/2*atan(1+f^(1/4)*x*_
+   sqrt(2)/e^(1/4))*(c*sqrt(e)+a*sqrt(f))/(e^(3/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                +-+      2 +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- c e f\|f  + a f \|e )log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              +-+      2 +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (c e f\|f  - a f \|e )log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R               +-+       2 +-+      x\|2 \|f  + \|e
+--R       (2c e f\|f  + 2a f \|e )atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R               +-+       2 +-+      x\|2 \|f  - \|e
+--R       (2c e f\|f  + 2a f \|e )atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                2 +-+
+--R            +-+4+-+3 4+-+3     x \|f      +-+       4      +-+4+-+3 +-+4+-+3
+--R       2b f\|2 \|e   \|f  atan(------ + d\|2 log(f x  + e)\|e \|e  \|f \|f
+--R                                 +-+
+--R                                \|e
+--R  /
+--R        +-+ +-+4+-+3 +-+4+-+3
+--R     4f\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 567
+t0:=a/(e+f*x^4)^2
+--R 
+--R
+--R                 a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 307
+
+--S 308 of 567
+r0:=1/4*a*x/(e*(e+f*x^4))-3/8*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(7/4)*f^(1/4)*sqrt(2))+3/8*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(7/4)*f^(1/4)*sqrt(2))-3/16*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))+3/16*a*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              4              +-+4+-+4+-+    2 +-+    +-+
+--R       (3a f x  + 3a e)log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                4                +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a f x  - 3a e)log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                              +-+4+-+   4+-+
+--R              4             x\|2 \|f  + \|e
+--R       (6a f x  + 6a e)atan(----------------)
+--R                                  4+-+
+--R                                  \|e
+--R     + 
+--R                              +-+4+-+   4+-+
+--R              4             x\|2 \|f  - \|e          +-+4+-+3 4+-+
+--R       (6a f x  + 6a e)atan(----------------) + 4a x\|2 \|e   \|f
+--R                                  4+-+
+--R                                  \|e
+--R  /
+--R             4      2  +-+4+-+3 4+-+
+--R     (16e f x  + 16e )\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 567
+t0:=b*x/(e+f*x^4)^2
+--R 
+--R
+--R                b x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 310
+
+--S 311 of 567
+r0:=1/4*b*x^2/(e*(e+f*x^4))+1/4*b*atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))
+--R 
+--R
+--R                            2 +-+
+--R              4            x \|f        2 +-+ +-+
+--R        (b f x  + b e)atan(------) + b x \|e \|f
+--R                             +-+
+--R                            \|e
+--R   (2)  -----------------------------------------
+--R                        4     2  +-+ +-+
+--R                 (4e f x  + 4e )\|e \|f
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 567
+t0:=(a+b*x)/(e+f*x^4)^2
+--R 
+--R
+--R              b x + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 313
+
+--S 314 of 567
+r0:=1/4*x*(a+b*x)/(e*(e+f*x^4))-3/8*a*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(7/4)*f^(1/4)*sqrt(2))+3/8*a*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(7/4)*f^(1/4)*sqrt(2))-3/16*a*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))+3/16*a*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))+_
+   1/4*b*atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R              4         +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       (3a f x  + 3a e)\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                4         +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a f x  - 3a e)\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R              4         +-+ +-+     x\|2 \|f  + \|e
+--R       (6a f x  + 6a e)\|e \|f atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R              4         +-+ +-+     x\|2 \|f  - \|e
+--R       (6a f x  + 6a e)\|e \|f atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                           2 +-+
+--R              4         +-+4+-+3 4+-+     x \|f
+--R       (4b f x  + 4b e)\|2 \|e   \|f atan(------)
+--R                                            +-+
+--R                                           \|e
+--R     + 
+--R            2         +-+ +-+4+-+3 +-+4+-+
+--R       (4b x  + 4a x)\|2 \|e \|e  \|f \|f
+--R  /
+--R             4      2  +-+ +-+4+-+3 +-+4+-+
+--R     (16e f x  + 16e )\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 567
+t0:=c*x^2/(e+f*x^4)^2
+--R 
+--R
+--R                   2
+--R                c x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 316
+
+--S 317 of 567
+r0:=1/4*c*x^3/(e*(e+f*x^4))-1/8*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(5/4)*f^(3/4)*sqrt(2))+1/8*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(5/4)*f^(3/4)*sqrt(2))+1/16*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))-1/16*c*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               4             +-+4+-+4+-+    2 +-+    +-+
+--R       (- c f x  - c e)log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             4               +-+4+-+4+-+    2 +-+    +-+
+--R       (c f x  + c e)log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                              +-+4+-+   4+-+
+--R              4             x\|2 \|f  + \|e
+--R       (2c f x  + 2c e)atan(----------------)
+--R                                  4+-+
+--R                                  \|e
+--R     + 
+--R                              +-+4+-+   4+-+
+--R              4             x\|2 \|f  - \|e         3 +-+4+-+4+-+3
+--R       (2c f x  + 2c e)atan(----------------) + 4c x \|2 \|e \|f
+--R                                  4+-+
+--R                                  \|e
+--R  /
+--R             4      2  +-+4+-+4+-+3
+--R     (16e f x  + 16e )\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 567
+t0:=(a+c*x^2)/(e+f*x^4)^2
+--R 
+--R
+--R                 2
+--R              c x  + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 319
+
+--S 320 of 567
+r0:=1/4*x*(a+c*x^2)/(e*(e+f*x^4))+1/16*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))-_
+   1/16*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-_
+   3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))-1/8*atan(1-f^(1/4)*x*_
+   sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))+_
+   1/8*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/_
+   (e^(7/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                 4         +-+           4        +-+
+--R         ((3a f x  + 3a e)\|f  + (- c f x  - c e)\|e )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                   4         +-+         4        +-+
+--R         ((- 3a f x  - 3a e)\|f  + (c f x  + c e)\|e )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                           +-+4+-+   4+-+
+--R               4         +-+          4         +-+      x\|2 \|f  + \|e
+--R       ((6a f x  + 6a e)\|f  + (2c f x  + 2c e)\|e )atan(----------------)
+--R                                                               4+-+
+--R                                                               \|e
+--R     + 
+--R                                                           +-+4+-+   4+-+
+--R               4         +-+          4         +-+      x\|2 \|f  - \|e
+--R       ((6a f x  + 6a e)\|f  + (2c f x  + 2c e)\|e )atan(----------------)
+--R                                                               4+-+
+--R                                                               \|e
+--R     + 
+--R            3         +-+4+-+3 4+-+3
+--R       (4c x  + 4a x)\|2 \|e   \|f
+--R  /
+--R             4      2  +-+4+-+3 4+-+3
+--R     (16e f x  + 16e )\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 567
+t0:=(b*x+c*x^2)/(e+f*x^4)^2
+--R 
+--R
+--R                2
+--R             c x  + b x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 322
+
+--S 323 of 567
+r0:=1/4*x^2*(b+c*x)/(e*(e+f*x^4))-1/8*c*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(5/4)*f^(3/4)*sqrt(2))+1/8*c*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))/_
+   (e^(5/4)*f^(3/4)*sqrt(2))+1/16*c*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))-1/16*c*log(e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))+_
+   1/4*b*atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R               4        +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       (- c f x  - c e)\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R             4        +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       (c f x  + c e)\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R              4         +-+ +-+     x\|2 \|f  + \|e
+--R       (2c f x  + 2c e)\|e \|f atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                      +-+4+-+   4+-+
+--R              4         +-+ +-+     x\|2 \|f  - \|e
+--R       (2c f x  + 2c e)\|e \|f atan(----------------)
+--R                                          4+-+
+--R                                          \|e
+--R     + 
+--R                                          2 +-+
+--R              4         +-+4+-+4+-+3     x \|f
+--R       (4b f x  + 4b e)\|2 \|e \|f  atan(------)
+--R                                           +-+
+--R                                          \|e
+--R     + 
+--R            3       2  +-+ +-+4+-+ +-+4+-+3
+--R       (4c x  + 4b x )\|2 \|e \|e \|f \|f
+--R  /
+--R             4      2  +-+ +-+4+-+ +-+4+-+3
+--R     (16e f x  + 16e )\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+)clear all
+
+--S 325 of 567
+t0:=(a+b*x+c*x^2)/(e+f*x^4)^2
+--R 
+--R
+--R              2
+--R           c x  + b x + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 325
+
+--S 326 of 567
+r0:=1/4*x*(a+b*x+c*x^2)/(e*(e+f*x^4))+1/4*b*atan(x^2*sqrt(f)/sqrt(e))/_
+   (e^(3/2)*sqrt(f))+1/16*log(-e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*_
+   sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))-_
+   1/16*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-_
+   3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))-1/8*atan(1-f^(1/4)*x*_
+   sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))+_
+   1/8*atan(1+f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/_
+   (e^(7/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                    4      2  +-+        2 4           +-+
+--R         ((- c e f x  - c e )\|f  + (3a f x  + 3a e f)\|e )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                  4      2  +-+          2 4           +-+
+--R         ((c e f x  + c e )\|f  + (- 3a f x  - 3a e f)\|e )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                                +-+4+-+   4+-+
+--R                 4       2  +-+        2 4           +-+      x\|2 \|f  + \|e
+--R       ((2c e f x  + 2c e )\|f  + (6a f x  + 6a e f)\|e )atan(----------------)
+--R                                                                    4+-+
+--R                                                                    \|e
+--R     + 
+--R                                                                +-+4+-+   4+-+
+--R                 4       2  +-+        2 4           +-+      x\|2 \|f  - \|e
+--R       ((2c e f x  + 2c e )\|f  + (6a f x  + 6a e f)\|e )atan(----------------)
+--R                                                                    4+-+
+--R                                                                    \|e
+--R     + 
+--R                                            2 +-+
+--R              4         +-+4+-+3 4+-+3     x \|f
+--R       (4b f x  + 4b e)\|2 \|e   \|f  atan(------)
+--R                                             +-+
+--R                                            \|e
+--R     + 
+--R            3       2         +-+ +-+4+-+3 +-+4+-+3
+--R       (4c x  + 4b x  + 4a x)\|2 \|e \|e  \|f \|f
+--R  /
+--R             4      2  +-+ +-+4+-+3 +-+4+-+3
+--R     (16e f x  + 16e )\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 567
+t0:=d*x^3/(e+f*x^4)^2
+--R 
+--R
+--R                   3
+--R                d x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 328
+
+--S 329 of 567
+r0:=-1/4*d/(f*(e+f*x^4))
+--R 
+--R
+--R              1
+--R              - d
+--R              4
+--R   (2)  - ----------
+--R           2 4
+--R          f x  + e f
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 329
+
+--S 330 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 567
+t0:=(a+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R                 3
+--R              d x  + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 331
+
+--S 332 of 567
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*a*x/(e*(e+f*x^4))-3/8*a*atan(1-f^(1/4)*x*_
+   sqrt(2)/e^(1/4))/(e^(7/4)*f^(1/4)*sqrt(2))+3/8*a*atan(1+f^(1/4)*x*_
+   sqrt(2)/e^(1/4))/(e^(7/4)*f^(1/4)*sqrt(2))-3/16*a*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))+_
+   3/16*a*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*_
+   f^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            2 4                +-+4+-+4+-+    2 +-+    +-+
+--R       (3a f x  + 3a e f)log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              2 4                  +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a f x  - 3a e f)log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                +-+4+-+   4+-+
+--R            2 4               x\|2 \|f  + \|e
+--R       (6a f x  + 6a e f)atan(----------------)
+--R                                    4+-+
+--R                                    \|e
+--R     + 
+--R                                +-+4+-+   4+-+
+--R            2 4               x\|2 \|f  - \|e                     +-+4+-+3 4+-+
+--R       (6a f x  + 6a e f)atan(----------------) + (4a f x - 4d e)\|2 \|e   \|f
+--R                                    4+-+
+--R                                    \|e
+--R  /
+--R           2 4      2   +-+4+-+3 4+-+
+--R     (16e f x  + 16e f)\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 567
+t0:=(b*x+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R                3
+--R             d x  + b x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 334
+
+--S 335 of 567
+r0:=1/4*(-d*e+b*f*x^2)/(e*f*(e+f*x^4))+1/4*b*atan(x^2*sqrt(f)/sqrt(e))/_
+   (e^(3/2)*sqrt(f))
+--R 
+--R
+--R                              2 +-+
+--R            2 4              x \|f           2        +-+ +-+
+--R        (b f x  + b e f)atan(------) + (b f x  - d e)\|e \|f
+--R                               +-+
+--R                              \|e
+--R   (2)  -----------------------------------------------------
+--R                            2 4     2   +-+ +-+
+--R                       (4e f x  + 4e f)\|e \|f
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 567
+t0:=(a+b*x+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R              3
+--R           d x  + b x + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 337
+
+--S 338 of 567
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*x*(a+b*x)/(e*(e+f*x^4))-3/8*a*atan(1-f^(1/4)*_
+   x*sqrt(2)/e^(1/4))/(e^(7/4)*f^(1/4)*sqrt(2))+3/8*a*atan(1+f^(1/4)*x*_
+   sqrt(2)/e^(1/4))/(e^(7/4)*f^(1/4)*sqrt(2))-3/16*a*log(-e^(1/4)*f^(1/4)*_
+   x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*sqrt(2))+3/16*a*_
+   log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(7/4)*f^(1/4)*_
+   sqrt(2))+1/4*b*atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R            2 4           +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       (3a f x  + 3a e f)\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R              2 4           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3a f x  - 3a e f)\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R            2 4           +-+ +-+     x\|2 \|f  + \|e
+--R       (6a f x  + 6a e f)\|e \|f atan(----------------)
+--R                                            4+-+
+--R                                            \|e
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R            2 4           +-+ +-+     x\|2 \|f  - \|e
+--R       (6a f x  + 6a e f)\|e \|f atan(----------------)
+--R                                            4+-+
+--R                                            \|e
+--R     + 
+--R                                             2 +-+
+--R            2 4           +-+4+-+3 4+-+     x \|f
+--R       (4b f x  + 4b e f)\|2 \|e   \|f atan(------)
+--R                                              +-+
+--R                                             \|e
+--R     + 
+--R              2                  +-+ +-+4+-+3 +-+4+-+
+--R       (4b f x  + 4a f x - 4d e)\|2 \|e \|e  \|f \|f
+--R  /
+--R           2 4      2   +-+ +-+4+-+3 +-+4+-+
+--R     (16e f x  + 16e f)\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 567
+t0:=(c*x^2+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R               3      2
+--R            d x  + c x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 340
+
+--S 341 of 567
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*c*x^3/(e*(e+f*x^4))-1/8*c*atan(1-f^(1/4)*x*_
+   sqrt(2)/e^(1/4))/(e^(5/4)*f^(3/4)*sqrt(2))+1/8*c*atan(1+f^(1/4)*x*_
+   sqrt(2)/e^(1/4))/(e^(5/4)*f^(3/4)*sqrt(2))+1/16*c*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))-_
+   1/16*c*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/_
+   (e^(5/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2 4               +-+4+-+4+-+    2 +-+    +-+
+--R       (- c f x  - c e f)log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           2 4                 +-+4+-+4+-+    2 +-+    +-+
+--R       (c f x  + c e f)log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                +-+4+-+   4+-+
+--R            2 4               x\|2 \|f  + \|e
+--R       (2c f x  + 2c e f)atan(----------------)
+--R                                    4+-+
+--R                                    \|e
+--R     + 
+--R                                +-+4+-+   4+-+
+--R            2 4               x\|2 \|f  - \|e            3         +-+4+-+4+-+3
+--R       (2c f x  + 2c e f)atan(----------------) + (4c f x  - 4d e)\|2 \|e \|f
+--R                                    4+-+
+--R                                    \|e
+--R  /
+--R           2 4      2   +-+4+-+4+-+3
+--R     (16e f x  + 16e f)\|2 \|e \|f
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 567
+t0:=(a+c*x^2+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R             3      2
+--R          d x  + c x  + a
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 343
+
+--S 344 of 567
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*x*(a+c*x^2)/(e*(e+f*x^4))+1/16*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/_
+   (e^(7/4)*f^(3/4)*sqrt(2))-1/16*log(e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/(e^(7/4)*f^(3/4)*_
+   sqrt(2))-1/8*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*_
+   sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))+1/8*atan(1+f^(1/4)*x*sqrt(2)/_
+   e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               2 4           +-+         2 4          +-+
+--R         ((3a f x  + 3a e f)\|f  + (- c f x  - c e f)\|e )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                 2 4           +-+       2 4          +-+
+--R         ((- 3a f x  - 3a e f)\|f  + (c f x  + c e f)\|e )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                                               +-+4+-+   4+-+
+--R             2 4           +-+        2 4           +-+      x\|2 \|f  + \|e
+--R       ((6a f x  + 6a e f)\|f  + (2c f x  + 2c e f)\|e )atan(----------------)
+--R                                                                   4+-+
+--R                                                                   \|e
+--R     + 
+--R                                                               +-+4+-+   4+-+
+--R             2 4           +-+        2 4           +-+      x\|2 \|f  - \|e
+--R       ((6a f x  + 6a e f)\|f  + (2c f x  + 2c e f)\|e )atan(----------------)
+--R                                                                   4+-+
+--R                                                                   \|e
+--R     + 
+--R              3                  +-+4+-+3 4+-+3
+--R       (4c f x  + 4a f x - 4d e)\|2 \|e   \|f
+--R  /
+--R           2 4      2   +-+4+-+3 4+-+3
+--R     (16e f x  + 16e f)\|2 \|e   \|f
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 567
+t0:=(b*x+c*x^2+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R            3      2
+--R         d x  + c x  + b x
+--R   (1)  -------------------
+--R         2 8         4    2
+--R        f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 346
+
+--S 347 of 567
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*x^2*(b+c*x)/(e*(e+f*x^4))-1/8*c*atan(1-f^(1/4)*_
+   x*sqrt(2)/e^(1/4))/(e^(5/4)*f^(3/4)*sqrt(2))+1/8*c*atan(1+f^(1/4)*_
+   x*sqrt(2)/e^(1/4))/(e^(5/4)*f^(3/4)*sqrt(2))+1/16*c*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(5/4)*f^(3/4)*sqrt(2))-_
+   1/16*c*log(e^(1/4)*f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))/(e^(5/4)*_
+   f^(3/4)*sqrt(2))+1/4*b*atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))
+--R 
+--R
+--R   (2)
+--R             2 4          +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       (- c f x  - c e f)\|e \|f log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R           2 4          +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       (c f x  + c e f)\|e \|f log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R            2 4           +-+ +-+     x\|2 \|f  + \|e
+--R       (2c f x  + 2c e f)\|e \|f atan(----------------)
+--R                                            4+-+
+--R                                            \|e
+--R     + 
+--R                                        +-+4+-+   4+-+
+--R            2 4           +-+ +-+     x\|2 \|f  - \|e
+--R       (2c f x  + 2c e f)\|e \|f atan(----------------)
+--R                                            4+-+
+--R                                            \|e
+--R     + 
+--R                                            2 +-+
+--R            2 4           +-+4+-+4+-+3     x \|f
+--R       (4b f x  + 4b e f)\|2 \|e \|f  atan(------)
+--R                                             +-+
+--R                                            \|e
+--R     + 
+--R              3         2         +-+ +-+4+-+ +-+4+-+3
+--R       (4c f x  + 4b f x  - 4d e)\|2 \|e \|e \|f \|f
+--R  /
+--R           2 4      2   +-+ +-+4+-+ +-+4+-+3
+--R     (16e f x  + 16e f)\|2 \|e \|e \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 567
+t0:=(a+b*x+c*x^2+d*x^3)/(e+f*x^4)^2
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + b x + a
+--R   (1)  ---------------------
+--R          2 8         4    2
+--R         f x  + 2e f x  + e
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 349
+
+--S 350 of 567
+r0:=-1/4*d/(f*(e+f*x^4))+1/4*x*(a+b*x+c*x^2)/(e*(e+f*x^4))+1/4*b*_
+   atan(x^2*sqrt(f)/sqrt(e))/(e^(3/2)*sqrt(f))+1/16*log(-e^(1/4)*_
+   f^(1/4)*x*sqrt(2)+sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/_
+   (e^(7/4)*f^(3/4)*sqrt(2))-1/16*log(e^(1/4)*f^(1/4)*x*sqrt(2)+_
+   sqrt(e)+x^2*sqrt(f))*(c*sqrt(e)-3*a*sqrt(f))/(e^(7/4)*f^(3/4)*_
+   sqrt(2))-1/8*atan(1-f^(1/4)*x*sqrt(2)/e^(1/4))*(c*sqrt(e)+3*a*_
+   sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))+1/8*atan(1+f^(1/4)*x*sqrt(2)/_
+   e^(1/4))*(c*sqrt(e)+3*a*sqrt(f))/(e^(7/4)*f^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  2 4      2   +-+        3 4         2  +-+
+--R         ((- c e f x  - c e f)\|f  + (3a f x  + 3a e f )\|e )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                2 4      2   +-+          3 4         2  +-+
+--R         ((c e f x  + c e f)\|f  + (- 3a f x  - 3a e f )\|e )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|e \|f  + x \|f  + \|e )
+--R     + 
+--R                 2 4       2   +-+        3 4         2  +-+
+--R         ((2c e f x  + 2c e f)\|f  + (6a f x  + 6a e f )\|e )
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|f  + \|e
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|e
+--R     + 
+--R                 2 4       2   +-+        3 4         2  +-+
+--R         ((2c e f x  + 2c e f)\|f  + (6a f x  + 6a e f )\|e )
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|f  - \|e
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|e
+--R     + 
+--R                                              2 +-+
+--R            2 4           +-+4+-+3 4+-+3     x \|f
+--R       (4b f x  + 4b e f)\|2 \|e   \|f  atan(------)
+--R                                               +-+
+--R                                              \|e
+--R     + 
+--R              3         2                  +-+ +-+4+-+3 +-+4+-+3
+--R       (4c f x  + 4b f x  + 4a f x - 4d e)\|2 \|e \|e  \|f \|f
+--R  /
+--R           2 4      2   +-+ +-+4+-+3 +-+4+-+3
+--R     (16e f x  + 16e f)\|2 \|e \|e  \|f \|f
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 567
+t0:=a/(2+3*x^4)
+--R 
+--R
+--R           a
+--R   (1)  -------
+--R          4
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 352
+
+--S 353 of 567
+r0:=-1/4*a*atan(1-6^(1/4)*x)/6^(1/4)+1/4*a*atan(1+6^(1/4)*x)/6^(1/4)-_
+   1/8*a*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)+1/8*a*_
+   log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)
+--R 
+--R
+--R   (2)
+--R               4+-+3 4+-+   2 +-+    +-+              4+-+3 4+-+   2 +-+    +-+
+--R       a log(x \|2   \|3 + x \|3  + \|2 ) - a log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R                4+-+                 4+-+
+--R       2a atan(x\|6  + 1) + 2a atan(x\|6  - 1)
+--R  /
+--R      4+-+
+--R     8\|6
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           4+-+2       2 4+-+3 4+-+3   4+-+4+-+ 4+-+       2
+--R        2a \|6   + (a x  \|2   \|3 - 2a\|2 \|3 )\|6  - 6a x
+--R   (3)  ----------------------------------------------------
+--R                               4     4+-+2
+--R                           (12x  + 8)\|6
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 567
+t0:=b*x/(2+3*x^4)
+--R 
+--R
+--R          b x
+--R   (1)  -------
+--R          4
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 355
+
+--S 356 of 567
+r0:=1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R                2 +-+
+--R               x \|3
+--R        b atan(------)
+--R                 +-+
+--R                \|2
+--R   (2)  --------------
+--R               +-+
+--R             2\|6
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              +-+ +-+ +-+
+--R        - b x\|2 \|3 \|6  + 6b x
+--R   (3)  ------------------------
+--R                   4
+--R                18x  + 12
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 567
+t0:=(a+b*x)/(2+3*x^4)
+--R 
+--R
+--R        b x + a
+--R   (1)  -------
+--R          4
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 358
+
+--S 359 of 567
+r0:=-1/4*a*atan(1-6^(1/4)*x)/6^(1/4)+1/4*a*atan(1+6^(1/4)*x)/6^(1/4)-_
+   1/8*a*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)+1/8*a*_
+   log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)+1/2*b*atan(x^2*_
+   sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R         +-+      4+-+3 4+-+   2 +-+    +-+
+--R       a\|6 log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+        4+-+3 4+-+   2 +-+    +-+       +-+      4+-+
+--R       - a\|6 log(- x \|2   \|3 + x \|3  + \|2 ) + 2a\|6 atan(x\|6  + 1)
+--R     + 
+--R                                           2 +-+
+--R          +-+      4+-+          4+-+     x \|3
+--R       2a\|6 atan(x\|6  - 1) + 4b\|6 atan(------)
+--R                                            +-+
+--R                                           \|2
+--R  /
+--R       +-+4+-+
+--R     8\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                  4+-+2       2 4+-+3 4+-+3   4+-+4+-+ 4+-+        4+-+2 4+-+2
+--R       (4b x + 2a)\|6   + (a x  \|2   \|3 - 2a\|2 \|3 )\|6  - 4b x \|2   \|3
+--R     + 
+--R             2
+--R       - 6a x
+--R  /
+--R         4     4+-+2
+--R     (12x  + 8)\|6
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 567
+t0:=c*x^2/(2+3*x^4)
+--R 
+--R
+--R             2
+--R          c x
+--R   (1)  -------
+--R          4
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 361
+
+--S 362 of 567
+r0:=-1/2*c*atan(1-6^(1/4)*x)/6^(3/4)+1/2*c*atan(1+6^(1/4)*x)/6^(3/4)+_
+   1/4*c*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)-1/4*c*_
+   log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R                 4+-+3 4+-+   2 +-+    +-+
+--R       - c log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R                 4+-+3 4+-+   2 +-+    +-+             4+-+
+--R       c log(- x \|2   \|3 + x \|3  + \|2 ) + 2c atan(x\|6  + 1)
+--R     + 
+--R                4+-+
+--R       2c atan(x\|6  - 1)
+--R  /
+--R      4+-+3
+--R     4\|6
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              2 4+-+3 4+-+3   4+-+4+-+ 4+-+3       2 4+-+2
+--R        (- c x  \|2   \|3 + 2c\|2 \|3 )\|6   + 6c x  \|6  - 12c
+--R   (3)  -------------------------------------------------------
+--R                                4      4+-+2
+--R                            (36x  + 24)\|6
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 567
+t0:=(a+c*x^2)/(2+3*x^4)
+--R 
+--R
+--R           2
+--R        c x  + a
+--R   (1)  --------
+--R           4
+--R         3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 364
+
+--S 365 of 567
+r0:=-1/8*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*(-2*c+a*_
+   sqrt(6))/6^(3/4)+1/8*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*_
+   (-2*c+a*sqrt(6))/6^(3/4)-1/4*atan(1-6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)+_
+   1/4*atan(1+6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R          +-+            4+-+3 4+-+   2 +-+    +-+
+--R       (a\|6  - 2c)log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R            +-+              4+-+3 4+-+   2 +-+    +-+
+--R       (- a\|6  + 2c)log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+            4+-+            +-+            4+-+
+--R       (2a\|6  + 4c)atan(x\|6  + 1) + (2a\|6  + 4c)atan(x\|6  - 1)
+--R  /
+--R      4+-+3
+--R     8\|6
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R             2 4+-+3 4+-+3   4+-+4+-+ 4+-+3        2      4+-+2
+--R       (- c x  \|2   \|3 + 2c\|2 \|3 )\|6   + (6c x  + 6a)\|6
+--R     + 
+--R            2 4+-+3 4+-+3   4+-+4+-+ 4+-+        2
+--R       (3a x  \|2   \|3 - 6a\|2 \|3 )\|6  - 18a x  - 12c
+--R  /
+--R         4      4+-+2
+--R     (36x  + 24)\|6
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 567
+t0:=(b*x+c*x^2)/(2+3*x^4)
+--R 
+--R
+--R           2
+--R        c x  + b x
+--R   (1)  ----------
+--R            4
+--R          3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 367
+
+--S 368 of 567
+r0:=-1/2*c*atan(1-6^(1/4)*x)/6^(3/4)+1/2*c*atan(1+6^(1/4)*x)/6^(3/4)+_
+   1/4*c*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)-1/4*c*_
+   log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)+1/2*b*atan(x^2*_
+   sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R           +-+      4+-+3 4+-+   2 +-+    +-+
+--R       - c\|6 log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R         +-+        4+-+3 4+-+   2 +-+    +-+       +-+      4+-+
+--R       c\|6 log(- x \|2   \|3 + x \|3  + \|2 ) + 2c\|6 atan(x\|6  + 1)
+--R     + 
+--R                                             2 +-+
+--R          +-+      4+-+           4+-+3     x \|3
+--R       2c\|6 atan(x\|6  - 1) + 2b \|6  atan(------)
+--R                                              +-+
+--R                                             \|2
+--R  /
+--R       +-+4+-+3
+--R     4\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R             2 4+-+3 4+-+3   4+-+4+-+ 4+-+3        2         4+-+2
+--R       (- c x  \|2   \|3 + 2c\|2 \|3 )\|6   + (6c x  + 12b x)\|6
+--R     + 
+--R               4+-+2 4+-+2
+--R       - 12b x \|2   \|3  - 12c
+--R  /
+--R         4      4+-+2
+--R     (36x  + 24)\|6
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 567
+t0:=(a+b*x+c*x^2)/(2+3*x^4)
+--R 
+--R
+--R           2
+--R        c x  + b x + a
+--R   (1)  --------------
+--R              4
+--R            3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 370
+
+--S 371 of 567
+r0:=1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)-1/8*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+_
+   x^2*sqrt(3))*(-2*c+a*sqrt(6))/6^(3/4)+1/8*log(2^(3/4)*3^(1/4)*x+_
+   sqrt(2)+x^2*sqrt(3))*(-2*c+a*sqrt(6))/6^(3/4)-1/4*atan(1-6^(1/4)*x)*_
+   (2*c+a*sqrt(6))/6^(3/4)+1/4*atan(1+6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R            +-+            4+-+3 4+-+   2 +-+    +-+
+--R       (- c\|6  + 3a)log(x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R          +-+              4+-+3 4+-+   2 +-+    +-+
+--R       (c\|6  - 3a)log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+            4+-+            +-+            4+-+
+--R       (2c\|6  + 6a)atan(x\|6  + 1) + (2c\|6  + 6a)atan(x\|6  - 1)
+--R     + 
+--R                     2 +-+
+--R          4+-+3     x \|3
+--R       2b \|6  atan(------)
+--R                      +-+
+--R                     \|2
+--R  /
+--R       +-+4+-+3
+--R     4\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R             2 4+-+3 4+-+3   4+-+4+-+ 4+-+3        2              4+-+2
+--R       (- c x  \|2   \|3 + 2c\|2 \|3 )\|6   + (6c x  + 12b x + 6a)\|6
+--R     + 
+--R            2 4+-+3 4+-+3   4+-+4+-+ 4+-+         4+-+2 4+-+2       2
+--R       (3a x  \|2   \|3 - 6a\|2 \|3 )\|6  - 12b x \|2   \|3  - 18a x  - 12c
+--R  /
+--R         4      4+-+2
+--R     (36x  + 24)\|6
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 567
+t0:=d*x^3/(2+3*x^4)
+--R 
+--R
+--R             3
+--R          d x
+--R   (1)  -------
+--R          4
+--R        3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 373
+
+--S 374 of 567
+r0:=1/12*d*log(2+3*x^4)
+--R 
+--R
+--R                4
+--R        d log(3x  + 2)
+--R   (2)  --------------
+--R              12
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 567
+t0:=(a+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3
+--R        d x  + a
+--R   (1)  --------
+--R           4
+--R         3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 376
+
+--S 377 of 567
+r0:=-1/4*a*atan(1-6^(1/4)*x)/6^(1/4)+1/4*a*atan(1+6^(1/4)*x)/6^(1/4)+_
+   1/12*d*log(2+3*x^4)-1/8*a*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*_
+   sqrt(3))/6^(1/4)+1/8*a*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)
+--R 
+--R
+--R   (2)
+--R                4+-+3 4+-+   2 +-+    +-+      4+-+      4
+--R       3a log(x \|2   \|3 + x \|3  + \|2 ) + 2d\|6 log(3x  + 2)
+--R     + 
+--R                    4+-+3 4+-+   2 +-+    +-+             4+-+
+--R       - 3a log(- x \|2   \|3 + x \|3  + \|2 ) + 6a atan(x\|6  + 1)
+--R     + 
+--R                4+-+
+--R       6a atan(x\|6  - 1)
+--R  /
+--R       4+-+
+--R     24\|6
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R           4+-+2       2 4+-+3 4+-+3   4+-+4+-+ 4+-+       2
+--R        2a \|6   + (a x  \|2   \|3 - 2a\|2 \|3 )\|6  - 6a x
+--R   (3)  ----------------------------------------------------
+--R                               4     4+-+2
+--R                           (12x  + 8)\|6
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 567
+t0:=(b*x+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3
+--R        d x  + b x
+--R   (1)  ----------
+--R            4
+--R          3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 379
+
+--S 380 of 567
+r0:=1/12*d*log(2+3*x^4)+1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R                                     2 +-+
+--R          +-+      4                x \|3
+--R        d\|6 log(3x  + 2) + 6b atan(------)
+--R                                      +-+
+--R                                     \|2
+--R   (2)  -----------------------------------
+--R                          +-+
+--R                       12\|6
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              +-+ +-+ +-+
+--R        - b x\|2 \|3 \|6  + 6b x
+--R   (3)  ------------------------
+--R                   4
+--R                18x  + 12
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 567
+t0:=(a+b*x+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3
+--R        d x  + b x + a
+--R   (1)  --------------
+--R              4
+--R            3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 382
+
+--S 383 of 567
+r0:=-1/4*a*atan(1-6^(1/4)*x)/6^(1/4)+1/4*a*atan(1+6^(1/4)*x)/6^(1/4)+_
+   1/12*d*log(2+3*x^4)-1/8*a*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/_
+   6^(1/4)+1/8*a*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(1/4)+_
+   1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R          +-+      4+-+3 4+-+   2 +-+    +-+       +-+4+-+      4
+--R       3a\|6 log(x \|2   \|3 + x \|3  + \|2 ) + 2d\|6 \|6 log(3x  + 2)
+--R     + 
+--R            +-+        4+-+3 4+-+   2 +-+    +-+       +-+      4+-+
+--R       - 3a\|6 log(- x \|2   \|3 + x \|3  + \|2 ) + 6a\|6 atan(x\|6  + 1)
+--R     + 
+--R                                            2 +-+
+--R          +-+      4+-+           4+-+     x \|3
+--R       6a\|6 atan(x\|6  - 1) + 12b\|6 atan(------)
+--R                                             +-+
+--R                                            \|2
+--R  /
+--R        +-+4+-+
+--R     24\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                  4+-+2       2 4+-+3 4+-+3   4+-+4+-+ 4+-+        4+-+2 4+-+2
+--R       (4b x + 2a)\|6   + (a x  \|2   \|3 - 2a\|2 \|3 )\|6  - 4b x \|2   \|3
+--R     + 
+--R             2
+--R       - 6a x
+--R  /
+--R         4     4+-+2
+--R     (12x  + 8)\|6
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 567
+t0:=(c*x^2+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x
+--R   (1)  -----------
+--R            4
+--R          3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 385
+
+--S 386 of 567
+r0:=-1/2*c*atan(1-6^(1/4)*x)/6^(3/4)+1/2*c*atan(1+6^(1/4)*x)/6^(3/4)+_
+   1/12*d*log(2+3*x^4)+1/4*c*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/_
+   6^(3/4)-1/4*c*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R                  4+-+3 4+-+   2 +-+    +-+      4+-+3      4
+--R       - 3c log(x \|2   \|3 + x \|3  + \|2 ) + d \|6  log(3x  + 2)
+--R     + 
+--R                  4+-+3 4+-+   2 +-+    +-+             4+-+
+--R       3c log(- x \|2   \|3 + x \|3  + \|2 ) + 6c atan(x\|6  + 1)
+--R     + 
+--R                4+-+
+--R       6c atan(x\|6  - 1)
+--R  /
+--R       4+-+3
+--R     12\|6
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              2 4+-+3 4+-+3   4+-+4+-+ 4+-+3       2 4+-+2
+--R        (- c x  \|2   \|3 + 2c\|2 \|3 )\|6   + 6c x  \|6  - 12c
+--R   (3)  -------------------------------------------------------
+--R                                4      4+-+2
+--R                            (36x  + 24)\|6
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 567
+t0:=(a+c*x^2+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + a
+--R   (1)  ---------------
+--R              4
+--R            3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 388
+
+--S 389 of 567
+r0:=1/12*d*log(2+3*x^4)-1/8*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*_
+   (-2*c+a*sqrt(6))/6^(3/4)+1/8*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*_
+   (-2*c+a*sqrt(6))/6^(3/4)-1/4*atan(1-6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)+_
+   1/4*atan(1+6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R           +-+            4+-+3 4+-+   2 +-+    +-+       4+-+3      4
+--R       (3a\|6  - 6c)log(x \|2   \|3 + x \|3  + \|2 ) + 2d \|6  log(3x  + 2)
+--R     + 
+--R             +-+              4+-+3 4+-+   2 +-+    +-+
+--R       (- 3a\|6  + 6c)log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+             4+-+            +-+             4+-+
+--R       (6a\|6  + 12c)atan(x\|6  + 1) + (6a\|6  + 12c)atan(x\|6  - 1)
+--R  /
+--R       4+-+3
+--R     24\|6
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R             2 4+-+3 4+-+3   4+-+4+-+ 4+-+3        2      4+-+2
+--R       (- c x  \|2   \|3 + 2c\|2 \|3 )\|6   + (6c x  + 6a)\|6
+--R     + 
+--R            2 4+-+3 4+-+3   4+-+4+-+ 4+-+        2
+--R       (3a x  \|2   \|3 - 6a\|2 \|3 )\|6  - 18a x  - 12c
+--R  /
+--R         4      4+-+2
+--R     (36x  + 24)\|6
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 567
+t0:=(b*x+c*x^2+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + b x
+--R   (1)  -----------------
+--R               4
+--R             3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 391
+
+--S 392 of 567
+r0:=-1/2*c*atan(1-6^(1/4)*x)/6^(3/4)+1/2*c*atan(1+6^(1/4)*x)/6^(3/4)+_
+   1/12*d*log(2+3*x^4)+1/4*c*log(-2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/_
+   6^(3/4)-1/4*c*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))/6^(3/4)+_
+   1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)
+--R 
+--R
+--R   (2)
+--R            +-+      4+-+3 4+-+   2 +-+    +-+      +-+4+-+3      4
+--R       - 3c\|6 log(x \|2   \|3 + x \|3  + \|2 ) + d\|6 \|6  log(3x  + 2)
+--R     + 
+--R          +-+        4+-+3 4+-+   2 +-+    +-+       +-+      4+-+
+--R       3c\|6 log(- x \|2   \|3 + x \|3  + \|2 ) + 6c\|6 atan(x\|6  + 1)
+--R     + 
+--R                                             2 +-+
+--R          +-+      4+-+           4+-+3     x \|3
+--R       6c\|6 atan(x\|6  - 1) + 6b \|6  atan(------)
+--R                                              +-+
+--R                                             \|2
+--R  /
+--R        +-+4+-+3
+--R     12\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R             2 4+-+3 4+-+3   4+-+4+-+ 4+-+3        2         4+-+2
+--R       (- c x  \|2   \|3 + 2c\|2 \|3 )\|6   + (6c x  + 12b x)\|6
+--R     + 
+--R               4+-+2 4+-+2
+--R       - 12b x \|2   \|3  - 12c
+--R  /
+--R         4      4+-+2
+--R     (36x  + 24)\|6
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 567
+t0:=(a+b*x+c*x^2+d*x^3)/(2+3*x^4)
+--R 
+--R
+--R           3      2
+--R        d x  + c x  + b x + a
+--R   (1)  ---------------------
+--R                 4
+--R               3x  + 2
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 394
+
+--S 395 of 567
+r0:=1/12*d*log(2+3*x^4)+1/2*b*atan(x^2*sqrt(3/2))/sqrt(6)-1/8*log(-2^(3/4)*_
+   3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*(-2*c+a*sqrt(6))/6^(3/4)+_
+   1/8*log(2^(3/4)*3^(1/4)*x+sqrt(2)+x^2*sqrt(3))*(-2*c+a*sqrt(6))/_
+   6^(3/4)-1/4*atan(1-6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)+1/4*atan(1+_
+   6^(1/4)*x)*(2*c+a*sqrt(6))/6^(3/4)
+--R 
+--R
+--R   (2)
+--R             +-+            4+-+3 4+-+   2 +-+    +-+      +-+4+-+3      4
+--R       (- 3c\|6  + 9a)log(x \|2   \|3 + x \|3  + \|2 ) + d\|6 \|6  log(3x  + 2)
+--R     + 
+--R           +-+              4+-+3 4+-+   2 +-+    +-+
+--R       (3c\|6  - 9a)log(- x \|2   \|3 + x \|3  + \|2 )
+--R     + 
+--R           +-+             4+-+            +-+             4+-+
+--R       (6c\|6  + 18a)atan(x\|6  + 1) + (6c\|6  + 18a)atan(x\|6  - 1)
+--R     + 
+--R                     2 +-+
+--R          4+-+3     x \|3
+--R       6b \|6  atan(------)
+--R                      +-+
+--R                     \|2
+--R  /
+--R        +-+4+-+3
+--R     12\|6 \|6
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R             2 4+-+3 4+-+3   4+-+4+-+ 4+-+3        2              4+-+2
+--R       (- c x  \|2   \|3 + 2c\|2 \|3 )\|6   + (6c x  + 12b x + 6a)\|6
+--R     + 
+--R            2 4+-+3 4+-+3   4+-+4+-+ 4+-+         4+-+2 4+-+2       2
+--R       (3a x  \|2   \|3 - 6a\|2 \|3 )\|6  - 12b x \|2   \|3  - 18a x  - 12c
+--R  /
+--R         4      4+-+2
+--R     (36x  + 24)\|6
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 567
+t0:=(c+d*x)/(a+b*x^4)
+--R 
+--R
+--R         d x + c
+--R   (1)  --------
+--R           4
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 397
+
+--S 398 of 567
+r0:=-1/2*c*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*sqrt(2))+_
+   1/2*c*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))/(a^(3/4)*b^(1/4)*sqrt(2))-_
+   1/4*c*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))/_
+   (a^(3/4)*b^(1/4)*sqrt(2))+1/4*c*log(a^(1/4)*b^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(b))/(a^(3/4)*b^(1/4)*sqrt(2))+1/2*d*atan(x^2*_
+   sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R         +-+ +-+      +-+4+-+4+-+    2 +-+    +-+
+--R       c\|a \|b log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R           +-+ +-+        +-+4+-+4+-+    2 +-+    +-+
+--R       - c\|a \|b log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                        +-+4+-+   4+-+                     +-+4+-+   4+-+
+--R          +-+ +-+     x\|2 \|b  + \|a        +-+ +-+     x\|2 \|b  - \|a
+--R       2c\|a \|b atan(----------------) + 2c\|a \|b atan(----------------)
+--R                            4+-+                               4+-+
+--R                            \|a                                \|a
+--R     + 
+--R                             2 +-+
+--R          +-+4+-+3 4+-+     x \|b
+--R       2d\|2 \|a   \|b atan(------)
+--R                              +-+
+--R                             \|a
+--R  /
+--R       +-+ +-+4+-+3 +-+4+-+
+--R     4\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 567
+t0:=(c+d*x)/(1+x^4)
+--R 
+--R
+--R        d x + c
+--R   (1)  -------
+--R          4
+--R         x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 400
+
+--S 401 of 567
+r0:=1/2*d*atan(x^2)-1/2*c*atan(1-x*sqrt(2))/sqrt(2)+1/2*c*atan(1+_
+   x*sqrt(2))/sqrt(2)-1/4*c*log(1+x^2-x*sqrt(2))/sqrt(2)+1/4*c*_
+   log(1+x^2+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R   (2)
+--R               +-+    2                  +-+    2                  +-+
+--R       c log(x\|2  + x  + 1) - c log(- x\|2  + x  + 1) + 2c atan(x\|2  + 1)
+--R     + 
+--R                 +-+           +-+      2
+--R       2c atan(x\|2  - 1) + 2d\|2 atan(x )
+--R  /
+--R       +-+
+--R     4\|2
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 567
+t0:=(c+d*x)/(a-b*x^4)
+--R 
+--R
+--R        - d x - c
+--R   (1)  ---------
+--R            4
+--R         b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 403
+
+--S 404 of 567
+r0:=1/2*c*atan(b^(1/4)*x/a^(1/4))/(a^(3/4)*b^(1/4))+1/2*c*atanh(b^(1/4)*_
+   x/a^(1/4))/(a^(3/4)*b^(1/4))+1/2*d*atanh(x^2*sqrt(b)/sqrt(a))/_
+   (sqrt(a)*sqrt(b))
+--R 
+--R
+--R   (2)
+--R                   4+-+                       2 +-+                  4+-+
+--R     +-+ +-+      x\|b       4+-+3 4+-+      x \|b      +-+ +-+     x\|b
+--R   c\|a \|b atanh(-----) + d \|a   \|b atanh(------ + c\|a \|b atan(-----)
+--R                   4+-+                        +-+                   4+-+
+--R                   \|a                        \|a                    \|a
+--R   -----------------------------------------------------------------------
+--R                                +-+4+-+3 +-+4+-+
+--R                              2\|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 567
+t0:=(c+d*x)/(1-x^4)
+--R 
+--R
+--R        - d x - c
+--R   (1)  ---------
+--R           4
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 406
+
+--S 407 of 567
+r0:=1/2*c*atan(x)+1/2*c*atanh(x)+1/2*d*atanh(x^2)
+--R 
+--R
+--R                 2
+--R        d atanh(x ) + c atanh(x) + c atan(x)
+--R   (2)  ------------------------------------
+--R                          2
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 567
+t0:=(1+x+x^2+x^3)/(1-x^4)
+--R 
+--R
+--R            1
+--R   (1)  - -----
+--R          x - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 409
+
+--S 410 of 567
+r0:=-log(1-x)
+--R 
+--R
+--R   (2)  - log(- x + 1)
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 567
+t0:=(1+x+x^2+x^3)/(1+x^4)
+--R 
+--R
+--R         3    2
+--R        x  + x  + x + 1
+--R   (1)  ---------------
+--R              4
+--R             x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 412
+
+--S 413 of 567
+r0:=1/2*atan(x^2)+1/4*log(1+x^4)-atan(1-x*sqrt(2))/sqrt(2)+_
+   atan(1+x*sqrt(2))/sqrt(2)
+--R 
+--R
+--R         +-+     4                +-+                +-+          +-+      2
+--R        \|2 log(x  + 1) + 4atan(x\|2  + 1) + 4atan(x\|2  - 1) + 2\|2 atan(x )
+--R   (2)  ---------------------------------------------------------------------
+--R                                          +-+
+--R                                        4\|2
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 567
+t0:=(1+x+x^2+x^3)/(a-b*x^4)
+--R 
+--R
+--R           3    2
+--R        - x  - x  - x - 1
+--R   (1)  -----------------
+--R                4
+--R             b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 415
+
+--S 416 of 567
+r0:=-1/4*log(a-b*x^4)/b-1/2*atan(b^(1/4)*x/a^(1/4))*(sqrt(a)-_
+   sqrt(b))/(a^(3/4)*b^(3/4))+1/2*atanh(x^2*sqrt(b)/sqrt(a))/_
+   (sqrt(a)*sqrt(b))+1/2*atanh(b^(1/4)*x/a^(1/4))*(sqrt(a)+sqrt(b))/_
+   (a^(3/4)*b^(3/4))
+--R 
+--R
+--R   (2)
+--R                                  4+-+                         2 +-+
+--R             +-+     2 +-+       x\|b        4+-+3 4+-+3      x \|b
+--R       (2a b\|b  + 2b \|a )atanh(-----) + 2b \|a   \|b  atanh(------)
+--R                                  4+-+                          +-+
+--R                                  \|a                          \|a
+--R     + 
+--R                                   4+-+
+--R               +-+     2 +-+      x\|b              4      +-+4+-+3 +-+4+-+3
+--R       (- 2a b\|b  + 2b \|a )atan(-----) - log(- b x  + a)\|a \|a  \|b \|b
+--R                                   4+-+
+--R                                   \|a
+--R  /
+--R        +-+4+-+3 +-+4+-+3
+--R     4b\|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 567
+t0:=(c+d*x+e*x^2+f*x^3)/(a-b*x^4)
+--R 
+--R
+--R             3      2
+--R        - f x  - e x  - d x - c
+--R   (1)  -----------------------
+--R                   4
+--R                b x  - a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 418
+
+--S 419 of 567
+r0:=-1/4*f*log(a-b*x^4)/b+1/2*d*atanh(x^2*sqrt(b)/sqrt(a))/(sqrt(a)*_
+   sqrt(b))+1/2*atan(b^(1/4)*x/a^(1/4))*(-e*sqrt(a)+c*sqrt(b))/(a^(3/4)*_
+   b^(3/4))+1/2*atanh(b^(1/4)*x/a^(1/4))*(e*sqrt(a)+c*sqrt(b))/_
+   (a^(3/4)*b^(3/4))
+--R 
+--R
+--R   (2)
+--R                                     4+-+                           2 +-+
+--R               +-+     2  +-+       x\|b          4+-+3 4+-+3      x \|b
+--R       (2a b e\|b  + 2b c\|a )atanh(-----) + 2b d \|a   \|b  atanh(------)
+--R                                     4+-+                            +-+
+--R                                     \|a                            \|a
+--R     + 
+--R                                    4+-+
+--R               +-+     2  +-+      x\|b                4      +-+4+-+3 +-+4+-+3
+--R     (- 2a b e\|b  + 2b c\|a )atan(-----) - f log(- b x  + a)\|a \|a  \|b \|b
+--R                                    4+-+
+--R                                    \|a
+--R  /
+--R        +-+4+-+3 +-+4+-+3
+--R     4b\|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 567
+t0:=(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^p
+--R 
+--R
+--R            3      2               4     p
+--R   (1)  (f x  + e x  + d x + c)(b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 567
+--r0:=1/4*f*(a+b*x^4)^(1+p)/(b*(1+p))+c*x*(a+b*x^4)^p*_
+--   hypergeometric(1/4,-p,5/4,-b*x^4/a)/((a+b*x^4)/a)^p+1/2*d*x^2*_
+--   (a+b*x^4)^p*hypergeometric(1/2,-p,3/2,-b*x^4/a)/((a+b*x^4)/a)^p+_
+--   1/3*e*x^3*(a+b*x^4)^p*hypergeometric(3/4,-p,7/4,-b*x^4/a)/((a+b*x^4)/a)^p
+--E 422
+
+--S 423 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 423
+
+)clear all
+
+--S 424 of 567
+t0:=(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^4
+--R 
+--R
+--R   (1)
+--R      4   19    4   18    4   17    4   16       3   15       3   14
+--R     b f x   + b e x   + b d x   + b c x   + 4a b f x   + 4a b e x
+--R   + 
+--R         3   13       3   12     2 2   11     2 2   10     2 2   9     2 2   8
+--R     4a b d x   + 4a b c x   + 6a b f x   + 6a b e x   + 6a b d x  + 6a b c x
+--R   + 
+--R     3     7     3     6     3     5     3     4    4   3    4   2    4       4
+--R   4a b f x  + 4a b e x  + 4a b d x  + 4a b c x  + a f x  + a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 424
+
+--S 425 of 567
+r0:=a^4*c*x+1/2*a^4*d*x^2+1/3*a^4*e*x^3+4/5*a^3*b*c*x^5+2/3*a^3*b*d*x^6+_
+   4/7*a^3*b*e*x^7+2/3*a^2*b^2*c*x^9+3/5*a^2*b^2*d*x^10+6/11*a^2*b^2*_
+   e*x^11+4/13*a*b^3*c*x^13+2/7*a*b^3*d*x^14+4/15*a*b^3*e*x^15+_
+   1/17*b^4*c*x^17+1/18*b^4*d*x^18+1/19*b^4*e*x^19+1/20*f*(a+b*x^4)^5/b
+--R 
+--R
+--R   (2)
+--R        1  5   20    1  5   19    1  5   18    1  5   17   1    4   16
+--R       -- b f x   + -- b e x   + -- b d x   + -- b c x   + - a b f x
+--R       20           19           18           17           4
+--R     + 
+--R        4    4   15   2    4   14    4    4   13   1  2 3   12    6  2 3   11
+--R       -- a b e x   + - a b d x   + -- a b c x   + - a b f x   + -- a b e x
+--R       15             7             13             2             11
+--R     + 
+--R       3  2 3   10   2  2 3   9   1  3 2   8   4  3 2   7   2  3 2   6
+--R       - a b d x   + - a b c x  + - a b f x  + - a b e x  + - a b d x
+--R       5             3            2            7            3
+--R     + 
+--R       4  3 2   5   1  4     4   1  4     3   1  4     2    4         1  5
+--R       - a b c x  + - a b f x  + - a b e x  + - a b d x  + a b c x + -- a f
+--R       5            4            3            2                      20
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 425
+
+--S 426 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 567
+t0:=(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3   15    3   14    3   13    3   12       2   11       2   10       2   9
+--R     b f x   + b e x   + b d x   + b c x   + 3a b f x   + 3a b e x   + 3a b d x
+--R   + 
+--R         2   8     2     7     2     6     2     5     2     4    3   3    3   2
+--R     3a b c x  + 3a b f x  + 3a b e x  + 3a b d x  + 3a b c x  + a f x  + a e x
+--R   + 
+--R      3       3
+--R     a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 427
+
+--S 428 of 567
+r0:=a^3*c*x+1/2*a^3*d*x^2+1/3*a^3*e*x^3+3/5*a^2*b*c*x^5+1/2*a^2*b*d*x^6+_
+   3/7*a^2*b*e*x^7+1/3*a*b^2*c*x^9+3/10*a*b^2*d*x^10+3/11*a*b^2*e*x^11+_
+   1/13*b^3*c*x^13+1/14*b^3*d*x^14+1/15*b^3*e*x^15+1/16*f*(a+b*x^4)^4/b
+--R 
+--R
+--R   (2)
+--R        1  4   16    1  4   15    1  4   14    1  4   13   1    3   12
+--R       -- b f x   + -- b e x   + -- b d x   + -- b c x   + - a b f x
+--R       16           15           14           13           4
+--R     + 
+--R        3    3   11    3    3   10   1    3   9   3  2 2   8   3  2 2   7
+--R       -- a b e x   + -- a b d x   + - a b c x  + - a b f x  + - a b e x
+--R       11             10             3            8            7
+--R     + 
+--R       1  2 2   6   3  2 2   5   1  3     4   1  3     3   1  3     2    3
+--R       - a b d x  + - a b c x  + - a b f x  + - a b e x  + - a b d x  + a b c x
+--R       2            5            4            3            2
+--R     + 
+--R        1  4
+--R       -- a f
+--R       16
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 428
+
+--S 429 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 567
+t0:=(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^2
+--R 
+--R
+--R   (1)
+--R      2   11    2   10    2   9    2   8           7           6           5
+--R     b f x   + b e x   + b d x  + b c x  + 2a b f x  + 2a b e x  + 2a b d x
+--R   + 
+--R             4    2   3    2   2    2       2
+--R     2a b c x  + a f x  + a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 430
+
+--S 431 of 567
+r0:=a^2*c*x+1/2*a^2*d*x^2+1/3*a^2*e*x^3+2/5*a*b*c*x^5+1/3*a*b*d*x^6+_
+   2/7*a*b*e*x^7+1/9*b^2*c*x^9+1/10*b^2*d*x^10+1/11*b^2*e*x^11+_
+   1/12*f*(a+b*x^4)^3/b
+--R 
+--R
+--R   (2)
+--R        1  3   12    1  3   11    1  3   10   1  3   9   1    2   8   2    2   7
+--R       -- b f x   + -- b e x   + -- b d x   + - b c x  + - a b f x  + - a b e x
+--R       12           11           10           9          4            7
+--R     + 
+--R       1    2   6   2    2   5   1  2     4   1  2     3   1  2     2    2
+--R       - a b d x  + - a b c x  + - a b f x  + - a b e x  + - a b d x  + a b c x
+--R       3            5            4            3            2
+--R     + 
+--R        1  3
+--R       -- a f
+--R       12
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 431
+
+--S 432 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 567
+t0:=(c+d*x+e*x^2+f*x^3)*(a+b*x^4)
+--R 
+--R
+--R             7        6        5        4        3        2
+--R   (1)  b f x  + b e x  + b d x  + b c x  + a f x  + a e x  + a d x + a c
+--R                                                    Type: Polynomial(Integer)
+--E 433
+
+--S 434 of 567
+r0:=a*c*x+1/2*a*d*x^2+1/3*a*e*x^3+1/4*a*f*x^4+1/5*b*c*x^5+1/6*b*d*x^6+_
+   1/7*b*e*x^7+1/8*b*f*x^8
+--R 
+--R
+--R   (2)
+--R     1      8   1      7   1      6   1      5   1      4   1      3   1      2
+--R     - b f x  + - b e x  + - b d x  + - b c x  + - a f x  + - a e x  + - a d x
+--R     8          7          6          5          4          3          2
+--R   + 
+--R     a c x
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 434
+
+--S 435 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 567
+t0:=(c+d*x+e*x^2+f*x^3)/(a+b*x^4)
+--R 
+--R
+--R           3      2
+--R        f x  + e x  + d x + c
+--R   (1)  ---------------------
+--R                  4
+--R               b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 436
+
+--S 437 of 567
+r0:=1/4*f*log(a+b*x^4)/b+1/2*d*atan(x^2*sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b))-_
+   1/4*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-e*sqrt(a)+_
+   c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))+1/4*log(a^(1/4)*b^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(b))*(-e*sqrt(a)+c*sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))-_
+   1/2*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(e*sqrt(a)+c*sqrt(b))/(a^(3/4)*_
+   b^(3/4)*sqrt(2))+1/2*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(e*sqrt(a)+c*_
+   sqrt(b))/(a^(3/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                +-+    2  +-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (- a b e\|b  + b c\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R              +-+    2  +-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (a b e\|b  - b c\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+     2  +-+      x\|2 \|b  + \|a
+--R       (2a b e\|b  + 2b c\|a )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                     +-+4+-+   4+-+
+--R               +-+     2  +-+      x\|2 \|b  - \|a
+--R       (2a b e\|b  + 2b c\|a )atan(----------------)
+--R                                         4+-+
+--R                                         \|a
+--R     + 
+--R                                2 +-+
+--R            +-+4+-+3 4+-+3     x \|b      +-+       4      +-+4+-+3 +-+4+-+3
+--R       2b d\|2 \|a   \|b  atan(------ + f\|2 log(b x  + a)\|a \|a  \|b \|b
+--R                                 +-+
+--R                                \|a
+--R  /
+--R        +-+ +-+4+-+3 +-+4+-+3
+--R     4b\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 567
+t0:=(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^2
+--R 
+--R
+--R           3      2
+--R        f x  + e x  + d x + c
+--R   (1)  ---------------------
+--R          2 8         4    2
+--R         b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 439
+
+--S 440 of 567
+r0:=-1/4*f/(b*(a+b*x^4))+1/4*x*(c+d*x+e*x^2)/(a*(a+b*x^4))+1/4*d*_
+   atan(x^2*sqrt(b)/sqrt(a))/(a^(3/2)*sqrt(b))-1/16*log(-a^(1/4)*b^(1/4)*_
+   x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-e*sqrt(a)+3*c*sqrt(b))/(a^(7/4)*_
+   b^(3/4)*sqrt(2))+1/16*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*_
+   sqrt(b))*(-e*sqrt(a)+3*c*sqrt(b))/(a^(7/4)*b^(3/4)*sqrt(2))-_
+   1/8*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(e*sqrt(a)+3*c*sqrt(b))/_
+   (a^(7/4)*b^(3/4)*sqrt(2))+1/8*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*_
+   (e*sqrt(a)+3*c*sqrt(b))/(a^(7/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                2   4    2     +-+      3   4       2   +-+
+--R         ((- a b e x  - a b e)\|b  + (3b c x  + 3a b c)\|a )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R              2   4    2     +-+        3   4       2   +-+
+--R         ((a b e x  + a b e)\|b  + (- 3b c x  - 3a b c)\|a )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                                                 +-+4+-+   4+-+
+--R             2   4     2     +-+      3   4       2   +-+      x\|2 \|b  + \|a
+--R       ((2a b e x  + 2a b e)\|b  + (6b c x  + 6a b c)\|a )atan(----------------)
+--R                                                                     4+-+
+--R                                                                     \|a
+--R     + 
+--R                                                                 +-+4+-+   4+-+
+--R             2   4     2     +-+      3   4       2   +-+      x\|2 \|b  - \|a
+--R       ((2a b e x  + 2a b e)\|b  + (6b c x  + 6a b c)\|a )atan(----------------)
+--R                                                                     4+-+
+--R                                                                     \|a
+--R     + 
+--R                                              2 +-+
+--R          2   4           +-+4+-+3 4+-+3     x \|b
+--R       (4b d x  + 4a b d)\|2 \|a   \|b  atan(------)
+--R                                               +-+
+--R                                              \|a
+--R     + 
+--R              3         2                  +-+ +-+4+-+3 +-+4+-+3
+--R       (4b e x  + 4b d x  + 4b c x - 4a f)\|2 \|a \|a  \|b \|b
+--R  /
+--R           2 4      2   +-+ +-+4+-+3 +-+4+-+3
+--R     (16a b x  + 16a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 567
+t0:=(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^3
+--R 
+--R
+--R                3      2
+--R             f x  + e x  + d x + c
+--R   (1)  ------------------------------
+--R         3 12       2 8     2   4    3
+--R        b x   + 3a b x  + 3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 442
+
+--S 443 of 567
+r0:=-1/8*f/(b*(a+b*x^4)^2)+1/8*x*(c+d*x+e*x^2)/(a*(a+b*x^4)^2)+1/32*x*_
+   (7*c+6*d*x+5*e*x^2)/(a^2*(a+b*x^4))+3/16*d*atan(x^2*sqrt(b)/sqrt(a))/_
+   (a^(5/2)*sqrt(b))-1/128*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+_
+   x^2*sqrt(b))*(-5*e*sqrt(a)+21*c*sqrt(b))/(a^(11/4)*b^(3/4)*sqrt(2))+_
+   1/128*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-5*e*_
+   sqrt(a)+21*c*sqrt(b))/(a^(11/4)*b^(3/4)*sqrt(2))-1/64*atan(1-b^(1/4)*_
+   x*sqrt(2)/a^(1/4))*(5*e*sqrt(a)+21*c*sqrt(b))/(a^(11/4)*b^(3/4)*_
+   sqrt(2))+1/64*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(5*e*sqrt(a)+21*c*_
+   sqrt(b))/(a^(11/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  3   8      2 2   4     3     +-+
+--R           (- 5a b e x  - 10a b e x  - 5a b e)\|b
+--R         + 
+--R               4   8        3   4      2 2   +-+
+--R           (21b c x  + 42a b c x  + 21a b c)\|a
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                3   8      2 2   4     3     +-+
+--R           (5a b e x  + 10a b e x  + 5a b e)\|b
+--R         + 
+--R                 4   8        3   4      2 2   +-+
+--R           (- 21b c x  - 42a b c x  - 21a b c)\|a
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                 3   8      2 2   4      3     +-+
+--R           (10a b e x  + 20a b e x  + 10a b e)\|b
+--R         + 
+--R               4   8        3   4      2 2   +-+
+--R           (42b c x  + 84a b c x  + 42a b c)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  + \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                 3   8      2 2   4      3     +-+
+--R           (10a b e x  + 20a b e x  + 10a b e)\|b
+--R         + 
+--R               4   8        3   4      2 2   +-+
+--R           (42b c x  + 84a b c x  + 42a b c)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  - \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                                                             2 +-+
+--R           3   8        2   4      2     +-+4+-+3 4+-+3     x \|b
+--R       (24b d x  + 48a b d x  + 24a b d)\|2 \|a   \|b  atan(------)
+--R                                                              +-+
+--R                                                             \|a
+--R     + 
+--R              2   7      2   6      2   5            3            2
+--R           20b e x  + 24b d x  + 28b c x  + 36a b e x  + 40a b d x  + 44a b c x
+--R         + 
+--R                2
+--R           - 16a f
+--R      *
+--R          +-+ +-+4+-+3 +-+4+-+3
+--R         \|2 \|a \|a  \|b \|b
+--R  /
+--R          2 3 8       3 2 4       4   +-+ +-+4+-+3 +-+4+-+3
+--R     (128a b x  + 256a b x  + 128a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 444
+
+)clear all
+
+--S 445 of 567
+t0:=(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^4
+--R 
+--R
+--R                     3      2
+--R                  f x  + e x  + d x + c
+--R   (1)  -----------------------------------------
+--R         4 16       3 12     2 2 8     3   4    4
+--R        b x   + 4a b x   + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 445
+
+--S 446 of 567
+r0:=-1/12*f/(b*(a+b*x^4)^3)+1/12*x*(c+d*x+e*x^2)/(a*(a+b*x^4)^3)+1/96*x*_
+   (11*c+10*d*x+9*e*x^2)/(a^2*(a+b*x^4)^2)+1/384*x*(77*c+60*d*x+45*e*x^2)/_
+   (a^3*(a+b*x^4))+5/32*d*atan(x^2*sqrt(b)/sqrt(a))/(a^(7/2)*sqrt(b))-_
+   1/512*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-15*e*_
+   sqrt(a)+77*c*sqrt(b))/(a^(15/4)*b^(3/4)*sqrt(2))+1/512*log(a^(1/4)*_
+   b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-15*e*sqrt(a)+77*c*sqrt(b))/_
+   (a^(15/4)*b^(3/4)*sqrt(2))-1/256*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*_
+   (15*e*sqrt(a)+77*c*sqrt(b))/(a^(15/4)*b^(3/4)*sqrt(2))+1/256*_
+   atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(15*e*sqrt(a)+77*c*sqrt(b))/_
+   (a^(15/4)*b^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   4   12       2 3   8       3 2   4      4     +-+
+--R           (- 45a b e x   - 135a b e x  - 135a b e x  - 45a b e)\|b
+--R         + 
+--R                5   12         4   8       2 3   4       3 2   +-+
+--R           (231b c x   + 693a b c x  + 693a b c x  + 231a b c)\|a
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                 4   12       2 3   8       3 2   4      4     +-+
+--R           (45a b e x   + 135a b e x  + 135a b e x  + 45a b e)\|b
+--R         + 
+--R                  5   12         4   8       2 3   4       3 2   +-+
+--R           (- 231b c x   - 693a b c x  - 693a b c x  - 231a b c)\|a
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                 4   12       2 3   8       3 2   4      4     +-+
+--R           (90a b e x   + 270a b e x  + 270a b e x  + 90a b e)\|b
+--R         + 
+--R                5   12          4   8        2 3   4       3 2   +-+
+--R           (462b c x   + 1386a b c x  + 1386a b c x  + 462a b c)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  + \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                 4   12       2 3   8       3 2   4      4     +-+
+--R           (90a b e x   + 270a b e x  + 270a b e x  + 90a b e)\|b
+--R         + 
+--R                5   12          4   8        2 3   4       3 2   +-+
+--R           (462b c x   + 1386a b c x  + 1386a b c x  + 462a b c)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  - \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R              4   12         3   8       2 2   4       3     +-+4+-+3 4+-+3
+--R         (240b d x   + 720a b d x  + 720a b d x  + 240a b d)\|2 \|a   \|b
+--R      *
+--R               2 +-+
+--R              x \|b
+--R         atan(------)
+--R                +-+
+--R               \|a
+--R     + 
+--R               3   11       3   10       3   9         2   7         2   6
+--R           180b e x   + 240b d x   + 308b c x  + 504a b e x  + 640a b d x
+--R         + 
+--R                 2   5       2     3       2     2       2            3
+--R           792a b c x  + 452a b e x  + 528a b d x  + 612a b c x - 128a f
+--R      *
+--R          +-+ +-+4+-+3 +-+4+-+3
+--R         \|2 \|a \|a  \|b \|b
+--R  /
+--R           3 4 12        4 3 8        5 2 4        6   +-+ +-+4+-+3 +-+4+-+3
+--R     (1536a b x   + 4608a b x  + 4608a b x  + 1536a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 567
+t0:=x^3*(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^p
+--R 
+--R
+--R            6      5      4      3     4     p
+--R   (1)  (f x  + e x  + d x  + c x )(b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 567
+--r0:=1/4*c*(a+b*x^4)^(1+p)/(b*(1+p))+d*x*(a+b*x^4)^(1+p)/(b*(5+4*p))+_
+--   1/2*e*x^2*(a+b*x^4)^(1+p)/(b*(3+2*p))+f*x^3*(a+b*x^4)^(1+p)/_
+--   (b*(7+4*p))-a*d*x*(a+b*x^4)^p*hypergeometric(1/4,-p,5/4,-b*x^4/a)/_
+--   (b*(5+4*p)*((a+b*x^4)/a)^p)-1/2*a*e*x^2*(a+b*x^4)^p*_
+--   hypergeometric(1/2,-p,3/2,-b*x^4/a)/(b*(3+2*p)*((a+b*x^4)/a)^p)-_
+--   a*f*x^3*(a+b*x^4)^p*hypergeometric(3/4,-p,7/4,-b*x^4/a)/(b*(7+4*p)*_
+--   ((a+b*x^4)/a)^p)
+--E 449
+
+--S 450 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 450
+
+)clear all
+
+--S 451 of 567
+t0:=x^3*(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^4
+--R 
+--R
+--R   (1)
+--R      4   22    4   21    4   20    4   19       3   18       3   17
+--R     b f x   + b e x   + b d x   + b c x   + 4a b f x   + 4a b e x
+--R   + 
+--R         3   16       3   15     2 2   14     2 2   13     2 2   12     2 2   11
+--R     4a b d x   + 4a b c x   + 6a b f x   + 6a b e x   + 6a b d x   + 6a b c x
+--R   + 
+--R       3     10     3     9     3     8     3     7    4   6    4   5    4   4
+--R     4a b f x   + 4a b e x  + 4a b d x  + 4a b c x  + a f x  + a e x  + a d x
+--R   + 
+--R      4   3
+--R     a c x
+--R                                                    Type: Polynomial(Integer)
+--E 451
+
+--S 452 of 567
+r0:=1/5*a^4*d*x^5+1/6*a^4*e*x^6+1/7*a^4*f*x^7+4/9*a^3*b*d*x^9+2/5*a^3*_
+   b*e*x^10+4/11*a^3*b*f*x^11+6/13*a^2*b^2*d*x^13+3/7*a^2*b^2*e*x^14+_
+   2/5*a^2*b^2*f*x^15+4/17*a*b^3*d*x^17+2/9*a*b^3*e*x^18+4/19*a*b^3*_
+   f*x^19+1/21*b^4*d*x^21+1/22*b^4*e*x^22+1/23*b^4*f*x^23+1/20*c*(a+b*x^4)^5/b
+--R 
+--R
+--R   (2)
+--R        1  5   23    1  5   22    1  5   21    1  5   20    4    4   19
+--R       -- b f x   + -- b e x   + -- b d x   + -- b c x   + -- a b f x
+--R       23           22           21           20           19
+--R     + 
+--R       2    4   18    4    4   17   1    4   16   2  2 3   15   3  2 3   14
+--R       - a b e x   + -- a b d x   + - a b c x   + - a b f x   + - a b e x
+--R       9             17             4             5             7
+--R     + 
+--R        6  2 3   13   1  2 3   12    4  3 2   11   2  3 2   10   4  3 2   9
+--R       -- a b d x   + - a b c x   + -- a b f x   + - a b e x   + - a b d x
+--R       13             2             11             5             9
+--R     + 
+--R       1  3 2   8   1  4     7   1  4     6   1  4     5   1  4     4    1  5
+--R       - a b c x  + - a b f x  + - a b e x  + - a b d x  + - a b c x  + -- a c
+--R       2            7            6            5            4            20
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 452
+
+--S 453 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 567
+t0:=x^3*(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^3
+--R 
+--R
+--R   (1)
+--R      3   18    3   17    3   16    3   15       2   14       2   13
+--R     b f x   + b e x   + b d x   + b c x   + 3a b f x   + 3a b e x
+--R   + 
+--R         2   12       2   11     2     10     2     9     2     8     2     7
+--R     3a b d x   + 3a b c x   + 3a b f x   + 3a b e x  + 3a b d x  + 3a b c x
+--R   + 
+--R      3   6    3   5    3   4    3   3
+--R     a f x  + a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 454
+
+--S 455 of 567
+r0:=1/5*a^3*d*x^5+1/6*a^3*e*x^6+1/7*a^3*f*x^7+1/3*a^2*b*d*x^9+3/10*a^2*b*_
+   e*x^10+3/11*a^2*b*f*x^11+3/13*a*b^2*d*x^13+3/14*a*b^2*e*x^14+_
+   1/5*a*b^2*f*x^15+1/17*b^3*d*x^17+1/18*b^3*e*x^18+1/19*b^3*f*x^19+_
+   1/16*c*(a+b*x^4)^4/b
+--R 
+--R
+--R   (2)
+--R        1  4   19    1  4   18    1  4   17    1  4   16   1    3   15
+--R       -- b f x   + -- b e x   + -- b d x   + -- b c x   + - a b f x
+--R       19           18           17           16           5
+--R     + 
+--R        3    3   14    3    3   13   1    3   12    3  2 2   11    3  2 2   10
+--R       -- a b e x   + -- a b d x   + - a b c x   + -- a b f x   + -- a b e x
+--R       14             13             4             11             10
+--R     + 
+--R       1  2 2   9   3  2 2   8   1  3     7   1  3     6   1  3     5
+--R       - a b d x  + - a b c x  + - a b f x  + - a b e x  + - a b d x
+--R       3            8            7            6            5
+--R     + 
+--R       1  3     4    1  4
+--R       - a b c x  + -- a c
+--R       4            16
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 455
+
+--S 456 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 567
+t0:=x^3*(c+d*x+e*x^2+f*x^3)*(a+b*x^4)^2
+--R 
+--R
+--R   (1)
+--R      2   14    2   13    2   12    2   11           10           9           8
+--R     b f x   + b e x   + b d x   + b c x   + 2a b f x   + 2a b e x  + 2a b d x
+--R   + 
+--R             7    2   6    2   5    2   4    2   3
+--R     2a b c x  + a f x  + a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 457
+
+--S 458 of 567
+r0:=1/5*a^2*d*x^5+1/6*a^2*e*x^6+1/7*a^2*f*x^7+2/9*a*b*d*x^9+1/5*a*b*_
+   e*x^10+2/11*a*b*f*x^11+1/13*b^2*d*x^13+1/14*b^2*e*x^14+1/15*b^2*_
+   f*x^15+1/12*c*(a+b*x^4)^3/b
+--R 
+--R
+--R   (2)
+--R        1  3   15    1  3   14    1  3   13    1  3   12    2    2   11
+--R       -- b f x   + -- b e x   + -- b d x   + -- b c x   + -- a b f x
+--R       15           14           13           12           11
+--R     + 
+--R       1    2   10   2    2   9   1    2   8   1  2     7   1  2     6
+--R       - a b e x   + - a b d x  + - a b c x  + - a b f x  + - a b e x
+--R       5             9            4            7            6
+--R     + 
+--R       1  2     5   1  2     4    1  3
+--R       - a b d x  + - a b c x  + -- a c
+--R       5            4            12
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 458
+
+--S 459 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 567
+t0:=x^3*(c+d*x+e*x^2+f*x^3)*(a+b*x^4)
+--R 
+--R
+--R             10        9        8        7        6        5        4        3
+--R   (1)  b f x   + b e x  + b d x  + b c x  + a f x  + a e x  + a d x  + a c x
+--R                                                    Type: Polynomial(Integer)
+--E 460
+
+--S 461 of 567
+r0:=1/4*a*c*x^4+1/5*a*d*x^5+1/6*a*e*x^6+1/7*a*f*x^7+1/8*b*c*x^8+1/9*b*_
+   d*x^9+1/10*b*e*x^10+1/11*b*f*x^11
+--R 
+--R
+--R   (2)
+--R      1      11    1      10   1      9   1      8   1      7   1      6
+--R     -- b f x   + -- b e x   + - b d x  + - b c x  + - a f x  + - a e x
+--R     11           10           9          8          7          6
+--R   + 
+--R     1      5   1      4
+--R     - a d x  + - a c x
+--R     5          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 461
+
+--S 462 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 567
+t0:=x^3*(c+d*x+e*x^2+f*x^3)/(a+b*x^4)
+--R 
+--R
+--R           6      5      4      3
+--R        f x  + e x  + d x  + c x
+--R   (1)  -------------------------
+--R                    4
+--R                 b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 463
+
+--S 464 of 567
+r0:=d*x/b+1/2*e*x^2/b+1/3*f*x^3/b+1/4*c*log(a+b*x^4)/b-1/2*e*atan(x^2*_
+   sqrt(b)/sqrt(a))*sqrt(a)/b^(3/2)+1/4*a^(1/4)*log(-a^(1/4)*b^(1/4)*_
+   x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-f*sqrt(a)+d*sqrt(b))/(b^(7/4)*_
+   sqrt(2))-1/4*a^(1/4)*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*_
+   sqrt(b))*(-f*sqrt(a)+d*sqrt(b))/(b^(7/4)*sqrt(2))+1/2*a^(1/4)*_
+   atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(f*sqrt(a)+d*sqrt(b))/(b^(7/4)*_
+   sqrt(2))-1/2*a^(1/4)*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(f*sqrt(a)+_
+   d*sqrt(b))/(b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R           +-+4+-+ +-+       4+-+       +-+4+-+4+-+    2 +-+    +-+
+--R       (3f\|a \|a \|b  - 3b d\|a )log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R             +-+4+-+ +-+       4+-+         +-+4+-+4+-+    2 +-+    +-+
+--R       (- 3f\|a \|a \|b  + 3b d\|a )log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                           +-+4+-+   4+-+
+--R             +-+4+-+ +-+       4+-+      x\|2 \|b  + \|a
+--R       (- 6f\|a \|a \|b  - 6b d\|a )atan(----------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R                                           +-+4+-+   4+-+
+--R             +-+4+-+ +-+       4+-+      x\|2 \|b  - \|a
+--R       (- 6f\|a \|a \|b  - 6b d\|a )atan(----------------)
+--R                                               4+-+
+--R                                               \|a
+--R     + 
+--R                              2 +-+
+--R            +-+ +-+4+-+3     x \|b
+--R       - 6e\|2 \|a \|b  atan(------)
+--R                               +-+
+--R                              \|a
+--R     + 
+--R           +-+       4             3       2          +-+  +-+4+-+3
+--R       (3c\|2 log(b x  + a) + (4f x  + 6e x  + 12d x)\|2 )\|b \|b
+--R  /
+--R         +-+ +-+4+-+3
+--R     12b\|2 \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 567
+t0:=x^3*(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^2
+--R 
+--R
+--R           6      5      4      3
+--R        f x  + e x  + d x  + c x
+--R   (1)  -------------------------
+--R            2 8         4    2
+--R           b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 466
+
+--S 467 of 567
+r0:=1/4*(-c-d*x-e*x^2-f*x^3)/(b*(a+b*x^4))+1/4*e*atan(x^2*sqrt(b)/_
+   sqrt(a))/(b^(3/2)*sqrt(a))-1/16*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(b))*(-3*f*sqrt(a)+d*sqrt(b))/(a^(3/4)*b^(7/4)*_
+   sqrt(2))+1/16*log(a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*_
+   (-3*f*sqrt(a)+d*sqrt(b))/(a^(3/4)*b^(7/4)*sqrt(2))-1/8*atan(1-b^(1/4)*_
+   x*sqrt(2)/a^(1/4))*(3*f*sqrt(a)+d*sqrt(b))/(a^(3/4)*b^(7/4)*_
+   sqrt(2))+1/8*atan(1+b^(1/4)*x*sqrt(2)/a^(1/4))*(3*f*sqrt(a)+d*_
+   sqrt(b))/(a^(3/4)*b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                     4     2   +-+     2   4          +-+
+--R         ((- 3a b f x  - 3a f)\|b  + (b d x  + a b d)\|a )
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                   4     2   +-+       2   4          +-+
+--R         ((3a b f x  + 3a f)\|b  + (- b d x  - a b d)\|a )
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                                                               +-+4+-+   4+-+
+--R                 4     2   +-+      2   4           +-+      x\|2 \|b  + \|a
+--R       ((6a b f x  + 6a f)\|b  + (2b d x  + 2a b d)\|a )atan(----------------)
+--R                                                                   4+-+
+--R                                                                   \|a
+--R     + 
+--R                                                               +-+4+-+   4+-+
+--R                 4     2   +-+      2   4           +-+      x\|2 \|b  - \|a
+--R       ((6a b f x  + 6a f)\|b  + (2b d x  + 2a b d)\|a )atan(----------------)
+--R                                                                   4+-+
+--R                                                                   \|a
+--R     + 
+--R                                            2 +-+
+--R              4         +-+4+-+3 4+-+3     x \|b
+--R       (4b e x  + 4a e)\|2 \|a   \|b  atan(------)
+--R                                             +-+
+--R                                            \|a
+--R     + 
+--R              3       2              +-+ +-+4+-+3 +-+4+-+3
+--R       (- 4f x  - 4e x  - 4d x - 4c)\|2 \|a \|a  \|b \|b
+--R  /
+--R         2 4          +-+ +-+4+-+3 +-+4+-+3
+--R     (16b x  + 16a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 567
+t0:=x^3*(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^3
+--R 
+--R
+--R              6      5      4      3
+--R           f x  + e x  + d x  + c x
+--R   (1)  ------------------------------
+--R         3 12       2 8     2   4    3
+--R        b x   + 3a b x  + 3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 469
+
+--S 470 of 567
+r0:=1/8*(-c-d*x-e*x^2-f*x^3)/(b*(a+b*x^4)^2)+1/32*x*(d+2*e*x+3*f*x^2)/_
+   (a*b*(a+b*x^4))+1/16*e*atan(x^2*sqrt(b)/sqrt(a))/(a^(3/2)*b^(3/2))-_
+   3/128*log(-a^(1/4)*b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-f*_
+   sqrt(a)+d*sqrt(b))/(a^(7/4)*b^(7/4)*sqrt(2))+3/128*log(a^(1/4)*_
+   b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-f*sqrt(a)+d*sqrt(b))/_
+   (a^(7/4)*b^(7/4)*sqrt(2))-3/64*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*_
+   (f*sqrt(a)+d*sqrt(b))/(a^(7/4)*b^(7/4)*sqrt(2))+3/64*atan(1+b^(1/4)*_
+   x*sqrt(2)/a^(1/4))*(f*sqrt(a)+d*sqrt(b))/(a^(7/4)*b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  2   8     2     4     3   +-+
+--R           (- 3a b f x  - 6a b f x  - 3a f)\|b
+--R         + 
+--R              3   8       2   4     2     +-+
+--R           (3b d x  + 6a b d x  + 3a b d)\|a
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                2   8     2     4     3   +-+
+--R           (3a b f x  + 6a b f x  + 3a f)\|b
+--R         + 
+--R                3   8       2   4     2     +-+
+--R           (- 3b d x  - 6a b d x  - 3a b d)\|a
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                2   8      2     4     3   +-+
+--R           (6a b f x  + 12a b f x  + 6a f)\|b
+--R         + 
+--R              3   8        2   4     2     +-+
+--R           (6b d x  + 12a b d x  + 6a b d)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  + \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                2   8      2     4     3   +-+
+--R           (6a b f x  + 12a b f x  + 6a f)\|b
+--R         + 
+--R              3   8        2   4     2     +-+
+--R           (6b d x  + 12a b d x  + 6a b d)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  - \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                                                         2 +-+
+--R          2   8            4     2   +-+4+-+3 4+-+3     x \|b
+--R       (8b e x  + 16a b e x  + 8a e)\|2 \|a   \|b  atan(------)
+--R                                                          +-+
+--R                                                         \|a
+--R     + 
+--R                 7         6         5         3         2
+--R         (12b f x  + 8b e x  + 4b d x  - 4a f x  - 8a e x  - 12a d x - 16a c)
+--R      *
+--R          +-+ +-+4+-+3 +-+4+-+3
+--R         \|2 \|a \|a  \|b \|b
+--R  /
+--R            3 8       2 2 4       3   +-+ +-+4+-+3 +-+4+-+3
+--R     (128a b x  + 256a b x  + 128a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 567
+t0:=x^3*(c+d*x+e*x^2+f*x^3)/(a+b*x^4)^4
+--R 
+--R
+--R                   6      5      4      3
+--R                f x  + e x  + d x  + c x
+--R   (1)  -----------------------------------------
+--R         4 16       3 12     2 2 8     3   4    4
+--R        b x   + 4a b x   + 6a b x  + 4a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 472
+
+--S 473 of 567
+r0:=1/12*(-c-d*x-e*x^2-f*x^3)/(b*(a+b*x^4)^3)+1/96*x*(d+2*e*x+3*f*x^2)/_
+   (a*b*(a+b*x^4)^2)+1/384*x*(7*d+12*e*x+15*f*x^2)/(a^2*b*(a+b*x^4))+_
+   1/32*e*atan(x^2*sqrt(b)/sqrt(a))/(a^(5/2)*b^(3/2))-1/512*log(-a^(1/4)*_
+   b^(1/4)*x*sqrt(2)+sqrt(a)+x^2*sqrt(b))*(-5*f*sqrt(a)+7*d*sqrt(b))/_
+   (a^(11/4)*b^(7/4)*sqrt(2))+1/512*log(a^(1/4)*b^(1/4)*x*sqrt(2)+_
+   sqrt(a)+x^2*sqrt(b))*(-5*f*sqrt(a)+7*d*sqrt(b))/(a^(11/4)*b^(7/4)*_
+   sqrt(2))-1/256*atan(1-b^(1/4)*x*sqrt(2)/a^(1/4))*(5*f*sqrt(a)+7*_
+   d*sqrt(b))/(a^(11/4)*b^(7/4)*sqrt(2))+1/256*atan(1+b^(1/4)*x*_
+   sqrt(2)/a^(1/4))*(5*f*sqrt(a)+7*d*sqrt(b))/(a^(11/4)*b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                   3   12      2 2   8      3     4      4   +-+
+--R           (- 15a b f x   - 45a b f x  - 45a b f x  - 15a f)\|b
+--R         + 
+--R               4   12        3   8      2 2   4      3     +-+
+--R           (21b d x   + 63a b d x  + 63a b d x  + 21a b d)\|a
+--R      *
+--R               +-+4+-+4+-+    2 +-+    +-+
+--R         log(x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                 3   12      2 2   8      3     4      4   +-+
+--R           (15a b f x   + 45a b f x  + 45a b f x  + 15a f)\|b
+--R         + 
+--R                 4   12        3   8      2 2   4      3     +-+
+--R           (- 21b d x   - 63a b d x  - 63a b d x  - 21a b d)\|a
+--R      *
+--R                 +-+4+-+4+-+    2 +-+    +-+
+--R         log(- x\|2 \|a \|b  + x \|b  + \|a )
+--R     + 
+--R                 3   12      2 2   8      3     4      4   +-+
+--R           (30a b f x   + 90a b f x  + 90a b f x  + 30a f)\|b
+--R         + 
+--R               4   12         3   8       2 2   4      3     +-+
+--R           (42b d x   + 126a b d x  + 126a b d x  + 42a b d)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  + \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                 3   12      2 2   8      3     4      4   +-+
+--R           (30a b f x   + 90a b f x  + 90a b f x  + 30a f)\|b
+--R         + 
+--R               4   12         3   8       2 2   4      3     +-+
+--R           (42b d x   + 126a b d x  + 126a b d x  + 42a b d)\|a
+--R      *
+--R                +-+4+-+   4+-+
+--R              x\|2 \|b  - \|a
+--R         atan(----------------)
+--R                    4+-+
+--R                    \|a
+--R     + 
+--R                                                                           2 +-+
+--R           3   12         2   8       2     4      3   +-+4+-+3 4+-+3     x \|b
+--R       (48b e x   + 144a b e x  + 144a b e x  + 48a e)\|2 \|a   \|b  atan(------)
+--R                                                                            +-+
+--R                                                                           \|a
+--R     + 
+--R              2   11      2   10      2   9             7             6
+--R           60b f x   + 48b e x   + 28b d x  + 168a b f x  + 128a b e x
+--R         + 
+--R                    5      2   3      2   2      2          2
+--R           72a b d x  - 20a f x  - 48a e x  - 84a d x - 128a c
+--R      *
+--R          +-+ +-+4+-+3 +-+4+-+3
+--R         \|2 \|a \|a  \|b \|b
+--R  /
+--R           2 4 12        3 3 8        4 2 4        5   +-+ +-+4+-+3 +-+4+-+3
+--R     (1536a b x   + 4608a b x  + 4608a b x  + 1536a b)\|2 \|a \|a  \|b \|b
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 567
+t0:=(c+d*x^(-1+n))*(a+b*x^n)^3
+--R 
+--R
+--R   (1)
+--R       3   n - 1    3    n 3        2   n - 1       2    n 2
+--R     (b d x      + b c)(x )  + (3a b d x      + 3a b c)(x )
+--R   + 
+--R        2     n - 1     2     n    3   n - 1    3
+--R     (3a b d x      + 3a b c)x  + a d x      + a c
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 567
+r0:=a^3*c*x+3*a^2*b*c*x^(1+n)/(1+n)+3*a*b^2*c*x^(1+2*n)/(1+2*n)+_
+   b^3*c*x^(1+3*n)/(1+3*n)+1/4*d*(a+b*x^n)^4/(b*n)
+--R 
+--R
+--R   (2)
+--R          4   3      4   2     4     3n + 1
+--R       (8b c n  + 12b c n  + 4b c n)x
+--R     + 
+--R             3   3        3   2        3     2n + 1
+--R       (36a b c n  + 48a b c n  + 12a b c n)x
+--R     + 
+--R           2 2   3      2 2   2      2 2     n + 1
+--R       (72a b c n  + 60a b c n  + 12a b c n)x
+--R     + 
+--R          4   3      4   2     4       4    n 4
+--R       (6b d n  + 11b d n  + 6b d n + b d)(x )
+--R     + 
+--R             3   3        3   2        3          3    n 3
+--R       (24a b d n  + 44a b d n  + 24a b d n + 4a b d)(x )
+--R     + 
+--R           2 2   3      2 2   2      2 2        2 2    n 2
+--R       (36a b d n  + 66a b d n  + 36a b d n + 6a b d)(x )
+--R     + 
+--R           3     3      3     2      3          3     n
+--R       (24a b d n  + 44a b d n  + 24a b d n + 4a b d)x
+--R     + 
+--R           3     4      3     3      3     2     3            4   3      4   2
+--R       (24a b c n  + 44a b c n  + 24a b c n  + 4a b c n)x + 6a d n  + 11a d n
+--R     + 
+--R         4       4
+--R       6a d n + a d
+--R  /
+--R          4        3        2
+--R     24b n  + 44b n  + 24b n  + 4b n
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 567
+t0:=(c+d*x^(-1+n))*(a+b*x^n)^2
+--R 
+--R
+--R   (1)
+--R     2   n - 1    2    n 2            n - 1           n    2   n - 1    2
+--R   (b d x      + b c)(x )  + (2a b d x      + 2a b c)x  + a d x      + a c
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 567
+r0:=a^2*c*x+2*a*b*c*x^(1+n)/(1+n)+b^2*c*x^(1+2*n)/(1+2*n)+_
+   1/3*d*(a+b*x^n)^3/(b*n)
+--R 
+--R
+--R   (2)
+--R          3   2     3     2n + 1         2   2       2     n + 1
+--R       (3b c n  + 3b c n)x       + (12a b c n  + 6a b c n)x
+--R     + 
+--R          3   2     3       3    n 3        2   2       2          2    n 2
+--R       (2b d n  + 3b d n + b d)(x )  + (6a b d n  + 9a b d n + 3a b d)(x )
+--R     + 
+--R          2     2     2          2     n      2     3     2     2     2
+--R       (6a b d n  + 9a b d n + 3a b d)x  + (6a b c n  + 9a b c n  + 3a b c n)x
+--R     + 
+--R         3   2     3       3
+--R       2a d n  + 3a d n + a d
+--R  /
+--R         3       2
+--R     6b n  + 9b n  + 3b n
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 567
+t0:=(c+d*x^(-1+n))*(a+b*x^n)
+--R 
+--R
+--R              n - 1        n        n - 1
+--R   (1)  (b d x      + b c)x  + a d x      + a c
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 567
+r0:=a*c*x+a*d*x^n/n+1/2*b*d*x^(2*n)/n+b*c*x^(1+n)/(1+n)
+--R 
+--R
+--R   (2)
+--R                 2n           n + 1                   n          2
+--R   (b d n + b d)x   + 2b c n x      + (2a d n + 2a d)x  + (2a c n  + 2a c n)x
+--R   --------------------------------------------------------------------------
+--R                                      2
+--R                                    2n  + 2n
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+)clear all
+
+--S 484 of 567
+t0:=c+d*x^(-1+n)
+--R 
+--R
+--R           n - 1
+--R   (1)  d x      + c
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 567
+r0:=c*x+d*x^n/n
+--R 
+--R
+--R           n
+--R        d x  + c n x
+--R   (2)  ------------
+--R              n
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 567
+t0:=(c+d*x^(-1+n))/(a+b*x^n)
+--R 
+--R
+--R           n - 1
+--R        d x      + c
+--R   (1)  ------------
+--R             n
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 567
+--r0:=c*x*hypergeometric(1,1/n,1+1/n,-b*x^n/a)/a+d*log(a+b*x^n)/(b*n)
+--E 488
+
+--S 489 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 489
+
+)clear all
+
+--S 490 of 567
+t0:=(c+d*x^(-1+n))/(a+b*x^n)^2
+--R 
+--R
+--R                n - 1
+--R             d x      + c
+--R   (1)  ----------------------
+--R         2  n 2         n    2
+--R        b (x )  + 2a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 567
+--r0:=-d/(b*n*(a+b*x^n))+c*x/(a*n*(a+b*x^n))-c*(1-n)*x*_
+--   hypergeometric(1,1/n,1+1/n,-b*x^n/a)/(a^2*n)
+--E 491
+
+--S 492 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 492
+
+)clear all
+
+--S 493 of 567
+t0:=(c+d*x^(-1+n))/(a+b*x^n)^3
+--R 
+--R
+--R                       n - 1
+--R                    d x      + c
+--R   (1)  -----------------------------------
+--R         3  n 3       2  n 2     2   n    3
+--R        b (x )  + 3a b (x )  + 3a b x  + a
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 567
+--r0:=-1/2*d/(b*n*(a+b*x^n)^2)+1/2*c*x/(a*n*(a+b*x^n)^2)-1/2*c*(1-2*n)*_
+--   x/(a^2*n^2*(a+b*x^n))+1/2*c*(1-2*n)*(1-n)*x*hypergeometric(1,1/n,_
+--   1+1/n,-b*x^n/a)/(a^3*n^2)
+--E 494
+
+--S 495 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 495
+
+)clear all
+
+--S 496 of 567
+t0:=x^2*(a+b*x)^n*(c+d*x^3)
+--R 
+--R
+--R            5      2          n
+--R   (1)  (d x  + c x )(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 567
+r0:=a^2*(b^3*c-a^3*d)*(a+b*x)^(1+n)/(b^6*(1+n))-a*(2*b^3*c-5*a^3*d)*_
+   (a+b*x)^(2+n)/(b^6*(2+n))+(b^3*c-10*a^3*d)*(a+b*x)^(3+n)/(b^6*(3+n))+_
+   10*a^2*d*(a+b*x)^(4+n)/(b^6*(4+n))-5*a*d*(a+b*x)^(5+n)/(b^6*(5+n))+_
+   d*(a+b*x)^(6+n)/(b^6*(6+n))
+--R 
+--R
+--R   (2)
+--R           5        4        3         2                          n + 6
+--R       (d n  + 15d n  + 85d n  + 225d n  + 274d n + 120d)(b x + a)
+--R     + 
+--R                  5          4           3            2
+--R         (- 5a d n  - 80a d n  - 475a d n  - 1300a d n  - 1620a d n - 720a d)
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R             2   5       2   4        2   3        2   2        2           2
+--R         (10a d n  + 170a d n  + 1070a d n  + 3070a d n  + 3960a d n + 1800a d)
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 3     3   5          3       3   4           3        3   3
+--R           (- 10a d + b c)n  + (- 180a d + 18b c)n  + (- 1210a d + 121b c)n
+--R         + 
+--R                   3        3   2           3        3           3        3
+--R           (- 3720a d + 372b c)n  + (- 5080a d + 508b c)n - 2400a d + 240b c
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R              4        3   5       4         3   4        4          3   3
+--R           (5a d - 2a b c)n  + (95a d - 38a b c)n  + (685a d - 274a b c)n
+--R         + 
+--R                 4          3   2         4           3           4          3
+--R           (2305a d - 922a b c)n  + (3510a d - 1404a b c)n + 1800a d - 720a b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               5     2 3   5         5       2 3   4          5        2 3   3
+--R           (- a d + a b c)n  + (- 20a d + 20a b c)n  + (- 155a d + 155a b c)n
+--R         + 
+--R                5        2 3   2           5         2 3          5        2 3
+--R         (- 580a d + 580a b c)n  + (- 1044a d + 1044a b c)n - 720a d + 720a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R      6 6      6 5       6 4       6 3        6 2        6        6
+--R     b n  + 21b n  + 175b n  + 735b n  + 1624b n  + 1764b n + 720b
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 567
+t0:=x*(a+b*x)^n*(c+d*x^3)
+--R 
+--R
+--R            4                n
+--R   (1)  (d x  + c x)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 567
+r0:=-a*(b^3*c-a^3*d)*(a+b*x)^(1+n)/(b^5*(1+n))+(b^3*c-4*a^3*d)*_
+   (a+b*x)^(2+n)/(b^5*(2+n))+6*a^2*d*(a+b*x)^(3+n)/(b^5*(3+n))-_
+   4*a*d*(a+b*x)^(4+n)/(b^5*(4+n))+d*(a+b*x)^(5+n)/(b^5*(5+n))
+--R 
+--R
+--R   (2)
+--R           4        3        2                        n + 5
+--R       (d n  + 10d n  + 35d n  + 50d n + 24d)(b x + a)
+--R     + 
+--R                4          3           2                              n + 4
+--R       (- 4a d n  - 44a d n  - 164a d n  - 244a d n - 120a d)(b x + a)
+--R     + 
+--R          2   4      2   3       2   2       2          2           n + 3
+--R       (6a d n  + 72a d n  + 294a d n  + 468a d n + 240a d)(b x + a)
+--R     + 
+--R                3     3   4         3       3   3          3       3   2
+--R           (- 4a d + b c)n  + (- 52a d + 13b c)n  + (- 236a d + 59b c)n
+--R         + 
+--R                  3        3          3       3
+--R           (- 428a d + 107b c)n - 240a d + 60b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             4       3   4       4         3   3       4         3   2
+--R           (a d - a b c)n  + (14a d - 14a b c)n  + (71a d - 71a b c)n
+--R         + 
+--R                4          3          4          3
+--R           (154a d - 154a b c)n + 120a d - 120a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R      5 5      5 4      5 3       5 2       5        5
+--R     b n  + 15b n  + 85b n  + 225b n  + 274b n + 120b
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 567
+t0:=(a+b*x)^n*(c+d*x^3)
+--R 
+--R
+--R            3              n
+--R   (1)  (d x  + c)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 567
+r0:=(b^3*c-a^3*d)*(a+b*x)^(1+n)/(b^4*(1+n))+3*a^2*d*(a+b*x)^(2+n)/(b^4*_
+   (2+n))-3*a*d*(a+b*x)^(3+n)/(b^4*(3+n))+d*(a+b*x)^(4+n)/(b^4*(4+n))
+--R 
+--R
+--R   (2)
+--R           3       2                       n + 4
+--R       (d n  + 6d n  + 11d n + 6d)(b x + a)
+--R     + 
+--R                3          2                            n + 3
+--R       (- 3a d n  - 21a d n  - 42a d n - 24a d)(b x + a)
+--R     + 
+--R          2   3      2   2      2         2           n + 2
+--R       (3a d n  + 24a d n  + 57a d n + 36a d)(b x + a)
+--R     + 
+--R               3     3   3        3      3   2         3       3         3
+--R           (- a d + b c)n  + (- 9a d + 9b c)n  + (- 26a d + 26b c)n - 24a d
+--R         + 
+--R              3
+--R           24b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R      4 4      4 3      4 2      4       4
+--R     b n  + 10b n  + 35b n  + 50b n + 24b
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 567
+t0:=(a+b*x)^n*(c+d*x^3)/x
+--R 
+--R
+--R            3              n
+--R        (d x  + c)(b x + a)
+--R   (1)  --------------------
+--R                  x
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 567
+--r0:=a^2*d*(a+b*x)^(1+n)/(b^3*(1+n))-2*a*d*(a+b*x)^(2+n)/(b^3*(2+n))+_
+--   d*(a+b*x)^(3+n)/(b^3*(3+n))-c*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*(1+n))
+--E 506
+
+--S 507 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 507
+
+)clear all
+
+--S 508 of 567
+t0:=x^2*(a+b*x)^n*(c+d*x^3)^2
+--R 
+--R
+--R          2 8         5    2 2          n
+--R   (1)  (d x  + 2c d x  + c x )(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 567
+r0:=a^2*(b^3*c-a^3*d)^2*(a+b*x)^(1+n)/(b^9*(1+n))-2*a*(b^3*c-4*a^3*d)*_
+   (b^3*c-a^3*d)*(a+b*x)^(2+n)/(b^9*(2+n))+(b^6*c^2-20*a^3*b^3*c*d+_
+   28*a^6*d^2)*(a+b*x)^(3+n)/(b^9*(3+n))+4*a^2*d*(5*b^3*c-14*a^3*d)*_
+   (a+b*x)^(4+n)/(b^9*(4+n))-10*a*d*(b^3*c-7*a^3*d)*(a+b*x)^(5+n)/_
+   (b^9*(5+n))+2*d*(b^3*c-28*a^3*d)*(a+b*x)^(6+n)/(b^9*(6+n))+28*a^2*_
+   d^2*(a+b*x)^(7+n)/(b^9*(7+n))-8*a*d^2*(a+b*x)^(8+n)/(b^9*(8+n))+_
+   d^2*(a+b*x)^(9+n)/(b^9*(9+n))
+--R 
+--R
+--R   (2)
+--R            2 8      2 7       2 6        2 5         2 4         2 3
+--R           d n  + 36d n  + 546d n  + 4536d n  + 22449d n  + 67284d n
+--R         + 
+--R                  2 2          2          2
+--R           118124d n  + 109584d n + 40320d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R                 2 8         2 7          2 6           2 5            2 4
+--R           - 8a d n  - 296a d n  - 4592a d n  - 38864a d n  - 195272a d n
+--R         + 
+--R                      2 3             2 2            2             2
+--R           - 592424a d n  - 1050048a d n  - 981216a d n - 362880a d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R              2 2 8        2 2 7         2 2 6          2 2 5          2 2 4
+--R           28a d n  + 1064a d n  + 16912a d n  + 146216a d n  + 748132a d n
+--R         + 
+--R                   2 2 3           2 2 2           2 2            2 2
+--R           2304176a d n  + 4133808a d n  + 3898944a d n + 1451520a d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                 3 2     3     8           3 2      3     7
+--R           (- 56a d  + 2b c d)n  + (- 2184a d  + 78b c d)n
+--R         + 
+--R                    3 2        3     6             3 2         3     5
+--R           (- 35616a d  + 1272b c d)n  + (- 315504a d  + 11268b c d)n
+--R         + 
+--R                      3 2         3     4              3 2          3     3
+--R           (- 1650264a d  + 58938b c d)n  + (- 5180616a d  + 185022b c d)n
+--R         + 
+--R                      3 2          3     2              3 2          3
+--R           (- 9442384a d  + 337228b c d)n  + (- 9016896a d  + 322032b c d)n
+--R         + 
+--R                     3 2          3
+--R           - 3386880a d  + 120960b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R               4 2        3     8         4 2         3     7
+--R           (70a d  - 10a b c d)n  + (2800a d  - 400a b c d)n
+--R         + 
+--R                  4 2          3     6           4 2           3     5
+--R           (46900a d  - 6700a b c d)n  + (427000a d  - 61000a b c d)n
+--R         + 
+--R                    4 2            3     4            4 2             3     3
+--R           (2294110a d  - 327730a b c d)n  + (7382200a d  - 1054600a b c d)n
+--R         + 
+--R                     4 2             3     2             4 2             3
+--R           (13746600a d  - 1963800a b c d)n  + (13356000a d  - 1908000a b c d)n
+--R         + 
+--R                   4 2            3
+--R           5080320a d  - 725760a b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                 5 2      2 3     8           5 2       2 3     7
+--R           (- 56a d  + 20a b c d)n  + (- 2296a d  + 820a b c d)n
+--R         + 
+--R                    5 2         2 3     6             5 2          2 3     5
+--R           (- 39536a d  + 14120a b c d)n  + (- 371056a d  + 132520a b c d)n
+--R         + 
+--R                      5 2          2 3     4
+--R           (- 2059064a d  + 735380a b c d)n
+--R         + 
+--R                      5 2           2 3     3
+--R           (- 6845944a d  + 2444980a b c d)n
+--R         + 
+--R                       5 2           2 3     2
+--R           (- 13142304a d  + 4693680a b c d)n
+--R         + 
+--R                       5 2           2 3                5 2           2 3
+--R           (- 13101984a d  + 4679280a b c d)n - 5080320a d  + 1814400a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R               6 2      3 3       6 2  8         6 2       3 3         6 2  7
+--R           (28a d  - 20a b c d + b c )n  + (1176a d  - 840a b c d + 42b c )n
+--R         + 
+--R                  6 2         3 3          6 2  6
+--R           (20832a d  - 14880a b c d + 744b c )n
+--R         + 
+--R                   6 2          3 3           6 2  5
+--R           (202104a d  - 144360a b c d + 7218b c )n
+--R         + 
+--R                    6 2          3 3            6 2  4
+--R           (1165332a d  - 832380a b c d + 41619b c )n
+--R         + 
+--R                    6 2           3 3             6 2  3
+--R           (4045104a d  - 2889360a b c d + 144468b c )n
+--R         + 
+--R                    6 2           3 3             6 2  2
+--R           (8127728a d  - 5805520a b c d + 290276b c )n
+--R         + 
+--R                    6 2           3 3             6 2             6 2
+--R           (8452416a d  - 6037440a b c d + 301872b c )n + 3386880a d
+--R         + 
+--R                     3 3             6 2
+--R           - 2419200a b c d + 120960b c
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R                7 2      4 3          6 2  8
+--R           (- 8a d  + 10a b c d - 2a b c )n
+--R         + 
+--R                  7 2       4 3           6 2  7
+--R           (- 344a d  + 430a b c d - 86a b c )n
+--R         + 
+--R                   7 2        4 3             6 2  6
+--R           (- 6272a d  + 7840a b c d - 1568a b c )n
+--R         + 
+--R                    7 2         4 3              6 2  5
+--R           (- 63056a d  + 78820a b c d - 15764a b c )n
+--R         + 
+--R                     7 2          4 3              6 2  4
+--R           (- 380072a d  + 475090a b c d - 95018a b c )n
+--R         + 
+--R                      7 2           4 3               6 2  3
+--R           (- 1394456a d  + 1743070a b c d - 348614a b c )n
+--R         + 
+--R                      7 2           4 3               6 2  2
+--R           (- 3000528a d  + 3750660a b c d - 750132a b c )n
+--R         + 
+--R                      7 2           4 3               6 2             7 2
+--R           (- 3380544a d  + 4225680a b c d - 845136a b c )n - 1451520a d
+--R         + 
+--R                   4 3               6 2
+--R           1814400a b c d - 362880a b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             8 2     5 3       2 6 2  8       8 2      5 3         2 6 2  7
+--R           (a d  - 2a b c d + a b c )n  + (44a d  - 88a b c d + 44a b c )n
+--R         + 
+--R                8 2        5 3          2 6 2  6
+--R           (826a d  - 1652a b c d + 826a b c )n
+--R         + 
+--R                 8 2         5 3           2 6 2  5
+--R           (8624a d  - 17248a b c d + 8624a b c )n
+--R         + 
+--R                  8 2          5 3            2 6 2  4
+--R           (54649a d  - 109298a b c d + 54649a b c )n
+--R         + 
+--R                   8 2          5 3             2 6 2  3
+--R           (214676a d  - 429352a b c d + 214676a b c )n
+--R         + 
+--R                   8 2           5 3             2 6 2  2
+--R           (509004a d  - 1018008a b c d + 509004a b c )n
+--R         + 
+--R                   8 2           5 3             2 6 2            8 2
+--R           (663696a d  - 1327392a b c d + 663696a b c )n + 362880a d
+--R         + 
+--R                    5 3             2 6 2
+--R           - 725760a b c d + 362880a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        9 9      9 8       9 7        9 6         9 5          9 4          9 3
+--R       b n  + 45b n  + 870b n  + 9450b n  + 63273b n  + 269325b n  + 723680b n
+--R     + 
+--R               9 2           9           9
+--R       1172700b n  + 1026576b n + 362880b
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 567
+t0:=x*(a+b*x)^n*(c+d*x^3)^2
+--R 
+--R
+--R          2 7         4    2           n
+--R   (1)  (d x  + 2c d x  + c x)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 567
+r0:=-a*(b^3*c-a^3*d)^2*(a+b*x)^(1+n)/(b^8*(1+n))+(b^3*c-7*a^3*d)*_
+   (b^3*c-a^3*d)*(a+b*x)^(2+n)/(b^8*(2+n))+3*a^2*d*(4*b^3*c-7*a^3*d)*_
+   (a+b*x)^(3+n)/(b^8*(3+n))-a*d*(8*b^3*c-35*a^3*d)*(a+b*x)^(4+n)/_
+   (b^8*(4+n))+d*(2*b^3*c-35*a^3*d)*(a+b*x)^(5+n)/(b^8*(5+n))+21*a^2*_
+   d^2*(a+b*x)^(6+n)/(b^8*(6+n))-7*a*d^2*(a+b*x)^(7+n)/(b^8*(7+n))+_
+   d^2*(a+b*x)^(8+n)/(b^8*(8+n))
+--R 
+--R
+--R   (2)
+--R            2 7      2 6       2 5        2 4        2 3         2 2         2
+--R           d n  + 28d n  + 322d n  + 1960d n  + 6769d n  + 13132d n  + 13068d n
+--R         + 
+--R                2
+--R           5040d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                 2 7         2 6          2 5           2 4           2 3
+--R           - 7a d n  - 203a d n  - 2401a d n  - 14945a d n  - 52528a d n
+--R         + 
+--R                      2 2            2            2
+--R           - 103292a d n  - 103824a d n - 40320a d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R              2 2 7       2 2 6        2 2 5         2 2 4          2 2 3
+--R           21a d n  + 630a d n  + 7686a d n  + 49140a d n  + 176589a d n
+--R         + 
+--R                  2 2 2          2 2           2 2
+--R           353430a d n  + 360024a d n + 141120a d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                 3 2     3     7           3 2      3     6
+--R           (- 35a d  + 2b c d)n  + (- 1085a d  + 62b c d)n
+--R         + 
+--R                    3 2       3     5            3 2        3     4
+--R           (- 13685a d  + 782b c d)n  + (- 90335a d  + 5162b c d)n
+--R         + 
+--R                     3 2         3     3             3 2         3     2
+--R           (- 334040a d  + 19088b c d)n  + (- 684740a d  + 39128b c d)n
+--R         + 
+--R                     3 2         3               3 2         3
+--R           (- 710640a d  + 40608b c d)n - 282240a d  + 16128b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R               4 2       3     7         4 2         3     6
+--R           (35a d  - 8a b c d)n  + (1120a d  - 256a b c d)n
+--R         + 
+--R                  4 2          3     5           4 2           3     4
+--R           (14630a d  - 3344a b c d)n  + (100240a d  - 22912a b c d)n
+--R         + 
+--R                   4 2           3     3           4 2            3     2
+--R           (384755a d  - 87944a b c d)n  + (815920a d  - 186496a b c d)n
+--R         + 
+--R                   4 2            3               4 2           3
+--R           (870660a d  - 199008a b c d)n + 352800a d  - 80640a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 5 2      2 3     7          5 2       2 3     6
+--R           (- 21a d  + 12a b c d)n  + (- 693a d  + 396a b c d)n
+--R         + 
+--R                   5 2        2 3     5            5 2         2 3     4
+--R           (- 9387a d  + 5364a b c d)n  + (- 67095a d  + 38340a b c d)n
+--R         + 
+--R                     5 2          2 3     3             5 2          2 3     2
+--R           (- 270144a d  + 154368a b c d)n  + (- 602532a d  + 344304a b c d)n
+--R         + 
+--R                     5 2          2 3               5 2          2 3
+--R           (- 673008a d  + 384576a b c d)n - 282240a d  + 161280a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R              6 2     3 3       6 2  7        6 2       3 3         6 2  6
+--R           (7a d  - 8a b c d + b c )n  + (238a d  - 272a b c d + 34b c )n
+--R         + 
+--R                 6 2        3 3          6 2  5
+--R           (3346a d  - 3824a b c d + 478b c )n
+--R         + 
+--R                  6 2         3 3           6 2  4
+--R           (25060a d  - 28640a b c d + 3580b c )n
+--R         + 
+--R                   6 2          3 3            6 2  3
+--R           (107023a d  - 122312a b c d + 15289b c )n
+--R         + 
+--R                   6 2          3 3            6 2  2
+--R           (256942a d  - 293648a b c d + 36706b c )n
+--R         + 
+--R                   6 2          3 3            6 2            6 2
+--R           (312984a d  - 357696a b c d + 44712b c )n + 141120a d
+--R         + 
+--R                    3 3            6 2
+--R           - 161280a b c d + 20160b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               7 2     4 3         6 2  7         7 2      4 3           6 2  6
+--R           (- a d  + 2a b c d - a b c )n  + (- 35a d  + 70a b c d - 35a b c )n
+--R         + 
+--R                  7 2        4 3            6 2  5
+--R           (- 511a d  + 1022a b c d - 511a b c )n
+--R         + 
+--R                   7 2        4 3             6 2  4
+--R           (- 4025a d  + 8050a b c d - 4025a b c )n
+--R         + 
+--R                    7 2         4 3              6 2  3
+--R           (- 18424a d  + 36848a b c d - 18424a b c )n
+--R         + 
+--R                    7 2         4 3              6 2  2
+--R           (- 48860a d  + 97720a b c d - 48860a b c )n
+--R         + 
+--R                    7 2          4 3              6 2           7 2
+--R           (- 69264a d  + 138528a b c d - 69264a b c )n - 40320a d
+--R         + 
+--R                 4 3              6 2
+--R           80640a b c d - 40320a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        8 8      8 7       8 6        8 5         8 4         8 3          8 2
+--R       b n  + 36b n  + 546b n  + 4536b n  + 22449b n  + 67284b n  + 118124b n
+--R     + 
+--R              8          8
+--R       109584b n + 40320b
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 513
+
+)clear all
+
+--S 514 of 567
+t0:=(a+b*x)^n*(c+d*x^3)^2
+--R 
+--R
+--R          2 6         3    2          n
+--R   (1)  (d x  + 2c d x  + c )(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 567
+r0:=(b^3*c-a^3*d)^2*(a+b*x)^(1+n)/(b^7*(1+n))+6*a^2*d*(b^3*c-a^3*d)*_
+   (a+b*x)^(2+n)/(b^7*(2+n))-3*a*d*(2*b^3*c-5*a^3*d)*(a+b*x)^(3+n)/_
+   (b^7*(3+n))+2*d*(b^3*c-10*a^3*d)*(a+b*x)^(4+n)/(b^7*(4+n))+15*a^2*_
+   d^2*(a+b*x)^(5+n)/(b^7*(5+n))-6*a*d^2*(a+b*x)^(6+n)/(b^7*(6+n))+_
+   d^2*(a+b*x)^(7+n)/(b^7*(7+n))
+--R 
+--R
+--R   (2)
+--R           2 6      2 5       2 4       2 3        2 2        2        2
+--R         (d n  + 21d n  + 175d n  + 735d n  + 1624d n  + 1764d n + 720d )
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                 2 6         2 5          2 4          2 3           2 2
+--R           - 6a d n  - 132a d n  - 1140a d n  - 4920a d n  - 11094a d n
+--R         + 
+--R                     2           2
+--R           - 12228a d n - 5040a d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R              2 2 6       2 2 5        2 2 4         2 2 3         2 2 2
+--R           15a d n  + 345a d n  + 3105a d n  + 13875a d n  + 32160a d n
+--R         + 
+--R                 2 2          2 2
+--R           36180a d n + 15120a d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                 3 2     3     6          3 2      3     5
+--R           (- 20a d  + 2b c d)n  + (- 480a d  + 48b c d)n
+--R         + 
+--R                   3 2       3     4            3 2        3     3
+--R           (- 4520a d  + 452b c d)n  + (- 21120a d  + 2112b c d)n
+--R         + 
+--R                    3 2        3     2            3 2        3              3 2
+--R           (- 50900a d  + 5090b c d)n  + (- 59040a d  + 5904b c d)n - 25200a d
+--R         + 
+--R                3
+--R           2520b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R               4 2       3     6        4 2         3     5
+--R           (15a d  - 6a b c d)n  + (375a d  - 150a b c d)n
+--R         + 
+--R                 4 2          3     4          4 2          3     3
+--R           (3705a d  - 1482a b c d)n  + (18285a d  - 7314a b c d)n
+--R         + 
+--R                  4 2           3     2          4 2           3
+--R           (46680a d  - 18672a b c d)n  + (56940a d  - 22776a b c d)n
+--R         + 
+--R                 4 2           3
+--R           25200a d  - 10080a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R                5 2     2 3     6          5 2       2 3     5
+--R           (- 6a d  + 6a b c d)n  + (- 156a d  + 156a b c d)n
+--R         + 
+--R                   5 2        2 3     4           5 2        2 3     3
+--R           (- 1620a d  + 1620a b c d)n  + (- 8520a d  + 8520a b c d)n
+--R         + 
+--R                    5 2         2 3     2            5 2         2 3
+--R           (- 23574a d  + 23574a b c d)n  + (- 31644a d  + 31644a b c d)n
+--R         + 
+--R                   5 2         2 3
+--R           - 15120a d  + 15120a b c d
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             6 2     3 3       6 2  6       6 2      3 3         6 2  5
+--R           (a d  - 2a b c d + b c )n  + (27a d  - 54a b c d + 27b c )n
+--R         + 
+--R                6 2       3 3          6 2  4
+--R           (295a d  - 590a b c d + 295b c )n
+--R         + 
+--R                 6 2        3 3           6 2  3
+--R           (1665a d  - 3330a b c d + 1665b c )n
+--R         + 
+--R                 6 2         3 3           6 2  2
+--R           (5104a d  - 10208a b c d + 5104b c )n
+--R         + 
+--R                 6 2         3 3           6 2          6 2         3 3
+--R           (8028a d  - 16056a b c d + 8028b c )n + 5040a d  - 10080a b c d
+--R         + 
+--R                6 2
+--R           5040b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        7 7      7 6       7 5        7 4        7 3         7 2         7
+--R       b n  + 28b n  + 322b n  + 1960b n  + 6769b n  + 13132b n  + 13068b n
+--R     + 
+--R            7
+--R       5040b
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 567
+t0:=(a+b*x)^n*(c+d*x^3)^2/x
+--R 
+--R
+--R          2 6         3    2          n
+--R        (d x  + 2c d x  + c )(b x + a)
+--R   (1)  -------------------------------
+--R                       x
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 567
+--r0:=2*a^2*c*d*(a+b*x)^(1+n)/(b^3*(1+n))-a^5*d^2*(a+b*x)^(1+n)/(b^6*(1+n))-_
+--   4*a*c*d*(a+b*x)^(2+n)/(b^3*(2+n))+5*a^4*d^2*(a+b*x)^(2+n)/(b^6*(2+n))+_
+--   2*c*d*(a+b*x)^(3+n)/(b^3*(3+n))-10*a^3*d^2*(a+b*x)^(3+n)/(b^6*(3+n))+_
+--   10*a^2*d^2*(a+b*x)^(4+n)/(b^6*(4+n))-5*a*d^2*(a+b*x)^(5+n)/(b^6*_
+--   (5+n))+d^2*(a+b*x)^(6+n)/(b^6*(6+n))-c^2*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*(1+n))
+--E 518
+
+--S 519 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 519
+
+)clear all
+
+--S 520 of 567
+t0:=x^2*(a+b*x)^n*(c+d*x^3)^3
+--R 
+--R
+--R          3 11       2 8     2   5    3 2          n
+--R   (1)  (d x   + 3c d x  + 3c d x  + c x )(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 567
+r0:=a^2*(b^3*c-a^3*d)^3*(a+b*x)^(1+n)/(b^12*(1+n))-a*(2*b^3*c-11*a^3*d)*_
+   (b^3*c-a^3*d)^2*(a+b*x)^(2+n)/(b^12*(2+n))+(b^3*c-a^3*d)*(b^6*c^2-29*_
+   a^3*b^3*c*d+55*a^6*d^2)*(a+b*x)^(3+n)/(b^12*(3+n))+3*a^2*d*(10*b^6*_
+   c^2-56*a^3*b^3*c*d+55*a^6*d^2)*(a+b*x)^(4+n)/(b^12*(4+n))-15*a*d*_
+   (b^6*c^2-14*a^3*b^3*c*d+22*a^6*d^2)*(a+b*x)^(5+n)/(b^12*(5+n))+_
+   3*d*(b^6*c^2-56*a^3*b^3*c*d+154*a^6*d^2)*(a+b*x)^(6+n)/(b^12*(6+n))+_
+   42*a^2*d^2*(2*b^3*c-11*a^3*d)*(a+b*x)^(7+n)/(b^12*(7+n))-6*a*d^2*_
+   (4*b^3*c-55*a^3*d)*(a+b*x)^(8+n)/(b^12*(8+n))+3*d^2*(b^3*c-55*a^3*d)*_
+   (a+b*x)^(9+n)/(b^12*(9+n))+55*a^2*d^3*(a+b*x)^(10+n)/(b^12*(10+n))-_
+   11*a*d^3*(a+b*x)^(11+n)/(b^12*(11+n))+d^3*(a+b*x)^(12+n)/(b^12*(12+n))
+--R 
+--R
+--R   (2)
+--R            3 11      3 10        3 9         3 8          3 7           3 6
+--R           d n   + 66d n   + 1925d n  + 32670d n  + 357423d n  + 2637558d n
+--R         + 
+--R                    3 5            3 4             3 3             3 2
+--R           13339535d n  + 45995730d n  + 105258076d n  + 150917976d n
+--R         + 
+--R                     3             3
+--R           120543840d n + 39916800d
+--R      *
+--R                  n + 12
+--R         (b x + a)
+--R     + 
+--R                  3 11         3 10           3 9            3 8             3 7
+--R           - 11a d n   - 737a d n   - 21780a d n  - 373890a d n  - 4131303a d n
+--R         + 
+--R                        3 6               3 5               3 4
+--R           - 30748641a d n  - 156657490a d n  - 543539260a d n
+--R         + 
+--R                        3 3                3 2                3                3
+--R         - 1250343336a d n  - 1800387072a d n  - 1442897280a d n - 479001600a d
+--R      *
+--R                  n + 11
+--R         (b x + a)
+--R     + 
+--R              2 3 11        2 3 10          2 3 9           2 3 8
+--R           55a d n   + 3740a d n   + 112035a d n  + 1947000a d n
+--R         + 
+--R                    2 3 7             2 3 6             2 3 5              2 3 4
+--R           21750465a d n  + 163460220a d n  + 839860505a d n  + 2935253200a d n
+--R         + 
+--R                    2 3 3              2 3 2              2 3               2 3
+--R         6793843980a d n  + 9832379040a d n  + 7911984960a d n + 2634508800a d
+--R      *
+--R                  n + 10
+--R         (b x + a)
+--R     + 
+--R                  3 3     3   2  11            3 3       3   2  10
+--R           (- 165a d  + 3b c d )n   + (- 11385a d  + 207b c d )n
+--R         + 
+--R                     3 3        3   2  9              3 3          3   2  8
+--R           (- 345840a d  + 6288b c d )n  + (- 6089490a d  + 110718b c d )n
+--R         + 
+--R                       3 3           3   2  7
+--R           (- 68855985a d  + 1251927b c d )n
+--R         + 
+--R                        3 3           3   2  6
+--R           (- 523190745a d  + 9512559b c d )n
+--R         + 
+--R                         3 3            3   2  5
+--R           (- 2714671410a d  + 49357662b c d )n
+--R         + 
+--R                         3 3             3   2  4
+--R           (- 9569532060a d  + 173991492b c d )n
+--R         + 
+--R                          3 3             3   2  3
+--R           (- 22313339400a d  + 405697080b c d )n
+--R         + 
+--R                          3 3             3   2  2
+--R           (- 32492401920a d  + 590770944b c d )n
+--R         + 
+--R                          3 3             3   2                3 3
+--R           (- 26275708800a d  + 477740160b c d )n - 8781696000a d
+--R         + 
+--R                     3   2
+--R           159667200b c d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R                4 3        3   2  11          4 3          3   2  10
+--R           (330a d  - 24a b c d )n   + (23100a d  - 1680a b c d )n
+--R         + 
+--R                   4 3           3   2  9             4 3            3   2  8
+--R           (711810a d  - 51768a b c d )n  + (12709620a d  - 924336a b c d )n
+--R         + 
+--R                      4 3              3   2  7
+--R           (145645830a d  - 10592424a b c d )n
+--R         + 
+--R                       4 3              3   2  6
+--R           (1120622580a d  - 81499824a b c d )n
+--R         + 
+--R                       4 3               3   2  5
+--R           (5881795590a d  - 427766952a b c d )n
+--R         + 
+--R                        4 3                3   2  4
+--R           (20948784780a d  - 1523547984a b c d )n
+--R         + 
+--R                        4 3                3   2  3
+--R           (49287977640a d  - 3584580192a b c d )n
+--R         + 
+--R                        4 3                3   2  2
+--R           (72321091920a d  - 5259715776a b c d )n
+--R         + 
+--R                        4 3                3   2                 4 3
+--R           (58845916800a d  - 4279703040a b c d )n + 19758816000a d
+--R         + 
+--R                          3   2
+--R           - 1437004800a b c d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                  5 3      2 3   2  11            5 3        2 3   2  10
+--R           (- 462a d  + 84a b c d )n   + (- 32802a d  + 5964a b c d )n
+--R         + 
+--R                      5 3          2 3   2  9
+--R           (- 1025640a d  + 186480a b c d )n
+--R         + 
+--R                       5 3           2 3   2  8
+--R           (- 18586260a d  + 3379320a b c d )n
+--R         + 
+--R                        5 3            2 3   2  7
+--R           (- 216148086a d  + 39299652a b c d )n
+--R         + 
+--R                         5 3             2 3   2  6
+--R           (- 1687068306a d  + 306739692a b c d )n
+--R         + 
+--R                         5 3              2 3   2  5
+--R           (- 8976008580a d  + 1632001560a b c d )n
+--R         + 
+--R                          5 3              2 3   2  4
+--R           (- 32372349240a d  + 5885881680a b c d )n
+--R         + 
+--R                          5 3               2 3   2  3
+--R           (- 77023113552a d  + 14004202464a b c d )n
+--R         + 
+--R                           5 3               2 3   2  2
+--R           (- 114113083392a d  + 20747833344a b c d )n
+--R         + 
+--R                          5 3               2 3   2                 5 3
+--R           (- 93588929280a d  + 17016168960a b c d )n - 31614105600a d
+--R         + 
+--R                      2 3   2
+--R           5748019200a b c d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                6 3       3 3   2     6 2   11
+--R           (462a d  - 168a b c d  + 3b c d)n
+--R         + 
+--R                  6 3         3 3   2       6 2   10
+--R           (33264a d  - 12096a b c d  + 216b c d)n
+--R         + 
+--R                    6 3          3 3   2        6 2   9
+--R           (1055670a d  - 383880a b c d  + 6855b c d)n
+--R         + 
+--R                     6 3           3 3   2          6 2   8
+--R           (19431720a d  - 7066080a b c d  + 126180b c d)n
+--R         + 
+--R                      6 3            3 3   2           6 2   7
+--R           (229661586a d  - 83513304a b c d  + 1491309b c d)n
+--R         + 
+--R                       6 3             3 3   2            6 2   6
+--R           (1822135392a d  - 662594688a b c d  + 11832048b c d)n
+--R         + 
+--R                       6 3              3 3   2            6 2   5
+--R           (9852674370a d  - 3582790680a b c d  + 63978405b c d)n
+--R         + 
+--R                        6 3               3 3   2             6 2   4
+--R           (36088363080a d  - 13123041120a b c d  + 234340020b c d)n
+--R         + 
+--R                        6 3               3 3   2             6 2   3
+--R           (87099379752a d  - 31672501728a b c d  + 565580388b c d)n
+--R         + 
+--R                         6 3               3 3   2             6 2   2
+--R           (130678599744a d  - 47519490816a b c d  + 848562336b c d)n
+--R         + 
+--R                         6 3               3 3   2             6 2
+--R           (108308914560a d  - 39385059840a b c d  + 703304640b c d)n
+--R         + 
+--R                       6 3               3 3   2             6 2
+--R           36883123200a d  - 13412044800a b c d  + 239500800b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                  7 3       4 3   2        6 2   11
+--R           (- 330a d  + 210a b c d  - 15a b c d)n
+--R         + 
+--R                    7 3         4 3   2          6 2   10
+--R           (- 24090a d  + 15330a b c d  - 1095a b c d)n
+--R         + 
+--R                     7 3          4 3   2           6 2   9
+--R           (- 776160a d  + 493920a b c d  - 35280a b c d)n
+--R         + 
+--R                       7 3           4 3   2            6 2   8
+--R           (- 14523300a d  + 9242100a b c d  - 660150a b c d)n
+--R         + 
+--R                        7 3             4 3   2             6 2   7
+--R           (- 174706290a d  + 111176730a b c d  - 7941195a b c d)n
+--R         + 
+--R                         7 3             4 3   2              6 2   6
+--R           (- 1412257770a d  + 898709490a b c d  - 64193535a b c d)n
+--R         + 
+--R                         7 3              4 3   2               6 2   5
+--R           (- 7785487380a d  + 4954401060a b c d  - 353885790a b c d)n
+--R         + 
+--R                          7 3               4 3   2                6 2   4
+--R           (- 29075712600a d  + 18502726200a b c d  - 1321623300a b c d)n
+--R         + 
+--R                          7 3               4 3   2                6 2   3
+--R           (- 71499692880a d  + 45499804560a b c d  - 3249986040a b c d)n
+--R         + 
+--R                           7 3               4 3   2                6 2   2
+--R           (- 109126448640a d  + 69444103680a b c d  - 4960293120a b c d)n
+--R         + 
+--R                          7 3               4 3   2                6 2
+--R           (- 91782408960a d  + 58406987520a b c d  - 4171927680a b c d)n
+--R         + 
+--R                         7 3               4 3   2                6 2
+--R           - 31614105600a d  + 20118067200a b c d  - 1437004800a b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                8 3       5 3   2      2 6 2   11
+--R           (165a d  - 168a b c d  + 30a b c d)n
+--R         + 
+--R                  8 3         5 3   2        2 6 2   10
+--R           (12210a d  - 12432a b c d  + 2220a b c d)n
+--R         + 
+--R                   8 3          5 3   2         2 6 2   9
+--R           (399465a d  - 406728a b c d  + 72630a b c d)n
+--R         + 
+--R                    8 3           5 3   2           2 6 2   8
+--R           (7604190a d  - 7742448a b c d  + 1382580a b c d)n
+--R         + 
+--R                     8 3            5 3   2            2 6 2   7
+--R           (93244635a d  - 94939992a b c d  + 16953570a b c d)n
+--R         + 
+--R                      8 3             5 3   2             2 6 2   6
+--R           (769916070a d  - 783914544a b c d  + 139984740a b c d)n
+--R         + 
+--R                       8 3              5 3   2             2 6 2   5
+--R           (4343723835a d  - 4422700632a b c d  + 789767970a b c d)n
+--R         + 
+--R                        8 3               5 3   2              2 6 2   4
+--R           (16626679410a d  - 16928982672a b c d  + 3023032620a b c d)n
+--R         + 
+--R                        8 3               5 3   2              2 6 2   3
+--R           (41932410300a d  - 42694817760a b c d  + 7624074600a b c d)n
+--R         + 
+--R                        8 3               5 3   2               2 6 2   2
+--R           (65582815320a d  - 66775230144a b c d  + 11924148240a b c d)n
+--R         + 
+--R                        8 3               5 3   2               2 6 2
+--R           (56376064800a d  - 57401084160a b c d  + 10250193600a b c d)n
+--R         + 
+--R                       8 3               5 3   2              2 6 2
+--R           19758816000a d  - 20118067200a b c d  + 3592512000a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 9 3      6 3   2      3 6 2     9 3  11
+--R           (- 55a d  + 84a b c d  - 30a b c d + b c )n
+--R         + 
+--R                   9 3        6 3   2        3 6 2       9 3  10
+--R           (- 4125a d  + 6300a b c d  - 2250a b c d + 75b c )n
+--R         + 
+--R                     9 3          6 3   2         3 6 2         9 3  9
+--R           (- 137060a d  + 209328a b c d  - 74760a b c d + 2492b c )n
+--R         + 
+--R                      9 3           6 3   2           3 6 2          9 3  8
+--R           (- 2656170a d  + 4056696a b c d  - 1448820a b c d + 48294b c )n
+--R         + 
+--R                       9 3            6 3   2            3 6 2           9 3  7
+--R           (- 33251955a d  + 50784804a b c d  - 18137430a b c d + 604581b c )n
+--R         + 
+--R                           9 3             6 3   2             3 6 2
+--R               - 281209005a d  + 429482844a b c d  - 153386730a b c d
+--R             + 
+--R                       9 3
+--R               5112891b c
+--R          *
+--R              6
+--R             n
+--R         + 
+--R                            9 3              6 3   2             3 6 2
+--R               - 1630835690a d  + 2490730872a b c d  - 889546740a b c d
+--R             + 
+--R                        9 3
+--R               29651558b c
+--R          *
+--R              5
+--R             n
+--R         + 
+--R                            9 3              6 3   2              3 6 2
+--R               - 6441351180a d  + 9837699984a b c d  - 3513464280a b c d
+--R             + 
+--R                         9 3
+--R               117115476b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                             9 3               6 3   2              3 6 2
+--R               - 16822322440a d  + 25692274272a b c d  - 9175812240a b c d
+--R             + 
+--R                         9 3
+--R               305860408b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                             9 3               6 3   2               3 6 2
+--R               - 27303851520a d  + 41700427776a b c d  - 14893009920a b c d
+--R             + 
+--R                         9 3
+--R               496433664b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                             9 3               6 3   2               3 6 2
+--R               - 24324220800a d  + 37149719040a b c d  - 13267756800a b c d
+--R             + 
+--R                         9 3
+--R               442258560b c
+--R          *
+--R             n
+--R         + 
+--R                        9 3               6 3   2              3 6 2
+--R           - 8781696000a d  + 13412044800a b c d  - 4790016000a b c d
+--R         + 
+--R                     9 3
+--R           159667200b c
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R               10 3      7 3   2      4 6 2        9 3  11
+--R           (11a  d  - 24a b c d  + 15a b c d - 2a b c )n
+--R         + 
+--R                10 3        7 3   2        4 6 2          9 3  10
+--R           (836a  d  - 1824a b c d  + 1140a b c d - 152a b c )n
+--R         + 
+--R                  10 3         7 3   2         4 6 2           9 3  9
+--R           (28215a  d  - 61560a b c d  + 38475a b c d - 5130a b c )n
+--R         + 
+--R                   10 3           7 3   2          4 6 2             9 3  8
+--R           (557040a  d  - 1215360a b c d  + 759600a b c d - 101280a b c )n
+--R         + 
+--R                    10 3            7 3   2           4 6 2              9 3  7
+--R           (7130013a  d  - 15556392a b c d  + 9722745a b c d - 1296366a b c )n
+--R         + 
+--R                        10 3             7 3   2            4 6 2
+--R               61932948a  d  - 135126432a b c d  + 84454020a b c d
+--R             + 
+--R                            9 3
+--R               - 11260536a b c
+--R          *
+--R              6
+--R             n
+--R         + 
+--R                         10 3             7 3   2             4 6 2
+--R               371026645a  d  - 809512680a b c d  + 505945425a b c d
+--R             + 
+--R                            9 3
+--R               - 67459390a b c
+--R          *
+--R              5
+--R             n
+--R         + 
+--R                          10 3              7 3   2              4 6 2
+--R               1524718360a  d  - 3326658240a b c d  + 2079161400a b c d
+--R             + 
+--R                             9 3
+--R               - 277221520a b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                          10 3              7 3   2              4 6 2
+--R               4179838476a  d  - 9119647584a b c d  + 5699779740a b c d
+--R             + 
+--R                             9 3
+--R               - 759970632a b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                          10 3               7 3   2              4 6 2
+--R               7194486816a  d  - 15697062144a b c d  + 9810663840a b c d
+--R             + 
+--R                              9 3
+--R               - 1308088512a b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                          10 3               7 3   2              4 6 2
+--R               6858181440a  d  - 14963304960a b c d  + 9352065600a b c d
+--R             + 
+--R                              9 3
+--R               - 1246942080a b c
+--R          *
+--R             n
+--R         + 
+--R                      10 3              7 3   2              4 6 2
+--R           2634508800a  d  - 5748019200a b c d  + 3592512000a b c d
+--R         + 
+--R                         9 3
+--R           - 479001600a b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               11 3     8 3   2     5 6 2     2 9 3  11
+--R           (- a  d  + 3a b c d  - 3a b c d + a b c )n
+--R         + 
+--R                 11 3       8 3   2       5 6 2       2 9 3  10
+--R           (- 77a  d  + 231a b c d  - 231a b c d + 77a b c )n
+--R         + 
+--R                   11 3        8 3   2        5 6 2         2 9 3  9
+--R           (- 2640a  d  + 7920a b c d  - 7920a b c d + 2640a b c )n
+--R         + 
+--R                    11 3          8 3   2          5 6 2          2 9 3  8
+--R           (- 53130a  d  + 159390a b c d  - 159390a b c d + 53130a b c )n
+--R         + 
+--R                     11 3           8 3   2           5 6 2           2 9 3  7
+--R           (- 696333a  d  + 2088999a b c d  - 2088999a b c d + 696333a b c )n
+--R         + 
+--R                           11 3            8 3   2            5 6 2
+--R                 - 6230301a  d  + 18690903a b c d  - 18690903a b c d
+--R               + 
+--R                         2 9 3
+--R                 6230301a b c
+--R          *
+--R              6
+--R             n
+--R         + 
+--R                          11 3             8 3   2             5 6 2
+--R               - 38759930a  d  + 116279790a b c d  - 116279790a b c d
+--R             + 
+--R                        2 9 3
+--R               38759930a b c
+--R          *
+--R              5
+--R             n
+--R         + 
+--R                           11 3             8 3   2             5 6 2
+--R               - 167310220a  d  + 501930660a b c d  - 501930660a b c d
+--R             + 
+--R                         2 9 3
+--R               167310220a b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                           11 3              8 3   2              5 6 2
+--R               - 489896616a  d  + 1469689848a b c d  - 1469689848a b c d
+--R             + 
+--R                         2 9 3
+--R               489896616a b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                           11 3              8 3   2              5 6 2
+--R               - 924118272a  d  + 2772354816a b c d  - 2772354816a b c d
+--R             + 
+--R                         2 9 3
+--R               924118272a b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                            11 3              8 3   2              5 6 2
+--R               - 1007441280a  d  + 3022323840a b c d  - 3022323840a b c d
+--R             + 
+--R                          2 9 3
+--R               1007441280a b c
+--R          *
+--R             n
+--R         + 
+--R                       11 3              8 3   2              5 6 2
+--R           - 479001600a  d  + 1437004800a b c d  - 1437004800a b c d
+--R         + 
+--R                     2 9 3
+--R           479001600a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        12 12      12 11        12 10         12 9          12 8           12 7
+--R       b  n   + 78b  n   + 2717b  n   + 55770b  n  + 749463b  n  + 6926634b  n
+--R     + 
+--R                12 6             12 5             12 4              12 3
+--R       44990231b  n  + 206070150b  n  + 657206836b  n  + 1414014888b  n
+--R     + 
+--R                  12 2              12              12
+--R       1931559552b  n  + 1486442880b  n + 479001600b
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 567
+t0:=x*(a+b*x)^n*(c+d*x^3)^3
+--R 
+--R
+--R          3 10       2 7     2   4    3           n
+--R   (1)  (d x   + 3c d x  + 3c d x  + c x)(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 567
+r0:=-a*(b^3*c-a^3*d)^3*(a+b*x)^(1+n)/(b^11*(1+n))+(b^3*c-10*a^3*d)*_
+   (b^3*c-a^3*d)^2*(a+b*x)^(2+n)/(b^11*(2+n))+9*a^2*d*(2*b^3*c-5*a^3*d)*_
+   (b^3*c-a^3*d)*(a+b*x)^(3+n)/(b^11*(3+n))-3*a*d*(4*b^6*c^2-35*a^3*b^3*_
+   c*d+40*a^6*d^2)*(a+b*x)^(4+n)/(b^11*(4+n))+3*d*(b^6*c^2-35*a^3*b^3*_
+   c*d+70*a^6*d^2)*(a+b*x)^(5+n)/(b^11*(5+n))+63*a^2*d^2*(b^3*c-4*a^3*d)*_
+   (a+b*x)^(6+n)/(b^11*(6+n))-21*a*d^2*(b^3*c-10*a^3*d)*(a+b*x)^(7+n)/_
+   (b^11*(7+n))+3*d^2*(b^3*c-40*a^3*d)*(a+b*x)^(8+n)/(b^11*(8+n))+45*a^2*_
+   d^3*(a+b*x)^(9+n)/(b^11*(9+n))-10*a*d^3*(a+b*x)^(10+n)/(b^11*(10+n))+_
+   d^3*(a+b*x)^(11+n)/(b^11*(11+n))
+--R 
+--R
+--R   (2)
+--R            3 10      3 9        3 8         3 7          3 6          3 5
+--R           d n   + 55d n  + 1320d n  + 18150d n  + 157773d n  + 902055d n
+--R         + 
+--R                   3 4           3 3            3 2            3            3
+--R           3416930d n  + 8409500d n  + 12753576d n  + 10628640d n + 3628800d
+--R      *
+--R                  n + 11
+--R         (b x + a)
+--R     + 
+--R                  3 10         3 9           3 8            3 7             3 6
+--R           - 10a d n   - 560a d n  - 13650a d n  - 190200a d n  - 1672230a d n
+--R         + 
+--R                       3 5              3 4              3 3               3 2
+--R           - 9653280a d n  - 36862550a d n  - 91331800a d n  - 139262760a d n
+--R         + 
+--R                         3               3
+--R           - 116552160a d n - 39916800a d
+--R      *
+--R                  n + 10
+--R         (b x + a)
+--R     + 
+--R              2 3 10        2 3 9         2 3 8          2 3 7           2 3 6
+--R           45a d n   + 2565a d n  + 63540a d n  + 898290a d n  + 7999425a d n
+--R         + 
+--R                    2 3 5             2 3 4             2 3 3             2 3 2
+--R           46695285a d n  + 180021510a d n  + 449614260a d n  + 690085080a d n
+--R         + 
+--R                     2 3              2 3
+--R           580543200a d n + 199584000a d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R                  3 3     3   2  10           3 3       3   2  9
+--R           (- 120a d  + 3b c d )n   + (- 6960a d  + 174b c d )n
+--R         + 
+--R                     3 3        3   2  8              3 3         3   2  7
+--R           (- 175320a d  + 4383b c d )n  + (- 2517840a d  + 62946b c d )n
+--R         + 
+--R                       3 3          3   2  6
+--R           (- 22748040a d  + 568701b c d )n
+--R         + 
+--R                        3 3           3   2  5
+--R           (- 134522640a d  + 3363066b c d )n
+--R         + 
+--R                        3 3            3   2  4
+--R           (- 524563080a d  + 13114077b c d )n
+--R         + 
+--R                         3 3            3   2  3
+--R           (- 1322982960a d  + 33074574b c d )n
+--R         + 
+--R                         3 3            3   2  2
+--R           (- 2047105440a d  + 51177636b c d )n
+--R         + 
+--R                       3 3            3   2               3 3            3   2
+--R         (- 1733313600a d  + 43332840b c d )n - 598752000a d  + 14968800b c d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                4 3        3   2  10          4 3          3   2  9
+--R           (210a d  - 21a b c d )n   + (12390a d  - 1239a b c d )n
+--R         + 
+--R                   4 3           3   2  8            4 3            3   2  7
+--R           (317520a d  - 31752a b c d )n  + (4638060a d  - 463806a b c d )n
+--R         + 
+--R                     4 3             3   2  6
+--R           (42592410a d  - 4259241a b c d )n
+--R         + 
+--R                      4 3              3   2  5
+--R           (255740310a d  - 25574031a b c d )n
+--R         + 
+--R                       4 3               3   2  4
+--R           (1011120180a d  - 101112018a b c d )n
+--R         + 
+--R                       4 3               3   2  3
+--R           (2581262040a d  - 258126204a b c d )n
+--R         + 
+--R                       4 3               3   2  2
+--R           (4035361680a d  - 403536168a b c d )n
+--R         + 
+--R                       4 3               3   2                4 3
+--R           (3445243200a d  - 344524320a b c d )n + 1197504000a d
+--R         + 
+--R                         3   2
+--R           - 119750400a b c d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                  5 3      2 3   2  10            5 3        2 3   2  9
+--R           (- 252a d  + 63a b c d )n   + (- 15120a d  + 3780a b c d )n
+--R         + 
+--R                     5 3         2 3   2  8
+--R           (- 394380a d  + 98595a b c d )n
+--R         + 
+--R                      5 3           2 3   2  7
+--R           (- 5866560a d  + 1466640a b c d )n
+--R         + 
+--R                       5 3            2 3   2  6
+--R           (- 54871236a d  + 13717809a b c d )n
+--R         + 
+--R                        5 3            2 3   2  5
+--R           (- 335437200a d  + 83859300a b c d )n
+--R         + 
+--R                         5 3             2 3   2  4
+--R           (- 1348939620a d  + 337234905a b c d )n
+--R         + 
+--R                         5 3             2 3   2  3
+--R           (- 3497286240a d  + 874321560a b c d )n
+--R         + 
+--R                         5 3              2 3   2  2
+--R           (- 5541317712a d  + 1385329428a b c d )n
+--R         + 
+--R                         5 3              2 3   2                5 3
+--R           (- 4783423680a d  + 1195855920a b c d )n - 1676505600a d
+--R         + 
+--R                     2 3   2
+--R           419126400a b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                6 3       3 3   2     6 2   10
+--R           (210a d  - 105a b c d  + 3b c d)n
+--R         + 
+--R                  6 3        3 3   2       6 2   9
+--R           (12810a d  - 6405a b c d  + 183b c d)n
+--R         + 
+--R                   6 3          3 3   2        6 2   8
+--R           (340200a d  - 170100a b c d  + 4860b c d)n
+--R         + 
+--R                    6 3           3 3   2         6 2   7
+--R           (5159700a d  - 2579850a b c d  + 73710b c d)n
+--R         + 
+--R                     6 3            3 3   2          6 2   6
+--R           (49260330a d  - 24630165a b c d  + 703719b c d)n
+--R         + 
+--R                      6 3             3 3   2           6 2   5
+--R           (307585530a d  - 153792765a b c d  + 4394079b c d)n
+--R         + 
+--R                       6 3             3 3   2            6 2   4
+--R           (1263374700a d  - 631687350a b c d  + 18048210b c d)n
+--R         + 
+--R                       6 3              3 3   2            6 2   3
+--R           (3342229800a d  - 1671114900a b c d  + 47746140b c d)n
+--R         + 
+--R                       6 3              3 3   2            6 2   2
+--R           (5393046960a d  - 2696523480a b c d  + 77043528b c d)n
+--R         + 
+--R                       6 3              3 3   2            6 2
+--R           (4727540160a d  - 2363770080a b c d  + 67536288b c d)n
+--R         + 
+--R                      6 3             3 3   2            6 2
+--R           1676505600a d  - 838252800a b c d  + 23950080b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R                  7 3       4 3   2        6 2   10
+--R           (- 120a d  + 105a b c d  - 12a b c d)n
+--R         + 
+--R                   7 3        4 3   2         6 2   9
+--R           (- 7440a d  + 6510a b c d  - 744a b c d)n
+--R         + 
+--R                     7 3          4 3   2           6 2   8
+--R           (- 201240a d  + 176085a b c d  - 20124a b c d)n
+--R         + 
+--R                      7 3           4 3   2            6 2   7
+--R           (- 3115440a d  + 2726010a b c d  - 311544a b c d)n
+--R         + 
+--R                       7 3            4 3   2             6 2   6
+--R           (- 30429000a d  + 26625375a b c d  - 3042900a b c d)n
+--R         + 
+--R                        7 3             4 3   2              6 2   5
+--R           (- 194790960a d  + 170442090a b c d  - 19479096a b c d)n
+--R         + 
+--R                        7 3             4 3   2              6 2   4
+--R           (- 821580360a d  + 718882815a b c d  - 82158036a b c d)n
+--R         + 
+--R                         7 3              4 3   2               6 2   3
+--R           (- 2233166160a d  + 1954020390a b c d  - 223316616a b c d)n
+--R         + 
+--R                         7 3              4 3   2               6 2   2
+--R           (- 3698304480a d  + 3236016420a b c d  - 369830448a b c d)n
+--R         + 
+--R                         7 3              4 3   2               6 2
+--R           (- 3316939200a d  + 2902321800a b c d  - 331693920a b c d)n
+--R         + 
+--R                        7 3              4 3   2               6 2
+--R           - 1197504000a d  + 1047816000a b c d  - 119750400a b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R               8 3      5 3   2      2 6 2   10
+--R           (45a d  - 63a b c d  + 18a b c d)n
+--R         + 
+--R                 8 3        5 3   2        2 6 2   9
+--R           (2835a d  - 3969a b c d  + 1134a b c d)n
+--R         + 
+--R                  8 3          5 3   2         2 6 2   8
+--R           (78120a d  - 109368a b c d  + 31248a b c d)n
+--R         + 
+--R                    8 3           5 3   2          2 6 2   7
+--R           (1235790a d  - 1730106a b c d  + 494316a b c d)n
+--R         + 
+--R                     8 3            5 3   2           2 6 2   6
+--R           (12376665a d  - 17327331a b c d  + 4950666a b c d)n
+--R         + 
+--R                     8 3             5 3   2            2 6 2   5
+--R           (81560115a d  - 114184161a b c d  + 32624046a b c d)n
+--R         + 
+--R                      8 3             5 3   2             2 6 2   4
+--R           (355598730a d  - 497838222a b c d  + 142239492a b c d)n
+--R         + 
+--R                       8 3              5 3   2             2 6 2   3
+--R           (1003011660a d  - 1404216324a b c d  + 401204664a b c d)n
+--R         + 
+--R                       8 3              5 3   2             2 6 2   2
+--R           (1727578440a d  - 2418609816a b c d  + 691031376a b c d)n
+--R         + 
+--R                       8 3              5 3   2             2 6 2
+--R           (1608573600a d  - 2252003040a b c d  + 643429440a b c d)n
+--R         + 
+--R                     8 3             5 3   2             2 6 2
+--R           598752000a d  - 838252800a b c d  + 239500800a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R                 9 3      6 3   2      3 6 2     9 3  10
+--R           (- 10a d  + 21a b c d  - 12a b c d + b c )n
+--R         + 
+--R                  9 3        6 3   2       3 6 2       9 3  9
+--R           (- 640a d  + 1344a b c d  - 768a b c d + 64b c )n
+--R         + 
+--R                    9 3         6 3   2         3 6 2         9 3  8
+--R           (- 17970a d  + 37737a b c d  - 21564a b c d + 1797b c )n
+--R         + 
+--R                     9 3          6 3   2          3 6 2          9 3  7
+--R           (- 290760a d  + 610596a b c d  - 348912a b c d + 29076b c )n
+--R         + 
+--R                      9 3           6 3   2           3 6 2           9 3  6
+--R           (- 2992710a d  + 6284691a b c d  - 3591252a b c d + 299271b c )n
+--R         + 
+--R                       9 3            6 3   2            3 6 2            9 3  5
+--R           (- 20390160a d  + 42819336a b c d  - 24468192a b c d + 2039016b c )n
+--R         + 
+--R                            9 3             6 3   2             3 6 2
+--R                 - 92615030a d  + 194491563a b c d  - 111138036a b c d
+--R               + 
+--R                         9 3
+--R                 9261503b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                           9 3             6 3   2             3 6 2
+--R               - 274727240a d  + 576927204a b c d  - 329672688a b c d
+--R             + 
+--R                        9 3
+--R               27472724b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                           9 3              6 3   2             3 6 2
+--R               - 503126280a d  + 1056565188a b c d  - 603751536a b c d
+--R             + 
+--R                        9 3
+--R               50312628b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                           9 3              6 3   2             3 6 2
+--R               - 502927200a d  + 1056147120a b c d  - 603512640a b c d
+--R             + 
+--R                        9 3
+--R               50292720b c
+--R          *
+--R             n
+--R         + 
+--R                     9 3             6 3   2             3 6 2             9 3
+--R         - 199584000a d  + 419126400a b c d  - 239500800a b c d + 19958400b c
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R             10 3     7 3   2     4 6 2       9 3  10
+--R           (a  d  - 3a b c d  + 3a b c d - a b c )n
+--R         + 
+--R               10 3       7 3   2       4 6 2         9 3  9
+--R           (65a  d  - 195a b c d  + 195a b c d - 65a b c )n
+--R         + 
+--R                 10 3        7 3   2        4 6 2           9 3  8
+--R           (1860a  d  - 5580a b c d  + 5580a b c d - 1860a b c )n
+--R         + 
+--R                  10 3         7 3   2         4 6 2            9 3  7
+--R           (30810a  d  - 92430a b c d  + 92430a b c d - 30810a b c )n
+--R         + 
+--R                   10 3          7 3   2          4 6 2             9 3  6
+--R           (326613a  d  - 979839a b c d  + 979839a b c d - 326613a b c )n
+--R         + 
+--R                    10 3           7 3   2           4 6 2              9 3  5
+--R           (2310945a  d  - 6932835a b c d  + 6932835a b c d - 2310945a b c )n
+--R         + 
+--R                          10 3            7 3   2            4 6 2
+--R                 11028590a  d  - 33085770a b c d  + 33085770a b c d
+--R               + 
+--R                              9 3
+--R                 - 11028590a b c
+--R          *
+--R              4
+--R             n
+--R         + 
+--R                        10 3             7 3   2             4 6 2
+--R               34967140a  d  - 104901420a b c d  + 104901420a b c d
+--R             + 
+--R                            9 3
+--R               - 34967140a b c
+--R          *
+--R              3
+--R             n
+--R         + 
+--R                        10 3             7 3   2             4 6 2
+--R               70290936a  d  - 210872808a b c d  + 210872808a b c d
+--R             + 
+--R                            9 3
+--R               - 70290936a b c
+--R          *
+--R              2
+--R             n
+--R         + 
+--R                        10 3             7 3   2             4 6 2
+--R               80627040a  d  - 241881120a b c d  + 241881120a b c d
+--R             + 
+--R                            9 3
+--R               - 80627040a b c
+--R          *
+--R             n
+--R         + 
+--R                  10 3             7 3   2             4 6 2               9 3
+--R         39916800a  d  - 119750400a b c d  + 119750400a b c d - 39916800a b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        11 11      11 10        11 9         11 8          11 7           11 6
+--R       b  n   + 66b  n   + 1925b  n  + 32670b  n  + 357423b  n  + 2637558b  n
+--R     + 
+--R                11 5            11 4             11 3             11 2
+--R       13339535b  n  + 45995730b  n  + 105258076b  n  + 150917976b  n
+--R     + 
+--R                 11             11
+--R       120543840b  n + 39916800b
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 567
+t0:=(a+b*x)^n*(c+d*x^3)^3
+--R 
+--R
+--R          3 9       2 6     2   3    3          n
+--R   (1)  (d x  + 3c d x  + 3c d x  + c )(b x + a)
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 567
+r0:=(b^3*c-a^3*d)^3*(a+b*x)^(1+n)/(b^10*(1+n))+9*a^2*d*(b^3*c-a^3*d)^2*_
+   (a+b*x)^(2+n)/(b^10*(2+n))-9*a*d*(b^3*c-4*a^3*d)*(b^3*c-a^3*d)*_
+   (a+b*x)^(3+n)/(b^10*(3+n))+3*d*(b^6*c^2-20*a^3*b^3*c*d+28*a^6*d^2)*_
+   (a+b*x)^(4+n)/(b^10*(4+n))+9*a^2*d^2*(5*b^3*c-14*a^3*d)*(a+b*x)^(5+n)/_
+   (b^10*(5+n))-18*a*d^2*(b^3*c-7*a^3*d)*(a+b*x)^(6+n)/(b^10*(6+n))+_
+   3*d^2*(b^3*c-28*a^3*d)*(a+b*x)^(7+n)/(b^10*(7+n))+36*a^2*d^3*_
+   (a+b*x)^(8+n)/(b^10*(8+n))-9*a*d^3*(a+b*x)^(9+n)/(b^10*(9+n))+_
+   d^3*(a+b*x)^(10+n)/(b^10*(10+n))
+--R 
+--R
+--R   (2)
+--R            3 9      3 8       3 7        3 6         3 5          3 4
+--R           d n  + 45d n  + 870d n  + 9450d n  + 63273d n  + 269325d n
+--R         + 
+--R                  3 3           3 2           3           3
+--R           723680d n  + 1172700d n  + 1026576d n + 362880d
+--R      *
+--R                  n + 10
+--R         (b x + a)
+--R     + 
+--R                 3 9         3 8          3 7           3 6            3 5
+--R           - 9a d n  - 414a d n  - 8154a d n  - 89964a d n  - 610281a d n
+--R         + 
+--R                       3 4             3 3              3 2              3
+--R           - 2625966a d n  - 7118676a d n  - 11617416a d n  - 10225440a d n
+--R         + 
+--R                       3
+--R           - 3628800a d
+--R      *
+--R                  n + 9
+--R         (b x + a)
+--R     + 
+--R              2 3 9        2 3 8         2 3 7          2 3 6           2 3 5
+--R           36a d n  + 1692a d n  + 33984a d n  + 381528a d n  + 2627604a d n
+--R         + 
+--R                    2 3 4            2 3 3            2 3 2            2 3
+--R           11453148a d n  + 31384296a d n  + 51667632a d n  + 45787680a d n
+--R         + 
+--R                    2 3
+--R           16329600a d
+--R      *
+--R                  n + 8
+--R         (b x + a)
+--R     + 
+--R                 3 3     3   2  9           3 3       3   2  8
+--R           (- 84a d  + 3b c d )n  + (- 4032a d  + 144b c d )n
+--R         + 
+--R                    3 3        3   2  7             3 3         3   2  6
+--R           (- 82656a d  + 2952b c d )n  + (- 946008a d  + 33786b c d )n
+--R         + 
+--R                      3 3          3   2  5               3 3           3   2  4
+--R           (- 6630876a d  + 236817b c d )n  + (- 29356488a d  + 1048446b c d )n
+--R         + 
+--R                       3 3           3   2  3
+--R           (- 81526704a d  + 2911668b c d )n
+--R         + 
+--R                        3 3           3   2  2
+--R           (- 135711072a d  + 4846824b c d )n
+--R         + 
+--R                        3 3           3   2              3 3           3   2
+--R           (- 121322880a d  + 4332960b c d )n - 43545600a d  + 1555200b c d
+--R      *
+--R                  n + 7
+--R         (b x + a)
+--R     + 
+--R                4 3        3   2  9         4 3         3   2  8
+--R           (126a d  - 18a b c d )n  + (6174a d  - 882a b c d )n
+--R         + 
+--R                   4 3           3   2  7            4 3            3   2  6
+--R           (129276a d  - 18468a b c d )n  + (1511244a d  - 215892a b c d )n
+--R         + 
+--R                     4 3             3   2  5
+--R           (10811934a d  - 1544562a b c d )n
+--R         + 
+--R                     4 3             3   2  4
+--R           (48787326a d  - 6969618a b c d )n
+--R         + 
+--R                      4 3              3   2  3
+--R           (137809224a d  - 19687032a b c d )n
+--R         + 
+--R                      4 3              3   2  2
+--R           (232741656a d  - 33248808a b c d )n
+--R         + 
+--R                    4 3              3   2              4 3              3   2
+--R         (210500640a d  - 30071520a b c d )n + 76204800a d  - 10886400a b c d
+--R      *
+--R                  n + 6
+--R         (b x + a)
+--R     + 
+--R                  5 3      2 3   2  9           5 3        2 3   2  8
+--R           (- 126a d  + 45a b c d )n  + (- 6300a d  + 2250a b c d )n
+--R         + 
+--R                     5 3         2 3   2  7              5 3          2 3   2  6
+--R           (- 134820a d  + 48150a b c d )n  + (- 1612800a d  + 576000a b c d )n
+--R         + 
+--R                       5 3           2 3   2  5
+--R           (- 11815398a d  + 4219785a b c d )n
+--R         + 
+--R                       5 3            2 3   2  4
+--R           (- 54581940a d  + 19493550a b c d )n
+--R         + 
+--R                        5 3            2 3   2  3
+--R           (- 157623480a d  + 56294100a b c d )n
+--R         + 
+--R                        5 3            2 3   2  2
+--R           (- 271479600a d  + 96957000a b c d )n
+--R         + 
+--R                      5 3            2 3   2              5 3            2 3   2
+--R         (- 249552576a d  + 89125920a b c d )n - 91445760a d  + 32659200a b c d
+--R      *
+--R                  n + 5
+--R         (b x + a)
+--R     + 
+--R               6 3      3 3   2     6 2   9
+--R           (84a d  - 60a b c d  + 3b c d)n
+--R         + 
+--R                 6 3        3 3   2       6 2   8
+--R           (4284a d  - 3060a b c d  + 153b c d)n
+--R         + 
+--R                  6 3         3 3   2        6 2   7
+--R           (93744a d  - 66960a b c d  + 3348b c d)n
+--R         + 
+--R                    6 3          3 3   2         6 2   6
+--R           (1149624a d  - 821160a b c d  + 41058b c d)n
+--R         + 
+--R                    6 3           3 3   2          6 2   5
+--R           (8654436a d  - 6181740a b c d  + 309087b c d)n
+--R         + 
+--R                     6 3            3 3   2           6 2   4
+--R           (41154876a d  - 29396340a b c d  + 1469817b c d)n
+--R         + 
+--R                      6 3            3 3   2           6 2   3
+--R           (122402616a d  - 87430440a b c d  + 4371522b c d)n
+--R         + 
+--R                      6 3             3 3   2           6 2   2
+--R           (216787536a d  - 154848240a b c d  + 7742412b c d)n
+--R         + 
+--R                      6 3             3 3   2           6 2               6 3
+--R           (204150240a d  - 145821600a b c d  + 7291080b c d)n + 76204800a d
+--R         + 
+--R                      3 3   2           6 2
+--R           - 54432000a b c d  + 2721600b c d
+--R      *
+--R                  n + 4
+--R         (b x + a)
+--R     + 
+--R                 7 3      4 3   2       6 2   9
+--R           (- 36a d  + 45a b c d  - 9a b c d)n
+--R         + 
+--R                   7 3        4 3   2         6 2   8
+--R           (- 1872a d  + 2340a b c d  - 468a b c d)n
+--R         + 
+--R                    7 3         4 3   2           6 2   7
+--R           (- 41904a d  + 52380a b c d  - 10476a b c d)n
+--R         + 
+--R                     7 3          4 3   2            6 2   6
+--R           (- 527688a d  + 659610a b c d  - 131922a b c d)n
+--R         + 
+--R                      7 3           4 3   2             6 2   5
+--R           (- 4096764a d  + 5120955a b c d  - 1024191a b c d)n
+--R         + 
+--R                       7 3            4 3   2             6 2   4
+--R           (- 20183688a d  + 25229610a b c d  - 5045922a b c d)n
+--R         + 
+--R                       7 3            4 3   2              6 2   3
+--R           (- 62458416a d  + 78073020a b c d  - 15614604a b c d)n
+--R         + 
+--R                        7 3             4 3   2              6 2   2
+--R           (- 115366752a d  + 144208440a b c d  - 28841688a b c d)n
+--R         + 
+--R                        7 3             4 3   2              6 2
+--R           (- 113028480a d  + 141285600a b c d  - 28257120a b c d)n
+--R         + 
+--R                      7 3            4 3   2              6 2
+--R           - 43545600a d  + 54432000a b c d  - 10886400a b c d
+--R      *
+--R                  n + 3
+--R         (b x + a)
+--R     + 
+--R              8 3      5 3   2     2 6 2   9
+--R           (9a d  - 18a b c d  + 9a b c d)n
+--R         + 
+--R                8 3       5 3   2       2 6 2   8
+--R           (477a d  - 954a b c d  + 477a b c d)n
+--R         + 
+--R                  8 3         5 3   2         2 6 2   7
+--R           (10926a d  - 21852a b c d  + 10926a b c d)n
+--R         + 
+--R                   8 3          5 3   2          2 6 2   6
+--R           (141498a d  - 282996a b c d  + 141498a b c d)n
+--R         + 
+--R                    8 3           5 3   2           2 6 2   5
+--R           (1136961a d  - 2273922a b c d  + 1136961a b c d)n
+--R         + 
+--R                    8 3            5 3   2           2 6 2   4
+--R           (5844573a d  - 11689146a b c d  + 5844573a b c d)n
+--R         + 
+--R                     8 3            5 3   2            2 6 2   3
+--R           (19063224a d  - 38126448a b c d  + 19063224a b c d)n
+--R         + 
+--R                     8 3            5 3   2            2 6 2   2
+--R           (37559052a d  - 75118104a b c d  + 37559052a b c d)n
+--R         + 
+--R                     8 3            5 3   2            2 6 2               8 3
+--R           (39664080a d  - 79328160a b c d  + 39664080a b c d)n + 16329600a d
+--R         + 
+--R                      5 3   2            2 6 2
+--R           - 32659200a b c d  + 16329600a b c d
+--R      *
+--R                  n + 2
+--R         (b x + a)
+--R     + 
+--R               9 3     6 3   2     3 6 2     9 3  9
+--R           (- a d  + 3a b c d  - 3a b c d + b c )n
+--R         + 
+--R                 9 3       6 3   2       3 6 2       9 3  8
+--R           (- 54a d  + 162a b c d  - 162a b c d + 54b c )n
+--R         + 
+--R                   9 3        6 3   2        3 6 2         9 3  7
+--R           (- 1266a d  + 3798a b c d  - 3798a b c d + 1266b c )n
+--R         + 
+--R                    9 3         6 3   2         3 6 2          9 3  6
+--R           (- 16884a d  + 50652a b c d  - 50652a b c d + 16884b c )n
+--R         + 
+--R                     9 3          6 3   2          3 6 2           9 3  5
+--R           (- 140889a d  + 422667a b c d  - 422667a b c d + 140889b c )n
+--R         + 
+--R                     9 3           6 3   2           3 6 2           9 3  4
+--R           (- 761166a d  + 2283498a b c d  - 2283498a b c d + 761166b c )n
+--R         + 
+--R                      9 3           6 3   2           3 6 2            9 3  3
+--R           (- 2655764a d  + 7967292a b c d  - 7967292a b c d + 2655764b c )n
+--R         + 
+--R                      9 3            6 3   2            3 6 2            9 3  2
+--R           (- 5753736a d  + 17261208a b c d  - 17261208a b c d + 5753736b c )n
+--R         + 
+--R                      9 3            6 3   2            3 6 2            9 3
+--R           (- 6999840a d  + 20999520a b c d  - 20999520a b c d + 6999840b c )n
+--R         + 
+--R                     9 3            6 3   2            3 6 2            9 3
+--R           - 3628800a d  + 10886400a b c d  - 10886400a b c d + 3628800b c
+--R      *
+--R                  n + 1
+--R         (b x + a)
+--R  /
+--R        10 10      10 9        10 8         10 7          10 6          10 5
+--R       b  n   + 55b  n  + 1320b  n  + 18150b  n  + 157773b  n  + 902055b  n
+--R     + 
+--R               10 4           10 3            10 2            10            10
+--R       3416930b  n  + 8409500b  n  + 12753576b  n  + 10628640b  n + 3628800b
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 567
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 567
+t0:=(a+b*x)^n*(c+d*x^3)^3/x
+--R 
+--R
+--R          3 9       2 6     2   3    3          n
+--R        (d x  + 3c d x  + 3c d x  + c )(b x + a)
+--R   (1)  -----------------------------------------
+--R                            x
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 567
+--r0:=3*a^2*c^2*d*(a+b*x)^(1+n)/(b^3*(1+n))-3*a^5*c*d^2*(a+b*x)^(1+n)/_
+--   (b^6*(1+n))+a^8*d^3*(a+b*x)^(1+n)/(b^9*(1+n))-6*a*c^2*d*(a+b*x)^(2+n)/_
+--   (b^3*(2+n))+15*a^4*c*d^2*(a+b*x)^(2+n)/(b^6*(2+n))-8*a^7*d^3*_
+--   (a+b*x)^(2+n)/(b^9*(2+n))+3*c^2*d*(a+b*x)^(3+n)/(b^3*(3+n))-_
+--   30*a^3*c*d^2*(a+b*x)^(3+n)/(b^6*(3+n))+28*a^6*d^3*(a+b*x)^(3+n)/_
+--   (b^9*(3+n))+30*a^2*c*d^2*(a+b*x)^(4+n)/(b^6*(4+n))-56*a^5*d^3*_
+--   (a+b*x)^(4+n)/(b^9*(4+n))-15*a*c*d^2*(a+b*x)^(5+n)/(b^6*(5+n))+_
+--   70*a^4*d^3*(a+b*x)^(5+n)/(b^9*(5+n))+3*c*d^2*(a+b*x)^(6+n)/(b^6*_
+--   (6+n))-56*a^3*d^3*(a+b*x)^(6+n)/(b^9*(6+n))+28*a^2*d^3*_
+--   (a+b*x)^(7+n)/(b^9*(7+n))-8*a*d^3*(a+b*x)^(8+n)/(b^9*(8+n))+d^3*_
+--   (a+b*x)^(9+n)/(b^9*(9+n))-c^3*(a+b*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(a+b*x)/a)/(a*(1+n))
+--E 530
+
+--S 531 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 531
+
+)clear all
+
+--S 532 of 567
+t0:=x^m*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R         m         n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 567
+--r0:=1/3*x^(1+m)*(e+f*x)^n*AppellF1(1+m,1,-n,2+m,-b^(1/3)*x/a^(1/3),_
+--   -f*x/e)/(a*(1+m)*((e+f*x)/e)^n)+1/3*x^(1+m)*(e+f*x)^n*_
+--   AppellF1(1+m,1,-n,2+m,(-1)^(1/3)*b^(1/3)*x/a^(1/3),-f*x/e)/_
+--   (a*(1+m)*((e+f*x)/e)^n)+1/3*x^(1+m)*(e+f*x)^n*AppellF1(1+m,1,-n,_
+--   2+m,-(-1)^(2/3)*b^(1/3)*x/a^(1/3),-f*x/e)/(a*(1+m)*((e+f*x)/e)^n)
+--E 533
+
+--S 534 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 534
+
+)clear all
+
+--S 535 of 567
+t0:=x^5*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R         5         n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 567
+--r0:=e^2*(e+f*x)^(1+n)/(b*f^3*(1+n))-2*e*(e+f*x)^(2+n)/(b*f^3*(2+n))+_
+--   (e+f*x)^(3+n)/(b*f^3*(3+n))+1/3*a*(e+f*x)^(1+n)*hypergeometric(1,_
+--   1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-a^(1/3)*f))/(b^(5/3)*(b^(1/3)*e-_
+--   a^(1/3)*f)*(1+n))+1/3*a*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*_
+--   (e+f*x)/(b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f))/(b^(5/3)*(b^(1/3)*e+_
+--   (-1)^(1/3)*a^(1/3)*f)*(1+n))+1/3*a*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-(-1)^(2/3)*_
+--   a^(1/3)*f))/(b^(5/3)*(b^(1/3)*e-(-1)^(2/3)*a^(1/3)*f)*(1+n))
+--E 536
+
+--S 537 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 537
+
+)clear all
+
+--S 538 of 567
+t0:=x^4*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R         4         n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 567
+--r0:=-e*(e+f*x)^(1+n)/(b*f^2*(1+n))+(e+f*x)^(2+n)/(b*f^2*(2+n))-_
+--   1/3*a^(2/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*_
+--   (e+f*x)/(b^(1/3)*e-a^(1/3)*f))/(b^(4/3)*(b^(1/3)*e-a^(1/3)*f)*_
+--   (1+n))+1/3*(-1)^(1/3)*a^(2/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,_
+--   2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f))/(b^(4/3)*_
+--   ((-1)^(2/3)*b^(1/3)*e-a^(1/3)*f)*(1+n))+1/3*(-1)^(2/3)*a^(2/3)*_
+--   (e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*_
+--   e-(-1)^(2/3)*a^(1/3)*f))/(b^(4/3)*((-1)^(1/3)*b^(1/3)*e+a^(1/3)*f)*(1+n))
+--E 539
+
+--S 540 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 540
+
+)clear all
+
+--S 541 of 567
+t0:=x^3*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R         3         n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 567
+--r0:=(e+f*x)^(1+n)/(b*f*(1+n))+1/3*a^(1/3)*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-a^(1/3)*f))/_
+--   (b*(b^(1/3)*e-a^(1/3)*f)*(1+n))+1/3*a^(1/3)*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e+(-1)^(1/3)*_
+--   a^(1/3)*f))/(b*((-1)^(2/3)*b^(1/3)*e-a^(1/3)*f)*(1+n))-1/3*a^(1/3)*_
+--   (e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*_
+--   e-(-1)^(2/3)*a^(1/3)*f))/(b*((-1)^(1/3)*b^(1/3)*e+a^(1/3)*f)*(1+n))
+--E 542
+
+--S 543 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 543
+
+)clear all
+
+--S 544 of 567
+t0:=x^2*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R         2         n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 567
+--r0:=-1/3*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/_
+--   (b^(1/3)*e-a^(1/3)*f))/(b^(2/3)*(b^(1/3)*e-a^(1/3)*f)*(1+n))-_
+--   1/3*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*_
+--   e+(-1)^(1/3)*a^(1/3)*f))/(b^(2/3)*(b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f)*_
+--   (1+n))-1/3*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/_
+--   (b^(1/3)*e-(-1)^(2/3)*a^(1/3)*f))/(b^(2/3)*(b^(1/3)*e-(-1)^(2/3)*_
+--   a^(1/3)*f)*(1+n))
+--E 545
+
+--S 546 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 546
+
+)clear all
+
+--S 547 of 567
+t0:=x*(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R                   n
+--R        x (f x + e)
+--R   (1)  ------------
+--R             3
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 567
+--r0:=1/3*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-_
+--   a^(1/3)*f))/(a^(1/3)*b^(1/3)*(b^(1/3)*e-a^(1/3)*f)*(1+n))-_
+--   1/3*(-1)^(1/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*_
+--   (e+f*x)/(b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f))/(a^(1/3)*b^(1/3)*_
+--   ((-1)^(2/3)*b^(1/3)*e-a^(1/3)*f)*(1+n))-1/3*(-1)^(2/3)*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-(-1)^(2/3)*_
+--   a^(1/3)*f))/(a^(1/3)*b^(1/3)*((-1)^(1/3)*b^(1/3)*e+a^(1/3)*f)*(1+n))
+--E 548
+
+--S 549 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 549
+
+)clear all
+
+--S 550 of 567
+t0:=(e+f*x)^n/(a+b*x^3)
+--R 
+--R
+--R                 n
+--R        (f x + e)
+--R   (1)  ----------
+--R            3
+--R         b x  + a
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 567
+--r0:=-1/3*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-_
+--   a^(1/3)*f))/(a^(2/3)*(b^(1/3)*e-a^(1/3)*f)*(1+n))-1/3*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e+(-1)^(1/3)*_
+--   a^(1/3)*f))/(a^(2/3)*((-1)^(2/3)*b^(1/3)*e-a^(1/3)*f)*(1+n))+1/3*_
+--   (e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*_
+--   e-(-1)^(2/3)*a^(1/3)*f))/(a^(2/3)*((-1)^(1/3)*b^(1/3)*e+a^(1/3)*f)*(1+n))
+--E 551
+
+--S 552 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 552
+
+)clear all
+
+--S 553 of 567
+t0:=(e+f*x)^n/(x*(a+b*x^3))
+--R 
+--R
+--R                 n
+--R        (f x + e)
+--R   (1)  ----------
+--R           4
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 567
+--r0:=-(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,(e+f*x)/e)/(a*e*(1+n))+_
+--   1/3*b^(1/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/_
+--   (b^(1/3)*e-a^(1/3)*f))/(a*(b^(1/3)*e-a^(1/3)*f)*(1+n))+1/3*b^(1/3)*_
+--   (e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*_
+--   e+(-1)^(1/3)*a^(1/3)*f))/(a*(b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f)*(1+n))+_
+--   1/3*b^(1/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/_
+--   (b^(1/3)*e-(-1)^(2/3)*a^(1/3)*f))/(a*(b^(1/3)*e-(-1)^(2/3)*_
+--   a^(1/3)*f)*(1+n))
+--E 554
+
+--S 555 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 555
+
+)clear all
+
+--S 556 of 567
+t0:=(e+f*x)^n/(x^2*(a+b*x^3))
+--R 
+--R
+--R                  n
+--R         (f x + e)
+--R   (1)  -----------
+--R           5      2
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 567
+--r0:=-(e+f*x)^(1+n)/(a*e*x)-f*n*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,(e+f*x)/e)/(a*e^2*(1+n))-1/3*b^(2/3)*_
+--   (e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-_
+--   a^(1/3)*f))/(a^(4/3)*(b^(1/3)*e-a^(1/3)*f)*(1+n))+1/3*(-1)^(1/3)*_
+--   b^(2/3)*(e+f*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/_
+--   (b^(1/3)*e+(-1)^(1/3)*a^(1/3)*f))/(a^(4/3)*((-1)^(2/3)*b^(1/3)*e-_
+--   a^(1/3)*f)*(1+n))+1/3*(-1)^(2/3)*b^(2/3)*(e+f*x)^(1+n)*_
+--   hypergeometric(1,1+n,2+n,b^(1/3)*(e+f*x)/(b^(1/3)*e-(-1)^(2/3)*_
+--   a^(1/3)*f))/(a^(4/3)*((-1)^(1/3)*b^(1/3)*e+a^(1/3)*f)*(1+n))
+--E 557
+
+--S 558 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 558
+
+)clear all
+
+--S 559 of 567
+t0:=x^2*(c+d*x)^(1+n)/(a+b*x^3)
+--R 
+--R
+--R         2         n + 1
+--R        x (d x + c)
+--R   (1)  ----------------
+--R               3
+--R            b x  + a
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 567
+--r0:=-1/3*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/3)*(c+d*x)/_
+--   (b^(1/3)*c-a^(1/3)*d))/(b^(2/3)*(b^(1/3)*c-a^(1/3)*d)*(2+n))-_
+--   1/3*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/3)*(c+d*x)/(b^(1/3)*_
+--   c+(-1)^(1/3)*a^(1/3)*d))/(b^(2/3)*(b^(1/3)*c+(-1)^(1/3)*a^(1/3)*d)*_
+--   (2+n))-1/3*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/3)*(c+d*x)/_
+--   (b^(1/3)*c-(-1)^(2/3)*a^(1/3)*d))/(b^(2/3)*(b^(1/3)*c-(-1)^(2/3)*_
+--   a^(1/3)*d)*(2+n))
+--E 560
+
+--S 561 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 561
+
+)clear all
+
+--S 562 of 567
+t0:=x^3*(c+d*x)^n/(a+b*x^4)
+--R 
+--R
+--R         3         n
+--R        x (d x + c)
+--R   (1)  ------------
+--R             4
+--R          b x  + a
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 567
+--r0:=-1/4*(c+d*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/4)*(c+d*x)/_
+--   (b^(1/4)*c-(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c-(-a)^(1/4)*d)*(1+n))-_
+--   1/4*(c+d*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c-%i*(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c-%i*(-a)^(1/4)*d)*(1+n))-_
+--   1/4*(c+d*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c+%i*(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c+%i*(-a)^(1/4)*d)*(1+n))-_
+--   1/4*(c+d*x)^(1+n)*hypergeometric(1,1+n,2+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c+(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c+(-a)^(1/4)*d)*(1+n))
+--E 563
+
+--S 564 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 564
+
+)clear all
+
+--S 565 of 567
+t0:=x^3*(c+d*x)^(1+n)/(a+b*x^4)
+--R 
+--R
+--R         3         n + 1
+--R        x (d x + c)
+--R   (1)  ----------------
+--R               4
+--R            b x  + a
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 567
+--r0:=-1/4*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/4)*(c+d*x)/_
+--   (b^(1/4)*c-(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c-(-a)^(1/4)*d)*(2+n))-_
+--   1/4*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c-%i*(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c-%i*(-a)^(1/4)*d)*(2+n))-_
+--   1/4*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c+%i*(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c+%i*(-a)^(1/4)*d)*(2+n))-_
+--   1/4*(c+d*x)^(2+n)*hypergeometric(1,2+n,3+n,b^(1/4)*(c+d*x)/(b^(1/4)*_
+--   c+(-a)^(1/4)*d))/(b^(3/4)*(b^(1/4)*c+(-a)^(1/4)*d)*(2+n))
+--E 566
+
+--S 567 of 567
+--d0:=normalize(t0-D(r0,x))
+--E 567
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder24a.input.pamphlet b/src/input/richder24a.input.pamphlet
new file mode 100644
index 0000000..6a0d20d
--- /dev/null
+++ b/src/input/richder24a.input.pamphlet
@@ -0,0 +1,5961 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder24a.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Exponential Functions
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder24a.output
+)spool richder24a.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^m
+--R 
+--R
+--R         b c x + a c         m
+--R   (1)  F           (e x + d)
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)^(1+m)*GAMMA(1+m,-b*c*(d+e*x)*log(F)/e)*_
+--  (-b*c*(d+e*x)*log(F)/e)^(-1-m)/e
+--E 2
+
+--S 3 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 3
+
+)clear all
+
+--S 4 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^5
+--R 
+--R
+--R          5 5       4 4      2 3 3      3 2 2     4       5  b c x + a c
+--R   (1)  (e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 600
+--r0:=-e^5*F^(c*(a-b*d/e))*GAMMA(6,-b*c*(d+e*x)*log(F)/e)/(b^6*c^6*log(F)^6)
+--E 5
+
+--S 6 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 6
+
+)clear all
+
+--S 7 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b c x + a c
+--R   (1)  (e x  + 4d e x  + 6d e x  + 4d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 600
+--r0:=e^4*F^(c*(a-b*d/e))*GAMMA(5,-b*c*(d+e*x)*log(F)/e)/(b^5*c^5*log(F)^5)
+--E 8
+
+--S 9 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 9
+
+)clear all
+
+--S 10 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^3
+--R 
+--R
+--R          3 3       2 2     2       3  b c x + a c
+--R   (1)  (e x  + 3d e x  + 3d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 600
+r0:=-6*e^3*F^(c*(a+b*x))/(b^4*c^4*log(F)^4)+6*e^2*F^(c*(a+b*x))*_
+   (d+e*x)/(b^3*c^3*log(F)^3)-3*e*F^(c*(a+b*x))*(d+e*x)^2/(b^2*c^2*_
+   log(F)^2)+F^(c*(a+b*x))*(d+e*x)^3/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R           3 3 3 3     3 3   2 2     3 3 2       3 3 3       3
+--R         (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F)
+--R       + 
+--R              2 2 3 2     2 2   2      2 2 2        2
+--R         (- 3b c e x  - 6b c d e x - 3b c d e)log(F)
+--R       + 
+--R                3            2            3
+--R         (6b c e x + 6b c d e )log(F) - 6e
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^2
+--R 
+--R
+--R          2 2             2  b c x + a c
+--R   (1)  (e x  + 2d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 600
+r0:=2*e^2*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)-2*e*F^(c*(a+b*x))*(d+e*x)/_
+   (b^2*c^2*log(F)^2)+F^(c*(a+b*x))*(d+e*x)^2/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R           2 2 2 2     2 2         2 2 2       2            2
+--R         (b c e x  + 2b c d e x + b c d )log(F)  + (- 2b c e x - 2b c d e)log(F)
+--R       + 
+--R           2
+--R         2e
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)
+--R 
+--R
+--R                  b c x + a c
+--R   (1)  (e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 600
+r0:=-e*F^(c*(a+b*x))/(b^2*c^2*log(F)^2)+F^(c*(a+b*x))*(d+e*x)/(b*c*log(F))
+--R 
+--R
+--R                                      b c x + a c
+--R        ((b c e x + b c d)log(F) - e)F
+--R   (2)  -----------------------------------------
+--R                        2 2      2
+--R                       b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 600
+t0:=F^(c*(a+b*x))
+--R 
+--R
+--R         b c x + a c
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 600
+r0:=F^(c*(a+b*x))/(b*c*log(F))
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (2)  ------------
+--R         b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (1)  ------------
+--R           e x + d
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 600
+r0:=F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*log(F)/e)/e
+--R 
+--R
+--R         a c e - b c d
+--R         -------------
+--R               e         (b c e x + b c d)log(F)
+--R        F             Ei(-----------------------)
+--R                                    e
+--R   (2)  -----------------------------------------
+--R                            e
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^2
+--R 
+--R
+--R            b c x + a c
+--R           F
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 600
+r0:=-F^(c*(a+b*x))/(e*(d+e*x))+b*c*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*_
+   log(F)/e)*log(F)/e^2
+--R 
+--R
+--R   (2)
+--R                               a c e - b c d
+--R                               -------------
+--R                                     e         (b c e x + b c d)log(F)
+--R       (b c e x + b c d)log(F)F             Ei(-----------------------)
+--R                                                          e
+--R     + 
+--R            b c x + a c
+--R       - e F
+--R  /
+--R      3       2
+--R     e x + d e
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^3
+--R 
+--R
+--R                 b c x + a c
+--R                F
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 600
+r0:=-1/2*F^(c*(a+b*x))/(e*(d+e*x)^2)-1/2*b*c*F^(c*(a+b*x))*_
+   log(F)/(e^2*(d+e*x))+1/2*b^2*c^2*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*_
+   log(F)/e)*log(F)^2/e^3
+--R 
+--R
+--R   (2)
+--R                                                 a c e - b c d
+--R                                                 -------------
+--R           2 2 2 2     2 2         2 2 2       2       e
+--R         (b c e x  + 2b c d e x + b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R                2                      2  b c x + a c
+--R       ((- b c e x - b c d e)log(F) - e )F
+--R  /
+--R       5 2       4      2 3
+--R     2e x  + 4d e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^4
+--R 
+--R
+--R                      b c x + a c
+--R                     F
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 600
+r0:=-1/3*F^(c*(a+b*x))/(e*(d+e*x)^3)-1/6*b*c*F^(c*(a+b*x))*log(F)/(e^2*_
+   (d+e*x)^2)-1/6*b^2*c^2*F^(c*(a+b*x))*log(F)^2/(e^3*(d+e*x))+_
+   1/6*b^3*c^3*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*log(F)/e)*log(F)^3/e^4
+--R 
+--R
+--R   (2)
+--R                                                               a c e - b c d
+--R                                                               -------------
+--R           3 3 3 3     3 3   2 2     3 3 2       3 3 3       3       e
+--R         (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R               2 2 3 2     2 2   2     2 2 2        2
+--R           (- b c e x  - 2b c d e x - b c d e)log(F)
+--R         + 
+--R                   3           2            3
+--R           (- b c e x - b c d e )log(F) - 2e
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R       7 3        6 2      2 5      3 4
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^5
+--R 
+--R
+--R                            b c x + a c
+--R                           F
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 600
+--r0:=-b^4*c^4*F^(c*(a-b*d/e))*GAMMA(-4,-b*c*(d+e*x)*log(F)/e)*log(F)^4/e^5
+--E 35
+
+--S 36 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 36
+
+)clear all
+
+--S 37 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^6
+--R 
+--R
+--R                                  b c x + a c
+--R                                 F
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 600
+--r0:=b^5*c^5*F^(c*(a-b*d/e))*GAMMA(-5,-b*c*(d+e*x)*log(F)/e)*log(F)^5/e^6
+--E 38
+
+--S 39 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 39
+
+)clear all
+
+--S 40 of 600
+t0:=F^(c*(a+b*x))*(d^5+5*d^4*e*x+10*d^3*e^2*x^2+10*d^2*e^3*x^3+_
+   5*d*e^4*x^4+e^5*x^5)
+--R 
+--R
+--R          5 5       4 4      2 3 3      3 2 2     4       5  b c x + a c
+--R   (1)  (e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 600
+--r0:=-e^5*F^(c*(a-b*d/e))*GAMMA(6,-b*c*(d+e*x)*log(F)/e)/(b^6*c^6*log(F)^6)
+--E 41
+
+--S 42 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 42
+
+)clear all
+
+--S 43 of 600
+t0:=F^(c*(a+b*x))*(d^4+4*d^3*e*x+6*d^2*e^2*x^2+4*d*e^3*x^3+e^4*x^4)
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b c x + a c
+--R   (1)  (e x  + 4d e x  + 6d e x  + 4d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 600
+--r0:=e^4*F^(c*(a-b*d/e))*GAMMA(5,-b*c*(d+e*x)*log(F)/e)/(b^5*c^5*log(F)^5)
+--E 44
+
+--S 45 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 45
+
+)clear all
+
+--S 46 of 600
+t0:=F^(c*(a+b*x))*(d^3+3*d^2*e*x+3*d*e^2*x^2+e^3*x^3)
+--R 
+--R
+--R          3 3       2 2     2       3  b c x + a c
+--R   (1)  (e x  + 3d e x  + 3d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 600
+r0:=-6*e^3*F^(c*(a+b*x))/(b^4*c^4*log(F)^4)+6*e^2*F^(c*(a+b*x))*(d+e*x)/_
+   (b^3*c^3*log(F)^3)-3*e*F^(c*(a+b*x))*(d+e*x)^2/(b^2*c^2*log(F)^2)+_
+   F^(c*(a+b*x))*(d+e*x)^3/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R           3 3 3 3     3 3   2 2     3 3 2       3 3 3       3
+--R         (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F)
+--R       + 
+--R              2 2 3 2     2 2   2      2 2 2        2
+--R         (- 3b c e x  - 6b c d e x - 3b c d e)log(F)
+--R       + 
+--R                3            2            3
+--R         (6b c e x + 6b c d e )log(F) - 6e
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 600
+t0:=F^(c*(a+b*x))*(d^2+2*d*e*x+e^2*x^2)
+--R 
+--R
+--R          2 2             2  b c x + a c
+--R   (1)  (e x  + 2d e x + d )F
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 600
+r0:=2*e^2*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)-2*e*F^(c*(a+b*x))*(d+e*x)/_
+   (b^2*c^2*log(F)^2)+F^(c*(a+b*x))*(d+e*x)^2/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R           2 2 2 2     2 2         2 2 2       2            2
+--R         (b c e x  + 2b c d e x + b c d )log(F)  + (- 2b c e x - 2b c d e)log(F)
+--R       + 
+--R           2
+--R         2e
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)
+--R 
+--R
+--R                  b c x + a c
+--R   (1)  (e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 600
+r0:=-e*F^(c*(a+b*x))/(b^2*c^2*log(F)^2)+F^(c*(a+b*x))*(d+e*x)/(b*c*log(F))
+--R 
+--R
+--R                                      b c x + a c
+--R        ((b c e x + b c d)log(F) - e)F
+--R   (2)  -----------------------------------------
+--R                        2 2      2
+--R                       b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 600
+t0:=F^(c*(a+b*x))
+--R 
+--R
+--R         b c x + a c
+--R   (1)  F
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 600
+r0:=F^(c*(a+b*x))/(b*c*log(F))
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (2)  ------------
+--R         b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (1)  ------------
+--R           e x + d
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 600
+r0:=F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*log(F)/e)/e
+--R 
+--R
+--R         a c e - b c d
+--R         -------------
+--R               e         (b c e x + b c d)log(F)
+--R        F             Ei(-----------------------)
+--R                                    e
+--R   (2)  -----------------------------------------
+--R                            e
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 600
+t0:=F^(c*(a+b*x))/(d^2+2*d*e*x+e^2*x^2)
+--R 
+--R
+--R            b c x + a c
+--R           F
+--R   (1)  ------------------
+--R         2 2             2
+--R        e x  + 2d e x + d
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 600
+r0:=-F^(c*(a+b*x))/(e*(d+e*x))+b*c*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*_
+   log(F)/e)*log(F)/e^2
+--R 
+--R
+--R   (2)
+--R                               a c e - b c d
+--R                               -------------
+--R                                     e         (b c e x + b c d)log(F)
+--R       (b c e x + b c d)log(F)F             Ei(-----------------------)
+--R                                                          e
+--R     + 
+--R            b c x + a c
+--R       - e F
+--R  /
+--R      3       2
+--R     e x + d e
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 600
+t0:=F^(c*(a+b*x))/(d^3+3*d^2*e*x+3*d*e^2*x^2+e^3*x^3)
+--R 
+--R
+--R                 b c x + a c
+--R                F
+--R   (1)  ----------------------------
+--R         3 3       2 2     2       3
+--R        e x  + 3d e x  + 3d e x + d
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 600
+r0:=-1/2*F^(c*(a+b*x))/(e*(d+e*x)^2)-1/2*b*c*F^(c*(a+b*x))*log(F)/_
+   (e^2*(d+e*x))+1/2*b^2*c^2*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*log(F)/e)*_
+   log(F)^2/e^3
+--R 
+--R
+--R   (2)
+--R                                                 a c e - b c d
+--R                                                 -------------
+--R           2 2 2 2     2 2         2 2 2       2       e
+--R         (b c e x  + 2b c d e x + b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R                2                      2  b c x + a c
+--R       ((- b c e x - b c d e)log(F) - e )F
+--R  /
+--R       5 2       4      2 3
+--R     2e x  + 4d e x + 2d e
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 600
+t0:=F^(c*(a+b*x))/(d^4+4*d^3*e*x+6*d^2*e^2*x^2+4*d*e^3*x^3+e^4*x^4)
+--R 
+--R
+--R                      b c x + a c
+--R                     F
+--R   (1)  --------------------------------------
+--R         4 4       3 3     2 2 2     3       4
+--R        e x  + 4d e x  + 6d e x  + 4d e x + d
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 600
+r0:=-1/3*F^(c*(a+b*x))/(e*(d+e*x)^3)-1/6*b*c*F^(c*(a+b*x))*log(F)/_
+   (e^2*(d+e*x)^2)-1/6*b^2*c^2*F^(c*(a+b*x))*log(F)^2/(e^3*(d+e*x))+_
+   1/6*b^3*c^3*F^(c*(a-b*d/e))*Ei(b*c*(d+e*x)*log(F)/e)*log(F)^3/e^4
+--R 
+--R
+--R   (2)
+--R                                                               a c e - b c d
+--R                                                               -------------
+--R           3 3 3 3     3 3   2 2     3 3 2       3 3 3       3       e
+--R         (b c e x  + 3b c d e x  + 3b c d e x + b c d )log(F) F
+--R      *
+--R            (b c e x + b c d)log(F)
+--R         Ei(-----------------------)
+--R                       e
+--R     + 
+--R               2 2 3 2     2 2   2     2 2 2        2
+--R           (- b c e x  - 2b c d e x - b c d e)log(F)
+--R         + 
+--R                   3           2            3
+--R           (- b c e x - b c d e )log(F) - 2e
+--R      *
+--R          b c x + a c
+--R         F
+--R  /
+--R       7 3        6 2      2 5      3 4
+--R     6e x  + 18d e x  + 18d e x + 6d e
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 600
+t0:=F^(c*(a+b*x))/(d^5+5*d^4*e*x+10*d^3*e^2*x^2+10*d^2*e^3*x^3+_
+   5*d*e^4*x^4+e^5*x^5)
+--R 
+--R
+--R                            b c x + a c
+--R                           F
+--R   (1)  --------------------------------------------------
+--R         5 5       4 4      2 3 3      3 2 2     4       5
+--R        e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 600
+--r0:=-b^4*c^4*F^(c*(a-b*d/e))*GAMMA(-4,-b*c*(d+e*x)*log(F)/e)*log(F)^4/e^5
+--E 71
+
+--S 72 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 72
+
+)clear all
+
+--S 73 of 600
+t0:=F^(c*(a+b*x))/(d^6+6*d^5*e*x+15*d^4*e^2*x^2+20*d^3*e^3*x^3+_
+   15*d^2*e^4*x^4+6*d*e^5*x^5+e^6*x^6)
+--R 
+--R
+--R                                  b c x + a c
+--R                                 F
+--R   (1)  -------------------------------------------------------------
+--R         6 6       5 5      2 4 4      3 3 3      4 2 2     5       6
+--R        e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 600
+--r0:=b^5*c^5*F^(c*(a-b*d/e))*GAMMA(-5,-b*c*(d+e*x)*log(F)/e)*log(F)^5/e^6
+--E 74
+
+--S 75 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 75
+
+)clear all
+
+--S 76 of 600
+t0:=F^(c*(a+b*x))*((d+e*x)^n)^m
+--R 
+--R
+--R         b c x + a c         m n
+--R   (1)  F           (e x + d)
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*((d+e*x)^n)^m*GAMMA(1+m*n,-b*c*(d+e*x)*_
+--  log(F)/e)*(-b*c*(d+e*x)*log(F)/e)^(-1-m*n)/e
+--E 77
+
+--S 78 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 78
+
+)clear all
+
+--S 79 of 600
+t0:=F^(c*(a+b*x))*(d^4+4*d^3*e*x+6*d^2*e^2*x^2+4*d*e^3*x^3+e^4*x^4)^m
+--R 
+--R
+--R         b c x + a c  4 4       3 3     2 2 2     3       4 m
+--R   (1)  F           (e x  + 4d e x  + 6d e x  + 4d e x + d )
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*((d+e*x)^4)^m*GAMMA(1+4*m,-b*c*(d+e*x)*_
+--  log(F)/e)*(-b*c*(d+e*x)*log(F)/e)^(-1-4*m)/e
+--E 80
+
+--S 81 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 81
+
+)clear all
+
+--S 82 of 600
+t0:=F^(c*(a+b*x))*(d^3+3*d^2*e*x+3*d*e^2*x^2+e^3*x^3)^m
+--R 
+--R
+--R         b c x + a c  3 3       2 2     2       3 m
+--R   (1)  F           (e x  + 3d e x  + 3d e x + d )
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*((d+e*x)^3)^m*GAMMA(1+3*m,-b*c*(d+e*x)*_
+--  log(F)/e)*(-b*c*(d+e*x)*log(F)/e)^(-1-3*m)/e
+--E 83
+
+--S 84 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 84
+
+)clear all
+
+--S 85 of 600
+t0:=F^(c*(a+b*x))*(d^2+2*d*e*x+e^2*x^2)^m
+--R 
+--R
+--R         b c x + a c  2 2             2 m
+--R   (1)  F           (e x  + 2d e x + d )
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*((d+e*x)^2)^m*GAMMA(1+2*m,-b*c*(d+e*x)*_
+--  log(F)/e)*(-b*c*(d+e*x)*log(F)/e)^(-1-2*m)/e
+--E 86
+
+--S 87 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 87
+
+)clear all
+
+--S 88 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^m
+--R 
+--R
+--R         b c x + a c         m
+--R   (1)  F           (e x + d)
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)^(1+m)*GAMMA(1+m,-b*c*(d+e*x)*log(F)/e)*_
+--  (-b*c*(d+e*x)*log(F)/e)^(-1-m)/e
+--E 89
+
+--S 90 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 90
+
+)clear all
+
+--S 91 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^m
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (1)  ------------
+--R                  m
+--R         (e x + d)
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)^(1-m)*GAMMA(1-m,-b*c*(d+e*x)*log(F)/e)*_
+--  (-b*c*(d+e*x)*log(F)/e)^(-1+m)/e
+--E 92
+
+--S 93 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 93
+
+)clear all
+
+--S 94 of 600
+t0:=F^(c*(a+b*x))/(d^2+2*d*e*x+e^2*x^2)^m
+--R 
+--R
+--R              b c x + a c
+--R             F
+--R   (1)  ---------------------
+--R          2 2             2 m
+--R        (e x  + 2d e x + d )
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*GAMMA(1-2*m,-b*c*(d+e*x)*log(F)/e)*_
+--  (-b*c*(d+e*x)*log(F)/e)^(-1+2*m)/(e*((d+e*x)^2)^m)
+--E 95
+
+--S 96 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 96
+
+)clear all
+
+--S 97 of 600
+t0:=F^(c*(a+b*x))/(d^3+3*d^2*e*x+3*d*e^2*x^2+e^3*x^3)^m
+--R 
+--R
+--R                   b c x + a c
+--R                  F
+--R   (1)  -------------------------------
+--R          3 3       2 2     2       3 m
+--R        (e x  + 3d e x  + 3d e x + d )
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)*GAMMA(1-3*m,-b*c*(d+e*x)*log(F)/e)*_
+--  (-b*c*(d+e*x)*log(F)/e)^(-1+3*m)/(e*((d+e*x)^3)^m)
+--E 98
+
+--S 99 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 99
+
+)clear all
+
+--S 100 of 600
+t0:=f^(2+5*x)
+--R 
+--R
+--R         5x + 2
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 600
+r0:=1/5*f^(2+5*x)/log(f)
+--R 
+--R
+--R         5x + 2
+--R        f
+--R   (2)  -------
+--R        5log(f)
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 600
+t0:=f^(a+b*x)
+--R 
+--R
+--R         b x + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 600
+r0:=f^(a+b*x)/(b*log(f))
+--R 
+--R
+--R         b x + a
+--R        f
+--R   (2)  --------
+--R        b log(f)
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 600
+t0:=10^(2+5*x)
+--R 
+--R
+--R          5x + 2
+--R   (1)  10
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 600
+r0:=2^(2+5*x)*5^(1+5*x)/log(10)
+--R 
+--R
+--R         5x + 2 5x + 1
+--R        2      5
+--R   (2)  --------------
+--R            log(10)
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                (5x + 2)log(10)
+--R       log(10)%e
+--R     + 
+--R                              (5x + 2)log(2)  (5x + 1)log(5)
+--R       (- 5log(5) - 5log(2))%e              %e
+--R  /
+--R     log(10)
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^(11/2)
+--R 
+--R
+--R   (1)
+--R     5 5       4 4      2 3 3      3 2 2     4       5  b c x + a c +-------+
+--R   (e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d )F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)^(13/2)*GAMMA(13/2,-b*c*(d+e*x)*log(F)/e)/_
+--  (e*(-b*c*(d+e*x)*log(F)/e)^(13/2))
+--E 110
+
+--S 111 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 111
+
+)clear all
+
+--S 112 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^(9/2)
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b c x + a c +-------+
+--R   (1)  (e x  + 4d e x  + 6d e x  + 4d e x + d )F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 600
+--r0:=-F^(c*(a-b*d/e))*(d+e*x)^(11/2)*GAMMA(11/2,-b*c*(d+e*x)*log(F)/e)/_
+--  (e*(-b*c*(d+e*x)*log(F)/e)^(11/2))
+--E 113
+
+--S 114 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 114
+
+)clear all
+
+--S 115 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^(7/2)
+--R 
+--R
+--R          3 3       2 2     2       3  b c x + a c +-------+
+--R   (1)  (e x  + 3d e x  + 3d e x + d )F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 600
+--r0:=35/4*e^2*F^(c*(a+b*x))*(d+e*x)^(3/2)/(b^3*c^3*log(F)^3)-_
+--   7/2*e*F^(c*(a+b*x))*(d+e*x)^(5/2)/(b^2*c^2*log(F)^2)+F^(c*(a+b*x))*_
+--   (d+e*x)^(7/2)/(b*c*log(F))+105/16*e^(7/2)*F^(c*(a-b*d/e))*_
+--   erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/sqrt(e))*sqrt(%pi)/_
+--   (b^(9/2)*c^(9/2)*log(F)^(9/2))-105/8*e^3*F^(c*(a+b*x))*_
+--   sqrt(d+e*x)/(b^4*c^4*log(F)^4)
+--E 116
+
+--S 117 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 117
+
+)clear all
+
+--S 118 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^(5/2)
+--R 
+--R
+--R          2 2             2  b c x + a c +-------+
+--R   (1)  (e x  + 2d e x + d )F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 600
+--r0:=-5/2*e*F^(c*(a+b*x))*(d+e*x)^(3/2)/(b^2*c^2*log(F)^2)+F^(c*(a+b*x))*_
+--  (d+e*x)^(5/2)/(b*c*log(F))-15/8*e^(5/2)*F^(c*(a-b*d/e))*_
+--  erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/sqrt(e))*_
+--  sqrt(%pi)/(b^(7/2)*c^(7/2)*log(F)^(7/2))+15/4*e^2*F^(c*(a+b*x))*_
+--  sqrt(d+e*x)/(b^3*c^3*log(F)^3)
+--E 119
+
+--S 120 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 120
+
+)clear all
+
+--S 121 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^(3/2)
+--R 
+--R
+--R                  b c x + a c +-------+
+--R   (1)  (e x + d)F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 600
+--r0:=F^(c*(a+b*x))*(d+e*x)^(3/2)/(b*c*log(F))+3/4*e^(3/2)*_
+--  F^(c*(a-b*d/e))*erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/_
+--  sqrt(e))*sqrt(%pi)/(b^(5/2)*c^(5/2)*log(F)^(5/2))-3/2*e*F^(c*_
+--  (a+b*x))*sqrt(d+e*x)/(b^2*c^2*log(F)^2)
+--E 122
+
+--S 123 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 123
+
+)clear all
+
+--S 124 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)^(1/2)
+--R 
+--R
+--R         b c x + a c +-------+
+--R   (1)  F           \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 600
+--r0:=-1/2*F^(c*(a-b*d/e))*erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/_
+--  sqrt(e))*sqrt(%pi)*sqrt(e)/(b^(3/2)*c^(3/2)*log(F)^(3/2))+_
+--  F^(c*(a+b*x))*sqrt(d+e*x)/(b*c*log(F))
+--E 125
+
+--S 126 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 126
+
+)clear all
+
+--S 127 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^(1/2)
+--R 
+--R
+--R         b c x + a c
+--R        F
+--R   (1)  ------------
+--R          +-------+
+--R         \|e x + d
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 600
+--r0:=F^(c*(a-b*d/e))*erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/_
+--  sqrt(e))*sqrt(%pi)/(sqrt(b)*sqrt(c)*sqrt(e)*sqrt(log(F)))
+--E 128
+
+--S 129 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 129
+
+)clear all
+
+--S 130 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^(3/2)
+--R 
+--R
+--R             b c x + a c
+--R            F
+--R   (1)  -------------------
+--R                  +-------+
+--R        (e x + d)\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 600
+--r0:=-2*F^(c*(a+b*x))/(e*sqrt(d+e*x))+2*F^(c*(a-b*d/e))*erfi(sqrt(b)*_
+--  sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/sqrt(e))*sqrt(%pi)*sqrt(b)*_
+--  sqrt(c)*sqrt(log(F))/e^(3/2)
+--E 131
+
+--S 132 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 132
+
+)clear all
+
+--S 133 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^(5/2)
+--R 
+--R
+--R                  b c x + a c
+--R                 F
+--R   (1)  ------------------------------
+--R          2 2             2  +-------+
+--R        (e x  + 2d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 600
+--r0:=-2/3*F^(c*(a+b*x))/(e*(d+e*x)^(3/2))+4/3*b^(3/2)*c^(3/2)*_
+--  F^(c*(a-b*d/e))*erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/_
+--  sqrt(e))*log(F)^(3/2)*sqrt(%pi)/e^(5/2)-4/3*b*c*F^(c*(a+b*x))*_
+--  log(F)/(e^2*sqrt(d+e*x))
+--E 134
+
+--S 135 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 135
+
+)clear all
+
+--S 136 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^(7/2)
+--R 
+--R
+--R                       b c x + a c
+--R                      F
+--R   (1)  ----------------------------------------
+--R          3 3       2 2     2       3  +-------+
+--R        (e x  + 3d e x  + 3d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 600
+--r0:=-2/5*F^(c*(a+b*x))/(e*(d+e*x)^(5/2))-4/15*b*c*F^(c*(a+b*x))*_
+--  log(F)/(e^2*(d+e*x)^(3/2))+8/15*b^(5/2)*c^(5/2)*F^(c*(a-b*d/e))*_
+--  erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/sqrt(e))*log(F)^(5/2)*_
+--  sqrt(%pi)/e^(7/2)-8/15*b^2*c^2*F^(c*(a+b*x))*log(F)^2/(e^3*sqrt(d+e*x))
+--E 137
+
+--S 138 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 138
+
+)clear all
+
+--S 139 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^(9/2)
+--R 
+--R
+--R                            b c x + a c
+--R                           F
+--R   (1)  --------------------------------------------------
+--R          4 4       3 3     2 2 2     3       4  +-------+
+--R        (e x  + 4d e x  + 6d e x  + 4d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 600
+--r0:=-2/7*F^(c*(a+b*x))/(e*(d+e*x)^(7/2))-4/35*b*c*F^(c*(a+b*x))*_
+--  log(F)/(e^2*(d+e*x)^(5/2))-8/105*b^2*c^2*F^(c*(a+b*x))*_
+--  log(F)^2/(e^3*(d+e*x)^(3/2))+16/105*b^(7/2)*c^(7/2)*F^(c*(a-b*d/e))*_
+--  erfi(sqrt(b)*sqrt(c)*sqrt(d+e*x)*sqrt(log(F))/sqrt(e))*log(F)^(7/2)*_
+--  sqrt(%pi)/e^(9/2)-16/105*b^3*c^3*F^(c*(a+b*x))*log(F)^3/(e^4*sqrt(d+e*x))
+--E 140
+
+--S 141 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 141
+
+)clear all
+
+--S 142 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^(11/2)
+--R 
+--R
+--R                                  b c x + a c
+--R                                 F
+--R   (1)  --------------------------------------------------------------
+--R          5 5       4 4      2 3 3      3 2 2     4       5  +-------+
+--R        (e x  + 5d e x  + 10d e x  + 10d e x  + 5d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 600
+--r0:=-F^(c*(a-b*d/e))*GAMMA(-9/2,-b*c*(d+e*x)*log(F)/e)*(-b*c*(d+e*x)*_
+--  log(F)/e)^(9/2)/(e*(d+e*x)^(9/2))
+--E 143
+
+--S 144 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 144
+
+)clear all
+
+--S 145 of 600
+t0:=F^(c*(a+b*x))/(d+e*x)^(13/2)
+--R 
+--R
+--R   (1)
+--R                                   b c x + a c
+--R                                  F
+--R   -------------------------------------------------------------------------
+--R     6 6       5 5      2 4 4      3 3 3      4 2 2     5       6  +-------+
+--R   (e x  + 6d e x  + 15d e x  + 20d e x  + 15d e x  + 6d e x + d )\|e x + d
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 600
+--r0:=-F^(c*(a-b*d/e))*GAMMA(-11/2,-b*c*(d+e*x)*log(F)/e)*(-b*c*(d+e*x)*_
+--  log(F)/e)^(11/2)/(e*(d+e*x)^(11/2))
+--E 146
+
+--S 147 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 147
+
+)clear all
+
+--S 148 of 600
+t0:=x^(13/2)/%e^(b*x)
+--R 
+--R
+--R         6 +-+
+--R        x \|x
+--R   (1)  ------
+--R           b x
+--R         %e
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 600
+--r0:=-x^(13/2)*GAMMA(15/2,b*x)/(b*(b*x)^(13/2))
+--E 149
+
+--S 150 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 150
+
+)clear all
+
+--S 151 of 600
+t0:=F^(c*(a+b*x))*(d+e*x)
+--R 
+--R
+--R                  b c x + a c
+--R   (1)  (e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 600
+r0:=-e*F^(c*(a+b*x))/(b^2*c^2*log(F)^2)+F^(c*(a+b*x))*(d+e*x)/(b*c*log(F))
+--R 
+--R
+--R                                      b c x + a c
+--R        ((b c e x + b c d)log(F) - e)F
+--R   (2)  -----------------------------------------
+--R                        2 2      2
+--R                       b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 600
+t0:=F^(c*(a+b*x))*(d+e*x+f*x^2)
+--R 
+--R
+--R            2            b c x + a c
+--R   (1)  (f x  + e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 600
+r0:=2*f*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)-e*F^(c*(a+b*x))/(b^2*c^2*log(F)^2)-_
+   2*f*F^(c*(a+b*x))*x/(b^2*c^2*log(F)^2)+d*F^(c*(a+b*x))/(b*c*log(F))+_
+   e*F^(c*(a+b*x))*x/(b*c*log(F))+f*F^(c*(a+b*x))*x^2/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R          2 2   2    2 2       2 2        2
+--R       ((b c f x  + b c e x + b c d)log(F)  + (- 2b c f x - b c e)log(F) + 2f)
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      3 3      3
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 600
+t0:=F^(c*(a+b*x))*(d+e*x+f*x^2+g*x^3)
+--R 
+--R
+--R            3      2            b c x + a c
+--R   (1)  (g x  + f x  + e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 600
+r0:=-6*F^(c*(a+b*x))*g/(b^4*c^4*log(F)^4)+2*f*F^(c*(a+b*x))/(b^3*c^3*_
+   log(F)^3)+6*F^(c*(a+b*x))*g*x/(b^3*c^3*log(F)^3)-e*F^(c*(a+b*x))/_
+   (b^2*c^2*log(F)^2)-2*f*F^(c*(a+b*x))*x/(b^2*c^2*log(F)^2)-3*F^(c*_
+   (a+b*x))*g*x^2/(b^2*c^2*log(F)^2)+d*F^(c*(a+b*x))/(b*c*log(F))+_
+   e*F^(c*(a+b*x))*x/(b*c*log(F))+f*F^(c*(a+b*x))*x^2/(b*c*log(F))+_
+   F^(c*(a+b*x))*g*x^3/(b*c*log(F))
+--R 
+--R
+--R   (2)
+--R           3 3   3    3 3   2    3 3       3 3        3
+--R         (b c g x  + b c f x  + b c e x + b c d)log(F)
+--R       + 
+--R            2 2   2     2 2       2 2        2
+--R       (- 3b c g x  - 2b c f x - b c e)log(F)  + (6b c g x + 2b c f)log(F) - 6g
+--R    *
+--R        b c x + a c
+--R       F
+--R  /
+--R      4 4      4
+--R     b c log(F)
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 600
+t0:=F^(c*(a+b*x))*(d+e*x+f*x^2+g*x^3+h*x^4)
+--R 
+--R
+--R            4      3      2            b c x + a c
+--R   (1)  (h x  + g x  + f x  + e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 600
+--r0:=F^(a*c)*h*GAMMA(5,-b*c*x*log(F))/(b^5*c^5*log(F)^5)-6*F^(c*(a+b*x))*_
+--  g/(b^4*c^4*log(F)^4)+2*f*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)+_
+--  6*F^(c*(a+b*x))*g*x/(b^3*c^3*log(F)^3)-e*F^(c*(a+b*x))/(b^2*c^2*_
+--  log(F)^2)-2*f*F^(c*(a+b*x))*x/(b^2*c^2*log(F)^2)-3*F^(c*(a+b*x))*_
+--  g*x^2/(b^2*c^2*log(F)^2)+d*F^(c*(a+b*x))/(b*c*log(F))+e*F^(c*(a+b*x))*_
+--  x/(b*c*log(F))+f*F^(c*(a+b*x))*x^2/(b*c*log(F))+F^(c*(a+b*x))*_
+--  g*x^3/(b*c*log(F))
+--E 161
+
+--S 162 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 162
+
+)clear all
+
+--S 163 of 600
+t0:=F^(c*(a+b*x))*(d+e*x+f*x^2+g*x^3+h*x^4+j*x^5)
+--R 
+--R
+--R            5      4      3      2            b c x + a c
+--R   (1)  (j x  + h x  + g x  + f x  + e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 600
+--r0:=-F^(a*c)*j*GAMMA(6,-b*c*x*log(F))/(b^6*c^6*log(F)^6)+F^(a*c)*h*_
+--  GAMMA(5,-b*c*x*log(F))/(b^5*c^5*log(F)^5)-6*F^(c*(a+b*x))*g/_
+--  (b^4*c^4*log(F)^4)+2*f*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)+_
+--  6*F^(c*(a+b*x))*g*x/(b^3*c^3*log(F)^3)-e*F^(c*(a+b*x))/_
+--  (b^2*c^2*log(F)^2)-2*f*F^(c*(a+b*x))*x/(b^2*c^2*log(F)^2)-_
+--  3*F^(c*(a+b*x))*g*x^2/(b^2*c^2*log(F)^2)+d*F^(c*(a+b*x))/_
+--  (b*c*log(F))+e*F^(c*(a+b*x))*x/(b*c*log(F))+f*F^(c*(a+b*x))*_
+--  x^2/(b*c*log(F))+F^(c*(a+b*x))*g*x^3/(b*c*log(F))
+--E 164
+
+--S 165 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 165
+
+)clear all
+
+--S 166 of 600
+t0:=F^(c*(a+b*x))*(d+e*x+f*x^2+g*x^3+h*x^4+j*x^5+k*x^6)
+--R 
+--R
+--R            6      5      4      3      2            b c x + a c
+--R   (1)  (k x  + j x  + h x  + g x  + f x  + e x + d)F
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 600
+--r0:=F^(a*c)*k*GAMMA(7,-b*c*x*log(F))/(b^7*c^7*log(F)^7)-F^(a*c)*j*_
+--  GAMMA(6,-b*c*x*log(F))/(b^6*c^6*log(F)^6)+F^(a*c)*h*_
+--  GAMMA(5,-b*c*x*log(F))/(b^5*c^5*log(F)^5)-6*F^(c*(a+b*x))*_
+--  g/(b^4*c^4*log(F)^4)+2*f*F^(c*(a+b*x))/(b^3*c^3*log(F)^3)+_
+--  6*F^(c*(a+b*x))*g*x/(b^3*c^3*log(F)^3)-e*F^(c*(a+b*x))/_
+--  (b^2*c^2*log(F)^2)-2*f*F^(c*(a+b*x))*x/(b^2*c^2*log(F)^2)-_
+--  3*F^(c*(a+b*x))*g*x^2/(b^2*c^2*log(F)^2)+d*F^(c*(a+b*x))/_
+--  (b*c*log(F))+e*F^(c*(a+b*x))*x/(b*c*log(F))+f*F^(c*(a+b*x))*_
+--  x^2/(b*c*log(F))+F^(c*(a+b*x))*g*x^3/(b*c*log(F))
+--E 167
+
+--S 168 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 168
+
+)clear all
+
+--S 169 of 600
+t0:=%e^(-a-b*x)*x^m*(a+b*x)^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a m
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x + a )%e         x
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 600
+--r0:=-a^4*x^m*GAMMA(1+m,b*x)/(%e^a*b*(b*x)^m)-4*a^3*x^(1+m)*(b*x)^(-1-m)*_
+--  GAMMA(2+m,b*x)/%e^a-6*a^2*b*x^(2+m)*(b*x)^(-2-m)*GAMMA(3+m,b*x)/%e^a-_
+--  4*a*b^2*x^(3+m)*(b*x)^(-3-m)*GAMMA(4+m,b*x)/%e^a-b^3*x^(4+m)*_
+--  (b*x)^(-4-m)*GAMMA(5+m,b*x)/%e^a
+--E 170
+
+--S 171 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 171
+
+)clear all
+
+--S 172 of 600
+t0:=%e^(-a-b*x)*x^7*(a+b*x)^4
+--R 
+--R
+--R          4 11       3 10     2 2 9     3   8    4 7   - b x - a
+--R   (1)  (b x   + 4a b x   + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 600
+--r0:=-a^4*GAMMA(8,b*x)/(%e^a*b^8)-4*a^3*GAMMA(9,b*x)/(%e^a*b^8)-_
+--  6*a^2*GAMMA(10,b*x)/(%e^a*b^8)-4*a*GAMMA(11,b*x)/(%e^a*b^8)-_
+--  GAMMA(12,b*x)/(%e^a*b^8)
+--E 173
+
+--S 174 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 174
+
+)clear all
+
+--S 175 of 600
+t0:=%e^(-a-b*x)*x^6*(a+b*x)^4
+--R 
+--R
+--R          4 10       3 9     2 2 8     3   7    4 6   - b x - a
+--R   (1)  (b x   + 4a b x  + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 600
+--r0:=-a^4*GAMMA(7,b*x)/(%e^a*b^7)-4*a^3*GAMMA(8,b*x)/(%e^a*b^7)-_
+--  6*a^2*GAMMA(9,b*x)/(%e^a*b^7)-4*a*GAMMA(10,b*x)/(%e^a*b^7)-_
+--  GAMMA(11,b*x)/(%e^a*b^7)
+--E 176
+
+--S 177 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 177
+
+)clear all
+
+--S 178 of 600
+t0:=%e^(-a-b*x)*x^5*(a+b*x)^4
+--R 
+--R
+--R          4 9       3 8     2 2 7     3   6    4 5   - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 600
+--r0:=-a^4*GAMMA(6,b*x)/(%e^a*b^6)-4*a^3*GAMMA(7,b*x)/(%e^a*b^6)-_
+--  6*a^2*GAMMA(8,b*x)/(%e^a*b^6)-4*a*GAMMA(9,b*x)/(%e^a*b^6)-_
+--  GAMMA(10,b*x)/(%e^a*b^6)
+--E 179
+
+--S 180 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 180
+
+)clear all
+
+--S 181 of 600
+t0:=%e^(-a-b*x)*x^4*(a+b*x)^4
+--R 
+--R
+--R          4 8       3 7     2 2 6     3   5    4 4   - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 600
+--r0:=-a^4*GAMMA(5,a+b*x)/b^5+4*a^3*GAMMA(6,a+b*x)/b^5-_
+--  6*a^2*GAMMA(7,a+b*x)/b^5+4*a*GAMMA(8,a+b*x)/b^5-GAMMA(9,a+b*x)/b^5
+--E 182
+
+--S 183 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 183
+
+)clear all
+
+--S 184 of 600
+t0:=%e^(-a-b*x)*x^3*(a+b*x)^4
+--R 
+--R
+--R          4 7       3 6     2 2 5     3   4    4 3   - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 600
+--r0:=a^3*GAMMA(5,a+b*x)/b^4-3*a^2*GAMMA(6,a+b*x)/b^4+_
+--  3*a*GAMMA(7,a+b*x)/b^4-GAMMA(8,a+b*x)/b^4
+--E 185
+
+--S 186 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 186
+
+)clear all
+
+--S 187 of 600
+t0:=%e^(-a-b*x)*x^2*(a+b*x)^4
+--R 
+--R
+--R          4 6       3 5     2 2 4     3   3    4 2   - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x )%e
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 600
+--r0:=-a^2*GAMMA(5,a+b*x)/b^3+2*a*GAMMA(6,a+b*x)/b^3-GAMMA(7,a+b*x)/b^3
+--E 188
+
+--S 189 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 189
+
+)clear all
+
+--S 190 of 600
+t0:=%e^(-a-b*x)*x*(a+b*x)^4
+--R 
+--R
+--R          4 5       3 4     2 2 3     3   2    4    - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x  + a x)%e
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 600
+--r0:=a*GAMMA(5,a+b*x)/b^2-GAMMA(6,a+b*x)/b^2
+--E 191
+
+--S 192 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 192
+
+)clear all
+
+--S 193 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R   (1)  (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 600
+--r0:=-GAMMA(5,a+b*x)/b
+--E 194
+
+--S 195 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 195
+
+)clear all
+
+--S 196 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^4/x
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 600
+r0:=-6*%e^(-a-b*x)-2*%e^(-a-b*x)*a-%e^(-a-b*x)*a^2-%e^(-a-b*x)*a^3-_
+   6*%e^(-a-b*x)*(a+b*x)-2*%e^(-a-b*x)*a*(a+b*x)-%e^(-a-b*x)*a^2*(a+b*x)-_
+   3*%e^(-a-b*x)*(a+b*x)^2-%e^(-a-b*x)*a*(a+b*x)^2-%e^(-a-b*x)*(a+b*x)^3+_
+   a^4*Ei(-b*x)/%e^a
+--R 
+--R
+--R   (2)
+--R             3 3              2 2        2                  3     2
+--R         (- b x  + (- 4a - 3)b x  + (- 6a  - 8a - 6)b x - 4a  - 6a  - 8a - 6)
+--R      *
+--R           - b x - a  a
+--R         %e         %e
+--R     + 
+--R        4
+--R       a Ei(- b x)
+--R  /
+--R       a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^2
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  2
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 600
+r0:=-2*%e^(-a-b*x)*b-4*%e^(-a-b*x)*a*b-6*%e^(-a-b*x)*a^2*b-%e^(-a-b*x)*a^4/x-_
+   2*%e^(-a-b*x)*b^2*x-4*%e^(-a-b*x)*a*b^2*x-%e^(-a-b*x)*b^3*x^2+_
+   4*a^3*b*Ei(-b*x)/%e^a-a^4*b*Ei(-b*x)/%e^a
+--R 
+--R
+--R   (2)
+--R           3 3              2 2        2                 4   - b x - a  a
+--R       (- b x  + (- 4a - 2)b x  + (- 6a  - 4a - 2)b x - a )%e         %e
+--R     + 
+--R           4     3
+--R       (- a  + 4a )b x Ei(- b x)
+--R  /
+--R         a
+--R     x %e
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^3
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  3
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 600
+r0:=-%e^(-a-b*x)*b^2-4*%e^(-a-b*x)*a*b^2-1/2*%e^(-a-b*x)*a^4/x^2-_
+   4*%e^(-a-b*x)*a^3*b/x+1/2*%e^(-a-b*x)*a^4*b/x-%e^(-a-b*x)*b^3*x+_
+   6*a^2*b^2*Ei(-b*x)/%e^a-4*a^3*b^2*Ei(-b*x)/%e^a+1/2*a^4*b^2*Ei(-b*x)/%e^a
+--R 
+--R
+--R   (2)
+--R            3 3              2 2     4     3        4   - b x - a  a
+--R       (- 2b x  + (- 8a - 2)b x  + (a  - 8a )b x - a )%e         %e
+--R     + 
+--R         4     3      2  2 2
+--R       (a  - 8a  + 12a )b x Ei(- b x)
+--R  /
+--R       2  a
+--R     2x %e
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  4
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 600
+r0:=-%e^(-a-b*x)*b^3-1/3*%e^(-a-b*x)*a^4/x^3-2*%e^(-a-b*x)*a^3*b/x^2+_
+   1/6*%e^(-a-b*x)*a^4*b/x^2-6*%e^(-a-b*x)*a^2*b^2/x+2*%e^(-a-b*x)*a^3*b^2/x-_
+   1/6*%e^(-a-b*x)*a^4*b^2/x+4*a*b^3*Ei(-b*x)/%e^a-6*a^2*b^3*Ei(-b*x)/%e^a+_
+   2*a^3*b^3*Ei(-b*x)/%e^a-1/6*a^4*b^3*Ei(-b*x)/%e^a
+--R 
+--R
+--R   (2)
+--R            3 3       4      3      2  2 2     4      3         4   - b x - a  a
+--R       (- 6b x  + (- a  + 12a  - 36a )b x  + (a  - 12a )b x - 2a )%e         %e
+--R     + 
+--R           4      3      2        3 3
+--R       (- a  + 12a  - 36a  + 24a)b x Ei(- b x)
+--R  /
+--R       3  a
+--R     6x %e
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^5
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  5
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 600
+--r0:=-4/3*%e^(-a-b*x)*a^3*b/x^3-3*%e^(-a-b*x)*a^2*b^2/x^2+_
+--  2/3*%e^(-a-b*x)*a^3*b^2/x^2-4*%e^(-a-b*x)*a*b^3/x+3*%e^(-a-b*x)*_
+--  a^2*b^3/x-2/3*%e^(-a-b*x)*a^3*b^3/x+b^4*Ei(-b*x)/%e^a-4*a*b^4*_
+--  Ei(-b*x)/%e^a+3*a^2*b^4*Ei(-b*x)/%e^a-2/3*a^3*b^4*Ei(-b*x)/%e^a-_
+--  a^4*b^4*GAMMA(-4,b*x)/%e^a
+--E 209
+
+--S 210 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 210
+
+)clear all
+
+--S 211 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^6
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  6
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 600
+--r0:=-2*%e^(-a-b*x)*a^2*b^2/x^3-2*%e^(-a-b*x)*a*b^3/x^2+%e^(-a-b*x)*_
+--  a^2*b^3/x^2-%e^(-a-b*x)*b^4/x+2*%e^(-a-b*x)*a*b^4/x-%e^(-a-b*x)*_
+--  a^2*b^4/x-b^5*Ei(-b*x)/%e^a+2*a*b^5*Ei(-b*x)/%e^a-a^2*b^5*Ei(-b*x)/%e^a-_
+--  a^4*b^5*GAMMA(-5,b*x)/%e^a-4*a^3*b^5*GAMMA(-4,b*x)/%e^a
+--E 212
+
+--S 213 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 213
+
+)clear all
+
+--S 214 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^7
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  7
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 600
+--r0:=-4/3*%e^(-a-b*x)*a*b^3/x^3-1/2*%e^(-a-b*x)*b^4/x^2+2/3*%e^(-a-b*x)*_
+--  a*b^4/x^2+1/2*%e^(-a-b*x)*b^5/x-2/3*%e^(-a-b*x)*a*b^5/x+1/2*b^6*_
+--  Ei(-b*x)/%e^a-2/3*a*b^6*Ei(-b*x)/%e^a-a^4*b^6*GAMMA(-6,b*x)/%e^a-4*_
+--  a^3*b^6*GAMMA(-5,b*x)/%e^a-6*a^2*b^6*GAMMA(-4,b*x)/%e^a
+--E 215
+
+--S 216 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 216
+
+)clear all
+
+--S 217 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^4/x^8
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4   - b x - a
+--R        (b x  + 4a b x  + 6a b x  + 4a b x + a )%e
+--R   (1)  ---------------------------------------------------
+--R                                  8
+--R                                 x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 600
+--r0:=-1/3*%e^(-a-b*x)*b^4/x^3+1/6*%e^(-a-b*x)*b^5/x^2-1/6*%e^(-a-b*x)*_
+--  b^6/x-1/6*b^7*Ei(-b*x)/%e^a-a^4*b^7*GAMMA(-7,b*x)/%e^a-4*a^3*b^7*_
+--  GAMMA(-6,b*x)/%e^a-6*a^2*b^7*GAMMA(-5,b*x)/%e^a-4*a*b^7*GAMMA(-4,b*x)/%e^a
+--E 218
+
+--S 219 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 219
+
+)clear all
+
+--S 220 of 600
+t0:=F^(a+b*(c+d*x))*x^m*(e+f*x)^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a m
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x + e )F               x
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 600
+--r0:=-f^4*F^(a+b*c)*x^(5+m)*GAMMA(5+m,-b*d*x*log(F))*(-b*d*x*_
+--  log(F))^(-5-m)-4*e*f^3*F^(a+b*c)*x^(4+m)*GAMMA(4+m,-b*d*x*log(F))*_
+--  (-b*d*x*log(F))^(-4-m)-6*e^2*f^2*F^(a+b*c)*x^(3+m)*GAMMA(3+m,-b*d*x*_
+--  log(F))*(-b*d*x*log(F))^(-3-m)-4*e^3*f*F^(a+b*c)*x^(2+m)*GAMMA(2+m,_
+--  -b*d*x*log(F))*(-b*d*x*log(F))^(-2-m)-e^4*F^(a+b*c)*x^(1+m)*_
+--  GAMMA(1+m,-b*d*x*log(F))*(-b*d*x*log(F))^(-1-m)
+--E 221
+
+--S 222 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 222
+
+)clear all
+
+--S 223 of 600
+t0:=F^(a+b*(c+d*x))*x^7*(e+f*x)^4
+--R 
+--R
+--R          4 11       3 10     2 2 9     3   8    4 7  b d x + b c + a
+--R   (1)  (f x   + 4e f x   + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 600
+--r0:=-f^4*F^(a+b*c)*GAMMA(12,-b*d*x*log(F))/(b^12*d^12*log(F)^12)+_
+--  4*e*f^3*F^(a+b*c)*GAMMA(11,-b*d*x*log(F))/(b^11*d^11*log(F)^11)-_
+--  6*e^2*f^2*F^(a+b*c)*GAMMA(10,-b*d*x*log(F))/(b^10*d^10*log(F)^10)+_
+--  4*e^3*f*F^(a+b*c)*GAMMA(9,-b*d*x*log(F))/(b^9*d^9*log(F)^9)-_
+--  e^4*F^(a+b*c)*GAMMA(8,-b*d*x*log(F))/(b^8*d^8*log(F)^8)
+--E 224
+
+--S 225 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 225
+
+)clear all
+
+--S 226 of 600
+t0:=F^(a+b*(c+d*x))*x^6*(e+f*x)^4
+--R 
+--R
+--R          4 10       3 9     2 2 8     3   7    4 6  b d x + b c + a
+--R   (1)  (f x   + 4e f x  + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 600
+--r0:=f^4*F^(a+b*c)*GAMMA(11,-b*d*x*log(F))/(b^11*d^11*log(F)^11)-_
+--  4*e*f^3*F^(a+b*c)*GAMMA(10,-b*d*x*log(F))/(b^10*d^10*log(F)^10)+_
+--  6*e^2*f^2*F^(a+b*c)*GAMMA(9,-b*d*x*log(F))/(b^9*d^9*log(F)^9)-_
+--  4*e^3*f*F^(a+b*c)*GAMMA(8,-b*d*x*log(F))/(b^8*d^8*log(F)^8)+_
+--  e^4*F^(a+b*c)*GAMMA(7,-b*d*x*log(F))/(b^7*d^7*log(F)^7)
+--E 227
+
+--S 228 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 228
+
+)clear all
+
+--S 229 of 600
+t0:=F^(a+b*(c+d*x))*x^5*(e+f*x)^4
+--R 
+--R
+--R          4 9       3 8     2 2 7     3   6    4 5  b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 600
+--r0:=-f^4*F^(a+b*c)*GAMMA(10,-b*d*x*log(F))/(b^10*d^10*log(F)^10)+_
+--  4*e*f^3*F^(a+b*c)*GAMMA(9,-b*d*x*log(F))/(b^9*d^9*log(F)^9)-_
+--  6*e^2*f^2*F^(a+b*c)*GAMMA(8,-b*d*x*log(F))/(b^8*d^8*log(F)^8)+_
+--  4*e^3*f*F^(a+b*c)*GAMMA(7,-b*d*x*log(F))/(b^7*d^7*log(F)^7)-_
+--  e^4*F^(a+b*c)*GAMMA(6,-b*d*x*log(F))/(b^6*d^6*log(F)^6)
+--E 230
+
+--S 231 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 231
+
+)clear all
+
+--S 232 of 600
+t0:=F^(a+b*(c+d*x))*x^4*(e+f*x)^4
+--R 
+--R
+--R          4 8       3 7     2 2 6     3   5    4 4  b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 600
+--r0:=f^4*F^(a+b*c-b*d*e/f)*GAMMA(9,-b*d*(e+f*x)*log(F)/f)/(b^9*d^9*_
+--  log(F)^9)+4*e*f^3*F^(a+b*c-b*d*e/f)*GAMMA(8,-b*d*(e+f*x)*log(F)/f)/_
+--  (b^8*d^8*log(F)^8)+6*e^2*f^2*F^(a+b*c-b*d*e/f)*GAMMA(7,-b*d*(e+f*x)*_
+--  log(F)/f)/(b^7*d^7*log(F)^7)+4*e^3*f*F^(a+b*c-b*d*e/f)*GAMMA(6,_
+--  -b*d*(e+f*x)*log(F)/f)/(b^6*d^6*log(F)^6)+e^4*F^(a+b*c-b*d*e/f)*_
+--  GAMMA(5,-b*d*(e+f*x)*log(F)/f)/(b^5*d^5*log(F)^5)
+--E 233
+
+--S 234 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 234
+
+)clear all
+
+--S 235 of 600
+t0:=F^(a+b*(c+d*x))*x^3*(e+f*x)^4
+--R 
+--R
+--R          4 7       3 6     2 2 5     3   4    4 3  b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 600
+--r0:=-f^4*F^(a+b*c-b*d*e/f)*GAMMA(8,-b*d*(e+f*x)*log(F)/f)/(b^8*d^8*_
+--  log(F)^8)-3*e*f^3*F^(a+b*c-b*d*e/f)*GAMMA(7,-b*d*(e+f*x)*log(F)/f)/_
+--  (b^7*d^7*log(F)^7)-3*e^2*f^2*F^(a+b*c-b*d*e/f)*GAMMA(6,-b*d*(e+f*x)*_
+--  log(F)/f)/(b^6*d^6*log(F)^6)-e^3*f*F^(a+b*c-b*d*e/f)*GAMMA(5,_
+--  -b*d*(e+f*x)*log(F)/f)/(b^5*d^5*log(F)^5)
+--E 236
+
+--S 237 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 237
+
+)clear all
+
+--S 238 of 600
+t0:=F^(a+b*(c+d*x))*x^2*(e+f*x)^4
+--R 
+--R
+--R          4 6       3 5     2 2 4     3   3    4 2  b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x  + e x )F
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 600
+--r0:=f^4*F^(a+b*c-b*d*e/f)*GAMMA(7,-b*d*(e+f*x)*log(F)/f)/(b^7*d^7*_
+--  log(F)^7)+2*e*f^3*F^(a+b*c-b*d*e/f)*GAMMA(6,-b*d*(e+f*x)*log(F)/f)/_
+--  (b^6*d^6*log(F)^6)+e^2*f^2*F^(a+b*c-b*d*e/f)*GAMMA(5,-b*d*(e+f*x)*_
+--  log(F)/f)/(b^5*d^5*log(F)^5)
+--E 239
+
+--S 240 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 240
+
+)clear all
+
+--S 241 of 600
+t0:=F^(a+b*(c+d*x))*x*(e+f*x)^4
+--R 
+--R
+--R          4 5       3 4     2 2 3     3   2    4   b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x  + e x)F
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 600
+--r0:=-f^4*F^(a+b*c-b*d*e/f)*GAMMA(6,-b*d*(e+f*x)*log(F)/f)/(b^6*d^6*_
+--  log(F)^6)-e*f^3*F^(a+b*c-b*d*e/f)*GAMMA(5,-b*d*(e+f*x)*log(F)/f)/_
+--  (b^5*d^5*log(F)^5)
+--E 242
+
+--S 243 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 243
+
+)clear all
+
+--S 244 of 600
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R   (1)  (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 600
+--r0:=f^4*F^(a+b*c-b*d*e/f)*GAMMA(5,-b*d*(e+f*x)*log(F)/f)/(b^5*d^5*log(F)^5)
+--E 245
+
+--S 246 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 246
+
+)clear all
+
+--S 247 of 600
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 600
+r0:=e^4*F^(a+b*c)*Ei(b*d*x*log(F))-6*f^4*F^(a+b*c+b*d*x)/(b^4*d^4*log(F)^4)+_
+   8*e*f^3*F^(a+b*c+b*d*x)/(b^3*d^3*log(F)^3)+6*f^4*F^(a+b*c+b*d*x)*x/_
+   (b^3*d^3*log(F)^3)-6*e^2*f^2*F^(a+b*c+b*d*x)/(b^2*d^2*log(F)^2)-_
+   8*e*f^3*F^(a+b*c+b*d*x)*x/(b^2*d^2*log(F)^2)-3*f^4*F^(a+b*c+b*d*x)*_
+   x^2/(b^2*d^2*log(F)^2)+4*e^3*f*F^(a+b*c+b*d*x)/(b*d*log(F))+_
+   6*e^2*f^2*F^(a+b*c+b*d*x)*x/(b*d*log(F))+4*e*f^3*F^(a+b*c+b*d*x)*_
+   x^2/(b*d*log(F))+f^4*F^(a+b*c+b*d*x)*x^3/(b*d*log(F))
+--R 
+--R
+--R   (2)
+--R        4 4 4      4 b c + a
+--R       b d e log(F) F       Ei(b d x log(F))
+--R     + 
+--R             3 3 4 3     3 3   3 2     3 3 2 2      3 3 3        3
+--R           (b d f x  + 4b d e f x  + 6b d e f x + 4b d e f)log(F)
+--R         + 
+--R                2 2 4 2     2 2   3      2 2 2 2       2
+--R           (- 3b d f x  - 8b d e f x - 6b d e f )log(F)
+--R         + 
+--R                  4            3            4
+--R           (6b d f x + 8b d e f )log(F) - 6f
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R      4 4      4
+--R     b d log(F)
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 600
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^2
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    2
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 600
+r0:=-e^4*F^(a+b*c+b*d*x)/x+4*e^3*f*F^(a+b*c)*Ei(b*d*x*log(F))+_
+   2*f^4*F^(a+b*c+b*d*x)/(b^3*d^3*log(F)^3)-4*e*f^3*F^(a+b*c+b*d*x)/_
+   (b^2*d^2*log(F)^2)-2*f^4*F^(a+b*c+b*d*x)*x/(b^2*d^2*log(F)^2)+_
+   6*e^2*f^2*F^(a+b*c+b*d*x)/(b*d*log(F))+4*e*f^3*F^(a+b*c+b*d*x)*x/_
+   (b*d*log(F))+f^4*F^(a+b*c+b*d*x)*x^2/(b*d*log(F))+b*d*e^4*F^(a+b*c)*_
+   Ei(b*d*x*log(F))*log(F)
+--R 
+--R
+--R   (2)
+--R         4 4 4        4     3 3 3          3  b c + a
+--R       (b d e x log(F)  + 4b d e f x log(F) )F       Ei(b d x log(F))
+--R     + 
+--R              3 3 4      3     2 2 4 3     2 2   3 2     2 2 2 2        2
+--R           - b d e log(F)  + (b d f x  + 4b d e f x  + 6b d e f x)log(F)
+--R         + 
+--R                    4 2           3             4
+--R           (- 2b d f x  - 4b d e f x)log(F) + 2f x
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R      3 3        3
+--R     b d x log(F)
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 600
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^3
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    3
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 600
+r0:=-1/2*e^4*F^(a+b*c+b*d*x)/x^2-4*e^3*f*F^(a+b*c+b*d*x)/x+_
+   6*e^2*f^2*F^(a+b*c)*Ei(b*d*x*log(F))-f^4*F^(a+b*c+b*d*x)/(b^2*d^2*_
+   log(F)^2)+4*e*f^3*F^(a+b*c+b*d*x)/(b*d*log(F))+f^4*F^(a+b*c+b*d*x)*_
+   x/(b*d*log(F))-1/2*b*d*e^4*F^(a+b*c+b*d*x)*log(F)/x+4*b*d*e^3*_
+   f*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)+1/2*b^2*d^2*e^4*F^(a+b*c)*_
+   Ei(b*d*x*log(F))*log(F)^2
+--R 
+--R
+--R   (2)
+--R           4 4 4 2      4     3 3 3   2      3      2 2 2 2 2      2  b c + a
+--R         (b d e x log(F)  + 8b d e f x log(F)  + 12b d e f x log(F) )F
+--R      *
+--R         Ei(b d x log(F))
+--R     + 
+--R              3 3 4        3        2 2 3       2 2 4       2
+--R           - b d e x log(F)  + (- 8b d e f x - b d e )log(F)
+--R         + 
+--R                  4 3           3 2            4 2
+--R           (2b d f x  + 8b d e f x )log(F) - 2f x
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R       2 2 2      2
+--R     2b d x log(F)
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 600
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^4
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    4
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 600
+r0:=-1/3*e^4*F^(a+b*c+b*d*x)/x^3-2*e^3*f*F^(a+b*c+b*d*x)/x^2-6*e^2*_
+   f^2*F^(a+b*c+b*d*x)/x+4*e*f^3*F^(a+b*c)*Ei(b*d*x*log(F))+f^4*_
+   F^(a+b*c+b*d*x)/(b*d*log(F))-1/6*b*d*e^4*F^(a+b*c+b*d*x)*log(F)/x^2-_
+   2*b*d*e^3*f*F^(a+b*c+b*d*x)*log(F)/x+6*b*d*e^2*f^2*F^(a+b*c)*_
+   Ei(b*d*x*log(F))*log(F)-1/6*b^2*d^2*e^4*F^(a+b*c+b*d*x)*log(F)^2/x+_
+   2*b^2*d^2*e^3*f*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^2+1/6*b^3*_
+   d^3*e^4*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^3
+--R 
+--R
+--R   (2)
+--R            4 4 4 3      4      3 3 3   3      3      2 2 2 2 3      2
+--R           b d e x log(F)  + 12b d e f x log(F)  + 36b d e f x log(F)
+--R         + 
+--R                    3 3
+--R           24b d e f x log(F)
+--R      *
+--R          b c + a
+--R         F       Ei(b d x log(F))
+--R     + 
+--R              3 3 4 2      3         2 2 3   2    2 2 4        2
+--R           - b d e x log(F)  + (- 12b d e f x  - b d e x)log(F)
+--R         + 
+--R                     2 2 2          3            4            4 3
+--R           (- 36b d e f x  - 12b d e f x - 2b d e )log(F) + 6f x
+--R      *
+--R          b d x + b c + a
+--R         F
+--R  /
+--R           3
+--R     6b d x log(F)
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 600
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^5
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    5
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 600
+--r0:=-4/3*e^3*f*F^(a+b*c+b*d*x)/x^3-3*e^2*f^2*F^(a+b*c+b*d*x)/x^2-_
+--  4*e*f^3*F^(a+b*c+b*d*x)/x+f^4*F^(a+b*c)*Ei(b*d*x*log(F))-2/3*b*d*_
+--  e^3*f*F^(a+b*c+b*d*x)*log(F)/x^2-3*b*d*e^2*f^2*F^(a+b*c+b*d*x)*_
+--  log(F)/x+4*b*d*e*f^3*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)-2/3*b^2*_
+--  d^2*e^3*f*F^(a+b*c+b*d*x)*log(F)^2/x+3*b^2*d^2*e^2*f^2*F^(a+b*c)*_
+--  Ei(b*d*x*log(F))*log(F)^2+2/3*b^3*d^3*e^3*f*F^(a+b*c)*Ei(b*d*x*_
+--  log(F))*log(F)^3-b^4*d^4*e^4*F^(a+b*c)*GAMMA(-4,-b*d*x*log(F))*log(F)^4
+--E 260
+
+--S 261 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 261
+
+)clear all
+
+--S 262 of 600
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^6
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    6
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 600
+--r0:=-2*e^2*f^2*F^(a+b*c+b*d*x)/x^3-2*e*f^3*F^(a+b*c+b*d*x)/x^2-_
+--  f^4*F^(a+b*c+b*d*x)/x-b*d*e^2*f^2*F^(a+b*c+b*d*x)*log(F)/x^2-2*b*d*_
+--  e*f^3*F^(a+b*c+b*d*x)*log(F)/x+b*d*f^4*F^(a+b*c)*Ei(b*d*x*log(F))*_
+--  log(F)-b^2*d^2*e^2*f^2*F^(a+b*c+b*d*x)*log(F)^2/x+2*b^2*d^2*e*f^3*_
+--  F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^2+b^3*d^3*e^2*f^2*F^(a+b*c)*_
+--  Ei(b*d*x*log(F))*log(F)^3-4*b^4*d^4*e^3*f*F^(a+b*c)*GAMMA(-4,_
+--  -b*d*x*log(F))*log(F)^4+b^5*d^5*e^4*F^(a+b*c)*GAMMA(-5,-b*_
+--  d*x*log(F))*log(F)^5
+--E 263
+
+--S 264 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 264
+
+)clear all
+
+--S 265 of 600
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^7
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    7
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 600
+--r0:=-4/3*e*f^3*F^(a+b*c+b*d*x)/x^3-1/2*f^4*F^(a+b*c+b*d*x)/x^2-_
+--  2/3*b*d*e*f^3*F^(a+b*c+b*d*x)*log(F)/x^2-1/2*b*d*f^4*F^(a+b*c+_
+--  b*d*x)*log(F)/x-2/3*b^2*d^2*e*f^3*F^(a+b*c+b*d*x)*log(F)^2/x+_
+--  1/2*b^2*d^2*f^4*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^2+2/3*b^3*d^3*_
+--  e*f^3*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^3-6*b^4*d^4*e^2*f^2*_
+--  F^(a+b*c)*GAMMA(-4,-b*d*x*log(F))*log(F)^4+4*b^5*d^5*e^3*f*_
+--  F^(a+b*c)*GAMMA(-5,-b*d*x*log(F))*log(F)^5-b^6*d^6*e^4*F^(a+b*c)*_
+--  GAMMA(-6,-b*d*x*log(F))*log(F)^6
+--E 266
+
+--S 267 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 267
+
+)clear all
+
+--S 268 of 600
+t0:=F^(a+b*(c+d*x))*(e+f*x)^4/x^8
+--R 
+--R
+--R          4 4       3 3     2 2 2     3       4  b d x + b c + a
+--R        (f x  + 4e f x  + 6e f x  + 4e f x + e )F
+--R   (1)  --------------------------------------------------------
+--R                                    8
+--R                                   x
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 600
+--r0:=-1/3*f^4*F^(a+b*c+b*d*x)/x^3-1/6*b*d*f^4*F^(a+b*c+b*d*x)*_
+--  log(F)/x^2-1/6*b^2*d^2*f^4*F^(a+b*c+b*d*x)*log(F)^2/x+1/6*b^3*_
+--  d^3*f^4*F^(a+b*c)*Ei(b*d*x*log(F))*log(F)^3-4*b^4*d^4*e*f^3*_
+--  F^(a+b*c)*GAMMA(-4,-b*d*x*log(F))*log(F)^4+6*b^5*d^5*e^2*f^2*_
+--  F^(a+b*c)*GAMMA(-5,-b*d*x*log(F))*log(F)^5-4*b^6*d^6*e^3*f*_
+--  F^(a+b*c)*GAMMA(-6,-b*d*x*log(F))*log(F)^6+b^7*d^7*e^4*_
+--  F^(a+b*c)*GAMMA(-7,-b*d*x*log(F))*log(F)^7
+--E 269
+
+--S 270 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 270
+
+)clear all
+
+--S 271 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)^6
+--R 
+--R
+--R   (1)
+--R        6 6 12        5 6     6   5  11       2 4 6        5   5      6 2 4  10
+--R       b d x   + (6a b d  + 6b c d )x   + (15a b d  + 36a b c d  + 15b c d )x
+--R     + 
+--R           3 3 6      2 4   5        5 2 4      6 3 3  9
+--R       (20a b d  + 90a b c d  + 90a b c d  + 20b c d )x
+--R     + 
+--R           4 2 6       3 3   5       2 4 2 4         5 3 3      6 4 2  8
+--R       (15a b d  + 120a b c d  + 225a b c d  + 120a b c d  + 15b c d )x
+--R     + 
+--R               5   6      4 2   5       3 3 2 4       2 4 3 3        5 4 2
+--R             6a b d  + 90a b c d  + 300a b c d  + 300a b c d  + 90a b c d
+--R           + 
+--R               6 5
+--R             6b c d
+--R      *
+--R          7
+--R         x
+--R     + 
+--R            6 6      5     5       4 2 2 4       3 3 3 3       2 4 4 2
+--R           a d  + 36a b c d  + 225a b c d  + 400a b c d  + 225a b c d
+--R         + 
+--R                5 5     6 6
+--R           36a b c d + b c
+--R      *
+--R          6
+--R         x
+--R     + 
+--R               6   5      5   2 4       4 2 3 3       3 3 4 2      2 4 5
+--R             6a c d  + 90a b c d  + 300a b c d  + 300a b c d  + 90a b c d
+--R           + 
+--R                 5 6
+--R             6a b c
+--R      *
+--R          5
+--R         x
+--R     + 
+--R           6 2 4       5   3 3       4 2 4 2       3 3 5       2 4 6  4
+--R       (15a c d  + 120a b c d  + 225a b c d  + 120a b c d + 15a b c )x
+--R     + 
+--R           6 3 3      5   4 2      4 2 5       3 3 6  3
+--R       (20a c d  + 90a b c d  + 90a b c d + 20a b c )x
+--R     + 
+--R           6 4 2      5   5       4 2 6  2      6 5      5   6      6 6
+--R       (15a c d  + 36a b c d + 15a b c )x  + (6a c d + 6a b c )x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 600
+--r0:=-(b*c-a*d)^6*GAMMA(7,a+b*x)/b^7-6*d*(b*c-a*d)^5*GAMMA(8,_
+--  a+b*x)/b^7-15*d^2*(b*c-a*d)^4*GAMMA(9,a+b*x)/b^7-20*d^3*(b*c-_
+--  a*d)^3*GAMMA(10,a+b*x)/b^7-15*d^4*(b*c-a*d)^2*GAMMA(11,a+b*x)/b^7-_
+--  6*d^5*(b*c-a*d)*GAMMA(12,a+b*x)/b^7-d^6*GAMMA(13,a+b*x)/b^7
+--E 272
+
+--S 273 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 273
+
+)clear all
+
+--S 274 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)^5
+--R 
+--R
+--R   (1)
+--R        6 5 11        5 5     6   4  10       2 4 5        5   4      6 2 3  9
+--R       b d x   + (6a b d  + 5b c d )x   + (15a b d  + 30a b c d  + 10b c d )x
+--R     + 
+--R           3 3 5      2 4   4        5 2 3      6 3 2  8
+--R       (20a b d  + 75a b c d  + 60a b c d  + 10b c d )x
+--R     + 
+--R           4 2 5       3 3   4       2 4 2 3        5 3 2     6 4   7
+--R       (15a b d  + 100a b c d  + 150a b c d  + 60a b c d  + 5b c d)x
+--R     + 
+--R          5   5      4 2   4       3 3 2 3       2 4 3 2        5 4     6 5  6
+--R       (6a b d  + 75a b c d  + 200a b c d  + 150a b c d  + 30a b c d + b c )x
+--R     + 
+--R         6 5      5     4       4 2 2 3       3 3 3 2      2 4 4        5 5  5
+--R       (a d  + 30a b c d  + 150a b c d  + 200a b c d  + 75a b c d + 6a b c )x
+--R     + 
+--R          6   4      5   2 3       4 2 3 2       3 3 4       2 4 5  4
+--R       (5a c d  + 60a b c d  + 150a b c d  + 100a b c d + 15a b c )x
+--R     + 
+--R           6 2 3      5   3 2      4 2 4       3 3 5  3
+--R       (10a c d  + 60a b c d  + 75a b c d + 20a b c )x
+--R     + 
+--R           6 3 2      5   4       4 2 5  2      6 4      5   5      6 5
+--R       (10a c d  + 30a b c d + 15a b c )x  + (5a c d + 6a b c )x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 600
+--r0:=-(b*c-a*d)^5*GAMMA(7,a+b*x)/b^6-5*d*(b*c-a*d)^4*GAMMA(8,a+b*x)/b^6-_
+--  10*d^2*(b*c-a*d)^3*GAMMA(9,a+b*x)/b^6-10*d^3*(b*c-a*d)^2*_
+--  GAMMA(10,a+b*x)/b^6-5*d^4*(b*c-a*d)*GAMMA(11,a+b*x)/b^6-d^5*_
+--  GAMMA(12,a+b*x)/b^6
+--E 275
+
+--S 276 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 276
+
+)clear all
+
+--S 277 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)^4
+--R 
+--R
+--R   (1)
+--R        6 4 10        5 4     6   3  9       2 4 4        5   3     6 2 2  8
+--R       b d x   + (6a b d  + 4b c d )x  + (15a b d  + 24a b c d  + 6b c d )x
+--R     + 
+--R           3 3 4      2 4   3        5 2 2     6 3   7
+--R       (20a b d  + 60a b c d  + 36a b c d  + 4b c d)x
+--R     + 
+--R           4 2 4      3 3   3      2 4 2 2        5 3     6 4  6
+--R       (15a b d  + 80a b c d  + 90a b c d  + 24a b c d + b c )x
+--R     + 
+--R          5   4      4 2   3       3 3 2 2      2 4 3        5 4  5
+--R       (6a b d  + 60a b c d  + 120a b c d  + 60a b c d + 6a b c )x
+--R     + 
+--R         6 4      5     3      4 2 2 2      3 3 3       2 4 4  4
+--R       (a d  + 24a b c d  + 90a b c d  + 80a b c d + 15a b c )x
+--R     + 
+--R          6   3      5   2 2      4 2 3       3 3 4  3
+--R       (4a c d  + 36a b c d  + 60a b c d + 20a b c )x
+--R     + 
+--R          6 2 2      5   3       4 2 4  2      6 3      5   4      6 4
+--R       (6a c d  + 24a b c d + 15a b c )x  + (4a c d + 6a b c )x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 600
+--r0:=-(b*c-a*d)^4*GAMMA(7,a+b*x)/b^5-4*d*(b*c-a*d)^3*GAMMA(8,a+b*x)/b^5-_
+--  6*d^2*(b*c-a*d)^2*GAMMA(9,a+b*x)/b^5-4*d^3*(b*c-a*d)*GAMMA(10,a+b*x)/_
+--  b^5-d^4*GAMMA(11,a+b*x)/b^5
+--E 278
+
+--S 279 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 279
+
+)clear all
+
+--S 280 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)^3
+--R 
+--R
+--R   (1)
+--R        6 3 9        5 3     6   2  8       2 4 3        5   2     6 2   7
+--R       b d x  + (6a b d  + 3b c d )x  + (15a b d  + 18a b c d  + 3b c d)x
+--R     + 
+--R           3 3 3      2 4   2        5 2     6 3  6
+--R       (20a b d  + 45a b c d  + 18a b c d + b c )x
+--R     + 
+--R           4 2 3      3 3   2      2 4 2        5 3  5
+--R       (15a b d  + 60a b c d  + 45a b c d + 6a b c )x
+--R     + 
+--R          5   3      4 2   2      3 3 2       2 4 3  4
+--R       (6a b d  + 45a b c d  + 60a b c d + 15a b c )x
+--R     + 
+--R         6 3      5     2      4 2 2       3 3 3  3
+--R       (a d  + 18a b c d  + 45a b c d + 20a b c )x
+--R     + 
+--R          6   2      5   2       4 2 3  2      6 2      5   3      6 3
+--R       (3a c d  + 18a b c d + 15a b c )x  + (3a c d + 6a b c )x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 600
+--r0:=-(b*c-a*d)^3*GAMMA(7,a+b*x)/b^4-3*d*(b*c-a*d)^2*GAMMA(8,a+b*x)/b^4-_
+--  3*d^2*(b*c-a*d)*GAMMA(9,a+b*x)/b^4-d^3*GAMMA(10,a+b*x)/b^4
+--E 281
+
+--S 282 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 282
+
+)clear all
+
+--S 283 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)^2
+--R 
+--R
+--R   (1)
+--R        6 2 8        5 2     6     7       2 4 2        5       6 2  6
+--R       b d x  + (6a b d  + 2b c d)x  + (15a b d  + 12a b c d + b c )x
+--R     + 
+--R           3 3 2      2 4          5 2  5       4 2 2      3 3         2 4 2  4
+--R       (20a b d  + 30a b c d + 6a b c )x  + (15a b d  + 40a b c d + 15a b c )x
+--R     + 
+--R          5   2      4 2         3 3 2  3     6 2      5           4 2 2  2
+--R       (6a b d  + 30a b c d + 20a b c )x  + (a d  + 12a b c d + 15a b c )x
+--R     + 
+--R          6        5   2      6 2
+--R       (2a c d + 6a b c )x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 600
+--r0:=-(b*c-a*d)^2*GAMMA(7,a+b*x)/b^3-2*d*(b*c-a*d)*GAMMA(8,a+b*x)/b^3-_
+--  d^2*GAMMA(9,a+b*x)/b^3
+--E 284
+
+--S 285 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 285
+
+)clear all
+
+--S 286 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^6*(c+d*x)
+--R 
+--R
+--R   (1)
+--R        6   7        5     6   6       2 4        5   5       3 3       2 4   4
+--R       b d x  + (6a b d + b c)x  + (15a b d + 6a b c)x  + (20a b d + 15a b c)x
+--R     + 
+--R           4 2       3 3   3      5         4 2   2     6      5         6
+--R       (15a b d + 20a b c)x  + (6a b d + 15a b c)x  + (a d + 6a b c)x + a c
+--R  *
+--R       - b x - a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 600
+--r0:=-(b*c-a*d)*GAMMA(7,a+b*x)/b^2-d*GAMMA(8,a+b*x)/b^2
+--E 287
+
+--S 288 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 288
+
+)clear all
+
+--S 289 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^6
+--R 
+--R
+--R   (1)
+--R     6 6       5 5      2 4 4      3 3 3      4 2 2     5       6   - b x - a
+--R   (b x  + 6a b x  + 15a b x  + 20a b x  + 15a b x  + 6a b x + a )%e
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 600
+--r0:=-GAMMA(7,a+b*x)/b
+--E 290
+
+--S 291 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 291
+
+)clear all
+
+--S 292 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^6/(c+d*x)
+--R 
+--R
+--R   (1)
+--R     6 6       5 5      2 4 4      3 3 3      4 2 2     5       6   - b x - a
+--R   (b x  + 6a b x  + 15a b x  + 20a b x  + 15a b x  + 6a b x + a )%e
+--R   --------------------------------------------------------------------------
+--R                                     d x + c
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 600
+--r0:=-6*%e^(-a-b*x)*(b*c-a*d)^2/d^3+2*%e^(-a-b*x)*(b*c-a*d)^3/_
+--  d^4-%e^(-a-b*x)*(b*c-a*d)^4/d^5+%e^(-a-b*x)*(b*c-a*d)^5/d^6-_
+--  6*%e^(-a-b*x)*(b*c-a*d)^2*(a+b*x)/d^3+2*%e^(-a-b*x)*(b*c-a*d)^3*_
+--  (a+b*x)/d^4-%e^(-a-b*x)*(b*c-a*d)^4*(a+b*x)/d^5-3*%e^(-a-b*x)*_
+--  (b*c-a*d)^2*(a+b*x)^2/d^3+%e^(-a-b*x)*(b*c-a*d)^3*(a+b*x)^2/d^4-_
+--  %e^(-a-b*x)*(b*c-a*d)^2*(a+b*x)^3/d^3+%e^(-a+b*c/d)*(b*c-a*d)^6*_
+--  Ei(-b*(c+d*x)/d)/d^7+(b*c-a*d)*GAMMA(5,a+b*x)/d^2-GAMMA(6,a+b*x)/d
+--E 293
+
+--S 294 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 294
+
+)clear all
+
+--S 295 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^6/(c+d*x)^2
+--R 
+--R
+--R   (1)
+--R     6 6       5 5      2 4 4      3 3 3      4 2 2     5       6   - b x - a
+--R   (b x  + 6a b x  + 15a b x  + 20a b x  + 15a b x  + 6a b x + a )%e
+--R   --------------------------------------------------------------------------
+--R                                2 2             2
+--R                               d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 600
+--r0:=36*%e^(-a-b*x)*b*(b*c-a*d)/d^3-30*%e^(-a-b*x)*b*(b*c-a*d)^2/d^4+_
+--  20*%e^(-a-b*x)*b*(b*c-a*d)^3/d^5-15*%e^(-a-b*x)*b*(b*c-a*d)^4/d^6-_
+--  %e^(-a-b*x)*(b*c-a*d)^6/(d^7*(c+d*x))+36*%e^(-a-b*x)*b^2*(b*c-a*d)*_
+--  (c+d*x)/d^4-30*%e^(-a-b*x)*b^2*(b*c-a*d)^2*(c+d*x)/d^5+_
+--  20*%e^(-a-b*x)*b^2*(b*c-a*d)^3*(c+d*x)/d^6+18*%e^(-a-b*x)*_
+--  b^3*(b*c-a*d)*(c+d*x)^2/d^5-15*%e^(-a-b*x)*b^3*(b*c-a*d)^2*(c+d*x)^2/_
+--  d^6+6*%e^(-a-b*x)*b^4*(b*c-a*d)*(c+d*x)^3/d^6-6*%e^(-a+b*c/d)*b*_
+--  (b*c-a*d)^5*Ei(-b*(c+d*x)/d)/d^7-%e^(-a+b*c/d)*b*(b*c-a*d)^6*_
+--  Ei(-b*(c+d*x)/d)/d^8-%e^(-a+b*c/d)*b*GAMMA(5,b*(c+d*x)/d)/d^2
+--E 296
+
+--S 297 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 297
+
+)clear all
+
+--S 298 of 600
+t0:=%e^(-a-b*x)*(a+b*x)^6/(c+d*x)^3
+--R 
+--R
+--R   (1)
+--R     6 6       5 5      2 4 4      3 3 3      4 2 2     5       6   - b x - a
+--R   (b x  + 6a b x  + 15a b x  + 20a b x  + 15a b x  + 6a b x + a )%e
+--R   --------------------------------------------------------------------------
+--R                           3 3       2 2     2       3
+--R                          d x  + 3c d x  + 3c d x + c
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 600
+r0:=-6*%e^(-a-b*x)*b^2/d^3+12*%e^(-a-b*x)*b^2*(b*c-a*d)/d^4-15*%e^(-a-b*x)*_
+   b^2*(b*c-a*d)^2/d^5+20*%e^(-a-b*x)*b^2*(b*c-a*d)^3/d^6-1/2*%e^(-a-b*x)*_
+   (b*c-a*d)^6/(d^7*(c+d*x)^2)+6*%e^(-a-b*x)*b*(b*c-a*d)^5/(d^7*(c+d*x))+_
+   1/2*%e^(-a-b*x)*b*(b*c-a*d)^6/(d^8*(c+d*x))-6*%e^(-a-b*x)*b^3*(c+d*x)/_
+   d^4+12*%e^(-a-b*x)*b^3*(b*c-a*d)*(c+d*x)/d^5-15*%e^(-a-b*x)*b^3*_
+   (b*c-a*d)^2*(c+d*x)/d^6-3*%e^(-a-b*x)*b^4*(c+d*x)^2/d^5+6*%e^(-a-b*x)*_
+   b^4*(b*c-a*d)*(c+d*x)^2/d^6-%e^(-a-b*x)*b^5*(c+d*x)^3/d^6+_
+   15*%e^(-a+b*c/d)*b^2*(b*c-a*d)^4*Ei(-b*(c+d*x)/d)/d^7+6*%e^(-a+b*c/d)*_
+   b^2*(b*c-a*d)^5*Ei(-b*(c+d*x)/d)/d^8+1/2*%e^(-a+b*c/d)*b^2*(b*c-a*d)^6*_
+   Ei(-b*(c+d*x)/d)/d^9
+--R 
+--R
+--R   (2)
+--R                 6      5      4  2 8        5      4       3  3   7
+--R               (a  - 12a  + 30a )b d  + (- 6a  + 60a  - 120a )b c d
+--R             + 
+--R                   4       3       2  4 2 6         3       2         5 3 5
+--R               (15a  - 120a  + 180a )b c d  + (- 20a  + 120a  - 120a)b c d
+--R             + 
+--R                   2             6 4 4               7 5 3    8 6 2
+--R               (15a  - 60a + 30)b c d  + (- 6a + 12)b c d  + b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                  6      5      4  2   7         5       4       3  3 2 6
+--R               (2a  - 24a  + 60a )b c d  + (- 12a  + 120a  - 240a )b c d
+--R             + 
+--R                   4       3       2  4 3 5         3       2         5 4 4
+--R               (30a  - 240a  + 360a )b c d  + (- 40a  + 240a  - 240a)b c d
+--R             + 
+--R                   2              6 5 3                7 6 2     8 7
+--R               (30a  - 120a + 60)b c d  + (- 12a + 24)b c d  + 2b c d
+--R          *
+--R             x
+--R         + 
+--R             6      5      4  2 2 6        5      4       3  3 3 5
+--R           (a  - 12a  + 30a )b c d  + (- 6a  + 60a  - 120a )b c d
+--R         + 
+--R               4       3       2  4 4 4         3       2         5 5 3
+--R           (15a  - 120a  + 180a )b c d  + (- 20a  + 120a  - 120a)b c d
+--R         + 
+--R               2             6 6 2               7 7     8 8
+--R           (15a  - 60a + 30)b c d  + (- 6a + 12)b c d + b c
+--R      *
+--R                            - a d + b c
+--R                            -----------
+--R            - b d x - b c        d
+--R         Ei(-------------)%e
+--R                  d
+--R     + 
+--R               5 8 5                4 8     5   7  4
+--R           - 2b d x  + ((- 12a - 6)b d  + 2b c d )x
+--R         + 
+--R                  2             3 8        4   7     5 2 6  3
+--R           ((- 30a  - 24a - 12)b d  + 12a b c d  - 2b c d )x
+--R         + 
+--R                     3      2             2 8       2             3   7
+--R               (- 40a  - 30a  - 24a - 12)b d  + (30a  - 12a - 12)b c d
+--R             + 
+--R                           4 2 6     5 3 5
+--R               (- 12a + 6)b c d  + 2b c d
+--R          *
+--R              2
+--R             x
+--R         + 
+--R                 6      5    8        5      4      3      2             2   7
+--R               (a  - 12a )b d  + (- 6a  + 60a  - 80a  - 60a  - 48a - 24)b c d
+--R             + 
+--R                   4       3       2             3 2 6
+--R               (15a  - 120a  + 150a  + 48a + 12)b c d
+--R             + 
+--R                     3       2              4 3 5       2             5 4 4
+--R               (- 20a  + 120a  - 108a - 12)b c d  + (15a  - 60a + 28)b c d
+--R             + 
+--R                           6 5 3    7 6 2
+--R               (- 6a + 12)b c d  + b c d
+--R          *
+--R             x
+--R         + 
+--R              6 8     6     5      7
+--R           - a d  + (a  - 6a )b c d
+--R         + 
+--R                5      4      3      2             2 2 6
+--R           (- 6a  + 45a  - 40a  - 30a  - 24a - 12)b c d
+--R         + 
+--R               4       3      2             3 3 5
+--R           (15a  - 100a  + 90a  + 36a + 12)b c d
+--R         + 
+--R                 3       2             4 4 4       2             5 5 3
+--R           (- 20a  + 105a  - 72a - 12)b c d  + (15a  - 54a + 20)b c d
+--R         + 
+--R                       6 6 2    7 7
+--R           (- 6a + 11)b c d  + b c d
+--R      *
+--R           - b x - a
+--R         %e
+--R  /
+--R       11 2       10      2 9
+--R     2d  x  + 4c d  x + 2c d
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 600
+t0:=f^(a+b*x^2)*x^m
+--R 
+--R
+--R            2
+--R         b x  + a m
+--R   (1)  f        x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 600
+--r0:=-1/2*f^a*x^(1+m)*GAMMA(1/2*(1+m),-b*x^2*log(f))*_
+--  (-b*x^2*log(f))^(1/2*(-1-m))
+--E 302
+
+--S 303 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 303
+
+)clear all
+
+--S 304 of 600
+t0:=f^(a+b*x^2)*x^11
+--R 
+--R
+--R               2
+--R         11 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 600
+--r0:=-1/2*f^a*GAMMA(6,-b*x^2*log(f))/(b^6*log(f)^6)
+--E 305
+
+--S 306 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 306
+
+)clear all
+
+--S 307 of 600
+t0:=f^(a+b*x^2)*x^9
+--R 
+--R
+--R              2
+--R         9 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 600
+--r0:=1/2*f^a*GAMMA(5,-b*x^2*log(f))/(b^5*log(f)^5)
+--E 308
+
+--S 309 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 309
+
+)clear all
+
+--S 310 of 600
+t0:=f^(a+b*x^2)*x^7
+--R 
+--R
+--R              2
+--R         7 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 600
+r0:=-3*f^(a+b*x^2)/(b^4*log(f)^4)+3*f^(a+b*x^2)*x^2/(b^3*log(f)^3)-_
+   3/2*f^(a+b*x^2)*x^4/(b^2*log(f)^2)+1/2*f^(a+b*x^2)*x^6/(b*log(f))
+--R 
+--R
+--R                                                          2
+--R          3 6      3     2 4      2       2            b x  + a
+--R        (b x log(f)  - 3b x log(f)  + 6b x log(f) - 6)f
+--R   (2)  -------------------------------------------------------
+--R                                 4      4
+--R                               2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 600
+t0:=f^(a+b*x^2)*x^5
+--R 
+--R
+--R              2
+--R         5 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 600
+r0:=f^(a+b*x^2)/(b^3*log(f)^3)-f^(a+b*x^2)*x^2/(b^2*log(f)^2)+_
+   1/2*f^(a+b*x^2)*x^4/(b*log(f))
+--R 
+--R
+--R                                           2
+--R          2 4      2       2            b x  + a
+--R        (b x log(f)  - 2b x log(f) + 2)f
+--R   (2)  ----------------------------------------
+--R                         3      3
+--R                       2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 600
+t0:=f^(a+b*x^2)*x^3
+--R 
+--R
+--R              2
+--R         3 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 600
+r0:=-1/2*f^(a+b*x^2)/(b^2*log(f)^2)+1/2*f^(a+b*x^2)*x^2/(b*log(f))
+--R 
+--R
+--R                            2
+--R            2            b x  + a
+--R        (b x log(f) - 1)f
+--R   (2)  -------------------------
+--R                  2      2
+--R                2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 600
+t0:=f^(a+b*x^2)*x
+--R 
+--R
+--R              2
+--R           b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 600
+r0:=1/2*f^(a+b*x^2)/(b*log(f))
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (2)  ---------
+--R        2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 600
+t0:=f^(a+b*x^2)/x
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 600
+r0:=1/2*f^a*Ei(b*x^2*log(f))
+--R 
+--R
+--R         a      2
+--R        f Ei(b x log(f))
+--R   (2)  ----------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+)clear all
+
+--S 325 of 600
+t0:=f^(a+b*x^2)/x^3
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 600
+r0:=-1/2*f^(a+b*x^2)/x^2+1/2*b*f^a*Ei(b*x^2*log(f))*log(f)
+--R 
+--R
+--R                                         2
+--R           2       a      2           b x  + a
+--R        b x log(f)f Ei(b x log(f)) - f
+--R   (2)  --------------------------------------
+--R                            2
+--R                          2x
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 600
+t0:=f^(a+b*x^2)/x^5
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             5
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 600
+r0:=-1/4*f^(a+b*x^2)/x^4-1/4*b*f^(a+b*x^2)*log(f)/x^2+1/4*b^2*f^a*_
+   Ei(b*x^2*log(f))*log(f)^2
+--R 
+--R
+--R                                                            2
+--R         2 4      2 a      2                2            b x  + a
+--R        b x log(f) f Ei(b x log(f)) + (- b x log(f) - 1)f
+--R   (2)  ---------------------------------------------------------
+--R                                     4
+--R                                   4x
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 600
+t0:=f^(a+b*x^2)/x^7
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             7
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 600
+r0:=-1/6*f^(a+b*x^2)/x^6-1/12*b*f^(a+b*x^2)*log(f)/x^4-_
+   1/12*b^2*f^(a+b*x^2)*log(f)^2/x^2+1/12*b^3*f^a*Ei(b*x^2*log(f))*log(f)^3
+--R 
+--R
+--R   (2)
+--R                                                                     2
+--R    3 6      3 a      2              2 4      2      2            b x  + a
+--R   b x log(f) f Ei(b x log(f)) + (- b x log(f)  - b x log(f) - 2)f
+--R   -----------------------------------------------------------------------
+--R                                        6
+--R                                     12x
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 600
+t0:=f^(a+b*x^2)/x^9
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             9
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 600
+--r0:=-1/2*b^4*f^a*GAMMA(-4,-b*x^2*log(f))*log(f)^4
+--E 335
+
+--S 336 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 336
+
+)clear all
+
+--S 337 of 600
+t0:=f^(a+b*x^2)/x^11
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            11
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 600
+--r0:=1/2*b^5*f^a*GAMMA(-5,-b*x^2*log(f))*log(f)^5
+--E 338
+
+--S 339 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 339
+
+)clear all
+
+--S 340 of 600
+t0:=f^(a+b*x^2)*x^12
+--R 
+--R
+--R               2
+--R         12 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 600
+--r0:=-1/2*f^a*x^13*GAMMA(13/2,-b*x^2*log(f))/(-b*x^2*log(f))^(13/2)
+--E 341
+
+--S 342 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 342
+
+)clear all
+
+--S 343 of 600
+t0:=f^(a+b*x^2)*x^10
+--R 
+--R
+--R               2
+--R         10 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 600
+--r0:=-1/2*f^a*x^11*GAMMA(11/2,-b*x^2*log(f))/(-b*x^2*log(f))^(11/2)
+--E 344
+
+--S 345 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 345
+
+)clear all
+
+--S 346 of 600
+t0:=f^(a+b*x^2)*x^8
+--R 
+--R
+--R              2
+--R         8 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 600
+--r0:=-105/16*f^(a+b*x^2)*x/(b^4*log(f)^4)+35/8*f^(a+b*x^2)*x^3/_
+--  (b^3*log(f)^3)-7/4*f^(a+b*x^2)*x^5/(b^2*log(f)^2)+1/2*f^(a+b*x^2)*_
+--  x^7/(b*log(f))+105/32*f^a*erfi(x*sqrt(b)*sqrt(log(f)))*_
+--  sqrt(%pi)/(b^(9/2)*log(f)^(9/2))
+--E 347
+
+--S 348 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 348
+
+)clear all
+
+--S 349 of 600
+t0:=f^(a+b*x^2)*x^6
+--R 
+--R
+--R              2
+--R         6 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 600
+--r0:=15/8*f^(a+b*x^2)*x/(b^3*log(f)^3)-5/4*f^(a+b*x^2)*x^3/_
+--  (b^2*log(f)^2)+1/2*f^(a+b*x^2)*x^5/(b*log(f))-15/16*f^a*_
+--  erfi(x*sqrt(b)*sqrt(log(f)))*sqrt(%pi)/(b^(7/2)*log(f)^(7/2))
+--E 350
+
+--S 351 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 351
+
+)clear all
+
+--S 352 of 600
+t0:=f^(a+b*x^2)*x^4
+--R 
+--R
+--R              2
+--R         4 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 600
+--r0:=-3/4*f^(a+b*x^2)*x/(b^2*log(f)^2)+1/2*f^(a+b*x^2)*x^3/(b*log(f))+_
+--  3/8*f^a*erfi(x*sqrt(b)*sqrt(log(f)))*sqrt(%pi)/(b^(5/2)*log(f)^(5/2))
+--E 353
+
+--S 354 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 354
+
+)clear all
+
+--S 355 of 600
+t0:=f^(a+b*x^2)*x^2
+--R 
+--R
+--R              2
+--R         2 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 600
+--r0:=1/2*f^(a+b*x^2)*x/(b*log(f))-1/4*f^a*erfi(x*sqrt(b)*sqrt(log(f)))*_
+--  sqrt(%pi)/(b^(3/2)*log(f)^(3/2))
+--E 356
+
+--S 357 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 357
+
+)clear all
+
+--S 358 of 600
+t0:=f^(a+b*x^2)
+--R 
+--R
+--R            2
+--R         b x  + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 600
+--r0:=1/2*f^a*erfi(x*sqrt(b)*sqrt(log(f)))*sqrt(%pi)/(sqrt(b)*sqrt(log(f)))
+--E 359
+
+--S 360 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 360
+
+)clear all
+
+--S 361 of 600
+t0:=f^(a+b*x^2)/x^2
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 600
+--r0:=-f^(a+b*x^2)/x+f^a*erfi(x*sqrt(b)*sqrt(log(f)))*sqrt(%pi)*_
+--  sqrt(b)*sqrt(log(f))
+--E 362
+
+--S 363 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 363
+
+)clear all
+
+--S 364 of 600
+t0:=f^(a+b*x^2)/x^4
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             4
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 600
+--r0:=-1/3*f^(a+b*x^2)/x^3-2/3*b*f^(a+b*x^2)*log(f)/x+2/3*b^(3/2)*f^a*_
+--  erfi(x*sqrt(b)*sqrt(log(f)))*log(f)^(3/2)*sqrt(%pi)
+--E 365
+
+--S 366 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 366
+
+)clear all
+
+--S 367 of 600
+t0:=f^(a+b*x^2)/x^6
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             6
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 600
+--r0:=-1/5*f^(a+b*x^2)/x^5-2/15*b*f^(a+b*x^2)*log(f)/x^3-4/15*b^2*_
+--  f^(a+b*x^2)*log(f)^2/x+4/15*b^(5/2)*f^a*erfi(x*sqrt(b)*_
+--  sqrt(log(f)))*log(f)^(5/2)*sqrt(%pi)
+--E 368
+
+--S 369 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 369
+
+)clear all
+
+--S 370 of 600
+t0:=f^(a+b*x^2)/x^8
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             8
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 600
+--r0:=-1/7*f^(a+b*x^2)/x^7-2/35*b*f^(a+b*x^2)*log(f)/x^5-4/105*b^2*_
+--  f^(a+b*x^2)*log(f)^2/x^3-8/105*b^3*f^(a+b*x^2)*log(f)^3/x+_
+--  8/105*b^(7/2)*f^a*erfi(x*sqrt(b)*sqrt(log(f)))*log(f)^(7/2)*sqrt(%pi)
+--E 371
+
+--S 372 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 372
+
+)clear all
+
+--S 373 of 600
+t0:=f^(a+b*x^2)/x^10
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            10
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 600
+--r0:=-1/2*f^a*GAMMA(-9/2,-b*x^2*log(f))*(-b*x^2*log(f))^(9/2)/x^9
+--E 374
+
+--S 375 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 375
+
+)clear all
+
+--S 376 of 600
+t0:=f^(a+b*x^2)/x^12
+--R 
+--R
+--R            2
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            12
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 600
+--r0:=-1/2*f^a*GAMMA(-11/2,-b*x^2*log(f))*(-b*x^2*log(f))^(11/2)/x^11
+--E 377
+
+--S 378 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 378
+
+)clear all
+
+--S 379 of 600
+t0:=f^(a+b*x^3)*x^m
+--R 
+--R
+--R            3
+--R         b x  + a m
+--R   (1)  f        x
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 600
+--r0:=-1/3*f^a*x^(1+m)*GAMMA(1/3*(1+m),-b*x^3*log(f))*_
+--  (-b*x^3*log(f))^(1/3*(-1-m))
+--E 380
+
+--S 381 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 381
+
+)clear all
+
+--S 382 of 600
+t0:=f^(a+b*x^3)*x^17
+--R 
+--R
+--R               3
+--R         17 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 600
+--r0:=-1/3*f^a*GAMMA(6,-b*x^3*log(f))/(b^6*log(f)^6)
+--E 383
+
+--S 384 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 384
+
+)clear all
+
+--S 385 of 600
+t0:=f^(a+b*x^3)*x^14
+--R 
+--R
+--R               3
+--R         14 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 600
+--r0:=1/3*f^a*GAMMA(5,-b*x^3*log(f))/(b^5*log(f)^5)
+--E 386
+
+--S 387 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 387
+
+)clear all
+
+--S 388 of 600
+t0:=f^(a+b*x^3)*x^11
+--R 
+--R
+--R               3
+--R         11 b x  + a
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 600
+r0:=-2*f^(a+b*x^3)/(b^4*log(f)^4)+2*f^(a+b*x^3)*x^3/(b^3*log(f)^3)-_
+   f^(a+b*x^3)*x^6/(b^2*log(f)^2)+1/3*f^(a+b*x^3)*x^9/(b*log(f))
+--R 
+--R
+--R                                                          3
+--R          3 9      3     2 6      2       3            b x  + a
+--R        (b x log(f)  - 3b x log(f)  + 6b x log(f) - 6)f
+--R   (2)  -------------------------------------------------------
+--R                                 4      4
+--R                               3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 600
+t0:=f^(a+b*x^3)*x^8
+--R 
+--R
+--R              3
+--R         8 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 600
+r0:=2/3*f^(a+b*x^3)/(b^3*log(f)^3)-2/3*f^(a+b*x^3)*x^3/(b^2*log(f)^2)+_
+   1/3*f^(a+b*x^3)*x^6/(b*log(f))
+--R 
+--R
+--R                                           3
+--R          2 6      2       3            b x  + a
+--R        (b x log(f)  - 2b x log(f) + 2)f
+--R   (2)  ----------------------------------------
+--R                         3      3
+--R                       3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 600
+t0:=f^(a+b*x^3)*x^5
+--R 
+--R
+--R              3
+--R         5 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 600
+r0:=-1/3*f^(a+b*x^3)/(b^2*log(f)^2)+1/3*f^(a+b*x^3)*x^3/(b*log(f))
+--R 
+--R
+--R                            3
+--R            3            b x  + a
+--R        (b x log(f) - 1)f
+--R   (2)  -------------------------
+--R                  2      2
+--R                3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 600
+t0:=f^(a+b*x^3)*x^2
+--R 
+--R
+--R              3
+--R         2 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 600
+r0:=1/3*f^(a+b*x^3)/(b*log(f))
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (2)  ---------
+--R        3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 600
+t0:=f^(a+b*x^3)/x
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 600
+r0:=1/3*f^a*Ei(b*x^3*log(f))
+--R 
+--R
+--R         a      3
+--R        f Ei(b x log(f))
+--R   (2)  ----------------
+--R                3
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 600
+t0:=f^(a+b*x^3)/x^4
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             4
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 600
+r0:=-1/3*f^(a+b*x^3)/x^3+1/3*b*f^a*Ei(b*x^3*log(f))*log(f)
+--R 
+--R
+--R                                         3
+--R           3       a      3           b x  + a
+--R        b x log(f)f Ei(b x log(f)) - f
+--R   (2)  --------------------------------------
+--R                            3
+--R                          3x
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 600
+t0:=f^(a+b*x^3)/x^7
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             7
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 600
+r0:=-1/6*f^(a+b*x^3)/x^6-1/6*b*f^(a+b*x^3)*log(f)/x^3+1/6*b^2*f^a*_
+   Ei(b*x^3*log(f))*log(f)^2
+--R 
+--R
+--R                                                            3
+--R         2 6      2 a      3                3            b x  + a
+--R        b x log(f) f Ei(b x log(f)) + (- b x log(f) - 1)f
+--R   (2)  ---------------------------------------------------------
+--R                                     6
+--R                                   6x
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 600
+t0:=f^(a+b*x^3)/x^10
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            10
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 600
+r0:=-1/9*f^(a+b*x^3)/x^9-1/18*b*f^(a+b*x^3)*log(f)/x^6-1/18*b^2*f^(a+b*x^3)*_
+   log(f)^2/x^3+1/18*b^3*f^a*Ei(b*x^3*log(f))*log(f)^3
+--R 
+--R
+--R   (2)
+--R                                                                     3
+--R    3 9      3 a      3              2 6      2      3            b x  + a
+--R   b x log(f) f Ei(b x log(f)) + (- b x log(f)  - b x log(f) - 2)f
+--R   -----------------------------------------------------------------------
+--R                                        9
+--R                                     18x
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 600
+t0:=f^(a+b*x^3)/x^13
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            13
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 600
+--r0:=-1/3*b^4*f^a*GAMMA(-4,-b*x^3*log(f))*log(f)^4
+--E 413
+
+--S 414 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 414
+
+)clear all
+
+--S 415 of 600
+t0:=f^(a+b*x^3)/x^16
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R            16
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 600
+--r0:=1/3*b^5*f^a*GAMMA(-5,-b*x^3*log(f))*log(f)^5
+--E 416
+
+--S 417 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 417
+
+)clear all
+
+--S 418 of 600
+t0:=f^(a+b*x^3)*x^4
+--R 
+--R
+--R              3
+--R         4 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 600
+--r0:=-1/3*f^a*x^5*GAMMA(5/3,-b*x^3*log(f))/(-b*x^3*log(f))^(5/3)
+--E 419
+
+--S 420 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 420
+
+)clear all
+
+--S 421 of 600
+t0:=f^(a+b*x^3)*x^3
+--R 
+--R
+--R              3
+--R         3 b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 600
+--r0:=-1/3*f^a*x^4*GAMMA(4/3,-b*x^3*log(f))/(-b*x^3*log(f))^(4/3)
+--E 422
+
+--S 423 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 423
+
+)clear all
+
+--S 424 of 600
+t0:=f^(a+b*x^3)*x
+--R 
+--R
+--R              3
+--R           b x  + a
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 600
+--r0:=-1/3*f^a*x^2*GAMMA(2/3,-b*x^3*log(f))/(-b*x^3*log(f))^(2/3)
+--E 425
+
+--S 426 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 426
+
+)clear all
+
+--S 427 of 600
+t0:=f^(a+b*x^3)
+--R 
+--R
+--R            3
+--R         b x  + a
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 600
+--r0:=-1/3*f^a*x*GAMMA(1/3,-b*x^3*log(f))/(-b*x^3*log(f))^(1/3)
+--E 428
+
+--S 429 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 429
+
+)clear all
+
+--S 430 of 600
+t0:=f^(a+b*x^3)/x^2
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 600
+--r0:=-1/3*f^a*GAMMA(-1/3,-b*x^3*log(f))*(-b*x^3*log(f))^(1/3)/x
+--E 431
+
+--S 432 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 432
+
+)clear all
+
+--S 433 of 600
+t0:=f^(a+b*x^3)/x^3
+--R 
+--R
+--R            3
+--R         b x  + a
+--R        f
+--R   (1)  ---------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 600
+--r0:=-1/3*f^a*GAMMA(-2/3,-b*x^3*log(f))*(-b*x^3*log(f))^(2/3)/x^2
+--E 434
+
+--S 435 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 435
+
+)clear all
+
+--S 436 of 600
+t0:=%e^(4*x^3)*x^2
+--R 
+--R
+--R              3
+--R         2  4x
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 600
+r0:=1/12*%e^(4*x^3)
+--R 
+--R
+--R            3
+--R          4x
+--R        %e
+--R   (2)  -----
+--R          12
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 600
+t0:=f^(a+b/x)*x^m
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x    m
+--R   (1)  f       x
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 600
+--r0:=f^a*x^(1+m)*GAMMA(-1-m,-b*log(f)/x)*(-b*log(f)/x)^(1+m)
+--E 440
+
+--S 441 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 441
+
+)clear all
+
+--S 442 of 600
+t0:=f^(a+b/x)*x^4
+--R 
+--R
+--R           a x + b
+--R           -------
+--R         4    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 600
+--r0:=-b^5*f^a*GAMMA(-5,-b*log(f)/x)*log(f)^5
+--E 443
+
+--S 444 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 444
+
+)clear all
+
+--S 445 of 600
+t0:=f^(a+b/x)*x^3
+--R 
+--R
+--R           a x + b
+--R           -------
+--R         3    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 600
+--r0:=b^4*f^a*GAMMA(-4,-b*log(f)/x)*log(f)^4
+--E 446
+
+--S 447 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 447
+
+)clear all
+
+--S 448 of 600
+t0:=f^(a+b/x)*x^2
+--R 
+--R
+--R           a x + b
+--R           -------
+--R         2    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 600
+r0:=1/3*f^(a+b/x)*x^3+1/6*b*f^(a+b/x)*x^2*log(f)+1/6*b^2*f^(a+b/x)*x*_
+   log(f)^2-1/6*b^3*f^a*Ei(b*log(f)/x)*log(f)^3
+--R 
+--R
+--R                                                                     a x + b
+--R                                                                     -------
+--R           3      3 a   b log(f)      2        2      2           3     x
+--R        - b log(f) f Ei(--------) + (b x log(f)  + b x log(f) + 2x )f
+--R                            x
+--R   (2)  --------------------------------------------------------------------
+--R                                          6
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 600
+t0:=f^(a+b/x)*x
+--R 
+--R
+--R           a x + b
+--R           -------
+--R              x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 600
+r0:=1/2*f^(a+b/x)*x^2+1/2*b*f^(a+b/x)*x*log(f)-1/2*b^2*f^a*Ei(b*log(f)/x)*_
+   log(f)^2
+--R 
+--R
+--R                                                      a x + b
+--R                                                      -------
+--R           2      2 a   b log(f)                   2     x
+--R        - b log(f) f Ei(--------) + (b x log(f) + x )f
+--R                            x
+--R   (2)  -----------------------------------------------------
+--R                                  2
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 600
+t0:=f^(a+b/x)
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 600
+r0:=f^(a+b/x)*x-b*f^a*Ei(b*log(f)/x)*log(f)
+--R 
+--R
+--R                                      a x + b
+--R                                      -------
+--R                   a   b log(f)          x
+--R   (2)  - b log(f)f Ei(--------) + x f
+--R                           x
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 600
+t0:=f^(a+b/x)/x
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 600
+r0:=-f^a*Ei(b*log(f)/x)
+--R 
+--R
+--R           a   b log(f)
+--R   (2)  - f Ei(--------)
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 600
+t0:=f^(a+b/x)/x^2
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            2
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 600
+r0:=-f^(a+b/x)/(b*log(f))
+--R 
+--R
+--R           a x + b
+--R           -------
+--R              x
+--R          f
+--R   (2)  - --------
+--R          b log(f)
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 600
+t0:=f^(a+b/x)/x^3
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            3
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 600
+r0:=f^(a+b/x)/(b^2*log(f)^2)-f^(a+b/x)/(b*x*log(f))
+--R 
+--R
+--R                         a x + b
+--R                         -------
+--R                            x
+--R        (- b log(f) + x)f
+--R   (2)  ------------------------
+--R                2        2
+--R               b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 600
+t0:=f^(a+b/x)/x^4
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            4
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 600
+r0:=-2*f^(a+b/x)/(b^3*log(f)^3)+2*f^(a+b/x)/(b^2*x*log(f)^2)-_
+   f^(a+b/x)/(b*x^2*log(f))
+--R 
+--R
+--R                                          a x + b
+--R                                          -------
+--R            2      2                   2     x
+--R        (- b log(f)  + 2b x log(f) - 2x )f
+--R   (2)  -----------------------------------------
+--R                        3 2      3
+--R                       b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 600
+t0:=f^(a+b/x)/x^5
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            5
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 600
+r0:=6*f^(a+b/x)/(b^4*log(f)^4)-6*f^(a+b/x)/(b^3*x*log(f)^3)+_
+   3*f^(a+b/x)/(b^2*x^2*log(f)^2)-f^(a+b/x)/(b*x^3*log(f))
+--R 
+--R
+--R                                                         a x + b
+--R                                                         -------
+--R            3      3     2        2       2           3     x
+--R        (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )f
+--R   (2)  --------------------------------------------------------
+--R                                4 3      4
+--R                               b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 600
+t0:=f^(a+b/x)/x^6
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            6
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 600
+--r0:=-f^a*GAMMA(5,-b*log(f)/x)/(b^5*log(f)^5)
+--E 473
+
+--S 474 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 474
+
+)clear all
+
+--S 475 of 600
+t0:=f^(a+b/x)/x^7
+--R 
+--R
+--R         a x + b
+--R         -------
+--R            x
+--R        f
+--R   (1)  --------
+--R            7
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 600
+--r0:=f^a*GAMMA(6,-b*log(f)/x)/(b^6*log(f)^6)
+--E 476
+
+--S 477 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 477
+
+)clear all
+
+--S 478 of 600
+t0:=f^(a+b/x^2)*x^m
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x     m
+--R   (1)  f        x
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 600
+--r0:=1/2*f^a*x^(1+m)*GAMMA(1/2*(-1-m),-b*log(f)/x^2)*_
+--  (-b*log(f)/x^2)^(1/2*(1+m))
+--E 479
+
+--S 480 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 480
+
+)clear all
+
+--S 481 of 600
+t0:=f^(a+b/x^2)*x^9
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         9    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 600
+--r0:=-1/2*b^5*f^a*GAMMA(-5,-b*log(f)/x^2)*log(f)^5
+--E 482
+
+--S 483 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 483
+
+)clear all
+
+--S 484 of 600
+t0:=f^(a+b/x^2)*x^7
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         7    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 600
+--r0:=1/2*b^4*f^a*GAMMA(-4,-b*log(f)/x^2)*log(f)^4
+--E 485
+
+--S 486 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 486
+
+)clear all
+
+--S 487 of 600
+t0:=f^(a+b/x^2)*x^5
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         5    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 600
+r0:=1/6*f^(a+b/x^2)*x^6+1/12*b*f^(a+b/x^2)*x^4*log(f)+_
+   1/12*b^2*f^(a+b/x^2)*x^2*log(f)^2-1/12*b^3*f^a*Ei(b*log(f)/x^2)*log(f)^3
+--R 
+--R
+--R                                                                        2
+--R                                                                     a x  + b
+--R                                                                     --------
+--R                                                                         2
+--R           3      3 a   b log(f)      2 2      2      4           6     x
+--R        - b log(f) f Ei(--------) + (b x log(f)  + b x log(f) + 2x )f
+--R                            2
+--R                           x
+--R   (2)  ---------------------------------------------------------------------
+--R                                          12
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 600
+t0:=f^(a+b/x^2)*x^3
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         3    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 600
+r0:=1/4*f^(a+b/x^2)*x^4+1/4*b*f^(a+b/x^2)*x^2*log(f)-_
+   1/4*b^2*f^a*Ei(b*log(f)/x^2)*log(f)^2
+--R 
+--R
+--R                                                         2
+--R                                                      a x  + b
+--R                                                      --------
+--R                                                          2
+--R           2      2 a   b log(f)        2          4     x
+--R        - b log(f) f Ei(--------) + (b x log(f) + x )f
+--R                            2
+--R                           x
+--R   (2)  ------------------------------------------------------
+--R                                   4
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 600
+t0:=f^(a+b/x^2)*x
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R              x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 600
+r0:=1/2*f^(a+b/x^2)*x^2-1/2*b*f^a*Ei(b*log(f)/x^2)*log(f)
+--R 
+--R
+--R                                         2
+--R                                      a x  + b
+--R                                      --------
+--R                                          2
+--R                   a   b log(f)     2    x
+--R        - b log(f)f Ei(--------) + x f
+--R                           2
+--R                          x
+--R   (2)  --------------------------------------
+--R                           2
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 600
+t0:=f^(a+b/x^2)/x
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 600
+r0:=-1/2*f^a*Ei(b*log(f)/x^2)
+--R 
+--R
+--R           a   b log(f)
+--R          f Ei(--------)
+--R                   2
+--R                  x
+--R   (2)  - --------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 600
+t0:=f^(a+b/x^2)/x^3
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             3
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 600
+r0:=-1/2*f^(a+b/x^2)/(b*log(f))
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R              x
+--R          f
+--R   (2)  - ---------
+--R          2b log(f)
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 600
+t0:=f^(a+b/x^2)/x^5
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             5
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 600
+r0:=1/2*f^(a+b/x^2)/(b^2*log(f)^2)-1/2*f^(a+b/x^2)/(b*x^2*log(f))
+--R 
+--R
+--R                             2
+--R                          a x  + b
+--R                          --------
+--R                              2
+--R                       2     x
+--R        (- b log(f) + x )f
+--R   (2)  --------------------------
+--R                 2 2      2
+--R               2b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 600
+t0:=f^(a+b/x^2)/x^7
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             7
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 600
+r0:=-f^(a+b/x^2)/(b^3*log(f)^3)+f^(a+b/x^2)/(b^2*x^2*log(f)^2)-_
+   1/2*f^(a+b/x^2)/(b*x^4*log(f))
+--R 
+--R
+--R                                             2
+--R                                          a x  + b
+--R                                          --------
+--R                                              2
+--R            2      2       2           4     x
+--R        (- b log(f)  + 2b x log(f) - 2x )f
+--R   (2)  ------------------------------------------
+--R                         3 4      3
+--R                       2b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 600
+t0:=f^(a+b/x^2)/x^9
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             9
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 600
+r0:=3*f^(a+b/x^2)/(b^4*log(f)^4)-3*f^(a+b/x^2)/(b^3*x^2*log(f)^3)+_
+   3/2*f^(a+b/x^2)/(b^2*x^4*log(f)^2)-1/2*f^(a+b/x^2)/(b*x^6*log(f))
+--R 
+--R
+--R                                                            2
+--R                                                         a x  + b
+--R                                                         --------
+--R                                                             2
+--R            3      3     2 2      2       4           6     x
+--R        (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )f
+--R   (2)  ---------------------------------------------------------
+--R                                 4 6      4
+--R                               2b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 600
+t0:=f^(a+b/x^2)/x^11
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            11
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 600
+--r0:=-1/2*f^a*GAMMA(5,-b*log(f)/x^2)/(b^5*log(f)^5)
+--E 512
+
+--S 513 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 513
+
+)clear all
+
+--S 514 of 600
+t0:=f^(a+b/x^2)/x^13
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            13
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 600
+--r0:=1/2*f^a*GAMMA(6,-b*log(f)/x^2)/(b^6*log(f)^6)
+--E 515
+
+--S 516 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 516
+
+)clear all
+
+--S 517 of 600
+t0:=f^(a+b/x^2)*x^10
+--R 
+--R
+--R               2
+--R            a x  + b
+--R            --------
+--R                2
+--R         10    x
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 600
+--r0:=1/2*f^a*x^11*GAMMA(-11/2,-b*log(f)/x^2)*(-b*log(f)/x^2)^(11/2)
+--E 518
+
+--S 519 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 519
+
+)clear all
+
+--S 520 of 600
+t0:=f^(a+b/x^2)*x^8
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         8    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 600
+--r0:=1/2*f^a*x^9*GAMMA(-9/2,-b*log(f)/x^2)*(-b*log(f)/x^2)^(9/2)
+--E 521
+
+--S 522 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 522
+
+)clear all
+
+--S 523 of 600
+t0:=f^(a+b/x^2)*x^6
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         6    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 600
+--r0:=1/7*f^(a+b/x^2)*x^7+2/35*b*f^(a+b/x^2)*x^5*log(f)+4/105*b^2*_
+--  f^(a+b/x^2)*x^3*log(f)^2+8/105*b^3*f^(a+b/x^2)*x*log(f)^3-_
+--  8/105*b^(7/2)*f^a*erfi(sqrt(b)*sqrt(log(f))/x)*log(f)^(7/2)*sqrt(%pi)
+--E 524
+
+--S 525 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 525
+
+)clear all
+
+--S 526 of 600
+t0:=f^(a+b/x^2)*x^4
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         4    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 600
+--r0:=1/5*f^(a+b/x^2)*x^5+2/15*b*f^(a+b/x^2)*x^3*log(f)+_
+--  4/15*b^2*f^(a+b/x^2)*x*log(f)^2-4/15*b^(5/2)*f^a*erfi(sqrt(b)*_
+--  sqrt(log(f))/x)*log(f)^(5/2)*sqrt(%pi)
+--E 527
+
+--S 528 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 528
+
+)clear all
+
+--S 529 of 600
+t0:=f^(a+b/x^2)*x^2
+--R 
+--R
+--R              2
+--R           a x  + b
+--R           --------
+--R               2
+--R         2    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 600
+--r0:=1/3*f^(a+b/x^2)*x^3+2/3*b*f^(a+b/x^2)*x*log(f)-_
+--  2/3*b^(3/2)*f^a*erfi(sqrt(b)*sqrt(log(f))/x)*log(f)^(3/2)*sqrt(%pi)
+--E 530
+
+--S 531 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 531
+
+)clear all
+
+--S 532 of 600
+t0:=f^(a+b/x^2)
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R   (1)  f
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 600
+--r0:=f^(a+b/x^2)*x-f^a*erfi(sqrt(b)*sqrt(log(f))/x)*sqrt(%pi)*_
+--  sqrt(b)*sqrt(log(f))
+--E 533
+
+--S 534 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 534
+
+)clear all
+
+--S 535 of 600
+t0:=f^(a+b/x^2)/x^2
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             2
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 600
+--r0:=-1/2*f^a*erfi(sqrt(b)*sqrt(log(f))/x)*sqrt(%pi)/(sqrt(b)*sqrt(log(f)))
+--E 536
+
+--S 537 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 537
+
+)clear all
+
+--S 538 of 600
+t0:=f^(a+b/x^2)/x^4
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             4
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 600
+--r0:=-1/2*f^(a+b/x^2)/(b*x*log(f))+1/4*f^a*erfi(sqrt(b)*_
+--  sqrt(log(f))/x)*sqrt(%pi)/(b^(3/2)*log(f)^(3/2))
+--E 539
+
+--S 540 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 540
+
+)clear all
+
+--S 541 of 600
+t0:=f^(a+b/x^2)/x^6
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             6
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 600
+--r0:=3/4*f^(a+b/x^2)/(b^2*x*log(f)^2)-1/2*f^(a+b/x^2)/(b*x^3*log(f))-_
+--  3/8*f^a*erfi(sqrt(b)*sqrt(log(f))/x)*sqrt(%pi)/(b^(5/2)*log(f)^(5/2))
+--E 542
+
+--S 543 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 543
+
+)clear all
+
+--S 544 of 600
+t0:=f^(a+b/x^2)/x^8
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R             8
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 600
+--r0:=-15/8*f^(a+b/x^2)/(b^3*x*log(f)^3)+5/4*f^(a+b/x^2)/(b^2*x^3*_
+--  log(f)^2)-1/2*f^(a+b/x^2)/(b*x^5*log(f))+15/16*f^a*erfi(sqrt(b)*_
+--  sqrt(log(f))/x)*sqrt(%pi)/(b^(7/2)*log(f)^(7/2))
+--E 545
+
+--S 546 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 546
+
+)clear all
+
+--S 547 of 600
+t0:=f^(a+b/x^2)/x^10
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            10
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 600
+--r0:=105/16*f^(a+b/x^2)/(b^4*x*log(f)^4)-35/8*f^(a+b/x^2)/_
+--  (b^3*x^3*log(f)^3)+7/4*f^(a+b/x^2)/(b^2*x^5*log(f)^2)-_
+--  1/2*f^(a+b/x^2)/(b*x^7*log(f))-105/32*f^a*erfi(sqrt(b)*_
+--  sqrt(log(f))/x)*sqrt(%pi)/(b^(9/2)*log(f)^(9/2))
+--E 548
+
+--S 549 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 549
+
+)clear all
+
+--S 550 of 600
+t0:=f^(a+b/x^2)/x^12
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            12
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 600
+--r0:=1/2*f^a*GAMMA(11/2,-b*log(f)/x^2)/(x^11*(-b*log(f)/x^2)^(11/2))
+--E 551
+
+--S 552 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 552
+
+)clear all
+
+--S 553 of 600
+t0:=f^(a+b/x^2)/x^14
+--R 
+--R
+--R            2
+--R         a x  + b
+--R         --------
+--R             2
+--R            x
+--R        f
+--R   (1)  ---------
+--R            14
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 600
+--r0:=1/2*f^a*GAMMA(13/2,-b*log(f)/x^2)/(x^13*(-b*log(f)/x^2)^(13/2))
+--E 554
+
+--S 555 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 555
+
+)clear all
+
+--S 556 of 600
+t0:=f^(a+b/x^3)*x^m
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x     m
+--R   (1)  f        x
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 600
+--r0:=1/3*f^a*x^(1+m)*GAMMA(1/3*(-1-m),-b*log(f)/x^3)*_
+--  (-b*log(f)/x^3)^(1/3*(1+m))
+--E 557
+
+--S 558 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 558
+
+)clear all
+
+--S 559 of 600
+t0:=f^(a+b/x^3)*x^14
+--R 
+--R
+--R               3
+--R            a x  + b
+--R            --------
+--R                3
+--R         14    x
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 600
+--r0:=-1/3*b^5*f^a*GAMMA(-5,-b*log(f)/x^3)*log(f)^5
+--E 560
+
+--S 561 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 561
+
+)clear all
+
+--S 562 of 600
+t0:=f^(a+b/x^3)*x^11
+--R 
+--R
+--R               3
+--R            a x  + b
+--R            --------
+--R                3
+--R         11    x
+--R   (1)  x  f
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 600
+--r0:=1/3*b^4*f^a*GAMMA(-4,-b*log(f)/x^3)*log(f)^4
+--E 563
+
+--S 564 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 564
+
+)clear all
+
+--S 565 of 600
+t0:=f^(a+b/x^3)*x^8
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R         8    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 600
+r0:=1/9*f^(a+b/x^3)*x^9+1/18*b*f^(a+b/x^3)*x^6*log(f)+_
+   1/18*b^2*f^(a+b/x^3)*x^3*log(f)^2-1/18*b^3*f^a*Ei(b*log(f)/x^3)*log(f)^3
+--R 
+--R
+--R                                                                        3
+--R                                                                     a x  + b
+--R                                                                     --------
+--R                                                                         3
+--R           3      3 a   b log(f)      2 3      2      6           9     x
+--R        - b log(f) f Ei(--------) + (b x log(f)  + b x log(f) + 2x )f
+--R                            3
+--R                           x
+--R   (2)  ---------------------------------------------------------------------
+--R                                          18
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 567
+
+)clear all
+
+--S 568 of 600
+t0:=f^(a+b/x^3)*x^5
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R         5    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 600
+r0:=1/6*f^(a+b/x^3)*x^6+1/6*b*f^(a+b/x^3)*x^3*log(f)-_
+   1/6*b^2*f^a*Ei(b*log(f)/x^3)*log(f)^2
+--R 
+--R
+--R                                                         3
+--R                                                      a x  + b
+--R                                                      --------
+--R                                                          3
+--R           2      2 a   b log(f)        3          6     x
+--R        - b log(f) f Ei(--------) + (b x log(f) + x )f
+--R                            3
+--R                           x
+--R   (2)  ------------------------------------------------------
+--R                                   6
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 600
+t0:=f^(a+b/x^3)*x^2
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R         2    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 600
+r0:=1/3*f^(a+b/x^3)*x^3-1/3*b*f^a*Ei(b*log(f)/x^3)*log(f)
+--R 
+--R
+--R                                         3
+--R                                      a x  + b
+--R                                      --------
+--R                                          3
+--R                   a   b log(f)     3    x
+--R        - b log(f)f Ei(--------) + x f
+--R                           3
+--R                          x
+--R   (2)  --------------------------------------
+--R                           3
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+)clear all
+
+--S 574 of 600
+t0:=f^(a+b/x^3)/x
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 600
+r0:=-1/3*f^a*Ei(b*log(f)/x^3)
+--R 
+--R
+--R           a   b log(f)
+--R          f Ei(--------)
+--R                   3
+--R                  x
+--R   (2)  - --------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 600
+t0:=f^(a+b/x^3)/x^4
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R             4
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 600
+r0:=-1/3*f^(a+b/x^3)/(b*log(f))
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R              x
+--R          f
+--R   (2)  - ---------
+--R          3b log(f)
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 579
+
+)clear all
+
+--S 580 of 600
+t0:=f^(a+b/x^3)/x^7
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R             7
+--R            x
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 600
+r0:=1/3*f^(a+b/x^3)/(b^2*log(f)^2)-1/3*f^(a+b/x^3)/(b*x^3*log(f))
+--R 
+--R
+--R                             3
+--R                          a x  + b
+--R                          --------
+--R                              3
+--R                       3     x
+--R        (- b log(f) + x )f
+--R   (2)  --------------------------
+--R                 2 3      2
+--R               3b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 600
+t0:=f^(a+b/x^3)/x^10
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R            10
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 600
+r0:=-2/3*f^(a+b/x^3)/(b^3*log(f)^3)+2/3*f^(a+b/x^3)/(b^2*x^3*log(f)^2)-_
+   1/3*f^(a+b/x^3)/(b*x^6*log(f))
+--R 
+--R
+--R                                             3
+--R                                          a x  + b
+--R                                          --------
+--R                                              3
+--R            2      2       3           6     x
+--R        (- b log(f)  + 2b x log(f) - 2x )f
+--R   (2)  ------------------------------------------
+--R                         3 6      3
+--R                       3b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 600
+t0:=f^(a+b/x^3)/x^13
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R            13
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 600
+r0:=2*f^(a+b/x^3)/(b^4*log(f)^4)-2*f^(a+b/x^3)/(b^3*x^3*log(f)^3)+_
+   f^(a+b/x^3)/(b^2*x^6*log(f)^2)-1/3*f^(a+b/x^3)/(b*x^9*log(f))
+--R 
+--R
+--R                                                            3
+--R                                                         a x  + b
+--R                                                         --------
+--R                                                             3
+--R            3      3     2 3      2       6           9     x
+--R        (- b log(f)  + 3b x log(f)  - 6b x log(f) + 6x )f
+--R   (2)  ---------------------------------------------------------
+--R                                 4 9      4
+--R                               3b x log(f)
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 588
+
+)clear all
+
+--S 589 of 600
+t0:=f^(a+b/x^3)/x^16
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R            16
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 600
+--r0:=-1/3*f^a*GAMMA(5,-b*log(f)/x^3)/(b^5*log(f)^5)
+--E 590
+
+--S 591 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 591
+
+)clear all
+
+--S 592 of 600
+t0:=f^(a+b/x^3)/x^19
+--R 
+--R
+--R            3
+--R         a x  + b
+--R         --------
+--R             3
+--R            x
+--R        f
+--R   (1)  ---------
+--R            19
+--R           x
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 600
+--r0:=1/3*f^a*GAMMA(6,-b*log(f)/x^3)/(b^6*log(f)^6)
+--E 593
+
+--S 594 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 594
+
+)clear all
+
+--S 595 of 600
+t0:=f^(a+b/x^3)*x^4
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R         4    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 600
+--r0:=1/3*f^a*x^5*GAMMA(-5/3,-b*log(f)/x^3)*(-b*log(f)/x^3)^(5/3)
+--E 596
+
+--S 597 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 597
+
+)clear all
+
+--S 598 of 600
+t0:=f^(a+b/x^3)*x^3
+--R 
+--R
+--R              3
+--R           a x  + b
+--R           --------
+--R               3
+--R         3    x
+--R   (1)  x f
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 600
+--r0:=1/3*f^a*x^4*GAMMA(-4/3,-b*log(f)/x^3)*(-b*log(f)/x^3)^(4/3)
+--E 599
+
+--S 600 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 600
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder24b.input.pamphlet b/src/input/richder24b.input.pamphlet
new file mode 100644
index 0000000..bec7b87
--- /dev/null
+++ b/src/input/richder24b.input.pamphlet
@@ -0,0 +1,3056 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder24b.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Exponential Functions
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder24b.output
+)spool richder24b.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 600
+t0:=f^(a+b/x^3)*x
+--E 1
+
+--S 2 of 600
+--r0:=1/3*f^a*x^2*GAMMA(-2/3,-b*log(f)/x^3)*(-b*log(f)/x^3)^(2/3)
+--E 2
+
+--S 3 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 3
+
+)clear all
+
+--S 4 of 600
+t0:=f^(a+b/x^3)
+--E 4
+
+--S 5 of 600
+--r0:=1/3*f^a*x*GAMMA(-1/3,-b*log(f)/x^3)*(-b*log(f)/x^3)^(1/3)
+--E 5
+
+--S 6 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 6
+
+)clear all
+
+--S 7 of 600
+t0:=f^(a+b/x^3)/x^2
+--E 7
+
+--S 8 of 600
+--r0:=1/3*f^a*GAMMA(1/3,-b*log(f)/x^3)/(x*(-b*log(f)/x^3)^(1/3))
+--E 8
+
+--S 9 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 9
+
+)clear all
+
+--S 10 of 600
+t0:=f^(a+b/x^3)/x^3
+--E 10
+
+--S 11 of 600
+--r0:=1/3*f^a*GAMMA(2/3,-b*log(f)/x^3)/(x^2*(-b*log(f)/x^3)^(2/3))
+--E 11
+
+--S 12 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 12
+
+)clear all
+
+--S 13 of 600
+t0:=f^(a+b/x^3)/x^5
+--E 13
+
+--S 14 of 600
+--r0:=1/3*f^a*GAMMA(4/3,-b*log(f)/x^3)/(x^4*(-b*log(f)/x^3)^(4/3))
+--E 14
+
+--S 15 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 15
+
+)clear all
+
+--S 16 of 600
+t0:=f^(a+b*x^n)*x^m
+--E 16
+
+--S 17 of 600
+--r0:=-f^a*x^(1+m)*GAMMA((1+m)/n,-b*x^n*log(f))/(n*(-b*x^n*log(f))^((1+m)/n))
+--E 17
+
+--S 18 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 18
+
+)clear all
+
+--S 19 of 600
+t0:=f^(a+b*x^n)*x^3
+--E 19
+
+--S 20 of 600
+--r0:=-f^a*x^4*GAMMA(4/n,-b*x^n*log(f))/(n*(-b*x^n*log(f))^(4/n))
+--E 20
+
+--S 21 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 21
+
+)clear all
+
+--S 22 of 600
+t0:=f^(a+b*x^n)*x^2
+--E 22
+
+--S 23 of 600
+--r0:=-f^a*x^3*GAMMA(3/n,-b*x^n*log(f))/(n*(-b*x^n*log(f))^(3/n))
+--E 23
+
+--S 24 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 24
+
+)clear all
+
+--S 25 of 600
+t0:=f^(a+b*x^n)*x
+--E 25
+
+--S 26 of 600
+--r0:=-f^a*x^2*GAMMA(2/n,-b*x^n*log(f))/(n*(-b*x^n*log(f))^(2/n))
+--E 26
+
+--S 27 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 27
+
+)clear all
+
+--S 28 of 600
+t0:=f^(a+b*x^n)
+--E 28
+
+--S 29 of 600
+--r0:=-f^a*x*GAMMA(1/n,-b*x^n*log(f))/(n*(-b*x^n*log(f))^(1/n))
+--E 29
+
+--S 30 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 30
+
+)clear all
+
+--S 31 of 600
+t0:=f^(a+b*x^n)/x
+--E 31
+
+--S 32 of 600
+r0:=f^a*Ei(b*x^n*log(f))/n
+--E 32
+
+--S 33 of 600
+d0:=normalize(t0-D(r0,x))
+--E 33
+
+)clear all
+
+--S 34 of 600
+t0:=f^(a+b*x^n)/x^2
+--E 34
+
+--S 35 of 600
+--r0:=-f^a*GAMMA((-1)/n,-b*x^n*log(f))*(-b*x^n*log(f))^(1/n)/(n*x)
+--E 35
+
+--S 36 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 36
+
+)clear all
+
+--S 37 of 600
+t0:=f^(a+b*x^n)/x^3
+--E 37
+
+--S 38 of 600
+--r0:=-f^a*GAMMA((-2)/n,-b*x^n*log(f))*(-b*x^n*log(f))^(2/n)/(n*x^2)
+--E 38
+
+--S 39 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 39
+
+)clear all
+
+--S 40 of 600
+t0:=f^(a+b*x^n)/x^4
+--E 40
+
+--S 41 of 600
+--r0:=-f^a*GAMMA((-3)/n,-b*x^n*log(f))*(-b*x^n*log(f))^(3/n)/(n*x^3)
+--E 41
+
+--S 42 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 42
+
+)clear all
+
+--S 43 of 600
+t0:=f^(a+b*x^n)*x^(-1+3*n)
+--E 43
+
+--S 44 of 600
+r0:=2*f^(a+b*x^n)/(b^3*n*log(f)^3)-2*f^(a+b*x^n)*x^n/(b^2*n*log(f)^2)+_
+   f^(a+b*x^n)*x^(2*n)/(b*n*log(f))
+--E 44
+
+--S 45 of 600
+d0:=normalize(t0-D(r0,x))
+--E 45
+
+)clear all
+
+--S 46 of 600
+t0:=f^(a+b*x^n)*x^(-1+2*n)
+--E 46
+
+--S 47 of 600
+r0:=-f^(a+b*x^n)/(b^2*n*log(f)^2)+f^(a+b*x^n)*x^n/(b*n*log(f))
+--E 47
+
+--S 48 of 600
+d0:=normalize(t0-D(r0,x))
+--E 48
+
+)clear all
+
+--S 49 of 600
+t0:=f^(a+b*x^n)*x^(-1+n)
+--E 49
+
+--S 50 of 600
+r0:=f^(a+b*x^n)/(b*n*log(f))
+--E 50
+
+--S 51 of 600
+d0:=normalize(t0-D(r0,x))
+--E 51
+
+)clear all
+
+--S 52 of 600
+t0:=f^(a+b*x^n)/x
+--E 52
+
+--S 53 of 600
+r0:=f^a*Ei(b*x^n*log(f))/n
+--E 53
+
+--S 54 of 600
+d0:=normalize(t0-D(r0,x))
+--E 54
+
+)clear all
+
+--S 55 of 600
+t0:=f^(a+b*x^n)*x^(-1-n)
+--E 55
+
+--S 56 of 600
+r0:=-f^(a+b*x^n)/(n*x^n)+b*f^a*Ei(b*x^n*log(f))*log(f)/n
+--E 56
+
+--S 57 of 600
+d0:=normalize(t0-D(r0,x))
+--E 57
+
+)clear all
+
+--S 58 of 600
+t0:=f^(a+b*x^n)*x^(-1-2*n)
+--E 58
+
+--S 59 of 600
+r0:=-1/2*f^(a+b*x^n)/(n*x^(2*n))-1/2*b*f^(a+b*x^n)*log(f)/(n*x^n)+_
+   1/2*b^2*f^a*Ei(b*x^n*log(f))*log(f)^2/n
+--E 59
+
+--S 60 of 600
+d0:=normalize(t0-D(r0,x))
+--E 60
+
+)clear all
+
+--S 61 of 600
+t0:=f^(a+b*x^n)*x^(-1+5/2*n)
+--E 61
+
+--S 62 of 600
+--r0:=-3/2*f^(a+b*x^n)*x^(1/2*n)/(b^2*n*log(f)^2)+f^(a+b*x^n)*_
+--  x^(3/2*n)/(b*n*log(f))+3/4*f^a*erfi(x^(1/2*n)*sqrt(b)*sqrt(log(f)))*_
+--  sqrt(%pi)/(b^(5/2)*n*log(f)^(5/2))
+--E 62
+
+--S 63 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 63
+
+)clear all
+
+--S 64 of 600
+t0:=f^(a+b*x^n)*x^(-1+3/2*n)
+--E 64
+
+--S 65 of 600
+--r0:=f^(a+b*x^n)*x^(1/2*n)/(b*n*log(f))-1/2*f^a*erfi(x^(1/2*n)*sqrt(b)*_
+--  sqrt(log(f)))*sqrt(%pi)/(b^(3/2)*n*log(f)^(3/2))
+--E 65
+
+--S 66 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 66
+
+)clear all
+
+--S 67 of 600
+t0:=f^(a+b*x^n)*x^(-1+1/2*n)
+--E 67
+
+--S 68 of 600
+--r0:=f^a*erfi(x^(1/2*n)*sqrt(b)*sqrt(log(f)))*sqrt(%pi)/(n*sqrt(b)*_
+--  sqrt(log(f)))
+--E 68
+
+--S 69 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 69
+
+)clear all
+
+--S 70 of 600
+t0:=f^(a+b*x^n)*x^(-1-1/2*n)
+--E 70
+
+--S 71 of 600
+--r0:=-2*f^(a+b*x^n)/(n*x^(1/2*n))+2*f^a*erfi(x^(1/2*n)*sqrt(b)*_
+--  sqrt(log(f)))*sqrt(%pi)*sqrt(b)*sqrt(log(f))/n
+--E 71
+
+--S 72 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 72
+
+)clear all
+
+--S 73 of 600
+t0:=f^(a+b*x^n)*x^(-1-3/2*n)
+--E 73
+
+--S 74 of 600
+--r0:=-2/3*f^(a+b*x^n)/(n*x^(3/2*n))-4/3*b*f^(a+b*x^n)*log(f)/(n*x^(1/2*n))+_
+--  4/3*b^(3/2)*f^a*erfi(x^(1/2*n)*sqrt(b)*sqrt(log(f)))*_
+--  log(f)^(3/2)*sqrt(%pi)/n
+--E 74
+
+--S 75 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 75
+
+)clear all
+
+--S 76 of 600
+t0:=%e^((-0.1)*x)*x
+--E 76
+
+--S 77 of 600
+--r0:=(-100.)*%e^((-0.1)*x)+(-10.)*%e^((-0.1)*x)*x
+--E 77
+
+--S 78 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 78
+
+)clear all
+
+--S 79 of 600
+t0:=f^(c*(a+b*x)^2)*x^m
+--E 79
+
+--S 80 of 600
+--r0:=Int(f^(a^2*c+2*a*b*c*x+b^2*c*x^2)*x^m,x)
+--E 80
+
+--S 81 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 81
+
+)clear all
+
+--S 82 of 600
+t0:=f^(c*(a+b*x)^2)*x^3
+--E 82
+
+--S 83 of 600
+--r0:=-1/2*f^(c*(a+b*x)^2)/(b^4*c^2*log(f)^2)+3/2*a^2*f^(c*(a+b*x)^2)/_
+--  (b^4*c*log(f))-3/2*a*f^(c*(a+b*x)^2)*(a+b*x)/(b^4*c*log(f))+_
+--  1/2*f^(c*(a+b*x)^2)*(a+b*x)^2/(b^4*c*log(f))+3/4*a*erfi((a+b*x)*_
+--  sqrt(c)*sqrt(log(f)))*sqrt(%pi)/(b^4*c^(3/2)*log(f)^(3/2))-_
+--  1/2*a^3*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*sqrt(%pi)/(b^4*sqrt(c)*_
+--  sqrt(log(f)))
+--E 83
+
+--S 84 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 84
+
+)clear all
+
+--S 85 of 600
+t0:=f^(c*(a+b*x)^2)*x^2
+--E 85
+
+--S 86 of 600
+--r0:=-a*f^(c*(a+b*x)^2)/(b^3*c*log(f))+1/2*f^(c*(a+b*x)^2)*(a+b*x)/_
+--  (b^3*c*log(f))-1/4*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*sqrt(%pi)/_
+--  (b^3*c^(3/2)*log(f)^(3/2))+1/2*a^2*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*_
+--  sqrt(%pi)/(b^3*sqrt(c)*sqrt(log(f)))
+--E 86
+
+--S 87 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 87
+
+)clear all
+
+--S 88 of 600
+t0:=f^(c*(a+b*x)^2)*x
+--E 88
+
+--S 89 of 600
+--r0:=1/2*f^(c*(a+b*x)^2)/(b^2*c*log(f))-1/2*a*erfi((a+b*x)*sqrt(c)*_
+--  sqrt(log(f)))*sqrt(%pi)/(b^2*sqrt(c)*sqrt(log(f)))
+--E 89
+
+--S 90 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 90
+
+)clear all
+
+--S 91 of 600
+t0:=f^(c*(a+b*x)^2)
+--E 91
+
+--S 92 of 600
+--r0:=1/2*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*sqrt(%pi)/(b*sqrt(c)*sqrt(log(f)))
+--E 92
+
+--S 93 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 93
+
+)clear all
+
+--S 94 of 600
+t0:=f^(c*(a+b*x)^2)/x
+--E 94
+
+--S 95 of 600
+--r0:=Int(f^(c*(a+b*x)^2)/x,x)
+--E 95
+
+--S 96 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 96
+
+)clear all
+
+--S 97 of 600
+t0:=f^(c*(a+b*x)^2)/x^2
+--E 97
+
+--S 98 of 600
+--r0:=-f^(c*(a+b*x)^2)/x+2*a*b*c*Int(f^(c*(a+b*x)^2)/x,x)*log(f)+_
+--  b*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*sqrt(%pi)*sqrt(c)*sqrt(log(f))
+--E 98
+
+--S 99 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 99
+
+)clear all
+
+--S 100 of 600
+t0:=f^(c*(a+b*x)^2)/x^3
+--E 100
+
+--S 101 of 600
+--r0:=-1/2*f^(c*(a+b*x)^2)/x^2-a*b*c*f^(c*(a+b*x)^2)*log(f)/x+b^2*c*_
+--  Int(f^(c*(a+b*x)^2)/x,x)*log(f)+2*a^2*b^2*c^2*Int(f^(c*(a+b*x)^2)/x,x)*_
+--  log(f)^2+a*b^2*c^(3/2)*erfi((a+b*x)*sqrt(c)*sqrt(log(f)))*_
+--  log(f)^(3/2)*sqrt(%pi)
+--E 101
+
+--S 102 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 102
+
+)clear all
+
+--S 103 of 600
+t0:=f^(c*(a+b*x)^3)*x^m
+--E 103
+
+--S 104 of 600
+--r0:=Int(f^(c*(a+b*x)^3)*x^m,x)
+--E 104
+
+--S 105 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 105
+
+)clear all
+
+--S 106 of 600
+t0:=f^(c*(a+b*x)^3)*x^2
+--E 106
+
+--S 107 of 600
+--r0:=1/3*f^(c*(a+b*x)^3)/(b^3*c*log(f))+2/3*a*(a+b*x)^2*_
+--  GAMMA(2/3,-c*(a+b*x)^3*log(f))/(b^3*(-c*(a+b*x)^3*log(f))^(2/3))-_
+--  1/3*a^2*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*log(f))/(b^3*(-c*(a+b*x)^3*_
+--  log(f))^(1/3))
+--E 107
+
+--S 108 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 108
+
+)clear all
+
+--S 109 of 600
+t0:=f^(c*(a+b*x)^3)*x
+--E 109
+
+--S 110 of 600
+--r0:=-1/3*(a+b*x)^2*GAMMA(2/3,-c*(a+b*x)^3*log(f))/(b^2*(-c*(a+b*x)^3*_
+--  log(f))^(2/3))+1/3*a*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*log(f))/_
+--  (b^2*(-c*(a+b*x)^3*log(f))^(1/3))
+--E 110
+
+--S 111 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 111
+
+)clear all
+
+--S 112 of 600
+t0:=f^(c*(a+b*x)^3)
+--E 112
+
+--S 113 of 600
+--r0:=-1/3*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*log(f))/(b*(-c*(a+b*x)^3*_
+--  log(f))^(1/3))
+--E 113
+
+--S 114 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 114
+
+)clear all
+
+--S 115 of 600
+t0:=f^(c*(a+b*x)^3)/x
+--E 115
+
+--S 116 of 600
+--r0:=Int(f^(c*(a+b*x)^3)/x,x)
+--E 116
+
+--S 117 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 117
+
+)clear all
+
+--S 118 of 600
+t0:=f^(c*(a+b*x)^3)/x^2
+--E 118
+
+--S 119 of 600
+--r0:=-f^(c*(a+b*x)^3)/x+3*a^2*b*c*Int(f^(c*(a+b*x)^3)/x,x)*log(f)-_
+--  b*c*(a+b*x)^2*GAMMA(2/3,-c*(a+b*x)^3*log(f))*log(f)/(-c*(a+b*x)^3*_
+--  log(f))^(2/3)-a*b*c*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*log(f))*log(f)/_
+--  (-c*(a+b*x)^3*log(f))^(1/3)
+--E 119
+
+--S 120 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 120
+
+)clear all
+
+--S 121 of 600
+t0:=f^(c*(a+b*x)^3)/x^3
+--E 121
+
+--S 122 of 600
+--r0:=-1/2*f^(c*(a+b*x)^3)/x^2-3/2*a^2*b*c*f^(c*(a+b*x)^3)*log(f)/x+_
+--  3*a*b^2*c*Int(f^(c*(a+b*x)^3)/x,x)*log(f)+9/2*a^4*b^2*c^2*_
+--  Int(f^(c*(a+b*x)^3)/x,x)*log(f)^2-3/2*a^2*b^2*c^2*(a+b*x)^2*_
+--  GAMMA(2/3,-c*(a+b*x)^3*log(f))*log(f)^2/(-c*(a+b*x)^3*log(f))^(2/3)-_
+--  1/2*b^2*c*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*log(f))*log(f)/(-c*(a+b*x)^3*_
+--  log(f))^(1/3)-3/2*a^3*b^2*c^2*(a+b*x)*GAMMA(1/3,-c*(a+b*x)^3*_
+--  log(f))*log(f)^2/(-c*(a+b*x)^3*log(f))^(1/3)
+--E 122
+
+--S 123 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 123
+
+)clear all
+
+--S 124 of 600
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x^m
+--E 124
+
+--S 125 of 600
+--r0:=Int(%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x^m,x)
+--E 125
+
+--S 126 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 126
+
+)clear all
+
+--S 127 of 600
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x^4
+--E 127
+
+--S 128 of 600
+--r0:=2*%e^((a+b*x)^3)*a^2/b^5-1/3*a^4*(a+b*x)*GAMMA(1/3,-(a+b*x)^3)/_
+--  (b^5*(-(a+b*x)^3)^(1/3))+4/3*a^3*(a+b*x)^2*GAMMA(2/3,-(a+b*x)^3)/_
+--  (b^5*(-(a+b*x)^3)^(2/3))+4/3*a*(a+b*x)^4*GAMMA(4/3,-(a+b*x)^3)/_
+--  (b^5*(-(a+b*x)^3)^(4/3))-1/3*(a+b*x)^5*GAMMA(5/3,-(a+b*x)^3)/_
+--  (b^5*(-(a+b*x)^3)^(5/3))
+--E 128
+
+--S 129 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 129
+
+)clear all
+
+--S 130 of 600
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x^3
+--E 130
+
+--S 131 of 600
+--r0:=-%e^((a+b*x)^3)*a/b^4+1/3*a^3*(a+b*x)*GAMMA(1/3,-(a+b*x)^3)/_
+--  (b^4*(-(a+b*x)^3)^(1/3))-a^2*(a+b*x)^2*GAMMA(2/3,-(a+b*x)^3)/_
+--  (b^4*(-(a+b*x)^3)^(2/3))-1/3*(a+b*x)^4*GAMMA(4/3,-(a+b*x)^3)/_
+--  (b^4*(-(a+b*x)^3)^(4/3))
+--E 131
+
+--S 132 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 132
+
+)clear all
+
+--S 133 of 600
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x^2
+--E 133
+
+--S 134 of 600
+--r0:=1/3*%e^((a+b*x)^3)/b^3-1/3*a^2*(a+b*x)*GAMMA(1/3,-(a+b*x)^3)/_
+--  (b^3*(-(a+b*x)^3)^(1/3))+2/3*a*(a+b*x)^2*GAMMA(2/3,-(a+b*x)^3)/_
+--  (b^3*(-(a+b*x)^3)^(2/3))
+--E 134
+
+--S 135 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 135
+
+)clear all
+
+--S 136 of 600
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)*x
+--E 136
+
+--S 137 of 600
+--r0:=1/3*a*(a+b*x)*GAMMA(1/3,-(a+b*x)^3)/(b^2*(-(a+b*x)^3)^(1/3))-_
+--  1/3*(a+b*x)^2*GAMMA(2/3,-(a+b*x)^3)/(b^2*(-(a+b*x)^3)^(2/3))
+--E 137
+
+--S 138 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 138
+
+)clear all
+
+--S 139 of 600
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)
+--E 139
+
+--S 140 of 600
+--r0:=-1/3*(a+b*x)*GAMMA(1/3,-(a+b*x)^3)/(b*(-(a+b*x)^3)^(1/3))
+--E 140
+
+--S 141 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 141
+
+)clear all
+
+--S 142 of 600
+t0:=%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)/x
+--E 142
+
+--S 143 of 600
+--r0:=Int(%e^(a^3+3*a^2*b*x+3*a*b^2*x^2+b^3*x^3)/x,x)
+--E 143
+
+--S 144 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 144
+
+)clear all
+
+--S 145 of 600
+t0:=%e^sqrt(5+3*x)
+--E 145
+
+--S 146 of 600
+r0:=-2/3*%e^sqrt(5+3*x)+2/3*%e^sqrt(5+3*x)*sqrt(5+3*x)
+--E 146
+
+--S 147 of 600
+d0:=normalize(t0-D(r0,x))
+--E 147
+
+)clear all
+
+--S 148 of 600
+t0:=f^(c/(a+b*x))*x^m
+--E 148
+
+--S 149 of 600
+--r0:=Int(f^(c/(a+b*x))*x^m,x)
+--E 149
+
+--S 150 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 150
+
+)clear all
+
+--S 151 of 600
+t0:=f^(c/(a+b*x))*x^4
+--E 151
+
+--S 152 of 600
+--r0:=a^4*f^(c/(a+b*x))*(a+b*x)/b^5-2*a^3*f^(c/(a+b*x))*(a+b*x)^2/b^5+_
+--  2*a^2*f^(c/(a+b*x))*(a+b*x)^3/b^5-2*a^3*c*f^(c/(a+b*x))*(a+b*x)*_
+--  log(f)/b^5+a^2*c*f^(c/(a+b*x))*(a+b*x)^2*log(f)/b^5-a^4*c*Ei(c*_
+--  log(f)/(a+b*x))*log(f)/b^5+a^2*c^2*f^(c/(a+b*x))*(a+b*x)*log(f)^2/_
+--  b^5+2*a^3*c^2*Ei(c*log(f)/(a+b*x))*log(f)^2/b^5-a^2*c^3*Ei(c*_
+--  log(f)/(a+b*x))*log(f)^3/b^5-4*a*c^4*GAMMA(-4,-c*log(f)/(a+b*x))*_
+--  log(f)^4/b^5-c^5*GAMMA(-5,-c*log(f)/(a+b*x))*log(f)^5/b^5
+--E 152
+
+--S 153 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 153
+
+)clear all
+
+--S 154 of 600
+t0:=f^(c/(a+b*x))*x^3
+--E 154
+
+--S 155 of 600
+--r0:=-a^3*f^(c/(a+b*x))*(a+b*x)/b^4+3/2*a^2*f^(c/(a+b*x))*(a+b*x)^2/b^4-_
+--  a*f^(c/(a+b*x))*(a+b*x)^3/b^4+3/2*a^2*c*f^(c/(a+b*x))*(a+b*x)*_
+--  log(f)/b^4-1/2*a*c*f^(c/(a+b*x))*(a+b*x)^2*log(f)/b^4+a^3*c*Ei(c*_
+--  log(f)/(a+b*x))*log(f)/b^4-1/2*a*c^2*f^(c/(a+b*x))*(a+b*x)*log(f)^2/_
+--  b^4-3/2*a^2*c^2*Ei(c*log(f)/(a+b*x))*log(f)^2/b^4+1/2*a*c^3*_
+--  Ei(c*log(f)/(a+b*x))*log(f)^3/b^4+c^4*GAMMA(-4,-c*log(f)/(a+b*x))*_
+--  log(f)^4/b^4
+--E 155
+
+--S 156 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 156
+
+)clear all
+
+--S 157 of 600
+t0:=f^(c/(a+b*x))*x^2
+--E 157
+
+--S 158 of 600
+r0:=a^2*f^(c/(a+b*x))*(a+b*x)/b^3-a*f^(c/(a+b*x))*(a+b*x)^2/b^3+_
+  1/3*f^(c/(a+b*x))*(a+b*x)^3/b^3-a*c*f^(c/(a+b*x))*(a+b*x)*_
+  log(f)/b^3+1/6*c*f^(c/(a+b*x))*(a+b*x)^2*log(f)/b^3-a^2*c*_
+  Ei(c*log(f)/(a+b*x))*log(f)/b^3+1/6*c^2*f^(c/(a+b*x))*(a+b*x)*_
+  log(f)^2/b^3+a*c^2*Ei(c*log(f)/(a+b*x))*log(f)^2/b^3-1/6*c^3*_
+  Ei(c*log(f)/(a+b*x))*log(f)^3/b^3
+--E 158
+
+--S 159 of 600
+d0:=normalize(t0-D(r0,x))
+--E 159
+
+)clear all
+
+--S 160 of 600
+t0:=f^(c/(a+b*x))*x
+--E 160
+
+--S 161 of 600
+r0:=-a*f^(c/(a+b*x))*(a+b*x)/b^2+1/2*f^(c/(a+b*x))*(a+b*x)^2/b^2+_
+  1/2*c*f^(c/(a+b*x))*(a+b*x)*log(f)/b^2+a*c*Ei(c*log(f)/(a+b*x))*_
+  log(f)/b^2-1/2*c^2*Ei(c*log(f)/(a+b*x))*log(f)^2/b^2
+--E 161
+
+--S 162 of 600
+d0:=normalize(t0-D(r0,x))
+--E 162
+
+)clear all
+
+--S 163 of 600
+t0:=f^(c/(a+b*x))
+--E 163
+
+--S 164 of 600
+r0:=f^(c/(a+b*x))*(a+b*x)/b-c*Ei(c*log(f)/(a+b*x))*log(f)/b
+--E 164
+
+--S 165 of 600
+d0:=normalize(t0-D(r0,x))
+--E 165
+
+)clear all
+
+--S 166 of 600
+t0:=f^(c/(a+b*x))/x
+--E 166
+
+--S 167 of 600
+r0:=-Ei(c*log(f)/(a+b*x))+f^(c/a)*Ei(-b*c*x*log(f)/(a*(a+b*x)))
+--E 167
+
+--S 168 of 600
+d0:=normalize(t0-D(r0,x))
+--E 168
+
+)clear all
+
+--S 169 of 600
+t0:=f^(c/(a+b*x))/x^2
+--E 169
+
+--S 170 of 600
+r0:=-b*f^(c/(a+b*x))/a-f^(c/(a+b*x))/x-b*c*f^(c/a)*Ei(-b*c*x*log(f)/_
+  (a*(a+b*x)))*log(f)/a^2
+--E 170
+
+--S 171 of 600
+d0:=normalize(t0-D(r0,x))
+--E 171
+
+)clear all
+
+--S 172 of 600
+t0:=f^(c/(a+b*x))/x^3
+--E 172
+
+--S 173 of 600
+r0:=1/2*b^2*f^(c/(a+b*x))/a^2-1/2*f^(c/(a+b*x))/x^2+1/2*b^2*c*f^(c/(a+b*x))*_
+   log(f)/a^3+1/2*b*c*f^(c/(a+b*x))*log(f)/(a^2*x)+b^2*c*f^(c/a)*_
+   Ei(-b*c*x*log(f)/(a*(a+b*x)))*log(f)/a^3+1/2*b^2*c^2*f^(c/a)*_
+   Ei(-b*c*x*log(f)/(a*(a+b*x)))*log(f)^2/a^4
+--E 173
+
+--S 174 of 600
+d0:=normalize(t0-D(r0,x))
+--E 174
+
+)clear all
+
+--S 175 of 600
+t0:=f^(c/(a+b*x)^2)*x^m
+--E 175
+
+--S 176 of 600
+--r0:=Int(f^(c/(a+b*x)^2)*x^m,x)
+--E 176
+
+--S 177 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 177
+
+)clear all
+
+--S 178 of 600
+t0:=f^(c/(a+b*x)^2)*x^4
+--E 178
+
+--S 179 of 600
+--r0:=a^4*f^(c/(a+b*x)^2)*(a+b*x)/b^5-2*a^3*f^(c/(a+b*x)^2)*(a+b*x)^2/b^5+_
+--  2*a^2*f^(c/(a+b*x)^2)*(a+b*x)^3/b^5-a*f^(c/(a+b*x)^2)*(a+b*x)^4/b^5+_
+--  1/5*f^(c/(a+b*x)^2)*(a+b*x)^5/b^5+4*a^2*c*f^(c/(a+b*x)^2)*(a+b*x)*_
+--  log(f)/b^5-a*c*f^(c/(a+b*x)^2)*(a+b*x)^2*log(f)/b^5+2/15*c*_
+--  f^(c/(a+b*x)^2)*(a+b*x)^3*log(f)/b^5+2*a^3*c*Ei(c*log(f)/(a+b*x)^2)*_
+--  log(f)/b^5+4/15*c^2*f^(c/(a+b*x)^2)*(a+b*x)*log(f)^2/b^5+a*c^2*_
+--  Ei(c*log(f)/(a+b*x)^2)*log(f)^2/b^5-4*a^2*c^(3/2)*erfi(sqrt(c)*_
+--  sqrt(log(f))/(a+b*x))*log(f)^(3/2)*sqrt(%pi)/b^5-4/15*c^(5/2)*_
+--  erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*log(f)^(5/2)*sqrt(%pi)/b^5-_
+--  a^4*erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*sqrt(%pi)*sqrt(c)*sqrt(log(f))/b^5
+--E 179
+
+--S 180 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 180
+
+)clear all
+
+--S 181 of 600
+t0:=f^(c/(a+b*x)^2)*x^3
+--E 181
+
+--S 182 of 600
+--r0:=-a^3*f^(c/(a+b*x)^2)*(a+b*x)/b^4+3/2*a^2*f^(c/(a+b*x)^2)*(a+b*x)^2/_
+--  b^4-a*f^(c/(a+b*x)^2)*(a+b*x)^3/b^4+1/4*f^(c/(a+b*x)^2)*(a+b*x)^4/_
+--  b^4-2*a*c*f^(c/(a+b*x)^2)*(a+b*x)*log(f)/b^4+1/4*c*f^(c/(a+b*x)^2)*_
+--  (a+b*x)^2*log(f)/b^4-3/2*a^2*c*Ei(c*log(f)/(a+b*x)^2)*log(f)/b^4-_
+--  1/4*c^2*Ei(c*log(f)/(a+b*x)^2)*log(f)^2/b^4+2*a*c^(3/2)*_
+--  erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*log(f)^(3/2)*sqrt(%pi)/b^4+_
+--  a^3*erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*sqrt(%pi)*sqrt(c)*sqrt(log(f))/b^4
+--E 182
+
+--S 183 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 183
+
+)clear all
+
+--S 184 of 600
+t0:=f^(c/(a+b*x)^2)*x^2
+--E 184
+
+--S 185 of 600
+--r0:=a^2*f^(c/(a+b*x)^2)*(a+b*x)/b^3-a*f^(c/(a+b*x)^2)*(a+b*x)^2/b^3+_
+--  1/3*f^(c/(a+b*x)^2)*(a+b*x)^3/b^3+2/3*c*f^(c/(a+b*x)^2)*(a+b*x)*_
+--  log(f)/b^3+a*c*Ei(c*log(f)/(a+b*x)^2)*log(f)/b^3-2/3*c^(3/2)*_
+--  erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*log(f)^(3/2)*sqrt(%pi)/b^3-_
+--  a^2*erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*sqrt(%pi)*sqrt(c)*sqrt(log(f))/b^3
+--E 185
+
+--S 186 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 186
+
+)clear all
+
+--S 187 of 600
+t0:=f^(c/(a+b*x)^2)*x
+--E 187
+
+--S 188 of 600
+--r0:=-a*f^(c/(a+b*x)^2)*(a+b*x)/b^2+1/2*f^(c/(a+b*x)^2)*(a+b*x)^2/b^2-_
+--  1/2*c*Ei(c*log(f)/(a+b*x)^2)*log(f)/b^2+a*erfi(sqrt(c)*sqrt(log(f))/_
+--  (a+b*x))*sqrt(%pi)*sqrt(c)*sqrt(log(f))/b^2
+--E 188
+
+--S 189 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 189
+
+)clear all
+
+--S 190 of 600
+t0:=f^(c/(a+b*x)^2)
+--E 190
+
+--S 191 of 600
+--r0:=f^(c/(a+b*x)^2)*(a+b*x)/b-erfi(sqrt(c)*sqrt(log(f))/(a+b*x))*_
+--  sqrt(%pi)*sqrt(c)*sqrt(log(f))/b
+--E 191
+
+--S 192 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 192
+
+)clear all
+
+--S 193 of 600
+t0:=f^(c/(a+b*x)^2)/x
+--E 193
+
+--S 194 of 600
+--r0:=Int(f^(c/(a+b*x)^2)/x,x)
+--E 194
+
+--S 195 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 195
+
+)clear all
+
+--S 196 of 600
+t0:=f^(c/(a+b*x)^2)/x^2
+--E 196
+
+--S 197 of 600
+--r0:=Int(f^(c/(a+b*x)^2)/x^2,x)
+--E 197
+
+--S 198 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 198
+
+)clear all
+
+--S 199 of 600
+t0:=f^(c/(a+b*x)^2)/x^3
+--E 199
+
+--S 200 of 600
+--r0:=Int(f^(c/(a+b*x)^2)/x^3,x)
+--E 200
+
+--S 201 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 201
+
+)clear all
+
+--S 202 of 600
+t0:=f^(c/(a+b*x)^3)*x^m
+--E 202
+
+--S 203 of 600
+--r0:=Int(f^(c/(a+b*x)^3)*x^m,x)
+--E 203
+
+--S 204 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 204
+
+)clear all
+
+--S 205 of 600
+t0:=f^(c/(a+b*x)^3)*x^4
+--E 205
+
+--S 206 of 600
+--r0:=2*a^2*f^(c/(a+b*x)^3)*(a+b*x)^3/b^5-2*a^2*c*Ei(c*log(f)/(a+b*x)^3)*_
+--  log(f)/b^5+1/3*a^4*(a+b*x)*GAMMA(-1/3,-c*log(f)/(a+b*x)^3)*(-c*log(f)/_
+--  (a+b*x)^3)^(1/3)/b^5-4/3*a^3*(a+b*x)^2*GAMMA(-2/3,-c*log(f)/(a+b*x)^3)*_
+--  (-c*log(f)/(a+b*x)^3)^(2/3)/b^5-4/3*a*(a+b*x)^4*GAMMA(-4/3,-c*log(f)/_
+--  (a+b*x)^3)*(-c*log(f)/(a+b*x)^3)^(4/3)/b^5+1/3*(a+b*x)^5*_
+--  GAMMA(-5/3,-c*log(f)/(a+b*x)^3)*(-c*log(f)/(a+b*x)^3)^(5/3)/b^5
+--E 206
+
+--S 207 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 207
+
+)clear all
+
+--S 208 of 600
+t0:=f^(c/(a+b*x)^3)*x^3
+--E 208
+
+--S 209 of 600
+--r0:=-a*f^(c/(a+b*x)^3)*(a+b*x)^3/b^4+a*c*Ei(c*log(f)/(a+b*x)^3)*log(f)/_
+--  b^4-1/3*a^3*(a+b*x)*GAMMA(-1/3,-c*log(f)/(a+b*x)^3)*(-c*log(f)/_
+--  (a+b*x)^3)^(1/3)/b^4+a^2*(a+b*x)^2*GAMMA(-2/3,-c*log(f)/(a+b*x)^3)*_
+--  (-c*log(f)/(a+b*x)^3)^(2/3)/b^4+1/3*(a+b*x)^4*GAMMA(-4/3,-c*log(f)/_
+--  (a+b*x)^3)*(-c*log(f)/(a+b*x)^3)^(4/3)/b^4
+--E 209
+
+--S 210 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 210
+
+)clear all
+
+--S 211 of 600
+t0:=f^(c/(a+b*x)^3)*x^2
+--E 211
+
+--S 212 of 600
+--r0:=1/3*f^(c/(a+b*x)^3)*(a+b*x)^3/b^3-1/3*c*Ei(c*log(f)/(a+b*x)^3)*_
+--  log(f)/b^3+1/3*a^2*(a+b*x)*GAMMA(-1/3,-c*log(f)/(a+b*x)^3)*(-c*_
+--  log(f)/(a+b*x)^3)^(1/3)/b^3-2/3*a*(a+b*x)^2*GAMMA(-2/3,-c*log(f)/_
+--  (a+b*x)^3)*(-c*log(f)/(a+b*x)^3)^(2/3)/b^3
+--E 212
+
+--S 213 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 213
+
+)clear all
+
+--S 214 of 600
+t0:=f^(c/(a+b*x)^3)*x
+--E 214
+
+--S 215 of 600
+--r0:=-1/3*a*(a+b*x)*GAMMA(-1/3,-c*log(f)/(a+b*x)^3)*(-c*log(f)/_
+--  (a+b*x)^3)^(1/3)/b^2+1/3*(a+b*x)^2*GAMMA(-2/3,-c*log(f)/(a+b*x)^3)*_
+--  (-c*log(f)/(a+b*x)^3)^(2/3)/b^2
+--E 215
+
+--S 216 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 216
+
+)clear all
+
+--S 217 of 600
+t0:=f^(c/(a+b*x)^3)
+--E 217
+
+--S 218 of 600
+--r0:=1/3*(a+b*x)*GAMMA(-1/3,-c*log(f)/(a+b*x)^3)*(-c*log(f)/(a+b*x)^3)^(1/3)/b
+--E 218
+
+--S 219 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 219
+
+)clear all
+
+--S 220 of 600
+t0:=f^(c/(a+b*x)^3)/x
+--E 220
+
+--S 221 of 600
+--r0:=Int(f^(c/(a+b*x)^3)/x,x)
+--E 221
+
+--S 222 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 222
+
+)clear all
+
+--S 223 of 600
+t0:=f^(c/(a+b*x)^3)/x^2
+--E 223
+
+--S 224 of 600
+--r0:=Int(f^(c/(a+b*x)^3)/x^2,x)
+--E 224
+
+--S 225 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 225
+
+)clear all
+
+--S 226 of 600
+t0:=f^(c/(a+b*x)^3)/x^3
+--E 226
+
+--S 227 of 600
+--r0:=Int(f^(c/(a+b*x)^3)/x^3,x)
+--E 227
+
+--S 228 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 228
+
+)clear all
+
+--S 229 of 600
+t0:=f^(c*(a+b*x)^n)*x^m
+--E 229
+
+--S 230 of 600
+--r0:=Int(f^(c*(a+b*x)^n)*x^m,x)
+--E 230
+
+--S 231 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 231
+
+)clear all
+
+--S 232 of 600
+t0:=f^(c*(a+b*x)^n)*x^3
+--E 232
+
+--S 233 of 600
+--r0:=-(a+b*x)^4*GAMMA(4/n,-c*(a+b*x)^n*log(f))/(b^4*n*(-c*(a+b*x)^n*_
+--  log(f))^(4/n))+3*a*(a+b*x)^3*GAMMA(3/n,-c*(a+b*x)^n*log(f))/(b^4*n*_
+--  (-c*(a+b*x)^n*log(f))^(3/n))-3*a^2*(a+b*x)^2*GAMMA(2/n,-c*(a+b*x)^n*_
+--  log(f))/(b^4*n*(-c*(a+b*x)^n*log(f))^(2/n))+a^3*(a+b*x)*_
+--  GAMMA(1/n,-c*(a+b*x)^n*log(f))/(b^4*n*(-c*(a+b*x)^n*log(f))^(1/n))
+--E 233
+
+--S 234 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 234
+
+)clear all
+
+--S 235 of 600
+t0:=f^(c*(a+b*x)^n)*x^2
+--E 235
+
+--S 236 of 600
+--r0:=-(a+b*x)^3*GAMMA(3/n,-c*(a+b*x)^n*log(f))/(b^3*n*(-c*(a+b*x)^n*_
+--  log(f))^(3/n))+2*a*(a+b*x)^2*GAMMA(2/n,-c*(a+b*x)^n*log(f))/(b^3*n*_
+--  (-c*(a+b*x)^n*log(f))^(2/n))-a^2*(a+b*x)*GAMMA(1/n,-c*(a+b*x)^n*_
+--  log(f))/(b^3*n*(-c*(a+b*x)^n*log(f))^(1/n))
+--E 236
+
+--S 237 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 237
+
+)clear all
+
+--S 238 of 600
+t0:=f^(c*(a+b*x)^n)*x
+--E 238
+
+--S 239 of 600
+--r0:=-(a+b*x)^2*GAMMA(2/n,-c*(a+b*x)^n*log(f))/(b^2*n*(-c*(a+b*x)^n*_
+--  log(f))^(2/n))+a*(a+b*x)*GAMMA(1/n,-c*(a+b*x)^n*log(f))/(b^2*n*_
+--  (-c*(a+b*x)^n*log(f))^(1/n))
+--E 239
+
+--S 240 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 240
+
+)clear all
+
+--S 241 of 600
+t0:=f^(c*(a+b*x)^n)
+--E 241
+
+--S 242 of 600
+--r0:=-(a+b*x)*GAMMA(1/n,-c*(a+b*x)^n*log(f))/(b*n*(-c*(a+b*x)^n*log(f))^(1/n))
+--E 242
+
+--S 243 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 243
+
+)clear all
+
+--S 244 of 600
+t0:=f^(c*(a+b*x)^n)/x
+--E 244
+
+--S 245 of 600
+--r0:=Int(f^(c*(a+b*x)^n)/x,x)
+--E 245
+
+--S 246 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 246
+
+)clear all
+
+--S 247 of 600
+t0:=f^(c*(a+b*x)^n)/x^2
+--E 247
+
+--S 248 of 600
+--r0:=Int(f^(c*(a+b*x)^n)/x^2,x)
+--E 248
+
+--S 249 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 249
+
+)clear all
+
+--S 250 of 600
+t0:=f^(c*(a+b*x)^n)/x^3
+--E 250
+
+--S 251 of 600
+--r0:=Int(f^(c*(a+b*x)^n)/x^3,x)
+--E 251
+
+--S 252 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 252
+
+)clear all
+
+--S 253 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^m
+--E 253
+
+--S 254 of 600
+--r0:=-1/2*F^a*(c+d*x)^(1+m)*GAMMA(1/2*(1+m),-b*(c+d*x)^2*log(F))*_
+--  (-b*(c+d*x)^2*log(F))^(1/2*(-1-m))/d
+--E 254
+
+--S 255 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 255
+
+)clear all
+
+--S 256 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^11
+--E 256
+
+--S 257 of 600
+--r0:=-1/2*F^a*GAMMA(6,-b*(c+d*x)^2*log(F))/(b^6*d*log(F)^6)
+--E 257
+
+--S 258 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 258
+
+)clear all
+
+--S 259 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^9
+--E 259
+
+--S 260 of 600
+--r0:=1/2*F^a*GAMMA(5,-b*(c+d*x)^2*log(F))/(b^5*d*log(F)^5)
+--E 260
+
+--S 261 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 261
+
+)clear all
+
+--S 262 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^7
+--E 262
+
+--S 263 of 600
+r0:=-3*F^(a+b*(c+d*x)^2)/(b^4*d*log(F)^4)+3*F^(a+b*(c+d*x)^2)*_
+  (c+d*x)^2/(b^3*d*log(F)^3)-3/2*F^(a+b*(c+d*x)^2)*(c+d*x)^4/_
+  (b^2*d*log(F)^2)+1/2*F^(a+b*(c+d*x)^2)*(c+d*x)^6/(b*d*log(F))
+--E 263
+
+--S 264 of 600
+d0:=normalize(t0-D(r0,x))
+--E 264
+
+)clear all
+
+--S 265 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^5
+--E 265
+
+--S 266 of 600
+r0:=F^(a+b*(c+d*x)^2)/(b^3*d*log(F)^3)-F^(a+b*(c+d*x)^2)*(c+d*x)^2/_
+  (b^2*d*log(F)^2)+1/2*F^(a+b*(c+d*x)^2)*(c+d*x)^4/(b*d*log(F))
+--E 266
+
+--S 267 of 600
+d0:=normalize(t0-D(r0,x))
+--E 267
+
+)clear all
+
+--S 268 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^3
+--E 268
+
+--S 269 of 600
+r0:=-1/2*F^(a+b*(c+d*x)^2)/(b^2*d*log(F)^2)+1/2*F^(a+b*(c+d*x)^2)*_
+  (c+d*x)^2/(b*d*log(F))
+--E 269
+
+--S 270 of 600
+d0:=normalize(t0-D(r0,x))
+--E 270
+
+)clear all
+
+--S 271 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)
+--E 271
+
+--S 272 of 600
+r0:=1/2*F^(a+b*(c+d*x)^2)/(b*d*log(F))
+--E 272
+
+--S 273 of 600
+d0:=normalize(t0-D(r0,x))
+--E 273
+
+)clear all
+
+--S 274 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)
+--E 274
+
+--S 275 of 600
+r0:=1/2*F^a*Ei(b*(c+d*x)^2*log(F))/d
+--E 275
+
+--S 276 of 600
+d0:=normalize(t0-D(r0,x))
+--E 276
+
+)clear all
+
+--S 277 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^3
+--E 277
+
+--S 278 of 600
+r0:=-1/2*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^2)+1/2*b*F^a*Ei(b*(c+d*x)^2*log(F))*_
+  log(F)/d
+--E 278
+
+--S 279 of 600
+d0:=normalize(t0-D(r0,x))
+--E 279
+
+)clear all
+
+--S 280 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^5
+--E 280
+
+--S 281 of 600
+r0:=-1/4*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^4)-1/4*b*F^(a+b*(c+d*x)^2)*log(F)/_
+  (d*(c+d*x)^2)+1/4*b^2*F^a*Ei(b*(c+d*x)^2*log(F))*log(F)^2/d
+--E 281
+
+--S 282 of 600
+d0:=normalize(t0-D(r0,x))
+--E 282
+
+)clear all
+
+--S 283 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^7
+--E 283
+
+--S 284 of 600
+r0:=-1/6*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^6)-1/12*b*F^(a+b*(c+d*x)^2)*log(F)/_
+  (d*(c+d*x)^4)-1/12*b^2*F^(a+b*(c+d*x)^2)*log(F)^2/(d*(c+d*x)^2)+_
+  1/12*b^3*F^a*Ei(b*(c+d*x)^2*log(F))*log(F)^3/d
+--E 284
+
+--S 285 of 600
+d0:=normalize(t0-D(r0,x))
+--E 285
+
+)clear all
+
+--S 286 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^9
+--E 286
+
+--S 287 of 600
+--r0:=-1/2*b^4*F^a*GAMMA(-4,-b*(c+d*x)^2*log(F))*log(F)^4/d
+--E 287
+
+--S 288 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 288
+
+)clear all
+
+--S 289 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^11
+--E 289
+
+--S 290 of 600
+--r0:=1/2*b^5*F^a*GAMMA(-5,-b*(c+d*x)^2*log(F))*log(F)^5/d
+--E 290
+
+--S 291 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 291
+
+)clear all
+
+--S 292 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^12
+--E 292
+
+--S 293 of 600
+--r0:=-1/2*F^a*(c+d*x)^13*GAMMA(13/2,-b*(c+d*x)^2*log(F))/(d*(-b*(c+d*x)^2*_
+--  log(F))^(13/2))
+--E 293
+
+--S 294 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 294
+
+)clear all
+
+--S 295 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^10
+--E 295
+
+--S 296 of 600
+--r0:=-1/2*F^a*(c+d*x)^11*GAMMA(11/2,-b*(c+d*x)^2*log(F))/_
+--  (d*(-b*(c+d*x)^2*log(F))^(11/2))
+--E 296
+
+--S 297 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 297
+
+)clear all
+
+--S 298 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^8
+--E 298
+
+--S 299 of 600
+--r0:=-105/16*F^(a+b*(c+d*x)^2)*(c+d*x)/(b^4*d*log(F)^4)+_
+--  35/8*F^(a+b*(c+d*x)^2)*(c+d*x)^3/(b^3*d*log(F)^3)-_
+--  7/4*F^(a+b*(c+d*x)^2)*(c+d*x)^5/(b^2*d*log(F)^2)+_
+--  1/2*F^(a+b*(c+d*x)^2)*(c+d*x)^7/(b*d*log(F))+_
+--  105/32*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/_
+--  (b^(9/2)*d*log(F)^(9/2))
+--E 299
+
+--S 300 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 300
+
+)clear all
+
+--S 301 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^6
+--E 301
+
+--S 302 of 600
+--r0:=15/8*F^(a+b*(c+d*x)^2)*(c+d*x)/(b^3*d*log(F)^3)-_
+--  5/4*F^(a+b*(c+d*x)^2)*(c+d*x)^3/(b^2*d*log(F)^2)+_
+--  1/2*F^(a+b*(c+d*x)^2)*(c+d*x)^5/(b*d*log(F))-_
+--  15/16*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(b^(7/2)*d*_
+--  log(F)^(7/2))
+--E 302
+
+--S 303 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 303
+
+)clear all
+
+--S 304 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^4
+--E 304
+
+--S 305 of 600
+--r0:=-3/4*F^(a+b*(c+d*x)^2)*(c+d*x)/(b^2*d*log(F)^2)+1/2*F^(a+b*(c+d*x)^2)*_
+--  (c+d*x)^3/(b*d*log(F))+3/8*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*_
+--  sqrt(%pi)/(b^(5/2)*d*log(F)^(5/2))
+--E 305
+
+--S 306 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 306
+
+)clear all
+
+--S 307 of 600
+t0:=F^(a+b*(c+d*x)^2)*(c+d*x)^2
+--E 307
+
+--S 308 of 600
+--r0:=1/2*F^(a+b*(c+d*x)^2)*(c+d*x)/(b*d*log(F))-1/4*F^a*erfi((c+d*x)*_
+--  sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(b^(3/2)*d*log(F)^(3/2))
+--E 308
+
+--S 309 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 309
+
+)clear all
+
+--S 310 of 600
+t0:=F^(a+b*(c+d*x)^2)
+--E 310
+
+--S 311 of 600
+--r0:=1/2*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/_
+--  (d*sqrt(b)*sqrt(log(F)))
+--E 311
+
+--S 312 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 312
+
+)clear all
+
+--S 313 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^2
+--E 313
+
+--S 314 of 600
+--r0:=-F^(a+b*(c+d*x)^2)/(d*(c+d*x))+F^a*erfi((c+d*x)*sqrt(b)*_
+--  sqrt(log(F)))*sqrt(%pi)*sqrt(b)*sqrt(log(F))/d
+--E 314
+
+--S 315 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 315
+
+)clear all
+
+--S 316 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^4
+--E 316
+
+--S 317 of 600
+--r0:=-1/3*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^3)-2/3*b*F^(a+b*(c+d*x)^2)*_
+--  log(F)/(d*(c+d*x))+2/3*b^(3/2)*F^a*erfi((c+d*x)*sqrt(b)*_
+--  sqrt(log(F)))*log(F)^(3/2)*sqrt(%pi)/d
+--E 317
+
+--S 318 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 318
+
+)clear all
+
+--S 319 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^6
+--E 319
+
+--S 320 of 600
+--r0:=-1/5*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^5)-2/15*b*F^(a+b*(c+d*x)^2)*_
+--  log(F)/(d*(c+d*x)^3)-4/15*b^2*F^(a+b*(c+d*x)^2)*log(F)^2/(d*(c+d*x))+_
+--  4/15*b^(5/2)*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*log(F)^(5/2)*_
+--  sqrt(%pi)/d
+--E 320
+
+--S 321 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 321
+
+)clear all
+
+--S 322 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^8
+--E 322
+
+--S 323 of 600
+--r0:=-1/7*F^(a+b*(c+d*x)^2)/(d*(c+d*x)^7)-2/35*b*F^(a+b*(c+d*x)^2)*_
+--  log(F)/(d*(c+d*x)^5)-4/105*b^2*F^(a+b*(c+d*x)^2)*log(F)^2/(d*(c+d*x)^3)-_
+--  8/105*b^3*F^(a+b*(c+d*x)^2)*log(F)^3/(d*(c+d*x))+8/105*b^(7/2)*F^a*_
+--  erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*log(F)^(7/2)*sqrt(%pi)/d
+--E 323
+
+--S 324 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 324
+
+)clear all
+
+--S 325 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^10
+--E 325
+
+--S 326 of 600
+--r0:=-1/2*F^a*GAMMA(-9/2,-b*(c+d*x)^2*log(F))*(-b*(c+d*x)^2*_
+--  log(F))^(9/2)/(d*(c+d*x)^9)
+--E 326
+
+--S 327 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 327
+
+)clear all
+
+--S 328 of 600
+t0:=F^(a+b*(c+d*x)^2)/(c+d*x)^12
+--E 328
+
+--S 329 of 600
+--r0:=-1/2*F^a*GAMMA(-11/2,-b*(c+d*x)^2*log(F))*(-b*(c+d*x)^2*_
+--  log(F))^(11/2)/(d*(c+d*x)^11)
+--E 329
+
+--S 330 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 330
+
+)clear all
+
+--S 331 of 600
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^m
+--E 331
+
+--S 332 of 600
+--r0:=-1/3*F^a*(c+d*x)^(1+m)*GAMMA(1/3*(1+m),-b*(c+d*x)^3*log(F))*_
+--  (-b*(c+d*x)^3*log(F))^(1/3*(-1-m))/d
+--E 332
+
+--S 333 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 333
+
+)clear all
+
+--S 334 of 600
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^17
+--E 334
+
+--S 335 of 600
+--r0:=-1/3*F^a*GAMMA(6,-b*(c+d*x)^3*log(F))/(b^6*d*log(F)^6)
+--E 335
+
+--S 336 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 336
+
+)clear all
+
+--S 337 of 600
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^14
+--E 337
+
+--S 338 of 600
+--r0:=1/3*F^a*GAMMA(5,-b*(c+d*x)^3*log(F))/(b^5*d*log(F)^5)
+--E 338
+
+--S 339 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 339
+
+)clear all
+
+--S 340 of 600
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^11
+--E 340
+
+--S 341 of 600
+r0:=-2*F^(a+b*(c+d*x)^3)/(b^4*d*log(F)^4)+2*F^(a+b*(c+d*x)^3)*(c+d*x)^3/_
+  (b^3*d*log(F)^3)-F^(a+b*(c+d*x)^3)*(c+d*x)^6/(b^2*d*log(F)^2)+_
+  1/3*F^(a+b*(c+d*x)^3)*(c+d*x)^9/(b*d*log(F))
+--E 341
+
+--S 342 of 600
+d0:=normalize(t0-D(r0,x))
+--E 342
+
+)clear all
+
+--S 343 of 600
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^8
+--E 343
+
+--S 344 of 600
+r0:=2/3*F^(a+b*(c+d*x)^3)/(b^3*d*log(F)^3)-2/3*F^(a+b*(c+d*x)^3)*_
+  (c+d*x)^3/(b^2*d*log(F)^2)+1/3*F^(a+b*(c+d*x)^3)*(c+d*x)^6/(b*d*log(F))
+--E 344
+
+--S 345 of 600
+d0:=normalize(t0-D(r0,x))
+--E 345
+
+)clear all
+
+--S 346 of 600
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^5
+--E 346
+
+--S 347 of 600
+r0:=-1/3*F^(a+b*(c+d*x)^3)/(b^2*d*log(F)^2)+1/3*F^(a+b*(c+d*x)^3)*_
+   (c+d*x)^3/(b*d*log(F))
+--E 347
+
+--S 348 of 600
+d0:=normalize(t0-D(r0,x))
+--E 348
+
+)clear all
+
+--S 349 of 600
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^2
+--E 349
+
+--S 350 of 600
+r0:=1/3*F^(a+b*(c+d*x)^3)/(b*d*log(F))
+--E 350
+
+--S 351 of 600
+d0:=normalize(t0-D(r0,x))
+--E 351
+
+)clear all
+
+--S 352 of 600
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)
+--E 352
+
+--S 353 of 600
+r0:=1/3*F^a*Ei(b*(c+d*x)^3*log(F))/d
+--E 353
+
+--S 354 of 600
+d0:=normalize(t0-D(r0,x))
+--E 354
+
+)clear all
+
+--S 355 of 600
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^4
+--E 355
+
+--S 356 of 600
+r0:=-1/3*F^(a+b*(c+d*x)^3)/(d*(c+d*x)^3)+1/3*b*F^a*Ei(b*(c+d*x)^3*_
+   log(F))*log(F)/d
+--E 356
+
+--S 357 of 600
+d0:=normalize(t0-D(r0,x))
+--E 357
+
+)clear all
+
+--S 358 of 600
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^7
+--E 358
+
+--S 359 of 600
+r0:=-1/6*F^(a+b*(c+d*x)^3)/(d*(c+d*x)^6)-1/6*b*F^(a+b*(c+d*x)^3)*_
+   log(F)/(d*(c+d*x)^3)+1/6*b^2*F^a*Ei(b*(c+d*x)^3*log(F))*log(F)^2/d
+--E 359
+
+--S 360 of 600
+d0:=normalize(t0-D(r0,x))
+--E 360
+
+)clear all
+
+--S 361 of 600
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^10
+--E 361
+
+--S 362 of 600
+r0:=-1/9*F^(a+b*(c+d*x)^3)/(d*(c+d*x)^9)-1/18*b*F^(a+b*(c+d*x)^3)*_
+   log(F)/(d*(c+d*x)^6)-1/18*b^2*F^(a+b*(c+d*x)^3)*log(F)^2/(d*(c+d*x)^3)+_
+   1/18*b^3*F^a*Ei(b*(c+d*x)^3*log(F))*log(F)^3/d
+--E 362
+
+--S 363 of 600
+d0:=normalize(t0-D(r0,x))
+--E 363
+
+)clear all
+
+--S 364 of 600
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^13
+--E 364
+
+--S 365 of 600
+--r0:=-1/3*b^4*F^a*GAMMA(-4,-b*(c+d*x)^3*log(F))*log(F)^4/d
+--E 365
+
+--S 366 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 366
+
+)clear all
+
+--S 367 of 600
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^16
+--E 367
+
+--S 368 of 600
+--r0:=1/3*b^5*F^a*GAMMA(-5,-b*(c+d*x)^3*log(F))*log(F)^5/d
+--E 368
+
+--S 369 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 369
+
+)clear all
+
+--S 370 of 600
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)^3
+--E 370
+
+--S 371 of 600
+--r0:=-1/3*F^a*(c+d*x)^4*GAMMA(4/3,-b*(c+d*x)^3*log(F))/(d*(-b*(c+d*x)^3*_
+--  log(F))^(4/3))
+--E 371
+
+--S 372 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 372
+
+)clear all
+
+--S 373 of 600
+t0:=F^(a+b*(c+d*x)^3)*(c+d*x)
+--E 373
+
+--S 374 of 600
+--r0:=-1/3*F^a*(c+d*x)^2*GAMMA(2/3,-b*(c+d*x)^3*log(F))/(d*(-b*(c+d*x)^3*_
+--  log(F))^(2/3))
+--E 374
+
+--S 375 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 375
+
+)clear all
+
+--S 376 of 600
+t0:=F^(a+b*(c+d*x)^3)
+--E 376
+
+--S 377 of 600
+--r0:=-1/3*F^a*(c+d*x)*GAMMA(1/3,-b*(c+d*x)^3*log(F))/(d*(-b*(c+d*x)^3*_
+--  log(F))^(1/3))
+--E 377
+
+--S 378 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 378
+
+)clear all
+
+--S 379 of 600
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^2
+--E 379
+
+--S 380 of 600
+--r0:=-1/3*F^a*GAMMA(-1/3,-b*(c+d*x)^3*log(F))*(-b*(c+d*x)^3*_
+--  log(F))^(1/3)/(d*(c+d*x))
+--E 380
+
+--S 381 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 381
+
+)clear all
+
+--S 382 of 600
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^3
+--E 382
+
+--S 383 of 600
+--r0:=-1/3*F^a*GAMMA(-2/3,-b*(c+d*x)^3*log(F))*(-b*(c+d*x)^3*_
+--  log(F))^(2/3)/(d*(c+d*x)^2)
+--E 383
+
+--S 384 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 384
+
+)clear all
+
+--S 385 of 600
+t0:=F^(a+b*(c+d*x)^3)/(c+d*x)^5
+--E 385
+
+--S 386 of 600
+--r0:=-1/3*F^a*GAMMA(-4/3,-b*(c+d*x)^3*log(F))*(-b*(c+d*x)^3*_
+--  log(F))^(4/3)/(d*(c+d*x)^4)
+--E 386
+
+--S 387 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 387
+
+)clear all
+
+--S 388 of 600
+t0:=f^(a+b*(c+d*x)^(1/2))
+--E 388
+
+--S 389 of 600
+r0:=-2*f^(a+b*sqrt(c+d*x))/(b^2*d*log(f)^2)+2*f^(a+b*sqrt(c+d*x))*_
+   sqrt(c+d*x)/(b*d*log(f))
+--E 389
+
+--S 390 of 600
+d0:=normalize(t0-D(r0,x))
+--E 390
+
+)clear all
+
+--S 391 of 600
+t0:=f^(a+b*(c+d*x)^(1/3))
+--E 391
+
+--S 392 of 600
+r0:=6*f^(a+b*(c+d*x)^(1/3))/(b^3*d*log(f)^3)-6*f^(a+b*(c+d*x)^(1/3))*_
+   (c+d*x)^(1/3)/(b^2*d*log(f)^2)+3*f^(a+b*(c+d*x)^(1/3))*(c+d*x)^(2/3)/_
+   (b*d*log(f))
+--E 392
+
+--S 393 of 600
+d0:=normalize(t0-D(r0,x))
+--E 393
+
+)clear all
+
+--S 394 of 600
+t0:=F^(a+b/(c+d*x))*(c+d*x)^m
+--E 394
+
+--S 395 of 600
+--r0:=F^a*(c+d*x)^(1+m)*GAMMA(-1-m,-b*log(F)/(c+d*x))*_
+--  (-b*log(F)/(c+d*x))^(1+m)/d
+--E 395
+
+--S 396 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 396
+
+)clear all
+
+--S 397 of 600
+t0:=F^(a+b/(c+d*x))*(c+d*x)^4
+--E 397
+
+--S 398 of 600
+--r0:=-b^5*F^a*GAMMA(-5,-b*log(F)/(c+d*x))*log(F)^5/d
+--E 398
+
+--S 399 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 399
+
+)clear all
+
+--S 400 of 600
+t0:=F^(a+b/(c+d*x))*(c+d*x)^3
+--E 400
+
+--S 401 of 600
+--r0:=b^4*F^a*GAMMA(-4,-b*log(F)/(c+d*x))*log(F)^4/d
+--E 401
+
+--S 402 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 402
+
+)clear all
+
+--S 403 of 600
+t0:=F^(a+b/(c+d*x))*(c+d*x)^2
+--E 403
+
+--S 404 of 600
+r0:=1/3*F^(a+b/(c+d*x))*(c+d*x)^3/d+1/6*b*F^(a+b/(c+d*x))*(c+d*x)^2*_
+  log(F)/d+1/6*b^2*F^(a+b/(c+d*x))*(c+d*x)*log(F)^2/d-1/6*b^3*F^a*_
+  Ei(b*log(F)/(c+d*x))*log(F)^3/d
+--E 404
+
+--S 405 of 600
+d0:=normalize(t0-D(r0,x))
+--E 405
+
+)clear all
+
+--S 406 of 600
+t0:=F^(a+b/(c+d*x))*(c+d*x)
+--E 406
+
+--S 407 of 600
+r0:=1/2*F^(a+b/(c+d*x))*(c+d*x)^2/d+1/2*b*F^(a+b/(c+d*x))*(c+d*x)*log(F)/d-_
+  1/2*b^2*F^a*Ei(b*log(F)/(c+d*x))*log(F)^2/d
+--E 407
+
+--S 408 of 600
+d0:=normalize(t0-D(r0,x))
+--E 408
+
+)clear all
+
+--S 409 of 600
+t0:=F^(a+b/(c+d*x))
+--E 409
+
+--S 410 of 600
+r0:=F^(a+b/(c+d*x))*(c+d*x)/d-b*F^a*Ei(b*log(F)/(c+d*x))*log(F)/d
+--E 410
+
+--S 411 of 600
+d0:=normalize(t0-D(r0,x))
+--E 411
+
+)clear all
+
+--S 412 of 600
+t0:=F^(a+b/(c+d*x))/(c+d*x)
+--E 412
+
+--S 413 of 600
+r0:=-F^a*Ei(b*log(F)/(c+d*x))/d
+--E 413
+
+--S 414 of 600
+d0:=normalize(t0-D(r0,x))
+--E 414
+
+)clear all
+
+--S 415 of 600
+t0:=F^(a+b/(c+d*x))/(c+d*x)^2
+--E 415
+
+--S 416 of 600
+r0:=-F^(a+b/(c+d*x))/(b*d*log(F))
+--E 416
+
+--S 417 of 600
+d0:=normalize(t0-D(r0,x))
+--E 417
+
+)clear all
+
+--S 418 of 600
+t0:=F^(a+b/(c+d*x))/(c+d*x)^3
+--E 418
+
+--S 419 of 600
+r0:=F^(a+b/(c+d*x))/(b^2*d*log(F)^2)-F^(a+b/(c+d*x))/(b*d*(c+d*x)*log(F))
+--E 419
+
+--S 420 of 600
+d0:=normalize(t0-D(r0,x))
+--E 420
+
+)clear all
+
+--S 421 of 600
+t0:=F^(a+b/(c+d*x))/(c+d*x)^4
+--E 421
+
+--S 422 of 600
+r0:=-2*F^(a+b/(c+d*x))/(b^3*d*log(F)^3)+2*F^(a+b/(c+d*x))/(b^2*d*(c+d*x)*_
+  log(F)^2)-F^(a+b/(c+d*x))/(b*d*(c+d*x)^2*log(F))
+--E 422
+
+--S 423 of 600
+d0:=normalize(t0-D(r0,x))
+--E 423
+
+)clear all
+
+--S 424 of 600
+t0:=F^(a+b/(c+d*x))/(c+d*x)^5
+--E 424
+
+--S 425 of 600
+r0:=6*F^(a+b/(c+d*x))/(b^4*d*log(F)^4)-6*F^(a+b/(c+d*x))/(b^3*d*(c+d*x)*_
+  log(F)^3)+3*F^(a+b/(c+d*x))/(b^2*d*(c+d*x)^2*log(F)^2)-_
+  F^(a+b/(c+d*x))/(b*d*(c+d*x)^3*log(F))
+--E 425
+
+--S 426 of 600
+d0:=normalize(t0-D(r0,x))
+--E 426
+
+)clear all
+
+--S 427 of 600
+t0:=F^(a+b/(c+d*x))/(c+d*x)^6
+--E 427
+
+--S 428 of 600
+--r0:=-F^a*GAMMA(5,-b*log(F)/(c+d*x))/(b^5*d*log(F)^5)
+--E 428
+
+--S 429 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 429
+
+)clear all
+
+--S 430 of 600
+t0:=F^(a+b/(c+d*x))/(c+d*x)^7
+--E 430
+
+--S 431 of 600
+--r0:=F^a*GAMMA(6,-b*log(F)/(c+d*x))/(b^6*d*log(F)^6)
+--E 431
+
+--S 432 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 432
+
+)clear all
+
+--S 433 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^m
+--E 433
+
+--S 434 of 600
+--r0:=1/2*F^a*(c+d*x)^(1+m)*GAMMA(1/2*(-1-m),-b*log(F)/(c+d*x)^2)*_
+--  (-b*log(F)/(c+d*x)^2)^(1/2*(1+m))/d
+--E 434
+
+--S 435 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 435
+
+)clear all
+
+--S 436 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^9
+--E 436
+
+--S 437 of 600
+--r0:=-1/2*b^5*F^a*GAMMA(-5,-b*log(F)/(c+d*x)^2)*log(F)^5/d
+--E 437
+
+--S 438 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 438
+
+)clear all
+
+--S 439 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^7
+--E 439
+
+--S 440 of 600
+--r0:=1/2*b^4*F^a*GAMMA(-4,-b*log(F)/(c+d*x)^2)*log(F)^4/d
+--E 440
+
+--S 441 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 441
+
+)clear all
+
+--S 442 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^5
+--E 442
+
+--S 443 of 600
+r0:=1/6*F^(a+b/(c+d*x)^2)*(c+d*x)^6/d+1/12*b*F^(a+b/(c+d*x)^2)*(c+d*x)^4*_
+   log(F)/d+1/12*b^2*F^(a+b/(c+d*x)^2)*(c+d*x)^2*log(F)^2/d-1/12*b^3*F^a*_
+   Ei(b*log(F)/(c+d*x)^2)*log(F)^3/d
+--E 443
+
+--S 444 of 600
+d0:=normalize(t0-D(r0,x))
+--E 444
+
+)clear all
+
+--S 445 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^3
+--E 445
+
+--S 446 of 600
+r0:=1/4*F^(a+b/(c+d*x)^2)*(c+d*x)^4/d+1/4*b*F^(a+b/(c+d*x)^2)*(c+d*x)^2*_
+   log(F)/d-1/4*b^2*F^a*Ei(b*log(F)/(c+d*x)^2)*log(F)^2/d
+--E 446
+
+--S 447 of 600
+d0:=normalize(t0-D(r0,x))
+--E 447
+
+)clear all
+
+--S 448 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)
+--E 448
+
+--S 449 of 600
+r0:=1/2*F^(a+b/(c+d*x)^2)*(c+d*x)^2/d-1/2*b*F^a*Ei(b*log(F)/(c+d*x)^2)*log(F)/d
+--E 449
+
+--S 450 of 600
+d0:=normalize(t0-D(r0,x))
+--E 450
+
+)clear all
+
+--S 451 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)
+--E 451
+
+--S 452 of 600
+r0:=-1/2*F^a*Ei(b*log(F)/(c+d*x)^2)/d
+--E 452
+
+--S 453 of 600
+d0:=normalize(t0-D(r0,x))
+--E 453
+
+)clear all
+
+--S 454 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^3
+--E 454
+
+--S 455 of 600
+r0:=-1/2*F^(a+b/(c+d*x)^2)/(b*d*log(F))
+--E 455
+
+--S 456 of 600
+d0:=normalize(t0-D(r0,x))
+--E 456
+
+)clear all
+
+--S 457 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^5
+--E 457
+
+--S 458 of 600
+r0:=1/2*F^(a+b/(c+d*x)^2)/(b^2*d*log(F)^2)-1/2*F^(a+b/(c+d*x)^2)/_
+   (b*d*(c+d*x)^2*log(F))
+--E 458
+
+--S 459 of 600
+d0:=normalize(t0-D(r0,x))
+--E 459
+
+)clear all
+
+--S 460 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^7
+--E 460
+
+--S 461 of 600
+r0:=-F^(a+b/(c+d*x)^2)/(b^3*d*log(F)^3)+F^(a+b/(c+d*x)^2)/(b^2*d*(c+d*x)^2*_
+   log(F)^2)-1/2*F^(a+b/(c+d*x)^2)/(b*d*(c+d*x)^4*log(F))
+--E 461
+
+--S 462 of 600
+d0:=normalize(t0-D(r0,x))
+--E 462
+
+)clear all
+
+--S 463 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^9
+--E 463
+
+--S 464 of 600
+r0:=3*F^(a+b/(c+d*x)^2)/(b^4*d*log(F)^4)-3*F^(a+b/(c+d*x)^2)/(b^3*d*_
+   (c+d*x)^2*log(F)^3)+3/2*F^(a+b/(c+d*x)^2)/(b^2*d*(c+d*x)^4*log(F)^2)-_
+   1/2*F^(a+b/(c+d*x)^2)/(b*d*(c+d*x)^6*log(F))
+--E 464
+
+--S 465 of 600
+d0:=normalize(t0-D(r0,x))
+--E 465
+
+)clear all
+
+--S 466 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^11
+--E 466
+
+--S 467 of 600
+--r0:=-1/2*F^a*GAMMA(5,-b*log(F)/(c+d*x)^2)/(b^5*d*log(F)^5)
+--E 467
+
+--S 468 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 468
+
+)clear all
+
+--S 469 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^13
+--E 469
+
+--S 470 of 600
+--r0:=1/2*F^a*GAMMA(6,-b*log(F)/(c+d*x)^2)/(b^6*d*log(F)^6)
+--E 470
+
+--S 471 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 471
+
+)clear all
+
+--S 472 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^10
+--E 472
+
+--S 473 of 600
+--r0:=1/2*F^a*(c+d*x)^11*GAMMA(-11/2,-b*log(F)/(c+d*x)^2)*_
+--  (-b*log(F)/(c+d*x)^2)^(11/2)/d
+--E 473
+
+--S 474 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 474
+
+)clear all
+
+--S 475 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^8
+--E 475
+
+--S 476 of 600
+--r0:=1/2*F^a*(c+d*x)^9*GAMMA(-9/2,-b*log(F)/(c+d*x)^2)*_
+--  (-b*log(F)/(c+d*x)^2)^(9/2)/d
+--E 476
+
+--S 477 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 477
+
+)clear all
+
+--S 478 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^6
+--E 478
+
+--S 479 of 600
+--r0:=1/7*F^(a+b/(c+d*x)^2)*(c+d*x)^7/d+2/35*b*F^(a+b/(c+d*x)^2)*(c+d*x)^5*_
+--  log(F)/d+4/105*b^2*F^(a+b/(c+d*x)^2)*(c+d*x)^3*log(F)^2/d+8/105*b^3*_
+--  F^(a+b/(c+d*x)^2)*(c+d*x)*log(F)^3/d-8/105*b^(7/2)*F^a*_
+--  erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*log(F)^(7/2)*sqrt(%pi)/d
+--E 479
+
+--S 480 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 480
+
+)clear all
+
+--S 481 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^4
+--E 481
+
+--S 482 of 600
+--r0:=1/5*F^(a+b/(c+d*x)^2)*(c+d*x)^5/d+2/15*b*F^(a+b/(c+d*x)^2)*(c+d*x)^3*_
+--  log(F)/d+4/15*b^2*F^(a+b/(c+d*x)^2)*(c+d*x)*log(F)^2/d-4/15*b^(5/2)*_
+--  F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*log(F)^(5/2)*sqrt(%pi)/d
+--E 482
+
+--S 483 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 483
+
+)clear all
+
+--S 484 of 600
+t0:=F^(a+b/(c+d*x)^2)*(c+d*x)^2
+--E 484
+
+--S 485 of 600
+--r0:=1/3*F^(a+b/(c+d*x)^2)*(c+d*x)^3/d+2/3*b*F^(a+b/(c+d*x)^2)*(c+d*x)*_
+--  log(F)/d-2/3*b^(3/2)*F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*_
+--  log(F)^(3/2)*sqrt(%pi)/d
+--E 485
+
+--S 486 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 486
+
+)clear all
+
+--S 487 of 600
+t0:=F^(a+b/(c+d*x)^2)
+--E 487
+
+--S 488 of 600
+--r0:=F^(a+b/(c+d*x)^2)*(c+d*x)/d-F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*_
+--  sqrt(%pi)*sqrt(b)*sqrt(log(F))/d
+--E 488
+
+--S 489 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 489
+
+)clear all
+
+--S 490 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^2
+--E 490
+
+--S 491 of 600
+--r0:=-1/2*F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*sqrt(%pi)/(d*sqrt(b)*_
+--  sqrt(log(F)))
+--E 491
+
+--S 492 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 492
+
+)clear all
+
+--S 493 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^4
+--E 493
+
+--S 494 of 600
+--r0:=-1/2*F^(a+b/(c+d*x)^2)/(b*d*(c+d*x)*log(F))+1/4*F^a*erfi(sqrt(b)*_
+--  sqrt(log(F))/(c+d*x))*sqrt(%pi)/(b^(3/2)*d*log(F)^(3/2))
+--E 494
+
+--S 495 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 495
+
+)clear all
+
+--S 496 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^6
+--E 496
+
+--S 497 of 600
+--r0:=3/4*F^(a+b/(c+d*x)^2)/(b^2*d*(c+d*x)*log(F)^2)-1/2*F^(a+b/(c+d*x)^2)/_
+--  (b*d*(c+d*x)^3*log(F))-3/8*F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*_
+--  sqrt(%pi)/(b^(5/2)*d*log(F)^(5/2))
+--E 497
+
+--S 498 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 498
+
+)clear all
+
+--S 499 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^8
+--E 499
+
+--S 500 of 600
+--r0:=-15/8*F^(a+b/(c+d*x)^2)/(b^3*d*(c+d*x)*log(F)^3)+5/4*_
+--  F^(a+b/(c+d*x)^2)/(b^2*d*(c+d*x)^3*log(F)^2)-1/2*F^(a+b/(c+d*x)^2)/_
+--  (b*d*(c+d*x)^5*log(F))+15/16*F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*_
+--  sqrt(%pi)/(b^(7/2)*d*log(F)^(7/2))
+--E 500
+
+--S 501 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 501
+
+)clear all
+
+--S 502 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^10
+--E 502
+
+--S 503 of 600
+--r0:=105/16*F^(a+b/(c+d*x)^2)/(b^4*d*(c+d*x)*log(F)^4)-35/8*_
+--  F^(a+b/(c+d*x)^2)/(b^3*d*(c+d*x)^3*log(F)^3)+7/4*F^(a+b/(c+d*x)^2)/_
+--  (b^2*d*(c+d*x)^5*log(F)^2)-1/2*F^(a+b/(c+d*x)^2)/(b*d*(c+d*x)^7*_
+--  log(F))-105/32*F^a*erfi(sqrt(b)*sqrt(log(F))/(c+d*x))*sqrt(%pi)/_
+--  (b^(9/2)*d*log(F)^(9/2))
+--E 503
+
+--S 504 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 504
+
+)clear all
+
+--S 505 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^12
+--E 505
+
+--S 506 of 600
+--r0:=1/2*F^a*GAMMA(11/2,-b*log(F)/(c+d*x)^2)/(d*(c+d*x)^11*_
+--  (-b*log(F)/(c+d*x)^2)^(11/2))
+--E 506
+
+--S 507 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 507
+
+)clear all
+
+--S 508 of 600
+t0:=F^(a+b/(c+d*x)^2)/(c+d*x)^14
+--E 508
+
+--S 509 of 600
+--r0:=1/2*F^a*GAMMA(13/2,-b*log(F)/(c+d*x)^2)/(d*(c+d*x)^13*_
+--  (-b*log(F)/(c+d*x)^2)^(13/2))
+--E 509
+
+--S 510 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 510
+
+)clear all
+
+--S 511 of 600
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^m
+--E 511
+
+--S 512 of 600
+--r0:=1/3*F^a*(c+d*x)^(1+m)*GAMMA(1/3*(-1-m),-b*log(F)/(c+d*x)^3)*_
+--  (-b*log(F)/(c+d*x)^3)^(1/3*(1+m))/d
+--E 512
+
+--S 513 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 513
+
+)clear all
+
+--S 514 of 600
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^14
+--E 514
+
+--S 515 of 600
+--r0:=-1/3*b^5*F^a*GAMMA(-5,-b*log(F)/(c+d*x)^3)*log(F)^5/d
+--E 515
+
+--S 516 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 516
+
+)clear all
+
+--S 517 of 600
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^11
+--E 517
+
+--S 518 of 600
+--r0:=1/3*b^4*F^a*GAMMA(-4,-b*log(F)/(c+d*x)^3)*log(F)^4/d
+--E 518
+
+--S 519 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 519
+
+)clear all
+
+--S 520 of 600
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^8
+--E 520
+
+--S 521 of 600
+r0:=1/9*F^(a+b/(c+d*x)^3)*(c+d*x)^9/d+1/18*b*F^(a+b/(c+d*x)^3)*(c+d*x)^6*_
+   log(F)/d+1/18*b^2*F^(a+b/(c+d*x)^3)*(c+d*x)^3*log(F)^2/d-1/18*b^3*F^a*_
+   Ei(b*log(F)/(c+d*x)^3)*log(F)^3/d
+--E 521
+
+--S 522 of 600
+d0:=normalize(t0-D(r0,x))
+--E 522
+
+)clear all
+
+--S 523 of 600
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^5
+--E 523
+
+--S 524 of 600
+r0:=1/6*F^(a+b/(c+d*x)^3)*(c+d*x)^6/d+1/6*b*F^(a+b/(c+d*x)^3)*(c+d*x)^3*_
+    log(F)/d-1/6*b^2*F^a*Ei(b*log(F)/(c+d*x)^3)*log(F)^2/d
+--E 524
+
+--S 525 of 600
+d0:=normalize(t0-D(r0,x))
+--E 525
+
+)clear all
+
+--S 526 of 600
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^2
+--E 526
+
+--S 527 of 600
+r0:=1/3*F^(a+b/(c+d*x)^3)*(c+d*x)^3/d-1/3*b*F^a*Ei(b*log(F)/(c+d*x)^3)*log(F)/d
+--E 527
+
+--S 528 of 600
+d0:=normalize(t0-D(r0,x))
+--E 528
+
+)clear all
+
+--S 529 of 600
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)
+--E 529
+
+--S 530 of 600
+r0:=-1/3*F^a*Ei(b*log(F)/(c+d*x)^3)/d
+--E 530
+
+--S 531 of 600
+d0:=normalize(t0-D(r0,x))
+--E 531
+
+)clear all
+
+--S 532 of 600
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^4
+--E 532
+
+--S 533 of 600
+r0:=-1/3*F^(a+b/(c+d*x)^3)/(b*d*log(F))
+--E 533
+
+--S 534 of 600
+d0:=normalize(t0-D(r0,x))
+--E 534
+
+)clear all
+
+--S 535 of 600
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^7
+--E 535
+
+--S 536 of 600
+r0:=1/3*F^(a+b/(c+d*x)^3)/(b^2*d*log(F)^2)-1/3*F^(a+b/(c+d*x)^3)/_
+   (b*d*(c+d*x)^3*log(F))
+--E 536
+
+--S 537 of 600
+d0:=normalize(t0-D(r0,x))
+--E 537
+
+)clear all
+
+--S 538 of 600
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^10
+--E 538
+
+--S 539 of 600
+r0:=-2/3*F^(a+b/(c+d*x)^3)/(b^3*d*log(F)^3)+2/3*F^(a+b/(c+d*x)^3)/(b^2*d*_
+   (c+d*x)^3*log(F)^2)-1/3*F^(a+b/(c+d*x)^3)/(b*d*(c+d*x)^6*log(F))
+--E 539
+
+--S 540 of 600
+d0:=normalize(t0-D(r0,x))
+--E 540
+
+)clear all
+
+--S 541 of 600
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^13
+--E 541
+
+--S 542 of 600
+r0:=2*F^(a+b/(c+d*x)^3)/(b^4*d*log(F)^4)-2*F^(a+b/(c+d*x)^3)/(b^3*d*_
+   (c+d*x)^3*log(F)^3)+F^(a+b/(c+d*x)^3)/(b^2*d*(c+d*x)^6*log(F)^2)-_
+   1/3*F^(a+b/(c+d*x)^3)/(b*d*(c+d*x)^9*log(F))
+--E 542
+
+--S 543 of 600
+d0:=normalize(t0-D(r0,x))
+--E 543
+
+)clear all
+
+--S 544 of 600
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^16
+--E 544
+
+--S 545 of 600
+--r0:=-1/3*F^a*GAMMA(5,-b*log(F)/(c+d*x)^3)/(b^5*d*log(F)^5)
+--E 545
+
+--S 546 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 546
+
+)clear all
+
+--S 547 of 600
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^19
+--E 547
+
+--S 548 of 600
+--r0:=1/3*F^a*GAMMA(6,-b*log(F)/(c+d*x)^3)/(b^6*d*log(F)^6)
+--E 548
+
+--S 549 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 549
+
+)clear all
+
+--S 550 of 600
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)^3
+--E 550
+
+--S 551 of 600
+--r0:=1/3*F^a*(c+d*x)^4*GAMMA(-4/3,-b*log(F)/(c+d*x)^3)*(-b*log(F)/_
+--  (c+d*x)^3)^(4/3)/d
+--E 551
+
+--S 552 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 552
+
+)clear all
+
+--S 553 of 600
+t0:=F^(a+b/(c+d*x)^3)*(c+d*x)
+--E 553
+
+--S 554 of 600
+--r0:=1/3*F^a*(c+d*x)^2*GAMMA(-2/3,-b*log(F)/(c+d*x)^3)*(-b*log(F)/_
+--  (c+d*x)^3)^(2/3)/d
+--E 554
+
+--S 555 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 555
+
+)clear all
+
+--S 556 of 600
+t0:=F^(a+b/(c+d*x)^3)
+--E 556
+
+--S 557 of 600
+--r0:=1/3*F^a*(c+d*x)*GAMMA(-1/3,-b*log(F)/(c+d*x)^3)*(-b*log(F)/_
+--  (c+d*x)^3)^(1/3)/d
+--E 557
+
+--S 558 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 558
+
+)clear all
+
+--S 559 of 600
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^2
+--E 559
+
+--S 560 of 600
+--r0:=1/3*F^a*GAMMA(1/3,-b*log(F)/(c+d*x)^3)/(d*(c+d*x)*(-b*log(F)/_
+--  (c+d*x)^3)^(1/3))
+--E 560
+
+--S 561 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 561
+
+)clear all
+
+--S 562 of 600
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^3
+--E 562
+
+--S 563 of 600
+--r0:=1/3*F^a*GAMMA(2/3,-b*log(F)/(c+d*x)^3)/(d*(c+d*x)^2*(-b*log(F)/_
+--  (c+d*x)^3)^(2/3))
+--E 563
+
+--S 564 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 564
+
+)clear all
+
+--S 565 of 600
+t0:=F^(a+b/(c+d*x)^3)/(c+d*x)^5
+--E 565
+
+--S 566 of 600
+--r0:=1/3*F^a*GAMMA(4/3,-b*log(F)/(c+d*x)^3)/(d*(c+d*x)^4*(-b*log(F)/_
+--  (c+d*x)^3)^(4/3))
+--E 566
+
+--S 567 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 567
+
+)clear all
+
+--S 568 of 600
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^m
+--E 568
+
+--S 569 of 600
+--r0:=-F^a*(c+d*x)^(1+m)*GAMMA((1+m)/n,-b*(c+d*x)^n*log(F))/_
+--  (d*n*(-b*(c+d*x)^n*log(F))^((1+m)/n))
+--E 569
+
+--S 570 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 570
+
+)clear all
+
+--S 571 of 600
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^3
+--E 571
+
+--S 572 of 600
+--r0:=-F^a*(c+d*x)^4*GAMMA(4/n,-b*(c+d*x)^n*log(F))/_
+--  (d*n*(-b*(c+d*x)^n*log(F))^(4/n))
+--E 572
+
+--S 573 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 573
+
+)clear all
+
+--S 574 of 600
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^2
+--E 574
+
+--S 575 of 600
+--r0:=-F^a*(c+d*x)^3*GAMMA(3/n,-b*(c+d*x)^n*log(F))/_
+--  (d*n*(-b*(c+d*x)^n*log(F))^(3/n))
+--E 575
+
+--S 576 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 576
+
+)clear all
+
+--S 577 of 600
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)
+--E 577
+
+--S 578 of 600
+--r0:=-F^a*(c+d*x)^2*GAMMA(2/n,-b*(c+d*x)^n*log(F))/_
+--  (d*n*(-b*(c+d*x)^n*log(F))^(2/n))
+--E 578
+
+--S 579 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 579
+
+)clear all
+
+--S 580 of 600
+t0:=F^(a+b*(c+d*x)^n)
+--E 580
+
+--S 581 of 600
+--r0:=-F^a*(c+d*x)*GAMMA(1/n,-b*(c+d*x)^n*log(F))/_
+--  (d*n*(-b*(c+d*x)^n*log(F))^(1/n))
+--E 581
+
+--S 582 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 582
+
+)clear all
+
+--S 583 of 600
+t0:=F^(a+b*(c+d*x)^n)/(c+d*x)
+--E 583
+
+--S 584 of 600
+r0:=F^a*Ei(b*(c+d*x)^n*log(F))/(d*n)
+--E 584
+
+--S 585 of 600
+d0:=normalize(t0-D(r0,x))
+--E 585
+
+)clear all
+
+--S 586 of 600
+t0:=F^(a+b*(c+d*x)^n)/(c+d*x)^2
+--E 586
+
+--S 587 of 600
+--r0:=-F^a*GAMMA((-1)/n,-b*(c+d*x)^n*log(F))*(-b*(c+d*x)^n*_
+--  log(F))^(1/n)/(d*n*(c+d*x))
+--E 587
+
+--S 588 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 588
+
+)clear all
+
+--S 589 of 600
+t0:=F^(a+b*(c+d*x)^n)/(c+d*x)^3
+--E 589
+
+--S 590 of 600
+--r0:=-F^a*GAMMA((-2)/n,-b*(c+d*x)^n*log(F))*(-b*(c+d*x)^n*_
+--  log(F))^(2/n)/(d*n*(c+d*x)^2)
+--E 590
+
+--S 591 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 591
+
+)clear all
+
+--S 592 of 600
+t0:=F^(a+b*(c+d*x)^n)/(c+d*x)^4
+--E 592
+
+--S 593 of 600
+--r0:=-F^a*GAMMA((-3)/n,-b*(c+d*x)^n*log(F))*(-b*(c+d*x)^n*_
+--  log(F))^(3/n)/(d*n*(c+d*x)^3)
+--E 593
+
+--S 594 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 594
+
+)clear all
+
+--S 595 of 600
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+6*n)
+--E 595
+
+--S 596 of 600
+--r0:=-F^a*GAMMA(6,-b*(c+d*x)^n*log(F))/(b^6*d*n*log(F)^6)
+--E 596
+
+--S 597 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 597
+
+)clear all
+
+--S 598 of 600
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+5*n)
+--E 598
+
+--S 599 of 600
+--r0:=F^a*GAMMA(5,-b*(c+d*x)^n*log(F))/(b^5*d*n*log(F)^5)
+--E 599
+
+--S 600 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 600
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder24c.input.pamphlet b/src/input/richder24c.input.pamphlet
new file mode 100644
index 0000000..bfc6ecd
--- /dev/null
+++ b/src/input/richder24c.input.pamphlet
@@ -0,0 +1,3129 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder24c.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Exponential Functions
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder24c.output
+)spool richder24c.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 602
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+4*n)
+--E 1
+
+--S 2 of 602
+r0:=-6*F^(a+b*(c+d*x)^n)/(b^4*d*n*log(F)^4)+6*F^(a+b*(c+d*x)^n)*_
+   (c+d*x)^n/(b^3*d*n*log(F)^3)-3*F^(a+b*(c+d*x)^n)*(c+d*x)^(2*n)/_
+   (b^2*d*n*log(F)^2)+F^(a+b*(c+d*x)^n)*(c+d*x)^(3*n)/(b*d*n*log(F))
+--E 2
+
+--S 3 of 602
+d0:=normalize(D(m0,x))
+--E 3
+
+)clear all
+
+--S 4 of 602
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+3*n)
+--E 4
+
+--S 5 of 602
+r0:=2*F^(a+b*(c+d*x)^n)/(b^3*d*n*log(F)^3)-2*F^(a+b*(c+d*x)^n)*(c+d*x)^n/_
+   (b^2*d*n*log(F)^2)+F^(a+b*(c+d*x)^n)*(c+d*x)^(2*n)/(b*d*n*log(F))
+--E 5
+
+--S 6 of 602
+d0:=normalize(D(m0,x))
+--E 6
+
+)clear all
+
+--S 7 of 602
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+2*n)
+--E 7
+
+--S 8 of 602
+r0:=-F^(a+b*(c+d*x)^n)/(b^2*d*n*log(F)^2)+F^(a+b*(c+d*x)^n)*(c+d*x)^n/_
+   (b*d*n*log(F))
+--E 8
+
+--S 9 of 602
+d0:=normalize(D(m0,x))
+--E 9
+
+)clear all
+
+--S 10 of 602
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1+n)
+--E 10
+
+--S 11 of 602
+r0:=F^(a+b*(c+d*x)^n)/(b*d*n*log(F))
+--E 11
+
+--S 12 of 602
+d0:=normalize(D(m0,x))
+--E 12
+
+)clear all
+
+--S 13 of 602
+t0:=F^(a+b*(c+d*x)^n)/(c+d*x)
+--E 13
+
+--S 14 of 602
+--r0:=F^a*Ei(b*(c+d*x)^n*log(F))/(d*n)
+--E 14
+
+--S 15 of 602
+--d0:=normalize(D(m0,x))
+--E 15
+
+)clear all
+
+--S 16 of 602
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1-n)
+--E 16
+
+--S 17 of 602
+--r0:=-F^(a+b*(c+d*x)^n)/(d*n*(c+d*x)^n)+b*F^a*Ei(b*(c+d*x)^n*log(F))*_
+--   log(F)/(d*n)
+--E 17
+
+--S 18 of 602
+--d0:=normalize(D(m0,x))
+--E 18
+
+)clear all
+
+--S 19 of 602
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1-2*n)
+--E 19
+
+--S 20 of 602
+--r0:=-1/2*F^(a+b*(c+d*x)^n)/(d*n*(c+d*x)^(2*n))-1/2*b*F^(a+b*(c+d*x)^n)*_
+--   log(F)/(d*n*(c+d*x)^n)+1/2*b^2*F^a*Ei(b*(c+d*x)^n*log(F))*log(F)^2/(d*n)
+--E 20
+
+--S 21 of 602
+--d0:=normalize(D(m0,x))
+--E 21
+
+)clear all
+
+--S 22 of 602
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1-3*n)
+--E 22
+
+--S 23 of 602
+--r0:=-1/3*F^(a+b*(c+d*x)^n)/(d*n*(c+d*x)^(3*n))-1/6*b*F^(a+b*(c+d*x)^n)*_
+--   log(F)/(d*n*(c+d*x)^(2*n))-1/6*b^2*F^(a+b*(c+d*x)^n)*log(F)^2/_
+--   (d*n*(c+d*x)^n)+1/6*b^3*F^a*Ei(b*(c+d*x)^n*log(F))*log(F)^3/(d*n)
+--E 23
+
+--S 24 of 602
+--d0:=normalize(D(m0,x))
+--E 24
+
+)clear all
+
+--S 25 of 602
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1-4*n)
+--E 25
+
+--S 26 of 602
+--r0:=-b^4*F^a*GAMMA(-4,-b*(c+d*x)^n*log(F))*log(F)^4/(d*n)
+--E 26
+
+--S 27 of 602
+--d0:=normalize(D(m0,x))
+--E 27
+
+)clear all
+
+--S 28 of 602
+t0:=F^(a+b*(c+d*x)^n)*(c+d*x)^(-1-5*n)
+--E 28
+
+--S 29 of 602
+--r0:=b^5*F^a*GAMMA(-5,-b*(c+d*x)^n*log(F))*log(F)^5/(d*n)
+--E 29
+
+--S 30 of 602
+--d0:=normalize(D(m0,x))
+--E 30
+
+)clear all
+
+--S 31 of 602
+t0:=F^(c*(a+b*x)^n)*(a+b*x)^(-1+1/2*n)
+--E 31
+
+--S 32 of 602
+--r0:=erfi((a+b*x)^(1/2*n)*sqrt(c)*sqrt(log(F)))*sqrt(%pi)/(b*n*sqrt(c)*_
+--   sqrt(log(F)))
+--E 32
+
+--S 33 of 602
+--d0:=normalize(D(m0,x))
+--E 33
+
+)clear all
+
+--S 34 of 602
+t0:=(a+b*x)^(-1+1/2*n)/F^(c*(a+b*x)^n)
+--E 34
+
+--S 35 of 602
+--r0:=erf((a+b*x)^(1/2*n)*sqrt(c)*sqrt(log(F)))*sqrt(%pi)/(b*n*sqrt(c)*_
+--   sqrt(log(F)))
+--E 35
+
+--S 36 of 602
+--d0:=normalize(D(m0,x))
+--E 36
+
+)clear all
+
+--S 37 of 602
+t0:=F^(a+b*(c+d*x)^2)*(e+f*x)^5
+--E 37
+
+--S 38 of 602
+--r0:=f^5*F^(a+b*(c+d*x)^2)/(b^3*d^6*log(F)^3)-5*f^3*(d*e-c*f)^2*F^(a+b*_
+--   (c+d*x)^2)/(b^2*d^6*log(F)^2)-15/4*f^4*(d*e-c*f)*F^(a+b*(c+d*x)^2)*_
+--   (c+d*x)/(b^2*d^6*log(F)^2)-f^5*F^(a+b*(c+d*x)^2)*(c+d*x)^2/(b^2*d^6*_
+--   log(F)^2)+5/2*f*(d*e-c*f)^4*F^(a+b*(c+d*x)^2)/(b*d^6*log(F))+5*f^2*_
+--   (d*e-c*f)^3*F^(a+b*(c+d*x)^2)*(c+d*x)/(b*d^6*log(F))+5*f^3*_
+--   (d*e-c*f)^2*F^(a+b*(c+d*x)^2)*(c+d*x)^2/(b*d^6*log(F))+5/2*f^4*_
+--   (d*e-c*f)*F^(a+b*(c+d*x)^2)*(c+d*x)^3/(b*d^6*log(F))+1/2*f^5*F^(a+_
+--   b*(c+d*x)^2)*(c+d*x)^4/(b*d^6*log(F))+15/8*f^4*(d*e-c*f)*F^a*_
+--   erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(b^(5/2)*d^6*_
+--   log(F)^(5/2))-5/2*f^2*(d*e-c*f)^3*F^a*erfi((c+d*x)*sqrt(b)*_
+--   sqrt(log(F)))*sqrt(%pi)/(b^(3/2)*d^6*log(F)^(3/2))+1/2*(d*e-c*f)^5*_
+--   F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(d^6*sqrt(b)*_
+--   sqrt(log(F)))
+--E 38
+
+--S 39 of 602
+--d0:=normalize(D(m0,x))
+--E 39
+
+)clear all
+
+--S 40 of 602
+t0:=F^(a+b*(c+d*x)^2)*(e+f*x)^4
+--E 40
+
+--S 41 of 602
+--r0:=-2*f^3*(d*e-c*f)*F^(a+b*(c+d*x)^2)/(b^2*d^5*log(F)^2)-3/4*f^4*_
+--   F^(a+b*(c+d*x)^2)*(c+d*x)/(b^2*d^5*log(F)^2)+2*f*(d*e-c*f)^3*_
+--   F^(a+b*(c+d*x)^2)/(b*d^5*log(F))+3*f^2*(d*e-c*f)^2*F^(a+b*(c+d*_
+--   x)^2)*(c+d*x)/(b*d^5*log(F))+2*f^3*(d*e-c*f)*F^(a+b*(c+d*x)^2)*_
+--   (c+d*x)^2/(b*d^5*log(F))+1/2*f^4*F^(a+b*(c+d*x)^2)*(c+d*x)^3/_
+--   (b*d^5*log(F))+3/8*f^4*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*_
+--   sqrt(%pi)/(b^(5/2)*d^5*log(F)^(5/2))-3/2*f^2*(d*e-c*f)^2*F^a*_
+--   erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(b^(3/2)*d^5*_
+--   log(F)^(3/2))+1/2*(d*e-c*f)^4*F^a*erfi((c+d*x)*sqrt(b)*_
+--   sqrt(log(F)))*sqrt(%pi)/(d^5*sqrt(b)*sqrt(log(F)))
+--E 41
+
+--S 42 of 602
+--d0:=normalize(D(m0,x))
+--E 42
+
+)clear all
+
+--S 43 of 602
+t0:=F^(a+b*(c+d*x)^2)*(e+f*x)^3
+--E 43
+
+--S 44 of 602
+--r0:=-1/2*f^3*F^(a+b*(c+d*x)^2)/(b^2*d^4*log(F)^2)+3/2*f*(d*e-c*f)^2*_
+--   F^(a+b*(c+d*x)^2)/(b*d^4*log(F))+3/2*f^2*(d*e-c*f)*F^(a+b*(c+d*x)^2)*_
+--   (c+d*x)/(b*d^4*log(F))+1/2*f^3*F^(a+b*(c+d*x)^2)*(c+d*x)^2/(b*d^4*_
+--   log(F))-3/4*f^2*(d*e-c*f)*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*_
+--   sqrt(%pi)/(b^(3/2)*d^4*log(F)^(3/2))+1/2*(d*e-c*f)^3*F^a*_
+--   erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(d^4*sqrt(b)*sqrt(log(F)))
+--E 44
+
+--S 45 of 602
+--d0:=normalize(D(m0,x))
+--E 45
+
+)clear all
+
+--S 46 of 602
+t0:=F^(a+b*(c+d*x)^2)*(e+f*x)^2
+--E 46
+
+--S 47 of 602
+--r0:=f*(d*e-c*f)*F^(a+b*(c+d*x)^2)/(b*d^3*log(F))+1/2*f^2*F^(a+b*(c+_
+--   d*x)^2)*(c+d*x)/(b*d^3*log(F))-1/4*f^2*F^a*erfi((c+d*x)*sqrt(b)*_
+--   sqrt(log(F)))*sqrt(%pi)/(b^(3/2)*d^3*log(F)^(3/2))+1/2*(d*e-c*f)^2*_
+--   F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(d^3*sqrt(b)*_
+--   sqrt(log(F)))
+--E 47
+
+--S 48 of 602
+--d0:=normalize(D(m0,x))
+--E 48
+
+)clear all
+
+--S 49 of 602
+t0:=F^(a+b*(c+d*x)^2)*(e+f*x)
+--E 49
+
+--S 50 of 602
+--r0:=1/2*f*F^(a+b*(c+d*x)^2)/(b*d^2*log(F))+1/2*(d*e-c*f)*F^a*_
+--   erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(d^2*sqrt(b)*sqrt(log(F)))
+--E 50
+
+--S 51 of 602
+--d0:=normalize(D(m0,x))
+--E 51
+
+)clear all
+
+--S 52 of 602
+t0:=F^(a+b*(c+d*x)^2)
+--E 52
+
+--S 53 of 602
+--r0:=1/2*F^a*erfi((c+d*x)*sqrt(b)*sqrt(log(F)))*sqrt(%pi)/(d*sqrt(b)*_
+--   sqrt(log(F)))
+--E 53
+
+--S 54 of 602
+--d0:=normalize(D(m0,x))
+--E 54
+
+)clear all
+
+--S 55 of 602
+t0:=F^(a+b*(c+d*x)^2)/(e+f*x)
+--E 55
+
+--S 56 of 602
+--r0:=Int(F^(a+b*(c+d*x)^2)/(e+f*x),x)
+--E 56
+
+--S 57 of 602
+--d0:=normalize(D(m0,x))
+--E 57
+
+)clear all
+
+--S 58 of 602
+t0:=F^(a+b*(c+d*x)^2)/(e+f*x)^2
+--E 58
+
+--S 59 of 602
+--r0:=-F^(a+b*(c+d*x)^2)/(f*(e+f*x))+d*F^a*erfi((c+d*x)*sqrt(b)*_
+--   sqrt(log(F)))*sqrt(%pi)*sqrt(b)*sqrt(log(F))/f^2-2*b*d*(d*e-c*f)*_
+--   log(F)*Int(F^(a+b*(c+d*x)^2)/(e+f*x),x)/f^2
+--E 59
+
+--S 60 of 602
+--d0:=normalize(D(m0,x))
+--E 60
+
+)clear all
+
+--S 61 of 602
+t0:=F^(a+b*(c+d*x)^2)/(e+f*x)^3
+--E 61
+
+--S 62 of 602
+--r0:=-1/2*F^(a+b*(c+d*x)^2)/(f*(e+f*x)^2)+b*d*(d*e-c*f)*F^(a+b*(c+d*x)^2)*_
+--   log(F)/(f^3*(e+f*x))-b^(3/2)*d^2*(d*e-c*f)*F^a*erfi((c+d*x)*sqrt(b)*_
+--   sqrt(log(F)))*log(F)^(3/2)*sqrt(%pi)/f^4+b*d^2*log(F)*Int(F^(a+b*_
+--   (c+d*x)^2)/(e+f*x),x)/f^2+2*b^2*d^2*(d*e-c*f)^2*log(F)^2*Int(F^(a+_
+--   b*(c+d*x)^2)/(e+f*x),x)/f^4
+--E 62
+
+--S 63 of 602
+--d0:=normalize(D(m0,x))
+--E 63
+
+)clear all
+
+--S 64 of 602
+t0:=%e^(e*(c+d*x)^3)*(a+b*x)^3
+--E 64
+
+--S 65 of 602
+--r0:=-%e^(e*(c+d*x)^3)*b^2*(b*c-a*d)/(d^4*e)+1/3*(b*c-a*d)^3*(c+d*x)*_
+--   GAMMA(1/3,-e*(c+d*x)^3)/(d^4*(-e*(c+d*x)^3)^(1/3))-b*(b*c-a*d)^2*_
+--   (c+d*x)^2*GAMMA(2/3,-e*(c+d*x)^3)/(d^4*(-e*(c+d*x)^3)^(2/3))-_
+--   1/3*b^3*(c+d*x)^4*GAMMA(4/3,-e*(c+d*x)^3)/(d^4*(-e*(c+d*x)^3)^(4/3))
+--E 65
+
+--S 66 of 602
+--d0:=normalize(D(m0,x))
+--E 66
+
+)clear all
+
+--S 67 of 602
+t0:=%e^(e*(c+d*x)^3)*(a+b*x)^2
+--E 67
+
+--S 68 of 602
+--r0:=1/3*%e^(e*(c+d*x)^3)*b^2/(d^3*e)-1/3*(b*c-a*d)^2*(c+d*x)*_
+--   GAMMA(1/3,-e*(c+d*x)^3)/(d^3*(-e*(c+d*x)^3)^(1/3))+2/3*b*(b*c-a*d)*_
+--   (c+d*x)^2*GAMMA(2/3,-e*(c+d*x)^3)/(d^3*(-e*(c+d*x)^3)^(2/3))
+--E 68
+
+--S 69 of 602
+--d0:=normalize(D(m0,x))
+--E 69
+
+)clear all
+
+--S 70 of 602
+t0:=%e^(e*(c+d*x)^3)*(a+b*x)
+--E 70
+
+--S 71 of 602
+--r0:=1/3*(b*c-a*d)*(c+d*x)*GAMMA(1/3,-e*(c+d*x)^3)/(d^2*(-e*_
+--   (c+d*x)^3)^(1/3))-1/3*b*(c+d*x)^2*GAMMA(2/3,-e*(c+d*x)^3)/_
+--   (d^2*(-e*(c+d*x)^3)^(2/3))
+--E 71
+
+--S 72 of 602
+--d0:=normalize(D(m0,x))
+--E 72
+
+)clear all
+
+--S 73 of 602
+t0:=%e^(e*(c+d*x)^3)
+--E 73
+
+--S 74 of 602
+--r0:=-1/3*(c+d*x)*GAMMA(1/3,-e*(c+d*x)^3)/(d*(-e*(c+d*x)^3)^(1/3))
+--E 74
+
+--S 75 of 602
+--d0:=normalize(D(m0,x))
+--E 75
+
+)clear all
+
+--S 76 of 602
+t0:=%e^(e*(c+d*x)^3)/(a+b*x)
+--E 76
+
+--S 77 of 602
+--r0:=Int(%e^(e*(c+d*x)^3)/(a+b*x),x)
+--E 77
+
+--S 78 of 602
+--d0:=normalize(D(m0,x))
+--E 78
+
+)clear all
+
+--S 79 of 602
+t0:=%e^(e*(c+d*x)^3)/(a+b*x)^2
+--E 79
+
+--S 80 of 602
+--r0:=-%e^(e*(c+d*x)^3)/(b*(a+b*x))-d*(b*c-a*d)*e*(c+d*x)*GAMMA(1/3,_
+--   -e*(c+d*x)^3)/(b^3*(-e*(c+d*x)^3)^(1/3))-d*e*(c+d*x)^2*GAMMA(2/3,_
+--   -e*(c+d*x)^3)/(b^2*(-e*(c+d*x)^3)^(2/3))+3*d*(b*c-a*d)^2*e*_
+--   Int(%e^(e*(c+d*x)^3)/(a+b*x),x)/b^3
+--E 80
+
+--S 81 of 602
+--d0:=normalize(D(m0,x))
+--E 81
+
+)clear all
+
+--S 82 of 602
+t0:=F^(a+b/(c+d*x))/(e+f*x)
+--E 82
+
+--S 83 of 602
+--r0:=-F^a*Ei(b*log(F)/(c+d*x))/f+F^(a-b*f/(d*e-c*f))*Ei(b*d*(e+f*x)*_
+--   log(F)/((d*e-c*f)*(c+d*x)))/f
+--E 83
+
+--S 84 of 602
+--d0:=normalize(D(m0,x))
+--E 84
+
+)clear all
+
+--S 85 of 602
+t0:=F^(a+b/(c+d*x))/(e+f*x)^2
+--E 85
+
+--S 86 of 602
+--r0:=d*F^(a+b/(c+d*x))/(f*(d*e-c*f))-F^(a+b/(c+d*x))/(f*(e+f*x))-_
+--   b*d*F^(a-b*f/(d*e-c*f))*Ei(b*d*(e+f*x)*log(F)/((d*e-c*f)*(c+d*x)))*_
+--   log(F)/(d*e-c*f)^2
+--E 86
+
+--S 87 of 602
+--d0:=normalize(D(m0,x))
+--E 87
+
+)clear all
+
+--S 88 of 602
+t0:=F^(a+b/(c+d*x))/(e+f*x)^3
+--E 88
+
+--S 89 of 602
+--r0:=1/2*d^2*F^(a+b/(c+d*x))/(f*(d*e-c*f)^2)-1/2*F^(a+b/(c+d*x))/_
+--   (f*(e+f*x)^2)-1/2*b*d^2*F^(a+b/(c+d*x))*log(F)/(d*e-c*f)^3+1/2*b*_
+--   d*F^(a+b/(c+d*x))*log(F)/((d*e-c*f)^2*(e+f*x))-b*d^2*F^(a-b*f/_
+--   (d*e-c*f))*Ei(b*d*(e+f*x)*log(F)/((d*e-c*f)*(c+d*x)))*log(F)/_
+--   (d*e-c*f)^3+1/2*b^2*d^2*f*F^(a-b*f/(d*e-c*f))*Ei(b*d*(e+f*x)*_
+--   log(F)/((d*e-c*f)*(c+d*x)))*log(F)^2/(d*e-c*f)^4
+--E 89
+
+--S 90 of 602
+--d0:=normalize(D(m0,x))
+--E 90
+
+)clear all
+
+--S 91 of 602
+t0:=F^(a+b/(c+d*x))/(e+f*x)^4
+--E 91
+
+--S 92 of 602
+--r0:=1/3*d^3*F^(a+b/(c+d*x))/(f*(d*e-c*f)^3)-1/3*F^(a+b/(c+d*x))/_
+--   (f*(e+f*x)^3)-5/6*b*d^3*F^(a+b/(c+d*x))*log(F)/(d*e-c*f)^4+1/6*b*_
+--   d*F^(a+b/(c+d*x))*log(F)/((d*e-c*f)^2*(e+f*x)^2)+2/3*b*d^2*F^(a+_
+--   b/(c+d*x))*log(F)/((d*e-c*f)^3*(e+f*x))-b*d^3*F^(a-b*f/(d*e-c*f))*_
+--   Ei(b*d*(e+f*x)*log(F)/((d*e-c*f)*(c+d*x)))*log(F)/(d*e-c*f)^4+_
+--   1/6*b^2*d^3*f*F^(a+b/(c+d*x))*log(F)^2/(d*e-c*f)^5-1/6*b^2*d^2*_
+--   f*F^(a+b/(c+d*x))*log(F)^2/((d*e-c*f)^4*(e+f*x))+b^2*d^3*f*F^(a-_
+--   b*f/(d*e-c*f))*Ei(b*d*(e+f*x)*log(F)/((d*e-c*f)*(c+d*x)))*log(F)^2/_
+--   (d*e-c*f)^5-1/6*b^3*d^3*f^2*F^(a-b*f/(d*e-c*f))*Ei(b*d*(e+f*x)*_
+--   log(F)/((d*e-c*f)*(c+d*x)))*log(F)^3/(d*e-c*f)^6
+--E 92
+
+--S 93 of 602
+--d0:=normalize(D(m0,x))
+--E 93
+
+)clear all
+
+--S 94 of 602
+t0:=%e^(e/(c+d*x))*(a+b*x)^4
+--E 94
+
+--S 95 of 602
+--r0:=%e^(e/(c+d*x))*(b*c-a*d)^4*(c+d*x)/d^5-2*%e^(e/(c+d*x))*b*_
+--   (b*c-a*d)^3*e*(c+d*x)/d^5+%e^(e/(c+d*x))*b^2*(b*c-a*d)^2*e^2*_
+--   (c+d*x)/d^5-2*%e^(e/(c+d*x))*b*(b*c-a*d)^3*(c+d*x)^2/d^5+%e^(e/_
+--   (c+d*x))*b^2*(b*c-a*d)^2*e*(c+d*x)^2/d^5+2*%e^(e/(c+d*x))*b^2*_
+--   (b*c-a*d)^2*(c+d*x)^3/d^5-(b*c-a*d)^4*e*Ei(e/(c+d*x))/d^5+2*b*_
+--   (b*c-a*d)^3*e^2*Ei(e/(c+d*x))/d^5-b^2*(b*c-a*d)^2*e^3*Ei(e/(c+d*x))/_
+--   d^5-b^4*e^5*GAMMA(-5,-e/(c+d*x))/d^5-4*b^3*(b*c-a*d)*e^4*_
+--   GAMMA(-4,-e/(c+d*x))/d^5
+--E 95
+
+--S 96 of 602
+--d0:=normalize(D(m0,x))
+--E 96
+
+)clear all
+
+--S 97 of 602
+t0:=%e^(e/(c+d*x))*(a+b*x)^3
+--E 97
+
+--S 98 of 602
+--r0:=-%e^(e/(c+d*x))*(b*c-a*d)^3*(c+d*x)/d^4+3/2*%e^(e/(c+d*x))*b*_
+--   (b*c-a*d)^2*e*(c+d*x)/d^4-1/2*%e^(e/(c+d*x))*b^2*(b*c-a*d)*e^2*_
+--   (c+d*x)/d^4+3/2*%e^(e/(c+d*x))*b*(b*c-a*d)^2*(c+d*x)^2/d^4-_
+--   1/2*%e^(e/(c+d*x))*b^2*(b*c-a*d)*e*(c+d*x)^2/d^4-%e^(e/(c+d*x))*_
+--   b^2*(b*c-a*d)*(c+d*x)^3/d^4+(b*c-a*d)^3*e*Ei(e/(c+d*x))/d^4-3/2*_
+--   b*(b*c-a*d)^2*e^2*Ei(e/(c+d*x))/d^4+1/2*b^2*(b*c-a*d)*e^3*_
+--   Ei(e/(c+d*x))/d^4+b^3*e^4*GAMMA(-4,-e/(c+d*x))/d^4
+--E 98
+
+--S 99 of 602
+--d0:=normalize(D(m0,x))
+--E 99
+
+)clear all
+
+--S 100 of 602
+t0:=%e^(e/(c+d*x))*(a+b*x)^2
+--E 100
+
+--S 101 of 602
+--r0:=%e^(e/(c+d*x))*(b*c-a*d)^2*(c+d*x)/d^3-%e^(e/(c+d*x))*b*(b*c-a*d)*_
+--   e*(c+d*x)/d^3+1/6*%e^(e/(c+d*x))*b^2*e^2*(c+d*x)/d^3-%e^(e/(c+d*x))*_
+--   b*(b*c-a*d)*(c+d*x)^2/d^3+1/6*%e^(e/(c+d*x))*b^2*e*(c+d*x)^2/d^3+_
+--   1/3*%e^(e/(c+d*x))*b^2*(c+d*x)^3/d^3-(b*c-a*d)^2*e*Ei(e/(c+d*x))/d^3+_
+--   b*(b*c-a*d)*e^2*Ei(e/(c+d*x))/d^3-1/6*b^2*e^3*Ei(e/(c+d*x))/d^3
+--E 101
+
+--S 102 of 602
+--d0:=normalize(D(m0,x))
+--E 102
+
+)clear all
+
+--S 103 of 602
+t0:=%e^(e/(c+d*x))*(a+b*x)
+--E 103
+
+--S 104 of 602
+--r0:=-%e^(e/(c+d*x))*(b*c-a*d)*(c+d*x)/d^2+1/2*%e^(e/(c+d*x))*b*e*_
+--   (c+d*x)/d^2+1/2*%e^(e/(c+d*x))*b*(c+d*x)^2/d^2+(b*c-a*d)*e*_
+--   Ei(e/(c+d*x))/d^2-1/2*b*e^2*Ei(e/(c+d*x))/d^2
+--E 104
+
+--S 105 of 602
+--d0:=normalize(D(m0,x))
+--E 105
+
+)clear all
+
+--S 106 of 602
+t0:=%e^(e/(c+d*x))
+--E 106
+
+--S 107 of 602
+--r0:=%e^(e/(c+d*x))*(c+d*x)/d-e*Ei(e/(c+d*x))/d
+--E 107
+
+--S 108 of 602
+--d0:=normalize(D(m0,x))
+--E 108
+
+)clear all
+
+--S 109 of 602
+t0:=%e^(e/(c+d*x))/(a+b*x)
+--E 109
+
+--S 110 of 602
+--r0:=-Ei(e/(c+d*x))/b+%e^(b*e/(b*c-a*d))*Ei(-d*e*(a+b*x)/((b*c-a*d)*_
+--   (c+d*x)))/b
+--E 110
+
+--S 111 of 602
+--d0:=normalize(D(m0,x))
+--E 111
+
+)clear all
+
+--S 112 of 602
+t0:=%e^(e/(c+d*x))/(a+b*x)^2
+--E 112
+
+--S 113 of 602
+--r0:=-%e^(e/(c+d*x))*d/(b*(b*c-a*d))-%e^(e/(c+d*x))/(b*(a+b*x))-%e^(b*_
+--   e/(b*c-a*d))*d*e*Ei(-d*e*(a+b*x)/((b*c-a*d)*(c+d*x)))/(b*c-a*d)^2
+--E 113
+
+--S 114 of 602
+--d0:=normalize(D(m0,x))
+--E 114
+
+)clear all
+
+--S 115 of 602
+t0:=%e^(e/(c+d*x))/(a+b*x)^3
+--E 115
+
+--S 116 of 602
+--r0:=1/2*%e^(e/(c+d*x))*d^2/(b*(b*c-a*d)^2)+1/2*%e^(e/(c+d*x))*d^2*e/_
+--   (b*c-a*d)^3-1/2*%e^(e/(c+d*x))/(b*(a+b*x)^2)+1/2*%e^(e/(c+d*x))*d*e/_
+--   ((b*c-a*d)^2*(a+b*x))+%e^(b*e/(b*c-a*d))*d^2*e*Ei(-d*e*(a+b*x)/_
+--   ((b*c-a*d)*(c+d*x)))/(b*c-a*d)^3+1/2*%e^(b*e/(b*c-a*d))*b*d^2*e^2*_
+--   Ei(-d*e*(a+b*x)/((b*c-a*d)*(c+d*x)))/(b*c-a*d)^4
+--E 116
+
+--S 117 of 602
+--d0:=normalize(D(m0,x))
+--E 117
+
+)clear all
+
+--S 118 of 602
+t0:=%e^(e/(c+d*x)^2)*(a+b*x)^3
+--E 118
+
+--S 119 of 602
+--r0:=-%e^(e/(c+d*x)^2)*(b*c-a*d)^3*(c+d*x)/d^4-2*%e^(e/(c+d*x)^2)*b^2*_
+--   (b*c-a*d)*e*(c+d*x)/d^4+3/2*%e^(e/(c+d*x)^2)*b*(b*c-a*d)^2*(c+d*x)^2/_
+--   d^4+1/4*%e^(e/(c+d*x)^2)*b^3*e*(c+d*x)^2/d^4-%e^(e/(c+d*x)^2)*b^2*_
+--   (b*c-a*d)*(c+d*x)^3/d^4+1/4*%e^(e/(c+d*x)^2)*b^3*(c+d*x)^4/d^4-_
+--   3/2*b*(b*c-a*d)^2*e*Ei(e/(c+d*x)^2)/d^4-1/4*b^3*e^2*Ei(e/(c+d*x)^2)/_
+--   d^4+2*b^2*(b*c-a*d)*e^(3/2)*erfi(sqrt(e)/(c+d*x))*sqrt(%pi)/d^4+_
+--   (b*c-a*d)^3*erfi(sqrt(e)/(c+d*x))*sqrt(%pi)*sqrt(e)/d^4
+--E 119
+
+--S 120 of 602
+--d0:=normalize(D(m0,x))
+--E 120
+
+)clear all
+
+--S 121 of 602
+t0:=%e^(e/(c+d*x)^2)*(a+b*x)^2
+--E 121
+
+--S 122 of 602
+--r0:=%e^(e/(c+d*x)^2)*(b*c-a*d)^2*(c+d*x)/d^3+2/3*%e^(e/(c+d*x)^2)*b^2*_
+--   e*(c+d*x)/d^3-%e^(e/(c+d*x)^2)*b*(b*c-a*d)*(c+d*x)^2/d^3+_
+--   1/3*%e^(e/(c+d*x)^2)*b^2*(c+d*x)^3/d^3+b*(b*c-a*d)*e*Ei(e/(c+_
+--   d*x)^2)/d^3-2/3*b^2*e^(3/2)*erfi(sqrt(e)/(c+d*x))*sqrt(%pi)/d^3-_
+--   (b*c-a*d)^2*erfi(sqrt(e)/(c+d*x))*sqrt(%pi)*sqrt(e)/d^3
+--E 122
+
+--S 123 of 602
+--d0:=normalize(D(m0,x))
+--E 123
+
+)clear all
+
+--S 124 of 602
+t0:=%e^(e/(c+d*x)^2)*(a+b*x)
+--E 124
+
+--S 125 of 602
+--r0:=-%e^(e/(c+d*x)^2)*(b*c-a*d)*(c+d*x)/d^2+1/2*%e^(e/(c+d*x)^2)*b*_
+--   (c+d*x)^2/d^2-1/2*b*e*Ei(e/(c+d*x)^2)/d^2+(b*c-a*d)*erfi(sqrt(e)/_
+--   (c+d*x))*sqrt(%pi)*sqrt(e)/d^2
+--E 125
+
+--S 126 of 602
+--d0:=normalize(D(m0,x))
+--E 126
+
+)clear all
+
+--S 127 of 602
+t0:=%e^(e/(c+d*x)^2)
+--E 127
+
+--S 128 of 602
+--r0:=%e^(e/(c+d*x)^2)*(c+d*x)/d-erfi(sqrt(e)/(c+d*x))*sqrt(%pi)*sqrt(e)/d
+--E 128
+
+--S 129 of 602
+--d0:=normalize(D(m0,x))
+--E 129
+
+)clear all
+
+--S 130 of 602
+t0:=%e^(e/(c+d*x)^2)/(a+b*x)
+--E 130
+
+--S 131 of 602
+--r0:=Int(%e^(e/(c+d*x)^2)/(a+b*x),x)
+--E 131
+
+--S 132 of 602
+--d0:=normalize(D(m0,x))
+--E 132
+
+)clear all
+
+--S 133 of 602
+t0:=%e^(e/(c+d*x)^2)/(a+b*x)^2
+--E 133
+
+--S 134 of 602
+--r0:=Int(%e^(e/(c+d*x)^2)/(a+b*x)^2,x)
+--E 134
+
+--S 135 of 602
+--d0:=normalize(D(m0,x))
+--E 135
+
+)clear all
+
+--S 136 of 602
+t0:=%e^(e/(c+d*x)^2)/(a+b*x)^3
+--E 136
+
+--S 137 of 602
+--r0:=Int(%e^(e/(c+d*x)^2)/(a+b*x)^3,x)
+--E 137
+
+--S 138 of 602
+--d0:=normalize(D(m0,x))
+--E 138
+
+)clear all
+
+--S 139 of 602
+t0:=%e^(e/(c+d*x)^3)*(a+b*x)^3
+--E 139
+
+--S 140 of 602
+--r0:=-%e^(e/(c+d*x)^3)*b^2*(b*c-a*d)*(c+d*x)^3/d^4+b^2*(b*c-a*d)*e*_
+--   Ei(e/(c+d*x)^3)/d^4+1/3*b^3*(-e/(c+d*x)^3)^(4/3)*(c+d*x)^4*_
+--   GAMMA(-4/3,-e/(c+d*x)^3)/d^4+b*(b*c-a*d)^2*(-e/(c+d*x)^3)^(2/3)*_
+--   (c+d*x)^2*GAMMA(-2/3,-e/(c+d*x)^3)/d^4-1/3*(b*c-a*d)^3*(-e/(c+_
+--   d*x)^3)^(1/3)*(c+d*x)*GAMMA(-1/3,-e/(c+d*x)^3)/d^4
+--E 140
+
+--S 141 of 602
+--d0:=normalize(D(m0,x))
+--E 141
+
+)clear all
+
+--S 142 of 602
+t0:=%e^(e/(c+d*x)^3)*(a+b*x)^2
+--E 142
+
+--S 143 of 602
+--r0:=1/3*%e^(e/(c+d*x)^3)*b^2*(c+d*x)^3/d^3-1/3*b^2*e*Ei(e/(c+d*x)^3)/d^3-_
+--   2/3*b*(b*c-a*d)*(-e/(c+d*x)^3)^(2/3)*(c+d*x)^2*GAMMA(-2/3,-e/_
+--   (c+d*x)^3)/d^3+1/3*(b*c-a*d)^2*(-e/(c+d*x)^3)^(1/3)*(c+d*x)*_
+--   GAMMA(-1/3,-e/(c+d*x)^3)/d^3
+--E 143
+
+--S 144 of 602
+--d0:=normalize(D(m0,x))
+--E 144
+
+)clear all
+
+--S 145 of 602
+t0:=%e^(e/(c+d*x)^3)*(a+b*x)
+--E 145
+
+--S 146 of 602
+--r0:=1/3*b*(-e/(c+d*x)^3)^(2/3)*(c+d*x)^2*GAMMA(-2/3,-e/(c+d*x)^3)/d^2-_
+--   1/3*(b*c-a*d)*(-e/(c+d*x)^3)^(1/3)*(c+d*x)*GAMMA(-1/3,-e/(c+d*x)^3)/d^2
+--E 146
+
+--S 147 of 602
+--d0:=normalize(D(m0,x))
+--E 147
+
+)clear all
+
+--S 148 of 602
+t0:=%e^(e/(c+d*x)^3)
+--E 148
+
+--S 149 of 602
+--r0:=1/3*(-e/(c+d*x)^3)^(1/3)*(c+d*x)*GAMMA(-1/3,-e/(c+d*x)^3)/d
+--E 149
+
+--S 150 of 602
+--d0:=normalize(D(m0,x))
+--E 150
+
+)clear all
+
+--S 151 of 602
+t0:=%e^(e/(c+d*x)^3)/(a+b*x)
+--E 151
+
+--S 152 of 602
+--r0:=Int(%e^(e/(c+d*x)^3)/(a+b*x),x)
+--E 152
+
+--S 153 of 602
+--d0:=normalize(D(m0,x))
+--E 153
+
+)clear all
+
+--S 154 of 602
+t0:=%e^(e/(c+d*x)^3)/(a+b*x)^2
+--E 154
+
+--S 155 of 602
+--r0:=Int(%e^(e/(c+d*x)^3)/(a+b*x)^2,x)
+--E 155
+
+--S 156 of 602
+--d0:=normalize(D(m0,x))
+--E 156
+
+)clear all
+
+--S 157 of 602
+t0:=F^(e+f*(a+b*x)/(c+d*x))/(g+h*x)
+--E 157
+
+--S 158 of 602
+--r0:=-F^(e+b*f/d)*Ei(-(b*c-a*d)*f*log(F)/(d*(c+d*x)))/h+F^(e+f*(b*g-a*h)/_
+--   (d*g-c*h))*Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))/h
+--E 158
+
+--S 159 of 602
+--d0:=normalize(D(m0,x))
+--E 159
+
+)clear all
+
+--S 160 of 602
+t0:=F^(e+f*(a+b*x)/(c+d*x))/(g+h*x)^2
+--E 160
+
+--S 161 of 602
+--r0:=d*F^(e+b*f/d-(b*c-a*d)*f/(d*(c+d*x)))/(h*(d*g-c*h))-F^(e+f*(a+b*x)/_
+--   (c+d*x))/(h*(g+h*x))+(b*c-a*d)*f*F^(e+f*(b*g-a*h)/(d*g-c*h))*_
+--   Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))*log(F)/(d*g-c*h)^2
+--E 161
+
+--S 162 of 602
+--d0:=normalize(D(m0,x))
+--E 162
+
+)clear all
+
+--S 163 of 602
+t0:=F^(e+f*(a+b*x)/(c+d*x))/(g+h*x)^3
+--E 163
+
+--S 164 of 602
+--r0:=1/2*d^2*F^(e+b*f/d-(b*c-a*d)*f/(d*(c+d*x)))/(h*(d*g-c*h)^2)-_
+--   1/2*F^(e+f*(a+b*x)/(c+d*x))/(h*(g+h*x)^2)+1/2*d*(b*c-a*d)*f*F^(e+_
+--   b*f/d-(b*c-a*d)*f/(d*(c+d*x)))*log(F)/(d*g-c*h)^3-1/2*(b*c-a*d)*f*_
+--   F^(e+f*(a+b*x)/(c+d*x))*log(F)/((d*g-c*h)^2*(g+h*x))+d*(b*c-a*d)*f*_
+--   F^(e+f*(b*g-a*h)/(d*g-c*h))*Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*_
+--   (c+d*x)))*log(F)/(d*g-c*h)^3+1/2*(b*c-a*d)^2*f^2*F^(e+f*(b*g-a*h)/_
+--   (d*g-c*h))*h*Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))*_
+--   log(F)^2/(d*g-c*h)^4
+--E 164
+
+--S 165 of 602
+--d0:=normalize(D(m0,x))
+--E 165
+
+)clear all
+
+--S 166 of 602
+t0:=F^(e+f*(a+b*x)/(c+d*x))/(g+h*x)^4
+--E 166
+
+--S 167 of 602
+--r0:=1/3*d^3*F^(e+b*f/d-(b*c-a*d)*f/(d*(c+d*x)))/(h*(d*g-c*h)^3)-_
+--   1/3*F^(e+f*(a+b*x)/(c+d*x))/(h*(g+h*x)^3)+5/6*d^2*(b*c-a*d)*f*_
+--   F^(e+b*f/d-(b*c-a*d)*f/(d*(c+d*x)))*log(F)/(d*g-c*h)^4-1/6*(b*c-_
+--   a*d)*f*F^(e+f*(a+b*x)/(c+d*x))*log(F)/((d*g-c*h)^2*(g+h*x)^2)-_
+--   2/3*d*(b*c-a*d)*f*F^(e+f*(a+b*x)/(c+d*x))*log(F)/((d*g-c*h)^3*_
+--   (g+h*x))+d^2*(b*c-a*d)*f*F^(e+f*(b*g-a*h)/(d*g-c*h))*Ei(-(b*c-a*d)*_
+--   f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))*log(F)/(d*g-c*h)^4+1/6*d*_
+--   (b*c-a*d)^2*f^2*F^(e+b*f/d-(b*c-a*d)*f/(d*(c+d*x)))*h*log(F)^2/_
+--   (d*g-c*h)^5-1/6*(b*c-a*d)^2*f^2*F^(e+f*(a+b*x)/(c+d*x))*h*log(F)^2/_
+--   ((d*g-c*h)^4*(g+h*x))+d*(b*c-a*d)^2*f^2*F^(e+f*(b*g-a*h)/(d*g-c*h))*_
+--   h*Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))*log(F)^2/_
+--   (d*g-c*h)^5+1/6*(b*c-a*d)^3*f^3*F^(e+f*(b*g-a*h)/(d*g-c*h))*h^2*_
+--   Ei(-(b*c-a*d)*f*(g+h*x)*log(F)/((d*g-c*h)*(c+d*x)))*log(F)^3/(d*g-c*h)^6
+--E 167
+
+--S 168 of 602
+--d0:=normalize(D(m0,x))
+--E 168
+
+)clear all
+
+--S 169 of 602
+t0:=f^(a+b*x+c*x^2)*x^3
+--E 169
+
+--S 170 of 602
+--r0:=-1/2*f^(a+b*x+c*x^2)/(c^2*log(f)^2)+1/8*b^2*f^(a+b*x+c*x^2)/(c^3*_
+--   log(f))-1/4*b*f^(a+b*x+c*x^2)*x/(c^2*log(f))+1/2*f^(a+b*x+c*x^2)*x^2/_
+--   (c*log(f))+3/8*b*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/_
+--   sqrt(c))*sqrt(%pi)/(c^(5/2)*log(f)^(3/2))-1/16*b^3*f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(7/2)*sqrt(log(f)))
+--E 170
+
+--S 171 of 602
+--d0:=normalize(D(m0,x))
+--E 171
+
+)clear all
+
+--S 172 of 602
+t0:=f^(a+b*x+c*x^2)*x^2
+--E 172
+
+--S 173 of 602
+--r0:=-1/4*b*f^(a+b*x+c*x^2)/(c^2*log(f))+1/2*f^(a+b*x+c*x^2)*x/(c*log(f))-_
+--   1/4*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*_
+--   sqrt(%pi)/(c^(3/2)*log(f)^(3/2))+1/8*b^2*f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(5/2)*sqrt(log(f)))
+--E 173
+
+--S 174 of 602
+--d0:=normalize(D(m0,x))
+--E 174
+
+)clear all
+
+--S 175 of 602
+t0:=f^(a+b*x+c*x^2)*x
+--E 175
+
+--S 176 of 602
+--r0:=1/2*f^(a+b*x+c*x^2)/(c*log(f))-1/4*b*f^(a-1/4*b^2/c)*erfi(1/2*_
+--   (b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(3/2)*sqrt(log(f)))
+--E 176
+
+--S 177 of 602
+--d0:=normalize(D(m0,x))
+--E 177
+
+)clear all
+
+--S 178 of 602
+t0:=f^(a+b*x+c*x^2)
+--E 178
+
+--S 179 of 602
+--r0:=1/2*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*_
+--   sqrt(%pi)/(sqrt(c)*sqrt(log(f)))
+--E 179
+
+--S 180 of 602
+--d0:=normalize(D(m0,x))
+--E 180
+
+)clear all
+
+--S 181 of 602
+t0:=f^(a+b*x+c*x^2)/x
+--E 181
+
+--S 182 of 602
+--r0:=Int(f^(a+b*x+c*x^2)/x,x)
+--E 182
+
+--S 183 of 602
+--d0:=normalize(D(m0,x))
+--E 183
+
+)clear all
+
+--S 184 of 602
+t0:=f^(a+b*x+c*x^2)/x^2
+--E 184
+
+--S 185 of 602
+--r0:=-f^(a+b*x+c*x^2)/x+b*Int(f^(a+b*x+c*x^2)/x,x)*log(f)+f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)*sqrt(c)*sqrt(log(f))
+--E 185
+
+--S 186 of 602
+--d0:=normalize(D(m0,x))
+--E 186
+
+)clear all
+
+--S 187 of 602
+t0:=%e^(a+b*x-c*x^2)*x^3
+--E 187
+
+--S 188 of 602
+--r0:=-1/8*%e^(a+b*x-c*x^2)*b^2/c^3-1/2*%e^(a+b*x-c*x^2)/c^2-1/4*%e^(a+_
+--   b*x-c*x^2)*b*x/c^2-1/2*%e^(a+b*x-c*x^2)*x^2/c-1/16*%e^(a+1/4*b^2/c)*_
+--   b^3*erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)/c^(7/2)-3/8*%e^(a+1/4*b^2/c)*_
+--   b*erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)/c^(5/2)
+--E 188
+
+--S 189 of 602
+--d0:=normalize(D(m0,x))
+--E 189
+
+)clear all
+
+--S 190 of 602
+t0:=%e^(a+b*x-c*x^2)*x^2
+--E 190
+
+--S 191 of 602
+--r0:=-1/4*%e^(a+b*x-c*x^2)*b/c^2-1/2*%e^(a+b*x-c*x^2)*x/c-1/8*%e^(a+1/4*_
+--   b^2/c)*b^2*erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)/c^(5/2)-1/4*%e^(a+_
+--   1/4*b^2/c)*erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)/c^(3/2)
+--E 191
+
+--S 192 of 602
+--d0:=normalize(D(m0,x))
+--E 192
+
+)clear all
+
+--S 193 of 602
+t0:=%e^(a+b*x-c*x^2)*x
+--E 193
+
+--S 194 of 602
+--r0:=-1/2*%e^(a+b*x-c*x^2)/c-1/4*%e^(a+1/4*b^2/c)*b*erf(1/2*(b-2*c*x)/_
+--   sqrt(c))*sqrt(%pi)/c^(3/2)
+--E 194
+
+--S 195 of 602
+--d0:=normalize(D(m0,x))
+--E 195
+
+)clear all
+
+--S 196 of 602
+t0:=%e^(a+b*x-c*x^2)
+--E 196
+
+--S 197 of 602
+--r0:=-1/2*%e^(a+1/4*b^2/c)*erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)/sqrt(c)
+--E 197
+
+--S 198 of 602
+--d0:=normalize(D(m0,x))
+--E 198
+
+)clear all
+
+--S 199 of 602
+t0:=%e^(a+b*x-c*x^2)/x
+--E 199
+
+--S 200 of 602
+--r0:=Int(%e^(a+b*x-c*x^2)/x,x)
+--E 200
+
+--S 201 of 602
+--d0:=normalize(D(m0,x))
+--E 201
+
+)clear all
+
+--S 202 of 602
+t0:=%e^(a+b*x-c*x^2)/x^2
+--E 202
+
+--S 203 of 602
+--r0:=-%e^(a+b*x-c*x^2)/x+b*Int(%e^(a+b*x-c*x^2)/x,x)+%e^(a+1/4*b^2/c)*_
+--   erf(1/2*(b-2*c*x)/sqrt(c))*sqrt(%pi)*sqrt(c)
+--E 203
+
+--S 204 of 602
+--d0:=normalize(D(m0,x))
+--E 204
+
+)clear all
+
+--S 205 of 602
+t0:=%e^((a+b*x)*(c+d*x))*x^3
+--E 205
+
+--S 206 of 602
+--r0:=-1/2*%e^(a*c+(b*c+a*d)*x+b*d*x^2)/(b^2*d^2)+1/8*%e^(a*c+(b*c+a*d)*x+_
+--   b*d*x^2)*(b*c+a*d)^2/(b^3*d^3)-1/4*%e^(a*c+(b*c+a*d)*x+b*d*x^2)*_
+--   (b*c+a*d)*x/(b^2*d^2)+1/2*%e^(a*c+(b*c+a*d)*x+b*d*x^2)*x^2/(b*d)+_
+--   3/8*(b*c+a*d)*erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*_
+--   sqrt(%pi)/(%e^(1/4*(b*c-a*d)^2/(b*d))*b^(5/2)*d^(5/2))-1/16*(b*c+_
+--   a*d)^3*erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*sqrt(%pi)/_
+--   (%e^(1/4*(b*c-a*d)^2/(b*d))*b^(7/2)*d^(7/2))
+--E 206
+
+--S 207 of 602
+--d0:=normalize(D(m0,x))
+--E 207
+
+)clear all
+
+--S 208 of 602
+t0:=%e^((a+b*x)*(c+d*x))*x^2
+--E 208
+
+--S 209 of 602
+--r0:=-1/4*%e^(a*c+(b*c+a*d)*x+b*d*x^2)*(b*c+a*d)/(b^2*d^2)+1/2*%e^(a*c+_
+--   (b*c+a*d)*x+b*d*x^2)*x/(b*d)-1/4*erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*_
+--   sqrt(d)))*sqrt(%pi)/(%e^(1/4*(b*c-a*d)^2/(b*d))*b^(3/2)*d^(3/2))+_
+--   1/8*(b*c+a*d)^2*erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*_
+--   sqrt(%pi)/(%e^(1/4*(b*c-a*d)^2/(b*d))*b^(5/2)*d^(5/2))
+--E 209
+
+--S 210 of 602
+--d0:=normalize(D(m0,x))
+--E 210
+
+)clear all
+
+--S 211 of 602
+t0:=%e^((a+b*x)*(c+d*x))*x
+--E 211
+
+--S 212 of 602
+--r0:=1/2*%e^(a*c+(b*c+a*d)*x+b*d*x^2)/(b*d)-1/4*(b*c+a*d)*erfi(1/2*(b*c+_
+--   a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*sqrt(%pi)/(%e^(1/4*(b*c-a*d)^2/_
+--   (b*d))*b^(3/2)*d^(3/2))
+--E 212
+
+--S 213 of 602
+--d0:=normalize(D(m0,x))
+--E 213
+
+)clear all
+
+--S 214 of 602
+t0:=%e^((a+b*x)*(c+d*x))
+--E 214
+
+--S 215 of 602
+--r0:=1/2*erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*sqrt(%pi)/_
+--   (%e^(1/4*(b*c-a*d)^2/(b*d))*sqrt(b)*sqrt(d))
+--E 215
+
+--S 216 of 602
+--d0:=normalize(D(m0,x))
+--E 216
+
+)clear all
+
+--S 217 of 602
+t0:=%e^((a+b*x)*(c+d*x))/x
+--E 217
+
+--S 218 of 602
+--r0:=Int(%e^(a*c+(b*c+a*d)*x+b*d*x^2)/x,x)
+--E 218
+
+--S 219 of 602
+--d0:=normalize(D(m0,x))
+--E 219
+
+)clear all
+
+--S 220 of 602
+t0:=%e^((a+b*x)*(c+d*x))/x^2
+--E 220
+
+--S 221 of 602
+--r0:=-%e^(a*c+(b*c+a*d)*x+b*d*x^2)/x+(b*c+a*d)*Int(%e^(a*c+(b*c+a*d)*x+_
+--   b*d*x^2)/x,x)+erfi(1/2*(b*c+a*d+2*b*d*x)/(sqrt(b)*sqrt(d)))*_
+--   sqrt(%pi)*sqrt(b)*sqrt(d)/%e^(1/4*(b*c-a*d)^2/(b*d))
+--E 221
+
+--S 222 of 602
+--d0:=normalize(D(m0,x))
+--E 222
+
+)clear all
+
+--S 223 of 602
+t0:=f^(a+b*x+c*x^2)*(d+e*x)^3
+--E 223
+
+--S 224 of 602
+--r0:=-1/2*e^3*f^(a+b*x+c*x^2)/(c^2*log(f)^2)+1/8*e*(2*c*d-b*e)^2*f^(a+b*x+_
+--   c*x^2)/(c^3*log(f))+1/4*e*(2*c*d-b*e)*f^(a+b*x+c*x^2)*(d+e*x)/(c^2*_
+--   log(f))+1/2*e*f^(a+b*x+c*x^2)*(d+e*x)^2/(c*log(f))-3/8*e^2*(2*c*d-_
+--   b*e)*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*_
+--   sqrt(%pi)/(c^(5/2)*log(f)^(3/2))+1/16*(2*c*d-b*e)^3*f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(7/2)*sqrt(log(f)))
+--E 224
+
+--S 225 of 602
+--d0:=normalize(D(m0,x))
+--E 225
+
+)clear all
+
+--S 226 of 602
+t0:=f^(a+b*x+c*x^2)*(d+e*x)^2
+--E 226
+
+--S 227 of 602
+--r0:=1/4*e*(2*c*d-b*e)*f^(a+b*x+c*x^2)/(c^2*log(f))+1/2*e*f^(a+b*x+c*x^2)*_
+--   (d+e*x)/(c*log(f))-1/4*e^2*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*_
+--   sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(3/2)*log(f)^(3/2))+1/8*(2*c*d-_
+--   b*e)^2*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*_
+--   sqrt(%pi)/(c^(5/2)*sqrt(log(f)))
+--E 227
+
+--S 228 of 602
+--d0:=normalize(D(m0,x))
+--E 228
+
+)clear all
+
+--S 229 of 602
+t0:=f^(a+b*x+c*x^2)*(d+e*x)
+--E 229
+
+--S 230 of 602
+--r0:=1/2*e*f^(a+b*x+c*x^2)/(c*log(f))+1/4*(2*c*d-b*e)*f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)/(c^(3/2)*sqrt(log(f)))
+--E 230
+
+--S 231 of 602
+--d0:=normalize(D(m0,x))
+--E 231
+
+)clear all
+
+--S 232 of 602
+t0:=f^(a+b*x+c*x^2)/(d+e*x)
+--E 232
+
+--S 233 of 602
+--r0:=Int(f^(a+b*x+c*x^2)/(d+e*x),x)
+--E 233
+
+--S 234 of 602
+--d0:=normalize(D(m0,x))
+--E 234
+
+)clear all
+
+--S 235 of 602
+t0:=f^(a+b*x+c*x^2)/(d+e*x)^2
+--E 235
+
+--S 236 of 602
+--r0:=-f^(a+b*x+c*x^2)/(e*(d+e*x))-(2*c*d-b*e)*Int(f^(a+b*x+c*x^2)/_
+--   (d+e*x),x)*log(f)/e^2+f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*_
+--   sqrt(log(f))/sqrt(c))*sqrt(%pi)*sqrt(c)*sqrt(log(f))/e^2
+--E 236
+
+--S 237 of 602
+--d0:=normalize(D(m0,x))
+--E 237
+
+)clear all
+
+--S 238 of 602
+t0:=f^(a+b*x+c*x^2)/(d+e*x)^3
+--E 238
+
+--S 239 of 602
+--r0:=-1/2*f^(a+b*x+c*x^2)/(e*(d+e*x)^2)+1/2*(2*c*d-b*e)*f^(a+b*x+c*x^2)*_
+--   log(f)/(e^3*(d+e*x))+c*Int(f^(a+b*x+c*x^2)/(d+e*x),x)*log(f)/e^2+_
+--   1/2*(2*c*d-b*e)^2*Int(f^(a+b*x+c*x^2)/(d+e*x),x)*log(f)^2/e^4-_
+--   1/2*(2*c*d-b*e)*f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*sqrt(log(f))/_
+--   sqrt(c))*log(f)^(3/2)*sqrt(%pi)*sqrt(c)/e^4
+--E 239
+
+--S 240 of 602
+--d0:=normalize(D(m0,x))
+--E 240
+
+)clear all
+
+--S 241 of 602
+t0:=f^(a+b*x+c*x^2)*(b+2*c*x)^3
+--E 241
+
+--S 242 of 602
+r0:=-4*c*f^(a+b*x+c*x^2)/log(f)^2+f^(a+b*x+c*x^2)*(b+2*c*x)^2/log(f)
+--E 242
+
+--S 243 of 602
+d0:=normalize(D(m0,x))
+--E 243
+
+)clear all
+
+--S 244 of 602
+t0:=f^(a+b*x+c*x^2)*(b+2*c*x)^2
+--E 244
+
+--S 245 of 602
+--r0:=f^(a+b*x+c*x^2)*(b+2*c*x)/log(f)-f^(a-1/4*b^2/c)*erfi(1/2*(b+2*c*x)*_
+--   sqrt(log(f))/sqrt(c))*sqrt(%pi)*sqrt(c)/log(f)^(3/2)
+--E 245
+
+--S 246 of 602
+--d0:=normalize(D(m0,x))
+--E 246
+
+)clear all
+
+--S 247 of 602
+t0:=f^(a+b*x+c*x^2)*(b+2*c*x)
+--E 247
+
+--S 248 of 602
+r0:=f^(a+b*x+c*x^2)/log(f)
+--E 248
+
+--S 249 of 602
+d0:=normalize(D(m0,x))
+--E 249
+
+)clear all
+
+--S 250 of 602
+t0:=f^(a+b*x+c*x^2)/(b+2*c*x)
+--E 250
+
+--S 251 of 602
+--r0:=1/4*f^(a-1/4*b^2/c)*Ei(1/4*(b+2*c*x)^2*log(f)/c)/c
+--E 251
+
+--S 252 of 602
+--d0:=normalize(D(m0,x))
+--E 252
+
+)clear all
+
+--S 253 of 602
+t0:=f^(a+b*x+c*x^2)/(b+2*c*x)^2
+--E 253
+
+--S 254 of 602
+--r0:=-1/2*f^(a+b*x+c*x^2)/(c*(b+2*c*x))+1/4*f^(a-1/4*b^2/c)*_
+--   erfi(1/2*(b+2*c*x)*sqrt(log(f))/sqrt(c))*sqrt(%pi)*sqrt(log(f))/c^(3/2)
+--E 254
+
+--S 255 of 602
+--d0:=normalize(D(m0,x))
+--E 255
+
+)clear all
+
+--S 256 of 602
+t0:=f^(a+b*x+c*x^2)/(b+2*c*x)^3
+--E 256
+
+--S 257 of 602
+--r0:=-1/4*f^(a+b*x+c*x^2)/(c*(b+2*c*x)^2)+1/16*f^(a-1/4*b^2/c)*_
+--   Ei(1/4*(b+2*c*x)^2*log(f)/c)*log(f)/c^2
+--E 257
+
+--S 258 of 602
+--d0:=normalize(D(m0,x))
+--E 258
+
+)clear all
+
+--S 259 of 602
+t0:=f^(b*x+c*x^2)*(b+2*c*x)^3
+--E 259
+
+--S 260 of 602
+r0:=-4*c*f^(b*x+c*x^2)/log(f)^2+f^(b*x+c*x^2)*(b+2*c*x)^2/log(f)
+--E 260
+
+--S 261 of 602
+d0:=normalize(D(m0,x))
+--E 261
+
+)clear all
+
+--S 262 of 602
+t0:=f^(b*x+c*x^2)*(b+2*c*x)^2
+--E 262
+
+--S 263 of 602
+--r0:=f^(b*x+c*x^2)*(b+2*c*x)/log(f)-erfi(1/2*(b+2*c*x)*sqrt(log(f))/_
+--   sqrt(c))*sqrt(%pi)*sqrt(c)/(f^(1/4*b^2/c)*log(f)^(3/2))
+--E 263
+
+--S 264 of 602
+--d0:=normalize(D(m0,x))
+--E 264
+
+)clear all
+
+--S 265 of 602
+t0:=f^(b*x+c*x^2)*(b+2*c*x)
+--E 265
+
+--S 266 of 602
+r0:=f^(b*x+c*x^2)/log(f)
+--E 266
+
+--S 267 of 602
+d0:=normalize(D(m0,x))
+--E 267
+
+)clear all
+
+--S 268 of 602
+t0:=f^(b*x+c*x^2)/(b+2*c*x)
+--E 268
+
+--S 269 of 602
+--r0:=1/4*Ei(1/4*(b+2*c*x)^2*log(f)/c)/(c*f^(1/4*b^2/c))
+--E 269
+
+--S 270 of 602
+--d0:=normalize(D(m0,x))
+--E 270
+
+)clear all
+
+--S 271 of 602
+t0:=f^(b*x+c*x^2)/(b+2*c*x)^2
+--E 271
+
+--S 272 of 602
+--r0:=-1/2*f^(b*x+c*x^2)/(c*(b+2*c*x))+1/4*erfi(1/2*(b+2*c*x)*_
+--   sqrt(log(f))/sqrt(c))*sqrt(%pi)*sqrt(log(f))/(c^(3/2)*f^(1/4*b^2/c))
+--E 272
+
+--S 273 of 602
+--d0:=normalize(D(m0,x))
+--E 273
+
+)clear all
+
+--S 274 of 602
+t0:=f^(b*x+c*x^2)/(b+2*c*x)^3
+--E 274
+
+--S 275 of 602
+--r0:=-1/4*f^(b*x+c*x^2)/(c*(b+2*c*x)^2)+1/16*Ei(1/4*(b+2*c*x)^2*_
+--   log(f)/c)*log(f)/(c^2*f^(1/4*b^2/c))
+--E 275
+
+--S 276 of 602
+--d0:=normalize(D(m0,x))
+--E 276
+
+)clear all
+
+--S 277 of 602
+t0:=x^3*sqrt(%e^(a+b*x))
+--E 277
+
+--S 278 of 602
+r0:=-96*sqrt(%e^(a+b*x))/b^4+48*x*sqrt(%e^(a+b*x))/b^3-12*x^2*_
+   sqrt(%e^(a+b*x))/b^2+2*x^3*sqrt(%e^(a+b*x))/b
+--E 278
+
+-- integrate: implementation incomplete (constant residues)
+--S 279 of 602
+--d0:=normalize(D(m0,x))
+--E 279
+
+)clear all
+
+--S 280 of 602
+t0:=x^2*sqrt(%e^(a+b*x))
+--E 280
+
+--S 281 of 602
+r0:=16*sqrt(%e^(a+b*x))/b^3-8*x*sqrt(%e^(a+b*x))/b^2+2*x^2*sqrt(%e^(a+b*x))/b
+--E 281
+
+-- integrate: implementation incomplete (constant residues)
+--S 282 of 602
+--d0:=normalize(D(m0,x))
+--E 282
+
+)clear all
+
+--S 283 of 602
+t0:=x*sqrt(%e^(a+b*x))
+--E 283
+
+--S 284 of 602
+r0:=-4*sqrt(%e^(a+b*x))/b^2+2*x*sqrt(%e^(a+b*x))/b
+--E 284
+
+-- integrate: implementation incomplete (constant residues)
+--S 285 of 602
+--d0:=normalize(D(m0,x))
+--E 285
+
+)clear all
+
+--S 286 of 602
+t0:=sqrt(%e^(a+b*x))
+--E 286
+
+--S 287 of 602
+r0:=2*sqrt(%e^(a+b*x))/b
+--E 287
+
+--S 288 of 602
+d0:=normalize(D(m0,x))
+--E 288
+
+)clear all
+
+--S 289 of 602
+t0:=sqrt(%e^(a+b*x))/x
+--E 289
+
+--S 290 of 602
+--r0:=Ei(1/2*b*x)*sqrt(%e^(a+b*x))/%e^(1/2*b*x)
+--E 290
+
+--S 291 of 602
+--d0:=normalize(D(m0,x))
+--E 291
+
+)clear all
+
+--S 292 of 602
+t0:=sqrt(%e^(a+b*x))/x^2
+--E 292
+
+--S 293 of 602
+--r0:=-sqrt(%e^(a+b*x))/x+1/2*b*Ei(1/2*b*x)*sqrt(%e^(a+b*x))/%e^(1/2*b*x)
+--E 293
+
+--S 294 of 602
+--d0:=normalize(D(m0,x))
+--E 294
+
+)clear all
+
+--S 295 of 602
+t0:=sqrt(%e^(a+b*x))/x^3
+--E 295
+
+--S 296 of 602
+--r0:=-1/2*sqrt(%e^(a+b*x))/x^2-1/4*b*sqrt(%e^(a+b*x))/x+1/8*b^2*_
+--   Ei(1/2*b*x)*sqrt(%e^(a+b*x))/%e^(1/2*b*x)
+--E 296
+
+--S 297 of 602
+--d0:=normalize(D(m0,x))
+--E 297
+
+)clear all
+
+--S 298 of 602
+t0:=1/((a+%e^(c+d*x)*b)*x)
+--E 298
+
+--S 299 of 602
+--r0:=Int(1/((a+%e^(c+d*x)*b)*x),x)
+--E 299
+
+--S 300 of 602
+--d0:=normalize(D(m0,x))
+--E 300
+
+)clear all
+
+--S 301 of 602
+t0:=1/(a+%e^(c+d*x)*b)
+--E 301
+
+--S 302 of 602
+r0:=x/a-log(a+%e^(c+d*x)*b)/(a*d)
+--E 302
+
+--S 303 of 602
+d0:=normalize(D(m0,x))
+--E 303
+
+)clear all
+
+--S 304 of 602
+t0:=x/(a+%e^(c+d*x)*b)
+--E 304
+
+--S 305 of 602
+--r0:=1/2*x^2/a-x*log(1+%e^(c+d*x)*b/a)/(a*d)-polylog(2,_
+--   -%e^(c+d*x)*b/a)/(a*d^2)
+--E 305
+
+--S 306 of 602
+--d0:=normalize(D(m0,x))
+--E 306
+
+)clear all
+
+--S 307 of 602
+t0:=x^2/(a+%e^(c+d*x)*b)
+--E 307
+
+--S 308 of 602
+--r0:=1/3*x^3/a-x^2*log(1+%e^(c+d*x)*b/a)/(a*d)-2*x*polylog(2,_
+--   -%e^(c+d*x)*b/a)/(a*d^2)+2*polylog(3,-%e^(c+d*x)*b/a)/(a*d^3)
+--E 308
+
+--S 309 of 602
+--d0:=normalize(D(m0,x))
+--E 309
+
+)clear all
+
+--S 310 of 602
+t0:=x^3/(a+%e^(c+d*x)*b)
+--E 310
+
+--S 311 of 602
+--r0:=1/4*x^4/a-x^3*log(1+%e^(c+d*x)*b/a)/(a*d)-3*x^2*polylog(2,_
+--   -%e^(c+d*x)*b/a)/(a*d^2)+6*x*polylog(3,-%e^(c+d*x)*b/a)/(a*d^3)-_
+--   6*polylog(4,-%e^(c+d*x)*b/a)/(a*d^4)
+--E 311
+
+--S 312 of 602
+--d0:=normalize(D(m0,x))
+--E 312
+
+)clear all
+
+--S 313 of 602
+t0:=1/(a+%e^(c-d*x)*b)
+--E 313
+
+--S 314 of 602
+r0:=x/a+log(a+%e^(c-d*x)*b)/(a*d)
+--E 314
+
+--S 315 of 602
+d0:=normalize(D(m0,x))
+--E 315
+
+)clear all
+
+--S 316 of 602
+t0:=1/(a+%e^(-c-d*x)*b)
+--E 316
+
+--S 317 of 602
+r0:=x/a+log(a+%e^(-c-d*x)*b)/(a*d)
+--E 317
+
+--S 318 of 602
+d0:=normalize(D(m0,x))
+--E 318
+
+)clear all
+
+--S 319 of 602
+t0:=1/((a+%e^(c+d*x)*b)^2*x)
+--E 319
+
+--S 320 of 602
+--r0:=Int(1/((a+%e^(c+d*x)*b)^2*x),x)
+--E 320
+
+--S 321 of 602
+--d0:=normalize(D(m0,x))
+--E 321
+
+)clear all
+
+--S 322 of 602
+t0:=1/(a+%e^(c+d*x)*b)^2
+--E 322
+
+--S 323 of 602
+r0:=1/(a*(a+%e^(c+d*x)*b)*d)+x/a^2-log(a+%e^(c+d*x)*b)/(a^2*d)
+--E 323
+
+--S 324 of 602
+d0:=normalize(D(m0,x))
+--E 324
+
+)clear all
+
+--S 325 of 602
+t0:=x/(a+%e^(c+d*x)*b)^2
+--E 325
+
+--S 326 of 602
+--r0:=-x/(a^2*d)+x/(a*(a+%e^(c+d*x)*b)*d)+1/2*x^2/a^2+log(a+%e^(c+d*x)*b)/_
+--   (a^2*d^2)-x*log(1+%e^(c+d*x)*b/a)/(a^2*d)-polylog(2,-%e^(c+d*x)*_
+--   b/a)/(a^2*d^2)
+--E 326
+
+--S 327 of 602
+--d0:=normalize(D(m0,x))
+--E 327
+
+)clear all
+
+--S 328 of 602
+t0:=x^2/(a+%e^(c+d*x)*b)^2
+--E 328
+
+--S 329 of 602
+--r0:=-x^2/(a^2*d)+x^2/(a*(a+%e^(c+d*x)*b)*d)+1/3*x^3/a^2+2*x*_
+--   log(1+%e^(c+d*x)*b/a)/(a^2*d^2)-x^2*log(1+%e^(c+d*x)*b/a)/(a^2*d)+_
+--   2*polylog(2,-%e^(c+d*x)*b/a)/(a^2*d^3)-2*x*polylog(2,-%e^(c+d*x)*_
+--   b/a)/(a^2*d^2)+2*polylog(3,-%e^(c+d*x)*b/a)/(a^2*d^3)
+--E 329
+
+--S 330 of 602
+--d0:=normalize(D(m0,x))
+--E 330
+
+)clear all
+
+--S 331 of 602
+t0:=x^3/(a+%e^(c+d*x)*b)^2
+--E 331
+
+--S 332 of 602
+--r0:=-x^3/(a^2*d)+x^3/(a*(a+%e^(c+d*x)*b)*d)+1/4*x^4/a^2+3*x^2*_
+--   log(1+%e^(c+d*x)*b/a)/(a^2*d^2)-x^3*log(1+%e^(c+d*x)*b/a)/(a^2*d)+_
+--   6*x*polylog(2,-%e^(c+d*x)*b/a)/(a^2*d^3)-3*x^2*polylog(2,_
+--   -%e^(c+d*x)*b/a)/(a^2*d^2)-6*polylog(3,-%e^(c+d*x)*b/a)/(a^2*d^4)+_
+--   6*x*polylog(3,-%e^(c+d*x)*b/a)/(a^2*d^3)-6*polylog(4,-%e^(c+_
+--   d*x)*b/a)/(a^2*d^4)
+--E 332
+
+--S 333 of 602
+--d0:=normalize(D(m0,x))
+--E 333
+
+)clear all
+
+--S 334 of 602
+t0:=1/(a+%e^(c-d*x)*b)^2
+--E 334
+
+--S 335 of 602
+r0:=(-1)/(a*(a+%e^(c-d*x)*b)*d)+x/a^2+log(a+%e^(c-d*x)*b)/(a^2*d)
+--E 335
+
+--S 336 of 602
+d0:=normalize(D(m0,x))
+--E 336
+
+)clear all
+
+--S 337 of 602
+t0:=1/(a+%e^(-c-d*x)*b)^2
+--E 337
+
+--S 338 of 602
+r0:=(-1)/(a*(a+%e^(-c-d*x)*b)*d)+x/a^2+log(a+%e^(-c-d*x)*b)/(a^2*d)
+--E 338
+
+--S 339 of 602
+d0:=normalize(D(m0,x))
+--E 339
+
+)clear all
+
+--S 340 of 602
+t0:=1/((a+%e^(c+d*x)*b)^3*x)
+--E 340
+
+--S 341 of 602
+--r0:=Int(1/((a+%e^(c+d*x)*b)^3*x),x)
+--E 341
+
+--S 342 of 602
+--d0:=normalize(D(m0,x))
+--E 342
+
+)clear all
+
+--S 343 of 602
+t0:=1/(a+%e^(c+d*x)*b)^3
+--E 343
+
+--S 344 of 602
+r0:=1/2/(a*(a+%e^(c+d*x)*b)^2*d)+1/(a^2*(a+%e^(c+d*x)*b)*d)+x/a^3-_
+   log(a+%e^(c+d*x)*b)/(a^3*d)
+--E 344
+
+--S 345 of 602
+d0:=normalize(D(m0,x))
+--E 345
+
+)clear all
+
+--S 346 of 602
+t0:=x/(a+%e^(c+d*x)*b)^3
+--E 346
+
+--S 347 of 602
+--r0:=(-1/2)/(a^2*(a+%e^(c+d*x)*b)*d^2)-3/2*x/(a^3*d)+1/2*x/(a*(a+_
+--   %e^(c+d*x)*b)^2*d)+x/(a^2*(a+%e^(c+d*x)*b)*d)+1/2*x^2/a^3+3/2*_
+--   log(a+%e^(c+d*x)*b)/(a^3*d^2)-x*log(1+%e^(c+d*x)*b/a)/(a^3*d)-_
+--   polylog(2,-%e^(c+d*x)*b/a)/(a^3*d^2)
+--E 347
+
+--S 348 of 602
+--d0:=normalize(D(m0,x))
+--E 348
+
+)clear all
+
+--S 349 of 602
+t0:=x^2/(a+%e^(c+d*x)*b)^3
+--E 349
+
+--S 350 of 602
+--r0:=x/(a^3*d^2)-x/(a^2*(a+%e^(c+d*x)*b)*d^2)-3/2*x^2/(a^3*d)+1/2*x^2/_
+--   (a*(a+%e^(c+d*x)*b)^2*d)+x^2/(a^2*(a+%e^(c+d*x)*b)*d)+1/3*x^3/a^3-_
+--   log(a+%e^(c+d*x)*b)/(a^3*d^3)+3*x*log(1+%e^(c+d*x)*b/a)/(a^3*d^2)-_
+--   x^2*log(1+%e^(c+d*x)*b/a)/(a^3*d)+3*polylog(2,-%e^(c+d*x)*b/a)/_
+--   (a^3*d^3)-2*x*polylog(2,-%e^(c+d*x)*b/a)/(a^3*d^2)+2*polylog(3,_
+--   -%e^(c+d*x)*b/a)/(a^3*d^3)
+--E 350
+
+--S 351 of 602
+--d0:=normalize(D(m0,x))
+--E 351
+
+)clear all
+
+--S 352 of 602
+--t0:=1 + (b*E^(c + d*x))/a])/(a^3*d^3) + (9*x^2*Log[1 + _
+--   (b*E^(c + d*x))/a])/(2*a^3*d^2) - (x^3*Log[1 + (b*E^(c + d*x))/a])/_
+--   (a^3*d) - (3*PolyLog[2
+--E 352
+
+--S 353 of 602
+--r0:= -((b*E^(c + d*x))/a)
+--E 353
+
+--S 354 of 602
+--d0:=normalize(D(m0,x))
+--E 354
+
+)clear all
+
+--S 355 of 602
+t0:=1/(a+%e^(c-d*x)*b)^3
+--E 355
+
+--S 356 of 602
+r0:=(-1/2)/(a*(a+%e^(c-d*x)*b)^2*d)+(-1)/(a^2*(a+%e^(c-d*x)*b)*d)+x/a^3+_
+   log(a+%e^(c-d*x)*b)/(a^3*d)
+--E 356
+
+--S 357 of 602
+d0:=normalize(D(m0,x))
+--E 357
+
+)clear all
+
+--S 358 of 602
+t0:=1/(a+%e^(-c-d*x)*b)^3
+--E 358
+
+--S 359 of 602
+r0:=(-1/2)/(a*(a+%e^(-c-d*x)*b)^2*d)+(-1)/(a^2*(a+%e^(-c-d*x)*b)*d)+_
+   x/a^3+log(a+%e^(-c-d*x)*b)/(a^3*d)
+--E 359
+
+--S 360 of 602
+d0:=normalize(D(m0,x))
+--E 360
+
+)clear all
+
+--S 361 of 602
+t0:=%e^(a+b*x)/(x^2*(c+d*x^2))
+--E 361
+
+--S 362 of 602
+--r0:=-%e^(a+b*x)/(c*x)+%e^a*b*Ei(b*x)/c+1/2*%e^(a+b*sqrt(-c)/sqrt(d))*_
+--   Ei(-b*(sqrt(-c)-x*sqrt(d))/sqrt(d))*sqrt(d)/(-c)^(3/2)-_
+--   1/2*%e^(a-b*sqrt(-c)/sqrt(d))*Ei(b*(sqrt(-c)+x*sqrt(d))/sqrt(d))*_
+--   sqrt(d)/(-c)^(3/2)
+--E 362
+
+--S 363 of 602
+--d0:=normalize(D(m0,x))
+--E 363
+
+)clear all
+
+--S 364 of 602
+t0:=%e^(a+b*x)/(x*(c+d*x^2))
+--E 364
+
+--S 365 of 602
+--r0:=%e^a*Ei(b*x)/c-1/2*%e^(a+b*sqrt(-c)/sqrt(d))*Ei(-b*(sqrt(-c)-_
+--   x*sqrt(d))/sqrt(d))/c-1/2*%e^(a-b*sqrt(-c)/sqrt(d))*Ei(b*_
+--   (sqrt(-c)+x*sqrt(d))/sqrt(d))/c
+--E 365
+
+--S 366 of 602
+--d0:=normalize(D(m0,x))
+--E 366
+
+)clear all
+
+--S 367 of 602
+t0:=%e^(a+b*x)/(c+d*x^2)
+--E 367
+
+--S 368 of 602
+--r0:=1/2*%e^(a+b*sqrt(-c)/sqrt(d))*Ei(-b*(sqrt(-c)-x*sqrt(d))/sqrt(d))/_
+--   (sqrt(-c)*sqrt(d))-1/2*%e^(a-b*sqrt(-c)/sqrt(d))*Ei(b*(sqrt(-c)+_
+--   x*sqrt(d))/sqrt(d))/(sqrt(-c)*sqrt(d))
+--E 368
+
+--S 369 of 602
+--d0:=normalize(D(m0,x))
+--E 369
+
+)clear all
+
+--S 370 of 602
+t0:=%e^(a+b*x)*x/(c+d*x^2)
+--E 370
+
+--S 371 of 602
+--r0:=1/2*%e^(a+b*sqrt(-c)/sqrt(d))*Ei(-b*(sqrt(-c)-x*sqrt(d))/sqrt(d))/d+_
+--   1/2*%e^(a-b*sqrt(-c)/sqrt(d))*Ei(b*(sqrt(-c)+x*sqrt(d))/sqrt(d))/d
+--E 371
+
+--S 372 of 602
+--d0:=normalize(D(m0,x))
+--E 372
+
+)clear all
+
+--S 373 of 602
+t0:=%e^(a+b*x)*x^2/(c+d*x^2)
+--E 373
+
+--S 374 of 602
+--r0:=%e^(a+b*x)/(b*d)+1/2*%e^(a+b*sqrt(-c)/sqrt(d))*Ei(-b*(sqrt(-c)-_
+--   x*sqrt(d))/sqrt(d))*sqrt(-c)/d^(3/2)-1/2*%e^(a-b*sqrt(-c)/sqrt(d))*_
+--   Ei(b*(sqrt(-c)+x*sqrt(d))/sqrt(d))*sqrt(-c)/d^(3/2)
+--E 374
+
+--S 375 of 602
+--d0:=normalize(D(m0,x))
+--E 375
+
+)clear all
+
+--S 376 of 602
+t0:=%e^(d+e*x)/(x^2*(a+b*x+c*x^2))
+--E 376
+
+--S 377 of 602
+--r0:=-%e^(d+e*x)/(a*x)-%e^d*b*Ei(e*x)/a^2+%e^d*e*Ei(e*x)/a+1/2*_
+--   %e^(d-1/2*e*(b+sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x+sqrt(b^2-_
+--   4*a*c))/c)*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/a^2+1/2*%e^(d-1/2*_
+--   e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x-sqrt(b^2-4*a*c))/c)*_
+--   (b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/a^2
+--E 377
+
+--S 378 of 602
+--d0:=normalize(D(m0,x))
+--E 378
+
+)clear all
+
+--S 379 of 602
+t0:=%e^(d+e*x)/(x*(a+b*x+c*x^2))
+--E 379
+
+--S 380 of 602
+--r0:=%e^d*Ei(e*x)/a-1/2*%e^(d-1/2*e*(b+sqrt(b^2-4*a*c))/c)*Ei(1/2*e*_
+--   (b+2*c*x+sqrt(b^2-4*a*c))/c)*(1-b/sqrt(b^2-4*a*c))/a-1/2*%e^(d-_
+--   1/2*e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x-sqrt(b^2-4*a*c))/c)*_
+--   (1+b/sqrt(b^2-4*a*c))/a
+--E 380
+
+--S 381 of 602
+--d0:=normalize(D(m0,x))
+--E 381
+
+)clear all
+
+--S 382 of 602
+t0:=%e^(d+e*x)/(a+b*x+c*x^2)
+--E 382
+
+--S 383 of 602
+--r0:=%e^(d-1/2*e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x-sqrt(b^2-_
+--   4*a*c))/c)/sqrt(b^2-4*a*c)-%e^(d-1/2*e*(b+sqrt(b^2-4*a*c))/c)*_
+--   Ei(1/2*e*(b+2*c*x+sqrt(b^2-4*a*c))/c)/sqrt(b^2-4*a*c)
+--E 383
+
+--S 384 of 602
+--d0:=normalize(D(m0,x))
+--E 384
+
+)clear all
+
+--S 385 of 602
+t0:=%e^(d+e*x)*x/(a+b*x+c*x^2)
+--E 385
+
+--S 386 of 602
+--r0:=1/2*%e^(d-1/2*e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x-_
+--   sqrt(b^2-4*a*c))/c)*(1-b/sqrt(b^2-4*a*c))/c+1/2*%e^(d-1/2*e*(b+_
+--   sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x+sqrt(b^2-4*a*c))/c)*(1+_
+--   b/sqrt(b^2-4*a*c))/c
+--E 386
+
+--S 387 of 602
+--d0:=normalize(D(m0,x))
+--E 387
+
+)clear all
+
+--S 388 of 602
+t0:=%e^(d+e*x)*x^2/(a+b*x+c*x^2)
+--E 388
+
+--S 389 of 602
+--r0:=%e^(d+e*x)/(c*e)-1/2*%e^(d-1/2*e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*_
+--   (b+2*c*x-sqrt(b^2-4*a*c))/c)*(b+(-b^2+2*a*c)/sqrt(b^2-4*a*c))/c^2-_
+--   1/2*%e^(d-1/2*e*(b+sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x+sqrt(b^2-_
+--   4*a*c))/c)*(b+(b^2-2*a*c)/sqrt(b^2-4*a*c))/c^2
+--E 389
+
+--S 390 of 602
+--d0:=normalize(D(m0,x))
+--E 390
+
+)clear all
+
+--S 391 of 602
+t0:=%e^(d+e*x)*x^3/(a+b*x+c*x^2)
+--E 391
+
+--S 392 of 602
+--r0:=-%e^(d+e*x)/(c*e^2)-%e^(d+e*x)*b/(c^2*e)+%e^(d+e*x)*x/(c*e)+_
+--   1/2*%e^(d-1/2*e*(b-sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x-sqrt(b^2-_
+--   4*a*c))/c)*(b^2-a*c-b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/c^3+1/2*%e^(d-_
+--   1/2*e*(b+sqrt(b^2-4*a*c))/c)*Ei(1/2*e*(b+2*c*x+sqrt(b^2-4*a*c))/c)*_
+--   (b^2-a*c+b*(b^2-3*a*c)/sqrt(b^2-4*a*c))/c^3
+--E 392
+
+--S 393 of 602
+--d0:=normalize(D(m0,x))
+--E 393
+
+)clear all
+
+--S 394 of 602
+t0:=4^x/(a+2^x*b)
+--E 394
+
+--S 395 of 602
+r0:=2^x/(b*log(2))-a*log(a+2^x*b)/(b^2*log(2))
+--E 395
+
+--S 396 of 602
+d0:=normalize(D(m0,x))
+--E 396
+
+)clear all
+
+--S 397 of 602
+t0:=2^(2*x)/(a+2^x*b)
+--E 397
+
+--S 398 of 602
+r0:=2^x/(b*log(2))-a*log(a+2^x*b)/(b^2*log(2))
+--E 398
+
+--S 399 of 602
+d0:=normalize(D(m0,x))
+--E 399
+
+)clear all
+
+--S 400 of 602
+t0:=4^x/(a-2^x*b)
+--E 400
+
+--S 401 of 602
+r0:=-2^x/(b*log(2))-a*log(a-2^x*b)/(b^2*log(2))
+--E 401
+
+--S 402 of 602
+d0:=normalize(D(m0,x))
+--E 402
+
+)clear all
+
+--S 403 of 602
+t0:=2^(2*x)/(a-2^x*b)
+--E 403
+
+--S 404 of 602
+r0:=-2^x/(b*log(2))-a*log(a-2^x*b)/(b^2*log(2))
+--E 404
+
+--S 405 of 602
+d0:=normalize(D(m0,x))
+--E 405
+
+)clear all
+
+--S 406 of 602
+t0:=4^x/(a+b/2^x)
+--E 406
+
+--S 407 of 602
+r0:=2^(-1+2*x)/(a*log(2))-2^x*b/(a^2*log(2))+b^2*log(2^x*a+b)/(a^3*log(2))
+--E 407
+
+--S 408 of 602
+d0:=normalize(D(m0,x))
+--E 408
+
+)clear all
+
+--S 409 of 602
+t0:=2^(2*x)/(a+b/2^x)
+--E 409
+
+--S 410 of 602
+r0:=2^(-1+2*x)/(a*log(2))-2^x*b/(a^2*log(2))+b^2*log(2^x*a+b)/(a^3*log(2))
+--E 410
+
+--S 411 of 602
+d0:=normalize(D(m0,x))
+--E 411
+
+)clear all
+
+--S 412 of 602
+t0:=4^x/(a-b/2^x)
+--E 412
+
+--S 413 of 602
+r0:=2^(-1+2*x)/(a*log(2))+2^x*b/(a^2*log(2))+b^2*log(2^x*a-b)/(a^3*log(2))
+--E 413
+
+--S 414 of 602
+d0:=normalize(D(m0,x))
+--E 414
+
+)clear all
+
+--S 415 of 602
+t0:=2^(2*x)/(a-b/2^x)
+--E 415
+
+--S 416 of 602
+r0:=2^(-1+2*x)/(a*log(2))+2^x*b/(a^2*log(2))+b^2*log(2^x*a-b)/(a^3*log(2))
+--E 416
+
+--S 417 of 602
+d0:=normalize(D(m0,x))
+--E 417
+
+)clear all
+
+--S 418 of 602
+t0:=2^x/(a+4^x*b)
+--E 418
+
+--S 419 of 602
+r0:=atan(2^x*sqrt(b)/sqrt(a))/(log(2)*sqrt(a)*sqrt(b))
+--E 419
+
+--S 420 of 602
+d0:=normalize(D(m0,x))
+--E 420
+
+)clear all
+
+--S 421 of 602
+t0:=2^x/(a+2^(2*x)*b)
+--E 421
+
+--S 422 of 602
+r0:=atan(2^x*sqrt(b)/sqrt(a))/(log(2)*sqrt(a)*sqrt(b))
+--E 422
+
+--S 423 of 602
+d0:=normalize(D(m0,x))
+--E 423
+
+)clear all
+
+--S 424 of 602
+t0:=2^x/(a-4^x*b)
+--E 424
+
+--S 425 of 602
+r0:=atanh(2^x*sqrt(b)/sqrt(a))/(log(2)*sqrt(a)*sqrt(b))
+--E 425
+
+--S 426 of 602
+d0:=normalize(D(m0,x))
+--E 426
+
+)clear all
+
+--S 427 of 602
+t0:=2^x/(a-2^(2*x)*b)
+--E 427
+
+--S 428 of 602
+r0:=atanh(2^x*sqrt(b)/sqrt(a))/(log(2)*sqrt(a)*sqrt(b))
+--E 428
+
+--S 429 of 602
+d0:=normalize(D(m0,x))
+--E 429
+
+)clear all
+
+--S 430 of 602
+t0:=2^x/(a+b/4^x)
+--E 430
+
+--S 431 of 602
+r0:=2^x/(a*log(2))-atan(2^x*sqrt(a)/sqrt(b))*sqrt(b)/(a^(3/2)*log(2))
+--E 431
+
+--S 432 of 602
+d0:=normalize(D(m0,x))
+--E 432
+
+)clear all
+
+--S 433 of 602
+t0:=2^x/(a+b/2^(2*x))
+--E 433
+
+--S 434 of 602
+r0:=2^x/(a*log(2))-atan(2^x*sqrt(a)/sqrt(b))*sqrt(b)/(a^(3/2)*log(2))
+--E 434
+
+--S 435 of 602
+d0:=normalize(D(m0,x))
+--E 435
+
+)clear all
+
+--S 436 of 602
+t0:=2^x/(a-b/4^x)
+--E 436
+
+--S 437 of 602
+r0:=2^x/(a*log(2))-atanh(2^x*sqrt(a)/sqrt(b))*sqrt(b)/(a^(3/2)*log(2))
+--E 437
+
+--S 438 of 602
+d0:=normalize(D(m0,x))
+--E 438
+
+)clear all
+
+--S 439 of 602
+t0:=2^x/(a-b/2^(2*x))
+--E 439
+
+--S 440 of 602
+r0:=2^x/(a*log(2))-atanh(2^x*sqrt(a)/sqrt(b))*sqrt(b)/(a^(3/2)*log(2))
+--E 440
+
+--S 441 of 602
+d0:=normalize(D(m0,x))
+--E 441
+
+)clear all
+
+--S 442 of 602
+t0:=2^x/sqrt(a+4^x*b)
+--E 442
+
+--S 443 of 602
+r0:=atanh(2^x*sqrt(b)/sqrt(a+2^(2*x)*b))/(log(2)*sqrt(b))
+--E 443
+
+-- integrate: implementation incomplete (constant residues)
+--S 444 of 602
+--d0:=normalize(D(m0,x))
+--E 444
+
+)clear all
+
+--S 445 of 602
+t0:=2^x/sqrt(a+2^(2*x)*b)
+--E 445
+
+--S 446 of 602
+r0:=atanh(2^x*sqrt(b)/sqrt(a+2^(2*x)*b))/(log(2)*sqrt(b))
+--E 446
+
+--S 447 of 602
+d0:=normalize(D(m0,x))
+--E 447
+
+)clear all
+
+--S 448 of 602
+t0:=2^x/sqrt(a-4^x*b)
+--E 448
+
+--S 449 of 602
+r0:=atan(2^x*sqrt(b)/sqrt(a-2^(2*x)*b))/(log(2)*sqrt(b))
+--E 449
+
+-- integrate: implementation incomplete (constant residues)
+--S 450 of 602
+--d0:=normalize(D(m0,x))
+--E 450
+
+)clear all
+
+--S 451 of 602
+t0:=2^x/sqrt(a-2^(2*x)*b)
+--E 451
+
+--S 452 of 602
+r0:=atan(2^x*sqrt(b)/sqrt(a-2^(2*x)*b))/(log(2)*sqrt(b))
+--E 452
+
+--S 453 of 602
+d0:=normalize(D(m0,x))
+--E 453
+
+)clear all
+
+--S 454 of 602
+t0:=2^x/sqrt(a+b/4^x)
+--E 454
+
+--S 455 of 602
+r0:=2^x*sqrt(a+b/2^(2*x))/(a*log(2))
+--E 455
+
+-- integrate: implementation incomplete (constant residues)
+--S 456 of 602
+--d0:=normalize(D(m0,x))
+--E 456
+
+)clear all
+
+--S 457 of 602
+t0:=2^x/sqrt(a+b/2^(2*x))
+--E 457
+
+--S 458 of 602
+r0:=2^x*sqrt(a+b/2^(2*x))/(a*log(2))
+--E 458
+
+--S 459 of 602
+d0:=normalize(D(m0,x))
+--E 459
+
+)clear all
+
+--S 460 of 602
+t0:=2^x/sqrt(a-b/4^x)
+--E 460
+
+--S 461 of 602
+r0:=2^x*sqrt(a-b/2^(2*x))/(a*log(2))
+--E 461
+
+-- integrate: implementation incomplete (constant residues)
+--S 462 of 602
+--d0:=normalize(D(m0,x))
+--E 462
+
+)clear all
+
+--S 463 of 602
+t0:=2^x/sqrt(a-b/2^(2*x))
+--E 463
+
+--S 464 of 602
+r0:=2^x*sqrt(a-b/2^(2*x))/(a*log(2))
+--E 464
+
+--S 465 of 602
+d0:=normalize(D(m0,x))
+--E 465
+
+)clear all
+
+--S 466 of 602
+t0:=4^x/sqrt(a+2^x*b)
+--E 466
+
+--S 467 of 602
+r0:=2/3*(a+2^x*b)^(3/2)/(b^2*log(2))-2*a*sqrt(a+2^x*b)/(b^2*log(2))
+--E 467
+
+-- integrate: implementation incomplete (constant residues)
+--S 468 of 602
+--d0:=normalize(D(m0,x))
+--E 468
+
+)clear all
+
+--S 469 of 602
+t0:=2^(2*x)/sqrt(a+2^x*b)
+--E 469
+
+--S 470 of 602
+r0:=2/3*(a+2^x*b)^(3/2)/(b^2*log(2))-2*a*sqrt(a+2^x*b)/(b^2*log(2))
+--E 470
+
+--S 471 of 602
+d0:=normalize(D(m0,x))
+--E 471
+
+)clear all
+
+--S 472 of 602
+t0:=4^x/sqrt(a-2^x*b)
+--E 472
+
+--S 473 of 602
+r0:=2/3*(a-2^x*b)^(3/2)/(b^2*log(2))-2*a*sqrt(a-2^x*b)/(b^2*log(2))
+--E 473
+
+-- integrate: implementation incomplete (constant residues)
+--S 474 of 602
+--d0:=normalize(D(m0,x))
+--E 474
+
+)clear all
+
+--S 475 of 602
+t0:=2^(2*x)/sqrt(a-2^x*b)
+--E 475
+
+--S 476 of 602
+r0:=2/3*(a-2^x*b)^(3/2)/(b^2*log(2))-2*a*sqrt(a-2^x*b)/(b^2*log(2))
+--E 476
+
+--S 477 of 602
+d0:=normalize(D(m0,x))
+--E 477
+
+)clear all
+
+--S 478 of 602
+t0:=4^x/sqrt(a+b/2^x)
+--E 478
+
+--S 479 of 602
+r0:=3/4*b^2*atanh(sqrt(a+b/2^x)/sqrt(a))/(a^(5/2)*log(2))+2^(-1+2*x)*_
+   sqrt(a+b/2^x)/(a*log(2))-3*2^(-2+x)*b*sqrt(a+b/2^x)/(a^2*log(2))
+--E 479
+
+-- integrate: implementation incomplete (constant residues)
+--S 480 of 602
+--d0:=normalize(D(m0,x))
+--E 480
+
+)clear all
+
+--S 481 of 602
+t0:=2^(2*x)/sqrt(a+b/2^x)
+--E 481
+
+--S 482 of 602
+r0:=3/4*b^2*atanh(sqrt(a+b/2^x)/sqrt(a))/(a^(5/2)*log(2))+2^(-1+2*x)*_
+   sqrt(a+b/2^x)/(a*log(2))-3*2^(-2+x)*b*sqrt(a+b/2^x)/(a^2*log(2))
+--E 482
+
+--S 483 of 602
+d0:=normalize(D(m0,x))
+--E 483
+
+)clear all
+
+--S 484 of 602
+t0:=4^x/sqrt(a-b/2^x)
+--E 484
+
+--S 485 of 602
+r0:=3/4*b^2*atanh(sqrt(a-b/2^x)/sqrt(a))/(a^(5/2)*log(2))+2^(-1+2*x)*_
+   sqrt(a-b/2^x)/(a*log(2))+3*2^(-2+x)*b*sqrt(a-b/2^x)/(a^2*log(2))
+--E 485
+
+-- integrate: implementation incomplete (constant residues)
+--S 486 of 602
+--d0:=normalize(D(m0,x))
+--E 486
+
+)clear all
+
+--S 487 of 602
+t0:=2^(2*x)/sqrt(a-b/2^x)
+--E 487
+
+--S 488 of 602
+r0:=3/4*b^2*atanh(sqrt(a-b/2^x)/sqrt(a))/(a^(5/2)*log(2))+2^(-1+2*x)*_
+   sqrt(a-b/2^x)/(a*log(2))+3*2^(-2+x)*b*sqrt(a-b/2^x)/(a^2*log(2))
+--E 488
+
+--S 489 of 602
+d0:=normalize(D(m0,x))
+--E 489
+
+)clear all
+
+--S 490 of 602
+t0:=f^(c+d*x)*x^3/(a+b*f^(c+d*x))
+--E 490
+
+--S 491 of 602
+--r0:=x^3*log(1+b*f^(c+d*x)/a)/(b*d*log(f))+3*x^2*polylog(2,-b*f^(c+_
+--   d*x)/a)/(b*d^2*log(f)^2)-6*x*polylog(3,-b*f^(c+d*x)/a)/(b*d^3*_
+--   log(f)^3)+6*polylog(4,-b*f^(c+d*x)/a)/(b*d^4*log(f)^4)
+--E 491
+
+--S 492 of 602
+--d0:=normalize(D(m0,x))
+--E 492
+
+)clear all
+
+--S 493 of 602
+t0:=f^(c+d*x)*x^2/(a+b*f^(c+d*x))
+--E 493
+
+--S 494 of 602
+--r0:=x^2*log(1+b*f^(c+d*x)/a)/(b*d*log(f))+2*x*polylog(2,-b*f^(c+_
+--   d*x)/a)/(b*d^2*log(f)^2)-2*polylog(3,-b*f^(c+d*x)/a)/(b*d^3*log(f)^3)
+--E 494
+
+--S 495 of 602
+--d0:=normalize(D(m0,x))
+--E 495
+
+)clear all
+
+--S 496 of 602
+t0:=f^(c+d*x)*x/(a+b*f^(c+d*x))
+--E 496
+
+--S 497 of 602
+--r0:=x*log(1+b*f^(c+d*x)/a)/(b*d*log(f))+polylog(2,-b*f^(c+d*x)/a)/_
+--   (b*d^2*log(f)^2)
+--E 497
+
+--S 498 of 602
+--d0:=normalize(D(m0,x))
+--E 498
+
+)clear all
+
+--S 499 of 602
+t0:=f^(c+d*x)/(a+b*f^(c+d*x))
+--E 499
+
+--S 500 of 602
+r0:=log(a+b*f^(c+d*x))/(b*d*log(f))
+--E 500
+
+--S 501 of 602
+d0:=normalize(D(m0,x))
+--E 501
+
+)clear all
+
+--S 502 of 602
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))*x)
+--E 502
+
+--S 503 of 602
+--r0:=Int(f^(c+d*x)/((a+b*f^(c+d*x))*x),x)
+--E 503
+
+--S 504 of 602
+--d0:=normalize(D(m0,x))
+--E 504
+
+)clear all
+
+--S 505 of 602
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))*x^2)
+--E 505
+
+--S 506 of 602
+--r0:=Int(f^(c+d*x)/((a+b*f^(c+d*x))*x^2),x)
+--E 506
+
+--S 507 of 602
+--d0:=normalize(D(m0,x))
+--E 507
+
+)clear all
+
+--S 508 of 602
+t0:=f^(c+d*x)*x^3/(a+b*f^(c+d*x))^2
+--E 508
+
+--S 509 of 602
+--r0:=x^3/(a*b*d*log(f))-x^3/(b*d*(a+b*f^(c+d*x))*log(f))-3*x^2*log(1+b*_
+--   f^(c+d*x)/a)/(a*b*d^2*log(f)^2)-6*x*polylog(2,-b*f^(c+d*x)/a)/_
+--   (a*b*d^3*log(f)^3)+6*polylog(3,-b*f^(c+d*x)/a)/(a*b*d^4*log(f)^4)
+--E 509
+
+--S 510 of 602
+--d0:=normalize(D(m0,x))
+--E 510
+
+)clear all
+
+--S 511 of 602
+t0:=f^(c+d*x)*x^2/(a+b*f^(c+d*x))^2
+--E 511
+
+--S 512 of 602
+--r0:=x^2/(a*b*d*log(f))-x^2/(b*d*(a+b*f^(c+d*x))*log(f))-2*x*log(1+_
+--   b*f^(c+d*x)/a)/(a*b*d^2*log(f)^2)-2*polylog(2,-b*f^(c+d*x)/a)/_
+--   (a*b*d^3*log(f)^3)
+--E 512
+
+--S 513 of 602
+--d0:=normalize(D(m0,x))
+--E 513
+
+)clear all
+
+--S 514 of 602
+t0:=f^(c+d*x)*x/(a+b*f^(c+d*x))^2
+--E 514
+
+--S 515 of 602
+r0:=x/(a*b*d*log(f))-x/(b*d*(a+b*f^(c+d*x))*log(f))-log(a+b*f^(c+d*x))/_
+   (a*b*d^2*log(f)^2)
+--E 515
+
+--S 516 of 602
+d0:=normalize(D(m0,x))
+--E 516
+
+)clear all
+
+--S 517 of 602
+t0:=f^(c+d*x)/(a+b*f^(c+d*x))^2
+--E 517
+
+--S 518 of 602
+r0:=(-1)/(b*d*(a+b*f^(c+d*x))*log(f))
+--E 518
+
+--S 519 of 602
+d0:=normalize(D(m0,x))
+--E 519
+
+)clear all
+
+--S 520 of 602
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))^2*x)
+--E 520
+
+--S 521 of 602
+--r0:=(-1)/(b*d*(a+b*f^(c+d*x))*x*log(f))-Int(1/((a+b*f^(c+d*x))*x^2),x)/_
+--   (b*d*log(f))
+--E 521
+
+--S 522 of 602
+--d0:=normalize(D(m0,x))
+--E 522
+
+)clear all
+
+--S 523 of 602
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))^2*x^2)
+--E 523
+
+--S 524 of 602
+--r0:=(-1)/(b*d*(a+b*f^(c+d*x))*x^2*log(f))-2*Int(1/((a+b*f^(c+d*x))*_
+--   x^3),x)/(b*d*log(f))
+--E 524
+
+--S 525 of 602
+--d0:=normalize(D(m0,x))
+--E 525
+
+)clear all
+
+--S 526 of 602
+t0:=f^(c+d*x)*x^3/(a+b*f^(c+d*x))^3
+--E 526
+
+--S 527 of 602
+--r0:=-3/2*x^2/(a^2*b*d^2*log(f)^2)+3/2*x^2/(a*b*d^2*(a+b*f^(c+d*x))*_
+--   log(f)^2)+1/2*x^3/(a^2*b*d*log(f))-1/2*x^3/(b*d*(a+b*f^(c+d*x))^2*_
+--   log(f))+3*x*log(1+b*f^(c+d*x)/a)/(a^2*b*d^3*log(f)^3)-3/2*x^2*_
+--   log(1+b*f^(c+d*x)/a)/(a^2*b*d^2*log(f)^2)+3*polylog(2,-b*f^(c+_
+--   d*x)/a)/(a^2*b*d^4*log(f)^4)-3*x*polylog(2,-b*f^(c+d*x)/a)/(a^2*b*_
+--   d^3*log(f)^3)+3*polylog(3,-b*f^(c+d*x)/a)/(a^2*b*d^4*log(f)^4)
+--E 527
+
+--S 528 of 602
+--d0:=normalize(D(m0,x))
+--E 528
+
+)clear all
+
+--S 529 of 602
+t0:=f^(c+d*x)*x^2/(a+b*f^(c+d*x))^3
+--E 529
+
+--S 530 of 602
+--r0:=-x/(a^2*b*d^2*log(f)^2)+x/(a*b*d^2*(a+b*f^(c+d*x))*log(f)^2)+1/2*x^2/_
+--   (a^2*b*d*log(f))-1/2*x^2/(b*d*(a+b*f^(c+d*x))^2*log(f))+log(a+b*_
+--   f^(c+d*x))/(a^2*b*d^3*log(f)^3)-x*log(1+b*f^(c+d*x)/a)/(a^2*b*d^2*_
+--   log(f)^2)-polylog(2,-b*f^(c+d*x)/a)/(a^2*b*d^3*log(f)^3)
+--E 530
+
+--S 531 of 602
+--d0:=normalize(D(m0,x))
+--E 531
+
+)clear all
+
+--S 532 of 602
+t0:=f^(c+d*x)*x/(a+b*f^(c+d*x))^3
+--E 532
+
+--S 533 of 602
+r0:=1/2/(a*b*d^2*(a+b*f^(c+d*x))*log(f)^2)+1/2*x/(a^2*b*d*log(f))-1/2*x/_
+   (b*d*(a+b*f^(c+d*x))^2*log(f))-1/2*log(a+b*f^(c+d*x))/(a^2*b*d^2*log(f)^2)
+--E 533
+
+--S 534 of 602
+d0:=normalize(D(m0,x))
+--E 534
+
+)clear all
+
+--S 535 of 602
+t0:=f^(c+d*x)/(a+b*f^(c+d*x))^3
+--E 535
+
+--S 536 of 602
+r0:=(-1/2)/(b*d*(a+b*f^(c+d*x))^2*log(f))
+--E 536
+
+--S 537 of 602
+d0:=normalize(D(m0,x))
+--E 537
+
+)clear all
+
+--S 538 of 602
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))^3*x)
+--E 538
+
+--S 539 of 602
+--r0:=(-1/2)/(b*d*(a+b*f^(c+d*x))^2*x*log(f))-1/2*Int(1/((a+b*f^(c+d*x))^2*_
+--   x^2),x)/(b*d*log(f))
+--E 539
+
+--S 540 of 602
+--d0:=normalize(D(m0,x))
+--E 540
+
+)clear all
+
+--S 541 of 602
+t0:=f^(c+d*x)/((a+b*f^(c+d*x))^3*x^2)
+--E 541
+
+--S 542 of 602
+--r0:=(-1/2)/(b*d*(a+b*f^(c+d*x))^2*x^2*log(f))-Int(1/((a+b*f^(c+d*x))^2*_
+--   x^3),x)/(b*d*log(f))
+--E 542
+
+--S 543 of 602
+--d0:=normalize(D(m0,x))
+--E 543
+
+)clear all
+
+--S 544 of 602
+t0:=%e^x/(4+6*%e^x)
+--E 544
+
+--S 545 of 602
+r0:=1/6*log(2+3*%e^x)
+--E 545
+
+--S 546 of 602
+d0:=normalize(D(m0,x))
+--E 546
+
+)clear all
+
+--S 547 of 602
+t0:=%e^x/(a+%e^x*b)
+--E 547
+
+--S 548 of 602
+r0:=log(a+%e^x*b)/b
+--E 548
+
+--S 549 of 602
+d0:=normalize(D(m0,x))
+--E 549
+
+)clear all
+
+--S 550 of 602
+t0:=%e^(d*x)/(a+%e^(c+d*x)*b)
+--E 550
+
+--S 551 of 602
+r0:=log(a+%e^(c+d*x)*b)/(%e^c*b*d)
+--E 551
+
+--S 552 of 602
+d0:=normalize(D(m0,x))
+--E 552
+
+)clear all
+
+--S 553 of 602
+t0:=%e^(c+d*x)/(a+%e^(c+d*x)*b)
+--E 553
+
+--S 554 of 602
+r0:=log(a+%e^(c+d*x)*b)/(b*d)
+--E 554
+
+--S 555 of 602
+d0:=normalize(D(m0,x))
+--E 555
+
+)clear all
+
+--S 556 of 602
+t0:=%e^x*(a+%e^x*b)^n
+--E 556
+
+--S 557 of 602
+r0:=(a+%e^x*b)^(1+n)/(b*(1+n))
+--E 557
+
+--S 558 of 602
+d0:=normalize(D(m0,x))
+--E 558
+
+)clear all
+
+--S 559 of 602
+t0:=%e^(d*x)*(a+%e^(c+d*x)*b)^n
+--E 559
+
+--S 560 of 602
+r0:=(a+%e^(c+d*x)*b)^(1+n)/(%e^c*b*d*(1+n))
+--E 560
+
+--S 561 of 602
+d0:=normalize(D(m0,x))
+--E 561
+
+)clear all
+
+--S 562 of 602
+t0:=%e^(c+d*x)*(a+%e^(c+d*x)*b)^n
+--E 562
+
+--S 563 of 602
+r0:=(a+%e^(c+d*x)*b)^(1+n)/(b*d*(1+n))
+--E 563
+
+--S 564 of 602
+d0:=normalize(D(m0,x))
+--E 564
+
+)clear all
+
+--S 565 of 602
+t0:=f^x/(a+b*f^x)
+--E 565
+
+--S 566 of 602
+r0:=log(a+b*f^x)/(b*log(f))
+--E 566
+
+--S 567 of 602
+d0:=normalize(D(m0,x))
+--E 567
+
+)clear all
+
+--S 568 of 602
+t0:=f^(d*x)/(a+b*f^(c+d*x))
+--E 568
+
+--S 569 of 602
+r0:=log(a+b*f^(c+d*x))/(b*d*f^c*log(f))
+--E 569
+
+--S 570 of 602
+d0:=normalize(D(m0,x))
+--E 570
+
+)clear all
+
+--S 571 of 602
+t0:=f^(c+d*x)/(a+b*f^(c+d*x))
+--E 571
+
+--S 572 of 602
+r0:=log(a+b*f^(c+d*x))/(b*d*log(f))
+--E 572
+
+--S 573 of 602
+d0:=normalize(D(m0,x))
+--E 573
+
+)clear all
+
+--S 574 of 602
+t0:=f^x*(a+b*f^x)^n
+--E 574
+
+--S 575 of 602
+r0:=(a+b*f^x)^(1+n)/(b*(1+n)*log(f))
+--E 575
+
+--S 576 of 602
+d0:=normalize(D(m0,x))
+--E 576
+
+)clear all
+
+--S 577 of 602
+t0:=f^(d*x)*(a+b*f^(c+d*x))^n
+--E 577
+
+--S 578 of 602
+r0:=(a+b*f^(c+d*x))^(1+n)/(b*d*f^c*(1+n)*log(f))
+--E 578
+
+--S 579 of 602
+d0:=normalize(D(m0,x))
+--E 579
+
+)clear all
+
+--S 580 of 602
+t0:=f^(c+d*x)*(a+b*f^(c+d*x))^n
+--E 580
+
+--S 581 of 602
+r0:=(a+b*f^(c+d*x))^(1+n)/(b*d*(1+n)*log(f))
+--E 581
+
+--S 582 of 602
+d0:=normalize(D(m0,x))
+--E 582
+
+)clear all
+
+--S 583 of 602
+t0:=1/(1+2*%e^x+%e^(2*x))
+--E 583
+
+--S 584 of 602
+r0:=1/(1+%e^x)+x-log(1+%e^x)
+--E 584
+
+--S 585 of 602
+d0:=normalize(D(m0,x))
+--E 585
+
+)clear all
+
+--S 586 of 602
+t0:=1/(2+3*%e^x+%e^(2*x))
+--E 586
+
+--S 587 of 602
+r0:=1/2*x-log(1+%e^x)+1/2*log(2+%e^x)
+--E 587
+
+--S 588 of 602
+d0:=normalize(D(m0,x))
+--E 588
+
+)clear all
+
+--S 589 of 602
+t0:=1/(-1+%e^x+%e^(2*x))
+--E 589
+
+--S 590 of 602
+r0:=-x+1/10*log(1+2*%e^x+sqrt(5))*(5-sqrt(5))+1/10*log(1+2*%e^x-sqrt(5))*_
+   (5+sqrt(5))
+--E 590
+
+--S 591 of 602
+d0:=normalize(D(m0,x))
+--E 591
+
+)clear all
+
+--S 592 of 602
+t0:=1/(3+3*%e^x+%e^(2*x))
+--E 592
+
+--S 593 of 602
+--r0:=1/3*x-1/6*log(3+3*%e^x+%e^(2*x))-atan((3+2*%e^x)/sqrt(3))/sqrt(3)
+--E 593
+
+--S 594 of 602
+--d0:=normalize(D(m0,x))
+--E 594
+
+)clear all
+
+--S 595 of 602
+t0:=1/(a+%e^x*b+%e^(2*x)*c)
+--E 595
+
+--S 596 of 602
+r0:=x/a-1/2*log(a+%e^x*b+%e^(2*x)*c)/a+b*atanh((b+2*%e^x*c)/sqrt(b^2-_
+   4*a*c))/(a*sqrt(b^2-4*a*c))
+--E 596
+
+--S 597 of 602
+d0a:=normalize(D(m0a,x))
+--E 597
+
+--S 598 of 602
+m0b:=a0.2-r0
+--E 598
+
+--S 599 of 602
+d0b:=normalize(D(m0b,x))
+--E 599
+
+)clear all
+
+--S 600 of 602
+t0:=x/(1+2*%e^x+%e^(2*x))
+--E 600
+
+--S 601 of 602
+--r0:=-x+x/(1+%e^x)+1/2*x^2+log(1+%e^x)-x*log(1+%e^x)-polylog(2,-%e^x)
+--E 601
+
+--S 602 of 602
+--d0:=normalize(D(m0,x))
+--E 602
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder24d.input.pamphlet b/src/input/richder24d.input.pamphlet
new file mode 100644
index 0000000..fc8111b
--- /dev/null
+++ b/src/input/richder24d.input.pamphlet
@@ -0,0 +1,6308 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder24d.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+Exponential Functions
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder24d.output
+)spool richder24d.output
+)set message test on
+)set message auto off
+)clear all
+
+
+--S 1 of 600
+t0:=x/(2+3*%e^x+%e^(2*x))
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 2
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 600
+--r0:=1/4*x^2+1/2*x*log(1+1/2*%e^x)-x*log(1+%e^x)-polylog(2,-%e^x)+_
+--  1/2*polylog(2,-1/2*%e^x)
+--E 2
+
+--S 3 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 3
+
+)clear all
+
+--S 4 of 600
+t0:=x/(-1+%e^x+%e^(2*x))
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R          2x     x
+--R        %e   + %e  - 1
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 600
+--r0:=x^2/((1-sqrt(5))*sqrt(5))-2*x*log(1+2*%e^x/(1-sqrt(5)))/((1-sqrt(5))*_
+--  sqrt(5))-2*polylog(2,-2*%e^x/(1-sqrt(5)))/((1-sqrt(5))*sqrt(5))-_
+--  x^2/(sqrt(5)*(1+sqrt(5)))+2*x*log(1+2*%e^x/(1+sqrt(5)))/(sqrt(5)*_
+--  (1+sqrt(5)))+2*polylog(2,-2*%e^x/(1+sqrt(5)))/(sqrt(5)*(1+sqrt(5)))
+--E 5
+
+--S 6 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 6
+
+)clear all
+
+--S 7 of 600
+t0:=x/(3+3*%e^x+%e^(2*x))
+--R 
+--R
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 3
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 600
+--r0:=-x^2/((3*%i-sqrt(3))*sqrt(3))+2*x*log(1+2*%e^x/(3+%i*sqrt(3)))/_
+--  ((3*%i-sqrt(3))*sqrt(3))+2*polylog(2,-2*%e^x/(3+%i*sqrt(3)))/_
+--  ((3*%i-sqrt(3))*sqrt(3))+x^2/(sqrt(3)*(3*%i+sqrt(3)))-_
+--  2*x*log(1+2*%e^x/(3-%i*sqrt(3)))/(sqrt(3)*(3*%i+sqrt(3)))-_
+--  2*polylog(2,-2*%e^x/(3-%i*sqrt(3)))/(sqrt(3)*(3*%i+sqrt(3)))
+--E 8
+
+--S 9 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 9
+
+)clear all
+
+--S 10 of 600
+t0:=x/(a+%e^x*b+%e^(2*x)*c)
+--R 
+--R
+--R                 x
+--R   (1)  ------------------
+--R            2x       x
+--R        c %e   + b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 600
+--r0:=-c*x^2/(b^2-4*a*c-b*sqrt(b^2-4*a*c))+2*c*x*log(1+2*%e^x*c/(b-_
+--  sqrt(b^2-4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-4*a*c))+2*c*polylog(2,_
+--  -2*%e^x*c/(b-sqrt(b^2-4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-4*a*c))-_
+--  c*x^2/(b^2-4*a*c+b*sqrt(b^2-4*a*c))+2*c*x*log(1+2*%e^x*c/(b+_
+--  sqrt(b^2-4*a*c)))/(b^2-4*a*c+b*sqrt(b^2-4*a*c))+2*c*_
+--  polylog(2,-2*%e^x*c/(b+sqrt(b^2-4*a*c)))/(b^2-4*a*c+b*sqrt(b^2-4*a*c))
+--E 11
+
+--S 12 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 12
+
+)clear all
+
+--S 13 of 600
+t0:=x^2/(1+2*%e^x+%e^(2*x))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 600
+--r0:=-x^2+x^2/(1+%e^x)+1/3*x^3+2*x*log(1+%e^x)-x^2*log(1+%e^x)+_
+--  2*polylog(2,-%e^x)-2*x*polylog(2,-%e^x)+2*polylog(3,-%e^x)
+--E 14
+
+--S 15 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 15
+
+)clear all
+
+--S 16 of 600
+t0:=x^2/(2+3*%e^x+%e^(2*x))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 2
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 600
+--r0:=1/6*x^3+1/2*x^2*log(1+1/2*%e^x)-x^2*log(1+%e^x)-2*x*polylog(2,-%e^x)+_
+--  x*polylog(2,-1/2*%e^x)+2*polylog(3,-%e^x)-polylog(3,-1/2*%e^x)
+--E 17
+
+--S 18 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 18
+
+)clear all
+
+--S 19 of 600
+t0:=x^2/(-1+%e^x+%e^(2*x))
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R          2x     x
+--R        %e   + %e  - 1
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 600
+--r0:=2/3*x^3/((1-sqrt(5))*sqrt(5))-2*x^2*log(1+2*%e^x/(1-sqrt(5)))/_
+--  ((1-sqrt(5))*sqrt(5))-4*x*polylog(2,-2*%e^x/(1-sqrt(5)))/((1-sqrt(5))*_
+--  sqrt(5))+4*polylog(3,-2*%e^x/(1-sqrt(5)))/((1-sqrt(5))*sqrt(5))-_
+--  2/3*x^3/(sqrt(5)*(1+sqrt(5)))+2*x^2*log(1+2*%e^x/(1+sqrt(5)))/_
+--  (sqrt(5)*(1+sqrt(5)))+4*x*polylog(2,-2*%e^x/(1+sqrt(5)))/_
+--  (sqrt(5)*(1+sqrt(5)))-4*polylog(3,-2*%e^x/(1+sqrt(5)))/_
+--  (sqrt(5)*(1+sqrt(5)))
+--E 20
+
+--S 21 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 21
+
+)clear all
+
+--S 22 of 600
+t0:=x^2/(3+3*%e^x+%e^(2*x))
+--R 
+--R
+--R                2
+--R               x
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 3
+--R                                                    Type: Expression(Integer)
+--E 22
+
+--S 23 of 600
+--r0:=-2/3*x^3/((3*%i-sqrt(3))*sqrt(3))+2*x^2*log(1+2*%e^x/(3+%i*sqrt(3)))/_
+--  ((3*%i-sqrt(3))*sqrt(3))+4*x*polylog(2,-2*%e^x/(3+%i*sqrt(3)))/_
+--  ((3*%i-sqrt(3))*sqrt(3))-4*polylog(3,-2*%e^x/(3+%i*sqrt(3)))/_
+--  ((3*%i-sqrt(3))*sqrt(3))+2/3*x^3/(sqrt(3)*(3*%i+sqrt(3)))-2*x^2*_
+--  log(1+2*%e^x/(3-%i*sqrt(3)))/(sqrt(3)*(3*%i+sqrt(3)))-4*x*_
+--  polylog(2,-2*%e^x/(3-%i*sqrt(3)))/(sqrt(3)*(3*%i+sqrt(3)))+4*_
+--  polylog(3,-2*%e^x/(3-%i*sqrt(3)))/(sqrt(3)*(3*%i+sqrt(3)))
+--E 23
+
+--S 24 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 24
+
+)clear all
+
+--S 25 of 600
+t0:=x^2/(a+%e^x*b+%e^(2*x)*c)
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  ------------------
+--R            2x       x
+--R        c %e   + b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 25
+
+--S 26 of 600
+--r0:=-2/3*c*x^3/(b^2-4*a*c-b*sqrt(b^2-4*a*c))+2*c*x^2*log(1+2*%e^x*c/(b-_
+--  sqrt(b^2-4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-4*a*c))+4*c*x*polylog(2,_
+--  -2*%e^x*c/(b-sqrt(b^2-4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-4*a*c))-4*c*_
+--  polylog(3,-2*%e^x*c/(b-sqrt(b^2-4*a*c)))/(b^2-4*a*c-b*sqrt(b^2-_
+--  4*a*c))-2/3*c*x^3/(b^2-4*a*c+b*sqrt(b^2-4*a*c))+2*c*x^2*log(1+_
+--  2*%e^x*c/(b+sqrt(b^2-4*a*c)))/(b^2-4*a*c+b*sqrt(b^2-4*a*c))+_
+--  4*c*x*polylog(2,-2*%e^x*c/(b+sqrt(b^2-4*a*c)))/(b^2-4*a*c+b*_
+--  sqrt(b^2-4*a*c))-4*c*polylog(3,-2*%e^x*c/(b+sqrt(b^2-4*a*c)))/_
+--  (b^2-4*a*c+b*sqrt(b^2-4*a*c))
+--E 26
+
+--S 27 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 27
+
+)clear all
+
+--S 28 of 600
+t0:=1/(1+2*f^(c+d*x)+f^(2*c+2*d*x))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R         2d x + 2c     d x + c
+--R        f          + 2f        + 1
+--R                                                    Type: Expression(Integer)
+--E 28
+
+--S 29 of 600
+r0:=x+1/(d*(1+f^(c+d*x))*log(f))-log(1+f^(c+d*x))/(d*log(f))
+--R 
+--R
+--R   (2)
+--R       d x + c          d x + c                   d x + c
+--R   (- f        - 1)log(f        + 1) + d x log(f)f        + d x log(f) + 1
+--R   -----------------------------------------------------------------------
+--R                                  d x + c
+--R                         d log(f)f        + d log(f)
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 600
+t0:=1/(a+b*f^(c+d*x)+c*f^(2*c+2*d*x))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R           2d x + 2c      d x + c
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 31
+
+--S 32 of 600
+r0:=x/a-1/2*log(a+b*f^(c+d*x)+c*f^(2*c+2*d*x))/(a*d*log(f))+b*_
+   atanh((b+2*c*f^(c+d*x))/sqrt(b^2-4*a*c))/(a*d*log(f)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +-----------+
+--R          |          2        2d x + 2c      d x + c
+--R       - \|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                    d x + c                    +-----------+
+--R                2c f        + b                |          2
+--R       2b atanh(---------------) + 2d x log(f)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a d log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 600
+t0:=1/(a+b*f^(g+h*x)+c*f^(2*(g+h*x)))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R           2h x + 2g      h x + g
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 34
+
+--S 35 of 600
+r0:=x/a-1/2*log(a+b*f^(g+h*x)+c*f^(2*g+2*h*x))/(a*h*log(f))+_
+   b*atanh((b+2*c*f^(g+h*x))/sqrt(b^2-4*a*c))/(a*h*log(f)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R          +-----------+
+--R          |          2        2h x + 2g      h x + g
+--R       - \|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                    h x + g                    +-----------+
+--R                2c f        + b                |          2
+--R       2b atanh(---------------) + 2h x log(f)\|- 4a c + b
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a h log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 600
+t0:=x/(1+2*f^(c+d*x)+f^(2*c+2*d*x))
+--R 
+--R
+--R                     x
+--R   (1)  --------------------------
+--R         2d x + 2c     d x + c
+--R        f          + 2f        + 1
+--R                                                    Type: Expression(Integer)
+--E 37
+
+--S 38 of 600
+--r0:=1/2*x^2-x/(d*log(f))+x/(d*(1+f^(c+d*x))*log(f))+log(1+f^(c+d*x))/_
+--  (d^2*log(f)^2)-x*log(1+f^(c+d*x))/(d*log(f))-_
+--  polylog(2,-f^(c+d*x))/(d^2*log(f)^2)
+--E 38
+
+--S 39 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 39
+
+)clear all
+
+--S 40 of 600
+t0:=x/(a+b*f^(c+d*x)+c*f^(2*c+2*d*x))
+--R 
+--R
+--R                      x
+--R   (1)  -----------------------------
+--R           2d x + 2c      d x + c
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 40
+
+--S 41 of 600
+--r0:=-2*c*x*log(1+2*c*f^(c+d*x)/(b-sqrt(b^2-4*a*c)))/(d*log(f)*_
+--  (b-sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))-2*c*polylog(2,-2*c*f^(c+d*x)/_
+--  (b-sqrt(b^2-4*a*c)))/(d^2*log(f)^2*(b-sqrt(b^2-4*a*c))*_
+--  sqrt(b^2-4*a*c))+2*c*x*log(1+2*c*f^(c+d*x)/(b+sqrt(b^2-4*a*c)))/_
+--  (d*log(f)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))+2*c*_
+--  polylog(2,-2*c*f^(c+d*x)/(b+sqrt(b^2-4*a*c)))/(d^2*log(f)^2*_
+--  sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))-c*x^2/(b^2-4*a*c-_
+--  b*sqrt(b^2-4*a*c))-c*x^2/(b^2-4*a*c+b*sqrt(b^2-4*a*c))
+--E 41
+
+--S 42 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 42
+
+)clear all
+
+--S 43 of 600
+t0:=x^2/(1+2*f^(c+d*x)+f^(2*c+2*d*x))
+--R 
+--R
+--R                     2
+--R                    x
+--R   (1)  --------------------------
+--R         2d x + 2c     d x + c
+--R        f          + 2f        + 1
+--R                                                    Type: Expression(Integer)
+--E 43
+
+--S 44 of 600
+--r0:=1/3*x^3-x^2/(d*log(f))+x^2/(d*(1+f^(c+d*x))*log(f))+2*x*_
+--  log(1+f^(c+d*x))/(d^2*log(f)^2)-x^2*log(1+f^(c+d*x))/(d*log(f))+_
+--  2*polylog(2,-f^(c+d*x))/(d^3*log(f)^3)-2*x*polylog(2,-f^(c+d*x))/_
+--  (d^2*log(f)^2)+2*polylog(3,-f^(c+d*x))/(d^3*log(f)^3)
+--E 44
+
+--S 45 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 45
+
+)clear all
+
+--S 46 of 600
+t0:=x^2/(a+b*f^(c+d*x)+c*f^(2*c+2*d*x))
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R           2d x + 2c      d x + c
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 46
+
+--S 47 of 600
+--r0:=-2*c*x^2*log(1+2*c*f^(c+d*x)/(b-sqrt(b^2-4*a*c)))/(d*log(f)*_
+--  (b-sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))-4*c*x*polylog(2,-2*c*f^(c+d*x)/_
+--  (b-sqrt(b^2-4*a*c)))/(d^2*log(f)^2*(b-sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))+_
+--  4*c*polylog(3,-2*c*f^(c+d*x)/(b-sqrt(b^2-4*a*c)))/(d^3*log(f)^3*(b-_
+--  sqrt(b^2-4*a*c))*sqrt(b^2-4*a*c))+2*c*x^2*log(1+2*c*f^(c+d*x)/(b+_
+--  sqrt(b^2-4*a*c)))/(d*log(f)*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))+_
+--  4*c*x*polylog(2,-2*c*f^(c+d*x)/(b+sqrt(b^2-4*a*c)))/(d^2*log(f)^2*_
+--  sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))-4*c*polylog(3,-2*c*f^(c+d*x)/_
+--  (b+sqrt(b^2-4*a*c)))/(d^3*log(f)^3*sqrt(b^2-4*a*c)*(b+sqrt(b^2-4*a*c)))-_
+--  2/3*c*x^3/(b^2-4*a*c-b*sqrt(b^2-4*a*c))-2/3*c*x^3/(b^2-4*a*c+_
+--  b*sqrt(b^2-4*a*c))
+--E 47
+
+--S 48 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 48
+
+)clear all
+
+--S 49 of 600
+t0:=(d+e*f^(g+h*x))/(a+b*f^(g+h*x)+c*f^(2*g+2*h*x))
+--R 
+--R
+--R                   h x + g
+--R                e f        + d
+--R   (1)  -----------------------------
+--R           2h x + 2g      h x + g
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 49
+
+--S 50 of 600
+r0:=d*x/a-1/2*d*log(a+b*f^(g+h*x)+c*f^(2*g+2*h*x))/(a*h*log(f))+_
+   (b*d-2*a*e)*atanh((b+2*c*f^(g+h*x))/sqrt(b^2-4*a*c))/(a*h*log(f)*_
+   sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R           +-----------+
+--R           |          2        2h x + 2g      h x + g
+--R       - d\|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                                h x + g                      +-----------+
+--R                            2c f        + b                  |          2
+--R       (- 4a e + 2b d)atanh(---------------) + 2d h x log(f)\|- 4a c + b
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a h log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 600
+t0:=(d+e*f^(g+h*x))/(a+b*f^(g+h*x)+c*f^(2*(g+h*x)))
+--R 
+--R
+--R                   h x + g
+--R                e f        + d
+--R   (1)  -----------------------------
+--R           2h x + 2g      h x + g
+--R        c f          + b f        + a
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 600
+r0:=d*x/a-1/2*d*log(a+b*f^(g+h*x)+c*f^(2*g+2*h*x))/(a*h*log(f))+(b*d-_
+   2*a*e)*atanh((b+2*c*f^(g+h*x))/sqrt(b^2-4*a*c))/(a*h*log(f)*sqrt(b^2-4*a*c))
+--R 
+--R
+--R   (2)
+--R           +-----------+
+--R           |          2        2h x + 2g      h x + g
+--R       - d\|- 4a c + b  log(c f          + b f        + a)
+--R     + 
+--R                                h x + g                      +-----------+
+--R                            2c f        + b                  |          2
+--R       (- 4a e + 2b d)atanh(---------------) + 2d h x log(f)\|- 4a c + b
+--R                              +-----------+
+--R                              |          2
+--R                             \|- 4a c + b
+--R  /
+--R                 +-----------+
+--R                 |          2
+--R     2a h log(f)\|- 4a c + b
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 600
+t0:=1/(2+1/%e^x+%e^x)
+--R 
+--R
+--R                 x
+--R               %e
+--R   (1)  -----------------
+--R           x 2      x
+--R        (%e )  + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 600
+r0:=(-1)/(1+%e^x)
+--R 
+--R
+--R             1
+--R   (2)  - -------
+--R            x
+--R          %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 600
+t0:=x/(2+1/%e^x+%e^x)
+--R 
+--R
+--R                  x
+--R              x %e
+--R   (1)  -----------------
+--R           x 2      x
+--R        (%e )  + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 600
+r0:=x-x/(1+%e^x)-log(1+%e^x)
+--R 
+--R
+--R             x           x            x
+--R        (- %e  - 1)log(%e  + 1) + x %e
+--R   (2)  -------------------------------
+--R                      x
+--R                    %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 600
+t0:=x^2/(2+1/%e^x+%e^x)
+--R 
+--R
+--R               2  x
+--R              x %e
+--R   (1)  -----------------
+--R           x 2      x
+--R        (%e )  + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 600
+--r0:=x^2-x^2/(1+%e^x)-2*x*log(1+%e^x)-2*polylog(2,-%e^x)
+--E 62
+
+--S 63 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 63
+
+)clear all
+
+--S 64 of 600
+t0:=1/(2+f^(-c-d*x)+f^(c+d*x))
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R         d x + c    - d x - c
+--R        f        + f          + 2
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 600
+r0:=(-1)/(d*(1+f^(c+d*x))*log(f))
+--R 
+--R
+--R                       1
+--R   (2)  - ---------------------------
+--R                   d x + c
+--R          d log(f)f        + d log(f)
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 600
+t0:=x/(2+f^(-c-d*x)+f^(c+d*x))
+--R 
+--R
+--R                    x
+--R   (1)  -------------------------
+--R         d x + c    - d x - c
+--R        f        + f          + 2
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 600
+r0:=x/(d*log(f))-x/(d*(1+f^(c+d*x))*log(f))-log(1+f^(c+d*x))/(d^2*log(f)^2)
+--R 
+--R
+--R            d x + c          d x + c                   d x + c
+--R        (- f        - 1)log(f        + 1) + d x log(f)f
+--R   (2)  ------------------------------------------------------
+--R                      2      2 d x + c    2      2
+--R                     d log(f) f        + d log(f)
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 600
+t0:=x^2/(2+f^(-c-d*x)+f^(c+d*x))
+--R 
+--R
+--R                     2
+--R                    x
+--R   (1)  -------------------------
+--R         d x + c    - d x - c
+--R        f        + f          + 2
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 600
+--r0:=x^2/(d*log(f))-x^2/(d*(1+f^(c+d*x))*log(f))-2*x*log(1+f^(c+d*x))/_
+--  (d^2*log(f)^2)-2*polylog(2,-f^(c+d*x))/(d^3*log(f)^3)
+--E 71
+
+--S 72 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 72
+
+)clear all
+
+--S 73 of 600
+t0:=1/(2+1/3^x+3^x)
+--R 
+--R
+--R                x
+--R               3
+--R   (1)  ----------------
+--R          x 2      x
+--R        (3 )  + 2 3  + 1
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 600
+r0:=(-1)/((1+3^x)*log(3))
+--R 
+--R
+--R                  1
+--R   (2)  - -----------------
+--R                 x
+--R          log(3)3  + log(3)
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 600
+t0:=1/(1+(-1)/%e^x+2*%e^x)
+--R 
+--R
+--R                 x
+--R               %e
+--R   (1)  -----------------
+--R            x 2     x
+--R        2(%e )  + %e  - 1
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 600
+r0:=1/3*log(1-2*%e^x)-1/3*log(1+%e^x)
+--R 
+--R
+--R                x                 x
+--R        - log(%e  + 1) + log(- 2%e  + 1)
+--R   (2)  --------------------------------
+--R                        3
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 600
+t0:=1/(a+b/%e^x+%e^x*c)
+--R 
+--R
+--R                   x
+--R                 %e
+--R   (1)  --------------------
+--R             x 2       x
+--R        c (%e )  + a %e  + b
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 600
+r0:=-2*atanh((a+2*%e^x*c)/sqrt(a^2-4*b*c))/sqrt(a^2-4*b*c)
+--R 
+--R
+--R                        x
+--R                   2c %e  + a
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |          2
+--R                 \|- 4b c + a
+--R   (2)  - ----------------------
+--R               +-----------+
+--R               |          2
+--R              \|- 4b c + a
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 600
+t0:=x/(a+b/%e^x+%e^x*c)
+--R 
+--R
+--R                    x
+--R                x %e
+--R   (1)  --------------------
+--R             x 2       x
+--R        c (%e )  + a %e  + b
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 600
+--r0:=x*log(1+2*%e^x*c/(a-sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)-x*_
+--  log(1+2*%e^x*c/(a+sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)+_
+--  polylog(2,-2*%e^x*c/(a-sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)-_
+--  polylog(2,-2*%e^x*c/(a+sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)
+--E 83
+
+--S 84 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 84
+
+)clear all
+
+--S 85 of 600
+t0:=x^2/(a+b/%e^x+%e^x*c)
+--R 
+--R
+--R                 2  x
+--R                x %e
+--R   (1)  --------------------
+--R             x 2       x
+--R        c (%e )  + a %e  + b
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 600
+--r0:=x^2*log(1+2*%e^x*c/(a-sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)-x^2*_
+--  log(1+2*%e^x*c/(a+sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)+2*x*_
+--  polylog(2,-2*%e^x*c/(a-sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)-2*x*_
+--  polylog(2,-2*%e^x*c/(a+sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)-2*_
+--  polylog(3,-2*%e^x*c/(a-sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)+2*_
+--  polylog(3,-2*%e^x*c/(a+sqrt(a^2-4*b*c)))/sqrt(a^2-4*b*c)
+--E 86
+
+--S 87 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 87
+
+)clear all
+
+--S 88 of 600
+t0:=1/(a+b*f^(-c-d*x)+c*f^(c+d*x))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R           d x + c      - d x - c
+--R        c f        + b f          + a
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 600
+r0:=-2*atanh((a+2*c*f^(c+d*x))/sqrt(a^2-4*b*c))/(d*log(f)*sqrt(a^2-4*b*c))
+--R 
+--R
+--R                     d x + c
+--R                 2c f        + a
+--R          2atanh(---------------)
+--R                   +-----------+
+--R                   |          2
+--R                  \|- 4b c + a
+--R   (2)  - -----------------------
+--R                    +-----------+
+--R                    |          2
+--R           d log(f)\|- 4b c + a
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 600
+t0:=x/(a+b*f^(-c-d*x)+c*f^(c+d*x))
+--R 
+--R
+--R                      x
+--R   (1)  -----------------------------
+--R           d x + c      - d x - c
+--R        c f        + b f          + a
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 600
+--r0:=x*log(1+2*c*f^(c+d*x)/(a-sqrt(a^2-4*b*c)))/(d*log(f)*sqrt(a^2-4*b*c))-_
+--  x*log(1+2*c*f^(c+d*x)/(a+sqrt(a^2-4*b*c)))/(d*log(f)*sqrt(a^2-4*b*c))+_
+--  polylog(2,-2*c*f^(c+d*x)/(a-sqrt(a^2-4*b*c)))/(d^2*log(f)^2*_
+--  sqrt(a^2-4*b*c))-polylog(2,-2*c*f^(c+d*x)/(a+sqrt(a^2-4*b*c)))/_
+--  (d^2*log(f)^2*sqrt(a^2-4*b*c))
+--E 92
+
+--S 93 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 93
+
+)clear all
+
+--S 94 of 600
+t0:=x^2/(a+b*f^(-c-d*x)+c*f^(c+d*x))
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R           d x + c      - d x - c
+--R        c f        + b f          + a
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 600
+--r0:=x^2*log(1+2*c*f^(c+d*x)/(a-sqrt(a^2-4*b*c)))/(d*log(f)*sqrt(a^2-_
+--  4*b*c))-x^2*log(1+2*c*f^(c+d*x)/(a+sqrt(a^2-4*b*c)))/(d*log(f)*_
+--  sqrt(a^2-4*b*c))+2*x*polylog(2,-2*c*f^(c+d*x)/(a-sqrt(a^2-4*b*c)))/_
+--  (d^2*log(f)^2*sqrt(a^2-4*b*c))-2*x*polylog(2,-2*c*f^(c+d*x)/(a+_
+--  sqrt(a^2-4*b*c)))/(d^2*log(f)^2*sqrt(a^2-4*b*c))-2*_
+--  polylog(3,-2*c*f^(c+d*x)/(a-sqrt(a^2-4*b*c)))/(d^3*log(f)^3*_
+--  sqrt(a^2-4*b*c))+2*polylog(3,-2*c*f^(c+d*x)/(a+sqrt(a^2-4*b*c)))/_
+--  (d^3*log(f)^3*sqrt(a^2-4*b*c))
+--E 95
+
+--S 96 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 96
+
+)clear all
+
+--S 97 of 600
+t0:=a^x*b^x*x^2
+--R 
+--R
+--R         2 x x
+--R   (1)  x a b
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 600
+r0:=2*a^x*b^x/(log(a)+log(b))^3-2*a^x*b^x*x/(log(a)+log(b))^2+_
+   a^x*b^x*x^2/(log(a)+log(b))
+--R 
+--R
+--R          2      2      2                      2      2                  x x
+--R        (x log(b)  + (2x log(a) - 2x)log(b) + x log(a)  - 2x log(a) + 2)a b
+--R   (2)  --------------------------------------------------------------------
+--R                       3                2          2               3
+--R                 log(b)  + 3log(a)log(b)  + 3log(a) log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 600
+t0:=a^x*b^x*x
+--R 
+--R
+--R           x x
+--R   (1)  x a b
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 600
+r0:=-a^x*b^x/(log(a)+log(b))^2+a^x*b^x*x/(log(a)+log(b))
+--R 
+--R
+--R                                    x x
+--R          (x log(b) + x log(a) - 1)a b
+--R   (2)  ---------------------------------
+--R              2                         2
+--R        log(b)  + 2log(a)log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 600
+t0:=a^x*b^x
+--R 
+--R
+--R         x x
+--R   (1)  a b
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 600
+r0:=a^x*b^x/(log(a)+log(b))
+--R 
+--R
+--R               x x
+--R              a b
+--R   (2)  ---------------
+--R        log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 600
+t0:=a^x*b^x/x
+--R 
+--R
+--R         x x
+--R        a b
+--R   (1)  ----
+--R          x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 600
+--r0:=Ei(x*(log(a)+log(b)))
+--E 107
+
+--S 108 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 108
+
+)clear all
+
+--S 109 of 600
+t0:=a^x*b^x/x^2
+--R 
+--R
+--R         x x
+--R        a b
+--R   (1)  ----
+--R          2
+--R         x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 600
+--r0:=-a^x*b^x/x+Ei(x*(log(a)+log(b)))*(log(a)+log(b))
+--E 110
+
+--S 111 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 111
+
+)clear all
+
+--S 112 of 600
+t0:=a^x*b^x/x^3
+--R 
+--R
+--R         x x
+--R        a b
+--R   (1)  ----
+--R          3
+--R         x
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 600
+--r0:=-1/2*a^x*b^x/x^2-1/2*a^x*b^x*(log(a)+log(b))/x+1/2*Ei(x*(log(a)+_
+--  log(b)))*(log(a)+log(b))^2
+--E 113
+
+--S 114 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 114
+
+)clear all
+
+--S 115 of 600
+t0:=a^x*b^x*c^x
+--R 
+--R
+--R         x x x
+--R   (1)  a b c
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 600
+r0:=a^x*b^x*c^x/(log(a)+log(b)+log(c))
+--R 
+--R
+--R                  x x x
+--R                 a b c
+--R   (2)  ------------------------
+--R        log(c) + log(b) + log(a)
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 600
+t0:=a^x/b^x
+--R 
+--R
+--R         x
+--R        a
+--R   (1)  --
+--R         x
+--R        b
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 600
+r0:=a^x/(b^x*(log(a)-log(b)))
+--R 
+--R
+--R                    x
+--R                   a
+--R   (2)  - -------------------
+--R                            x
+--R          (log(b) - log(a))b
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 600
+t0:=a^x*x^2/b^x
+--R 
+--R
+--R         2 x
+--R        x a
+--R   (1)  ----
+--R          x
+--R         b
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 600
+r0:=2*a^x/(b^x*(log(a)-log(b))^3)-2*a^x*x/(b^x*(log(a)-log(b))^2)+_
+   a^x*x^2/(b^x*(log(a)-log(b)))
+--R 
+--R
+--R            2      2      2                      2      2                  x
+--R        (- x log(b)  + (2x log(a) - 2x)log(b) - x log(a)  + 2x log(a) - 2)a
+--R   (2)  --------------------------------------------------------------------
+--R                      3                2          2               3  x
+--R               (log(b)  - 3log(a)log(b)  + 3log(a) log(b) - log(a) )b
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 600
+t0:=%e^(2*x)/(a+%e^x*b)
+--R 
+--R
+--R             2x
+--R           %e
+--R   (1)  ---------
+--R            x
+--R        b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 600
+r0:=%e^x/b-a*log(a+%e^x*b)/b^2
+--R 
+--R
+--R                    x            x
+--R        - a log(b %e  + a) + b %e
+--R   (2)  --------------------------
+--R                     2
+--R                    b
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 600
+t0:=%e^(2*x)/(a+%e^x*b)^2
+--R 
+--R
+--R                    2x
+--R                  %e
+--R   (1)  ------------------------
+--R         2   x 2          x    2
+--R        b (%e )  + 2a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 600
+r0:=a/(b^2*(a+%e^x*b))+log(a+%e^x*b)/b^2
+--R 
+--R
+--R             x             x
+--R        (b %e  + a)log(b %e  + a) + a
+--R   (2)  -----------------------------
+--R                  3  x      2
+--R                 b %e  + a b
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 600
+t0:=%e^(2*x)/(a+%e^x*b)^3
+--R 
+--R
+--R                           2x
+--R                         %e
+--R   (1)  --------------------------------------
+--R         3   x 3       2   x 2     2    x    3
+--R        b (%e )  + 3a b (%e )  + 3a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 600
+r0:=1/2*%e^(2*x)/(a*(a+%e^x*b)^2)
+--R 
+--R
+--R                      2x
+--R                    %e
+--R   (2)  ----------------------------
+--R            2   x 2     2    x     3
+--R        2a b (%e )  + 4a b %e  + 2a
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 600
+t0:=%e^(2*x)/(a+%e^x*b)^4
+--R 
+--R
+--R                                  2x
+--R                                %e
+--R   (1)  ----------------------------------------------------
+--R         4   x 4       3   x 3     2 2   x 2     3    x    4
+--R        b (%e )  + 4a b (%e )  + 6a b (%e )  + 4a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 600
+r0:=1/3*a/(b^2*(a+%e^x*b)^3)+(-1/2)/(b^2*(a+%e^x*b)^2)
+--R 
+--R
+--R                               x
+--R                        - 3b %e  - a
+--R   (2)  --------------------------------------------
+--R          5   x 3        4   x 2      2 3  x     3 2
+--R        6b (%e )  + 18a b (%e )  + 18a b %e  + 6a b
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 600
+t0:=%e^(4*x)/(a+%e^(2*x)*b)
+--R 
+--R
+--R             4x
+--R           %e
+--R   (1)  ----------
+--R            2x
+--R        b %e   + a
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 600
+r0:=1/2*%e^(2*x)/b-1/2*a*log(a+%e^(2*x)*b)/b^2
+--R 
+--R
+--R                    2x            2x
+--R        - a log(b %e   + a) + b %e
+--R   (2)  ----------------------------
+--R                       2
+--R                     2b
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 600
+t0:=%e^(4*x)/(a+%e^(2*x)*b)^2
+--R 
+--R
+--R                     4x
+--R                   %e
+--R   (1)  --------------------------
+--R         2   2x 2          2x    2
+--R        b (%e  )  + 2a b %e   + a
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 600
+r0:=1/2*a/(b^2*(a+%e^(2*x)*b))+1/2*log(a+%e^(2*x)*b)/b^2
+--R 
+--R
+--R             2x             2x
+--R        (b %e   + a)log(b %e   + a) + a
+--R   (2)  -------------------------------
+--R                  3  2x       2
+--R                2b %e   + 2a b
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 600
+t0:=%e^(4*x)/(a+%e^(2*x)*b)^3
+--R 
+--R
+--R                             4x
+--R                           %e
+--R   (1)  -----------------------------------------
+--R         3   2x 3       2   2x 2     2    2x    3
+--R        b (%e  )  + 3a b (%e  )  + 3a b %e   + a
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 600
+r0:=1/4*%e^(4*x)/(a*(a+%e^(2*x)*b)^2)
+--R 
+--R
+--R                       4x
+--R                     %e
+--R   (2)  ------------------------------
+--R            2   2x 2     2    2x     3
+--R        4a b (%e  )  + 8a b %e   + 4a
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 600
+t0:=%e^(4*x)/(a+%e^(2*x)*b)^4
+--R 
+--R
+--R                                    4x
+--R                                  %e
+--R   (1)  --------------------------------------------------------
+--R         4   2x 4       3   2x 3     2 2   2x 2     3    2x    4
+--R        b (%e  )  + 4a b (%e  )  + 6a b (%e  )  + 4a b %e   + a
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 600
+r0:=1/6*a/(b^2*(a+%e^(2*x)*b)^3)+(-1/4)/(b^2*(a+%e^(2*x)*b)^2)
+--R 
+--R
+--R                                 2x
+--R                          - 3b %e   - a
+--R   (2)  -------------------------------------------------
+--R           5   2x 3        4   2x 2      2 3  2x      3 2
+--R        12b (%e  )  + 36a b (%e  )  + 36a b %e   + 12a b
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 600
+t0:=%e^(4*x)/(a+%e^(2*x)*b)^(2/3)
+--R 
+--R
+--R               4x
+--R             %e
+--R   (1)  --------------
+--R         +----------+2
+--R        3|    2x
+--R        \|b %e   + a
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 600
+r0:=-3/2*a*(a+%e^(2*x)*b)^(1/3)/b^2+3/8*(a+%e^(2*x)*b)^(4/3)/b^2
+--R 
+--R
+--R                       +----------+
+--R              2x      3|    2x
+--R        (3b %e   - 9a)\|b %e   + a
+--R   (2)  ---------------------------
+--R                      2
+--R                    8b
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 600
+t0:=(a+%e^(n*x)*b)/%e^(n*x)
+--R 
+--R
+--R            n x
+--R        b %e    + a
+--R   (1)  -----------
+--R             n x
+--R           %e
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 600
+r0:=-a/(%e^(n*x)*n)+b*x
+--R 
+--R
+--R                n x
+--R        b n x %e    - a
+--R   (2)  ---------------
+--R                n x
+--R            n %e
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 600
+t0:=(a+%e^(n*x)*b)^2/%e^(n*x)
+--R 
+--R
+--R         2   n x 2          n x    2
+--R        b (%e   )  + 2a b %e    + a
+--R   (1)  ----------------------------
+--R                      n x
+--R                    %e
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 600
+r0:=-a^2/(%e^(n*x)*n)+%e^(n*x)*b^2/n+2*a*b*x
+--R 
+--R
+--R         2   n x 2              n x    2
+--R        b (%e   )  + 2a b n x %e    - a
+--R   (2)  --------------------------------
+--R                         n x
+--R                     n %e
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 600
+t0:=(a+%e^(n*x)*b)^3/%e^(n*x)
+--R 
+--R
+--R         3   n x 3       2   n x 2     2    n x    3
+--R        b (%e   )  + 3a b (%e   )  + 3a b %e    + a
+--R   (1)  --------------------------------------------
+--R                              n x
+--R                            %e
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 600
+r0:=-a^3/(%e^(n*x)*n)+3*%e^(n*x)*a*b^2/n+1/2*%e^(2*n*x)*b^3/n+3*a^2*b*x
+--R 
+--R
+--R         3  n x  2n x       2   n x 2     2        n x     3
+--R        b %e   %e     + 6a b (%e   )  + 6a b n x %e    - 2a
+--R   (2)  ----------------------------------------------------
+--R                                   n x
+--R                              2n %e
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 600
+t0:=1/(%e^(n*x)*(a+%e^(n*x)*b))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R             n x 2       n x
+--R        b (%e   )  + a %e
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 600
+r0:=(-1)/(%e^(n*x)*a*n)-b*x/a^2+b*log(a+%e^(n*x)*b)/(a^2*n)
+--R 
+--R
+--R            n x        n x                n x
+--R        b %e   log(b %e    + a) - b n x %e    - a
+--R   (2)  -----------------------------------------
+--R                         2    n x
+--R                        a n %e
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 600
+t0:=1/(%e^(n*x)*(a+%e^(n*x)*b)^2)
+--R 
+--R
+--R                          1
+--R   (1)  ------------------------------------
+--R         2   n x 3           n x 2    2  n x
+--R        b (%e   )  + 2a b (%e   )  + a %e
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 600
+r0:=(-1)/(%e^(n*x)*a^2*n)-b/(a^2*(a+%e^(n*x)*b)*n)-2*b*x/a^3+_
+   2*b*log(a+%e^(n*x)*b)/(a^3*n)
+--R 
+--R
+--R   (2)
+--R          2   n x 2          n x         n x          2       n x 2
+--R       (2b (%e   )  + 2a b %e   )log(b %e    + a) - 2b n x (%e   )
+--R     + 
+--R                            n x    2
+--R       (- 2a b n x - 2a b)%e    - a
+--R  /
+--R      3       n x 2    4    n x
+--R     a b n (%e   )  + a n %e
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 600
+t0:=1/(%e^(n*x)*(a+%e^(n*x)*b)^3)
+--R 
+--R
+--R                                  1
+--R   (1)  ----------------------------------------------------
+--R         3   n x 4       2   n x 3     2     n x 2    3  n x
+--R        b (%e   )  + 3a b (%e   )  + 3a b (%e   )  + a %e
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 600
+r0:=(-1)/(%e^(n*x)*a^3*n)-1/2*b/(a^2*(a+%e^(n*x)*b)^2*n)-_
+   2*b/(a^3*(a+%e^(n*x)*b)*n)-3*b*x/a^4+3*b*log(a+%e^(n*x)*b)/(a^4*n)
+--R 
+--R
+--R   (2)
+--R          3   n x 3        2   n x 2     2    n x         n x
+--R       (6b (%e   )  + 12a b (%e   )  + 6a b %e   )log(b %e    + a)
+--R     + 
+--R           3       n x 3           2          2    n x 2
+--R       - 6b n x (%e   )  + (- 12a b n x - 6a b )(%e   )
+--R     + 
+--R            2          2    n x     3
+--R       (- 6a b n x - 9a b)%e    - 2a
+--R  /
+--R       4 2     n x 3     5       n x 2     6    n x
+--R     2a b n (%e   )  + 4a b n (%e   )  + 2a n %e
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 600
+t0:=f^(a+b*x)/(c+d*f^(e+2*b*x))
+--R 
+--R
+--R             b x + a
+--R            f
+--R   (1)  ---------------
+--R           2b x + e
+--R        d f         + c
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 600
+r0:=f^a*atan(f^(b*x)*sqrt(d)/(sqrt(c)*sqrt(1/f^e)))*sqrt(1/f^e)/(b*log(f)*_
+   sqrt(c)*sqrt(d))
+--R 
+--R
+--R           +--+       b x +-+
+--R         a | 1       f   \|d
+--R        f  |-- atan(---------)
+--R           | e           +--+
+--R          \|f        +-+ | 1
+--R                    \|c  |--
+--R                         | e
+--R                        \|f
+--R   (2)  ----------------------
+--R                    +-+ +-+
+--R           b log(f)\|c \|d
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 600
+t0:=f^(a+2*b*x)/(c+d*f^(e+2*b*x))
+--R 
+--R
+--R            2b x + a
+--R           f
+--R   (1)  ---------------
+--R           2b x + e
+--R        d f         + c
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 600
+r0:=1/2*f^(a-e)*log(c+d*f^(e+2*b*x))/(b*d*log(f))
+--R 
+--R
+--R         - e + a       2b x + e
+--R        f       log(d f         + c)
+--R   (2)  ----------------------------
+--R                 2b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 600
+t0:=f^(a+3*b*x)/(c+d*f^(e+2*b*x))
+--R 
+--R
+--R            3b x + a
+--R           f
+--R   (1)  ---------------
+--R           2b x + e
+--R        d f         + c
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 600
+r0:=f^(a-e+b*x)/(b*d*log(f))-f^a*(1/f^e)^(3/2)*atan(f^(b*x)*sqrt(d)/(sqrt(c)*_
+   sqrt(1/f^e)))*sqrt(c)/(b*d^(3/2)*log(f))
+--R 
+--R
+--R                 +--+       b x +-+
+--R           a +-+ | 1       f   \|d      e b x - e + a +-+
+--R        - f \|c  |-- atan(---------) + f f           \|d
+--R                 | e           +--+
+--R                \|f        +-+ | 1
+--R                          \|c  |--
+--R                               | e
+--R                              \|f
+--R   (2)  -------------------------------------------------
+--R                                    e +-+
+--R                         b d log(f)f \|d
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 600
+t0:=f^(a+4*b*x)/(c+d*f^(e+2*b*x))
+--R 
+--R
+--R            4b x + a
+--R           f
+--R   (1)  ---------------
+--R           2b x + e
+--R        d f         + c
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 600
+r0:=1/2*f^(a-e+2*b*x)/(b*d*log(f))-1/2*c*f^(a-2*e)*log(c+d*f^(e+2*b*x))/_
+   (b*d^2*log(f))
+--R 
+--R
+--R             - 2e + a       2b x + e           2b x - e + a
+--R        - c f        log(d f         + c) + d f
+--R   (2)  ---------------------------------------------------
+--R                                2
+--R                            2b d log(f)
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 600
+t0:=f^(a+5*b*x)/(c+d*f^(e+2*b*x))
+--R 
+--R
+--R            5b x + a
+--R           f
+--R   (1)  ---------------
+--R           2b x + e
+--R        d f         + c
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 600
+r0:=-c*f^(a-2*e+b*x)/(b*d^2*log(f))+1/3*f^(a-e+3*b*x)/(b*d*log(f))+c^(3/2)*_
+   f^(a-2*e)*atan(f^(b*x)*sqrt(d)/(sqrt(c)*sqrt(1/f^e)))*sqrt(1/f^e)/_
+   (b*d^(5/2)*log(f))
+--R 
+--R
+--R   (2)
+--R                        +--+       b x +-+
+--R           - 2e + a +-+ | 1       f   \|d
+--R       3c f        \|c  |-- atan(---------)
+--R                        | e           +--+
+--R                       \|f        +-+ | 1
+--R                                 \|c  |--
+--R                                      | e
+--R                                     \|f
+--R     + 
+--R           3b x - e + a       b x - 2e + a  +-+
+--R       (d f             - 3c f            )\|d
+--R  /
+--R         2       +-+
+--R     3b d log(f)\|d
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 600
+t0:=%e^x/(1-%e^(2*x))
+--R 
+--R
+--R               x
+--R             %e
+--R   (1)  - --------
+--R            2x
+--R          %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 600
+r0:=atanh(%e^x)
+--R 
+--R
+--R                x
+--R   (2)  atanh(%e )
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 600
+t0:=%e^x*x/(1-%e^(2*x))
+--R 
+--R
+--R                x
+--R            x %e
+--R   (1)  - --------
+--R            2x
+--R          %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 600
+--r0:=x*atanh(%e^x)+1/2*polylog(2,-%e^x)-1/2*polylog(2,%e^x)
+--E 188
+
+--S 189 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 189
+
+)clear all
+
+--S 190 of 600
+t0:=%e^x*x^2/(1-%e^(2*x))
+--R 
+--R
+--R             2  x
+--R            x %e
+--R   (1)  - --------
+--R            2x
+--R          %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 600
+--r0:=x^2*atanh(%e^x)+x*polylog(2,-%e^x)-x*polylog(2,%e^x)-_
+--  polylog(3,-%e^x)+polylog(3,%e^x)
+--E 191
+
+--S 192 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 192
+
+)clear all
+
+--S 193 of 600
+t0:=%e^x*x^3/(1-%e^(2*x))
+--R 
+--R
+--R             3  x
+--R            x %e
+--R   (1)  - --------
+--R            2x
+--R          %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 600
+--r0:=x^3*atanh(%e^x)+3/2*x^2*polylog(2,-%e^x)-3/2*x^2*polylog(2,%e^x)-_
+--  3*x*polylog(3,-%e^x)+3*x*polylog(3,%e^x)+3*polylog(4,-%e^x)-_
+--  3*polylog(4,%e^x)
+--E 194
+
+--S 195 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 195
+
+)clear all
+
+--S 196 of 600
+t0:=f^x/(a+b*f^(2*x))
+--R 
+--R
+--R             x
+--R            f
+--R   (1)  ---------
+--R           2x
+--R        b f   + a
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 600
+r0:=atan(f^x*sqrt(b)/sqrt(a))/(log(f)*sqrt(a)*sqrt(b))
+--R 
+--R
+--R               x +-+
+--R              f \|b
+--R         atan(------)
+--R                +-+
+--R               \|a
+--R   (2)  --------------
+--R               +-+ +-+
+--R        log(f)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 600
+t0:=f^x*x/(a+b*f^(2*x))
+--R 
+--R
+--R              x
+--R           x f
+--R   (1)  ---------
+--R           2x
+--R        b f   + a
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 600
+--r0:=x*atan(f^x*sqrt(b)/sqrt(a))/(log(f)*sqrt(a)*sqrt(b))-1/2*%i*_
+--  polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*sqrt(b))+_
+--  1/2*%i*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*sqrt(b))
+--E 200
+
+--S 201 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 201
+
+)clear all
+
+--S 202 of 600
+t0:=f^x*x^2/(a+b*f^(2*x))
+--R 
+--R
+--R            2 x
+--R           x f
+--R   (1)  ---------
+--R           2x
+--R        b f   + a
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 600
+--r0:=x^2*atan(f^x*sqrt(b)/sqrt(a))/(log(f)*sqrt(a)*sqrt(b))-%i*x*_
+--  polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*sqrt(b))+%i*x*_
+--  polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*sqrt(b))+%i*_
+--  polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^3*sqrt(a)*sqrt(b))-%i*_
+--  polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^3*sqrt(a)*sqrt(b))
+--E 203
+
+--S 204 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 204
+
+)clear all
+
+--S 205 of 600
+t0:=f^x*x^3/(a+b*f^(2*x))
+--R 
+--R
+--R            3 x
+--R           x f
+--R   (1)  ---------
+--R           2x
+--R        b f   + a
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 600
+--r0:=x^3*atan(f^x*sqrt(b)/sqrt(a))/(log(f)*sqrt(a)*sqrt(b))-3/2*%i*x^2*_
+--  polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*sqrt(b))+_
+--  3/2*%i*x^2*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^2*sqrt(a)*_
+--  sqrt(b))+3*%i*x*polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^3*sqrt(a)*_
+--  sqrt(b))-3*%i*x*polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^3*sqrt(a)*_
+--  sqrt(b))-3*%i*polylog(4,-%i*f^x*sqrt(b)/sqrt(a))/(log(f)^4*sqrt(a)*_
+--  sqrt(b))+3*%i*polylog(4,%i*f^x*sqrt(b)/sqrt(a))/(log(f)^4*sqrt(a)*sqrt(b))
+--E 206
+
+--S 207 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 207
+
+)clear all
+
+--S 208 of 600
+t0:=f^x/(a+b*f^(2*x))^2
+--R 
+--R
+--R                    x
+--R                   f
+--R   (1)  ------------------------
+--R         2  2x 2         2x    2
+--R        b (f  )  + 2a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 600
+r0:=1/2*f^x/(a*(a+b*f^(2*x))*log(f))+1/2*atan(f^x*sqrt(b)/sqrt(a))/_
+   (a^(3/2)*log(f)*sqrt(b))
+--R 
+--R
+--R                         x +-+
+--R            2x          f \|b      x +-+ +-+
+--R        (b f   + a)atan(------) + f \|a \|b
+--R                          +-+
+--R                         \|a
+--R   (2)  ------------------------------------
+--R                     2x     2        +-+ +-+
+--R        (2a b log(f)f   + 2a log(f))\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 600
+t0:=f^x*x/(a+b*f^(2*x))^2
+--R 
+--R
+--R                     x
+--R                  x f
+--R   (1)  ------------------------
+--R         2  2x 2         2x    2
+--R        b (f  )  + 2a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 600
+--r0:=1/2*f^x*x/(a*(a+b*f^(2*x))*log(f))-1/2*atan(f^x*sqrt(b)/sqrt(a))/_
+--  (a^(3/2)*log(f)^2*sqrt(b))+1/2*x*atan(f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)*sqrt(b))-1/4*%i*polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^2*sqrt(b))+1/4*%i*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^2*sqrt(b))
+--E 212
+
+--S 213 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 213
+
+)clear all
+
+--S 214 of 600
+t0:=f^x*x^2/(a+b*f^(2*x))^2
+--R 
+--R
+--R                   2 x
+--R                  x f
+--R   (1)  ------------------------
+--R         2  2x 2         2x    2
+--R        b (f  )  + 2a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 600
+--r0:=1/2*f^x*x^2/(a*(a+b*f^(2*x))*log(f))-x*atan(f^x*sqrt(b)/sqrt(a))/_
+--  (a^(3/2)*log(f)^2*sqrt(b))+1/2*x^2*atan(f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)*sqrt(b))+1/2*%i*polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^3*sqrt(b))-1/2*%i*x*polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^2*sqrt(b))-1/2*%i*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^3*sqrt(b))+1/2*%i*x*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^2*sqrt(b))+1/2*%i*polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^3*sqrt(b))-1/2*%i*polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*_
+--  log(f)^3*sqrt(b))
+--E 215
+
+--S 216 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 216
+
+)clear all
+
+--S 217 of 600
+t0:=f^x*x^3/(a+b*f^(2*x))^2
+--R 
+--R
+--R                   3 x
+--R                  x f
+--R   (1)  ------------------------
+--R         2  2x 2         2x    2
+--R        b (f  )  + 2a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 600
+--r0:=1/2*f^x*x^3/(a*(a+b*f^(2*x))*log(f))-3/2*x^2*atan(f^x*sqrt(b)/_
+--  sqrt(a))/(a^(3/2)*log(f)^2*sqrt(b))+1/2*x^3*atan(f^x*sqrt(b)/_
+--  sqrt(a))/(a^(3/2)*log(f)*sqrt(b))+3/2*%i*x*polylog(2,-%i*f^x*sqrt(b)/_
+--  sqrt(a))/(a^(3/2)*log(f)^3*sqrt(b))-3/4*%i*x^2*polylog(2,-%i*f^x*_
+--  sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^2*sqrt(b))-3/2*%i*x*polylog(2,%i*f^x*_
+--  sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^3*sqrt(b))+3/4*%i*x^2*_
+--  polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^2*sqrt(b))-3/2*%i*_
+--  polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^4*sqrt(b))+_
+--  3/2*%i*x*polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^3*_
+--  sqrt(b))+3/2*%i*polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^4*_
+--  sqrt(b))-3/2*%i*x*polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^3*_
+--  sqrt(b))-3/2*%i*polylog(4,-%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^4*_
+--  sqrt(b))+3/2*%i*polylog(4,%i*f^x*sqrt(b)/sqrt(a))/(a^(3/2)*log(f)^4*_
+--  sqrt(b))
+--E 218
+
+--S 219 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 219
+
+)clear all
+
+--S 220 of 600
+t0:=f^x/(a+b*f^(2*x))^3
+--R 
+--R
+--R                           x
+--R                          f
+--R   (1)  --------------------------------------
+--R         3  2x 3       2  2x 2     2   2x    3
+--R        b (f  )  + 3a b (f  )  + 3a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 600
+r0:=1/4*f^x/(a*(a+b*f^(2*x))^2*log(f))+3/8*f^x/(a^2*(a+b*f^(2*x))*log(f))+_
+   3/8*atan(f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)*sqrt(b))
+--R 
+--R
+--R                                          x +-+
+--R           2  2x 2         2x     2      f \|b          x 2x       x  +-+ +-+
+--R        (3b (f  )  + 6a b f   + 3a )atan(------) + (3b f f   + 5a f )\|a \|b
+--R                                           +-+
+--R                                          \|a
+--R   (2)  ---------------------------------------------------------------------
+--R                 2 2        2x 2      3         2x     4        +-+ +-+
+--R              (8a b log(f)(f  )  + 16a b log(f)f   + 8a log(f))\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 600
+t0:=f^x*x/(a+b*f^(2*x))^3
+--R 
+--R
+--R                            x
+--R                         x f
+--R   (1)  --------------------------------------
+--R         3  2x 3       2  2x 2     2   2x    3
+--R        b (f  )  + 3a b (f  )  + 3a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 600
+--r0:=-1/8*f^x/(a^2*(a+b*f^(2*x))*log(f)^2)+1/4*f^x*x/(a*(a+b*f^(2*x))^2*_
+--  log(f))+3/8*f^x*x/(a^2*(a+b*f^(2*x))*log(f))-1/2*atan(f^x*sqrt(b)/_
+--  sqrt(a))/(a^(5/2)*log(f)^2*sqrt(b))+3/8*x*atan(f^x*sqrt(b)/sqrt(a))/_
+--  (a^(5/2)*log(f)*sqrt(b))-3/16*%i*polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/_
+--  (a^(5/2)*log(f)^2*sqrt(b))+3/16*%i*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/_
+--  (a^(5/2)*log(f)^2*sqrt(b))
+--E 224
+
+--S 225 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 225
+
+)clear all
+
+--S 226 of 600
+t0:=f^x*x^2/(a+b*f^(2*x))^3
+--R 
+--R
+--R                          2 x
+--R                         x f
+--R   (1)  --------------------------------------
+--R         3  2x 3       2  2x 2     2   2x    3
+--R        b (f  )  + 3a b (f  )  + 3a b f   + a
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 600
+--r0:=-1/4*f^x*x/(a^2*(a+b*f^(2*x))*log(f)^2)+1/4*f^x*x^2/(a*(a+_
+--  b*f^(2*x))^2*log(f))+3/8*f^x*x^2/(a^2*(a+b*f^(2*x))*log(f))+_
+--  1/4*atan(f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)^3*sqrt(b))-_
+--  x*atan(f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)^2*sqrt(b))+3/8*x^2*_
+--  atan(f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)*sqrt(b))+1/2*%i*_
+--  polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)^3*sqrt(b))-_
+--  3/8*%i*x*polylog(2,-%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)^2*_
+--  sqrt(b))-1/2*%i*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*log(f)^3*_
+--  sqrt(b))+3/8*%i*x*polylog(2,%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*_
+--  log(f)^2*sqrt(b))+3/8*%i*polylog(3,-%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*_
+--  log(f)^3*sqrt(b))-3/8*%i*polylog(3,%i*f^x*sqrt(b)/sqrt(a))/(a^(5/2)*_
+--  log(f)^3*sqrt(b))
+--E 227
+
+--S 228 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 228
+
+)clear all
+
+--S 229 of 600
+t0:=1/(b/f^x+a*f^x)
+--R 
+--R
+--R              x
+--R             f
+--R   (1)  -----------
+--R            x 2
+--R        a (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 600
+r0:=atan(f^x*sqrt(a)/sqrt(b))/(log(f)*sqrt(a)*sqrt(b))
+--R 
+--R
+--R               x +-+
+--R              f \|a
+--R         atan(------)
+--R                +-+
+--R               \|b
+--R   (2)  --------------
+--R               +-+ +-+
+--R        log(f)\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 600
+t0:=x/(b/f^x+a*f^x)
+--R 
+--R
+--R               x
+--R            x f
+--R   (1)  -----------
+--R            x 2
+--R        a (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 600
+--r0:=x*atan(f^x*sqrt(a)/sqrt(b))/(log(f)*sqrt(a)*sqrt(b))-1/2*%i*_
+--  polylog(2,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*sqrt(b))+1/2*%i*_
+--  polylog(2,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*sqrt(b))
+--E 233
+
+--S 234 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 234
+
+)clear all
+
+--S 235 of 600
+t0:=x^2/(b/f^x+a*f^x)
+--R 
+--R
+--R             2 x
+--R            x f
+--R   (1)  -----------
+--R            x 2
+--R        a (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 600
+--r0:=x^2*atan(f^x*sqrt(a)/sqrt(b))/(log(f)*sqrt(a)*sqrt(b))-%i*x*_
+--  polylog(2,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*sqrt(b))+%i*x*_
+--  polylog(2,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*sqrt(b))+%i*_
+--  polylog(3,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^3*sqrt(a)*sqrt(b))-%i*_
+--  polylog(3,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^3*sqrt(a)*sqrt(b))
+--E 236
+
+--S 237 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 237
+
+)clear all
+
+--S 238 of 600
+t0:=x^3/(b/f^x+a*f^x)
+--R 
+--R
+--R             3 x
+--R            x f
+--R   (1)  -----------
+--R            x 2
+--R        a (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 600
+--r0:=x^3*atan(f^x*sqrt(a)/sqrt(b))/(log(f)*sqrt(a)*sqrt(b))-3/2*%i*x^2*_
+--  polylog(2,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*sqrt(b))+_
+--  3/2*%i*x^2*polylog(2,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^2*sqrt(a)*_
+--  sqrt(b))+3*%i*x*polylog(3,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^3*sqrt(a)*_
+--  sqrt(b))-3*%i*x*polylog(3,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^3*sqrt(a)*_
+--  sqrt(b))-3*%i*polylog(4,-%i*f^x*sqrt(a)/sqrt(b))/(log(f)^4*sqrt(a)*_
+--  sqrt(b))+3*%i*polylog(4,%i*f^x*sqrt(a)/sqrt(b))/(log(f)^4*sqrt(a)*sqrt(b))
+--E 239
+
+--S 240 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 240
+
+)clear all
+
+--S 241 of 600
+t0:=1/(b/f^x+a*f^x)^2
+--R 
+--R
+--R                    2x
+--R                   f
+--R   (1)  -------------------------
+--R         2  x 4          x 2    2
+--R        a (f )  + 2a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 600
+r0:=(-1/2)/(a*(b+a*f^(2*x))*log(f))
+--R 
+--R
+--R                       1
+--R   (2)  - --------------------------
+--R            2       2x
+--R          2a log(f)f   + 2a b log(f)
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 600
+t0:=x/(b/f^x+a*f^x)^2
+--R 
+--R
+--R                     2x
+--R                  x f
+--R   (1)  -------------------------
+--R         2  x 4          x 2    2
+--R        a (f )  + 2a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 600
+r0:=1/2*x/(a*b*log(f))-1/2*x/(a*(b+a*f^(2*x))*log(f))-1/4*log(b+a*f^(2*x))/_
+   (a*b*log(f)^2)
+--R 
+--R
+--R              2x            2x                    2x
+--R        (- a f   - b)log(a f   + b) + 2a x log(f)f
+--R   (2)  --------------------------------------------
+--R                 2        2 2x       2      2
+--R               4a b log(f) f   + 4a b log(f)
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 600
+t0:=x^2/(b/f^x+a*f^x)^2
+--R 
+--R
+--R                   2 2x
+--R                  x f
+--R   (1)  -------------------------
+--R         2  x 4          x 2    2
+--R        a (f )  + 2a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 600
+--r0:=1/2*x^2/(a*b*log(f))-1/2*x^2/(a*(b+a*f^(2*x))*log(f))-_
+--  1/2*x*log(1+a*f^(2*x)/b)/(a*b*log(f)^2)-1/4*polylog(2,-a*f^(2*x)/b)/_
+--  (a*b*log(f)^3)
+--E 248
+
+--S 249 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 249
+
+)clear all
+
+--S 250 of 600
+t0:=x^3/(b/f^x+a*f^x)^2
+--R 
+--R
+--R                   3 2x
+--R                  x f
+--R   (1)  -------------------------
+--R         2  x 4          x 2    2
+--R        a (f )  + 2a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 600
+--r0:=1/2*x^3/(a*b*log(f))-1/2*x^3/(a*(b+a*f^(2*x))*log(f))-3/4*x^2*_
+--  log(1+a*f^(2*x)/b)/(a*b*log(f)^2)-3/4*x*polylog(2,-a*f^(2*x)/b)/_
+--  (a*b*log(f)^3)+3/8*polylog(3,-a*f^(2*x)/b)/(a*b*log(f)^4)
+--E 251
+
+--S 252 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 252
+
+)clear all
+
+--S 253 of 600
+t0:=1/(b/f^x+a*f^x)^3
+--R 
+--R
+--R                           3x
+--R                          f
+--R   (1)  --------------------------------------
+--R         3  x 6     2    x 4       2  x 2    3
+--R        a (f )  + 3a b (f )  + 3a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 600
+r0:=-1/4*f^x/(a*(b+a*f^(2*x))^2*log(f))+1/8*f^x/(a*b*(b+a*f^(2*x))*log(f))+_
+   1/8*atan(f^x*sqrt(a)/sqrt(b))/(a^(3/2)*b^(3/2)*log(f))
+--R 
+--R
+--R                                        x +-+
+--R          2  2x 2         2x    2      f \|a         x 2x      x  +-+ +-+
+--R        (a (f  )  + 2a b f   + b )atan(------) + (a f f   - b f )\|a \|b
+--R                                         +-+
+--R                                        \|b
+--R   (2)  -----------------------------------------------------------------
+--R              3          2x 2      2 2       2x       3        +-+ +-+
+--R           (8a b log(f)(f  )  + 16a b log(f)f   + 8a b log(f))\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 600
+t0:=x/(b/f^x+a*f^x)^3
+--R 
+--R
+--R                            3x
+--R                         x f
+--R   (1)  --------------------------------------
+--R         3  x 6     2    x 4       2  x 2    3
+--R        a (f )  + 3a b (f )  + 3a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 600
+--r0:=1/8*f^x/(a*b*(b+a*f^(2*x))*log(f)^2)-1/4*f^x*x/(a*(b+a*f^(2*x))^2*_
+--  log(f))+1/8*f^x*x/(a*b*(b+a*f^(2*x))*log(f))+1/8*x*atan(f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f))-1/16*%i*polylog(2,-%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^2)+1/16*%i*polylog(2,%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^2)
+--E 257
+
+--S 258 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 258
+
+)clear all
+
+--S 259 of 600
+t0:=x^2/(b/f^x+a*f^x)^3
+--R 
+--R
+--R                          2 3x
+--R                         x f
+--R   (1)  --------------------------------------
+--R         3  x 6     2    x 4       2  x 2    3
+--R        a (f )  + 3a b (f )  + 3a b (f )  + b
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 600
+--r0:=-1/4*atan(f^x*sqrt(a)/sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^3)+1/4*f^x*x/_
+--  (a*b*(b+a*f^(2*x))*log(f)^2)-1/4*f^x*x^2/(a*(b+a*f^(2*x))^2*log(f))+_
+--  1/8*f^x*x^2/(a*b*(b+a*f^(2*x))*log(f))+1/8*x^2*atan(f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f))-1/8*%i*x*polylog(2,-%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^2)+1/8*%i*x*polylog(2,%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^2)+1/8*%i*polylog(3,-%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^3)-1/8*%i*polylog(3,%i*f^x*sqrt(a)/_
+--  sqrt(b))/(a^(3/2)*b^(3/2)*log(f)^3)
+--E 260
+
+--S 261 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 261
+
+)clear all
+
+--S 262 of 600
+t0:=f^(a+b*x+c*x^2)*g^(d+e*x+f*x^2)
+--R 
+--R
+--R            2              2
+--R         c x  + b x + a f x  + e x + d
+--R   (1)  f              g
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 600
+--r0:=1/2*f^a*g^d*erfi(1/2*(b*log(f)+e*log(g)+2*x*(c*log(f)+f*log(g)))/_
+--  sqrt(c*log(f)+f*log(g)))*sqrt(%pi)/(%e^(1/4*(b*log(f)+e*log(g))^2/_
+--  (c*log(f)+f*log(g)))*sqrt(c*log(f)+f*log(g)))
+--E 263
+
+--S 264 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 264
+
+)clear all
+
+--S 265 of 600
+t0:=F^(e*(c+d*x))*(a+b*G^(h*(f+g*x)))^n
+--R 
+--R
+--R         d e x + c e    g h x + f h     n
+--R   (1)  F           (b G            + a)
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 600
+--r0:=F^(e*(c+d*x))*(a+b*G^(h*(f+g*x)))^n*hypergeometric(-n,d*e*log(F)/_
+--  (g*h*log(G)),1+d*e*log(F)/(g*h*log(G)),-b*G^(h*(f+g*x))/a)/_
+--  (d*e*((a+b*G^(h*(f+g*x)))/a)^n*log(F))
+--E 266
+
+--S 267 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 267
+
+)clear all
+
+--S 268 of 600
+t0:=F^(a+b*x+c*x^3)*(b+3*c*x^2)
+--R 
+--R
+--R                       3
+--R             2      c x  + b x + a
+--R   (1)  (3c x  + b)F
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 600
+r0:=F^(a+b*x+c*x^3)/log(F)
+--R 
+--R
+--R            3
+--R         c x  + b x + a
+--R        F
+--R   (2)  ---------------
+--R             log(F)
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 600
+t0:=F^(1/(a+b*x+c*x^2))*(b+2*c*x)/(a+b*x+c*x^2)^2
+--R 
+--R
+--R                                    1
+--R                             --------------
+--R                                2
+--R                             c x  + b x + a
+--R                  (2c x + b)F
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 600
+r0:=-F^(1/(a+b*x+c*x^2))/log(F)
+--R 
+--R
+--R                  1
+--R           --------------
+--R              2
+--R           c x  + b x + a
+--R          F
+--R   (2)  - ---------------
+--R               log(F)
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^m
+--R 
+--R
+--R                       2
+--R                    c x  + b x + a    2           m
+--R   (1)  (2c x + b)%e              (c x  + b x + a)
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 600
+--r0:=(a+b*x+c*x^2)^m*GAMMA(1+m,-a-b*x-c*x^2)/(-a-b*x-c*x^2)^m
+--E 275
+
+--S 276 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 276
+
+)clear all
+
+--S 277 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R         4 7       3 6        3     2 2  5           2     3   4
+--R       2c x  + 7b c x  + (6a c  + 9b c )x  + (15a b c  + 5b c)x
+--R     + 
+--R          2 2        2     4  3      2          3  2      3      2 2      3
+--R       (6a c  + 12a b c + b )x  + (9a b c + 3a b )x  + (2a c + 3a b )x + a b
+--R  *
+--R          2
+--R       c x  + b x + a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 600
+r0:=-6*%e^(a+b*x+c*x^2)+6*%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)-3*%e^(a+b*x+c*x^2)*_
+   (a+b*x+c*x^2)^2+%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)^3
+--R 
+--R
+--R   (2)
+--R        3 6       2 5             2     2   4                   3  3
+--R       c x  + 3b c x  + ((3a - 3)c  + 3b c)x  + ((6a - 6)b c + b )x
+--R     + 
+--R           2                       2  2      2                 3     2
+--R       ((3a  - 6a + 6)c + (3a - 3)b )x  + (3a  - 6a + 6)b x + a  - 3a  + 6a - 6
+--R  *
+--R          2
+--R       c x  + b x + a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^2
+--R 
+--R
+--R   (1)
+--R         3 5       2 4        2     2   3              3  2      2        2
+--R       2c x  + 5b c x  + (4a c  + 4b c)x  + (6a b c + b )x  + (2a c + 2a b )x
+--R     + 
+--R        2
+--R       a b
+--R  *
+--R          2
+--R       c x  + b x + a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 600
+r0:=2*%e^(a+b*x+c*x^2)-2*%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)+%e^(a+b*x+c*x^2)*_
+   (a+b*x+c*x^2)^2
+--R 
+--R
+--R   (2)
+--R       2 4         3                 2  2                  2
+--R     (c x  + 2b c x  + ((2a - 2)c + b )x  + (2a - 2)b x + a  - 2a + 2)
+--R  *
+--R          2
+--R       c x  + b x + a
+--R     %e
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)
+--R 
+--R
+--R                                                   2
+--R           2 3         2            2           c x  + b x + a
+--R   (1)  (2c x  + 3b c x  + (2a c + b )x + a b)%e
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 600
+r0:=-%e^(a+b*x+c*x^2)+%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)
+--R 
+--R
+--R                                 2
+--R            2                 c x  + b x + a
+--R   (2)  (c x  + b x + a - 1)%e
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)
+--R 
+--R
+--R                       2
+--R                    c x  + b x + a
+--R   (1)  (2c x + b)%e
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 600
+r0:=%e^(a+b*x+c*x^2)
+--R 
+--R
+--R             2
+--R          c x  + b x + a
+--R   (2)  %e
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)
+--R 
+--R
+--R                       2
+--R                    c x  + b x + a
+--R        (2c x + b)%e
+--R   (1)  --------------------------
+--R                 2
+--R              c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 600
+--r0:=Ei(a+b*x+c*x^2)
+--E 290
+
+--S 291 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 291
+
+)clear all
+
+--S 292 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)^2
+--R 
+--R
+--R                                2
+--R                             c x  + b x + a
+--R                 (2c x + b)%e
+--R   (1)  --------------------------------------------
+--R         2 4         3            2  2             2
+--R        c x  + 2b c x  + (2a c + b )x  + 2a b x + a
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 600
+--r0:=-%e^(a+b*x+c*x^2)/(a+b*x+c*x^2)+Ei(a+b*x+c*x^2)
+--E 293
+
+--S 294 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 294
+
+)clear all
+
+--S 295 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)^3
+--R 
+--R
+--R   (1)
+--R                    2
+--R                 c x  + b x + a
+--R     (2c x + b)%e
+--R  /
+--R        3 6       2 5        2     2   4              3  3      2        2  2
+--R       c x  + 3b c x  + (3a c  + 3b c)x  + (6a b c + b )x  + (3a c + 3a b )x
+--R     + 
+--R         2       3
+--R       3a b x + a
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 600
+--r0:=-1/2*%e^(a+b*x+c*x^2)/(a+b*x+c*x^2)^2-1/2*%e^(a+b*x+c*x^2)/_
+--  (a+b*x+c*x^2)+1/2*Ei(a+b*x+c*x^2)
+--E 296
+
+--S 297 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 297
+
+)clear all
+
+--S 298 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^(5/2)
+--R 
+--R
+--R   (1)
+--R         3 5       2 4        2     2   3              3  2      2        2
+--R       2c x  + 5b c x  + (4a c  + 4b c)x  + (6a b c + b )x  + (2a c + 2a b )x
+--R     + 
+--R        2
+--R       a b
+--R  *
+--R          2           +--------------+
+--R       c x  + b x + a |   2
+--R     %e              \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 600
+--r0:=-5/2*%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)^(3/2)+%e^(a+b*x+c*x^2)*_
+--  (a+b*x+c*x^2)^(5/2)-15/8*erfi(sqrt(a+b*x+c*x^2))*sqrt(%pi)+_
+--  15/4*%e^(a+b*x+c*x^2)*sqrt(a+b*x+c*x^2)
+--E 299
+
+--S 300 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 300
+
+)clear all
+
+--S 301 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^(3/2)
+--R 
+--R
+--R   (1)
+--R                                              2           +--------------+
+--R      2 3         2            2           c x  + b x + a |   2
+--R   (2c x  + 3b c x  + (2a c + b )x + a b)%e              \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 600
+--r0:=%e^(a+b*x+c*x^2)*(a+b*x+c*x^2)^(3/2)+3/4*erfi(sqrt(a+b*x+c*x^2))*_
+--  sqrt(%pi)-3/2*%e^(a+b*x+c*x^2)*sqrt(a+b*x+c*x^2)
+--E 302
+
+--S 303 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 303
+
+)clear all
+
+--S 304 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)*(a+b*x+c*x^2)^(1/2)
+--R 
+--R
+--R                       2           +--------------+
+--R                    c x  + b x + a |   2
+--R   (1)  (2c x + b)%e              \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 600
+--r0:=-1/2*erfi(sqrt(a+b*x+c*x^2))*sqrt(%pi)+%e^(a+b*x+c*x^2)*sqrt(a+b*x+c*x^2)
+--E 305
+
+--S 306 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 306
+
+)clear all
+
+--S 307 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)^(1/2)
+--R 
+--R
+--R                       2
+--R                    c x  + b x + a
+--R        (2c x + b)%e
+--R   (1)  --------------------------
+--R              +--------------+
+--R              |   2
+--R             \|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 600
+--r0:=erfi(sqrt(a+b*x+c*x^2))*sqrt(%pi)
+--E 308
+
+--S 309 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 309
+
+)clear all
+
+--S 310 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)^(3/2)
+--R 
+--R
+--R                           2
+--R                        c x  + b x + a
+--R            (2c x + b)%e
+--R   (1)  ---------------------------------
+--R                         +--------------+
+--R            2            |   2
+--R        (c x  + b x + a)\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 600
+--r0:=2*erfi(sqrt(a+b*x+c*x^2))*sqrt(%pi)-2*%e^(a+b*x+c*x^2)/sqrt(a+b*x+c*x^2)
+--E 311
+
+--S 312 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 312
+
+)clear all
+
+--S 313 of 600
+t0:=%e^(a+b*x+c*x^2)*(b+2*c*x)/(a+b*x+c*x^2)^(5/2)
+--R 
+--R
+--R                                          2
+--R                                       c x  + b x + a
+--R                           (2c x + b)%e
+--R   (1)  ---------------------------------------------------------------
+--R                                                       +--------------+
+--R          2 4         3            2  2             2  |   2
+--R        (c x  + 2b c x  + (2a c + b )x  + 2a b x + a )\|c x  + b x + a
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 600
+--r0:=-2/3*%e^(a+b*x+c*x^2)/(a+b*x+c*x^2)^(3/2)+4/3*erfi(sqrt(a+b*x+c*x^2))*_
+--  sqrt(%pi)-4/3*%e^(a+b*x+c*x^2)/sqrt(a+b*x+c*x^2)
+--E 314
+
+--S 315 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 315
+
+)clear all
+
+--S 316 of 600
+t0:=%e^(x/(2+x^2))*(2-x^2)/(2*x+x^3)
+--R 
+--R
+--R                       x
+--R                    ------
+--R                     2
+--R            2       x  + 2
+--R        (- x  + 2)%e
+--R   (1)  ------------------
+--R               3
+--R              x  + 2x
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 600
+--r0:=Ei(x/(2+x^2))
+--E 317
+
+--S 318 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 318
+
+)clear all
+
+--S 319 of 600
+t0:=%e^(x/(2+x^2))*(2+2*x+3*x^2-x^3+2*x^4)/(2*x+x^3)
+--R 
+--R
+--R                                      x
+--R                                   ------
+--R                                    2
+--R           4    3     2            x  + 2
+--R        (2x  - x  + 3x  + 2x + 2)%e
+--R   (1)  ---------------------------------
+--R                      3
+--R                     x  + 2x
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 600
+--r0:=%e^(x/(2+x^2))*(2+x^2)+Ei(x/(2+x^2))
+--E 320
+
+--S 321 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 321
+
+)clear all
+
+--S 322 of 600
+t0:=%e^(%e^x+x)*(1+%e^x)/(%e^x+x)
+--R 
+--R
+--R                     x
+--R           x       %e  + x
+--R        (%e  + 1)%e
+--R   (1)  ------------------
+--R                x
+--R              %e  + x
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 600
+--r0:=Ei(%e^x+x)
+--E 323
+
+--S 324 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 324
+
+)clear all
+
+--S 325 of 600
+t0:=%e^(1/(-1+x^2))*(1-3*x-x^2+x^3)/(1-x-x^2+x^3)
+--R 
+--R
+--R                               1
+--R                            ------
+--R                             2
+--R          3    2            x  - 1
+--R        (x  - x  - 3x + 1)%e
+--R   (1)  --------------------------
+--R               3    2
+--R              x  - x  - x + 1
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 600
+r0:=%e^(1/(-1+x^2))*(1+x)
+--R 
+--R
+--R                    1
+--R                 ------
+--R                  2
+--R                 x  - 1
+--R   (2)  (x + 1)%e
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 600
+t0:=%e^(1+1/log(x))*(-1+log(x)^2)/log(x)^2
+--R 
+--R
+--R                       log(x) + 1
+--R                       ----------
+--R               2         log(x)
+--R        (log(x)  - 1)%e
+--R   (1)  -------------------------
+--R                       2
+--R                 log(x)
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 600
+r0:=%e^(1+1/log(x))*x
+--R 
+--R
+--R            log(x) + 1
+--R            ----------
+--R              log(x)
+--R   (2)  x %e
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 600
+t0:=1/(%e^x*sqrt(1+(-1)/%e^(2*x)))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R            +--------+
+--R            |  2x
+--R          x |%e   - 1
+--R        %e  |--------
+--R            |    2x
+--R           \|  %e
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 600
+r0:=-asin(1/%e^x)
+--R 
+--R
+--R                1
+--R   (2)  - asin(---)
+--R                 x
+--R               %e
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 600
+t0:=%e^x/(4+%e^(2*x))
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R          2x
+--R        %e   + 4
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 600
+r0:=1/2*atan(1/2*%e^x)
+--R 
+--R
+--R               x
+--R             %e
+--R        atan(---)
+--R              2
+--R   (2)  ---------
+--R            2
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 600
+t0:=%e^x/(1-%e^(2*x))
+--R 
+--R
+--R               x
+--R             %e
+--R   (1)  - --------
+--R            2x
+--R          %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 600
+r0:=atanh(%e^x)
+--R 
+--R
+--R                x
+--R   (2)  atanh(%e )
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 600
+t0:=%e^x/(3-4*%e^(2*x))
+--R 
+--R
+--R               x
+--R             %e
+--R   (1)  - ---------
+--R             2x
+--R          4%e   - 3
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 600
+r0:=1/2*atanh(2*%e^x/sqrt(3))/sqrt(3)
+--R 
+--R
+--R                 x
+--R              2%e
+--R        atanh(----)
+--R               +-+
+--R              \|3
+--R   (2)  -----------
+--R             +-+
+--R           2\|3
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 600
+t0:=%e^x*sqrt(3-4*%e^(2*x))
+--R 
+--R
+--R            +-----------+
+--R          x |     2x
+--R   (1)  %e \|- 4%e   + 3
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 600
+r0:=3/4*asin(2*%e^x/sqrt(3))+1/2*%e^x*sqrt(3-4*%e^(2*x))
+--R 
+--R
+--R             +-----------+            x
+--R           x |     2x              2%e
+--R        2%e \|- 4%e   + 3  + 3asin(----)
+--R                                    +-+
+--R                                   \|3
+--R   (2)  --------------------------------
+--R                        4
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 600
+t0:=%e^(x^2)*x^3
+--R 
+--R
+--R             2
+--R         3  x
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 600
+r0:=-1/2*%e^(x^2)+1/2*%e^(x^2)*x^2
+--R 
+--R
+--R                   2
+--R          2       x
+--R        (x  - 1)%e
+--R   (2)  ------------
+--R              2
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 600
+t0:=%e^x*sqrt(1-%e^(2*x))
+--R 
+--R
+--R            +----------+
+--R          x |    2x
+--R   (1)  %e \|- %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 600
+r0:=1/2*asin(%e^x)+1/2*%e^x*sqrt(1-%e^(2*x))
+--R 
+--R
+--R            +----------+
+--R          x |    2x               x
+--R        %e \|- %e   + 1  + asin(%e )
+--R   (2)  ----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 600
+t0:=%e^x/sqrt(1+%e^x+%e^(2*x))
+--R 
+--R
+--R                 x
+--R               %e
+--R   (1)  -----------------
+--R         +--------------+
+--R         |  2x     x
+--R        \|%e   + %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 600
+r0:=asinh((1+2*%e^x)/sqrt(3))
+--R 
+--R
+--R                 x
+--R              2%e  + 1
+--R   (2)  asinh(--------)
+--R                 +-+
+--R                \|3
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R            +------------------+        +----------------+
+--R          x |    x 2      x           x |   x 2     x
+--R        %e \|4(%e )  + 4%e  + 4  - 2%e \|(%e )  + %e  + 1
+--R   (3)  --------------------------------------------------
+--R              +----------------+ +------------------+
+--R              |   x 2     x      |    x 2      x
+--R             \|(%e )  + %e  + 1 \|4(%e )  + 4%e  + 4
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 600
+t0:=%e^x/(-4+%e^(2*x))
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R          2x
+--R        %e   - 4
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 600
+r0:=-1/2*atanh(1/2*%e^x)
+--R 
+--R
+--R                  x
+--R                %e
+--R          atanh(---)
+--R                 2
+--R   (2)  - ----------
+--R               2
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 600
+t0:=%e^sqrt(x)
+--R 
+--R
+--R           +-+
+--R          \|x
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 600
+r0:=-2*%e^sqrt(x)+2*%e^sqrt(x)*sqrt(x)
+--R 
+--R
+--R                      +-+
+--R           +-+       \|x
+--R   (2)  (2\|x  - 2)%e
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 600
+t0:=%e^x/(1+%e^(2*x))
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R          2x
+--R        %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 600
+r0:=atan(%e^x)
+--R 
+--R
+--R               x
+--R   (2)  atan(%e )
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 600
+t0:=%e^(2-x^2)*x
+--R 
+--R
+--R               2
+--R            - x  + 2
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 600
+r0:=-1/2*%e^(2-x^2)
+--R 
+--R
+--R               2
+--R            - x  + 2
+--R          %e
+--R   (2)  - ----------
+--R               2
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 600
+t0:=%e^x-x^%e
+--R 
+--R
+--R           %e     x
+--R   (1)  - x   + %e
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 600
+r0:=%e^x-x^(1+%e)/(1+%e)
+--R 
+--R
+--R           %e + 1             x
+--R        - x       + (%e + 1)%e
+--R   (2)  -----------------------
+--R                 %e + 1
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 600
+t0:=(-1+%e^(2*x))/(3+%e^(2*x))
+--R 
+--R
+--R          2x
+--R        %e   - 1
+--R   (1)  --------
+--R          2x
+--R        %e   + 3
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 600
+r0:=-1/3*x+2/3*log(3+%e^(2*x))
+--R 
+--R
+--R               2x
+--R        2log(%e   + 3) - x
+--R   (2)  ------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 600
+t0:=%e^x/sqrt(1-%e^(2*x))
+--R 
+--R
+--R               x
+--R             %e
+--R   (1)  -------------
+--R         +----------+
+--R         |    2x
+--R        \|- %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 600
+r0:=asin(%e^x)
+--R 
+--R
+--R               x
+--R   (2)  asin(%e )
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 600
+t0:=%e^(2*x)/(1+%e^(4*x))
+--R 
+--R
+--R            2x
+--R          %e
+--R   (1)  --------
+--R          4x
+--R        %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 600
+r0:=1/2*atan(%e^(2*x))
+--R 
+--R
+--R               2x
+--R        atan(%e  )
+--R   (2)  ----------
+--R             2
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 600
+t0:=1/(-3*%e^x+%e^(2*x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R          2x      x
+--R        %e   - 3%e
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 600
+r0:=1/3/%e^x-1/9*x+1/9*log(3-%e^x)
+--R 
+--R
+--R          x        x            x
+--R        %e log(- %e  + 3) - x %e  + 3
+--R   (2)  -----------------------------
+--R                        x
+--R                     9%e
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 600
+t0:=%e^x*(-2+%e^x)/(1+%e^x)
+--R 
+--R
+--R           x 2      x
+--R        (%e )  - 2%e
+--R   (1)  -------------
+--R             x
+--R           %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 600
+r0:=%e^x-3*log(1+%e^x)
+--R 
+--R
+--R                 x          x
+--R   (2)  - 3log(%e  + 1) + %e
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 600
+t0:=%e^x/(-1+%e^(2*x))
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R          2x
+--R        %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 600
+r0:=-atanh(%e^x)
+--R 
+--R
+--R                  x
+--R   (2)  - atanh(%e )
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 600
+t0:=%e^x/(1+%e^(2*x))
+--R 
+--R
+--R             x
+--R           %e
+--R   (1)  --------
+--R          2x
+--R        %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 600
+r0:=atan(%e^x)
+--R 
+--R
+--R               x
+--R   (2)  atan(%e )
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 600
+t0:=(1/%e^x+%e^x)/((-1)/%e^x+%e^x)
+--R 
+--R
+--R           x 2
+--R        (%e )  + 1
+--R   (1)  ----------
+--R           x 2
+--R        (%e )  - 1
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 600
+r0:=log(1/%e^x-%e^x),-x+log(1-%e^(2*x))
+--R 
+--R
+--R                  x 2
+--R             - (%e )  + 1          2x
+--R   (2)  [log(------------),log(- %e   + 1) - x]
+--R                    x
+--R                  %e
+--R                                             Type: Tuple(Expression(Integer))
+--E 392
+
+--S 393 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 600
+t0:=((-1)/%e^x+%e^x)/(1/%e^x+%e^x)
+--R 
+--R
+--R           x 2
+--R        (%e )  - 1
+--R   (1)  ----------
+--R           x 2
+--R        (%e )  + 1
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 600
+r0:=log(1/%e^x+%e^x),-x+log(1+%e^(2*x))
+--R 
+--R
+--R                x 2
+--R             (%e )  + 1        2x
+--R   (2)  [log(----------),log(%e   + 1) - x]
+--R                   x
+--R                 %e
+--R                                             Type: Tuple(Expression(Integer))
+--E 395
+
+--S 396 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 600
+t0:=(1/%e^(2*x)+%e^(2*x))/((-1)/%e^(2*x)+%e^(2*x))
+--R 
+--R
+--R           2x 2
+--R        (%e  )  + 1
+--R   (1)  -----------
+--R           2x 2
+--R        (%e  )  - 1
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 600
+r0:=-x+1/2*log(1-%e^(4*x))
+--R 
+--R
+--R                4x
+--R        log(- %e   + 1) - 2x
+--R   (2)  --------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 600
+t0:=%e^x/sqrt(1+%e^(2*x))
+--R 
+--R
+--R              x
+--R            %e
+--R   (1)  -----------
+--R         +--------+
+--R         |  2x
+--R        \|%e   + 1
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 600
+r0:=asinh(%e^x)
+--R 
+--R
+--R                x
+--R   (2)  asinh(%e )
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 600
+t0:=%e^sqrt(4+x)/sqrt(4+x)
+--R 
+--R
+--R           +-----+
+--R          \|x + 4
+--R        %e
+--R   (1)  ----------
+--R          +-----+
+--R         \|x + 4
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 600
+r0:=2*%e^sqrt(4+x)
+--R 
+--R
+--R            +-----+
+--R           \|x + 4
+--R   (2)  2%e
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 600
+t0:=x/sqrt(-1+%e^(2*x^2))
+--R 
+--R
+--R              x
+--R   (1)  ------------
+--R         +---------+
+--R         |    2
+--R         |  2x
+--R        \|%e    - 1
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 600
+r0:=1/2*atan(sqrt(-1+%e^(2*x^2)))
+--R 
+--R
+--R              +---------+
+--R              |    2
+--R              |  2x
+--R        atan(\|%e    - 1 )
+--R   (2)  ------------------
+--R                 2
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 600
+t0:=%e^x*sqrt(9+%e^(2*x))
+--R 
+--R
+--R            +--------+
+--R          x |  2x
+--R   (1)  %e \|%e   + 9
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 600
+r0:=9/2*asinh(1/3*%e^x)+1/2*%e^x*sqrt(9+%e^(2*x))
+--R 
+--R
+--R            +--------+            x
+--R          x |  2x               %e
+--R        %e \|%e   + 9  + 9asinh(---)
+--R                                 3
+--R   (2)  ----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 600
+t0:=%e^x*sqrt(1+%e^(2*x))
+--R 
+--R
+--R            +--------+
+--R          x |  2x
+--R   (1)  %e \|%e   + 1
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 600
+r0:=1/2*asinh(%e^x)+1/2*%e^x*sqrt(1+%e^(2*x))
+--R 
+--R
+--R            +--------+
+--R          x |  2x                x
+--R        %e \|%e   + 1  + asinh(%e )
+--R   (2)  ---------------------------
+--R                     2
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 600
+t0:=%e^(x^2)*x/(1+%e^(2*x^2))
+--R 
+--R
+--R               2
+--R              x
+--R          x %e
+--R   (1)  ---------
+--R            2
+--R          2x
+--R        %e    + 1
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 600
+r0:=1/2*atan(%e^(x^2))
+--R 
+--R
+--R                2
+--R               x
+--R        atan(%e  )
+--R   (2)  ----------
+--R             2
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 600
+t0:=%e^(x^(3/2))*x^2
+--R 
+--R
+--R              +-+
+--R         2  x\|x
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 600
+r0:=-2/3*%e^(x^(3/2))+2/3*%e^(x^(3/2))*x^(3/2)
+--R 
+--R
+--R                        +-+
+--R            +-+       x\|x
+--R        (2x\|x  - 2)%e
+--R   (2)  -------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 600
+t0:=%e^x/sqrt(-3+%e^(2*x))
+--R 
+--R
+--R              x
+--R            %e
+--R   (1)  -----------
+--R         +--------+
+--R         |  2x
+--R        \|%e   - 3
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 600
+r0:=atanh(%e^x/sqrt(-3+%e^(2*x)))
+--R 
+--R
+--R                    x
+--R                  %e
+--R   (2)  atanh(-----------)
+--R               +--------+
+--R               |  2x
+--R              \|%e   - 3
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 600
+t0:=%e^x/(16-%e^(2*x))
+--R 
+--R
+--R               x
+--R             %e
+--R   (1)  - ---------
+--R            2x
+--R          %e   - 16
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 600
+r0:=1/4*atanh(1/4*%e^x)
+--R 
+--R
+--R                x
+--R              %e
+--R        atanh(---)
+--R               4
+--R   (2)  ----------
+--R             4
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 600
+t0:=%e^(5*x)/(1+%e^(10*x))
+--R 
+--R
+--R             5x
+--R           %e
+--R   (1)  ---------
+--R          10x
+--R        %e    + 1
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 600
+r0:=1/5*atan(%e^(5*x))
+--R 
+--R
+--R               5x
+--R        atan(%e  )
+--R   (2)  ----------
+--R             5
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 600
+t0:=%e^(4*x)/sqrt(16+%e^(8*x))
+--R 
+--R
+--R              4x
+--R            %e
+--R   (1)  ------------
+--R         +---------+
+--R         |  8x
+--R        \|%e   + 16
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 600
+r0:=1/4*asinh(1/4*%e^(4*x))
+--R 
+--R
+--R                4x
+--R              %e
+--R        asinh(----)
+--R                4
+--R   (2)  -----------
+--R             4
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 600
+t0:=%e^(4*x^3)*x^2*cos(7*x^3)
+--R 
+--R
+--R                      3
+--R         2      3   4x
+--R   (1)  x cos(7x )%e
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 600
+r0:=4/195*%e^(4*x^3)*cos(7*x^3)+7/195*%e^(4*x^3)*sin(7*x^3)
+--R 
+--R
+--R             3                        3
+--R           4x       3           3   4x
+--R        7%e   sin(7x ) + 4cos(7x )%e
+--R   (2)  -------------------------------
+--R                      195
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 600
+t0:=%e^(1+x^2)*x
+--R 
+--R
+--R             2
+--R            x  + 1
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 600
+r0:=1/2*%e^(1+x^2)
+--R 
+--R
+--R           2
+--R          x  + 1
+--R        %e
+--R   (2)  --------
+--R            2
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 600
+t0:=%e^(1+x^3)*x^2
+--R 
+--R
+--R             3
+--R         2  x  + 1
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 600
+r0:=1/3*%e^(1+x^3)
+--R 
+--R
+--R           3
+--R          x  + 1
+--R        %e
+--R   (2)  --------
+--R            3
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 600
+t0:=%e^sqrt(x)/sqrt(x)
+--R 
+--R
+--R           +-+
+--R          \|x
+--R        %e
+--R   (1)  ------
+--R          +-+
+--R         \|x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 600
+r0:=2*%e^sqrt(x)
+--R 
+--R
+--R            +-+
+--R           \|x
+--R   (2)  2%e
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 444
+
+)clear all
+
+--S 445 of 600
+t0:=%e^(x^(1/3))/x^(2/3)
+--R 
+--R
+--R          3+-+
+--R          \|x
+--R        %e
+--R   (1)  ------
+--R         3+-+2
+--R         \|x
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 600
+r0:=3*%e^(x^(1/3))
+--R 
+--R
+--R           3+-+
+--R           \|x
+--R   (2)  3%e
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 600
+t0:=%e^(3*x)*(-8+2*x^3+x^5)
+--R 
+--R
+--R          5     3       3x
+--R   (1)  (x  + 2x  - 8)%e
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 600
+--r0:=-76/27*%e^(3*x)+4/9*%e^(3*x)*x-2/3*%e^(3*x)*x^2+2/3*%e^(3*x)*x^3-_
+--  1/729*GAMMA(6,-3*x)
+--E 449
+
+--S 450 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 450
+
+)clear all
+
+--S 451 of 600
+t0:=(%e^x+x)^2
+--R 
+--R
+--R           x 2        x    2
+--R   (1)  (%e )  + 2x %e  + x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 600
+r0:=-2*%e^x+1/2*%e^(2*x)+2*%e^x*x+1/3*x^3
+--R 
+--R
+--R           2x               x     3
+--R        3%e   + (12x - 12)%e  + 2x
+--R   (2)  ---------------------------
+--R                     6
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 600
+t0:=(%e^x+%e^(2*x)+%e^(3*x))/%e^(4*x)
+--R 
+--R
+--R          3x     2x     x
+--R        %e   + %e   + %e
+--R   (1)  -----------------
+--R                 4x
+--R               %e
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 600
+r0:=(-1/3)/%e^(3*x)+(-1/2)/%e^(2*x)+(-1)/%e^x
+--R 
+--R
+--R              2x      x   3x      x  2x
+--R        (- 6%e   - 3%e )%e   - 2%e %e
+--R   (2)  -------------------------------
+--R                     x  2x  3x
+--R                  6%e %e  %e
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 600
+t0:=%e^x/(1+2*%e^x+%e^(2*x))
+--R 
+--R
+--R                x
+--R              %e
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 2%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 600
+r0:=(-1)/(1+%e^x)
+--R 
+--R
+--R             1
+--R   (2)  - -------
+--R            x
+--R          %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 600
+t0:=cos(3*x)/%e^x
+--R 
+--R
+--R        cos(3x)
+--R   (1)  -------
+--R            x
+--R          %e
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 600
+r0:=-1/10*cos(3*x)/%e^x+3/10*sin(3*x)/%e^x
+--R 
+--R
+--R        3sin(3x) - cos(3x)
+--R   (2)  ------------------
+--R                   x
+--R               10%e
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 600
+t0:=%e^(2*x)/(2+3*%e^x+%e^(2*x))
+--R 
+--R
+--R                2x
+--R              %e
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 2
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 600
+r0:=-log(1+%e^x)+2*log(2+%e^x)
+--R 
+--R
+--R               x              x
+--R   (2)  2log(%e  + 2) - log(%e  + 1)
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 600
+t0:=%e^(2*x)/(1+%e^x)
+--R 
+--R
+--R            2x
+--R          %e
+--R   (1)  -------
+--R          x
+--R        %e  + 1
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 600
+r0:=%e^x-log(1+%e^x)
+--R 
+--R
+--R                x          x
+--R   (2)  - log(%e  + 1) + %e
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 600
+t0:=%e^(3*x)*cos(5*x)
+--R 
+--R
+--R                 3x
+--R   (1)  cos(5x)%e
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 600
+r0:=3/34*%e^(3*x)*cos(5*x)+5/34*%e^(3*x)*sin(5*x)
+--R 
+--R
+--R           3x                    3x
+--R        5%e  sin(5x) + 3cos(5x)%e
+--R   (2)  ---------------------------
+--R                     34
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 600
+t0:=%e^x*sech(%e^x)
+--R 
+--R
+--R          x       x
+--R   (1)  %e sech(%e )
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 600
+r0:=atan(sinh(%e^x))
+--R 
+--R
+--R                    x
+--R   (2)  atan(sinh(%e ))
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 600
+t0:=1/(%e^x*(1+2*%e^x))
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R            x 2     x
+--R        2(%e )  + %e
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 600
+r0:=(-1)/%e^x-2*x+2*log(1+2*%e^x)
+--R 
+--R
+--R           x       x             x
+--R        2%e log(2%e  + 1) - 2x %e  - 1
+--R   (2)  ------------------------------
+--R                        x
+--R                      %e
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 600
+t0:=%e^x*cos(4+3*x)
+--R 
+--R
+--R                     x
+--R   (1)  cos(3x + 4)%e
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 600
+r0:=1/10*%e^x*cos(4+3*x)+3/10*%e^x*sin(4+3*x)
+--R 
+--R
+--R           x                           x
+--R        3%e sin(3x + 4) + cos(3x + 4)%e
+--R   (2)  --------------------------------
+--R                       10
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 600
+t0:=%e^x*sec(1-%e^x)^3
+--R 
+--R
+--R          x      x     3
+--R   (1)  %e sec(%e  - 1)
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 600
+r0:=-1/2*atanh(sin(1-%e^x))-1/2*sec(1-%e^x)*tan(1-%e^x)
+--R 
+--R
+--R                    x               x           x
+--R        atanh(sin(%e  - 1)) + sec(%e  - 1)tan(%e  - 1)
+--R   (2)  ----------------------------------------------
+--R                               2
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+)clear all
+
+--S 484 of 600
+t0:=(1/%e^x+%e^x)*x
+--R 
+--R
+--R             x 2
+--R        x (%e )  + x
+--R   (1)  ------------
+--R               x
+--R             %e
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 600
+r0:=(-1)/%e^x-%e^x-x/%e^x+%e^x*x
+--R 
+--R
+--R                  x 2
+--R        (x - 1)(%e )  - x - 1
+--R   (2)  ---------------------
+--R                   x
+--R                 %e
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 600
+t0:=%e^x/(2+3*%e^x+%e^(2*x))
+--R 
+--R
+--R                x
+--R              %e
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   + 3%e  + 2
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 600
+r0:=-2*atanh(3+2*%e^x)
+--R 
+--R
+--R                    x
+--R   (2)  - 2atanh(2%e  + 3)
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 600
+t0:=%e^(2*x)/(1+%e^x)^(1/3)
+--R 
+--R
+--R             2x
+--R           %e
+--R   (1)  ----------
+--R         +-------+
+--R        3|  x
+--R        \|%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 600
+r0:=-3/2*(1+%e^x)^(2/3)+3/5*(1+%e^x)^(5/3)
+--R 
+--R
+--R                   +-------+2
+--R            x     3|  x
+--R        (6%e  - 9)\|%e  + 1
+--R   (2)  ---------------------
+--R                  10
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 600
+t0:=%e^(2*x)/(1+%e^x)^(1/4)
+--R 
+--R
+--R             2x
+--R           %e
+--R   (1)  ----------
+--R         +-------+
+--R        4|  x
+--R        \|%e  + 1
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 600
+r0:=-4/3*(1+%e^x)^(3/4)+4/7*(1+%e^x)^(7/4)
+--R 
+--R
+--R                     +-------+3
+--R             x      4|  x
+--R        (12%e  - 16)\|%e  + 1
+--R   (2)  -----------------------
+--R                   21
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 600
+t0:=(-%e^x+2*%e^(2*x))/sqrt(-1-6*%e^x+3*%e^(2*x))
+--R 
+--R
+--R               2x     x
+--R            2%e   - %e
+--R   (1)  -------------------
+--R         +----------------+
+--R         |   2x      x
+--R        \|3%e   - 6%e  - 1
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 600
+r0:=-atanh((1-%e^x)*sqrt(3)/sqrt(-1-6*%e^x+3*%e^(2*x)))/sqrt(3)+_
+   2/3*sqrt(-1-6*%e^x+3*%e^(2*x))
+--R 
+--R
+--R                   +-+  x    +-+            +----------------+
+--R                  \|3 %e  - \|3         +-+ |   2x      x
+--R        3atanh(-------------------) + 2\|3 \|3%e   - 6%e  - 1
+--R                +----------------+
+--R                |   2x      x
+--R               \|3%e   - 6%e  - 1
+--R   (2)  ------------------------------------------------------
+--R                                   +-+
+--R                                 3\|3
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 600
+t0:=%e^x*(-5*x+x^2)
+--R 
+--R
+--R          2        x
+--R   (1)  (x  - 5x)%e
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 600
+r0:=7*%e^x-7*%e^x*x+%e^x*x^2,-3*%e^x-3*%e^x*(5-x)+%e^x*(5-x)^2
+--R 
+--R
+--R           2            x   2            x
+--R   (2)  [(x  - 7x + 7)%e ,(x  - 7x + 7)%e ]
+--R                                             Type: Tuple(Expression(Integer))
+--E 500
+
+--S 501 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 600
+t0:=%e^(3*x)*(-x+x^2)
+--R 
+--R
+--R          2       3x
+--R   (1)  (x  - x)%e
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 600
+r0:=-1/27*%e^(3*x)-1/9*%e^(3*x)*(1-x)+1/3*%e^(3*x)*(1-x)^2
+--R 
+--R
+--R           2             3x
+--R        (9x  - 15x + 5)%e
+--R   (2)  -------------------
+--R                 27
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 600
+t0:=%e^(x^x)*x^(2*x)*(1+log(x))
+--R 
+--R
+--R                          x
+--R                     2x  x
+--R   (1)  (log(x) + 1)x  %e
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 600
+r0:=%e^(x^x)*(-1+x^x)
+--R 
+--R
+--R                   x
+--R          x       x
+--R   (2)  (x  - 1)%e
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 600
+t0:=(%e^(5*x)+%e^(7*x))/(1/%e^x+%e^x)
+--R 
+--R
+--R          x  7x     x  5x
+--R        %e %e   + %e %e
+--R   (1)  -----------------
+--R               x 2
+--R            (%e )  + 1
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 600
+r0:=1/6*%e^(6*x)
+--R 
+--R
+--R          6x
+--R        %e
+--R   (2)  ----
+--R          6
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 600
+t0:=x^(-2+(-1)/x)*(1-log(x))
+--R 
+--R
+--R                       - 2x - 1
+--R                       --------
+--R                           x
+--R   (1)  (- log(x) + 1)x
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 600
+r0:=(-1)/x^(1/x)
+--R 
+--R
+--R           1
+--R   (2)  - --
+--R           1
+--R           -
+--R           x
+--R          x
+--R                                                    Type: Expression(Integer)
+--E 512
+
+-- Error detected within library code: Cannot happen
+-- d0:=normalize(t0-D(r0,x))
+--S 513 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 513
+
+)clear all
+
+--S 514 of 600
+t0:=(a+%e^x*b)^2
+--R 
+--R
+--R         2   x 2          x    2
+--R   (1)  b (%e )  + 2a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 600
+r0:=2*%e^x*a*b+1/2*%e^(2*x)*b^2+a^2*x
+--R 
+--R
+--R         2  2x          x     2
+--R        b %e   + 4a b %e  + 2a x
+--R   (2)  ------------------------
+--R                    2
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 600
+t0:=(a+%e^x*b)^3
+--R 
+--R
+--R         3   x 3       2   x 2     2    x    3
+--R   (1)  b (%e )  + 3a b (%e )  + 3a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 600
+r0:=3*%e^x*a^2*b+3/2*%e^(2*x)*a*b^2+1/3*%e^(3*x)*b^3+a^3*x
+--R 
+--R
+--R          3  3x       2  2x      2    x     3
+--R        2b %e   + 9a b %e   + 18a b %e  + 6a x
+--R   (2)  --------------------------------------
+--R                           6
+--R                                                    Type: Expression(Integer)
+--E 518
+
+--S 519 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 519
+
+)clear all
+
+--S 520 of 600
+t0:=(a+%e^x*b)^4
+--R 
+--R
+--R         4   x 4       3   x 3     2 2   x 2     3    x    4
+--R   (1)  b (%e )  + 4a b (%e )  + 6a b (%e )  + 4a b %e  + a
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 600
+r0:=4*%e^x*a^3*b+3*%e^(2*x)*a^2*b^2+4/3*%e^(3*x)*a*b^3+1/4*%e^(4*x)*b^4+a^4*x
+--R 
+--R
+--R          4  4x        3  3x      2 2  2x      3    x      4
+--R        3b %e   + 16a b %e   + 36a b %e   + 48a b %e  + 12a x
+--R   (2)  -----------------------------------------------------
+--R                                  12
+--R                                                    Type: Expression(Integer)
+--E 521
+
+--S 522 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 522
+
+)clear all
+
+--S 523 of 600
+t0:=1/sqrt(a+%e^(c+d*x)*b)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         |    d x + c
+--R        \|b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 600
+r0:=-2*atanh(sqrt(a+%e^(c+d*x)*b)/sqrt(a))/(d*sqrt(a))
+--R 
+--R
+--R                  +---------------+
+--R                  |    d x + c
+--R                 \|b %e        + a
+--R          2atanh(------------------)
+--R                         +-+
+--R                        \|a
+--R   (2)  - --------------------------
+--R                       +-+
+--R                     d\|a
+--R                                                    Type: Expression(Integer)
+--E 524
+
+--S 525 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 525
+
+)clear all
+
+--S 526 of 600
+t0:=1/sqrt(-a+%e^(c+d*x)*b)
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         +---------------+
+--R         |    d x + c
+--R        \|b %e        - a
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 600
+r0:=2*atan(sqrt(-a+%e^(c+d*x)*b)/sqrt(a))/(d*sqrt(a))
+--R 
+--R
+--R               +---------------+
+--R               |    d x + c
+--R              \|b %e        - a
+--R        2atan(------------------)
+--R                      +-+
+--R                     \|a
+--R   (2)  -------------------------
+--R                    +-+
+--R                  d\|a
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 600
+t0:=sqrt(a+%e^(c+d*x)*b)
+--R 
+--R
+--R         +---------------+
+--R         |    d x + c
+--R   (1)  \|b %e        + a
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 600
+r0:=-2*atanh(sqrt(a+%e^(c+d*x)*b)/sqrt(a))*sqrt(a)/d+2*sqrt(a+%e^(c+d*x)*b)/d
+--R 
+--R
+--R                      +---------------+
+--R                      |    d x + c           +---------------+
+--R            +-+      \|b %e        + a       |    d x + c
+--R        - 2\|a atanh(------------------) + 2\|b %e        + a
+--R                             +-+
+--R                            \|a
+--R   (2)  ------------------------------------------------------
+--R                                   d
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 531
+
+)clear all
+
+--S 532 of 600
+t0:=sqrt(-a+%e^(c+d*x)*b)
+--R 
+--R
+--R         +---------------+
+--R         |    d x + c
+--R   (1)  \|b %e        - a
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 600
+r0:=-2*atan(sqrt(-a+%e^(c+d*x)*b)/sqrt(a))*sqrt(a)/d+2*sqrt(-a+%e^(c+d*x)*b)/d
+--R 
+--R
+--R                     +---------------+
+--R                     |    d x + c           +---------------+
+--R            +-+     \|b %e        - a       |    d x + c
+--R        - 2\|a atan(------------------) + 2\|b %e        - a
+--R                            +-+
+--R                           \|a
+--R   (2)  -----------------------------------------------------
+--R                                  d
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 534
+
+)clear all
+
+--S 535 of 600
+t0:=f^(a+b*x)*x^(3/2)
+--R 
+--R
+--R           b x + a +-+
+--R   (1)  x f       \|x
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 600
+--r0:=f^(a+b*x)*x^(3/2)/(b*log(f))+3/4*f^a*erfi(sqrt(b)*sqrt(x)*_
+--  sqrt(log(f)))*sqrt(%pi)/(b^(5/2)*log(f)^(5/2))-3/2*f^(a+b*x)*_
+--  sqrt(x)/(b^2*log(f)^2)
+--E 536
+
+--S 537 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 537
+
+)clear all
+
+--S 538 of 600
+t0:=f^(a+b*x)*x^(1/2)
+--R 
+--R
+--R         b x + a +-+
+--R   (1)  f       \|x
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 600
+--r0:=-1/2*f^a*erfi(sqrt(b)*sqrt(x)*sqrt(log(f)))*sqrt(%pi)/(b^(3/2)*_
+--  log(f)^(3/2))+f^(a+b*x)*sqrt(x)/(b*log(f))
+--E 539
+
+--S 540 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 540
+
+)clear all
+
+--S 541 of 600
+t0:=f^(a+b*x)/x^(1/2)
+--R 
+--R
+--R         b x + a
+--R        f
+--R   (1)  --------
+--R           +-+
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 600
+--r0:=f^a*erfi(sqrt(b)*sqrt(x)*sqrt(log(f)))*sqrt(%pi)/(sqrt(b)*sqrt(log(f)))
+--E 542
+
+--S 543 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 543
+
+)clear all
+
+--S 544 of 600
+t0:=f^(a+b*x)/x^(3/2)
+--R 
+--R
+--R         b x + a
+--R        f
+--R   (1)  --------
+--R            +-+
+--R          x\|x
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 600
+--r0:=-2*f^(a+b*x)/sqrt(x)+2*f^a*erfi(sqrt(b)*sqrt(x)*sqrt(log(f)))*_
+--  sqrt(%pi)*sqrt(b)*sqrt(log(f))
+--E 545
+
+--S 546 of 600
+--d0:=normalize(t0-D(r0,x))
+--E 546
+
+)clear all
+
+--S 547 of 600
+t0:=1/((-5)/%e^(m*x)+2*%e^(m*x))
+--R 
+--R
+--R              m x
+--R            %e
+--R   (1)  -------------
+--R            m x 2
+--R        2(%e   )  - 5
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 600
+r0:=-atanh(%e^(m*x)*sqrt(2/5))/(m*sqrt(10))
+--R 
+--R
+--R                 +-+  m x
+--R                \|2 %e
+--R          atanh(---------)
+--R                    +-+
+--R                   \|5
+--R   (2)  - ----------------
+--R                 +--+
+--R               m\|10
+--R                                                    Type: Expression(Integer)
+--E 548
+
+--S 549 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R            +-+ +-+ +--+        m x
+--R        (- \|2 \|5 \|10  + 10)%e
+--R   (3)  ---------------------------
+--R                   m x 2
+--R              20(%e   )  - 50
+--R                                                    Type: Expression(Integer)
+--E 549
+
+)clear all
+
+--S 550 of 600
+t0:=%e^(6*x)*sin(3*x)
+--R 
+--R
+--R          6x
+--R   (1)  %e  sin(3x)
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 600
+r0:=-1/15*%e^(6*x)*cos(3*x)+2/15*%e^(6*x)*sin(3*x)
+--R 
+--R
+--R           6x                   6x
+--R        2%e  sin(3x) - cos(3x)%e
+--R   (2)  --------------------------
+--R                    15
+--R                                                    Type: Expression(Integer)
+--E 551
+
+--S 552 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 552
+
+)clear all
+
+--S 553 of 600
+t0:=%e^(3*x)/(1+%e^(2*x))
+--R 
+--R
+--R            3x
+--R          %e
+--R   (1)  --------
+--R          2x
+--R        %e   + 1
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 600
+r0:=%e^x-atan(%e^x)
+--R 
+--R
+--R                 x      x
+--R   (2)  - atan(%e ) + %e
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 600
+t0:=%e^(3*x)/(-1+%e^(2*x))
+--R 
+--R
+--R            3x
+--R          %e
+--R   (1)  --------
+--R          2x
+--R        %e   - 1
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 600
+r0:=%e^x-atanh(%e^x)
+--R 
+--R
+--R                  x      x
+--R   (2)  - atanh(%e ) + %e
+--R                                                    Type: Expression(Integer)
+--E 557
+
+--S 558 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 558
+
+)clear all
+
+--S 559 of 600
+t0:=1/(%e^x*sqrt(1+%e^(2*x)))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R            +--------+
+--R          x |  2x
+--R        %e \|%e   + 1
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 600
+r0:=-sqrt(1+%e^(2*x))/%e^x
+--R 
+--R
+--R           +--------+
+--R           |  2x
+--R          \|%e   + 1
+--R   (2)  - -----------
+--R                x
+--R              %e
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 600
+t0:=%e^x/(-1-8*%e^x+%e^(2*x))
+--R 
+--R
+--R                x
+--R              %e
+--R   (1)  ---------------
+--R          2x      x
+--R        %e   - 8%e  - 1
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 600
+r0:=atanh((4-%e^x)/sqrt(17))/sqrt(17)
+--R 
+--R
+--R                  x
+--R                %e  - 4
+--R          atanh(-------)
+--R                  +--+
+--R                 \|17
+--R   (2)  - --------------
+--R                +--+
+--R               \|17
+--R                                                    Type: Expression(Integer)
+--E 563
+
+--S 564 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 564
+
+)clear all
+
+--S 565 of 600
+t0:=%e^(7*x)*x^3
+--R 
+--R
+--R         3  7x
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 600
+r0:=-6/2401*%e^(7*x)+6/343*%e^(7*x)*x-3/49*%e^(7*x)*x^2+1/7*%e^(7*x)*x^3
+--R 
+--R
+--R             3       2             7x
+--R        (343x  - 147x  + 42x - 6)%e
+--R   (2)  -----------------------------
+--R                     2401
+--R                                                    Type: Expression(Integer)
+--E 566
+
+--S 567 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 567
+
+)clear all
+
+--S 568 of 600
+t0:=%e^(8-2*x)*x^3
+--R 
+--R
+--R         3  - 2x + 8
+--R   (1)  x %e
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 600
+r0:=-3/8*%e^(8-2*x)-3/4*%e^(8-2*x)*x-3/4*%e^(8-2*x)*x^2-1/2*%e^(8-2*x)*x^3
+--R 
+--R
+--R             3     2            - 2x + 8
+--R        (- 4x  - 6x  - 6x - 3)%e
+--R   (2)  --------------------------------
+--R                        8
+--R                                                    Type: Expression(Integer)
+--E 569
+
+--S 570 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 570
+
+)clear all
+
+--S 571 of 600
+t0:=%e^x*sqrt(9-%e^(2*x))
+--R 
+--R
+--R            +----------+
+--R          x |    2x
+--R   (1)  %e \|- %e   + 9
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 600
+r0:=9/2*asin(1/3*%e^x)+1/2*%e^x*sqrt(9-%e^(2*x))
+--R 
+--R
+--R            +----------+           x
+--R          x |    2x              %e
+--R        %e \|- %e   + 9  + 9asin(---)
+--R                                  3
+--R   (2)  -----------------------------
+--R                      2
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+)clear all
+
+--S 574 of 600
+t0:=%e^(6*x)*sqrt(9-%e^(2*x))
+--R 
+--R
+--R             +----------+
+--R          6x |    2x
+--R   (1)  %e  \|- %e   + 9
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 600
+r0:=-27*(9-%e^(2*x))^(3/2)+18/5*(9-%e^(2*x))^(5/2)-1/7*(9-%e^(2*x))^(7/2)
+--R 
+--R
+--R                                               +----------+
+--R             2x 3       2x 2        2x         |    2x
+--R        (5(%e  )  - 9(%e  )  - 108%e   - 1944)\|- %e   + 9
+--R   (2)  ---------------------------------------------------
+--R                                 35
+--R                                                    Type: Expression(Integer)
+--E 575
+
+--S 576 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 576
+
+)clear all
+
+--S 577 of 600
+t0:=%e^(6*x)/(9-%e^x)^(5/2)
+--R 
+--R
+--R                         6x
+--R                       %e
+--R   (1)  ---------------------------------
+--R                              +---------+
+--R            x 2       x       |    x
+--R        ((%e )  - 18%e  + 81)\|- %e  + 9
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 600
+r0:=39366/(9-%e^x)^(3/2)+540*(9-%e^x)^(3/2)-18*(9-%e^x)^(5/2)+_
+   2/7*(9-%e^x)^(7/2)+(-65610)/sqrt(9-%e^x)-14580*sqrt(9-%e^x)
+--R 
+--R
+--R            x 5        x 4         x 3           x 2            x
+--R        2(%e )  + 36(%e )  + 864(%e )  + 46656(%e )  - 1679616%e  + 10077696
+--R   (2)  --------------------------------------------------------------------
+--R                                           +---------+
+--R                                   x       |    x
+--R                               (7%e  - 63)\|- %e  + 9
+--R                                                    Type: Expression(Integer)
+--E 578
+
+--S 579 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 579
+
+)clear all
+
+--S 580 of 600
+t0:=(2-7*%e^(x^4))^5*x^3
+--R 
+--R
+--R   (1)
+--R                  4 5              4 4              4 3             4 2
+--R             3   x            3   x            3   x           3   x
+--R     - 16807x (%e  )  + 24010x (%e  )  - 13720x (%e  )  + 3920x (%e  )
+--R   + 
+--R               4
+--R           3  x       3
+--R     - 560x %e   + 32x
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 600
+r0:=-140*%e^(x^4)+490*%e^(2*x^4)-3430/3*%e^(3*x^4)+12005/8*%e^(4*x^4)-_
+   16807/20*%e^(5*x^4)+8*x^4
+--R 
+--R
+--R   (2)
+--R               4             4             4            4           4
+--R             5x            4x            3x           2x           x        4
+--R   - 100842%e    + 180075%e    - 137200%e    + 58800%e    - 16800%e   + 960x
+--R   --------------------------------------------------------------------------
+--R                                       120
+--R                                                    Type: Expression(Integer)
+--E 581
+
+--S 582 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 582
+
+)clear all
+
+--S 583 of 600
+t0:=%e^(x^2)*x*sqrt(1-%e^(2*x^2))
+--R 
+--R
+--R               +-----------+
+--R             2 |      2
+--R            x  |    2x
+--R   (1)  x %e  \|- %e    + 1
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 600
+r0:=1/4*asin(%e^(x^2))+1/4*%e^(x^2)*sqrt(1-%e^(2*x^2))
+--R 
+--R
+--R             +-----------+
+--R           2 |      2                2
+--R          x  |    2x                x
+--R        %e  \|- %e    + 1  + asin(%e  )
+--R   (2)  -------------------------------
+--R                       4
+--R                                                    Type: Expression(Integer)
+--E 584
+
+--S 585 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 585
+
+)clear all
+
+--S 586 of 600
+t0:=%e^(x^3)*(1-%e^(4*x^3))^2*x^2
+--R 
+--R
+--R             3     3 2         3    3        3
+--R         2  x    4x        2  x   4x     2  x
+--R   (1)  x %e  (%e   )  - 2x %e  %e    + x %e
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 600
+r0:=1/3*%e^(x^3)-2/15*%e^(5*x^3)+1/27*%e^(9*x^3)
+--R 
+--R
+--R             3         3        3
+--R           9x        5x        x
+--R        5%e    - 18%e    + 45%e
+--R   (2)  -------------------------
+--R                   135
+--R                                                    Type: Expression(Integer)
+--E 587
+
+--S 588 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 588
+
+)clear all
+
+--S 589 of 600
+t0:=%e^(%e^x+x)
+--R 
+--R
+--R            x
+--R          %e  + x
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 600
+r0:=%e^(%e^x)
+--R 
+--R
+--R            x
+--R          %e
+--R   (2)  %e
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 600
+d0:=t0-D(r0,x)
+--R 
+--R
+--R            x              x
+--R          %e  + x     x  %e
+--R   (3)  %e        - %e %e
+--R                                                    Type: Expression(Integer)
+--E 591
+
+)clear all
+
+--S 592 of 600
+t0:=%e^(%e^(%e^x)+%e^x+x)
+--R 
+--R
+--R              x
+--R            %e      x
+--R          %e    + %e  + x
+--R   (1)  %e
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 600
+r0:=%e^(%e^(%e^x))
+--R 
+--R
+--R              x
+--R            %e
+--R          %e
+--R   (2)  %e
+--R                                                    Type: Expression(Integer)
+--E 593
+
+--S 594 of 600
+d0:=t0-D(r0,x)
+--R 
+--R
+--R              x                           x
+--R            %e      x              x    %e
+--R          %e    + %e  + x     x  %e   %e
+--R   (3)  %e                - %e %e   %e
+--R                                                    Type: Expression(Integer)
+--E 594
+
+)clear all
+
+--S 595 of 600
+t0:=(1/%e^x+%e^x)^2
+--R 
+--R
+--R           x 4       x 2
+--R        (%e )  + 2(%e )  + 1
+--R   (1)  --------------------
+--R                  x 2
+--R               (%e )
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 600
+r0:=(-1/2)/%e^(2*x)+1/2*%e^(2*x)+2*x
+--R 
+--R
+--R           2x 2        2x
+--R        (%e  )  + 4x %e   - 1
+--R   (2)  ---------------------
+--R                   2x
+--R                2%e
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 597
+
+)clear all
+
+--S 598 of 600
+t0:=1/(1/%e^x+%e^x)
+--R 
+--R
+--R              x
+--R            %e
+--R   (1)  ----------
+--R           x 2
+--R        (%e )  + 1
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 600
+r0:=atan(%e^x)
+--R 
+--R
+--R               x
+--R   (2)  atan(%e )
+--R                                                    Type: Expression(Integer)
+--E 599
+
+--S 600 of 600
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 600
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder8b.input.pamphlet b/src/input/richder8b.input.pamphlet
new file mode 100644
index 0000000..1977367
--- /dev/null
+++ b/src/input/richder8b.input.pamphlet
@@ -0,0 +1,8803 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder8b.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a x^q+b x^n)^p|
+
+All derivatives match.
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder8b.output
+)spool richder8b.output
+)set message test on
+)set message auto off
+)clear all
+
+
+--S 1 of 762
+t0:=1/(x^3*(a*x+b*x^3))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           6      4
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1
+
+--S 2 of 762
+r0:=(-1/3)/(a*x^3)+b/(a^2*x)+b^(3/2)*atan(x*sqrt(b)/sqrt(a))/a^(5/2)
+--R 
+--R
+--R                        +-+
+--R            3 +-+     x\|b          2      +-+
+--R        3b x \|b atan(-----) + (3b x  - a)\|a
+--R                        +-+
+--R                       \|a
+--R   (2)  --------------------------------------
+--R                         2 3 +-+
+--R                       3a x \|a
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 762
+t0:=1/(x^4*(a*x+b*x^3))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           7      5
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 4
+
+--S 5 of 762
+r0:=(-1/4)/(a*x^4)+1/2*b/(a^2*x^2)+b^2*log(x)/a^3-1/2*b^2*log(a+b*x^2)/a^3
+--R 
+--R
+--R            2 4       2          2 4               2    2
+--R        - 2b x log(b x  + a) + 4b x log(x) + 2a b x  - a
+--R   (2)  -------------------------------------------------
+--R                                3 4
+--R                              4a x
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 762
+t0:=x^2/(a*x+b*x^3)^2
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 7
+
+--S 8 of 762
+r0:=1/2*x/(a*(a+b*x^2))+1/2*atan(x*sqrt(b)/sqrt(a))/(a^(3/2)*sqrt(b))
+--R 
+--R
+--R                         +-+
+--R            2          x\|b       +-+ +-+
+--R        (b x  + a)atan(-----) + x\|a \|b
+--R                         +-+
+--R                        \|a
+--R   (2)  ---------------------------------
+--R                    2     2  +-+ +-+
+--R             (2a b x  + 2a )\|a \|b
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 762
+t0:=x/(a*x+b*x^3)^2
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         2 5         3    2
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 10
+
+--S 11 of 762
+r0:=1/2/(a*(a+b*x^2))+log(x)/a^2-1/2*log(a+b*x^2)/a^2
+--R 
+--R
+--R              2            2             2
+--R        (- b x  - a)log(b x  + a) + (2b x  + 2a)log(x) + a
+--R   (2)  --------------------------------------------------
+--R                             2   2     3
+--R                           2a b x  + 2a
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 762
+t0:=1/(a*x+b*x^3)^2
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 6         4    2 2
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 13
+
+--S 14 of 762
+r0:=(-3/2)/(a^2*x)+1/2/(a*x*(a+b*x^2))-3/2*atan(x*sqrt(b)/sqrt(a))*_
+     sqrt(b)/a^(5/2)
+--R 
+--R
+--R                                   +-+
+--R               3         +-+     x\|b            2       +-+
+--R        (- 3b x  - 3a x)\|b atan(-----) + (- 3b x  - 2a)\|a
+--R                                   +-+
+--R                                  \|a
+--R   (2)  ----------------------------------------------------
+--R                           2   3     3   +-+
+--R                        (2a b x  + 2a x)\|a
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 762
+t0:=1/(x*(a*x+b*x^3)^2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 7         5    2 3
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 16
+
+--S 17 of 762
+r0:=(-1)/(a^2*x^2)+1/2/(a*x^2*(a+b*x^2))-2*b*log(x)/a^3+b*log(a+b*x^2)/a^3
+--R 
+--R
+--R   (2)
+--R      2 4         2        2             2 4         2                2    2
+--R   (2b x  + 2a b x )log(b x  + a) + (- 4b x  - 4a b x )log(x) - 2a b x  - a
+--R   -------------------------------------------------------------------------
+--R                                  3   4     4 2
+--R                                2a b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 762
+t0:=1/(x^2*(a*x+b*x^3)^2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 8         6    2 4
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 19
+
+--S 20 of 762
+r0:=(-5/6)/(a^2*x^3)+5/2*b/(a^3*x)+1/2/(a*x^3*(a+b*x^2))+_
+     5/2*b^(3/2)*atan(x*sqrt(b)/sqrt(a))/a^(7/2)
+--R 
+--R
+--R                                      +-+
+--R            2 5          3  +-+     x\|b         2 4          2     2  +-+
+--R        (15b x  + 15a b x )\|b atan(-----) + (15b x  + 10a b x  - 2a )\|a
+--R                                      +-+
+--R                                     \|a
+--R   (2)  ------------------------------------------------------------------
+--R                                  3   5     4 3  +-+
+--R                               (6a b x  + 6a x )\|a
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 762
+t0:=x^5/(x-x^3)
+--R 
+--R
+--R             4
+--R            x
+--R   (1)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 22
+
+--S 23 of 762
+r0:=-x-1/3*x^3+atanh(x)
+--R 
+--R
+--R                     3
+--R        3atanh(x) - x  - 3x
+--R   (2)  -------------------
+--R                 3
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 762
+t0:=x^4/(x-x^3)
+--R 
+--R
+--R             3
+--R            x
+--R   (1)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 25
+
+--S 26 of 762
+r0:=-1/2*x^2-1/2*log(1-x^2)
+--R 
+--R
+--R                 2         2
+--R        - log(- x  + 1) - x
+--R   (2)  --------------------
+--R                  2
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 762
+t0:=x^3/(x-x^3)
+--R 
+--R
+--R             2
+--R            x
+--R   (1)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 28
+
+--S 29 of 762
+r0:=-x+atanh(x)
+--R 
+--R
+--R   (2)  atanh(x) - x
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 762
+t0:=x^2/(x-x^3)
+--R 
+--R
+--R             x
+--R   (1)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 31
+
+--S 32 of 762
+r0:=-1/2*log(1-x^2)
+--R 
+--R
+--R                 2
+--R          log(- x  + 1)
+--R   (2)  - -------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 762
+t0:=x/(x-x^3)
+--R 
+--R
+--R             1
+--R   (1)  - ------
+--R           2
+--R          x  - 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 34
+
+--S 35 of 762
+r0:=atanh(x)
+--R 
+--R
+--R   (2)  atanh(x)
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 762
+t0:=1/(x-x^3)
+--R 
+--R
+--R             1
+--R   (1)  - ------
+--R           3
+--R          x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 37
+
+--S 38 of 762
+r0:=-atanh(1-2*x^2)
+--R 
+--R
+--R                2
+--R   (2)  atanh(2x  - 1)
+--R                                                    Type: Expression(Integer)
+--E 38
+
+--S 39 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 39
+
+)clear all
+
+--S 40 of 762
+t0:=1/(x*(x-x^3))
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R           4    2
+--R          x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 40
+
+--S 41 of 762
+r0:=(-1)/x+atanh(x)
+--R 
+--R
+--R        x atanh(x) - 1
+--R   (2)  --------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 762
+t0:=1/(x^2*(x-x^3))
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R           5    3
+--R          x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 43
+
+--S 44 of 762
+r0:=(-1/2)/x^2-atanh(1-2*x^2)
+--R 
+--R
+--R          2        2
+--R        2x atanh(2x  - 1) - 1
+--R   (2)  ---------------------
+--R                   2
+--R                 2x
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 762
+t0:=1/(x^3*(x-x^3))
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R           6    4
+--R          x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 46
+
+--S 47 of 762
+r0:=(-1/3)/x^3+(-1)/x+atanh(x)
+--R 
+--R
+--R          3             2
+--R        3x atanh(x) - 3x  - 1
+--R   (2)  ---------------------
+--R                   3
+--R                 3x
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 762
+t0:=1/(x^4*(x-x^3))
+--R 
+--R
+--R             1
+--R   (1)  - -------
+--R           7    5
+--R          x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 49
+
+--S 50 of 762
+r0:=(-1/4)/x^4+(-1/2)/x^2-atanh(1-2*x^2)
+--R 
+--R
+--R          4        2          2
+--R        4x atanh(2x  - 1) - 2x  - 1
+--R   (2)  ---------------------------
+--R                      4
+--R                    4x
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 762
+t0:=1/(x+b*x^3)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R           3
+--R        b x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 52
+
+--S 53 of 762
+r0:=-atanh(1+2*b*x^2)
+--R 
+--R
+--R                    2
+--R   (2)  - atanh(2b x  + 1)
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 762
+t0:=1/(-x+b*x^3)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R           3
+--R        b x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 55
+
+--S 56 of 762
+r0:=atanh(1-2*b*x^2)
+--R 
+--R
+--R                    2
+--R   (2)  - atanh(2b x  - 1)
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 762
+t0:=x^3*sqrt(a*x+b*x^3)
+--R 
+--R
+--R           +----------+
+--R         3 |   3
+--R   (1)  x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 762
+--r0:=20/231*a^(13/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(9/4)*sqrt(a*x+b*x^3))-_
+--     20/231*a^2*sqrt(a*x+b*x^3)/b^2+4/77*a*x^2*_
+--     sqrt(a*x+b*x^3)/b+2/11*x^4*sqrt(a*x+b*x^3)
+--E 59
+
+--S 60 of 762
+--d0:=t0-D(r0,x)
+--E 60
+
+)clear all
+
+--S 61 of 762
+t0:=x^2*sqrt(a*x+b*x^3)
+--R 
+--R
+--R           +----------+
+--R         2 |   3
+--R   (1)  x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 762
+--r0:=4/15*a^(11/4)*elliptic_e(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(7/4)*sqrt(a*x+b*x^3))-_
+--     4/15*a^(11/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(7/4)*sqrt(a*x+b*x^3))+_
+--     4/45*a*x*sqrt(a*x+b*x^3)/b+2/9*x^3*sqrt(a*x+b*x^3)
+--E 62
+
+--S 63 of 762
+--d0:=t0-D(r0,x)
+--E 63
+
+)clear all
+
+--S 64 of 762
+t0:=x*sqrt(a*x+b*x^3)
+--R 
+--R
+--R          +----------+
+--R          |   3
+--R   (1)  x\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 762
+--r0:=4/21*a^(9/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(5/4)*sqrt(a*x+b*x^3))+_
+--     4/21*a*sqrt(a*x+b*x^3)/b+2/7*x^2*sqrt(a*x+b*x^3)
+--E 65
+
+--S 66 of 762
+--d0:=t0-D(r0,x)
+--E 66
+
+)clear all
+
+--S 67 of 762
+t0:=sqrt(a*x+b*x^3)
+--R 
+--R
+--R         +----------+
+--R         |   3
+--R   (1)  \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 762
+--r0:=4/5*a^(7/4)*elliptic_e(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(3/4)*sqrt(a*x+b*x^3))-_
+--     4/5*a^(7/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(3/4)*sqrt(a*x+b*x^3))+_
+--     2/5*x*sqrt(a*x+b*x^3)
+--E 68
+
+--S 69 of 762
+--d0:=t0-D(r0,x)
+--E 69
+
+)clear all
+
+--S 70 of 762
+t0:=sqrt(a*x+b*x^3)/x
+--R 
+--R
+--R         +----------+
+--R         |   3
+--R        \|b x  + a x
+--R   (1)  -------------
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 762
+--r0:=4/3*a^(5/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(1/4)*sqrt(a*x+b*x^3))+_
+--     2/3*sqrt(a*x+b*x^3)
+--E 71
+
+--S 72 of 762
+--d0:=t0-D(r0,x)
+--E 72
+
+)clear all
+
+--S 73 of 762
+t0:=sqrt(a*x+b*x^3)/x^2
+--R 
+--R
+--R         +----------+
+--R         |   3
+--R        \|b x  + a x
+--R   (1)  -------------
+--R               2
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 762
+--r0:=-4*a^(3/4)*(-b)^(1/4)*elliptic_e(asin((-b)^(1/4)*sqrt(x)/_
+--     a^(1/4)),-1)*sqrt(x)*sqrt((a+b*x^2)/a)/sqrt(a*x+b*x^3)+_
+--     4*a^(3/4)*(-b)^(1/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/sqrt(a*x+b*x^3)-2*sqrt(a*x+b*x^3)/x
+--E 74
+
+--S 75 of 762
+--d0:=t0-D(r0,x)
+--E 75
+
+)clear all
+
+--S 76 of 762
+t0:=x^2*(a*x+b*x^3)^(3/2)
+--R 
+--R
+--R                      +----------+
+--R            5      3  |   3
+--R   (1)  (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 762
+--r0:=2/15*x^3*(a*x+b*x^3)^(3/2)+8/231*a^(17/4)*_
+--     elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*sqrt(x)*_
+--     sqrt((a+b*x^2)/a)/((-b)^(9/4)*sqrt(a*x+b*x^3))-8/231*a^3*_
+--     sqrt(a*x+b*x^3)/b^2+8/385*a^2*x^2*sqrt(a*x+b*x^3)/b+_
+--     4/55*a*x^4*sqrt(a*x+b*x^3)
+--E 77
+
+--S 78 of 762
+--d0:=t0-D(r0,x)
+--E 78
+
+)clear all
+
+--S 79 of 762
+t0:=x*(a*x+b*x^3)^(3/2)
+--R 
+--R
+--R                      +----------+
+--R            4      2  |   3
+--R   (1)  (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 762
+--r0:=2/13*x^2*(a*x+b*x^3)^(3/2)+8/65*a^(15/4)*_
+--     elliptic_e(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*sqrt(x)*_
+--     sqrt((a+b*x^2)/a)/((-b)^(7/4)*sqrt(a*x+b*x^3))-8/65*a^(15/4)*_
+--     elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*sqrt(x)*_
+--     sqrt((a+b*x^2)/a)/((-b)^(7/4)*sqrt(a*x+b*x^3))+8/195*a^2*x*_
+--     sqrt(a*x+b*x^3)/b+4/39*a*x^3*sqrt(a*x+b*x^3)
+--E 80
+
+--S 81 of 762
+--d0:=t0-D(r0,x)
+--E 81
+
+)clear all
+
+--S 82 of 762
+t0:=(a*x+b*x^3)^(3/2)
+--R 
+--R
+--R                     +----------+
+--R            3        |   3
+--R   (1)  (b x  + a x)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 762
+--r0:=2/11*x*(a*x+b*x^3)^(3/2)+8/77*a^(13/4)*elliptic_f(asin((-b)^(1/4)*_
+--     sqrt(x)/a^(1/4)),-1)*sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(5/4)*_
+--     sqrt(a*x+b*x^3))+8/77*a^2*sqrt(a*x+b*x^3)/b+12/77*a*x^2*sqrt(a*x+b*x^3)
+--E 83
+
+--S 84 of 762
+--d0:=t0-D(r0,x)
+--E 84
+
+)clear all
+
+--S 85 of 762
+t0:=(a*x+b*x^3)^(3/2)/x
+--R 
+--R
+--R                   +----------+
+--R            2      |   3
+--R   (1)  (b x  + a)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 762
+--r0:=2/9*(a*x+b*x^3)^(3/2)+8/15*a^(11/4)*elliptic_e(asin((-b)^(1/4)*_
+--     sqrt(x)/a^(1/4)),-1)*sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(3/4)*_
+--     sqrt(a*x+b*x^3))-8/15*a^(11/4)*elliptic_f(asin((-b)^(1/4)*_
+--     sqrt(x)/a^(1/4)),-1)*sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(3/4)*_
+--     sqrt(a*x+b*x^3))+4/15*a*x*sqrt(a*x+b*x^3)
+--E 86
+
+--S 87 of 762
+--d0:=t0-D(r0,x)
+--E 87
+
+)clear all
+
+--S 88 of 762
+t0:=(a*x+b*x^3)^(3/2)/x^2
+--R 
+--R
+--R                   +----------+
+--R            2      |   3
+--R        (b x  + a)\|b x  + a x
+--R   (1)  -----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 762
+--r0:=2/7*(a*x+b*x^3)^(3/2)/x+8/7*a^(9/4)*elliptic_f(asin((-b)^(1/4)*_
+--     sqrt(x)/a^(1/4)),-1)*sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(1/4)*_
+--     sqrt(a*x+b*x^3))+4/7*a*sqrt(a*x+b*x^3)
+--E 89
+
+--S 90 of 762
+--d0:=t0-D(r0,x)
+--E 90
+
+)clear all
+
+--S 91 of 762
+t0:=x^4/sqrt(a*x+b*x^3)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  -------------
+--R         +----------+
+--R         |   3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 762
+--r0:=10/21*a^(9/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(9/4)*sqrt(a*x+b*x^3))-10/21*a*_
+--     sqrt(a*x+b*x^3)/b^2+2/7*x^2*sqrt(a*x+b*x^3)/b
+--E 92
+
+--S 93 of 762
+--d0:=t0-D(r0,x)
+--E 93
+
+)clear all
+
+--S 94 of 762
+t0:=x^3/sqrt(a*x+b*x^3)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  -------------
+--R         +----------+
+--R         |   3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 762
+--r0:=6/5*a^(7/4)*elliptic_e(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(7/4)*sqrt(a*x+b*x^3))-_
+--     6/5*a^(7/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(7/4)*sqrt(a*x+b*x^3))+_
+--     2/5*x*sqrt(a*x+b*x^3)/b
+--E 95
+
+--S 96 of 762
+--d0:=t0-D(r0,x)
+--E 96
+
+)clear all
+
+--S 97 of 762
+t0:=x^2/sqrt(a*x+b*x^3)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  -------------
+--R         +----------+
+--R         |   3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 762
+--r0:=2/3*a^(5/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(5/4)*sqrt(a*x+b*x^3))+_
+--     2/3*sqrt(a*x+b*x^3)/b
+--E 98
+
+--S 99 of 762
+--d0:=t0-D(r0,x)
+--E 99
+
+)clear all
+
+--S 100 of 762
+t0:=x/sqrt(a*x+b*x^3)
+--R 
+--R
+--R              x
+--R   (1)  -------------
+--R         +----------+
+--R         |   3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 762
+--r0:=2*a^(3/4)*elliptic_e(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(3/4)*sqrt(a*x+b*x^3))-_
+--     2*a^(3/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(3/4)*sqrt(a*x+b*x^3))
+--E 101
+
+--S 102 of 762
+--d0:=t0-D(r0,x)
+--E 102
+
+)clear all
+
+--S 103 of 762
+t0:=1/sqrt(a*x+b*x^3)
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         +----------+
+--R         |   3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 762
+--r0:=2*a^(1/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/((-b)^(1/4)*sqrt(a*x+b*x^3))
+--E 104
+
+--S 105 of 762
+--d0:=t0-D(r0,x)
+--E 105
+
+)clear all
+
+--S 106 of 762
+t0:=1/(x*sqrt(a*x+b*x^3))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R          +----------+
+--R          |   3
+--R        x\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 762
+--r0:=-2*(-b)^(1/4)*elliptic_e(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/(a^(1/4)*sqrt(a*x+b*x^3))+2*(-b)^(1/4)*_
+--     elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*sqrt(x)*_
+--     sqrt((a+b*x^2)/a)/(a^(1/4)*sqrt(a*x+b*x^3))-2*sqrt(a*x+b*x^3)/(a*x)
+--E 107
+
+--S 108 of 762
+--d0:=t0-D(r0,x)
+--E 108
+
+)clear all
+
+--S 109 of 762
+t0:=1/(x^2*sqrt(a*x+b*x^3))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           +----------+
+--R         2 |   3
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 762
+--r0:=2/3*(-b)^(3/4)*elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/(a^(3/4)*sqrt(a*x+b*x^3))-_
+--     2/3*sqrt(a*x+b*x^3)/(a*x^2)
+--E 110
+
+--S 111 of 762
+--d0:=t0-D(r0,x)
+--E 111
+
+)clear all
+
+--S 112 of 762
+t0:=1/(x^3*sqrt(a*x+b*x^3))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           +----------+
+--R         3 |   3
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 762
+--r0:=-6/5*(-b)^(5/4)*elliptic_e(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/(a^(5/4)*sqrt(a*x+b*x^3))+6/5*(-b)^(5/4)*_
+--     elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*sqrt(x)*_
+--     sqrt((a+b*x^2)/a)/(a^(5/4)*sqrt(a*x+b*x^3))-2/5*_
+--     sqrt(a*x+b*x^3)/(a*x^3)+6/5*b*sqrt(a*x+b*x^3)/(a^2*x)
+--E 113
+
+--S 114 of 762
+--d0:=t0-D(r0,x)
+--E 114
+
+)clear all
+
+--S 115 of 762
+t0:=x^2/(a*x+b*x^3)^(3/2)
+--R 
+--R
+--R                   x
+--R   (1)  -----------------------
+--R                   +----------+
+--R            2      |   3
+--R        (b x  + a)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 762
+--r0:=x^2/(a*sqrt(a*x+b*x^3))-elliptic_e(asin((-b)^(1/4)*sqrt(x)/_
+--     a^(1/4)),-1)*sqrt(x)*sqrt((a+b*x^2)/a)/(a^(1/4)*(-b)^(3/4)*_
+--     sqrt(a*x+b*x^3))+elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*_
+--     sqrt(x)*sqrt((a+b*x^2)/a)/(a^(1/4)*(-b)^(3/4)*sqrt(a*x+b*x^3))
+--E 116
+
+--S 117 of 762
+--d0:=t0-D(r0,x)
+--E 117
+
+)clear all
+
+--S 118 of 762
+t0:=x/(a*x+b*x^3)^(3/2)
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R                   +----------+
+--R            2      |   3
+--R        (b x  + a)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 762
+--r0:=x/(a*sqrt(a*x+b*x^3))+elliptic_f(asin((-b)^(1/4)*sqrt(x)/_
+--     a^(1/4)),-1)*sqrt(x)*sqrt((a+b*x^2)/a)/(a^(3/4)*(-b)^(1/4)*_
+--     sqrt(a*x+b*x^3))
+--E 119
+
+--S 120 of 762
+--d0:=t0-D(r0,x)
+--E 120
+
+)clear all
+
+--S 121 of 762
+t0:=1/(a*x+b*x^3)^(3/2)
+--R 
+--R
+--R                    1
+--R   (1)  -------------------------
+--R                     +----------+
+--R            3        |   3
+--R        (b x  + a x)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 762
+--r0:=1/(a*sqrt(a*x+b*x^3))-3*(-b)^(1/4)*elliptic_e(asin((-b)^(1/4)*_
+--     sqrt(x)/a^(1/4)),-1)*sqrt(x)*sqrt((a+b*x^2)/a)/(a^(5/4)*_
+--     sqrt(a*x+b*x^3))+3*(-b)^(1/4)*elliptic_f(asin((-b)^(1/4)*_
+--     sqrt(x)/a^(1/4)),-1)*sqrt(x)*sqrt((a+b*x^2)/a)/(a^(5/4)*_
+--     sqrt(a*x+b*x^3))-3*sqrt(a*x+b*x^3)/(a^2*x)
+--E 122
+
+--S 123 of 762
+--d0:=t0-D(r0,x)
+--E 123
+
+)clear all
+
+--S 124 of 762
+t0:=1/(x*(a*x+b*x^3)^(3/2))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                      +----------+
+--R            4      2  |   3
+--R        (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 762
+--r0:=1/(a*x*sqrt(a*x+b*x^3))+5/3*(-b)^(3/4)*elliptic_f(asin((-b)^(1/4)*_
+--     sqrt(x)/a^(1/4)),-1)*sqrt(x)*sqrt((a+b*x^2)/a)/(a^(7/4)*_
+--     sqrt(a*x+b*x^3))-5/3*sqrt(a*x+b*x^3)/(a^2*x^2)
+--E 125
+
+--S 126 of 762
+--d0:=t0-D(r0,x)
+--E 126
+
+)clear all
+
+--S 127 of 762
+t0:=1/(x^2*(a*x+b*x^3)^(3/2))
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                      +----------+
+--R            5      3  |   3
+--R        (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 762
+--r0:=1/(a*x^2*sqrt(a*x+b*x^3))-21/5*(-b)^(5/4)*_
+--     elliptic_e(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*sqrt(x)*_
+--     sqrt((a+b*x^2)/a)/(a^(9/4)*sqrt(a*x+b*x^3))+21/5*(-b)^(5/4)*_
+--     elliptic_f(asin((-b)^(1/4)*sqrt(x)/a^(1/4)),-1)*sqrt(x)*_
+--     sqrt((a+b*x^2)/a)/(a^(9/4)*sqrt(a*x+b*x^3))-_
+--     7/5*sqrt(a*x+b*x^3)/(a^2*x^3)+21/5*b*sqrt(a*x+b*x^3)/(a^3*x)
+--E 128
+
+--S 129 of 762
+--d0:=t0-D(r0,x)
+--E 129
+
+)clear all
+
+--S 130 of 762
+t0:=x^(29/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                 10 +-+
+--R                                x  \|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 762
+r0:=-1/7*x^(25/2)/(b*(a*x+b*x^3)^(7/2))-9/35*x^(19/2)/(b^2*(a*x+_
+     b*x^3)^(5/2))-3/5*x^(13/2)/(b^3*(a*x+b*x^3)^(3/2))-_
+     9/2*a*atanh(x^(3/2)*sqrt(b)/sqrt(a*x+b*x^3))/b^(11/2)-_
+     3*x^(7/2)/(b^4*sqrt(a*x+b*x^3))+9/2*sqrt(x)*sqrt(a*x+b*x^3)/b^5
+--R 
+--R
+--R   (2)
+--R                                                       +----------+
+--R                  3 6       2 2 4       3   2       4  |   3
+--R         (- 315a b x  - 945a b x  - 945a b x  - 315a )\|b x  + a x
+--R      *
+--R                   +-+ +-+
+--R                 x\|b \|x
+--R         atanh(-------------)
+--R                +----------+
+--R                |   3
+--R               \|b x  + a x
+--R     + 
+--R           4 9         3 7        2 2 5        3   3       4   +-+ +-+
+--R       (35b x  + 528a b x  + 1218a b x  + 1050a b x  + 315a x)\|b \|x
+--R  /
+--R                                                   +----------+
+--R         8 6         7 4       2 6 2      3 5  +-+ |   3
+--R     (70b x  + 210a b x  + 210a b x  + 70a b )\|b \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 762
+t0:=x^(27/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                 9 +-+
+--R                                x \|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 762
+r0:=-1/7*x^(23/2)/(b*(a*x+b*x^3)^(7/2))-8/35*x^(17/2)/(b^2*(a*x+_
+     b*x^3)^(5/2))-16/35*x^(11/2)/(b^3*(a*x+b*x^3)^(3/2))-_
+     64/35*x^(5/2)/(b^4*sqrt(a*x+b*x^3))+128/35*sqrt(a*x+b*x^3)/(b^5*sqrt(x))
+--R 
+--R
+--R               4 9         3 7       2 2 5       3   3       4
+--R            35b x  + 280a b x  + 560a b x  + 448a b x  + 128a x
+--R   (2)  ----------------------------------------------------------
+--R                                                      +----------+
+--R            8 6         7 4       2 6 2      3 5  +-+ |   3
+--R        (35b x  + 105a b x  + 105a b x  + 35a b )\|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 762
+t0:=x^(25/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                 8 +-+
+--R                                x \|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 762
+r0:=-1/7*x^(21/2)/(b*(a*x+b*x^3)^(7/2))-1/5*x^(15/2)/(b^2*(a*x+_
+     b*x^3)^(5/2))-1/3*x^(9/2)/(b^3*(a*x+b*x^3)^(3/2))+atanh(x^(3/2)*_
+     sqrt(b)/sqrt(a*x+b*x^3))/b^(9/2)-x^(3/2)/(b^4*sqrt(a*x+b*x^3))
+--R 
+--R
+--R   (2)
+--R                                                   +----------+
+--R              3 6         2 4       2   2       3  |   3
+--R         (105b x  + 315a b x  + 315a b x  + 105a )\|b x  + a x
+--R      *
+--R                   +-+ +-+
+--R                 x\|b \|x
+--R         atanh(-------------)
+--R                +----------+
+--R                |   3
+--R               \|b x  + a x
+--R     + 
+--R              3 7         2 5       2   3       3   +-+ +-+
+--R       (- 176b x  - 406a b x  - 350a b x  - 105a x)\|b \|x
+--R  /
+--R                                                     +----------+
+--R          7 6         6 4       2 5 2       3 4  +-+ |   3
+--R     (105b x  + 315a b x  + 315a b x  + 105a b )\|b \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 762
+t0:=x^(23/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                 7 +-+
+--R                                x \|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 762
+r0:=-1/7*x^(19/2)/(b*(a*x+b*x^3)^(7/2))-6/35*x^(13/2)/(b^2*(a*x+_
+     b*x^3)^(5/2))-8/35*x^(7/2)/(b^3*(a*x+b*x^3)^(3/2))-_
+     16/35*sqrt(x)/(b^4*sqrt(a*x+b*x^3))
+--R 
+--R
+--R                    3 6        2 4      2   2      3  +-+
+--R              (- 35b x  - 70a b x  - 56a b x  - 16a )\|x
+--R   (2)  ------------------------------------------------------
+--R                                                  +----------+
+--R            7 6         6 4       2 5 2      3 4  |   3
+--R        (35b x  + 105a b x  + 105a b x  + 35a b )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 762
+t0:=x^(21/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                 6 +-+
+--R                                x \|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 762
+r0:=1/7*x^(21/2)/(a*(a*x+b*x^3)^(7/2))
+--R 
+--R
+--R                               7 +-+
+--R                              x \|x
+--R   (2)  --------------------------------------------------
+--R                                              +----------+
+--R             3 6      2 2 4      3   2     4  |   3
+--R        (7a b x  + 21a b x  + 21a b x  + 7a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 762
+t0:=x^(19/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                 5 +-+
+--R                                x \|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 762
+r0:=-1/7*x^(15/2)/(b*(a*x+b*x^3)^(7/2))-4/35*x^(9/2)/(b^2*(a*x+_
+     b*x^3)^(5/2))-8/105*x^(3/2)/(b^3*(a*x+b*x^3)^(3/2))
+--R 
+--R
+--R                           2 4          2     2  +-+
+--R                     (- 35b x  - 28a b x  - 8a )\|x
+--R   (2)  --------------------------------------------------------
+--R                                                    +----------+
+--R             6 6         5 4       2 4 2       3 3  |   3
+--R        (105b x  + 315a b x  + 315a b x  + 105a b )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 762
+t0:=x^(17/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                 4 +-+
+--R                                x \|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 762
+r0:=1/7*x^(17/2)/(a*(a*x+b*x^3)^(7/2))+2/35*x^(15/2)/(a^2*(a*x+b*x^3)^(5/2))
+--R 
+--R
+--R                               7       5  +-+
+--R                          (2b x  + 7a x )\|x
+--R   (2)  ------------------------------------------------------
+--R                                                  +----------+
+--R            2 3 6       3 2 4       4   2      5  |   3
+--R        (35a b x  + 105a b x  + 105a b x  + 35a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 762
+t0:=x^(15/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                 3 +-+
+--R                                x \|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 762
+r0:=-1/7*x^(11/2)/(b*(a*x+b*x^3)^(7/2))-2/35*x^(5/2)/(b^2*(a*x+b*x^3)^(5/2))
+--R 
+--R
+--R                                 2       +-+
+--R                          (- 7b x  - 2a)\|x
+--R   (2)  ------------------------------------------------------
+--R                                                  +----------+
+--R            5 6         4 4       2 3 2      3 2  |   3
+--R        (35b x  + 105a b x  + 105a b x  + 35a b )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 762
+t0:=x^(13/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                 2 +-+
+--R                                x \|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 762
+r0:=1/7*x^(13/2)/(a*(a*x+b*x^3)^(7/2))+4/35*x^(11/2)/(a^2*(a*x+_
+     b*x^3)^(5/2))+8/105*x^(9/2)/(a^3*(a*x+b*x^3)^(3/2))
+--R 
+--R
+--R                        2 7          5      2 3  +-+
+--R                     (8b x  + 28a b x  + 35a x )\|x
+--R   (2)  --------------------------------------------------------
+--R                                                    +----------+
+--R             3 3 6       4 2 4       5   2       6  |   3
+--R        (105a b x  + 315a b x  + 315a b x  + 105a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 762
+t0:=x^(11/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                   +-+
+--R                                 x\|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 762
+r0:=-1/7*x^(7/2)/(b*(a*x+b*x^3)^(7/2))
+--R 
+--R
+--R                                  +-+
+--R                                 \|x
+--R   (2)  - -------------------------------------------------
+--R                                               +----------+
+--R             4 6        3 4      2 2 2     3   |   3
+--R          (7b x  + 21a b x  + 21a b x  + 7a b)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 762
+t0:=x^(9/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                  +-+
+--R                                 \|x
+--R   (1)  ------------------------------------------------------
+--R                                                  +----------+
+--R          4 8       3 6     2 2 4     3   2    4  |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 762
+r0:=1/7*x^(9/2)/(a*(a*x+b*x^3)^(7/2))+6/35*x^(7/2)/(a^2*(a*x+_
+     b*x^3)^(5/2))+8/35*x^(5/2)/(a^3*(a*x+b*x^3)^(3/2))+_
+     16/35*x^(3/2)/(a^4*sqrt(a*x+b*x^3))
+--R 
+--R
+--R                  3 7        2 5      2   3      3   +-+
+--R              (16b x  + 56a b x  + 70a b x  + 35a x)\|x
+--R   (2)  ------------------------------------------------------
+--R                                                  +----------+
+--R            4 3 6       5 2 4       6   2      7  |   3
+--R        (35a b x  + 105a b x  + 105a b x  + 35a )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 762
+t0:=x^(7/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                   +-+
+--R                                  \|x
+--R   (1)  -------------------------------------------------------
+--R                                                   +----------+
+--R          4 9       3 7     2 2 5     3   3    4   |   3
+--R        (b x  + 4a b x  + 6a b x  + 4a b x  + a x)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 762
+r0:=1/7*x^(7/2)/(a*(a*x+b*x^3)^(7/2))+1/5*x^(5/2)/(a^2*(a*x+_
+     b*x^3)^(5/2))+1/3*x^(3/2)/(a^3*(a*x+b*x^3)^(3/2))-_
+     atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*x^3))/a^(9/2)+_
+     sqrt(x)/(a^4*sqrt(a*x+b*x^3))
+--R 
+--R
+--R   (2)
+--R                                                     +----------+
+--R                3 6         2 4       2   2       3  |   3
+--R         (- 105b x  - 315a b x  - 315a b x  - 105a )\|b x  + a x
+--R      *
+--R                   +-+ +-+
+--R                  \|a \|x
+--R         atanh(-------------)
+--R                +----------+
+--R                |   3
+--R               \|b x  + a x
+--R     + 
+--R            3 6         2 4       2   2       3  +-+ +-+
+--R       (105b x  + 350a b x  + 406a b x  + 176a )\|a \|x
+--R  /
+--R                                                     +----------+
+--R          4 3 6       5 2 4       6   2       7  +-+ |   3
+--R     (105a b x  + 315a b x  + 315a b x  + 105a )\|a \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 762
+t0:=x^(5/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                    +-+
+--R                                   \|x
+--R   (1)  ---------------------------------------------------------
+--R                                                     +----------+
+--R          4 10       3 8     2 2 6     3   4    4 2  |   3
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 762
+r0:=1/7*x^(5/2)/(a*(a*x+b*x^3)^(7/2))+8/35*x^(3/2)/(a^2*(a*x+_
+     b*x^3)^(5/2))+16/35*sqrt(x)/(a^3*(a*x+b*x^3)^(3/2))+_
+     64/35/(a^4*sqrt(x)*sqrt(a*x+b*x^3))-128/35*sqrt(a*x+b*x^3)/(a^5*x^(3/2))
+--R 
+--R
+--R                 4 8         3 6       2 2 4       3   2      4
+--R           - 128b x  - 448a b x  - 560a b x  - 280a b x  - 35a
+--R   (2)  ----------------------------------------------------------
+--R                                                      +----------+
+--R            5 3 6       6 2 4       7   2      8  +-+ |   3
+--R        (35a b x  + 105a b x  + 105a b x  + 35a )\|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 762
+t0:=x^(3/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                    +-+
+--R                                   \|x
+--R   (1)  ---------------------------------------------------------
+--R                                                     +----------+
+--R          4 11       3 9     2 2 7     3   5    4 3  |   3
+--R        (b x   + 4a b x  + 6a b x  + 4a b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 762
+r0:=1/7*x^(3/2)/(a*(a*x+b*x^3)^(7/2))+9/2*b*atanh(sqrt(a)*_
+     sqrt(x)/sqrt(a*x+b*x^3))/a^(11/2)+3/5/(a^3*(a*x+_
+     b*x^3)^(3/2)*sqrt(x))+9/35*sqrt(x)/(a^2*(a*x+_
+     b*x^3)^(5/2))+3/(a^4*x^(3/2)*sqrt(a*x+b*x^3))-_
+     9/2*sqrt(a*x+b*x^3)/(a^5*x^(5/2))
+--R 
+--R
+--R   (2)
+--R                                                          +----------+
+--R              4 7         3 5       2 2 3       3     +-+ |   3
+--R         (315b x  + 945a b x  + 945a b x  + 315a b x)\|x \|b x  + a x
+--R      *
+--R                   +-+ +-+
+--R                  \|a \|x
+--R         atanh(-------------)
+--R                +----------+
+--R                |   3
+--R               \|b x  + a x
+--R     + 
+--R              4 8          3 6        2 2 4       3   2      4  +-+
+--R       (- 315b x  - 1050a b x  - 1218a b x  - 528a b x  - 35a )\|a
+--R  /
+--R                                                        +----------+
+--R         5 3 7       6 2 5       7   3      8   +-+ +-+ |   3
+--R     (70a b x  + 210a b x  + 210a b x  + 70a x)\|a \|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 762
+t0:=x^(1/2)/(a*x+b*x^3)^(9/2)
+--R 
+--R
+--R                                    +-+
+--R                                   \|x
+--R   (1)  ----------------------------------------------------------
+--R                                                      +----------+
+--R          4 12       3 10     2 2 8     3   6    4 4  |   3
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 762
+r0:=16/21/(a^3*x^(3/2)*(a*x+b*x^3)^(3/2))+2/7/(a^2*(a*x+b*x^3)^(5/2)*_
+     sqrt(x))+1/7*sqrt(x)/(a*(a*x+b*x^3)^(7/2))+32/7/(a^4*x^(5/2)*_
+     sqrt(a*x+b*x^3))-128/21*sqrt(a*x+b*x^3)/(a^5*x^(7/2))+_
+     256/21*b*sqrt(a*x+b*x^3)/(a^6*x^(3/2))
+--R 
+--R
+--R            5 10         4 8        2 3 6       3 2 4      4   2     5
+--R        256b x   + 896a b x  + 1120a b x  + 560a b x  + 70a b x  - 7a
+--R   (2)  --------------------------------------------------------------
+--R                                                        +----------+
+--R              6 3 8      7 2 6      8   4      9 2  +-+ |   3
+--R          (21a b x  + 63a b x  + 63a b x  + 21a x )\|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 762
+t0:=1/(x^(1/2)*(a*x+b*x^3)^(9/2))
+--R 
+--R
+--R                                       1
+--R   (1)  --------------------------------------------------------------
+--R                                                          +----------+
+--R          4 12       3 10     2 2 8     3   6    4 4  +-+ |   3
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 762
+r0:=11/35/(a^2*x^(3/2)*(a*x+b*x^3)^(5/2))+33/35/(a^3*x^(5/2)*_
+     (a*x+b*x^3)^(3/2))-99/8*b^2*atanh(sqrt(a)*sqrt(x)/_
+     sqrt(a*x+b*x^3))/a^(13/2)+1/7/(a*(a*x+b*x^3)^(7/2)*sqrt(x))+_
+     33/5/(a^4*x^(7/2)*sqrt(a*x+b*x^3))-33/4*sqrt(a*x+b*x^3)/_
+     (a^5*x^(9/2))+99/8*b*sqrt(a*x+b*x^3)/(a^6*x^(5/2))
+--R 
+--R
+--R   (2)
+--R                                                                   +----------+
+--R                 5 9           4 7         2 3 5        3 2 3  +-+ |   3
+--R         (- 3465b x  - 10395a b x  - 10395a b x  - 3465a b x )\|x \|b x  + a x
+--R      *
+--R                   +-+ +-+
+--R                  \|a \|x
+--R         atanh(-------------)
+--R                +----------+
+--R                |   3
+--R               \|b x  + a x
+--R     + 
+--R           5 10           4 8         2 3 6        3 2 4       4   2      5  +-+
+--R     (3465b x   + 11550a b x  + 13398a b x  + 5808a b x  + 385a b x  - 70a )\|a
+--R  /
+--R                                                           +----------+
+--R          6 3 9       7 2 7       8   5       9 3  +-+ +-+ |   3
+--R     (280a b x  + 840a b x  + 840a b x  + 280a x )\|a \|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 762
+t0:=1/(x^(3/2)*(a*x+b*x^3)^(9/2))
+--R 
+--R
+--R                                       1
+--R   (1)  --------------------------------------------------------------
+--R                                                          +----------+
+--R          4 13       3 11     2 2 9     3   7    4 5  +-+ |   3
+--R        (b x   + 4a b x   + 6a b x  + 4a b x  + a x )\|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 762
+r0:=1/7/(a*x^(3/2)*(a*x+b*x^3)^(7/2))+12/35/(a^2*x^(5/2)*(a*x+_
+     b*x^3)^(5/2))+8/7/(a^3*x^(7/2)*(a*x+b*x^3)^(3/2))+64/7/_
+     (a^4*x^(9/2)*sqrt(a*x+b*x^3))-384/35*sqrt(a*x+b*x^3)/_
+     (a^5*x^(11/2))+512/35*b*sqrt(a*x+b*x^3)/(a^6*x^(7/2))-_
+     1024/35*b^2*sqrt(a*x+b*x^3)/(a^7*x^(3/2))
+--R 
+--R
+--R   (2)
+--R              6 12          5 10        2 4 8        3 3 6       4 2 4
+--R       - 1024b x   - 3584a b x   - 4480a b x  - 2240a b x  - 280a b x
+--R     + 
+--R          5   2     6
+--R       28a b x  - 7a
+--R  /
+--R                                                       +----------+
+--R         7 3 10       8 2 8       9   6      10 4  +-+ |   3
+--R     (35a b x   + 105a b x  + 105a b x  + 35a  x )\|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 762
+t0:=x^4/sqrt(a*x+b*x^4)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  -------------
+--R         +----------+
+--R         |   4
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 762
+r0:=-1/3*a*atanh(x^2*sqrt(b)/sqrt(a*x+b*x^4))/b^(3/2)+1/3*x*sqrt(a*x+b*x^4)/b
+--R 
+--R
+--R                       2 +-+             +----------+
+--R                      x \|b          +-+ |   4
+--R        - a atanh(-------------) + x\|b \|b x  + a x
+--R                   +----------+
+--R                   |   4
+--R                  \|b x  + a x
+--R   (2)  ---------------------------------------------
+--R                               +-+
+--R                            3b\|b
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 762
+t0:=x^3/sqrt(a*x+b*x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  -------------
+--R         +----------+
+--R         |   4
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 762
+--r0:=1/2*sqrt(a*x+b*x^4)/b-1/4*a^(2/3)*x*(a^(1/3)+b^(1/3)*x)*_
+--     elliptic_f(acos((a^(1/3)+b^(1/3)*x*(1-sqrt(3)))/(a^(1/3)+_
+--     b^(1/3)*x*(1+sqrt(3)))),1/4*(2+sqrt(3)))*sqrt((a^(2/3)-_
+--     a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(1/3)+b^(1/3)*x*(1+sqrt(3)))^2)/_
+--     (3^(1/4)*b*sqrt(a*x+b*x^4)*sqrt(b^(1/3)*x*(a^(1/3)+b^(1/3)*x)/_
+--     (a^(1/3)+b^(1/3)*x*(1+sqrt(3)))^2))
+--E 185
+
+--S 186 of 762
+--d0:=t0-D(r0,x)
+--E 186
+
+)clear all
+
+--S 187 of 762
+t0:=x^2/sqrt(a*x+b*x^4)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  -------------
+--R         +----------+
+--R         |   4
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 762
+--r0:=2/5*x^3*hypergeometric(1/2,5/6,11/6,-b*x^3/a)*_
+--     sqrt((a+b*x^3)/a)/sqrt(a*x+b*x^4)
+--E 188
+
+--S 189 of 762
+--d0:=t0-D(r0,x)
+--E 189
+
+)clear all
+
+--S 190 of 762
+t0:=x/sqrt(a*x+b*x^4)
+--R 
+--R
+--R              x
+--R   (1)  -------------
+--R         +----------+
+--R         |   4
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 762
+r0:=2/3*atanh(x^2*sqrt(b)/sqrt(a*x+b*x^4))/sqrt(b)
+--R 
+--R
+--R                    2 +-+
+--R                   x \|b
+--R        2atanh(-------------)
+--R                +----------+
+--R                |   4
+--R               \|b x  + a x
+--R   (2)  ---------------------
+--R                  +-+
+--R                3\|b
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 762
+t0:=1/sqrt(a*x+b*x^4)
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         +----------+
+--R         |   4
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 762
+--r0:=x*(a^(1/3)+b^(1/3)*x)*elliptic_f(acos((a^(1/3)+b^(1/3)*x*_
+--     (1-sqrt(3)))/(a^(1/3)+b^(1/3)*x*(1+sqrt(3)))),1/4*(2+sqrt(3)))*_
+--     sqrt((a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(1/3)+b^(1/3)*x*_
+--     (1+sqrt(3)))^2)/(3^(1/4)*a^(1/3)*sqrt(a*x+b*x^4)*sqrt(b^(1/3)*_
+--     x*(a^(1/3)+b^(1/3)*x)/(a^(1/3)+b^(1/3)*x*(1+sqrt(3)))^2))
+--E 194
+
+--S 195 of 762
+--d0:=t0-D(r0,x)
+--E 195
+
+)clear all
+
+--S 196 of 762
+t0:=1/(x*sqrt(a*x+b*x^4))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R          +----------+
+--R          |   4
+--R        x\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 762
+--r0:=4/5*b*x^3*hypergeometric(1/2,5/6,11/6,-b*x^3/a)*_
+--     sqrt((a+b*x^3)/a)/(a*sqrt(a*x+b*x^4))-2*sqrt(a*x+b*x^4)/(a*x)
+--E 197
+
+--S 198 of 762
+--d0:=t0-D(r0,x)
+--E 198
+
+)clear all
+
+--S 199 of 762
+t0:=1/(x^2*sqrt(a*x+b*x^4))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           +----------+
+--R         2 |   4
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 762
+r0:=-2/3*sqrt(a*x+b*x^4)/(a*x^2)
+--R 
+--R
+--R            +----------+
+--R            |   4
+--R          2\|b x  + a x
+--R   (2)  - --------------
+--R                   2
+--R               3a x
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 762
+t0:=1/(x^3*sqrt(a*x+b*x^4))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           +----------+
+--R         3 |   4
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 762
+--r0:=-2/5*sqrt(a*x+b*x^4)/(a*x^3)-2/5*b*x*(a^(1/3)+b^(1/3)*x)*_
+--     elliptic_f(acos((a^(1/3)+b^(1/3)*x*(1-sqrt(3)))/(a^(1/3)+b^(1/3)*_
+--     x*(1+sqrt(3)))),1/4*(2+sqrt(3)))*sqrt((a^(2/3)-a^(1/3)*b^(1/3)*x+_
+--     b^(2/3)*x^2)/(a^(1/3)+b^(1/3)*x*(1+sqrt(3)))^2)/(3^(1/4)*a^(4/3)*_
+--     sqrt(a*x+b*x^4)*sqrt(b^(1/3)*x*(a^(1/3)+b^(1/3)*x)/(a^(1/3)+_
+--     b^(1/3)*x*(1+sqrt(3)))^2))
+--E 203
+
+--S 204 of 762
+--d0:=t0-D(r0,x)
+--E 204
+
+)clear all
+
+--S 205 of 762
+t0:=1/(x^4*sqrt(a*x+b*x^4))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           +----------+
+--R         4 |   4
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 762
+--r0:=-16/35*b^2*x^3*hypergeometric(1/2,5/6,11/6,-b*x^3/a)*_
+--     sqrt((a+b*x^3)/a)/(a^2*sqrt(a*x+b*x^4))-2/7*sqrt(a*x+b*x^4)/_
+--     (a*x^4)+8/7*b*sqrt(a*x+b*x^4)/(a^2*x)
+--E 206
+
+--S 207 of 762
+--d0:=t0-D(r0,x)
+--E 207
+
+)clear all
+
+--S 208 of 762
+t0:=1/(x^5*sqrt(a*x+b*x^4))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           +----------+
+--R         5 |   4
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 762
+r0:=-2/9*sqrt(a*x+b*x^4)/(a*x^5)+4/9*b*sqrt(a*x+b*x^4)/(a^2*x^2)
+--R 
+--R
+--R                     +----------+
+--R             3       |   4
+--R        (4b x  - 2a)\|b x  + a x
+--R   (2)  -------------------------
+--R                    2 5
+--R                  9a x
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 762
+t0:=x^2/(b*x^(1/2)+a*x)^(1/2)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |  +-+
+--R        \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 762
+r0:=-63/64*b^5*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(11/2)+_
+     63/64*b^4*sqrt(a*x+b*sqrt(x))/a^5+21/40*b^2*x*sqrt(a*x+b*sqrt(x))/a^3-_
+     9/20*b*x^(3/2)*sqrt(a*x+b*sqrt(x))/a^2+2/5*x^2*sqrt(a*x+b*sqrt(x))/a-_
+     21/32*b^3*sqrt(x)*sqrt(a*x+b*sqrt(x))/a^4
+--R 
+--R
+--R   (2)
+--R                        +-+ +-+
+--R             5         \|a \|x
+--R       - 315b atanh(--------------)
+--R                     +-----------+
+--R                     |  +-+
+--R                    \|b\|x  + a x
+--R     + 
+--R                 3            3  +-+ +-+        4 2       2 2        4  +-+
+--R         ((- 144a b x - 210a b )\|a \|x  + (128a x  + 168a b x + 315b )\|a )
+--R      *
+--R          +-----------+
+--R          |  +-+
+--R         \|b\|x  + a x
+--R  /
+--R         5 +-+
+--R     320a \|a
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 762
+t0:=x/(b*x^(1/2)+a*x)^(1/2)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R         +-----------+
+--R         |  +-+
+--R        \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 762
+r0:=-5/4*b^3*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(7/2)+_
+     5/4*b^2*sqrt(a*x+b*sqrt(x))/a^3+2/3*x*sqrt(a*x+b*sqrt(x))/a-_
+     5/6*b*sqrt(x)*sqrt(a*x+b*sqrt(x))/a^2
+--R 
+--R
+--R   (2)
+--R                       +-+ +-+
+--R            3         \|a \|x
+--R       - 15b atanh(--------------)
+--R                    +-----------+
+--R                    |  +-+
+--R                   \|b\|x  + a x
+--R     + 
+--R                                             +-----------+
+--R                +-+ +-+      2       2  +-+  |  +-+
+--R       (- 10a b\|a \|x  + (8a x + 15b )\|a )\|b\|x  + a x
+--R  /
+--R        3 +-+
+--R     12a \|a
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 762
+t0:=1/(b*x^(1/2)+a*x)^(1/2)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |  +-+
+--R        \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 762
+r0:=-2*b*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(3/2)+_
+     2*sqrt(a*x+b*sqrt(x))/a
+--R 
+--R
+--R                       +-+ +-+             +-----------+
+--R                      \|a \|x          +-+ |  +-+
+--R        - 2b atanh(--------------) + 2\|a \|b\|x  + a x
+--R                    +-----------+
+--R                    |  +-+
+--R                   \|b\|x  + a x
+--R   (2)  ------------------------------------------------
+--R                                +-+
+--R                              a\|a
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 762
+t0:=1/(x*(b*x^(1/2)+a*x)^(1/2))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          +-----------+
+--R          |  +-+
+--R        x\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 762
+r0:=-4*sqrt(a*x+b*sqrt(x))/(b*sqrt(x))
+--R 
+--R
+--R            +-----------+
+--R            |  +-+
+--R          4\|b\|x  + a x
+--R   (2)  - ---------------
+--R                 +-+
+--R               b\|x
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 762
+t0:=1/(x^2*(b*x^(1/2)+a*x)^(1/2))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         2 |  +-+
+--R        x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 762
+r0:=-4/5*sqrt(a*x+b*sqrt(x))/(b*x^(3/2))+16/15*a*sqrt(a*x+b*sqrt(x))/_
+     (b^2*x)-32/15*a^2*sqrt(a*x+b*sqrt(x))/(b^3*sqrt(x))
+--R 
+--R
+--R                                   +-----------+
+--R               +-+      2       2  |  +-+
+--R        (16a b\|x  - 32a x - 12b )\|b\|x  + a x
+--R   (2)  ----------------------------------------
+--R                           3  +-+
+--R                        15b x\|x
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 762
+t0:=1/(x^3*(b*x^(1/2)+a*x)^(1/2))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         3 |  +-+
+--R        x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 762
+r0:=-4/9*sqrt(a*x+b*sqrt(x))/(b*x^(5/2))+32/63*a*sqrt(a*x+b*sqrt(x))/_
+     (b^2*x^2)-64/105*a^2*sqrt(a*x+b*sqrt(x))/(b^3*x^(3/2))+_
+     256/315*a^3*sqrt(a*x+b*sqrt(x))/(b^4*x)-_
+     512/315*a^4*sqrt(a*x+b*sqrt(x))/(b^5*sqrt(x))
+--R 
+--R
+--R                                                                +-----------+
+--R              3            3  +-+       4 2       2 2        4  |  +-+
+--R        ((256a b x + 160a b )\|x  - 512a x  - 192a b x - 140b )\|b\|x  + a x
+--R   (2)  ---------------------------------------------------------------------
+--R                                         5 2 +-+
+--R                                     315b x \|x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 762
+t0:=1/(x^4*(b*x^(1/2)+a*x)^(1/2))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         4 |  +-+
+--R        x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 762
+r0:=-4/13*sqrt(a*x+b*sqrt(x))/(b*x^(7/2))+48/143*a*sqrt(a*x+b*sqrt(x))/_
+     (b^2*x^3)-160/429*a^2*sqrt(a*x+b*sqrt(x))/(b^3*x^(5/2))+_
+     1280/3003*a^3*sqrt(a*x+b*sqrt(x))/(b^4*x^2)-_
+     512/1001*a^4*sqrt(a*x+b*sqrt(x))/(b^5*x^(3/2))+_
+     2048/3003*a^5*sqrt(a*x+b*sqrt(x))/(b^6*x)-_
+     4096/3003*a^6*sqrt(a*x+b*sqrt(x))/(b^7*sqrt(x))
+--R 
+--R
+--R   (2)
+--R               5   2        3 3           5  +-+        6 3        4 2 2
+--R         (2048a b x  + 1280a b x + 1008a b )\|x  - 4096a x  - 1536a b x
+--R       + 
+--R                2 4        6
+--R         - 1120a b x - 924b
+--R    *
+--R        +-----------+
+--R        |  +-+
+--R       \|b\|x  + a x
+--R  /
+--R          7 3 +-+
+--R     3003b x \|x
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 762
+t0:=x^3/(b*x^(1/2)+a*x)^(3/2)
+--R 
+--R
+--R                      3
+--R                     x
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R           +-+        |  +-+
+--R        (b\|x  + a x)\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 762
+r0:=-693/64*b^5*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(13/2)-_
+     4*x^3/(a*sqrt(a*x+b*sqrt(x)))+693/64*b^4*sqrt(a*x+b*sqrt(x))/_
+     a^6+231/40*b^2*x*sqrt(a*x+b*sqrt(x))/a^4-99/20*b*x^(3/2)*_
+     sqrt(a*x+b*sqrt(x))/a^3+22/5*x^2*sqrt(a*x+b*sqrt(x))/a^2-_
+     231/32*b^3*sqrt(x)*sqrt(a*x+b*sqrt(x))/a^5
+--R 
+--R
+--R   (2)
+--R                +-----------+          +-+ +-+
+--R              5 |  +-+                \|a \|x
+--R       - 3465b \|b\|x  + a x atanh(--------------)
+--R                                    +-----------+
+--R                                    |  +-+
+--R                                   \|b\|x  + a x
+--R     + 
+--R              4   2       2 3         5  +-+ +-+
+--R       (- 176a b x  - 462a b x + 3465b )\|a \|x
+--R     + 
+--R            5 3       3 2 2          4   +-+
+--R       (128a x  + 264a b x  + 1155a b x)\|a
+--R  /
+--R               +-----------+
+--R         6 +-+ |  +-+
+--R     320a \|a \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 762
+t0:=x^2/(b*x^(1/2)+a*x)^(3/2)
+--R 
+--R
+--R                      2
+--R                     x
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R           +-+        |  +-+
+--R        (b\|x  + a x)\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 762
+r0:=-35/4*b^3*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(9/2)-_
+     4*x^2/(a*sqrt(a*x+b*sqrt(x)))+35/4*b^2*sqrt(a*x+b*sqrt(x))/a^4+_
+     14/3*x*sqrt(a*x+b*sqrt(x))/a^2-35/6*b*sqrt(x)*sqrt(a*x+b*sqrt(x))/a^3
+--R 
+--R
+--R   (2)
+--R               +-----------+          +-+ +-+
+--R             3 |  +-+                \|a \|x              2          3  +-+ +-+
+--R       - 105b \|b\|x  + a x atanh(--------------) + (- 14a b x + 105b )\|a \|x
+--R                                   +-----------+
+--R                                   |  +-+
+--R                                  \|b\|x  + a x
+--R     + 
+--R          3 2        2   +-+
+--R       (8a x  + 35a b x)\|a
+--R  /
+--R              +-----------+
+--R        4 +-+ |  +-+
+--R     12a \|a \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 762
+t0:=x/(b*x^(1/2)+a*x)^(3/2)
+--R 
+--R
+--R                     x
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R           +-+        |  +-+
+--R        (b\|x  + a x)\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 762
+r0:=-6*b*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(5/2)-_
+     4*x/(a*sqrt(a*x+b*sqrt(x)))+6*sqrt(a*x+b*sqrt(x))/a^2
+--R 
+--R
+--R             +-----------+          +-+ +-+
+--R             |  +-+                \|a \|x           +-+ +-+        +-+
+--R        - 6b\|b\|x  + a x atanh(--------------) + 6b\|a \|x  + 2a x\|a
+--R                                 +-----------+
+--R                                 |  +-+
+--R                                \|b\|x  + a x
+--R   (2)  ---------------------------------------------------------------
+--R                                     +-----------+
+--R                               2 +-+ |  +-+
+--R                              a \|a \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 762
+t0:=1/(b*x^(1/2)+a*x)^(3/2)
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R           +-+        |  +-+
+--R        (b\|x  + a x)\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 762
+r0:=4*sqrt(x)/(b*sqrt(a*x+b*sqrt(x)))
+--R 
+--R
+--R               +-+
+--R             4\|x
+--R   (2)  ---------------
+--R          +-----------+
+--R          |  +-+
+--R        b\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 762
+t0:=1/(x*(b*x^(1/2)+a*x)^(3/2))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R                         +-----------+
+--R             +-+      2  |  +-+
+--R        (b x\|x  + a x )\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 762
+r0:=4/(b*sqrt(x)*sqrt(a*x+b*sqrt(x)))-16/3*sqrt(a*x+b*sqrt(x))/(b^2*x)+_
+     32/3*a*sqrt(a*x+b*sqrt(x))/(b^3*sqrt(x))
+--R 
+--R
+--R              +-+      2      2
+--R        16a b\|x  + 32a x - 4b
+--R   (2)  -----------------------
+--R                 +-----------+
+--R           3 +-+ |  +-+
+--R         3b \|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 762
+t0:=1/(x^2*(b*x^(1/2)+a*x)^(3/2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            2 +-+      3  |  +-+
+--R        (b x \|x  + a x )\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 762
+r0:=4/(b*x^(3/2)*sqrt(a*x+b*sqrt(x)))-32/7*sqrt(a*x+b*sqrt(x))/(b^2*x^2)+_
+     192/35*a*sqrt(a*x+b*sqrt(x))/(b^3*x^(3/2))-_
+     256/35*a^2*sqrt(a*x+b*sqrt(x))/(b^4*x)+_
+     512/35*a^3*sqrt(a*x+b*sqrt(x))/(b^5*sqrt(x))
+--R 
+--R
+--R             3           3  +-+       4 2      2 2       4
+--R        (256a b x + 32a b )\|x  + 512a x  - 64a b x - 20b
+--R   (2)  --------------------------------------------------
+--R                                +-----------+
+--R                         5  +-+ |  +-+
+--R                      35b x\|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 762
+t0:=1/(x^3*(b*x^(1/2)+a*x)^(3/2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            3 +-+      4  |  +-+
+--R        (b x \|x  + a x )\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 762
+r0:=4/(b*x^(5/2)*sqrt(a*x+b*sqrt(x)))-48/11*sqrt(a*x+b*sqrt(x))/(b^2*x^3)+_
+     160/33*a*sqrt(a*x+b*sqrt(x))/(b^3*x^(5/2))-_
+     1280/231*a^2*sqrt(a*x+b*sqrt(x))/(b^4*x^2)+_
+     512/77*a^3*sqrt(a*x+b*sqrt(x))/(b^5*x^(3/2))-_
+     2048/231*a^4*sqrt(a*x+b*sqrt(x))/(b^6*x)+_
+     4096/231*a^5*sqrt(a*x+b*sqrt(x))/(b^7*sqrt(x))
+--R 
+--R
+--R   (2)
+--R             5   2       3 3          5  +-+        6 3       4 2 2       2 4
+--R       (2048a b x  + 256a b x + 112a b )\|x  + 4096a x  - 512a b x  - 160a b x
+--R     + 
+--R            6
+--R       - 84b
+--R  /
+--R                 +-----------+
+--R         7 2 +-+ |  +-+
+--R     231b x \|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 762
+t0:=x^(5/2)/(b*x^(1/2)+a*x)^(1/2)
+--R 
+--R
+--R             2 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |  +-+
+--R        \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 762
+r0:=231/256*b^6*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(13/2)-_
+     231/256*b^5*sqrt(a*x+b*sqrt(x))/a^6-_
+     77/160*b^3*x*sqrt(a*x+b*sqrt(x))/a^4+_
+     33/80*b^2*x^(3/2)*sqrt(a*x+b*sqrt(x))/a^3-_
+     11/30*b*x^2*sqrt(a*x+b*sqrt(x))/a^2+_
+     1/3*x^(5/2)*sqrt(a*x+b*sqrt(x))/a+_
+     77/128*b^4*sqrt(x)*sqrt(a*x+b*sqrt(x))/a^5
+--R 
+--R
+--R   (2)
+--R                       +-+ +-+
+--R            6         \|a \|x
+--R       3465b atanh(--------------)
+--R                    +-----------+
+--R                    |  +-+
+--R                   \|b\|x  + a x
+--R     + 
+--R                 5 2        3 2           4  +-+ +-+
+--R           (1280a x  + 1584a b x + 2310a b )\|a \|x
+--R         + 
+--R                   4   2        2 3         5  +-+
+--R           (- 1408a b x  - 1848a b x - 3465b )\|a
+--R      *
+--R          +-----------+
+--R          |  +-+
+--R         \|b\|x  + a x
+--R  /
+--R          6 +-+
+--R     3840a \|a
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 762
+t0:=x^(3/2)/(b*x^(1/2)+a*x)^(1/2)
+--R 
+--R
+--R               +-+
+--R             x\|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |  +-+
+--R        \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 762
+r0:=35/32*b^4*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(9/2)-_
+     35/32*b^3*sqrt(a*x+b*sqrt(x))/a^4-7/12*b*x*sqrt(a*x+b*sqrt(x))/a^2+_
+     1/2*x^(3/2)*sqrt(a*x+b*sqrt(x))/a+_
+     35/48*b^2*sqrt(x)*sqrt(a*x+b*sqrt(x))/a^3
+--R 
+--R
+--R   (2)
+--R                      +-+ +-+
+--R           4         \|a \|x
+--R       105b atanh(--------------)
+--R                   +-----------+
+--R                   |  +-+
+--R                  \|b\|x  + a x
+--R     + 
+--R                                                            +-----------+
+--R            3         2  +-+ +-+         2          3  +-+  |  +-+
+--R       ((48a x + 70a b )\|a \|x  + (- 56a b x - 105b )\|a )\|b\|x  + a x
+--R  /
+--R        4 +-+
+--R     96a \|a
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 762
+t0:=x^(1/2)/(b*x^(1/2)+a*x)^(1/2)
+--R 
+--R
+--R              +-+
+--R             \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |  +-+
+--R        \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 762
+r0:=3/2*b^2*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(5/2)-_
+     3/2*b*sqrt(a*x+b*sqrt(x))/a^2+sqrt(x)*sqrt(a*x+b*sqrt(x))/a
+--R 
+--R
+--R                     +-+ +-+                             +-----------+
+--R          2         \|a \|x            +-+ +-+      +-+  |  +-+
+--R        3b atanh(--------------) + (2a\|a \|x  - 3b\|a )\|b\|x  + a x
+--R                  +-----------+
+--R                  |  +-+
+--R                 \|b\|x  + a x
+--R   (2)  --------------------------------------------------------------
+--R                                      2 +-+
+--R                                    2a \|a
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 762
+t0:=1/(x^(1/2)*(b*x^(1/2)+a*x)^(1/2))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R             +-----------+
+--R         +-+ |  +-+
+--R        \|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 762
+r0:=4*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/sqrt(a)
+--R 
+--R
+--R                   +-+ +-+
+--R                  \|a \|x
+--R        4atanh(--------------)
+--R                +-----------+
+--R                |  +-+
+--R               \|b\|x  + a x
+--R   (2)  ----------------------
+--R                  +-+
+--R                 \|a
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 762
+t0:=1/(x^(3/2)*(b*x^(1/2)+a*x)^(1/2))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R              +-----------+
+--R          +-+ |  +-+
+--R        x\|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 762
+r0:=-4/3*sqrt(a*x+b*sqrt(x))/(b*x)+8/3*a*sqrt(a*x+b*sqrt(x))/(b^2*sqrt(x))
+--R 
+--R
+--R                          +-----------+
+--R              +-+         |  +-+
+--R        (- 4b\|x  + 8a x)\|b\|x  + a x
+--R   (2)  -------------------------------
+--R                      2  +-+
+--R                    3b x\|x
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 762
+t0:=1/(x^(5/2)*(b*x^(1/2)+a*x)^(1/2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         2 +-+ |  +-+
+--R        x \|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 762
+r0:=-4/7*sqrt(a*x+b*sqrt(x))/(b*x^2)+24/35*a*sqrt(a*x+b*sqrt(x))/_
+     (b^2*x^(3/2))-32/35*a^2*sqrt(a*x+b*sqrt(x))/(b^3*x)+_
+     64/35*a^3*sqrt(a*x+b*sqrt(x))/(b^4*sqrt(x))
+--R 
+--R
+--R                                                    +-----------+
+--R               2         3  +-+      3 2        2   |  +-+
+--R        ((- 32a b x - 20b )\|x  + 64a x  + 24a b x)\|b\|x  + a x
+--R   (2)  ---------------------------------------------------------
+--R                                   4 2 +-+
+--R                                35b x \|x
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 762
+t0:=1/(x^(7/2)*(b*x^(1/2)+a*x)^(1/2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         3 +-+ |  +-+
+--R        x \|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 762
+r0:=-4/11*sqrt(a*x+b*sqrt(x))/(b*x^3)+40/99*a*sqrt(a*x+b*sqrt(x))/_
+     (b^2*x^(5/2))-320/693*a^2*sqrt(a*x+b*sqrt(x))/(b^3*x^2)+_
+     128/231*a^3*sqrt(a*x+b*sqrt(x))/(b^4*x^(3/2))-_
+     512/693*a^4*sqrt(a*x+b*sqrt(x))/(b^5*x)+_
+     1024/693*a^5*sqrt(a*x+b*sqrt(x))/(b^6*sqrt(x))
+--R 
+--R
+--R   (2)
+--R               4   2       2 3        5  +-+        5 3       3 2 2         4
+--R       ((- 512a b x  - 320a b x - 252b )\|x  + 1024a x  + 384a b x  + 280a b x)
+--R    *
+--R        +-----------+
+--R        |  +-+
+--R       \|b\|x  + a x
+--R  /
+--R         6 3 +-+
+--R     693b x \|x
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 762
+t0:=x^(5/2)/(b*x^(1/2)+a*x)^(3/2)
+--R 
+--R
+--R                    2 +-+
+--R                   x \|x
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R           +-+        |  +-+
+--R        (b\|x  + a x)\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 762
+r0:=315/32*b^4*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(11/2)-_
+     4*x^(5/2)/(a*sqrt(a*x+b*sqrt(x)))-315/32*b^3*sqrt(a*x+b*sqrt(x))/a^5-_
+     21/4*b*x*sqrt(a*x+b*sqrt(x))/a^3+9/2*x^(3/2)*sqrt(a*x+b*sqrt(x))/a^2+_
+     105/16*b^2*sqrt(x)*sqrt(a*x+b*sqrt(x))/a^4
+--R 
+--R
+--R   (2)
+--R             +-----------+          +-+ +-+
+--R           4 |  +-+                \|a \|x
+--R       315b \|b\|x  + a x atanh(--------------)
+--R                                 +-----------+
+--R                                 |  +-+
+--R                                \|b\|x  + a x
+--R     + 
+--R           4 2      2 2        4  +-+ +-+         3   2         3   +-+
+--R       (16a x  + 42a b x - 315b )\|a \|x  + (- 24a b x  - 105a b x)\|a
+--R  /
+--R              +-----------+
+--R        5 +-+ |  +-+
+--R     32a \|a \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 762
+t0:=x^(3/2)/(b*x^(1/2)+a*x)^(3/2)
+--R 
+--R
+--R                     +-+
+--R                   x\|x
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R           +-+        |  +-+
+--R        (b\|x  + a x)\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 762
+r0:=15/2*b^2*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(7/2)-_
+     4*x^(3/2)/(a*sqrt(a*x+b*sqrt(x)))-_
+     15/2*b*sqrt(a*x+b*sqrt(x))/a^3+5*sqrt(x)*sqrt(a*x+b*sqrt(x))/a^2
+--R 
+--R
+--R   (2)
+--R        +-----------+          +-+ +-+
+--R      2 |  +-+                \|a \|x           2       2  +-+ +-+          +-+
+--R   15b \|b\|x  + a x atanh(--------------) + (2a x - 15b )\|a \|x  - 5a b x\|a
+--R                            +-----------+
+--R                            |  +-+
+--R                           \|b\|x  + a x
+--R   ----------------------------------------------------------------------------
+--R                                       +-----------+
+--R                                 3 +-+ |  +-+
+--R                               2a \|a \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 762
+t0:=x^(1/2)/(b*x^(1/2)+a*x)^(3/2)
+--R 
+--R
+--R                     +-+
+--R                    \|x
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R           +-+        |  +-+
+--R        (b\|x  + a x)\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 762
+r0:=4*atanh(sqrt(a)*sqrt(x)/sqrt(a*x+b*sqrt(x)))/a^(3/2)-_
+     4*sqrt(x)/(a*sqrt(a*x+b*sqrt(x)))
+--R 
+--R
+--R          +-----------+          +-+ +-+
+--R          |  +-+                \|a \|x          +-+ +-+
+--R        4\|b\|x  + a x atanh(--------------) - 4\|a \|x
+--R                              +-----------+
+--R                              |  +-+
+--R                             \|b\|x  + a x
+--R   (2)  ------------------------------------------------
+--R                             +-----------+
+--R                         +-+ |  +-+
+--R                       a\|a \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 762
+t0:=1/(x^(1/2)*(b*x^(1/2)+a*x)^(3/2))
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R                        +-----------+
+--R             +-+        |  +-+
+--R        (a x\|x  + b x)\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 762
+r0:=4/(b*sqrt(a*x+b*sqrt(x)))-8*sqrt(a*x+b*sqrt(x))/(b^2*sqrt(x))
+--R 
+--R
+--R                +-+
+--R           - 4b\|x  - 8a x
+--R   (2)  --------------------
+--R               +-----------+
+--R         2 +-+ |  +-+
+--R        b \|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 762
+t0:=1/(x^(3/2)*(b*x^(1/2)+a*x)^(3/2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            2 +-+      2  |  +-+
+--R        (a x \|x  + b x )\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 762
+r0:=4/(b*x*sqrt(a*x+b*sqrt(x)))-24/5*sqrt(a*x+b*sqrt(x))/(b^2*x^(3/2))+_
+     32/5*a*sqrt(a*x+b*sqrt(x))/(b^3*x)-_
+     64/5*a^2*sqrt(a*x+b*sqrt(x))/(b^4*sqrt(x))
+--R 
+--R
+--R              2        3  +-+      3 2       2
+--R        (- 32a b x - 4b )\|x  - 64a x  + 8a b x
+--R   (2)  ---------------------------------------
+--R                          +-----------+
+--R                   4  +-+ |  +-+
+--R                 5b x\|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 762
+t0:=1/(x^(5/2)*(b*x^(1/2)+a*x)^(3/2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            3 +-+      3  |  +-+
+--R        (a x \|x  + b x )\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 762
+r0:=4/(b*x^2*sqrt(a*x+b*sqrt(x)))-40/9*sqrt(a*x+b*sqrt(x))/(b^2*x^(5/2))+_
+     320/63*a*sqrt(a*x+b*sqrt(x))/(b^3*x^2)-_
+     128/21*a^2*sqrt(a*x+b*sqrt(x))/(b^4*x^(3/2))+_
+     512/63*a^3*sqrt(a*x+b*sqrt(x))/(b^5*x)-_
+     1024/63*a^4*sqrt(a*x+b*sqrt(x))/(b^6*sqrt(x))
+--R 
+--R
+--R               4   2      2 3       5  +-+        5 3       3 2 2        4
+--R        (- 512a b x  - 64a b x - 28b )\|x  - 1024a x  + 128a b x  + 40a b x
+--R   (2)  -------------------------------------------------------------------
+--R                                         +-----------+
+--R                                 6 2 +-+ |  +-+
+--R                              63b x \|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 762
+t0:=1/(x^(7/2)*(b*x^(1/2)+a*x)^(3/2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            4 +-+      4  |  +-+
+--R        (a x \|x  + b x )\|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 762
+r0:=4/(b*x^3*sqrt(a*x+b*sqrt(x)))-_
+     56/13*sqrt(a*x+b*sqrt(x))/(b^2*x^(7/2))+_
+     672/143*a*sqrt(a*x+b*sqrt(x))/(b^3*x^3)-_
+     2240/429*a^2*sqrt(a*x+b*sqrt(x))/(b^4*x^(5/2))+_
+     2560/429*a^3*sqrt(a*x+b*sqrt(x))/(b^5*x^2)-_
+     1024/143*a^4*sqrt(a*x+b*sqrt(x))/(b^6*x^(3/2))+_
+     4096/429*a^5*sqrt(a*x+b*sqrt(x))/(b^7*x)-_
+     8192/429*a^6*sqrt(a*x+b*sqrt(x))/(b^8*sqrt(x))
+--R 
+--R
+--R   (2)
+--R               6   3       4 3 2       2 5        7  +-+        7 4        5 2 3
+--R       (- 4096a b x  - 512a b x  - 224a b x - 132b )\|x  - 8192a x  + 1024a b x
+--R     + 
+--R           3 4 2         6
+--R       320a b x  + 168a b x
+--R  /
+--R                 +-----------+
+--R         8 3 +-+ |  +-+
+--R     429b x \|x \|b\|x  + a x
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 762
+t0:=x^2*(a*x^2+b*x^3)
+--R 
+--R
+--R           5      4
+--R   (1)  b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 295
+
+--S 296 of 762
+r0:=1/5*a*x^5+1/6*b*x^6
+--R 
+--R
+--R        1    6   1    5
+--R   (2)  - b x  + - a x
+--R        6        5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 296
+
+--S 297 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 297
+
+)clear all
+
+--S 298 of 762
+t0:=x*(a*x^2+b*x^3)
+--R 
+--R
+--R           4      3
+--R   (1)  b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 298
+
+--S 299 of 762
+r0:=1/4*a*x^4+1/5*b*x^5
+--R 
+--R
+--R        1    5   1    4
+--R   (2)  - b x  + - a x
+--R        5        4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 299
+
+--S 300 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 300
+
+)clear all
+
+--S 301 of 762
+t0:=a*x^2+b*x^3
+--R 
+--R
+--R           3      2
+--R   (1)  b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 301
+
+--S 302 of 762
+r0:=1/3*a*x^3+1/4*b*x^4
+--R 
+--R
+--R        1    4   1    3
+--R   (2)  - b x  + - a x
+--R        4        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 302
+
+--S 303 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 303
+
+)clear all
+
+--S 304 of 762
+t0:=(a*x^2+b*x^3)/x
+--R 
+--R
+--R           2
+--R   (1)  b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 304
+
+--S 305 of 762
+r0:=1/2*a*x^2+1/3*b*x^3
+--R 
+--R
+--R        1    3   1    2
+--R   (2)  - b x  + - a x
+--R        3        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 305
+
+--S 306 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 306
+
+)clear all
+
+--S 307 of 762
+t0:=(a*x^2+b*x^3)/x^2
+--R 
+--R
+--R   (1)  b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 307
+
+--S 308 of 762
+r0:=a*x+1/2*b*x^2
+--R 
+--R
+--R        1    2
+--R   (2)  - b x  + a x
+--R        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 308
+
+--S 309 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 309
+
+)clear all
+
+--S 310 of 762
+t0:=x^2*(a*x^2+b*x^3)^2
+--R 
+--R
+--R         2 8         7    2 6
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 310
+
+--S 311 of 762
+r0:=1/7*a^2*x^7+1/4*a*b*x^8+1/9*b^2*x^9
+--R 
+--R
+--R        1  2 9   1      8   1  2 7
+--R   (2)  - b x  + - a b x  + - a x
+--R        9        4          7
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 311
+
+--S 312 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 312
+
+)clear all
+
+--S 313 of 762
+t0:=x*(a*x^2+b*x^3)^2
+--R 
+--R
+--R         2 7         6    2 5
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 313
+
+--S 314 of 762
+r0:=1/6*a^2*x^6+2/7*a*b*x^7+1/8*b^2*x^8
+--R 
+--R
+--R        1  2 8   2      7   1  2 6
+--R   (2)  - b x  + - a b x  + - a x
+--R        8        7          6
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 314
+
+--S 315 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 315
+
+)clear all
+
+--S 316 of 762
+t0:=(a*x^2+b*x^3)^2
+--R 
+--R
+--R         2 6         5    2 4
+--R   (1)  b x  + 2a b x  + a x
+--R                                                    Type: Polynomial(Integer)
+--E 316
+
+--S 317 of 762
+r0:=1/5*a^2*x^5+1/3*a*b*x^6+1/7*b^2*x^7
+--R 
+--R
+--R        1  2 7   1      6   1  2 5
+--R   (2)  - b x  + - a b x  + - a x
+--R        7        3          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 317
+
+--S 318 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 318
+
+)clear all
+
+--S 319 of 762
+t0:=(a*x^2+b*x^3)^2/x
+--R 
+--R
+--R         2 5         4    2 3
+--R   (1)  b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 319
+
+--S 320 of 762
+r0:=1/4*a^2*x^4+2/5*a*b*x^5+1/6*b^2*x^6
+--R 
+--R
+--R        1  2 6   2      5   1  2 4
+--R   (2)  - b x  + - a b x  + - a x
+--R        6        5          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 320
+
+--S 321 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 321
+
+)clear all
+
+--S 322 of 762
+t0:=(a*x^2+b*x^3)^2/x^2
+--R 
+--R
+--R         2 4         3    2 2
+--R   (1)  b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 322
+
+--S 323 of 762
+r0:=1/3*a^2*x^3+1/2*a*b*x^4+1/5*b^2*x^5
+--R 
+--R
+--R        1  2 5   1      4   1  2 3
+--R   (2)  - b x  + - a b x  + - a x
+--R        5        2          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 323
+
+--S 324 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 324
+
+)clear all
+
+--S 325 of 762
+t0:=x^6/(a*x^2+b*x^3)
+--R 
+--R
+--R            4
+--R           x
+--R   (1)  -------
+--R        b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 325
+
+--S 326 of 762
+r0:=-a^3*x/b^4+1/2*a^2*x^2/b^3-1/3*a*x^3/b^2+1/4*x^4/b+a^4*log(a+b*x)/b^5
+--R 
+--R
+--R           4                 4 4       3 3     2 2 2      3
+--R        12a log(b x + a) + 3b x  - 4a b x  + 6a b x  - 12a b x
+--R   (2)  ------------------------------------------------------
+--R                                    5
+--R                                 12b
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 762
+t0:=x^5/(a*x^2+b*x^3)
+--R 
+--R
+--R            3
+--R           x
+--R   (1)  -------
+--R        b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 328
+
+--S 329 of 762
+r0:=a^2*x/b^3-1/2*a*x^2/b^2+1/3*x^3/b-a^3*log(a+b*x)/b^4
+--R 
+--R
+--R            3                 3 3       2 2     2
+--R        - 6a log(b x + a) + 2b x  - 3a b x  + 6a b x
+--R   (2)  --------------------------------------------
+--R                               4
+--R                             6b
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 762
+t0:=x^4/(a*x^2+b*x^3)
+--R 
+--R
+--R            2
+--R           x
+--R   (1)  -------
+--R        b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 331
+
+--S 332 of 762
+r0:=-a*x/b^2+1/2*x^2/b+a^2*log(a+b*x)/b^3
+--R 
+--R
+--R          2                2 2
+--R        2a log(b x + a) + b x  - 2a b x
+--R   (2)  -------------------------------
+--R                        3
+--R                      2b
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 762
+t0:=x^3/(a*x^2+b*x^3)
+--R 
+--R
+--R           x
+--R   (1)  -------
+--R        b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 334
+
+--S 335 of 762
+r0:=x/b-a*log(a+b*x)/b^2
+--R 
+--R
+--R        - a log(b x + a) + b x
+--R   (2)  ----------------------
+--R                   2
+--R                  b
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 762
+t0:=x^2/(a*x^2+b*x^3)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R        b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 337
+
+--S 338 of 762
+r0:=log(a+b*x)/b
+--R 
+--R
+--R        log(b x + a)
+--R   (2)  ------------
+--R              b
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 762
+t0:=x/(a*x^2+b*x^3)
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R           2
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 340
+
+--S 341 of 762
+r0:=log(x)/a-log(a+b*x)/a
+--R 
+--R
+--R        - log(b x + a) + log(x)
+--R   (2)  -----------------------
+--R                   a
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 762
+t0:=1/(a*x^2+b*x^3)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           3      2
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 343
+
+--S 344 of 762
+r0:=(-1)/(a*x)-b*log(x)/a^2+b*log(a+b*x)/a^2
+--R 
+--R
+--R        b x log(b x + a) - b x log(x) - a
+--R   (2)  ---------------------------------
+--R                        2
+--R                       a x
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 762
+t0:=1/(x*(a*x^2+b*x^3))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           4      3
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 346
+
+--S 347 of 762
+r0:=(-1/2)/(a*x^2)+b/(a^2*x)+b^2*log(x)/a^3-b^2*log(a+b*x)/a^3
+--R 
+--R
+--R            2 2                 2 2                   2
+--R        - 2b x log(b x + a) + 2b x log(x) + 2a b x - a
+--R   (2)  -----------------------------------------------
+--R                               3 2
+--R                             2a x
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 762
+t0:=1/(x^2*(a*x^2+b*x^3))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           5      4
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 349
+
+--S 350 of 762
+r0:=(-1/3)/(a*x^3)+1/2*b/(a^2*x^2)-b^2/(a^3*x)-b^3*log(x)/a^4+_
+     b^3*log(a+b*x)/a^4
+--R 
+--R
+--R          3 3                 3 3             2 2     2        3
+--R        6b x log(b x + a) - 6b x log(x) - 6a b x  + 3a b x - 2a
+--R   (2)  --------------------------------------------------------
+--R                                    4 3
+--R                                  6a x
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 762
+t0:=x^8/(a*x^2+b*x^3)^2
+--R 
+--R
+--R                 4
+--R                x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 352
+
+--S 353 of 762
+r0:=3*a^2*x/b^4-a*x^2/b^3+1/3*x^3/b^2-a^4/(b^5*(a+b*x))-4*a^3*log(a+b*x)/b^5
+--R 
+--R
+--R   (2)
+--R         3         4                 4 4       3 3     2 2 2     3        4
+--R   (- 12a b x - 12a )log(b x + a) + b x  - 2a b x  + 6a b x  + 9a b x - 3a
+--R   ------------------------------------------------------------------------
+--R                                   6        5
+--R                                 3b x + 3a b
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 762
+t0:=x^7/(a*x^2+b*x^3)^2
+--R 
+--R
+--R                 3
+--R                x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 355
+
+--S 356 of 762
+r0:=-2*a*x/b^3+1/2*x^2/b^2+a^3/(b^4*(a+b*x))+3*a^2*log(a+b*x)/b^4
+--R 
+--R
+--R           2        3                 3 3       2 2     2        3
+--R        (6a b x + 6a )log(b x + a) + b x  - 3a b x  - 4a b x + 2a
+--R   (2)  ----------------------------------------------------------
+--R                                 5        4
+--R                               2b x + 2a b
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 762
+t0:=x^6/(a*x^2+b*x^3)^2
+--R 
+--R
+--R                 2
+--R                x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 358
+
+--S 359 of 762
+r0:=x/b^2-a^2/(b^3*(a+b*x))-2*a*log(a+b*x)/b^3
+--R 
+--R
+--R                      2                 2 2            2
+--R        (- 2a b x - 2a )log(b x + a) + b x  + a b x - a
+--R   (2)  ------------------------------------------------
+--R                            4       3
+--R                           b x + a b
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 762
+t0:=x^5/(a*x^2+b*x^3)^2
+--R 
+--R
+--R                 x
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 361
+
+--S 362 of 762
+r0:=a/(b^2*(a+b*x))+log(a+b*x)/b^2
+--R 
+--R
+--R        (b x + a)log(b x + a) + a
+--R   (2)  -------------------------
+--R                 3       2
+--R                b x + a b
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 762
+t0:=x^4/(a*x^2+b*x^3)^2
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R         2 2             2
+--R        b x  + 2a b x + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 364
+
+--S 365 of 762
+r0:=(-1)/(b*(a+b*x))
+--R 
+--R
+--R              1
+--R   (2)  - ---------
+--R           2
+--R          b x + a b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 365
+
+--S 366 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 366
+
+)clear all
+
+--S 367 of 762
+t0:=x^3/(a*x^2+b*x^3)^2
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         2 3         2    2
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 367
+
+--S 368 of 762
+r0:=1/(a*(a+b*x))+log(x)/a^2-log(a+b*x)/a^2
+--R 
+--R
+--R        (- b x - a)log(b x + a) + (b x + a)log(x) + a
+--R   (2)  ---------------------------------------------
+--R                           2       3
+--R                          a b x + a
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 762
+t0:=x^2/(a*x^2+b*x^3)^2
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 4         3    2 2
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 370
+
+--S 371 of 762
+r0:=(-1)/(a^2*x)-b/(a^2*(a+b*x))-2*b*log(x)/a^3+2*b*log(a+b*x)/a^3
+--R 
+--R
+--R           2 2                              2 2                             2
+--R        (2b x  + 2a b x)log(b x + a) + (- 2b x  - 2a b x)log(x) - 2a b x - a
+--R   (2)  ---------------------------------------------------------------------
+--R                                      3   2    4
+--R                                     a b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 762
+t0:=x/(a*x^2+b*x^3)^2
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 5         4    2 3
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 373
+
+--S 374 of 762
+r0:=(-1/2)/(a^2*x^2)+2*b/(a^3*x)+b^2/(a^3*(a+b*x))+_
+     3*b^2*log(x)/a^4-3*b^2*log(a+b*x)/a^4
+--R 
+--R
+--R   (2)
+--R            3 3       2 2                   3 3       2 2              2 2
+--R       (- 6b x  - 6a b x )log(b x + a) + (6b x  + 6a b x )log(x) + 6a b x
+--R     + 
+--R         2       3
+--R       3a b x - a
+--R  /
+--R       4   3     5 2
+--R     2a b x  + 2a x
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 762
+t0:=1/(a*x^2+b*x^3)^2
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 6         5    2 4
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 376
+
+--S 377 of 762
+r0:=(-1/3)/(a^2*x^3)+b/(a^3*x^2)-3*b^2/(a^4*x)-_
+     b^3/(a^4*(a+b*x))-4*b^3*log(x)/a^5+4*b^3*log(a+b*x)/a^5
+--R 
+--R
+--R   (2)
+--R           4 4        3 3                      4 4        3 3               3 3
+--R       (12b x  + 12a b x )log(b x + a) + (- 12b x  - 12a b x )log(x) - 12a b x
+--R     + 
+--R           2 2 2     3       4
+--R       - 6a b x  + 2a b x - a
+--R  /
+--R       5   4     6 3
+--R     3a b x  + 3a x
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 762
+t0:=1/(x*(a*x^2+b*x^3)^2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 7         6    2 5
+--R        b x  + 2a b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 379
+
+--S 380 of 762
+r0:=(-1/4)/(a^2*x^4)+2/3*b/(a^3*x^3)-3/2*b^2/(a^4*x^2)+_
+     4*b^3/(a^5*x)+b^4/(a^5*(a+b*x))+5*b^4*log(x)/a^6-5*b^4*log(a+b*x)/a^6
+--R 
+--R
+--R   (2)
+--R             5 5        4 4                    5 5        4 4               4 4
+--R       (- 60b x  - 60a b x )log(b x + a) + (60b x  + 60a b x )log(x) + 60a b x
+--R     + 
+--R          2 3 3      3 2 2     4        5
+--R       30a b x  - 10a b x  + 5a b x - 3a
+--R  /
+--R        6   5      7 4
+--R     12a b x  + 12a x
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 762
+t0:=x^2*sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R           +-----------+
+--R         2 |   3      2
+--R   (1)  x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 762
+r0:=2/9*(a*x^2+b*x^3)^(3/2)/b-32/315*a^3*(a*x^2+b*x^3)^(3/2)/(b^4*x^3)+_
+     16/105*a^2*(a*x^2+b*x^3)^(3/2)/(b^3*x^2)-_
+     4/21*a*(a*x^2+b*x^3)^(3/2)/(b^2*x)
+--R 
+--R
+--R                                                        +-----------+
+--R            4 4        3 3      2 2 2      3         4  |   3      2
+--R        (70b x  + 10a b x  - 12a b x  + 16a b x - 32a )\|b x  + a x
+--R   (2)  -------------------------------------------------------------
+--R                                        4
+--R                                    315b x
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 762
+t0:=x*sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R          +-----------+
+--R          |   3      2
+--R   (1)  x\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 762
+r0:=16/105*a^2*(a*x^2+b*x^3)^(3/2)/(b^3*x^3)-8/35*a*(a*x^2+_
+     b*x^3)^(3/2)/(b^2*x^2)+2/7*(a*x^2+b*x^3)^(3/2)/(b*x)
+--R 
+--R
+--R                                           +-----------+
+--R            3 3       2 2     2         3  |   3      2
+--R        (30b x  + 6a b x  - 8a b x + 16a )\|b x  + a x
+--R   (2)  ------------------------------------------------
+--R                                 3
+--R                             105b x
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 762
+t0:=sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R         +-----------+
+--R         |   3      2
+--R   (1)  \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 762
+r0:=-4/15*a*(a*x^2+b*x^3)^(3/2)/(b^2*x^3)+2/5*(a*x^2+b*x^3)^(3/2)/(b*x^2)
+--R 
+--R
+--R                               +-----------+
+--R           2 2              2  |   3      2
+--R        (6b x  + 2a b x - 4a )\|b x  + a x
+--R   (2)  ------------------------------------
+--R                           2
+--R                        15b x
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 762
+t0:=sqrt(a*x^2+b*x^3)/x
+--R 
+--R
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R   (1)  --------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 762
+r0:=2/3*(a*x^2+b*x^3)^(3/2)/(b*x^3)
+--R 
+--R
+--R                    +-----------+
+--R                    |   3      2
+--R        (2b x + 2a)\|b x  + a x
+--R   (2)  -------------------------
+--R                   3b x
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 762
+t0:=sqrt(a*x^2+b*x^3)/x^2
+--R 
+--R
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R   (1)  --------------
+--R               2
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 762
+r0:=-2*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))*sqrt(a)+2*sqrt(a*x^2+b*x^3)/x
+--R 
+--R
+--R                             +-+          +-----------+
+--R             +-+           x\|a           |   3      2
+--R        - 2x\|a atanh(--------------) + 2\|b x  + a x
+--R                       +-----------+
+--R                       |   3      2
+--R                      \|b x  + a x
+--R   (2)  -----------------------------------------------
+--R                               x
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 762
+t0:=sqrt(a*x^2+b*x^3)/x^3
+--R 
+--R
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R   (1)  --------------
+--R               3
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 762
+r0:=-b*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/sqrt(a)-sqrt(a*x^2+b*x^3)/x^2
+--R 
+--R
+--R                           +-+             +-----------+
+--R             2           x\|a          +-+ |   3      2
+--R        - b x atanh(--------------) - \|a \|b x  + a x
+--R                     +-----------+
+--R                     |   3      2
+--R                    \|b x  + a x
+--R   (2)  ------------------------------------------------
+--R                              2 +-+
+--R                             x \|a
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 762
+t0:=sqrt(a*x^2+b*x^3)/x^4
+--R 
+--R
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R   (1)  --------------
+--R               4
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 762
+r0:=1/4*b^2*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/a^(3/2)-_
+     1/2*sqrt(a*x^2+b*x^3)/x^3-1/4*b*sqrt(a*x^2+b*x^3)/(a*x^2)
+--R 
+--R
+--R                         +-+                         +-----------+
+--R         2 3           x\|a                      +-+ |   3      2
+--R        b x atanh(--------------) + (- b x - 2a)\|a \|b x  + a x
+--R                   +-----------+
+--R                   |   3      2
+--R                  \|b x  + a x
+--R   (2)  ----------------------------------------------------------
+--R                                     3 +-+
+--R                                 4a x \|a
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 762
+t0:=sqrt(a*x^2+b*x^3)/x^5
+--R 
+--R
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R   (1)  --------------
+--R               5
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 762
+r0:=-1/8*b^3*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/a^(5/2)-_
+     1/3*sqrt(a*x^2+b*x^3)/x^4-1/12*b*sqrt(a*x^2+b*x^3)/(a*x^3)+_
+     1/8*b^2*sqrt(a*x^2+b*x^3)/(a^2*x^2)
+--R 
+--R
+--R   (2)
+--R                       +-+                                   +-----------+
+--R       3 4           x\|a            2 2              2  +-+ |   3      2
+--R   - 3b x atanh(--------------) + (3b x  - 2a b x - 8a )\|a \|b x  + a x
+--R                 +-----------+
+--R                 |   3      2
+--R                \|b x  + a x
+--R   -----------------------------------------------------------------------
+--R                                     2 4 +-+
+--R                                  24a x \|a
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 762
+t0:=x^2*(a*x^2+b*x^3)^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R            5      4  |   3      2
+--R   (1)  (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 762
+r0:=2/15*(a*x^2+b*x^3)^(5/2)/b-512/45045*a^5*(a*x^2+b*x^3)^(5/2)/_
+     (b^6*x^5)+256/9009*a^4*(a*x^2+b*x^3)^(5/2)/(b^5*x^4)-_
+     64/1287*a^3*(a*x^2+b*x^3)^(5/2)/(b^4*x^3)+_
+     32/429*a^2*(a*x^2+b*x^3)^(5/2)/(b^3*x^2)-_
+     4/39*a*(a*x^2+b*x^3)^(5/2)/(b^2*x)
+--R 
+--R
+--R   (2)
+--R              7 7          6 6       2 5 5       3 4 4       4 3 3       5 2 2
+--R         6006b x  + 7392a b x  + 126a b x  - 140a b x  + 160a b x  - 192a b x
+--R       + 
+--R             6          7
+--R         256a b x - 512a
+--R    *
+--R        +-----------+
+--R        |   3      2
+--R       \|b x  + a x
+--R  /
+--R           6
+--R     45045b x
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 762
+t0:=x*(a*x^2+b*x^3)^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R            4      3  |   3      2
+--R   (1)  (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 762
+r0:=256/15015*a^4*(a*x^2+b*x^3)^(5/2)/(b^5*x^5)-_
+     128/3003*a^3*(a*x^2+b*x^3)^(5/2)/(b^4*x^4)+_
+     32/429*a^2*(a*x^2+b*x^3)^(5/2)/(b^3*x^3)-_
+     16/143*a*(a*x^2+b*x^3)^(5/2)/(b^2*x^2)+2/13*(a*x^2+b*x^3)^(5/2)/(b*x)
+--R 
+--R
+--R   (2)
+--R                6 6          5 5      2 4 4      3 3 3      4 2 2       5
+--R           2310b x  + 2940a b x  + 70a b x  - 80a b x  + 96a b x  - 128a b x
+--R         + 
+--R               6
+--R           256a
+--R    *
+--R        +-----------+
+--R        |   3      2
+--R       \|b x  + a x
+--R  /
+--R           5
+--R     15015b x
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 762
+t0:=(a*x^2+b*x^3)^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R            3      2  |   3      2
+--R   (1)  (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 762
+r0:=-32/1155*a^3*(a*x^2+b*x^3)^(5/2)/(b^4*x^5)+_
+     16/231*a^2*(a*x^2+b*x^3)^(5/2)/(b^3*x^4)-_
+     4/33*a*(a*x^2+b*x^3)^(5/2)/(b^2*x^3)+2/11*(a*x^2+b*x^3)^(5/2)/(b*x^2)
+--R 
+--R
+--R   (2)
+--R                                                                +-----------+
+--R        5 5         4 4      2 3 3      3 2 2      4         5  |   3      2
+--R   (210b x  + 280a b x  + 10a b x  - 12a b x  + 16a b x - 32a )\|b x  + a x
+--R   --------------------------------------------------------------------------
+--R                                          4
+--R                                     1155b x
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 762
+t0:=(a*x^2+b*x^3)^(3/2)/x
+--R 
+--R
+--R                     +-----------+
+--R            2        |   3      2
+--R   (1)  (b x  + a x)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 762
+r0:=16/315*a^2*(a*x^2+b*x^3)^(5/2)/(b^3*x^5)-_
+     8/63*a*(a*x^2+b*x^3)^(5/2)/(b^2*x^4)+2/9*(a*x^2+b*x^3)^(5/2)/(b*x^3)
+--R 
+--R
+--R                                                       +-----------+
+--R            4 4         3 3     2 2 2     3         4  |   3      2
+--R        (70b x  + 100a b x  + 6a b x  - 8a b x + 16a )\|b x  + a x
+--R   (2)  ------------------------------------------------------------
+--R                                       3
+--R                                   315b x
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 762
+t0:=(a*x^2+b*x^3)^(3/2)/x^2
+--R 
+--R
+--R                  +-----------+
+--R                  |   3      2
+--R   (1)  (b x + a)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 762
+r0:=-4/35*a*(a*x^2+b*x^3)^(5/2)/(b^2*x^5)+2/7*(a*x^2+b*x^3)^(5/2)/(b*x^4)
+--R 
+--R
+--R                                           +-----------+
+--R            3 3        2 2     2        3  |   3      2
+--R        (10b x  + 16a b x  + 2a b x - 4a )\|b x  + a x
+--R   (2)  ------------------------------------------------
+--R                                 2
+--R                              35b x
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 762
+t0:=(a*x^2+b*x^3)^(3/2)/x^3
+--R 
+--R
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R   (1)  -----------------------
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 762
+r0:=2/5*(a*x^2+b*x^3)^(5/2)/(b*x^5)
+--R 
+--R
+--R                               +-----------+
+--R           2 2              2  |   3      2
+--R        (2b x  + 4a b x + 2a )\|b x  + a x
+--R   (2)  ------------------------------------
+--R                        5b x
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 762
+t0:=(a*x^2+b*x^3)^(3/2)/x^4
+--R 
+--R
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R   (1)  -----------------------
+--R                    2
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 762
+r0:=2/3*(a*x^2+b*x^3)^(3/2)/x^3-2*a^(3/2)*atanh(x*sqrt(a)/_
+     sqrt(a*x^2+b*x^3))+2*a*sqrt(a*x^2+b*x^3)/x
+--R 
+--R
+--R                               +-+                    +-----------+
+--R               +-+           x\|a                     |   3      2
+--R        - 6a x\|a atanh(--------------) + (2b x + 8a)\|b x  + a x
+--R                         +-----------+
+--R                         |   3      2
+--R                        \|b x  + a x
+--R   (2)  -----------------------------------------------------------
+--R                                     3x
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 762
+t0:=(a*x^2+b*x^3)^(3/2)/x^5
+--R 
+--R
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R   (1)  -----------------------
+--R                    3
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 762
+r0:=-(a*x^2+b*x^3)^(3/2)/x^4-3*b*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))*_
+     sqrt(a)+3*b*sqrt(a*x^2+b*x^3)/x
+--R 
+--R
+--R                                +-+                   +-----------+
+--R              2 +-+           x\|a                    |   3      2
+--R        - 3b x \|a atanh(--------------) + (2b x - a)\|b x  + a x
+--R                          +-----------+
+--R                          |   3      2
+--R                         \|b x  + a x
+--R   (2)  -----------------------------------------------------------
+--R                                      2
+--R                                     x
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 762
+t0:=(a*x^2+b*x^3)^(3/2)/x^6
+--R 
+--R
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R   (1)  -----------------------
+--R                    4
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 762
+r0:=-1/2*(a*x^2+b*x^3)^(3/2)/x^5-3/4*b^2*atanh(x*sqrt(a)/_
+     sqrt(a*x^2+b*x^3))/sqrt(a)-3/4*b*sqrt(a*x^2+b*x^3)/x^2
+--R 
+--R
+--R                            +-+                          +-----------+
+--R            2 3           x\|a                       +-+ |   3      2
+--R        - 3b x atanh(--------------) + (- 5b x - 2a)\|a \|b x  + a x
+--R                      +-----------+
+--R                      |   3      2
+--R                     \|b x  + a x
+--R   (2)  --------------------------------------------------------------
+--R                                      3 +-+
+--R                                    4x \|a
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 762
+t0:=(a*x^2+b*x^3)^(3/2)/x^7
+--R 
+--R
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R   (1)  -----------------------
+--R                    5
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 762
+r0:=-1/3*(a*x^2+b*x^3)^(3/2)/x^6+1/8*b^3*atanh(x*sqrt(a)/_
+     sqrt(a*x^2+b*x^3))/a^(3/2)-1/4*b*sqrt(a*x^2+b*x^3)/x^3-_
+     1/8*b^2*sqrt(a*x^2+b*x^3)/(a*x^2)
+--R 
+--R
+--R   (2)
+--R                     +-+                                      +-----------+
+--R     3 4           x\|a              2 2               2  +-+ |   3      2
+--R   3b x atanh(--------------) + (- 3b x  - 14a b x - 8a )\|a \|b x  + a x
+--R               +-----------+
+--R               |   3      2
+--R              \|b x  + a x
+--R   ------------------------------------------------------------------------
+--R                                       4 +-+
+--R                                  24a x \|a
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 762
+t0:=(a*x^2+b*x^3)^(3/2)/x^8
+--R 
+--R
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R   (1)  -----------------------
+--R                    6
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 762
+r0:=-1/4*(a*x^2+b*x^3)^(3/2)/x^7-3/64*b^4*atanh(x*sqrt(a)/_
+     sqrt(a*x^2+b*x^3))/a^(5/2)-1/8*b*sqrt(a*x^2+b*x^3)/x^4-_
+     1/32*b^2*sqrt(a*x^2+b*x^3)/(a*x^3)+3/64*b^3*sqrt(a*x^2+b*x^3)/(a^2*x^2)
+--R 
+--R
+--R   (2)
+--R                           +-+
+--R           4 5           x\|a
+--R       - 3b x atanh(--------------)
+--R                     +-----------+
+--R                     |   3      2
+--R                    \|b x  + a x
+--R     + 
+--R                                              +-----------+
+--R          3 3       2 2      2         3  +-+ |   3      2
+--R       (3b x  - 2a b x  - 24a b x - 16a )\|a \|b x  + a x
+--R  /
+--R        2 5 +-+
+--R     64a x \|a
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 762
+t0:=(a*x^2+b*x^3)^(3/2)/x^9
+--R 
+--R
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R   (1)  -----------------------
+--R                    7
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 762
+r0:=-1/5*(a*x^2+b*x^3)^(3/2)/x^8+3/128*b^5*atanh(x*sqrt(a)/_
+     sqrt(a*x^2+b*x^3))/a^(7/2)-3/40*b*sqrt(a*x^2+b*x^3)/x^5-_
+     1/80*b^2*sqrt(a*x^2+b*x^3)/(a*x^4)+1/64*b^3*sqrt(a*x^2+b*x^3)/_
+     (a^2*x^3)-3/128*b^4*sqrt(a*x^2+b*x^3)/(a^3*x^2)
+--R 
+--R
+--R   (2)
+--R                          +-+
+--R          5 6           x\|a
+--R       15b x atanh(--------------)
+--R                    +-----------+
+--R                    |   3      2
+--R                   \|b x  + a x
+--R     + 
+--R                                                              +-----------+
+--R             4 4        3 3     2 2 2       3          4  +-+ |   3      2
+--R       (- 15b x  + 10a b x  - 8a b x  - 176a b x - 128a )\|a \|b x  + a x
+--R  /
+--R         3 6 +-+
+--R     640a x \|a
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 762
+t0:=x^4/sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 762
+r0:=16/35*a^2*sqrt(a*x^2+b*x^3)/b^3-32/35*a^3*sqrt(a*x^2+b*x^3)/(b^4*x)-_
+     12/35*a*x*sqrt(a*x^2+b*x^3)/b^2+2/7*x^2*sqrt(a*x^2+b*x^3)/b
+--R 
+--R
+--R                                             +-----------+
+--R            3 3        2 2      2         3  |   3      2
+--R        (10b x  - 12a b x  + 16a b x - 32a )\|b x  + a x
+--R   (2)  --------------------------------------------------
+--R                                  4
+--R                               35b x
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 444
+
+)clear all
+
+--S 445 of 762
+t0:=x^3/sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 762
+r0:=-8/15*a*sqrt(a*x^2+b*x^3)/b^2+16/15*a^2*sqrt(a*x^2+b*x^3)/(b^3*x)+_
+     2/5*x*sqrt(a*x^2+b*x^3)/b
+--R 
+--R
+--R                                +-----------+
+--R           2 2               2  |   3      2
+--R        (6b x  - 8a b x + 16a )\|b x  + a x
+--R   (2)  -------------------------------------
+--R                           3
+--R                        15b x
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 762
+t0:=x^2/sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 762
+r0:=2/3*sqrt(a*x^2+b*x^3)/b-4/3*a*sqrt(a*x^2+b*x^3)/(b^2*x)
+--R 
+--R
+--R                    +-----------+
+--R                    |   3      2
+--R        (2b x - 4a)\|b x  + a x
+--R   (2)  -------------------------
+--R                     2
+--R                   3b x
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 762
+t0:=x/sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 762
+r0:=2*sqrt(a*x^2+b*x^3)/(b*x)
+--R 
+--R
+--R          +-----------+
+--R          |   3      2
+--R        2\|b x  + a x
+--R   (2)  ---------------
+--R              b x
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 762
+t0:=1/sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 762
+r0:=-2*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/sqrt(a)
+--R 
+--R
+--R                        +-+
+--R                      x\|a
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |   3      2
+--R                 \|b x  + a x
+--R   (2)  - ----------------------
+--R                    +-+
+--R                   \|a
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 762
+t0:=1/(x*sqrt(a*x^2+b*x^3))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          +-----------+
+--R          |   3      2
+--R        x\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 762
+r0:=b*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/a^(3/2)-sqrt(a*x^2+b*x^3)/(a*x^2)
+--R 
+--R
+--R                         +-+             +-----------+
+--R           2           x\|a          +-+ |   3      2
+--R        b x atanh(--------------) - \|a \|b x  + a x
+--R                   +-----------+
+--R                   |   3      2
+--R                  \|b x  + a x
+--R   (2)  ----------------------------------------------
+--R                              2 +-+
+--R                           a x \|a
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 762
+t0:=1/(x^2*sqrt(a*x^2+b*x^3))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         2 |   3      2
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 762
+r0:=-3/4*b^2*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/a^(5/2)-_
+     1/2*sqrt(a*x^2+b*x^3)/(a*x^3)+3/4*b*sqrt(a*x^2+b*x^3)/(a^2*x^2)
+--R 
+--R
+--R                            +-+                        +-----------+
+--R            2 3           x\|a                     +-+ |   3      2
+--R        - 3b x atanh(--------------) + (3b x - 2a)\|a \|b x  + a x
+--R                      +-----------+
+--R                      |   3      2
+--R                     \|b x  + a x
+--R   (2)  ------------------------------------------------------------
+--R                                    2 3 +-+
+--R                                  4a x \|a
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 762
+t0:=1/(x^3*sqrt(a*x^2+b*x^3))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         3 |   3      2
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 762
+r0:=5/8*b^3*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/a^(7/2)-_
+     1/3*sqrt(a*x^2+b*x^3)/(a*x^4)+5/12*b*sqrt(a*x^2+b*x^3)/(a^2*x^3)-_
+     5/8*b^2*sqrt(a*x^2+b*x^3)/(a^3*x^2)
+--R 
+--R
+--R   (2)
+--R                      +-+                                       +-----------+
+--R      3 4           x\|a               2 2               2  +-+ |   3      2
+--R   15b x atanh(--------------) + (- 15b x  + 10a b x - 8a )\|a \|b x  + a x
+--R                +-----------+
+--R                |   3      2
+--R               \|b x  + a x
+--R   --------------------------------------------------------------------------
+--R                                      3 4 +-+
+--R                                   24a x \|a
+--R                                                    Type: Expression(Integer)
+--E 464
+
+--S 465 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 465
+
+)clear all
+
+--S 466 of 762
+t0:=x^6/(a*x^2+b*x^3)^(3/2)
+--R 
+--R
+--R                    4
+--R                   x
+--R   (1)  -----------------------
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 762
+r0:=-2*x^4/(b*sqrt(a*x^2+b*x^3))-16/5*a*sqrt(a*x^2+b*x^3)/b^3+_
+     32/5*a^2*sqrt(a*x^2+b*x^3)/(b^4*x)+12/5*x*sqrt(a*x^2+b*x^3)/b^2
+--R 
+--R
+--R          3 4       2 3      2   2      3
+--R        2b x  - 4a b x  + 16a b x  + 32a x
+--R   (2)  ----------------------------------
+--R                     +-----------+
+--R                   4 |   3      2
+--R                 5b \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 467
+
+--S 468 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 468
+
+)clear all
+
+--S 469 of 762
+t0:=x^5/(a*x^2+b*x^3)^(3/2)
+--R 
+--R
+--R                    3
+--R                   x
+--R   (1)  -----------------------
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 762
+r0:=-2*x^3/(b*sqrt(a*x^2+b*x^3))+8/3*sqrt(a*x^2+b*x^3)/b^2-_
+     16/3*a*sqrt(a*x^2+b*x^3)/(b^3*x)
+--R 
+--R
+--R          2 3         2      2
+--R        2b x  - 8a b x  - 16a x
+--R   (2)  -----------------------
+--R               +-----------+
+--R             3 |   3      2
+--R           3b \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 470
+
+--S 471 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 471
+
+)clear all
+
+--S 472 of 762
+t0:=x^4/(a*x^2+b*x^3)^(3/2)
+--R 
+--R
+--R                    2
+--R                   x
+--R   (1)  -----------------------
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 762
+r0:=-2*x^2/(b*sqrt(a*x^2+b*x^3))+4*sqrt(a*x^2+b*x^3)/(b^2*x)
+--R 
+--R
+--R              2
+--R          2b x  + 4a x
+--R   (2)  ----------------
+--R           +-----------+
+--R         2 |   3      2
+--R        b \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 473
+
+--S 474 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 474
+
+)clear all
+
+--S 475 of 762
+t0:=x^3/(a*x^2+b*x^3)^(3/2)
+--R 
+--R
+--R                   x
+--R   (1)  -----------------------
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 762
+r0:=-2*x/(b*sqrt(a*x^2+b*x^3))
+--R 
+--R
+--R                 2x
+--R   (2)  - ---------------
+--R            +-----------+
+--R            |   3      2
+--R          b\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 476
+
+--S 477 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 477
+
+)clear all
+
+--S 478 of 762
+t0:=x^2/(a*x^2+b*x^3)^(3/2)
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R                  +-----------+
+--R                  |   3      2
+--R        (b x + a)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 762
+r0:=-2*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/a^(3/2)+2*x/(a*sqrt(a*x^2+b*x^3))
+--R 
+--R
+--R            +-----------+             +-+
+--R            |   3      2            x\|a            +-+
+--R        - 2\|b x  + a x  atanh(--------------) + 2x\|a
+--R                                +-----------+
+--R                                |   3      2
+--R                               \|b x  + a x
+--R   (2)  -----------------------------------------------
+--R                            +-----------+
+--R                        +-+ |   3      2
+--R                      a\|a \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 479
+
+--S 480 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 480
+
+)clear all
+
+--S 481 of 762
+t0:=x/(a*x^2+b*x^3)^(3/2)
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                     +-----------+
+--R            2        |   3      2
+--R        (b x  + a x)\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 762
+r0:=3*b*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/a^(5/2)+2/(a*sqrt(a*x^2+b*x^3))-_
+     3*sqrt(a*x^2+b*x^3)/(a^2*x^2)
+--R 
+--R
+--R           +-----------+             +-+
+--R           |   3      2            x\|a                      +-+
+--R        3b\|b x  + a x  atanh(--------------) + (- 3b x - a)\|a
+--R                               +-----------+
+--R                               |   3      2
+--R                              \|b x  + a x
+--R   (2)  --------------------------------------------------------
+--R                                 +-----------+
+--R                           2 +-+ |   3      2
+--R                          a \|a \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 482
+
+--S 483 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 483
+
+)clear all
+
+--S 484 of 762
+t0:=1/(a*x^2+b*x^3)^(3/2)
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            3      2  |   3      2
+--R        (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 762
+r0:=-15/4*b^2*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/a^(7/2)+_
+     2/(a*x*sqrt(a*x^2+b*x^3))-5/2*sqrt(a*x^2+b*x^3)/(a^2*x^3)+_
+     15/4*b*sqrt(a*x^2+b*x^3)/(a^3*x^2)
+--R 
+--R
+--R   (2)
+--R           +-----------+             +-+
+--R        2  |   3      2            x\|a             2 2              2  +-+
+--R   - 15b x\|b x  + a x  atanh(--------------) + (15b x  + 5a b x - 2a )\|a
+--R                               +-----------+
+--R                               |   3      2
+--R                              \|b x  + a x
+--R   ------------------------------------------------------------------------
+--R                                     +-----------+
+--R                              3  +-+ |   3      2
+--R                            4a x\|a \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 485
+
+--S 486 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 486
+
+)clear all
+
+--S 487 of 762
+t0:=1/(x*(a*x^2+b*x^3)^(3/2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            4      3  |   3      2
+--R        (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 762
+r0:=35/8*b^3*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/a^(9/2)+_
+     2/(a*x^2*sqrt(a*x^2+b*x^3))-7/3*sqrt(a*x^2+b*x^3)/(a^2*x^4)+_
+     35/12*b*sqrt(a*x^2+b*x^3)/(a^3*x^3)-35/8*b^2*sqrt(a*x^2+b*x^3)/(a^4*x^2)
+--R 
+--R
+--R   (2)
+--R               +-----------+             +-+
+--R           3 2 |   3      2            x\|a
+--R       105b x \|b x  + a x  atanh(--------------)
+--R                                   +-----------+
+--R                                   |   3      2
+--R                                  \|b x  + a x
+--R     + 
+--R              3 3        2 2      2        3  +-+
+--R       (- 105b x  - 35a b x  + 14a b x - 8a )\|a
+--R  /
+--R                +-----------+
+--R        4 2 +-+ |   3      2
+--R     24a x \|a \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 488
+
+--S 489 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 489
+
+)clear all
+
+--S 490 of 762
+t0:=1/(x^2*(a*x^2+b*x^3)^(3/2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            5      4  |   3      2
+--R        (b x  + a x )\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 762
+r0:=-315/64*b^4*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^3))/a^(11/2)+_
+     2/(a*x^3*sqrt(a*x^2+b*x^3))-9/4*sqrt(a*x^2+b*x^3)/(a^2*x^5)+_
+     21/8*b*sqrt(a*x^2+b*x^3)/(a^3*x^4)-_
+     105/32*b^2*sqrt(a*x^2+b*x^3)/(a^4*x^3)+_
+     315/64*b^3*sqrt(a*x^2+b*x^3)/(a^5*x^2)
+--R 
+--R
+--R   (2)
+--R                 +-----------+             +-+
+--R             4 3 |   3      2            x\|a
+--R       - 315b x \|b x  + a x  atanh(--------------)
+--R                                     +-----------+
+--R                                     |   3      2
+--R                                    \|b x  + a x
+--R     + 
+--R            4 4         3 3      2 2 2      3         4  +-+
+--R       (315b x  + 105a b x  - 42a b x  + 24a b x - 16a )\|a
+--R  /
+--R                +-----------+
+--R        5 3 +-+ |   3      2
+--R     64a x \|a \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 491
+
+--S 492 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 492
+
+)clear all
+
+--S 493 of 762
+t0:=x^(7/2)/sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R             3 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 762
+r0:=-5/8*a^3*atanh(x^(3/2)*sqrt(b)/sqrt(a*x^2+b*x^3))/b^(7/2)+_
+     1/3*x^(3/2)*sqrt(a*x^2+b*x^3)/b+5/8*a^2*sqrt(a*x^2+b*x^3)/_
+     (b^3*sqrt(x))-5/12*a*sqrt(x)*sqrt(a*x^2+b*x^3)/b^2
+--R 
+--R
+--R   (2)
+--R                        +-+ +-+                                   +-----------+
+--R        3 +-+         x\|b \|x          2 2                2  +-+ |   3      2
+--R   - 15a \|x atanh(--------------) + (8b x  - 10a b x + 15a )\|b \|b x  + a x
+--R                    +-----------+
+--R                    |   3      2
+--R                   \|b x  + a x
+--R   ----------------------------------------------------------------------------
+--R                                      3 +-+ +-+
+--R                                   24b \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 494
+
+--S 495 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 495
+
+)clear all
+
+--S 496 of 762
+t0:=x^(5/2)/sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R             2 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 762
+r0:=3/4*a^2*atanh(x^(3/2)*sqrt(b)/sqrt(a*x^2+b*x^3))/b^(5/2)-_
+     3/4*a*sqrt(a*x^2+b*x^3)/(b^2*sqrt(x))+1/2*sqrt(x)*sqrt(a*x^2+b*x^3)/b
+--R 
+--R
+--R                          +-+ +-+                      +-----------+
+--R          2 +-+         x\|b \|x                   +-+ |   3      2
+--R        3a \|x atanh(--------------) + (2b x - 3a)\|b \|b x  + a x
+--R                      +-----------+
+--R                      |   3      2
+--R                     \|b x  + a x
+--R   (2)  ------------------------------------------------------------
+--R                                   2 +-+ +-+
+--R                                 4b \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 497
+
+--S 498 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 498
+
+)clear all
+
+--S 499 of 762
+t0:=x^(3/2)/sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R               +-+
+--R             x\|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 762
+r0:=-a*atanh(x^(3/2)*sqrt(b)/sqrt(a*x^2+b*x^3))/b^(3/2)+_
+     sqrt(a*x^2+b*x^3)/(b*sqrt(x))
+--R 
+--R
+--R                          +-+ +-+           +-----------+
+--R            +-+         x\|b \|x        +-+ |   3      2
+--R        - a\|x atanh(--------------) + \|b \|b x  + a x
+--R                      +-----------+
+--R                      |   3      2
+--R                     \|b x  + a x
+--R   (2)  -------------------------------------------------
+--R                              +-+ +-+
+--R                            b\|b \|x
+--R                                                    Type: Expression(Integer)
+--E 500
+
+--S 501 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 501
+
+)clear all
+
+--S 502 of 762
+t0:=x^(1/2)/sqrt(a*x^2+b*x^3)
+--R 
+--R
+--R              +-+
+--R             \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   3      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 762
+r0:=2*atanh(x^(3/2)*sqrt(b)/sqrt(a*x^2+b*x^3))/sqrt(b)
+--R 
+--R
+--R                    +-+ +-+
+--R                  x\|b \|x
+--R        2atanh(--------------)
+--R                +-----------+
+--R                |   3      2
+--R               \|b x  + a x
+--R   (2)  ----------------------
+--R                  +-+
+--R                 \|b
+--R                                                    Type: Expression(Integer)
+--E 503
+
+--S 504 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 504
+
+)clear all
+
+--S 505 of 762
+t0:=1/(x^(1/2)*sqrt(a*x^2+b*x^3))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R             +-----------+
+--R         +-+ |   3      2
+--R        \|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 762
+r0:=-2*sqrt(a*x^2+b*x^3)/(a*x^(3/2))
+--R 
+--R
+--R            +-----------+
+--R            |   3      2
+--R          2\|b x  + a x
+--R   (2)  - ---------------
+--R                  +-+
+--R              a x\|x
+--R                                                    Type: Expression(Integer)
+--E 506
+
+--S 507 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 507
+
+)clear all
+
+--S 508 of 762
+t0:=1/(x^(3/2)*sqrt(a*x^2+b*x^3))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R              +-----------+
+--R          +-+ |   3      2
+--R        x\|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 762
+r0:=-2/3*sqrt(a*x^2+b*x^3)/(a*x^(5/2))+4/3*b*sqrt(a*x^2+b*x^3)/(a^2*x^(3/2))
+--R 
+--R
+--R                    +-----------+
+--R                    |   3      2
+--R        (4b x - 2a)\|b x  + a x
+--R   (2)  -------------------------
+--R                  2 2 +-+
+--R                3a x \|x
+--R                                                    Type: Expression(Integer)
+--E 509
+
+--S 510 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 510
+
+)clear all
+
+--S 511 of 762
+t0:=1/(x^(5/2)*sqrt(a*x^2+b*x^3))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         2 +-+ |   3      2
+--R        x \|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 762
+r0:=-2/5*sqrt(a*x^2+b*x^3)/(a*x^(7/2))+8/15*b*sqrt(a*x^2+b*x^3)/_
+     (a^2*x^(5/2))-16/15*b^2*sqrt(a*x^2+b*x^3)/(a^3*x^(3/2))
+--R 
+--R
+--R                                  +-----------+
+--R              2 2              2  |   3      2
+--R        (- 16b x  + 8a b x - 6a )\|b x  + a x
+--R   (2)  ---------------------------------------
+--R                          3 3 +-+
+--R                       15a x \|x
+--R                                                    Type: Expression(Integer)
+--E 512
+
+--S 513 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 513
+
+)clear all
+
+--S 514 of 762
+t0:=1/(x^(7/2)*sqrt(a*x^2+b*x^3))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         3 +-+ |   3      2
+--R        x \|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 762
+r0:=-2/7*sqrt(a*x^2+b*x^3)/(a*x^(9/2))+12/35*b*sqrt(a*x^2+b*x^3)/_
+     (a^2*x^(7/2))-16/35*b^2*sqrt(a*x^2+b*x^3)/(a^3*x^(5/2))+_
+     32/35*b^3*sqrt(a*x^2+b*x^3)/(a^4*x^(3/2))
+--R 
+--R
+--R                                             +-----------+
+--R            3 3        2 2      2         3  |   3      2
+--R        (32b x  - 16a b x  + 12a b x - 10a )\|b x  + a x
+--R   (2)  --------------------------------------------------
+--R                               4 4 +-+
+--R                            35a x \|x
+--R                                                    Type: Expression(Integer)
+--E 515
+
+--S 516 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 516
+
+)clear all
+
+--S 517 of 762
+t0:=x^(1-3*n)*(a*x^2+b*x^3)^n
+--R 
+--R
+--R         - 3n + 1    3      2 n
+--R   (1)  x        (b x  + a x )
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 762
+--r0:=1/2*x^(-1-3*n)*(a*x^2+b*x^3)^(1+n)/b-1/2*x^(-1-3*n)*_
+--     (a*x^2+b*x^3)^(1+n)*hypergeometric(1,2,2-n,-b*x/a)/b
+--E 518
+
+--S 519 of 762
+--d0:=t0-D(r0,x)
+--E 519
+
+)clear all
+
+--S 520 of 762
+t0:=(a*x^2+b*x^3)^n/x^(3*n)
+--R 
+--R
+--R            3      2 n
+--R        (b x  + a x )
+--R   (1)  --------------
+--R               3n
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 762
+--r0:=x^(-1-3*n)*(a*x^2+b*x^3)^(1+n)*hypergeometric(1,2,2-n,-b*x/a)/(a*(1-n))
+--E 521
+
+--S 522 of 762
+--d0:=t0-D(r0,x)
+--E 522
+
+)clear all
+
+--S 523 of 762
+t0:=x^(-1-3*n)*(a*x^2+b*x^3)^n
+--R 
+--R
+--R         - 3n - 1    3      2 n
+--R   (1)  x        (b x  + a x )
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 762
+--r0:=-x^(-2-3*n)*(a*x^2+b*x^3)^(1+n)/(a*n)+b*x^(-1-3*n)*_
+--     (a*x^2+b*x^3)^(1+n)*hypergeometric(1,2,2-n,-b*x/a)/(a^2*(1-n)*n)
+--E 524
+
+--S 525 of 762
+--d0:=t0-D(r0,x)
+--E 525
+
+)clear all
+
+--S 526 of 762
+t0:=x^(-2-3*n)*(a*x^2+b*x^3)^n
+--R 
+--R
+--R         - 3n - 2    3      2 n
+--R   (1)  x        (b x  + a x )
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 762
+r0:=-(a*x^2+b*x^3)^(1+n)/(a*(1+n)*x^(3*(1+n)))
+--R 
+--R
+--R              3      2 n + 1
+--R          (b x  + a x )
+--R   (2)  - ------------------
+--R                     3n + 3
+--R           (a n + a)x
+--R                                                    Type: Expression(Integer)
+--E 527
+
+--S 528 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 528
+
+)clear all
+
+--S 529 of 762
+t0:=x^(-3-3*n)*(a*x^2+b*x^3)^n
+--R 
+--R
+--R         - 3n - 3    3      2 n
+--R   (1)  x        (b x  + a x )
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 762
+r0:=-x^(-4-3*n)*(a*x^2+b*x^3)^(1+n)/(a*(2+n))+b*(a*x^2+b*x^3)^(1+n)/_
+     (a^2*(1+n)*(2+n)*x^(3*(1+n)))
+--R 
+--R
+--R                     - 3n - 4 3n + 3         3      2 n + 1
+--R        ((- a n - a)x        x       + b)(b x  + a x )
+--R   (2)  ---------------------------------------------------
+--R                       2 2     2      2  3n + 3
+--R                     (a n  + 3a n + 2a )x
+--R                                                    Type: Expression(Integer)
+--E 530
+
+--S 531 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 531
+
+)clear all
+
+--S 532 of 762
+t0:=x^(-4-3*n)*(a*x^2+b*x^3)^n
+--R 
+--R
+--R         - 3n - 4    3      2 n
+--R   (1)  x        (b x  + a x )
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 762
+r0:=-x^(-5-3*n)*(a*x^2+b*x^3)^(1+n)/(a*(3+n))+2*b*x^(-4-3*n)*_
+     (a*x^2+b*x^3)^(1+n)/(a^2*(2+n)*(3+n))-2*b^2*_
+     (a*x^2+b*x^3)^(1+n)/(a^3*(1+n)*(2+n)*(3+n)*x^(3*(1+n)))
+--R 
+--R
+--R   (2)
+--R                            - 3n - 4       2 2     2      2  - 3n - 5  3n + 3
+--R           ((2a b n + 2a b)x         + (- a n  - 3a n - 2a )x        )x
+--R         + 
+--R               2
+--R           - 2b
+--R    *
+--R           3      2 n + 1
+--R       (b x  + a x )
+--R  /
+--R       3 3     3 2      3      3  3n + 3
+--R     (a n  + 6a n  + 11a n + 6a )x
+--R                                                    Type: Expression(Integer)
+--E 533
+
+--S 534 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 534
+
+)clear all
+
+--S 535 of 762
+t0:=x^m*(b*x^2+c*x^4)
+--R 
+--R
+--R            4      2  m
+--R   (1)  (c x  + b x )x
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 762
+r0:=b*x^(3+m)/(3+m)+c*x^(5+m)/(5+m)
+--R 
+--R
+--R                   m + 5              m + 3
+--R        (c m + 3c)x      + (b m + 5b)x
+--R   (2)  -----------------------------------
+--R                     2
+--R                    m  + 8m + 15
+--R                                                    Type: Expression(Integer)
+--E 536
+
+--S 537 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 537
+
+)clear all
+
+--S 538 of 762
+t0:=x^2*(b*x^2+c*x^4)
+--R 
+--R
+--R           6      4
+--R   (1)  c x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 538
+
+--S 539 of 762
+r0:=1/5*b*x^5+1/7*c*x^7
+--R 
+--R
+--R        1    7   1    5
+--R   (2)  - c x  + - b x
+--R        7        5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 539
+
+--S 540 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 540
+
+)clear all
+
+--S 541 of 762
+t0:=x*(b*x^2+c*x^4)
+--R 
+--R
+--R           5      3
+--R   (1)  c x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 541
+
+--S 542 of 762
+r0:=1/4*b*x^4+1/6*c*x^6
+--R 
+--R
+--R        1    6   1    4
+--R   (2)  - c x  + - b x
+--R        6        4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 542
+
+--S 543 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 543
+
+)clear all
+
+--S 544 of 762
+t0:=b*x^2+c*x^4
+--R 
+--R
+--R           4      2
+--R   (1)  c x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 544
+
+--S 545 of 762
+r0:=1/3*b*x^3+1/5*c*x^5
+--R 
+--R
+--R        1    5   1    3
+--R   (2)  - c x  + - b x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 545
+
+--S 546 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 546
+
+)clear all
+
+--S 547 of 762
+t0:=(b*x^2+c*x^4)/x
+--R 
+--R
+--R           3
+--R   (1)  c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 547
+
+--S 548 of 762
+r0:=1/2*b*x^2+1/4*c*x^4
+--R 
+--R
+--R        1    4   1    2
+--R   (2)  - c x  + - b x
+--R        4        2
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 548
+
+--S 549 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 549
+
+)clear all
+
+--S 550 of 762
+t0:=(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R           2
+--R   (1)  c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 550
+
+--S 551 of 762
+r0:=b*x+1/3*c*x^3
+--R 
+--R
+--R        1    3
+--R   (2)  - c x  + b x
+--R        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 551
+
+--S 552 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 552
+
+)clear all
+
+--S 553 of 762
+t0:=(b*x^2+c*x^4)/x^3
+--R 
+--R
+--R           2
+--R        c x  + b
+--R   (1)  --------
+--R            x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 553
+
+--S 554 of 762
+r0:=1/2*c*x^2+b*log(x)
+--R 
+--R
+--R                       2
+--R        2b log(x) + c x
+--R   (2)  ----------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 554
+
+--S 555 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 555
+
+)clear all
+
+--S 556 of 762
+t0:=(b*x^2+c*x^4)/x^4
+--R 
+--R
+--R           2
+--R        c x  + b
+--R   (1)  --------
+--R            2
+--R           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 556
+
+--S 557 of 762
+r0:=-b/x+c*x
+--R 
+--R
+--R           2
+--R        c x  - b
+--R   (2)  --------
+--R            x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 557
+
+--S 558 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 558
+
+)clear all
+
+--S 559 of 762
+t0:=(b*x^2+c*x^4)/x^5
+--R 
+--R
+--R           2
+--R        c x  + b
+--R   (1)  --------
+--R            3
+--R           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 559
+
+--S 560 of 762
+r0:=-1/2*b/x^2+c*log(x)
+--R 
+--R
+--R            2
+--R        2c x log(x) - b
+--R   (2)  ---------------
+--R                2
+--R              2x
+--R                                                    Type: Expression(Integer)
+--E 560
+
+--S 561 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 561
+
+)clear all
+
+--S 562 of 762
+t0:=(b*x^2+c*x^4)/x^6
+--R 
+--R
+--R           2
+--R        c x  + b
+--R   (1)  --------
+--R            4
+--R           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 562
+
+--S 563 of 762
+r0:=-1/3*b/x^3-c/x
+--R 
+--R
+--R             2   1
+--R        - c x  - - b
+--R                 3
+--R   (2)  ------------
+--R              3
+--R             x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 563
+
+--S 564 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 564
+
+)clear all
+
+--S 565 of 762
+t0:=(b*x^2+c*x^4)/x^7
+--R 
+--R
+--R           2
+--R        c x  + b
+--R   (1)  --------
+--R            5
+--R           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 565
+
+--S 566 of 762
+r0:=-1/4*b/x^4-1/2*c/x^2
+--R 
+--R
+--R          1    2   1
+--R        - - c x  - - b
+--R          2        4
+--R   (2)  --------------
+--R               4
+--R              x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 566
+
+--S 567 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 567
+
+)clear all
+
+--S 568 of 762
+t0:=(b*x^2+c*x^4)/x^8
+--R 
+--R
+--R           2
+--R        c x  + b
+--R   (1)  --------
+--R            6
+--R           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 568
+
+--S 569 of 762
+r0:=-1/5*b/x^5-1/3*c/x^3
+--R 
+--R
+--R          1    2   1
+--R        - - c x  - - b
+--R          3        5
+--R   (2)  --------------
+--R               5
+--R              x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 569
+
+--S 570 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 570
+
+)clear all
+
+--S 571 of 762
+t0:=x^m*(b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 8         6    2 4  m
+--R   (1)  (c x  + 2b c x  + b x )x
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 762
+r0:=b^2*x^(5+m)/(5+m)+2*b*c*x^(7+m)/(7+m)+c^2*x^(9+m)/(9+m)
+--R 
+--R
+--R   (2)
+--R         2 2      2       2  m + 9          2                    m + 7
+--R       (c m  + 12c m + 35c )x      + (2b c m  + 28b c m + 90b c)x
+--R     + 
+--R         2 2      2       2  m + 5
+--R       (b m  + 16b m + 63b )x
+--R  /
+--R      3      2
+--R     m  + 21m  + 143m + 315
+--R                                                    Type: Expression(Integer)
+--E 572
+
+--S 573 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 573
+
+)clear all
+
+--S 574 of 762
+t0:=(b*x^2+c*x^4)^2
+--R 
+--R
+--R         2 8         6    2 4
+--R   (1)  c x  + 2b c x  + b x
+--R                                                    Type: Polynomial(Integer)
+--E 574
+
+--S 575 of 762
+r0:=1/5*b^2*x^5+2/7*b*c*x^7+1/9*c^2*x^9
+--R 
+--R
+--R        1  2 9   2      7   1  2 5
+--R   (2)  - c x  + - b c x  + - b x
+--R        9        7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 575
+
+--S 576 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 576
+
+)clear all
+
+--S 577 of 762
+t0:=(b*x^2+c*x^4)^2/x
+--R 
+--R
+--R         2 7         5    2 3
+--R   (1)  c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 577
+
+--S 578 of 762
+r0:=1/4*b^2*x^4+1/3*b*c*x^6+1/8*c^2*x^8
+--R 
+--R
+--R        1  2 8   1      6   1  2 4
+--R   (2)  - c x  + - b c x  + - b x
+--R        8        3          4
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 578
+
+--S 579 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 579
+
+)clear all
+
+--S 580 of 762
+t0:=(b*x^2+c*x^4)^2/x^2
+--R 
+--R
+--R         2 6         4    2 2
+--R   (1)  c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 580
+
+--S 581 of 762
+r0:=1/3*b^2*x^3+2/5*b*c*x^5+1/7*c^2*x^7
+--R 
+--R
+--R        1  2 7   2      5   1  2 3
+--R   (2)  - c x  + - b c x  + - b x
+--R        7        5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 581
+
+--S 582 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 582
+
+)clear all
+
+--S 583 of 762
+t0:=(b*x^2+c*x^4)^2/x^3
+--R 
+--R
+--R         2 5         3    2
+--R   (1)  c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 583
+
+--S 584 of 762
+r0:=1/6*(b+c*x^2)^3/c
+--R 
+--R
+--R        1  3 6   1    2 4   1  2   2   1  3
+--R        - c x  + - b c x  + - b c x  + - b
+--R        6        2          2          6
+--R   (2)  -----------------------------------
+--R                         c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 584
+
+--S 585 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 585
+
+)clear all
+
+--S 586 of 762
+t0:=(b*x^2+c*x^4)^2/x^4
+--R 
+--R
+--R         2 4         2    2
+--R   (1)  c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 586
+
+--S 587 of 762
+r0:=b^2*x+2/3*b*c*x^3+1/5*c^2*x^5
+--R 
+--R
+--R        1  2 5   2      3    2
+--R   (2)  - c x  + - b c x  + b x
+--R        5        3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 587
+
+--S 588 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 588
+
+)clear all
+
+--S 589 of 762
+t0:=(b*x^2+c*x^4)^2/x^5
+--R 
+--R
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R   (1)  -------------------
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 589
+
+--S 590 of 762
+r0:=b*c*x^2+1/4*c^2*x^4+b^2*log(x)
+--R 
+--R
+--R          2          2 4         2
+--R        4b log(x) + c x  + 4b c x
+--R   (2)  --------------------------
+--R                     4
+--R                                                    Type: Expression(Integer)
+--E 590
+
+--S 591 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 591
+
+)clear all
+
+--S 592 of 762
+t0:=(b*x^2+c*x^4)^2/x^6
+--R 
+--R
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 592
+
+--S 593 of 762
+r0:=-b^2/x+2*b*c*x+1/3*c^2*x^3
+--R 
+--R
+--R         2 4         2     2
+--R        c x  + 6b c x  - 3b
+--R   (2)  --------------------
+--R                 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 593
+
+--S 594 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 594
+
+)clear all
+
+--S 595 of 762
+t0:=(b*x^2+c*x^4)^2/x^7
+--R 
+--R
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R   (1)  -------------------
+--R                  3
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 595
+
+--S 596 of 762
+r0:=-1/2*b^2/x^2+1/2*c^2*x^2+2*b*c*log(x)
+--R 
+--R
+--R              2          2 4    2
+--R        4b c x log(x) + c x  - b
+--R   (2)  -------------------------
+--R                     2
+--R                   2x
+--R                                                    Type: Expression(Integer)
+--E 596
+
+--S 597 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 597
+
+)clear all
+
+--S 598 of 762
+t0:=(b*x^2+c*x^4)^2/x^8
+--R 
+--R
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R   (1)  -------------------
+--R                  4
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 598
+
+--S 599 of 762
+r0:=-1/3*b^2/x^3-2*b*c/x+c^2*x
+--R 
+--R
+--R         2 4         2   1  2
+--R        c x  - 2b c x  - - b
+--R                         3
+--R   (2)  ---------------------
+--R                   3
+--R                  x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 599
+
+--S 600 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 600
+
+)clear all
+
+--S 601 of 762
+t0:=(b*x^2+c*x^4)^2/x^9
+--R 
+--R
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R   (1)  -------------------
+--R                  5
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 601
+
+--S 602 of 762
+r0:=-1/4*b^2/x^4-b*c/x^2+c^2*log(x)
+--R 
+--R
+--R          2 4               2    2
+--R        4c x log(x) - 4b c x  - b
+--R   (2)  --------------------------
+--R                      4
+--R                    4x
+--R                                                    Type: Expression(Integer)
+--E 602
+
+--S 603 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 603
+
+)clear all
+
+--S 604 of 762
+t0:=(b*x^2+c*x^4)^2/x^10
+--R 
+--R
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R   (1)  -------------------
+--R                  6
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 604
+
+--S 605 of 762
+r0:=-1/5*b^2/x^5-2/3*b*c/x^3-c^2/x
+--R 
+--R
+--R           2 4   2      2   1  2
+--R        - c x  - - b c x  - - b
+--R                 3          5
+--R   (2)  ------------------------
+--R                    5
+--R                   x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 605
+
+--S 606 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 606
+
+)clear all
+
+--S 607 of 762
+t0:=(b*x^2+c*x^4)^2/x^11
+--R 
+--R
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R   (1)  -------------------
+--R                  7
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 607
+
+--S 608 of 762
+r0:=-1/6*(b+c*x^2)^3/(b*x^6)
+--R 
+--R
+--R          1  3 6   1    2 4   1  2   2   1  3
+--R        - - c x  - - b c x  - - b c x  - - b
+--R          6        2          2          6
+--R   (2)  -------------------------------------
+--R                            6
+--R                         b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 608
+
+--S 609 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 609
+
+)clear all
+
+--S 610 of 762
+t0:=(b*x^2+c*x^4)^2/x^12
+--R 
+--R
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R   (1)  -------------------
+--R                  8
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 610
+
+--S 611 of 762
+r0:=-1/7*b^2/x^7-2/5*b*c/x^5-1/3*c^2/x^3
+--R 
+--R
+--R          1  2 4   2      2   1  2
+--R        - - c x  - - b c x  - - b
+--R          3        5          7
+--R   (2)  --------------------------
+--R                     7
+--R                    x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 611
+
+--S 612 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 612
+
+)clear all
+
+--S 613 of 762
+t0:=x^m*(b*x^2+c*x^4)^3
+--R 
+--R
+--R          3 12       2 10     2   8    3 6  m
+--R   (1)  (c x   + 3b c x   + 3b c x  + b x )x
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 762
+r0:=b^3*x^(7+m)/(7+m)+3*b^2*c*x^(9+m)/(9+m)+3*b*c^2*x^(11+m)/(11+m)+_
+     c^3*x^(13+m)/(13+m)
+--R 
+--R
+--R   (2)
+--R         3 3      3 2       3        3  m + 13
+--R       (c m  + 27c m  + 239c m + 693c )x
+--R     + 
+--R            2 3        2 2         2           2  m + 11
+--R       (3b c m  + 87b c m  + 813b c m + 2457b c )x
+--R     + 
+--R          2   3      2   2       2           2   m + 9
+--R       (3b c m  + 93b c m  + 933b c m + 3003b c)x
+--R     + 
+--R         3 3      3 2       3         3  m + 7
+--R       (b m  + 33b m  + 359b m + 1287b )x
+--R  /
+--R      4      3       2
+--R     m  + 40m  + 590m  + 3800m + 9009
+--R                                                    Type: Expression(Integer)
+--E 614
+
+--S 615 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 615
+
+)clear all
+
+--S 616 of 762
+t0:=(b*x^2+c*x^4)^3/x^2
+--R 
+--R
+--R         3 10       2 8     2   6    3 4
+--R   (1)  c x   + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 616
+
+--S 617 of 762
+r0:=1/5*b^3*x^5+3/7*b^2*c*x^7+1/3*b*c^2*x^9+1/11*c^3*x^11
+--R 
+--R
+--R         1  3 11   1    2 9   3  2   7   1  3 5
+--R   (2)  -- c x   + - b c x  + - b c x  + - b x
+--R        11         3          7          5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 617
+
+--S 618 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 618
+
+)clear all
+
+--S 619 of 762
+t0:=(b*x^2+c*x^4)^3/x^3
+--R 
+--R
+--R         3 9       2 7     2   5    3 3
+--R   (1)  c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 619
+
+--S 620 of 762
+r0:=-1/8*b*(b+c*x^2)^4/c^2+1/10*(b+c*x^2)^5/c^2
+--R 
+--R
+--R         1  5 10   3    4 8   1  2 3 6   1  3 2 4    1  5
+--R        -- c x   + - b c x  + - b c x  + - b c x  - -- b
+--R        10         8          2          4          40
+--R   (2)  -------------------------------------------------
+--R                                 2
+--R                                c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 620
+
+--S 621 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 621
+
+)clear all
+
+--S 622 of 762
+t0:=(b*x^2+c*x^4)^3/x^4
+--R 
+--R
+--R         3 8       2 6     2   4    3 2
+--R   (1)  c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 622
+
+--S 623 of 762
+r0:=1/3*b^3*x^3+3/5*b^2*c*x^5+3/7*b*c^2*x^7+1/9*c^3*x^9
+--R 
+--R
+--R        1  3 9   3    2 7   3  2   5   1  3 3
+--R   (2)  - c x  + - b c x  + - b c x  + - b x
+--R        9        7          5          3
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 623
+
+--S 624 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 624
+
+)clear all
+
+--S 625 of 762
+t0:=(b*x^2+c*x^4)^3/x^5
+--R 
+--R
+--R         3 7       2 5     2   3    3
+--R   (1)  c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 625
+
+--S 626 of 762
+r0:=1/8*(b+c*x^2)^4/c
+--R 
+--R
+--R        1  4 8   1    3 6   3  2 2 4   1  3   2   1  4
+--R        - c x  + - b c x  + - b c x  + - b c x  + - b
+--R        8        2          4          2          8
+--R   (2)  ----------------------------------------------
+--R                               c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 626
+
+--S 627 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 627
+
+)clear all
+
+--S 628 of 762
+t0:=(b*x^2+c*x^4)^3/x^6
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R   (1)  c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 628
+
+--S 629 of 762
+r0:=b^3*x+b^2*c*x^3+3/5*b*c^2*x^5+1/7*c^3*x^7
+--R 
+--R
+--R        1  3 7   3    2 5    2   3    3
+--R   (2)  - c x  + - b c x  + b c x  + b x
+--R        7        5
+--R                                          Type: Polynomial(Fraction(Integer))
+--E 629
+
+--S 630 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 630
+
+)clear all
+
+--S 631 of 762
+t0:=(b*x^2+c*x^4)^3/x^7
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 631
+
+--S 632 of 762
+r0:=3/2*b^2*c*x^2+3/4*b*c^2*x^4+1/6*c^3*x^6+b^3*log(x)
+--R 
+--R
+--R           3           3 6       2 4      2   2
+--R        12b log(x) + 2c x  + 9b c x  + 18b c x
+--R   (2)  ---------------------------------------
+--R                           12
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 633
+
+)clear all
+
+--S 634 of 762
+t0:=(b*x^2+c*x^4)^3/x^8
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                       2
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 634
+
+--S 635 of 762
+r0:=-b^3/x+3*b^2*c*x+b*c^2*x^3+1/5*c^3*x^5
+--R 
+--R
+--R         3 6       2 4      2   2     3
+--R        c x  + 5b c x  + 15b c x  - 5b
+--R   (2)  -------------------------------
+--R                       5x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 635
+
+--S 636 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 636
+
+)clear all
+
+--S 637 of 762
+t0:=(b*x^2+c*x^4)^3/x^9
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                       3
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 637
+
+--S 638 of 762
+r0:=-1/2*b^3/x^2+3/2*b*c^2*x^2+1/4*c^3*x^4+3*b^2*c*log(x)
+--R 
+--R
+--R           2   2          3 6       2 4     3
+--R        12b c x log(x) + c x  + 6b c x  - 2b
+--R   (2)  -------------------------------------
+--R                           2
+--R                         4x
+--R                                                    Type: Expression(Integer)
+--E 638
+
+--S 639 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 639
+
+)clear all
+
+--S 640 of 762
+t0:=(b*x^2+c*x^4)^3/x^10
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                       4
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 640
+
+--S 641 of 762
+r0:=-1/3*b^3/x^3-3*b^2*c/x+3*b*c^2*x+1/3*c^3*x^3
+--R 
+--R
+--R        1  3 6       2 4     2   2   1  3
+--R        - c x  + 3b c x  - 3b c x  - - b
+--R        3                            3
+--R   (2)  ---------------------------------
+--R                         3
+--R                        x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 641
+
+--S 642 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 642
+
+)clear all
+
+--S 643 of 762
+t0:=(b*x^2+c*x^4)^3/x^11
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                       5
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 643
+
+--S 644 of 762
+r0:=-1/4*b^3/x^4-3/2*b^2*c/x^2+1/2*c^3*x^2+3*b*c^2*log(x)
+--R 
+--R
+--R             2 4           3 6     2   2    3
+--R        12b c x log(x) + 2c x  - 6b c x  - b
+--R   (2)  -------------------------------------
+--R                           4
+--R                         4x
+--R                                                    Type: Expression(Integer)
+--E 644
+
+--S 645 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 645
+
+)clear all
+
+--S 646 of 762
+t0:=(b*x^2+c*x^4)^3/x^12
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                       6
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 646
+
+--S 647 of 762
+r0:=-1/5*b^3/x^5-b^2*c/x^3-3*b*c^2/x+c^3*x
+--R 
+--R
+--R         3 6       2 4    2   2   1  3
+--R        c x  - 3b c x  - b c x  - - b
+--R                                  5
+--R   (2)  ------------------------------
+--R                       5
+--R                      x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 647
+
+--S 648 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 648
+
+)clear all
+
+--S 649 of 762
+t0:=(b*x^2+c*x^4)^3/x^13
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                       7
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 649
+
+--S 650 of 762
+r0:=-1/6*b^3/x^6-3/4*b^2*c/x^4-3/2*b*c^2/x^2+c^3*log(x)
+--R 
+--R
+--R           3 6              2 4     2   2     3
+--R        12c x log(x) - 18b c x  - 9b c x  - 2b
+--R   (2)  ---------------------------------------
+--R                             6
+--R                          12x
+--R                                                    Type: Expression(Integer)
+--E 650
+
+--S 651 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 651
+
+)clear all
+
+--S 652 of 762
+t0:=(b*x^2+c*x^4)^3/x^14
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                       8
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 652
+
+--S 653 of 762
+r0:=-1/7*b^3/x^7-3/5*b^2*c/x^5-b*c^2/x^3-c^3/x
+--R 
+--R
+--R           3 6      2 4   3  2   2   1  3
+--R        - c x  - b c x  - - b c x  - - b
+--R                          5          7
+--R   (2)  ---------------------------------
+--R                         7
+--R                        x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 653
+
+--S 654 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 654
+
+)clear all
+
+--S 655 of 762
+t0:=(b*x^2+c*x^4)^3/x^15
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                       9
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 655
+
+--S 656 of 762
+r0:=-1/8*(b+c*x^2)^4/(b*x^8)
+--R 
+--R
+--R          1  4 8   1    3 6   3  2 2 4   1  3   2   1  4
+--R        - - c x  - - b c x  - - b c x  - - b c x  - - b
+--R          8        2          4          2          8
+--R   (2)  ------------------------------------------------
+--R                                 8
+--R                              b x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 656
+
+--S 657 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 657
+
+)clear all
+
+--S 658 of 762
+t0:=(b*x^2+c*x^4)^3/x^16
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                      10
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 658
+
+--S 659 of 762
+r0:=-1/9*b^3/x^9-3/7*b^2*c/x^7-3/5*b*c^2/x^5-1/3*c^3/x^3
+--R 
+--R
+--R          1  3 6   3    2 4   3  2   2   1  3
+--R        - - c x  - - b c x  - - b c x  - - b
+--R          3        5          7          9
+--R   (2)  -------------------------------------
+--R                           9
+--R                          x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 659
+
+--S 660 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 660
+
+)clear all
+
+--S 661 of 762
+t0:=(b*x^2+c*x^4)^3/x^17
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R   (1)  -----------------------------
+--R                      11
+--R                     x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 661
+
+--S 662 of 762
+r0:=-1/10*b^3/x^10-3/8*b^2*c/x^8-1/2*b*c^2/x^6-1/4*c^3/x^4
+--R 
+--R
+--R          1  3 6   1    2 4   3  2   2    1  3
+--R        - - c x  - - b c x  - - b c x  - -- b
+--R          4        2          8          10
+--R   (2)  --------------------------------------
+--R                           10
+--R                          x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 662
+
+--S 663 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 663
+
+)clear all
+
+--S 664 of 762
+t0:=x^4/(a*x^2+b*x^4)
+--R 
+--R
+--R            2
+--R           x
+--R   (1)  --------
+--R           2
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 664
+
+--S 665 of 762
+r0:=x/b-atan(x*sqrt(b)/sqrt(a))*sqrt(a)/b^(3/2)
+--R 
+--R
+--R                     +-+
+--R           +-+     x\|b       +-+
+--R        - \|a atan(-----) + x\|b
+--R                     +-+
+--R                    \|a
+--R   (2)  -------------------------
+--R                    +-+
+--R                  b\|b
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 666
+
+)clear all
+
+--S 667 of 762
+t0:=x^3/(a*x^2+b*x^4)
+--R 
+--R
+--R            x
+--R   (1)  --------
+--R           2
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 667
+
+--S 668 of 762
+r0:=1/2*log(a+b*x^2)/b
+--R 
+--R
+--R               2
+--R        log(b x  + a)
+--R   (2)  -------------
+--R              2b
+--R                                                    Type: Expression(Integer)
+--E 668
+
+--S 669 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 669
+
+)clear all
+
+--S 670 of 762
+t0:=x^2/(a*x^2+b*x^4)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R           2
+--R        b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 670
+
+--S 671 of 762
+r0:=atan(x*sqrt(b)/sqrt(a))/(sqrt(a)*sqrt(b))
+--R 
+--R
+--R               +-+
+--R             x\|b
+--R        atan(-----)
+--R               +-+
+--R              \|a
+--R   (2)  -----------
+--R           +-+ +-+
+--R          \|a \|b
+--R                                                    Type: Expression(Integer)
+--E 671
+
+--S 672 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 672
+
+)clear all
+
+--S 673 of 762
+t0:=x/(a*x^2+b*x^4)
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R           3
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 673
+
+--S 674 of 762
+r0:=log(x)/a-1/2*log(a+b*x^2)/a
+--R 
+--R
+--R                 2
+--R        - log(b x  + a) + 2log(x)
+--R   (2)  -------------------------
+--R                    2a
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+)clear all
+
+--S 676 of 762
+t0:=1/(a*x^2+b*x^4)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           4      2
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 676
+
+--S 677 of 762
+r0:=(-1)/(a*x)-atan(x*sqrt(b)/sqrt(a))*sqrt(b)/a^(3/2)
+--R 
+--R
+--R                      +-+
+--R            +-+     x\|b      +-+
+--R        - x\|b atan(-----) - \|a
+--R                      +-+
+--R                     \|a
+--R   (2)  -------------------------
+--R                     +-+
+--R                 a x\|a
+--R                                                    Type: Expression(Integer)
+--E 677
+
+--S 678 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 678
+
+)clear all
+
+--S 679 of 762
+t0:=1/(x*(a*x^2+b*x^4))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           5      3
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 679
+
+--S 680 of 762
+r0:=(-1/2)/(a*x^2)-b*log(x)/a^2+1/2*b*log(a+b*x^2)/a^2
+--R 
+--R
+--R           2       2            2
+--R        b x log(b x  + a) - 2b x log(x) - a
+--R   (2)  -----------------------------------
+--R                         2 2
+--R                       2a x
+--R                                                    Type: Expression(Integer)
+--E 680
+
+--S 681 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 681
+
+)clear all
+
+--S 682 of 762
+t0:=1/(x^2*(a*x^2+b*x^4))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           6      4
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 682
+
+--S 683 of 762
+r0:=(-1/3)/(a*x^3)+b/(a^2*x)+b^(3/2)*atan(x*sqrt(b)/sqrt(a))/a^(5/2)
+--R 
+--R
+--R                        +-+
+--R            3 +-+     x\|b          2      +-+
+--R        3b x \|b atan(-----) + (3b x  - a)\|a
+--R                        +-+
+--R                       \|a
+--R   (2)  --------------------------------------
+--R                         2 3 +-+
+--R                       3a x \|a
+--R                                                    Type: Expression(Integer)
+--E 683
+
+--S 684 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 684
+
+)clear all
+
+--S 685 of 762
+t0:=1/(x^3*(a*x^2+b*x^4))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           7      5
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 685
+
+--S 686 of 762
+r0:=(-1/4)/(a*x^4)+1/2*b/(a^2*x^2)+b^2*log(x)/a^3-1/2*b^2*log(a+b*x^2)/a^3
+--R 
+--R
+--R            2 4       2          2 4               2    2
+--R        - 2b x log(b x  + a) + 4b x log(x) + 2a b x  - a
+--R   (2)  -------------------------------------------------
+--R                                3 4
+--R                              4a x
+--R                                                    Type: Expression(Integer)
+--E 686
+
+--S 687 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 687
+
+)clear all
+
+--S 688 of 762
+t0:=1/(x^4*(a*x^2+b*x^4))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           8      6
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 688
+
+--S 689 of 762
+r0:=(-1/5)/(a*x^5)+1/3*b/(a^2*x^3)-b^2/(a^3*x)-b^(5/2)*_
+     atan(x*sqrt(b)/sqrt(a))/a^(7/2)
+--R 
+--R
+--R                           +-+
+--R             2 5 +-+     x\|b           2 4         2     2  +-+
+--R        - 15b x \|b atan(-----) + (- 15b x  + 5a b x  - 3a )\|a
+--R                           +-+
+--R                          \|a
+--R   (2)  --------------------------------------------------------
+--R                                  3 5 +-+
+--R                               15a x \|a
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 690
+
+)clear all
+
+--S 691 of 762
+t0:=x^10/(b*x^2+c*x^4)
+--R 
+--R
+--R            8
+--R           x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 691
+
+--S 692 of 762
+r0:=-b^3*x/c^4+1/3*b^2*x^3/c^3-1/5*b*x^5/c^2+1/7*x^7/c+_
+     b^(7/2)*atan(x*sqrt(c)/sqrt(b))/c^(9/2)
+--R 
+--R
+--R                        +-+
+--R            3 +-+     x\|c         3 7        2 5      2   3       3   +-+
+--R        105b \|b atan(-----) + (15c x  - 21b c x  + 35b c x  - 105b x)\|c
+--R                        +-+
+--R                       \|b
+--R   (2)  ------------------------------------------------------------------
+--R                                         4 +-+
+--R                                     105c \|c
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 693
+
+)clear all
+
+--S 694 of 762
+t0:=x^9/(b*x^2+c*x^4)
+--R 
+--R
+--R            7
+--R           x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 694
+
+--S 695 of 762
+r0:=1/2*b^2*x^2/c^3-1/4*b*x^4/c^2+1/6*x^6/c-1/2*b^3*log(b+c*x^2)/c^4
+--R 
+--R
+--R            3       2          3 6       2 4     2   2
+--R        - 6b log(c x  + b) + 2c x  - 3b c x  + 6b c x
+--R   (2)  ----------------------------------------------
+--R                                4
+--R                             12c
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 696
+
+)clear all
+
+--S 697 of 762
+t0:=x^8/(b*x^2+c*x^4)
+--R 
+--R
+--R            6
+--R           x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 697
+
+--S 698 of 762
+r0:=b^2*x/c^3-1/3*b*x^3/c^2+1/5*x^5/c-b^(5/2)*atan(x*sqrt(c)/sqrt(b))/c^(7/2)
+--R 
+--R
+--R                         +-+
+--R             2 +-+     x\|c        2 5         3      2   +-+
+--R        - 15b \|b atan(-----) + (3c x  - 5b c x  + 15b x)\|c
+--R                         +-+
+--R                        \|b
+--R   (2)  -----------------------------------------------------
+--R                                  3 +-+
+--R                               15c \|c
+--R                                                    Type: Expression(Integer)
+--E 698
+
+--S 699 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 699
+
+)clear all
+
+--S 700 of 762
+t0:=x^7/(b*x^2+c*x^4)
+--R 
+--R
+--R            5
+--R           x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 700
+
+--S 701 of 762
+r0:=-1/2*b*x^2/c^2+1/4*x^4/c+1/2*b^2*log(b+c*x^2)/c^3
+--R 
+--R
+--R          2       2         2 4         2
+--R        2b log(c x  + b) + c x  - 2b c x
+--R   (2)  ---------------------------------
+--R                         3
+--R                       4c
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 702
+
+)clear all
+
+--S 703 of 762
+t0:=x^6/(b*x^2+c*x^4)
+--R 
+--R
+--R            4
+--R           x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 703
+
+--S 704 of 762
+r0:=-b*x/c^2+1/3*x^3/c+b^(3/2)*atan(x*sqrt(c)/sqrt(b))/c^(5/2)
+--R 
+--R
+--R                     +-+
+--R           +-+     x\|c         3         +-+
+--R        3b\|b atan(-----) + (c x  - 3b x)\|c
+--R                     +-+
+--R                    \|b
+--R   (2)  -------------------------------------
+--R                         2 +-+
+--R                       3c \|c
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 705
+
+)clear all
+
+--S 706 of 762
+t0:=x^5/(b*x^2+c*x^4)
+--R 
+--R
+--R            3
+--R           x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 706
+
+--S 707 of 762
+r0:=1/2*x^2/c-1/2*b*log(b+c*x^2)/c^2
+--R 
+--R
+--R                   2           2
+--R        - b log(c x  + b) + c x
+--R   (2)  ------------------------
+--R                     2
+--R                   2c
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 708
+
+)clear all
+
+--S 709 of 762
+t0:=x^4/(b*x^2+c*x^4)
+--R 
+--R
+--R            2
+--R           x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 709
+
+--S 710 of 762
+r0:=x/c-atan(x*sqrt(c)/sqrt(b))*sqrt(b)/c^(3/2)
+--R 
+--R
+--R                     +-+
+--R           +-+     x\|c       +-+
+--R        - \|b atan(-----) + x\|c
+--R                     +-+
+--R                    \|b
+--R   (2)  -------------------------
+--R                    +-+
+--R                  c\|c
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 711
+
+)clear all
+
+--S 712 of 762
+t0:=x^3/(b*x^2+c*x^4)
+--R 
+--R
+--R            x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 712
+
+--S 713 of 762
+r0:=1/2*log(b+c*x^2)/c
+--R 
+--R
+--R               2
+--R        log(c x  + b)
+--R   (2)  -------------
+--R              2c
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 714
+
+)clear all
+
+--S 715 of 762
+t0:=x^2/(b*x^2+c*x^4)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 715
+
+--S 716 of 762
+r0:=atan(x*sqrt(c)/sqrt(b))/(sqrt(b)*sqrt(c))
+--R 
+--R
+--R               +-+
+--R             x\|c
+--R        atan(-----)
+--R               +-+
+--R              \|b
+--R   (2)  -----------
+--R           +-+ +-+
+--R          \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 717
+
+)clear all
+
+--S 718 of 762
+t0:=x/(b*x^2+c*x^4)
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R           3
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 718
+
+--S 719 of 762
+r0:=log(x)/b-1/2*log(b+c*x^2)/b
+--R 
+--R
+--R                 2
+--R        - log(c x  + b) + 2log(x)
+--R   (2)  -------------------------
+--R                    2b
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 720
+
+)clear all
+
+--S 721 of 762
+t0:=1/(b*x^2+c*x^4)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           4      2
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 721
+
+--S 722 of 762
+r0:=(-1)/(b*x)-atan(x*sqrt(c)/sqrt(b))*sqrt(c)/b^(3/2)
+--R 
+--R
+--R                      +-+
+--R            +-+     x\|c      +-+
+--R        - x\|c atan(-----) - \|b
+--R                      +-+
+--R                     \|b
+--R   (2)  -------------------------
+--R                     +-+
+--R                 b x\|b
+--R                                                    Type: Expression(Integer)
+--E 722
+
+--S 723 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 723
+
+)clear all
+
+--S 724 of 762
+t0:=1/(x*(b*x^2+c*x^4))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           5      3
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 724
+
+--S 725 of 762
+r0:=(-1/2)/(b*x^2)-c*log(x)/b^2+1/2*c*log(b+c*x^2)/b^2
+--R 
+--R
+--R           2       2            2
+--R        c x log(c x  + b) - 2c x log(x) - b
+--R   (2)  -----------------------------------
+--R                         2 2
+--R                       2b x
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 726
+
+)clear all
+
+--S 727 of 762
+t0:=1/(x^2*(b*x^2+c*x^4))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           6      4
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 727
+
+--S 728 of 762
+r0:=(-1/3)/(b*x^3)+c/(b^2*x)+c^(3/2)*atan(x*sqrt(c)/sqrt(b))/b^(5/2)
+--R 
+--R
+--R                        +-+
+--R            3 +-+     x\|c          2      +-+
+--R        3c x \|c atan(-----) + (3c x  - b)\|b
+--R                        +-+
+--R                       \|b
+--R   (2)  --------------------------------------
+--R                         2 3 +-+
+--R                       3b x \|b
+--R                                                    Type: Expression(Integer)
+--E 728
+
+--S 729 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 729
+
+)clear all
+
+--S 730 of 762
+t0:=1/(x^3*(b*x^2+c*x^4))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           7      5
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 730
+
+--S 731 of 762
+r0:=(-1/4)/(b*x^4)+1/2*c/(b^2*x^2)+c^2*log(x)/b^3-1/2*c^2*log(b+c*x^2)/b^3
+--R 
+--R
+--R            2 4       2          2 4               2    2
+--R        - 2c x log(c x  + b) + 4c x log(x) + 2b c x  - b
+--R   (2)  -------------------------------------------------
+--R                                3 4
+--R                              4b x
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 732
+
+)clear all
+
+--S 733 of 762
+t0:=1/(x^4*(b*x^2+c*x^4))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           8      6
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 733
+
+--S 734 of 762
+r0:=(-1/5)/(b*x^5)+1/3*c/(b^2*x^3)-c^2/(b^3*x)-_
+     c^(5/2)*atan(x*sqrt(c)/sqrt(b))/b^(7/2)
+--R 
+--R
+--R                           +-+
+--R             2 5 +-+     x\|c           2 4         2     2  +-+
+--R        - 15c x \|c atan(-----) + (- 15c x  + 5b c x  - 3b )\|b
+--R                           +-+
+--R                          \|b
+--R   (2)  --------------------------------------------------------
+--R                                  3 5 +-+
+--R                               15b x \|b
+--R                                                    Type: Expression(Integer)
+--E 734
+
+--S 735 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 735
+
+)clear all
+
+--S 736 of 762
+t0:=1/(x^5*(b*x^2+c*x^4))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           9      7
+--R        c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 736
+
+--S 737 of 762
+r0:=(-1/6)/(b*x^6)+1/4*c/(b^2*x^4)-1/2*c^2/(b^3*x^2)-_
+     c^3*log(x)/b^4+1/2*c^3*log(b+c*x^2)/b^4
+--R 
+--R
+--R          3 6       2           3 6             2 4     2   2     3
+--R        6c x log(c x  + b) - 12c x log(x) - 6b c x  + 3b c x  - 2b
+--R   (2)  -----------------------------------------------------------
+--R                                      4 6
+--R                                   12b x
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 738
+
+)clear all
+
+--S 739 of 762
+t0:=x^12/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  8
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 739
+
+--S 740 of 762
+r0:=7/2*b^2*x/c^4-7/6*b*x^3/c^3+7/10*x^5/c^2-_
+     1/2*x^7/(c*(b+c*x^2))-7/2*b^(5/2)*atan(x*sqrt(c)/sqrt(b))/c^(9/2)
+--R 
+--R
+--R   (2)
+--R                                       +-+
+--R              2   2       3  +-+     x\|c
+--R       (- 105b c x  - 105b )\|b atan(-----)
+--R                                       +-+
+--R                                      \|b
+--R     + 
+--R          3 7        2 5      2   3       3   +-+
+--R       (6c x  - 14b c x  + 70b c x  + 105b x)\|c
+--R  /
+--R         5 2        4  +-+
+--R     (30c x  + 30b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 741
+
+)clear all
+
+--S 742 of 762
+t0:=x^11/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  7
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 742
+
+--S 743 of 762
+r0:=-b*x^2/c^3+1/4*x^4/c^2+1/2*b^3/(c^4*(b+c*x^2))+3/2*b^2*log(b+c*x^2)/c^4
+--R 
+--R
+--R           2   2     3        2         3 6       2 4     2   2     3
+--R        (6b c x  + 6b )log(c x  + b) + c x  - 3b c x  - 4b c x  + 2b
+--R   (2)  -------------------------------------------------------------
+--R                                  5 2       4
+--R                                4c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 743
+
+--S 744 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 744
+
+)clear all
+
+--S 745 of 762
+t0:=x^10/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  6
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 745
+
+--S 746 of 762
+r0:=-5/2*b*x/c^3+5/6*x^3/c^2-1/2*x^5/(c*(b+c*x^2))+_
+     5/2*b^(3/2)*atan(x*sqrt(c)/sqrt(b))/c^(7/2)
+--R 
+--R
+--R                                    +-+
+--R                2      2  +-+     x\|c        2 5          3      2   +-+
+--R        (15b c x  + 15b )\|b atan(-----) + (2c x  - 10b c x  - 15b x)\|c
+--R                                    +-+
+--R                                   \|b
+--R   (2)  -----------------------------------------------------------------
+--R                                  4 2       3  +-+
+--R                               (6c x  + 6b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 747
+
+)clear all
+
+--S 748 of 762
+t0:=x^9/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  5
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 748
+
+--S 749 of 762
+r0:=1/2*x^2/c^2-1/2*b^2/(c^3*(b+c*x^2))-b*log(b+c*x^2)/c^3
+--R 
+--R
+--R                 2     2        2         2 4        2    2
+--R        (- 2b c x  - 2b )log(c x  + b) + c x  + b c x  - b
+--R   (2)  ---------------------------------------------------
+--R                             4 2       3
+--R                           2c x  + 2b c
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 750
+
+)clear all
+
+--S 751 of 762
+t0:=x^8/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  4
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 751
+
+--S 752 of 762
+r0:=3/2*x/c^2-1/2*x^3/(c*(b+c*x^2))-3/2*atan(x*sqrt(c)/sqrt(b))*sqrt(b)/c^(5/2)
+--R 
+--R
+--R                                 +-+
+--R               2       +-+     x\|c          3         +-+
+--R        (- 3c x  - 3b)\|b atan(-----) + (2c x  + 3b x)\|c
+--R                                 +-+
+--R                                \|b
+--R   (2)  --------------------------------------------------
+--R                           3 2       2  +-+
+--R                        (2c x  + 2b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 753
+
+)clear all
+
+--S 754 of 762
+t0:=x^7/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  3
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 754
+
+--S 755 of 762
+r0:=1/2*b/(c^2*(b+c*x^2))+1/2*log(b+c*x^2)/c^2
+--R 
+--R
+--R            2            2
+--R        (c x  + b)log(c x  + b) + b
+--R   (2)  ---------------------------
+--R                 3 2       2
+--R               2c x  + 2b c
+--R                                                    Type: Expression(Integer)
+--E 755
+
+--S 756 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 756
+
+)clear all
+
+--S 757 of 762
+t0:=x^6/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  2
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 757
+
+--S 758 of 762
+r0:=-1/2*x/(c*(b+c*x^2))+1/2*atan(x*sqrt(c)/sqrt(b))/(c^(3/2)*sqrt(b))
+--R 
+--R
+--R                         +-+
+--R            2          x\|c       +-+ +-+
+--R        (c x  + b)atan(-----) - x\|b \|c
+--R                         +-+
+--R                        \|b
+--R   (2)  ---------------------------------
+--R                 2 2         +-+ +-+
+--R              (2c x  + 2b c)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 758
+
+--S 759 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 759
+
+)clear all
+
+--S 760 of 762
+t0:=x^5/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                 x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 760
+
+--S 761 of 762
+r0:=(-1/2)/(c*(b+c*x^2))
+--R 
+--R
+--R               1
+--R               -
+--R               2
+--R   (2)  - ----------
+--R           2 2
+--R          c x  + b c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 761
+
+--S 762 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 762
+
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder8c.input.pamphlet b/src/input/richder8c.input.pamphlet
new file mode 100644
index 0000000..deb7f92
--- /dev/null
+++ b/src/input/richder8c.input.pamphlet
@@ -0,0 +1,9455 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder8c.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a x^q+b x^n)^p|
+
+Two derivatives did not match.
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder8c.output
+)spool richder8c.output
+)set message test on
+)set message auto off
+)clear all
+
+
+--S 1 of 762
+t0:=x^4/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 1
+
+--S 2 of 762
+r0:=1/2*x/(b*(b+c*x^2))+1/2*atan(x*sqrt(c)/sqrt(b))/(b^(3/2)*sqrt(c))
+--R 
+--R
+--R                         +-+
+--R            2          x\|c       +-+ +-+
+--R        (c x  + b)atan(-----) + x\|b \|c
+--R                         +-+
+--R                        \|b
+--R   (2)  ---------------------------------
+--R                    2     2  +-+ +-+
+--R             (2b c x  + 2b )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 762
+t0:=x^3/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         2 5         3    2
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 4
+
+--S 5 of 762
+r0:=1/2/(b*(b+c*x^2))+log(x)/b^2-1/2*log(b+c*x^2)/b^2
+--R 
+--R
+--R              2            2             2
+--R        (- c x  - b)log(c x  + b) + (2c x  + 2b)log(x) + b
+--R   (2)  --------------------------------------------------
+--R                             2   2     3
+--R                           2b c x  + 2b
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 762
+t0:=x^2/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 6         4    2 2
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 7
+
+--S 8 of 762
+r0:=(-3/2)/(b^2*x)+1/2/(b*x*(b+c*x^2))-3/2*atan(x*sqrt(c)/sqrt(b))*_
+     sqrt(c)/b^(5/2)
+--R 
+--R
+--R                                   +-+
+--R               3         +-+     x\|c            2       +-+
+--R        (- 3c x  - 3b x)\|c atan(-----) + (- 3c x  - 2b)\|b
+--R                                   +-+
+--R                                  \|b
+--R   (2)  ----------------------------------------------------
+--R                           2   3     3   +-+
+--R                        (2b c x  + 2b x)\|b
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 762
+t0:=x/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 7         5    2 3
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 10
+
+--S 11 of 762
+r0:=(-1)/(b^2*x^2)+1/2/(b*x^2*(b+c*x^2))-2*c*log(x)/b^3+c*log(b+c*x^2)/b^3
+--R 
+--R
+--R   (2)
+--R      2 4         2        2             2 4         2                2    2
+--R   (2c x  + 2b c x )log(c x  + b) + (- 4c x  - 4b c x )log(x) - 2b c x  - b
+--R   -------------------------------------------------------------------------
+--R                                  3   4     4 2
+--R                                2b c x  + 2b x
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 762
+t0:=1/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 8         6    2 4
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 13
+
+--S 14 of 762
+r0:=(-5/6)/(b^2*x^3)+5/2*c/(b^3*x)+1/2/(b*x^3*(b+c*x^2))+_
+     5/2*c^(3/2)*atan(x*sqrt(c)/sqrt(b))/b^(7/2)
+--R 
+--R
+--R                                      +-+
+--R            2 5          3  +-+     x\|c         2 4          2     2  +-+
+--R        (15c x  + 15b c x )\|c atan(-----) + (15c x  + 10b c x  - 2b )\|b
+--R                                      +-+
+--R                                     \|b
+--R   (2)  ------------------------------------------------------------------
+--R                                  3   5     4 3  +-+
+--R                               (6b c x  + 6b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 762
+t0:=1/(x*(b*x^2+c*x^4)^2)
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         2 9         7    2 5
+--R        c x  + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 16
+
+--S 17 of 762
+r0:=(-3/4)/(b^2*x^4)+3/2*c/(b^3*x^2)+1/2/(b*x^4*(b+c*x^2))+_
+     3*c^2*log(x)/b^4-3/2*c^2*log(b+c*x^2)/b^4
+--R 
+--R
+--R   (2)
+--R            3 6       2 4        2            3 6        2 4              2 4
+--R       (- 6c x  - 6b c x )log(c x  + b) + (12c x  + 12b c x )log(x) + 6b c x
+--R     + 
+--R         2   2    3
+--R       3b c x  - b
+--R  /
+--R       4   6     5 4
+--R     4b c x  + 4b x
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 762
+t0:=1/(x^2*(b*x^2+c*x^4)^2)
+--R 
+--R
+--R                   1
+--R   (1)  ----------------------
+--R         2 10         8    2 6
+--R        c x   + 2b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 19
+
+--S 20 of 762
+r0:=(-7/10)/(b^2*x^5)+7/6*c/(b^3*x^3)-7/2*c^2/(b^4*x)+_
+     1/2/(b*x^5*(b+c*x^2))-7/2*c^(5/2)*atan(x*sqrt(c)/sqrt(b))/b^(9/2)
+--R 
+--R
+--R   (2)
+--R                                         +-+
+--R              3 7         2 5  +-+     x\|c
+--R       (- 105c x  - 105b c x )\|c atan(-----)
+--R                                         +-+
+--R                                        \|b
+--R     + 
+--R              3 6        2 4      2   2     3  +-+
+--R       (- 105c x  - 70b c x  + 14b c x  - 6b )\|b
+--R  /
+--R         4   7      5 5  +-+
+--R     (30b c x  + 30b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 762
+t0:=x^14/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       8
+--R                      x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 22
+
+--S 23 of 762
+r0:=-35/8*b*x/c^4+35/24*x^3/c^3-1/4*x^7/(c*(b+c*x^2)^2)-_
+     7/8*x^5/(c^2*(b+c*x^2))+35/8*b^(3/2)*atan(x*sqrt(c)/sqrt(b))/c^(9/2)
+--R 
+--R
+--R   (2)
+--R                                                 +-+
+--R              2 4       2   2       3  +-+     x\|c
+--R       (105b c x  + 210b c x  + 105b )\|b atan(-----)
+--R                                                 +-+
+--R                                                \|b
+--R     + 
+--R          3 7        2 5       2   3       3   +-+
+--R       (8c x  - 56b c x  - 175b c x  - 105b x)\|c
+--R  /
+--R         6 4        5 2      2 4  +-+
+--R     (24c x  + 48b c x  + 24b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 762
+t0:=x^13/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       7
+--R                      x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 25
+
+--S 26 of 762
+r0:=1/2*x^2/c^3+1/4*b^3/(c^4*(b+c*x^2)^2)-3/2*b^2/(c^4*(b+c*x^2))-_
+     3/2*b*log(b+c*x^2)/c^4
+--R 
+--R
+--R   (2)
+--R          2 4      2   2     3        2          3 6       2 4     2   2     3
+--R   (- 6b c x  - 12b c x  - 6b )log(c x  + b) + 2c x  + 4b c x  - 4b c x  - 5b
+--R   ---------------------------------------------------------------------------
+--R                               6 4       5 2     2 4
+--R                             4c x  + 8b c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 762
+t0:=x^12/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       6
+--R                      x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 28
+
+--S 29 of 762
+r0:=15/8*x/c^3-1/4*x^5/(c*(b+c*x^2)^2)-5/8*x^3/(c^2*(b+c*x^2))-_
+     15/8*atan(x*sqrt(c)/sqrt(b))*sqrt(b)/c^(7/2)
+--R 
+--R
+--R   (2)
+--R                                          +-+
+--R         2 4          2      2  +-+     x\|c        2 5          3      2   +-+
+--R   (- 15c x  - 30b c x  - 15b )\|b atan(-----) + (8c x  + 25b c x  + 15b x)\|c
+--R                                          +-+
+--R                                         \|b
+--R   ----------------------------------------------------------------------------
+--R                             5 4        4 2     2 3  +-+
+--R                          (8c x  + 16b c x  + 8b c )\|c
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 762
+t0:=x^11/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       5
+--R                      x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 31
+
+--S 32 of 762
+r0:=-1/4*b^2/(c^3*(b+c*x^2)^2)+b/(c^3*(b+c*x^2))+1/2*log(b+c*x^2)/c^3
+--R 
+--R
+--R           2 4         2     2        2              2     2
+--R        (2c x  + 4b c x  + 2b )log(c x  + b) + 4b c x  + 3b
+--R   (2)  ----------------------------------------------------
+--R                         5 4       4 2     2 3
+--R                       4c x  + 8b c x  + 4b c
+--R                                                    Type: Expression(Integer)
+--E 32
+
+--S 33 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 33
+
+)clear all
+
+--S 34 of 762
+t0:=x^10/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       4
+--R                      x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 34
+
+--S 35 of 762
+r0:=-1/4*x^3/(c*(b+c*x^2)^2)-3/8*x/(c^2*(b+c*x^2))+_
+     3/8*atan(x*sqrt(c)/sqrt(b))/(c^(5/2)*sqrt(b))
+--R 
+--R
+--R                                      +-+
+--R           2 4         2     2      x\|c            3         +-+ +-+
+--R        (3c x  + 6b c x  + 3b )atan(-----) + (- 5c x  - 3b x)\|b \|c
+--R                                      +-+
+--R                                     \|b
+--R   (2)  -------------------------------------------------------------
+--R                         4 4        3 2     2 2  +-+ +-+
+--R                      (8c x  + 16b c x  + 8b c )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 35
+
+--S 36 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 36
+
+)clear all
+
+--S 37 of 762
+t0:=x^9/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       3
+--R                      x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 37
+
+--S 38 of 762
+r0:=1/4*x^4/(b*(b+c*x^2)^2)
+--R 
+--R
+--R                 1  4
+--R                 - x
+--R                 4
+--R   (2)  ---------------------
+--R           2 4     2   2    3
+--R        b c x  + 2b c x  + b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 38
+
+--S 39 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 39
+
+)clear all
+
+--S 40 of 762
+t0:=x^8/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       2
+--R                      x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 40
+
+--S 41 of 762
+r0:=-1/4*x/(c*(b+c*x^2)^2)+1/8*x/(b*c*(b+c*x^2))+_
+     1/8*atan(x*sqrt(c)/sqrt(b))/(b^(3/2)*c^(3/2))
+--R 
+--R
+--R                                    +-+
+--R          2 4         2    2      x\|c         3        +-+ +-+
+--R        (c x  + 2b c x  + b )atan(-----) + (c x  - b x)\|b \|c
+--R                                    +-+
+--R                                   \|b
+--R   (2)  -------------------------------------------------------
+--R                       3 4      2 2 2     3   +-+ +-+
+--R                  (8b c x  + 16b c x  + 8b c)\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 41
+
+--S 42 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 42
+
+)clear all
+
+--S 43 of 762
+t0:=x^7/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 43
+
+--S 44 of 762
+r0:=(-1/4)/(c*(b+c*x^2)^2)
+--R 
+--R
+--R                    1
+--R                    -
+--R                    4
+--R   (2)  - --------------------
+--R           3 4       2 2    2
+--R          c x  + 2b c x  + b c
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 44
+
+--S 45 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 45
+
+)clear all
+
+--S 46 of 762
+t0:=x^6/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      1
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 46
+
+--S 47 of 762
+r0:=1/4*x/(b*(b+c*x^2)^2)+3/8*x/(b^2*(b+c*x^2))+_
+     3/8*atan(x*sqrt(c)/sqrt(b))/(b^(5/2)*sqrt(c))
+--R 
+--R
+--R                                      +-+
+--R           2 4         2     2      x\|c          3         +-+ +-+
+--R        (3c x  + 6b c x  + 3b )atan(-----) + (3c x  + 5b x)\|b \|c
+--R                                      +-+
+--R                                     \|b
+--R   (2)  -----------------------------------------------------------
+--R                        2 2 4      3   2     4  +-+ +-+
+--R                     (8b c x  + 16b c x  + 8b )\|b \|c
+--R                                                    Type: Expression(Integer)
+--E 47
+
+--S 48 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 48
+
+)clear all
+
+--S 49 of 762
+t0:=x^5/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R         3 7       2 5     2   3    3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 49
+
+--S 50 of 762
+r0:=1/4/(b*(b+c*x^2)^2)+1/2/(b^2*(b+c*x^2))+log(x)/b^3-1/2*log(b+c*x^2)/b^3
+--R 
+--R
+--R   (2)
+--R            2 4         2     2        2           2 4         2     2
+--R       (- 2c x  - 4b c x  - 2b )log(c x  + b) + (4c x  + 8b c x  + 4b )log(x)
+--R     + 
+--R             2     2
+--R       2b c x  + 3b
+--R  /
+--R       3 2 4     4   2     5
+--R     4b c x  + 8b c x  + 4b
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 762
+t0:=x^4/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R         3 8       2 6     2   4    3 2
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 52
+
+--S 53 of 762
+r0:=(-15/8)/(b^3*x)+1/4/(b*x*(b+c*x^2)^2)+5/8/(b^2*x*(b+c*x^2))-_
+     15/8*atan(x*sqrt(c)/sqrt(b))*sqrt(c)/b^(7/2)
+--R 
+--R
+--R   (2)
+--R                                               +-+
+--R             2 5          3      2   +-+     x\|c
+--R       (- 15c x  - 30b c x  - 15b x)\|c atan(-----)
+--R                                               +-+
+--R                                              \|b
+--R     + 
+--R             2 4          2     2  +-+
+--R       (- 15c x  - 25b c x  - 8b )\|b
+--R  /
+--R        3 2 5      4   3     5   +-+
+--R     (8b c x  + 16b c x  + 8b x)\|b
+--R                                                    Type: Expression(Integer)
+--E 53
+
+--S 54 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 54
+
+)clear all
+
+--S 55 of 762
+t0:=x^3/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R         3 9       2 7     2   5    3 3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 55
+
+--S 56 of 762
+r0:=(-3/2)/(b^3*x^2)+1/4/(b*x^2*(b+c*x^2)^2)+3/4/(b^2*x^2*(b+c*x^2))-_
+     3*c*log(x)/b^4+3/2*c*log(b+c*x^2)/b^4
+--R 
+--R
+--R   (2)
+--R          3 6        2 4     2   2        2
+--R       (6c x  + 12b c x  + 6b c x )log(c x  + b)
+--R     + 
+--R             3 6        2 4      2   2              2 4     2   2     3
+--R       (- 12c x  - 24b c x  - 12b c x )log(x) - 6b c x  - 9b c x  - 2b
+--R  /
+--R       4 2 6     5   4     6 2
+--R     4b c x  + 8b c x  + 4b x
+--R                                                    Type: Expression(Integer)
+--E 56
+
+--S 57 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 57
+
+)clear all
+
+--S 58 of 762
+t0:=x^2/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R         3 10       2 8     2   6    3 4
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 58
+
+--S 59 of 762
+r0:=(-35/24)/(b^3*x^3)+35/8*c/(b^4*x)+1/4/(b*x^3*(b+c*x^2)^2)+_
+     7/8/(b^2*x^3*(b+c*x^2))+35/8*c^(3/2)*atan(x*sqrt(c)/sqrt(b))/b^(9/2)
+--R 
+--R
+--R   (2)
+--R                                                   +-+
+--R            3 7         2 5       2   3  +-+     x\|c
+--R       (105c x  + 210b c x  + 105b c x )\|c atan(-----)
+--R                                                   +-+
+--R                                                  \|b
+--R     + 
+--R            3 6         2 4      2   2     3  +-+
+--R       (105c x  + 175b c x  + 56b c x  - 8b )\|b
+--R  /
+--R         4 2 7      5   5      6 3  +-+
+--R     (24b c x  + 48b c x  + 24b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 59
+
+--S 60 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 60
+
+)clear all
+
+--S 61 of 762
+t0:=x/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                        1
+--R   (1)  --------------------------------
+--R         3 11       2 9     2   7    3 5
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 61
+
+--S 62 of 762
+r0:=(-3/2)/(b^3*x^4)+3*c/(b^4*x^2)+1/4/(b*x^4*(b+c*x^2)^2)+_
+     1/(b^2*x^4*(b+c*x^2))+6*c^2*log(x)/b^5-3*c^2*log(b+c*x^2)/b^5
+--R 
+--R
+--R   (2)
+--R             4 8        3 6      2 2 4        2
+--R       (- 12c x  - 24b c x  - 12b c x )log(c x  + b)
+--R     + 
+--R         4 8        3 6      2 2 4               3 6      2 2 4     3   2    4
+--R     (24c x  + 48b c x  + 24b c x )log(x) + 12b c x  + 18b c x  + 4b c x  - b
+--R  /
+--R       5 2 8     6   6     7 4
+--R     4b c x  + 8b c x  + 4b x
+--R                                                    Type: Expression(Integer)
+--E 62
+
+--S 63 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 63
+
+)clear all
+
+--S 64 of 762
+t0:=1/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R         3 12       2 10     2   8    3 6
+--R        c x   + 3b c x   + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 64
+
+--S 65 of 762
+r0:=(-63/40)/(b^3*x^5)+21/8*c/(b^4*x^3)-63/8*c^2/(b^5*x)+_
+     1/4/(b*x^5*(b+c*x^2)^2)+9/8/(b^2*x^5*(b+c*x^2))-_
+     63/8*c^(5/2)*atan(x*sqrt(c)/sqrt(b))/b^(11/2)
+--R 
+--R
+--R   (2)
+--R                                                     +-+
+--R              4 9         3 7       2 2 5  +-+     x\|c
+--R       (- 315c x  - 630b c x  - 315b c x )\|c atan(-----)
+--R                                                     +-+
+--R                                                    \|b
+--R     + 
+--R              4 8         3 6       2 2 4      3   2     4  +-+
+--R       (- 315c x  - 525b c x  - 168b c x  + 24b c x  - 8b )\|b
+--R  /
+--R         5 2 9      6   7      7 5  +-+
+--R     (40b c x  + 80b c x  + 40b x )\|b
+--R                                                    Type: Expression(Integer)
+--E 65
+
+--S 66 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 66
+
+)clear all
+
+--S 67 of 762
+t0:=1/(x*(b*x^2+c*x^4)^3)
+--R 
+--R
+--R                        1
+--R   (1)  ---------------------------------
+--R         3 13       2 11     2   9    3 7
+--R        c x   + 3b c x   + 3b c x  + b x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 67
+
+--S 68 of 762
+r0:=(-5/3)/(b^3*x^6)+5/2*c/(b^4*x^4)-5*c^2/(b^5*x^2)+_
+     1/4/(b*x^6*(b+c*x^2)^2)+5/4/(b^2*x^6*(b+c*x^2))-_
+     10*c^3*log(x)/b^6+5*c^3*log(b+c*x^2)/b^6
+--R 
+--R
+--R   (2)
+--R           5 10         4 8      2 3 6        2
+--R       (60c x   + 120b c x  + 60b c x )log(c x  + b)
+--R     + 
+--R              5 10         4 8       2 3 6               4 8      2 3 6
+--R       (- 120c x   - 240b c x  - 120b c x )log(x) - 60b c x  - 90b c x
+--R     + 
+--R            3 2 4     4   2     5
+--R       - 20b c x  + 5b c x  - 2b
+--R  /
+--R        6 2 10      7   8      8 6
+--R     12b c x   + 24b c x  + 12b x
+--R                                                    Type: Expression(Integer)
+--E 68
+
+--S 69 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 69
+
+)clear all
+
+--S 70 of 762
+t0:=x^5*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R           +-----------+
+--R         5 |   4      2
+--R   (1)  x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 762
+r0:=-5/128*b^4*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(7/2)+_
+     5/128*b^3*sqrt(b*x^2+c*x^4)/c^3-5/192*b^2*x^2*_
+     sqrt(b*x^2+c*x^4)/c^2+1/48*b*x^4*sqrt(b*x^2+c*x^4)/c+_
+     1/8*x^6*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R   (2)
+--R                        2 +-+
+--R            4          x \|c
+--R       - 15b atanh(--------------)
+--R                    +-----------+
+--R                    |   4      2
+--R                   \|c x  + b x
+--R     + 
+--R                                                +-----------+
+--R           3 6       2 4      2   2      3  +-+ |   4      2
+--R       (48c x  + 8b c x  - 10b c x  + 15b )\|c \|c x  + b x
+--R  /
+--R         3 +-+
+--R     384c \|c
+--R                                                    Type: Expression(Integer)
+--E 71
+
+--S 72 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 72
+
+)clear all
+
+--S 73 of 762
+t0:=x^3*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R           +-----------+
+--R         3 |   4      2
+--R   (1)  x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 762
+r0:=1/16*b^3*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(5/2)-1/16*b^2*_
+     sqrt(b*x^2+c*x^4)/c^2+1/24*b*x^2*sqrt(b*x^2+c*x^4)/c+1/6*x^4*_
+     sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      2 +-+                                    +-----------+
+--R          3          x \|c            2 4         2     2  +-+ |   4      2
+--R        3b atanh(--------------) + (8c x  + 2b c x  - 3b )\|c \|c x  + b x
+--R                  +-----------+
+--R                  |   4      2
+--R                 \|c x  + b x
+--R   (2)  --------------------------------------------------------------------
+--R                                         2 +-+
+--R                                      48c \|c
+--R                                                    Type: Expression(Integer)
+--E 74
+
+--S 75 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 75
+
+)clear all
+
+--S 76 of 762
+t0:=x*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R          +-----------+
+--R          |   4      2
+--R   (1)  x\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 762
+r0:=-1/8*b^2*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)+_
+     1/8*b*sqrt(b*x^2+c*x^4)/c+1/4*x^2*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                       2 +-+                        +-----------+
+--R           2          x \|c              2      +-+ |   4      2
+--R        - b atanh(--------------) + (2c x  + b)\|c \|c x  + b x
+--R                   +-----------+
+--R                   |   4      2
+--R                  \|c x  + b x
+--R   (2)  ---------------------------------------------------------
+--R                                     +-+
+--R                                  8c\|c
+--R                                                    Type: Expression(Integer)
+--E 77
+
+--S 78 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 78
+
+)clear all
+
+--S 79 of 762
+t0:=sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               x
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 762
+r0:=1/2*b*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/sqrt(c)+1/2*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                     2 +-+             +-----------+
+--R                    x \|c          +-+ |   4      2
+--R        b atanh(--------------) + \|c \|c x  + b x
+--R                 +-----------+
+--R                 |   4      2
+--R                \|c x  + b x
+--R   (2)  --------------------------------------------
+--R                              +-+
+--R                            2\|c
+--R                                                    Type: Expression(Integer)
+--E 80
+
+--S 81 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 81
+
+)clear all
+
+--S 82 of 762
+t0:=sqrt(b*x^2+c*x^4)/x^3
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               3
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 762
+r0:=atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))*sqrt(c)-sqrt(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R                         2 +-+         +-----------+
+--R         2 +-+          x \|c          |   4      2
+--R        x \|c atanh(--------------) - \|c x  + b x
+--R                     +-----------+
+--R                     |   4      2
+--R                    \|c x  + b x
+--R   (2)  --------------------------------------------
+--R                              2
+--R                             x
+--R                                                    Type: Expression(Integer)
+--E 83
+
+--S 84 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 84
+
+)clear all
+
+--S 85 of 762
+t0:=sqrt(b*x^2+c*x^4)/x^5
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               5
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 762
+r0:=-1/3*(b*x^2+c*x^4)^(3/2)/(b*x^6)
+--R 
+--R
+--R                     +-----------+
+--R              2      |   4      2
+--R        (- c x  - b)\|c x  + b x
+--R   (2)  --------------------------
+--R                       4
+--R                   3b x
+--R                                                    Type: Expression(Integer)
+--E 86
+
+--S 87 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 87
+
+)clear all
+
+--S 88 of 762
+t0:=sqrt(b*x^2+c*x^4)/x^7
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               7
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 762
+r0:=-1/5*(b*x^2+c*x^4)^(3/2)/(b*x^8)+2/15*c*(b*x^2+c*x^4)^(3/2)/(b^2*x^6)
+--R 
+--R
+--R                               +-----------+
+--R           2 4        2     2  |   4      2
+--R        (2c x  - b c x  - 3b )\|c x  + b x
+--R   (2)  ------------------------------------
+--R                          2 6
+--R                       15b x
+--R                                                    Type: Expression(Integer)
+--E 89
+
+--S 90 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 90
+
+)clear all
+
+--S 91 of 762
+t0:=sqrt(b*x^2+c*x^4)/x^9
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               9
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 762
+r0:=-1/7*(b*x^2+c*x^4)^(3/2)/(b*x^10)+4/35*c*(b*x^2+c*x^4)^(3/2)/(b^2*x^8)-_
+     8/105*c^2*(b*x^2+c*x^4)^(3/2)/(b^3*x^6)
+--R 
+--R
+--R                                             +-----------+
+--R             3 6       2 4     2   2      3  |   4      2
+--R        (- 8c x  + 4b c x  - 3b c x  - 15b )\|c x  + b x
+--R   (2)  --------------------------------------------------
+--R                                  3 8
+--R                              105b x
+--R                                                    Type: Expression(Integer)
+--E 92
+
+--S 93 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 93
+
+)clear all
+
+--S 94 of 762
+t0:=sqrt(b*x^2+c*x^4)/x^11
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               11
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 762
+r0:=-1/9*(b*x^2+c*x^4)^(3/2)/(b*x^12)+2/21*c*(b*x^2+c*x^4)^(3/2)/(b^2*x^10)-_
+     8/105*c^2*(b*x^2+c*x^4)^(3/2)/(b^3*x^8)+_
+     16/315*c^3*(b*x^2+c*x^4)^(3/2)/(b^4*x^6)
+--R 
+--R
+--R                                                      +-----------+
+--R            4 8       3 6     2 2 4     3   2      4  |   4      2
+--R        (16c x  - 8b c x  + 6b c x  - 5b c x  - 35b )\|c x  + b x
+--R   (2)  -----------------------------------------------------------
+--R                                      4 10
+--R                                  315b x
+--R                                                    Type: Expression(Integer)
+--E 95
+
+--S 96 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 96
+
+)clear all
+
+--S 97 of 762
+t0:=sqrt(b*x^2+c*x^4)/x^13
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               13
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 762
+r0:=-1/11*(b*x^2+c*x^4)^(3/2)/(b*x^14)+8/99*c*(b*x^2+c*x^4)^(3/2)/_
+     (b^2*x^12)-16/231*c^2*(b*x^2+c*x^4)^(3/2)/(b^3*x^10)+_
+     64/1155*c^3*(b*x^2+c*x^4)^(3/2)/(b^4*x^8)-_
+     128/3465*c^4*(b*x^2+c*x^4)^(3/2)/(b^5*x^6)
+--R 
+--R
+--R   (2)
+--R              5 10        4 8      2 3 6      3 2 4      4   2       5
+--R       (- 128c x   + 64b c x  - 48b c x  + 40b c x  - 35b c x  - 315b )
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R          5 12
+--R     3465b x
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 762
+t0:=x^4*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R           +-----------+
+--R         4 |   4      2
+--R   (1)  x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 762
+r0:=8/105*b^2*(b*x^2+c*x^4)^(3/2)/(c^3*x^3)-4/35*b*(b*x^2+c*x^4)^(3/2)/_
+     (c^2*x)+1/7*x*(b*x^2+c*x^4)^(3/2)/c
+--R 
+--R
+--R                                           +-----------+
+--R            3 6       2 4     2   2     3  |   4      2
+--R        (15c x  + 3b c x  - 4b c x  + 8b )\|c x  + b x
+--R   (2)  ------------------------------------------------
+--R                                 3
+--R                             105c x
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 762
+t0:=x^2*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R           +-----------+
+--R         2 |   4      2
+--R   (1)  x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 762
+r0:=-2/15*b*(b*x^2+c*x^4)^(3/2)/(c^2*x^3)+1/5*(b*x^2+c*x^4)^(3/2)/(c*x)
+--R 
+--R
+--R                               +-----------+
+--R           2 4        2     2  |   4      2
+--R        (3c x  + b c x  - 2b )\|c x  + b x
+--R   (2)  ------------------------------------
+--R                           2
+--R                        15c x
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 762
+t0:=sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R   (1)  \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 762
+r0:=1/3*(b*x^2+c*x^4)^(3/2)/(c*x^3)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (2)  ------------------------
+--R                  3c x
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 762
+t0:=sqrt(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               2
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 762
+r0:=-atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))*sqrt(b)+sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R                            +-+         +-----------+
+--R            +-+           x\|b          |   4      2
+--R        - x\|b atanh(--------------) + \|c x  + b x
+--R                      +-----------+
+--R                      |   4      2
+--R                     \|c x  + b x
+--R   (2)  ---------------------------------------------
+--R                              x
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 762
+t0:=sqrt(b*x^2+c*x^4)/x^4
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               4
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 762
+r0:=-1/2*c*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/sqrt(b)-_
+     1/2*sqrt(b*x^2+c*x^4)/x^3
+--R 
+--R
+--R                           +-+             +-----------+
+--R             3           x\|b          +-+ |   4      2
+--R        - c x atanh(--------------) - \|b \|c x  + b x
+--R                     +-----------+
+--R                     |   4      2
+--R                    \|c x  + b x
+--R   (2)  ------------------------------------------------
+--R                               3 +-+
+--R                             2x \|b
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 762
+t0:=sqrt(b*x^2+c*x^4)/x^6
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               6
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 762
+r0:=-1/4*(b*x^2+c*x^4)^(3/2)/(b*x^7)+1/8*c^2*atanh(x*sqrt(b)/_
+     sqrt(b*x^2+c*x^4))/b^(3/2)+1/8*c*sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R                         +-+                          +-----------+
+--R         2 5           x\|b               2       +-+ |   4      2
+--R        c x atanh(--------------) + (- c x  - 2b)\|b \|c x  + b x
+--R                   +-----------+
+--R                   |   4      2
+--R                  \|c x  + b x
+--R   (2)  -----------------------------------------------------------
+--R                                     5 +-+
+--R                                 8b x \|b
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 762
+t0:=sqrt(b*x^2+c*x^4)/x^8
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               8
+--R              x
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 762
+r0:=-1/6*(b*x^2+c*x^4)^(3/2)/(b*x^9)+1/8*c*(b*x^2+c*x^4)^(3/2)/(b^2*x^7)-_
+     1/16*c^3*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)-_
+     1/16*c^2*sqrt(b*x^2+c*x^4)/(b^2*x^3)
+--R 
+--R
+--R   (2)
+--R                       +-+                                    +-----------+
+--R       3 7           x\|b            2 4         2     2  +-+ |   4      2
+--R   - 3c x atanh(--------------) + (3c x  - 2b c x  - 8b )\|b \|c x  + b x
+--R                 +-----------+
+--R                 |   4      2
+--R                \|c x  + b x
+--R   ------------------------------------------------------------------------
+--R                                     2 7 +-+
+--R                                  48b x \|b
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 762
+t0:=x^3*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R            7      5  |   4      2
+--R   (1)  (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 762
+r0:=1/10*x^4*(b*x^2+c*x^4)^(3/2)-3/256*b^5*atanh(x^2*sqrt(c)/_
+     sqrt(b*x^2+c*x^4))/c^(7/2)+3/256*b^4*sqrt(b*x^2+c*x^4)/c^3-_
+     1/128*b^3*x^2*sqrt(b*x^2+c*x^4)/c^2+1/160*b^2*x^4*_
+     sqrt(b*x^2+c*x^4)/c+3/80*b*x^6*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R   (2)
+--R                        2 +-+
+--R            5          x \|c
+--R       - 15b atanh(--------------)
+--R                    +-----------+
+--R                    |   4      2
+--R                   \|c x  + b x
+--R     + 
+--R                                                             +-----------+
+--R            4 8         3 6     2 2 4      3   2      4  +-+ |   4      2
+--R       (128c x  + 176b c x  + 8b c x  - 10b c x  + 15b )\|c \|c x  + b x
+--R  /
+--R          3 +-+
+--R     1280c \|c
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 762
+t0:=x*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R            5      3  |   4      2
+--R   (1)  (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 762
+r0:=1/8*x^2*(b*x^2+c*x^4)^(3/2)+3/128*b^4*atanh(x^2*sqrt(c)/_
+     sqrt(b*x^2+c*x^4))/c^(5/2)-3/128*b^3*sqrt(b*x^2+c*x^4)/c^2+_
+     1/64*b^2*x^2*sqrt(b*x^2+c*x^4)/c+1/16*b*x^4*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R   (2)
+--R                     2 +-+
+--R         4          x \|c
+--R       3b atanh(--------------)
+--R                 +-----------+
+--R                 |   4      2
+--R                \|c x  + b x
+--R     + 
+--R                                               +-----------+
+--R           3 6        2 4     2   2     3  +-+ |   4      2
+--R       (16c x  + 24b c x  + 2b c x  - 3b )\|c \|c x  + b x
+--R  /
+--R         2 +-+
+--R     128c \|c
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x
+--R 
+--R
+--R                     +-----------+
+--R            3        |   4      2
+--R   (1)  (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 127
+
+--S 128 of 762
+r0:=1/6*(b*x^2+c*x^4)^(3/2)-1/16*b^3*atanh(x^2*sqrt(c)/sqrt(b*x^2+_
+     c*x^4))/c^(3/2)+1/16*b^2*sqrt(b*x^2+c*x^4)/c+1/8*b*x^2*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R   (2)
+--R                   2 +-+                                     +-----------+
+--R       3          x \|c            2 4          2     2  +-+ |   4      2
+--R   - 3b atanh(--------------) + (8c x  + 14b c x  + 3b )\|c \|c x  + b x
+--R               +-----------+
+--R               |   4      2
+--R              \|c x  + b x
+--R   -----------------------------------------------------------------------
+--R                                       +-+
+--R                                   48c\|c
+--R                                                    Type: Expression(Integer)
+--E 128
+
+--S 129 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 129
+
+)clear all
+
+--S 130 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^3
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    x
+--R                                                    Type: Expression(Integer)
+--E 130
+
+--S 131 of 762
+r0:=1/4*(b*x^2+c*x^4)^(3/2)/x^2+3/8*b^2*atanh(x^2*sqrt(c)/_
+     sqrt(b*x^2+c*x^4))/sqrt(c)+3/8*b*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                      2 +-+                         +-----------+
+--R          2          x \|c              2       +-+ |   4      2
+--R        3b atanh(--------------) + (2c x  + 5b)\|c \|c x  + b x
+--R                  +-----------+
+--R                  |   4      2
+--R                 \|c x  + b x
+--R   (2)  ---------------------------------------------------------
+--R                                    +-+
+--R                                  8\|c
+--R                                                    Type: Expression(Integer)
+--E 131
+
+--S 132 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 132
+
+)clear all
+
+--S 133 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^5
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    3
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 133
+
+--S 134 of 762
+r0:=-(b*x^2+c*x^4)^(3/2)/x^4+3/2*b*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))*_
+     sqrt(c)+3/2*c*sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R                            2 +-+                    +-----------+
+--R            2 +-+          x \|c             2       |   4      2
+--R        3b x \|c atanh(--------------) + (c x  - 2b)\|c x  + b x
+--R                        +-----------+
+--R                        |   4      2
+--R                       \|c x  + b x
+--R   (2)  ----------------------------------------------------------
+--R                                      2
+--R                                    2x
+--R                                                    Type: Expression(Integer)
+--E 134
+
+--S 135 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 135
+
+)clear all
+
+--S 136 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^7
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    5
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 762
+r0:=-1/3*(b*x^2+c*x^4)^(3/2)/x^6+c^(3/2)*atanh(x^2*sqrt(c)/_
+     sqrt(b*x^2+c*x^4))-c*sqrt(b*x^2+c*x^4)/x^2
+--R 
+--R
+--R                            2 +-+                      +-----------+
+--R            4 +-+          x \|c                2      |   4      2
+--R        3c x \|c atanh(--------------) + (- 4c x  - b)\|c x  + b x
+--R                        +-----------+
+--R                        |   4      2
+--R                       \|c x  + b x
+--R   (2)  ------------------------------------------------------------
+--R                                       4
+--R                                     3x
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^9
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    7
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 139
+
+--S 140 of 762
+r0:=-1/5*(b*x^2+c*x^4)^(5/2)/(b*x^10)
+--R 
+--R
+--R                                +-----------+
+--R            2 4         2    2  |   4      2
+--R        (- c x  - 2b c x  - b )\|c x  + b x
+--R   (2)  -------------------------------------
+--R                            6
+--R                        5b x
+--R                                                    Type: Expression(Integer)
+--E 140
+
+--S 141 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 141
+
+)clear all
+
+--S 142 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^11
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    9
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 142
+
+--S 143 of 762
+r0:=-1/7*(b*x^2+c*x^4)^(5/2)/(b*x^12)+2/35*c*(b*x^2+c*x^4)^(5/2)/(b^2*x^10)
+--R 
+--R
+--R                                         +-----------+
+--R           3 6      2 4     2   2     3  |   4      2
+--R        (2c x  - b c x  - 8b c x  - 5b )\|c x  + b x
+--R   (2)  ----------------------------------------------
+--R                               2 8
+--R                            35b x
+--R                                                    Type: Expression(Integer)
+--E 143
+
+--S 144 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 144
+
+)clear all
+
+--S 145 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^13
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    11
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 145
+
+--S 146 of 762
+r0:=-1/9*(b*x^2+c*x^4)^(5/2)/(b*x^14)+4/63*c*(b*x^2+c*x^4)^(5/2)/_
+     (b^2*x^12)-8/315*c^2*(b*x^2+c*x^4)^(5/2)/(b^3*x^10)
+--R 
+--R
+--R                                                        +-----------+
+--R             4 8       3 6     2 2 4      3   2      4  |   4      2
+--R        (- 8c x  + 4b c x  - 3b c x  - 50b c x  - 35b )\|c x  + b x
+--R   (2)  -------------------------------------------------------------
+--R                                       3 10
+--R                                   315b x
+--R                                                    Type: Expression(Integer)
+--E 146
+
+--S 147 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 147
+
+)clear all
+
+--S 148 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^15
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    13
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 762
+r0:=-1/11*(b*x^2+c*x^4)^(5/2)/(b*x^16)+2/33*c*(b*x^2+c*x^4)^(5/2)/_
+     (b^2*x^14)-8/231*c^2*(b*x^2+c*x^4)^(5/2)/(b^3*x^12)+_
+     16/1155*c^3*(b*x^2+c*x^4)^(5/2)/(b^4*x^10)
+--R 
+--R
+--R   (2)
+--R                                                               +-----------+
+--R       5 10       4 8     2 3 6     3 2 4       4   2       5  |   4      2
+--R   (16c x   - 8b c x  + 6b c x  - 5b c x  - 140b c x  - 105b )\|c x  + b x
+--R   -------------------------------------------------------------------------
+--R                                        4 12
+--R                                   1155b x
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^17
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    15
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 762
+r0:=-1/13*(b*x^2+c*x^4)^(5/2)/(b*x^18)+8/143*c*(b*x^2+c*x^4)^(5/2)/_
+     (b^2*x^16)-16/429*c^2*(b*x^2+c*x^4)^(5/2)/(b^3*x^14)+_
+     64/3003*c^3*(b*x^2+c*x^4)^(5/2)/(b^4*x^12)-_
+     128/15015*c^4*(b*x^2+c*x^4)^(5/2)/(b^5*x^10)
+--R 
+--R
+--R   (2)
+--R               6 12        5 10      2 4 8      3 3 6      4 2 4        5   2
+--R         - 128c x   + 64b c x   - 48b c x  + 40b c x  - 35b c x  - 1470b c x
+--R       + 
+--R                6
+--R         - 1155b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R           5 14
+--R     15015b x
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 762
+t0:=x^6*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                       +-----------+
+--R            10      8  |   4      2
+--R   (1)  (c x   + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 762
+r0:=128/15015*b^4*(b*x^2+c*x^4)^(5/2)/(c^5*x^5)-64/3003*b^3*_
+     (b*x^2+c*x^4)^(5/2)/(c^4*x^3)+16/429*b^2*(b*x^2+c*x^4)^(5/2)/_
+     (c^3*x)-8/143*b*x*(b*x^2+c*x^4)^(5/2)/c^2+1/13*x^3*(b*x^2+c*x^4)^(5/2)/c
+--R 
+--R
+--R   (2)
+--R              6 12          5 10      2 4 8      3 3 6      4 2 4      5   2
+--R         1155c x   + 1470b c x   + 35b c x  - 40b c x  + 48b c x  - 64b c x
+--R       + 
+--R             6
+--R         128b
+--R    *
+--R        +-----------+
+--R        |   4      2
+--R       \|c x  + b x
+--R  /
+--R           5
+--R     15015c x
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 762
+t0:=x^4*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R            8      6  |   4      2
+--R   (1)  (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 762
+r0:=-16/1155*b^3*(b*x^2+c*x^4)^(5/2)/(c^4*x^5)+8/231*b^2*_
+     (b*x^2+c*x^4)^(5/2)/(c^3*x^3)-2/33*b*(b*x^2+c*x^4)^(5/2)/_
+     (c^2*x)+1/11*x*(b*x^2+c*x^4)^(5/2)/c
+--R 
+--R
+--R   (2)
+--R                                                               +-----------+
+--R        5 10         4 8     2 3 6     3 2 4     4   2      5  |   4      2
+--R   (105c x   + 140b c x  + 5b c x  - 6b c x  + 8b c x  - 16b )\|c x  + b x
+--R   -------------------------------------------------------------------------
+--R                                         4
+--R                                    1155c x
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 762
+t0:=x^2*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R            6      4  |   4      2
+--R   (1)  (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 160
+
+--S 161 of 762
+r0:=8/315*b^2*(b*x^2+c*x^4)^(5/2)/(c^3*x^5)-4/63*b*(b*x^2+c*x^4)^(5/2)/_
+     (c^2*x^3)+1/9*(b*x^2+c*x^4)^(5/2)/(c*x)
+--R 
+--R
+--R                                                      +-----------+
+--R            4 8        3 6     2 2 4     3   2     4  |   4      2
+--R        (35c x  + 50b c x  + 3b c x  - 4b c x  + 8b )\|c x  + b x
+--R   (2)  -----------------------------------------------------------
+--R                                       3
+--R                                   315c x
+--R                                                    Type: Expression(Integer)
+--E 161
+
+--S 162 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 162
+
+)clear all
+
+--S 163 of 762
+t0:=(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R            4      2  |   4      2
+--R   (1)  (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 163
+
+--S 164 of 762
+r0:=-2/35*b*(b*x^2+c*x^4)^(5/2)/(c^2*x^5)+1/7*(b*x^2+c*x^4)^(5/2)/(c*x^3)
+--R 
+--R
+--R                                         +-----------+
+--R           3 6       2 4    2   2     3  |   4      2
+--R        (5c x  + 8b c x  + b c x  - 2b )\|c x  + b x
+--R   (2)  ----------------------------------------------
+--R                                2
+--R                             35c x
+--R                                                    Type: Expression(Integer)
+--E 164
+
+--S 165 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 165
+
+)clear all
+
+--S 166 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^2
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R   (1)  (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 166
+
+--S 167 of 762
+r0:=1/5*(b*x^2+c*x^4)^(5/2)/(c*x^5)
+--R 
+--R
+--R                              +-----------+
+--R          2 4         2    2  |   4      2
+--R        (c x  + 2b c x  + b )\|c x  + b x
+--R   (2)  -----------------------------------
+--R                        5c x
+--R                                                    Type: Expression(Integer)
+--E 167
+
+--S 168 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 168
+
+)clear all
+
+--S 169 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^4
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    2
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 169
+
+--S 170 of 762
+r0:=1/3*(b*x^2+c*x^4)^(3/2)/x^3-b^(3/2)*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))+_
+     b*sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R                               +-+                    +-----------+
+--R               +-+           x\|b             2       |   4      2
+--R        - 3b x\|b atanh(--------------) + (c x  + 4b)\|c x  + b x
+--R                         +-----------+
+--R                         |   4      2
+--R                        \|c x  + b x
+--R   (2)  -----------------------------------------------------------
+--R                                     3x
+--R                                                    Type: Expression(Integer)
+--E 170
+
+--S 171 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 171
+
+)clear all
+
+--S 172 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^6
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    4
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 172
+
+--S 173 of 762
+r0:=-1/2*(b*x^2+c*x^4)^(3/2)/x^5-3/2*c*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))*_
+     sqrt(b)+3/2*c*sqrt(b*x^2+c*x^4)/x
+--R 
+--R
+--R                                +-+                    +-----------+
+--R              3 +-+           x\|b              2      |   4      2
+--R        - 3c x \|b atanh(--------------) + (2c x  - b)\|c x  + b x
+--R                          +-----------+
+--R                          |   4      2
+--R                         \|c x  + b x
+--R   (2)  ------------------------------------------------------------
+--R                                       3
+--R                                     2x
+--R                                                    Type: Expression(Integer)
+--E 173
+
+--S 174 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 174
+
+)clear all
+
+--S 175 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^8
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    6
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 175
+
+--S 176 of 762
+r0:=-1/4*(b*x^2+c*x^4)^(3/2)/x^7-3/8*c^2*atanh(x*sqrt(b)/_
+     sqrt(b*x^2+c*x^4))/sqrt(b)-3/8*c*sqrt(b*x^2+c*x^4)/x^3
+--R 
+--R
+--R                            +-+                           +-----------+
+--R            2 5           x\|b                2       +-+ |   4      2
+--R        - 3c x atanh(--------------) + (- 5c x  - 2b)\|b \|c x  + b x
+--R                      +-----------+
+--R                      |   4      2
+--R                     \|c x  + b x
+--R   (2)  ---------------------------------------------------------------
+--R                                      5 +-+
+--R                                    8x \|b
+--R                                                    Type: Expression(Integer)
+--E 176
+
+--S 177 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 177
+
+)clear all
+
+--S 178 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^10
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    8
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 762
+r0:=1/24*c*(b*x^2+c*x^4)^(3/2)/(b*x^7)-1/6*(b*x^2+c*x^4)^(5/2)/_
+     (b*x^11)+1/16*c^3*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)+_
+     1/16*c^2*sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R   (2)
+--R                     +-+                                       +-----------+
+--R     3 7           x\|b              2 4          2     2  +-+ |   4      2
+--R   3c x atanh(--------------) + (- 3c x  - 14b c x  - 8b )\|b \|c x  + b x
+--R               +-----------+
+--R               |   4      2
+--R              \|c x  + b x
+--R   -------------------------------------------------------------------------
+--R                                        7 +-+
+--R                                   48b x \|b
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^12
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    10
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 762
+r0:=-1/64*c^2*(b*x^2+c*x^4)^(3/2)/(b^2*x^7)-1/8*(b*x^2+c*x^4)^(5/2)/_
+     (b*x^13)+1/16*c*(b*x^2+c*x^4)^(5/2)/(b^2*x^11)-3/128*c^4*_
+     atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)-3/128*c^3*_
+     sqrt(b*x^2+c*x^4)/(b^2*x^3)
+--R 
+--R
+--R   (2)
+--R                           +-+
+--R           4 9           x\|b
+--R       - 3c x atanh(--------------)
+--R                     +-----------+
+--R                     |   4      2
+--R                    \|c x  + b x
+--R     + 
+--R                                               +-----------+
+--R          3 6       2 4      2   2      3  +-+ |   4      2
+--R       (3c x  - 2b c x  - 24b c x  - 16b )\|b \|c x  + b x
+--R  /
+--R         2 9 +-+
+--R     128b x \|b
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^14
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    12
+--R                   x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 762
+r0:=1/128*c^3*(b*x^2+c*x^4)^(3/2)/(b^3*x^7)-1/10*(b*x^2+c*x^4)^(5/2)/_
+     (b*x^15)+1/16*c*(b*x^2+c*x^4)^(5/2)/(b^2*x^13)-1/32*c^2*(b*x^2+_
+     c*x^4)^(5/2)/(b^3*x^11)+3/256*c^5*atanh(x*sqrt(b)/sqrt(b*x^2+_
+     c*x^4))/b^(7/2)+3/256*c^4*sqrt(b*x^2+c*x^4)/(b^3*x^3)
+--R 
+--R
+--R   (2)
+--R                           +-+
+--R          5 11           x\|b
+--R       15c x  atanh(--------------)
+--R                     +-----------+
+--R                     |   4      2
+--R                    \|c x  + b x
+--R     + 
+--R                                                               +-----------+
+--R             4 8        3 6     2 2 4       3   2       4  +-+ |   4      2
+--R       (- 15c x  + 10b c x  - 8b c x  - 176b c x  - 128b )\|b \|c x  + b x
+--R  /
+--R          3 11 +-+
+--R     1280b x  \|b
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 762
+t0:=x^7/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R               7
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 762
+r0:=-5/16*b^3*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(7/2)+5/16*b^2*_
+     sqrt(b*x^2+c*x^4)/c^3-5/24*b*x^2*sqrt(b*x^2+c*x^4)/c^2+1/6*x^4*_
+     sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R   (2)
+--R                    2 +-+                                      +-----------+
+--R        3          x \|c            2 4          2      2  +-+ |   4      2
+--R   - 15b atanh(--------------) + (8c x  - 10b c x  + 15b )\|c \|c x  + b x
+--R                +-----------+
+--R                |   4      2
+--R               \|c x  + b x
+--R   -------------------------------------------------------------------------
+--R                                       3 +-+
+--R                                    48c \|c
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 762
+t0:=x^5/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R               5
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 762
+r0:=3/8*b^2*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(5/2)-_
+     3/8*b*sqrt(b*x^2+c*x^4)/c^2+1/4*x^2*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                      2 +-+                         +-----------+
+--R          2          x \|c              2       +-+ |   4      2
+--R        3b atanh(--------------) + (2c x  - 3b)\|c \|c x  + b x
+--R                  +-----------+
+--R                  |   4      2
+--R                 \|c x  + b x
+--R   (2)  ---------------------------------------------------------
+--R                                   2 +-+
+--R                                 8c \|c
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 762
+t0:=x^3/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 762
+r0:=-1/2*b*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)+_
+     1/2*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                       2 +-+             +-----------+
+--R                      x \|c          +-+ |   4      2
+--R        - b atanh(--------------) + \|c \|c x  + b x
+--R                   +-----------+
+--R                   |   4      2
+--R                  \|c x  + b x
+--R   (2)  ----------------------------------------------
+--R                               +-+
+--R                            2c\|c
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 762
+t0:=x/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 762
+r0:=atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/sqrt(c)
+--R 
+--R
+--R                   2 +-+
+--R                  x \|c
+--R        atanh(--------------)
+--R               +-----------+
+--R               |   4      2
+--R              \|c x  + b x
+--R   (2)  ---------------------
+--R                  +-+
+--R                 \|c
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 762
+t0:=1/(x*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          +-----------+
+--R          |   4      2
+--R        x\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 762
+r0:=-sqrt(b*x^2+c*x^4)/(b*x^2)
+--R 
+--R
+--R           +-----------+
+--R           |   4      2
+--R          \|c x  + b x
+--R   (2)  - --------------
+--R                  2
+--R               b x
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 762
+t0:=1/(x^3*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         3 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 762
+r0:=-1/3*sqrt(b*x^2+c*x^4)/(b*x^4)+2/3*c*sqrt(b*x^2+c*x^4)/(b^2*x^2)
+--R 
+--R
+--R                    +-----------+
+--R             2      |   4      2
+--R        (2c x  - b)\|c x  + b x
+--R   (2)  -------------------------
+--R                    2 4
+--R                  3b x
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 762
+t0:=1/(x^5*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         5 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 762
+r0:=-1/5*sqrt(b*x^2+c*x^4)/(b*x^6)+4/15*c*sqrt(b*x^2+c*x^4)/(b^2*x^4)-_
+     8/15*c^2*sqrt(b*x^2+c*x^4)/(b^3*x^2)
+--R 
+--R
+--R                                  +-----------+
+--R             2 4         2     2  |   4      2
+--R        (- 8c x  + 4b c x  - 3b )\|c x  + b x
+--R   (2)  ---------------------------------------
+--R                            3 6
+--R                         15b x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 762
+t0:=1/(x^7*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         7 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 762
+r0:=-1/7*sqrt(b*x^2+c*x^4)/(b*x^8)+6/35*c*sqrt(b*x^2+c*x^4)/(b^2*x^6)-_
+     8/35*c^2*sqrt(b*x^2+c*x^4)/(b^3*x^4)+16/35*c^3*sqrt(b*x^2+_
+     c*x^4)/(b^4*x^2)
+--R 
+--R
+--R                                           +-----------+
+--R            3 6       2 4     2   2     3  |   4      2
+--R        (16c x  - 8b c x  + 6b c x  - 5b )\|c x  + b x
+--R   (2)  ------------------------------------------------
+--R                                4 8
+--R                             35b x
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 762
+t0:=x^4/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 211
+
+--S 212 of 762
+r0:=-2/3*b*sqrt(b*x^2+c*x^4)/(c^2*x)+1/3*x*sqrt(b*x^2+c*x^4)/c
+--R 
+--R
+--R                    +-----------+
+--R            2       |   4      2
+--R        (c x  - 2b)\|c x  + b x
+--R   (2)  -------------------------
+--R                     2
+--R                   3c x
+--R                                                    Type: Expression(Integer)
+--E 212
+
+--S 213 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 213
+
+)clear all
+
+--S 214 of 762
+t0:=x^2/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 762
+r0:=sqrt(b*x^2+c*x^4)/(c*x)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (2)  --------------
+--R              c x
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 762
+t0:=1/sqrt(b*x^2+c*x^4)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 762
+r0:=-atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/sqrt(b)
+--R 
+--R
+--R                       +-+
+--R                     x\|b
+--R          atanh(--------------)
+--R                 +-----------+
+--R                 |   4      2
+--R                \|c x  + b x
+--R   (2)  - ---------------------
+--R                    +-+
+--R                   \|b
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 762
+t0:=1/(x^2*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         2 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 762
+r0:=1/2*c*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)-_
+     1/2*sqrt(b*x^2+c*x^4)/(b*x^3)
+--R 
+--R
+--R                         +-+             +-----------+
+--R           3           x\|b          +-+ |   4      2
+--R        c x atanh(--------------) - \|b \|c x  + b x
+--R                   +-----------+
+--R                   |   4      2
+--R                  \|c x  + b x
+--R   (2)  ----------------------------------------------
+--R                               3 +-+
+--R                           2b x \|b
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 762
+t0:=1/(x^4*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         4 |   4      2
+--R        x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 762
+r0:=-3/8*c^2*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)-_
+     1/4*sqrt(b*x^2+c*x^4)/(b*x^5)+3/8*c*sqrt(b*x^2+c*x^4)/(b^2*x^3)
+--R 
+--R
+--R                            +-+                         +-----------+
+--R            2 5           x\|b              2       +-+ |   4      2
+--R        - 3c x atanh(--------------) + (3c x  - 2b)\|b \|c x  + b x
+--R                      +-----------+
+--R                      |   4      2
+--R                     \|c x  + b x
+--R   (2)  -------------------------------------------------------------
+--R                                    2 5 +-+
+--R                                  8b x \|b
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 762
+t0:=x^9/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    7
+--R                   x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 762
+r0:=15/8*b^2*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(7/2)-_
+     x^6/(c*sqrt(b*x^2+c*x^4))-15/8*b*sqrt(b*x^2+c*x^4)/c^3+_
+     5/4*x^2*sqrt(b*x^2+c*x^4)/c^2
+--R 
+--R
+--R   (2)
+--R        +-----------+           2 +-+
+--R      2 |   4      2           x \|c            2 6         4      2 2  +-+
+--R   15b \|c x  + b x  atanh(--------------) + (2c x  - 5b c x  - 15b x )\|c
+--R                            +-----------+
+--R                            |   4      2
+--R                           \|c x  + b x
+--R   ------------------------------------------------------------------------
+--R                                     +-----------+
+--R                               3 +-+ |   4      2
+--R                             8c \|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 762
+t0:=x^7/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    5
+--R                   x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 762
+r0:=-3/2*b*atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(5/2)-_
+     x^4/(c*sqrt(b*x^2+c*x^4))+3/2*sqrt(b*x^2+c*x^4)/c^2
+--R 
+--R
+--R             +-----------+           2 +-+
+--R             |   4      2           x \|c             4       2  +-+
+--R        - 3b\|c x  + b x  atanh(--------------) + (c x  + 3b x )\|c
+--R                                 +-----------+
+--R                                 |   4      2
+--R                                \|c x  + b x
+--R   (2)  ------------------------------------------------------------
+--R                                    +-----------+
+--R                              2 +-+ |   4      2
+--R                            2c \|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 762
+t0:=x^5/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    3
+--R                   x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 762
+r0:=atanh(x^2*sqrt(c)/sqrt(b*x^2+c*x^4))/c^(3/2)-x^2/(c*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R         +-----------+           2 +-+
+--R         |   4      2           x \|c          2 +-+
+--R        \|c x  + b x  atanh(--------------) - x \|c
+--R                             +-----------+
+--R                             |   4      2
+--R                            \|c x  + b x
+--R   (2)  --------------------------------------------
+--R                           +-----------+
+--R                       +-+ |   4      2
+--R                     c\|c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 762
+t0:=x^3/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 762
+r0:=x^2/(b*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                2
+--R               x
+--R   (2)  ---------------
+--R          +-----------+
+--R          |   4      2
+--R        b\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 762
+t0:=x/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                     1
+--R   (1)  --------------------------
+--R                     +-----------+
+--R            3        |   4      2
+--R        (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 762
+r0:=1/(b*sqrt(b*x^2+c*x^4))-2*sqrt(b*x^2+c*x^4)/(b^2*x^2)
+--R 
+--R
+--R                 2
+--R           - 2c x  - b
+--R   (2)  ----------------
+--R           +-----------+
+--R         2 |   4      2
+--R        b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 762
+t0:=1/(x*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            5      3  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 762
+r0:=1/(b*x^2*sqrt(b*x^2+c*x^4))-4/3*sqrt(b*x^2+c*x^4)/(b^2*x^4)+_
+     8/3*c*sqrt(b*x^2+c*x^4)/(b^3*x^2)
+--R 
+--R
+--R          2 4         2    2
+--R        8c x  + 4b c x  - b
+--R   (2)  --------------------
+--R               +-----------+
+--R           3 2 |   4      2
+--R         3b x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 762
+t0:=1/(x^3*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            7      5  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 762
+r0:=1/(b*x^4*sqrt(b*x^2+c*x^4))-6/5*sqrt(b*x^2+c*x^4)/(b^2*x^6)+_
+     8/5*c*sqrt(b*x^2+c*x^4)/(b^3*x^4)-16/5*c^2*sqrt(b*x^2+c*x^4)/(b^4*x^2)
+--R 
+--R
+--R             3 6       2 4     2   2    3
+--R        - 16c x  - 8b c x  + 2b c x  - b
+--R   (2)  ---------------------------------
+--R                     +-----------+
+--R                 4 4 |   4      2
+--R               5b x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 762
+t0:=1/(x^5*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            9      7  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 762
+r0:=1/(b*x^6*sqrt(b*x^2+c*x^4))-8/7*sqrt(b*x^2+c*x^4)/(b^2*x^8)+_
+     48/35*c*sqrt(b*x^2+c*x^4)/(b^3*x^6)-_
+     64/35*c^2*sqrt(b*x^2+c*x^4)/(b^4*x^4)+_
+     128/35*c^3*sqrt(b*x^2+c*x^4)/(b^5*x^2)
+--R 
+--R
+--R            4 8        3 6      2 2 4     3   2     4
+--R        128c x  + 64b c x  - 16b c x  + 8b c x  - 5b
+--R   (2)  ---------------------------------------------
+--R                            +-----------+
+--R                        5 6 |   4      2
+--R                     35b x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 762
+t0:=x^6/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    4
+--R                   x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 762
+r0:=-x^3/(c*sqrt(b*x^2+c*x^4))+2*sqrt(b*x^2+c*x^4)/(c^2*x)
+--R 
+--R
+--R              3
+--R           c x  + 2b x
+--R   (2)  ----------------
+--R           +-----------+
+--R         2 |   4      2
+--R        c \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 762
+t0:=x^4/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    2
+--R                   x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 762
+r0:=-x/(c*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R                 x
+--R   (2)  - ---------------
+--R            +-----------+
+--R            |   4      2
+--R          c\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 762
+t0:=x^2/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    1
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 762
+r0:=-atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(3/2)+x/(b*sqrt(b*x^2+c*x^4))
+--R 
+--R
+--R           +-----------+             +-+
+--R           |   4      2            x\|b           +-+
+--R        - \|c x  + b x  atanh(--------------) + x\|b
+--R                               +-----------+
+--R                               |   4      2
+--R                              \|c x  + b x
+--R   (2)  ---------------------------------------------
+--R                           +-----------+
+--R                       +-+ |   4      2
+--R                     b\|b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 762
+t0:=1/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            4      2  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 762
+r0:=3/2*c*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(5/2)+1/(b*x*_
+     sqrt(b*x^2+c*x^4))-3/2*sqrt(b*x^2+c*x^4)/(b^2*x^3)
+--R 
+--R
+--R             +-----------+             +-+
+--R             |   4      2            x\|b                2      +-+
+--R        3c x\|c x  + b x  atanh(--------------) + (- 3c x  - b)\|b
+--R                                 +-----------+
+--R                                 |   4      2
+--R                                \|c x  + b x
+--R   (2)  -----------------------------------------------------------
+--R                                    +-----------+
+--R                             2  +-+ |   4      2
+--R                           2b x\|b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 762
+t0:=1/(x^2*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            6      4  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 262
+
+--S 263 of 762
+r0:=-15/8*c^2*atanh(x*sqrt(b)/sqrt(b*x^2+c*x^4))/b^(7/2)+1/(b*x^3*_
+     sqrt(b*x^2+c*x^4))-5/4*sqrt(b*x^2+c*x^4)/(b^2*x^5)+15/8*c*_
+     sqrt(b*x^2+c*x^4)/(b^3*x^3)
+--R 
+--R
+--R   (2)
+--R            +-----------+             +-+
+--R        2 3 |   4      2            x\|b             2 4         2     2  +-+
+--R   - 15c x \|c x  + b x  atanh(--------------) + (15c x  + 5b c x  - 2b )\|b
+--R                                +-----------+
+--R                                |   4      2
+--R                               \|c x  + b x
+--R   --------------------------------------------------------------------------
+--R                                       +-----------+
+--R                               3 3 +-+ |   4      2
+--R                             8b x \|b \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 762
+t0:=x^3/sqrt(3*x^2-4*x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |    4     2
+--R        \|- 4x  + 3x
+--R                                                    Type: Expression(Integer)
+--E 265
+
+--S 266 of 762
+r0:=-3/32*asin(1-8/3*x^2)-1/8*sqrt(3*x^2-4*x^4)
+--R 
+--R
+--R            +-----------+           2
+--R            |    4     2          8x  - 3
+--R        - 4\|- 4x  + 3x   + 3asin(-------)
+--R                                     3
+--R   (2)  ----------------------------------
+--R                        32
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R              +-----------+      +-------------+
+--R              |    4     2       |     4      2
+--R        - 12x\|- 4x  + 3x   + 3x\|- 64x  + 48x
+--R   (3)  ----------------------------------------
+--R               +-------------+ +-----------+
+--R               |     4      2  |    4     2
+--R             8\|- 64x  + 48x  \|- 4x  + 3x
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 762
+t0:=x^3/sqrt(-3*x^2-4*x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |    4     2
+--R        \|- 4x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 268
+
+--S 269 of 762
+r0:=-3/32*asin(1+8/3*x^2)-1/8*sqrt(-3*x^2-4*x^4)
+--R 
+--R
+--R            +-----------+           2
+--R            |    4     2          8x  + 3
+--R        - 4\|- 4x  - 3x   - 3asin(-------)
+--R                                     3
+--R   (2)  ----------------------------------
+--R                        32
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R            +-----------+      +-------------+
+--R            |    4     2       |     4      2
+--R        12x\|- 4x  - 3x   - 3x\|- 64x  - 48x
+--R   (3)  --------------------------------------
+--R              +-------------+ +-----------+
+--R              |     4      2  |    4     2
+--R            8\|- 64x  - 48x  \|- 4x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 762
+t0:=x^3/sqrt(3*x^2+4*x^4)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         +---------+
+--R         |  4     2
+--R        \|4x  + 3x
+--R                                                    Type: Expression(Integer)
+--E 271
+
+--S 272 of 762
+r0:=-3/16*atanh(2*x^2/sqrt(3*x^2+4*x^4))+1/8*sqrt(3*x^2+4*x^4)
+--R 
+--R
+--R                        2          +---------+
+--R                      2x           |  4     2
+--R        - 3atanh(------------) + 2\|4x  + 3x
+--R                  +---------+
+--R                  |  4     2
+--R                 \|4x  + 3x
+--R   (2)  --------------------------------------
+--R                          16
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 762
+t0:=x^3/sqrt(-3*x^2+4*x^4)
+--R 
+--R
+--R              3
+--R             x
+--R   (1)  ------------
+--R         +---------+
+--R         |  4     2
+--R        \|4x  - 3x
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 762
+r0:=3/16*atanh(2*x^2/sqrt(-3*x^2+4*x^4))+1/8*sqrt(-3*x^2+4*x^4)
+--R 
+--R
+--R                      2          +---------+
+--R                    2x           |  4     2
+--R        3atanh(------------) + 2\|4x  - 3x
+--R                +---------+
+--R                |  4     2
+--R               \|4x  - 3x
+--R   (2)  ------------------------------------
+--R                         16
+--R                                                    Type: Expression(Integer)
+--E 275
+
+--S 276 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 276
+
+)clear all
+
+--S 277 of 762
+t0:=x^3/sqrt(a*x^2+b*x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 762
+r0:=-1/2*a*atanh(x^2*sqrt(b)/sqrt(a*x^2+b*x^4))/b^(3/2)+_
+     1/2*sqrt(a*x^2+b*x^4)/b
+--R 
+--R
+--R                       2 +-+             +-----------+
+--R                      x \|b          +-+ |   4      2
+--R        - a atanh(--------------) + \|b \|b x  + a x
+--R                   +-----------+
+--R                   |   4      2
+--R                  \|b x  + a x
+--R   (2)  ----------------------------------------------
+--R                               +-+
+--R                            2b\|b
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 762
+t0:=x^3/sqrt(a*x^2-b*x^4)
+--R 
+--R
+--R                3
+--R               x
+--R   (1)  ----------------
+--R         +-------------+
+--R         |     4      2
+--R        \|- b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 762
+r0:=1/2*a*atan(x^2*sqrt(b)/sqrt(a*x^2-b*x^4))/b^(3/2)-1/2*sqrt(a*x^2-b*x^4)/b
+--R 
+--R
+--R                     2 +-+          +-------------+
+--R                    x \|b           |     4      2  +-+
+--R        a atan(----------------) - \|- b x  + a x  \|b
+--R                +-------------+
+--R                |     4      2
+--R               \|- b x  + a x
+--R   (2)  -----------------------------------------------
+--R                                +-+
+--R                             2b\|b
+--R                                                    Type: Expression(Integer)
+--E 281
+
+--S 282 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 282
+
+)clear all
+
+--S 283 of 762
+t0:=x^(7/2)*(b*x^2+c*x^4)
+--R 
+--R
+--R            7      5  +-+
+--R   (1)  (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 762
+r0:=2/13*b*x^(13/2)+2/17*c*x^(17/2)
+--R 
+--R
+--R              8        6  +-+
+--R        (26c x  + 34b x )\|x
+--R   (2)  ---------------------
+--R                 221
+--R                                                    Type: Expression(Integer)
+--E 284
+
+--S 285 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 285
+
+)clear all
+
+--S 286 of 762
+t0:=x^(5/2)*(b*x^2+c*x^4)
+--R 
+--R
+--R            6      4  +-+
+--R   (1)  (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 762
+r0:=2/11*b*x^(11/2)+2/15*c*x^(15/2)
+--R 
+--R
+--R              7        5  +-+
+--R        (22c x  + 30b x )\|x
+--R   (2)  ---------------------
+--R                 165
+--R                                                    Type: Expression(Integer)
+--E 287
+
+--S 288 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 288
+
+)clear all
+
+--S 289 of 762
+t0:=x^(3/2)*(b*x^2+c*x^4)
+--R 
+--R
+--R            5      3  +-+
+--R   (1)  (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 762
+r0:=2/9*b*x^(9/2)+2/13*c*x^(13/2)
+--R 
+--R
+--R              6        4  +-+
+--R        (18c x  + 26b x )\|x
+--R   (2)  ---------------------
+--R                 117
+--R                                                    Type: Expression(Integer)
+--E 290
+
+--S 291 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 291
+
+)clear all
+
+--S 292 of 762
+t0:=x^(1/2)*(b*x^2+c*x^4)
+--R 
+--R
+--R            4      2  +-+
+--R   (1)  (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 762
+r0:=2/7*b*x^(7/2)+2/11*c*x^(11/2)
+--R 
+--R
+--R              5        3  +-+
+--R        (14c x  + 22b x )\|x
+--R   (2)  ---------------------
+--R                  77
+--R                                                    Type: Expression(Integer)
+--E 293
+
+--S 294 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 294
+
+)clear all
+
+--S 295 of 762
+t0:=(b*x^2+c*x^4)/x^(1/2)
+--R 
+--R
+--R           4      2
+--R        c x  + b x
+--R   (1)  -----------
+--R             +-+
+--R            \|x
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 762
+r0:=2/5*b*x^(5/2)+2/9*c*x^(9/2)
+--R 
+--R
+--R              4        2  +-+
+--R        (10c x  + 18b x )\|x
+--R   (2)  ---------------------
+--R                  45
+--R                                                    Type: Expression(Integer)
+--E 296
+
+--S 297 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 297
+
+)clear all
+
+--S 298 of 762
+t0:=(b*x^2+c*x^4)/x^(3/2)
+--R 
+--R
+--R           3
+--R        c x  + b x
+--R   (1)  ----------
+--R            +-+
+--R           \|x
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 762
+r0:=2/3*b*x^(3/2)+2/7*c*x^(7/2)
+--R 
+--R
+--R             3          +-+
+--R        (6c x  + 14b x)\|x
+--R   (2)  -------------------
+--R                 21
+--R                                                    Type: Expression(Integer)
+--E 299
+
+--S 300 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 300
+
+)clear all
+
+--S 301 of 762
+t0:=(b*x^2+c*x^4)/x^(5/2)
+--R 
+--R
+--R           2
+--R        c x  + b
+--R   (1)  --------
+--R           +-+
+--R          \|x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 762
+r0:=2/5*c*x^(5/2)+2*b*sqrt(x)
+--R 
+--R
+--R             2        +-+
+--R        (2c x  + 10b)\|x
+--R   (2)  -----------------
+--R                5
+--R                                                    Type: Expression(Integer)
+--E 302
+
+--S 303 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 303
+
+)clear all
+
+--S 304 of 762
+t0:=(b*x^2+c*x^4)/x^(7/2)
+--R 
+--R
+--R           2
+--R        c x  + b
+--R   (1)  --------
+--R            +-+
+--R          x\|x
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 762
+r0:=2/3*c*x^(3/2)-2*b/sqrt(x)
+--R 
+--R
+--R            2
+--R        2c x  - 6b
+--R   (2)  ----------
+--R             +-+
+--R           3\|x
+--R                                                    Type: Expression(Integer)
+--E 305
+
+--S 306 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 306
+
+)clear all
+
+--S 307 of 762
+t0:=x^(7/2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 11         9    2 7  +-+
+--R   (1)  (c x   + 2b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 762
+r0:=2/17*b^2*x^(17/2)+4/21*b*c*x^(21/2)+2/25*c^2*x^(25/2)
+--R 
+--R
+--R             2 12            10        2 8  +-+
+--R        (714c x   + 1700b c x   + 1050b x )\|x
+--R   (2)  ---------------------------------------
+--R                          8925
+--R                                                    Type: Expression(Integer)
+--E 308
+
+--S 309 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 309
+
+)clear all
+
+--S 310 of 762
+t0:=x^(5/2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 10         8    2 6  +-+
+--R   (1)  (c x   + 2b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 762
+r0:=2/15*b^2*x^(15/2)+4/19*b*c*x^(19/2)+2/23*c^2*x^(23/2)
+--R 
+--R
+--R             2 11            9       2 7  +-+
+--R        (570c x   + 1380b c x  + 874b x )\|x
+--R   (2)  -------------------------------------
+--R                         6555
+--R                                                    Type: Expression(Integer)
+--E 311
+
+--S 312 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 312
+
+)clear all
+
+--S 313 of 762
+t0:=x^(3/2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 9         7    2 5  +-+
+--R   (1)  (c x  + 2b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 762
+r0:=2/13*b^2*x^(13/2)+4/17*b*c*x^(17/2)+2/21*c^2*x^(21/2)
+--R 
+--R
+--R             2 10            8       2 6  +-+
+--R        (442c x   + 1092b c x  + 714b x )\|x
+--R   (2)  -------------------------------------
+--R                         4641
+--R                                                    Type: Expression(Integer)
+--E 314
+
+--S 315 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 315
+
+)clear all
+
+--S 316 of 762
+t0:=x^(1/2)*(b*x^2+c*x^4)^2
+--R 
+--R
+--R          2 8         6    2 4  +-+
+--R   (1)  (c x  + 2b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 762
+r0:=2/11*b^2*x^(11/2)+4/15*b*c*x^(15/2)+2/19*c^2*x^(19/2)
+--R 
+--R
+--R             2 9           7       2 5  +-+
+--R        (330c x  + 836b c x  + 570b x )\|x
+--R   (2)  -----------------------------------
+--R                        3135
+--R                                                    Type: Expression(Integer)
+--E 317
+
+--S 318 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 318
+
+)clear all
+
+--S 319 of 762
+t0:=(b*x^2+c*x^4)^2/x^(1/2)
+--R 
+--R
+--R         2 8         6    2 4
+--R        c x  + 2b c x  + b x
+--R   (1)  ---------------------
+--R                  +-+
+--R                 \|x
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 762
+r0:=2/9*b^2*x^(9/2)+4/13*b*c*x^(13/2)+2/17*c^2*x^(17/2)
+--R 
+--R
+--R             2 8           6       2 4  +-+
+--R        (234c x  + 612b c x  + 442b x )\|x
+--R   (2)  -----------------------------------
+--R                        1989
+--R                                                    Type: Expression(Integer)
+--E 320
+
+--S 321 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 321
+
+)clear all
+
+--S 322 of 762
+t0:=(b*x^2+c*x^4)^2/x^(3/2)
+--R 
+--R
+--R         2 7         5    2 3
+--R        c x  + 2b c x  + b x
+--R   (1)  ---------------------
+--R                  +-+
+--R                 \|x
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 762
+r0:=2/7*b^2*x^(7/2)+4/11*b*c*x^(11/2)+2/15*c^2*x^(15/2)
+--R 
+--R
+--R             2 7           5       2 3  +-+
+--R        (154c x  + 420b c x  + 330b x )\|x
+--R   (2)  -----------------------------------
+--R                        1155
+--R                                                    Type: Expression(Integer)
+--E 323
+
+--S 324 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 324
+
+)clear all
+
+--S 325 of 762
+t0:=(b*x^2+c*x^4)^2/x^(5/2)
+--R 
+--R
+--R         2 6         4    2 2
+--R        c x  + 2b c x  + b x
+--R   (1)  ---------------------
+--R                  +-+
+--R                 \|x
+--R                                                    Type: Expression(Integer)
+--E 325
+
+--S 326 of 762
+r0:=2/5*b^2*x^(5/2)+4/9*b*c*x^(9/2)+2/13*c^2*x^(13/2)
+--R 
+--R
+--R            2 6           4       2 2  +-+
+--R        (90c x  + 260b c x  + 234b x )\|x
+--R   (2)  ----------------------------------
+--R                        585
+--R                                                    Type: Expression(Integer)
+--E 326
+
+--S 327 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 327
+
+)clear all
+
+--S 328 of 762
+t0:=(b*x^2+c*x^4)^2/x^(7/2)
+--R 
+--R
+--R         2 5         3    2
+--R        c x  + 2b c x  + b x
+--R   (1)  --------------------
+--R                 +-+
+--R                \|x
+--R                                                    Type: Expression(Integer)
+--E 328
+
+--S 329 of 762
+r0:=2/3*b^2*x^(3/2)+4/7*b*c*x^(7/2)+2/11*c^2*x^(11/2)
+--R 
+--R
+--R            2 5           3       2   +-+
+--R        (42c x  + 132b c x  + 154b x)\|x
+--R   (2)  ---------------------------------
+--R                       231
+--R                                                    Type: Expression(Integer)
+--E 329
+
+--S 330 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 330
+
+)clear all
+
+--S 331 of 762
+t0:=x^(7/2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R          3 15       2 13     2   11    3 9  +-+
+--R   (1)  (c x   + 3b c x   + 3b c x   + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 331
+
+--S 332 of 762
+r0:=2/21*b^3*x^(21/2)+6/25*b^2*c*x^(25/2)+6/29*b*c^2*x^(29/2)+_
+     2/33*c^3*x^(33/2)
+--R 
+--R
+--R               3 16           2 14         2   12         3 10  +-+
+--R        (10150c x   + 34650b c x   + 40194b c x   + 15950b x  )\|x
+--R   (2)  -----------------------------------------------------------
+--R                                   167475
+--R                                                    Type: Expression(Integer)
+--E 332
+
+--S 333 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 333
+
+)clear all
+
+--S 334 of 762
+t0:=x^(5/2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R          3 14       2 12     2   10    3 8  +-+
+--R   (1)  (c x   + 3b c x   + 3b c x   + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 334
+
+--S 335 of 762
+r0:=2/19*b^3*x^(19/2)+6/23*b^2*c*x^(23/2)+2/9*b*c^2*x^(27/2)+2/31*c^3*x^(31/2)
+--R 
+--R
+--R              3 15           2 13         2   11         3 9  +-+
+--R        (7866c x   + 27094b c x   + 31806b c x   + 12834b x )\|x
+--R   (2)  ---------------------------------------------------------
+--R                                  121923
+--R                                                    Type: Expression(Integer)
+--E 335
+
+--S 336 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 336
+
+)clear all
+
+--S 337 of 762
+t0:=x^(3/2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R          3 13       2 11     2   9    3 7  +-+
+--R   (1)  (c x   + 3b c x   + 3b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 337
+
+--S 338 of 762
+r0:=2/17*b^3*x^(17/2)+2/7*b^2*c*x^(21/2)+6/25*b*c^2*x^(25/2)+2/29*c^3*x^(29/2)
+--R 
+--R
+--R              3 14           2 12         2   10         3 8  +-+
+--R        (5950c x   + 20706b c x   + 24650b c x   + 10150b x )\|x
+--R   (2)  ---------------------------------------------------------
+--R                                  86275
+--R                                                    Type: Expression(Integer)
+--E 338
+
+--S 339 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 339
+
+)clear all
+
+--S 340 of 762
+t0:=x^(1/2)*(b*x^2+c*x^4)^3
+--R 
+--R
+--R          3 12       2 10     2   8    3 6  +-+
+--R   (1)  (c x   + 3b c x   + 3b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 340
+
+--S 341 of 762
+r0:=2/15*b^3*x^(15/2)+6/19*b^2*c*x^(19/2)+6/23*b*c^2*x^(23/2)+2/27*c^3*x^(27/2)
+--R 
+--R
+--R              3 13           2 11         2   9        3 7  +-+
+--R        (4370c x   + 15390b c x   + 18630b c x  + 7866b x )\|x
+--R   (2)  -------------------------------------------------------
+--R                                 58995
+--R                                                    Type: Expression(Integer)
+--E 341
+
+--S 342 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 342
+
+)clear all
+
+--S 343 of 762
+t0:=(b*x^2+c*x^4)^3/x^(1/2)
+--R 
+--R
+--R         3 12       2 10     2   8    3 6
+--R        c x   + 3b c x   + 3b c x  + b x
+--R   (1)  ---------------------------------
+--R                        +-+
+--R                       \|x
+--R                                                    Type: Expression(Integer)
+--E 343
+
+--S 344 of 762
+r0:=2/13*b^3*x^(13/2)+6/17*b^2*c*x^(17/2)+2/7*b*c^2*x^(21/2)+2/25*c^3*x^(25/2)
+--R 
+--R
+--R              3 12           2 10         2   8        3 6  +-+
+--R        (3094c x   + 11050b c x   + 13650b c x  + 5950b x )\|x
+--R   (2)  -------------------------------------------------------
+--R                                 38675
+--R                                                    Type: Expression(Integer)
+--E 344
+
+--S 345 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 345
+
+)clear all
+
+--S 346 of 762
+t0:=(b*x^2+c*x^4)^3/x^(3/2)
+--R 
+--R
+--R         3 11       2 9     2   7    3 5
+--R        c x   + 3b c x  + 3b c x  + b x
+--R   (1)  --------------------------------
+--R                       +-+
+--R                      \|x
+--R                                                    Type: Expression(Integer)
+--E 346
+
+--S 347 of 762
+r0:=2/11*b^3*x^(11/2)+2/5*b^2*c*x^(15/2)+6/19*b*c^2*x^(19/2)+2/23*c^3*x^(23/2)
+--R 
+--R
+--R              3 11          2 9        2   7        3 5  +-+
+--R        (2090c x   + 7590b c x  + 9614b c x  + 4370b x )\|x
+--R   (2)  ----------------------------------------------------
+--R                                24035
+--R                                                    Type: Expression(Integer)
+--E 347
+
+--S 348 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 348
+
+)clear all
+
+--S 349 of 762
+t0:=(b*x^2+c*x^4)^3/x^(5/2)
+--R 
+--R
+--R         3 10       2 8     2   6    3 4
+--R        c x   + 3b c x  + 3b c x  + b x
+--R   (1)  --------------------------------
+--R                       +-+
+--R                      \|x
+--R                                                    Type: Expression(Integer)
+--E 349
+
+--S 350 of 762
+r0:=2/9*b^3*x^(9/2)+6/13*b^2*c*x^(13/2)+6/17*b*c^2*x^(17/2)+2/21*c^3*x^(21/2)
+--R 
+--R
+--R              3 10          2 8        2   6        3 4  +-+
+--R        (1326c x   + 4914b c x  + 6426b c x  + 3094b x )\|x
+--R   (2)  ----------------------------------------------------
+--R                                13923
+--R                                                    Type: Expression(Integer)
+--E 350
+
+--S 351 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 351
+
+)clear all
+
+--S 352 of 762
+t0:=(b*x^2+c*x^4)^3/x^(7/2)
+--R 
+--R
+--R         3 9       2 7     2   5    3 3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R   (1)  -------------------------------
+--R                       +-+
+--R                      \|x
+--R                                                    Type: Expression(Integer)
+--E 352
+
+--S 353 of 762
+r0:=2/7*b^3*x^(7/2)+6/11*b^2*c*x^(11/2)+2/5*b*c^2*x^(15/2)+2/19*c^3*x^(19/2)
+--R 
+--R
+--R             3 9          2 7        2   5        3 3  +-+
+--R        (770c x  + 2926b c x  + 3990b c x  + 2090b x )\|x
+--R   (2)  --------------------------------------------------
+--R                               7315
+--R                                                    Type: Expression(Integer)
+--E 353
+
+--S 354 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 354
+
+)clear all
+
+--S 355 of 762
+t0:=x^(13/2)/(b*x^2+c*x^4)
+--R 
+--R
+--R          4 +-+
+--R         x \|x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                                    Type: Expression(Integer)
+--E 355
+
+--S 356 of 762
+r0:=-2/3*b*x^(3/2)/c^2+2/7*x^(7/2)/c-b^(7/4)*atan(1-c^(1/4)*sqrt(2)*_
+     sqrt(x)/b^(1/4))/(c^(11/4)*sqrt(2))+b^(7/4)*atan(1+c^(1/4)*_
+     sqrt(2)*sqrt(x)/b^(1/4))/(c^(11/4)*sqrt(2))+1/2*b^(7/4)*_
+     log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(11/4)*_
+     sqrt(2))-1/2*b^(7/4)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(c^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 21b \|b  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       21b \|b  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                      +-+4+-+ +-+   4+-+                   +-+4+-+ +-+   4+-+
+--R           4+-+3     \|2 \|c \|x  + \|b         4+-+3     \|2 \|c \|x  - \|b
+--R       42b \|b  atan(-------------------) + 42b \|b  atan(-------------------)
+--R                             4+-+                                 4+-+
+--R                             \|b                                  \|b
+--R     + 
+--R             3          +-+4+-+3 +-+
+--R       (12c x  - 28b x)\|2 \|c  \|x
+--R  /
+--R        2 +-+4+-+3
+--R     42c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 356
+
+--S 357 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 357
+
+)clear all
+
+--S 358 of 762
+t0:=x^(11/2)/(b*x^2+c*x^4)
+--R 
+--R
+--R          3 +-+
+--R         x \|x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                                    Type: Expression(Integer)
+--E 358
+
+--S 359 of 762
+r0:=2/5*x^(5/2)/c-b^(5/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(9/4)*_
+     sqrt(2))+b^(5/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(9/4)*_
+     sqrt(2))-1/2*b^(5/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+     sqrt(x))/(c^(9/4)*sqrt(2))+1/2*b^(5/4)*log(sqrt(b)+x*sqrt(c)+_
+     b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(9/4)*sqrt(2))-2*b*sqrt(x)/c^2
+--R 
+--R
+--R   (2)
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       5b\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 5b\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    +-+4+-+ +-+   4+-+                 +-+4+-+ +-+   4+-+
+--R          4+-+     \|2 \|c \|x  + \|b        4+-+     \|2 \|c \|x  - \|b
+--R       10b\|b atan(-------------------) + 10b\|b atan(-------------------)
+--R                           4+-+                               4+-+
+--R                           \|b                                \|b
+--R     + 
+--R            2        +-+4+-+ +-+
+--R       (4c x  - 20b)\|2 \|c \|x
+--R  /
+--R        2 +-+4+-+
+--R     10c \|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 359
+
+--S 360 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 360
+
+)clear all
+
+--S 361 of 762
+t0:=x^(9/2)/(b*x^2+c*x^4)
+--R 
+--R
+--R          2 +-+
+--R         x \|x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                                    Type: Expression(Integer)
+--E 361
+
+--S 362 of 762
+r0:=2/3*x^(3/2)/c+b^(3/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(7/4)*_
+     sqrt(2))-b^(3/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(7/4)*_
+     sqrt(2))-1/2*b^(3/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+     sqrt(x))/(c^(7/4)*sqrt(2))+1/2*b^(3/4)*log(sqrt(b)+x*sqrt(c)+_
+     b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R        4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       3\|b  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R          4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 3\|b  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                     +-+4+-+ +-+   4+-+                +-+4+-+ +-+   4+-+
+--R          4+-+3     \|2 \|c \|x  + \|b      4+-+3     \|2 \|c \|x  - \|b
+--R       - 6\|b  atan(-------------------) - 6\|b  atan(-------------------)
+--R                            4+-+                              4+-+
+--R                            \|b                               \|b
+--R     + 
+--R          +-+4+-+3 +-+
+--R       4x\|2 \|c  \|x
+--R  /
+--R        +-+4+-+3
+--R     6c\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 362
+
+--S 363 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 363
+
+)clear all
+
+--S 364 of 762
+t0:=x^(7/2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            +-+
+--R          x\|x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                                    Type: Expression(Integer)
+--E 364
+
+--S 365 of 762
+r0:=b^(1/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(5/4)*sqrt(2))-_
+     b^(1/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(5/4)*sqrt(2))+_
+     1/2*b^(1/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+     sqrt(x))/(c^(5/4)*sqrt(2))-1/2*b^(1/4)*log(sqrt(b)+x*sqrt(c)+_
+     b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(5/4)*sqrt(2))+2*sqrt(x)/c
+--R 
+--R
+--R   (2)
+--R         4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - \|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R       4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       \|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                    +-+4+-+ +-+   4+-+               +-+4+-+ +-+   4+-+
+--R          4+-+     \|2 \|c \|x  + \|b      4+-+     \|2 \|c \|x  - \|b
+--R       - 2\|b atan(-------------------) - 2\|b atan(-------------------)
+--R                           4+-+                             4+-+
+--R                           \|b                              \|b
+--R     + 
+--R         +-+4+-+ +-+
+--R       4\|2 \|c \|x
+--R  /
+--R        +-+4+-+
+--R     2c\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 365
+
+--S 366 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 366
+
+)clear all
+
+--S 367 of 762
+t0:=x^(5/2)/(b*x^2+c*x^4)
+--R 
+--R
+--R           +-+
+--R          \|x
+--R   (1)  --------
+--R           2
+--R        c x  + b
+--R                                                    Type: Expression(Integer)
+--E 367
+
+--S 368 of 762
+r0:=-atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(1/4)*c^(3/4)*sqrt(2))+_
+     atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(1/4)*c^(3/4)*sqrt(2))+_
+     1/2*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (b^(1/4)*c^(3/4)*sqrt(2))-1/2*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*c^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R       - log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                       +-+4+-+ +-+   4+-+
+--R              +-+4+-+4+-+ +-+     +-+    +-+          \|2 \|c \|x  + \|b
+--R       log(- \|2 \|b \|c \|x  + x\|c  + \|b ) + 2atan(-------------------)
+--R                                                              4+-+
+--R                                                              \|b
+--R     + 
+--R              +-+4+-+ +-+   4+-+
+--R             \|2 \|c \|x  - \|b
+--R       2atan(-------------------)
+--R                     4+-+
+--R                     \|b
+--R  /
+--R       +-+4+-+4+-+3
+--R     2\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 368
+
+--S 369 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 369
+
+)clear all
+
+--S 370 of 762
+t0:=x^(3/2)/(b*x^2+c*x^4)
+--R 
+--R
+--R            +-+
+--R           \|x
+--R   (1)  ----------
+--R           3
+--R        c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 370
+
+--S 371 of 762
+r0:=-atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(1/4)*sqrt(2))+_
+     atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(1/4)*sqrt(2))-_
+     1/2*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (b^(3/4)*c^(1/4)*sqrt(2))+1/2*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*c^(1/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            +-+4+-+4+-+ +-+     +-+    +-+
+--R       log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                         +-+4+-+ +-+   4+-+
+--R                +-+4+-+4+-+ +-+     +-+    +-+          \|2 \|c \|x  + \|b
+--R       - log(- \|2 \|b \|c \|x  + x\|c  + \|b ) + 2atan(-------------------)
+--R                                                                4+-+
+--R                                                                \|b
+--R     + 
+--R              +-+4+-+ +-+   4+-+
+--R             \|2 \|c \|x  - \|b
+--R       2atan(-------------------)
+--R                     4+-+
+--R                     \|b
+--R  /
+--R       +-+4+-+3 4+-+
+--R     2\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 371
+
+--S 372 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 372
+
+)clear all
+
+--S 373 of 762
+t0:=sqrt(x)/(b*x^2+c*x^4)
+--R 
+--R
+--R             +-+
+--R            \|x
+--R   (1)  -----------
+--R           4      2
+--R        c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 373
+
+--S 374 of 762
+r0:=c^(1/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*sqrt(2))-_
+     c^(1/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*sqrt(2))-_
+     1/2*c^(1/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (b^(5/4)*sqrt(2))+1/2*c^(1/4)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*sqrt(2))+(-2)/(b*sqrt(x))
+--R 
+--R
+--R   (2)
+--R       4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R         4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                        +-+4+-+ +-+   4+-+                   +-+4+-+ +-+   4+-+
+--R          4+-+ +-+     \|2 \|c \|x  + \|b      4+-+ +-+     \|2 \|c \|x  - \|b
+--R       - 2\|c \|x atan(-------------------) - 2\|c \|x atan(-------------------)
+--R                               4+-+                                 4+-+
+--R                               \|b                                  \|b
+--R     + 
+--R           +-+4+-+
+--R       - 4\|2 \|b
+--R  /
+--R        +-+4+-+ +-+
+--R     2b\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 374
+
+--S 375 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 375
+
+)clear all
+
+--S 376 of 762
+t0:=1/((b*x^2+c*x^4)*sqrt(x))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R            4      2  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 376
+
+--S 377 of 762
+r0:=(-2/3)/(b*x^(3/2))+c^(3/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(7/4)*sqrt(2))-c^(3/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(7/4)*sqrt(2))+1/2*c^(3/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*sqrt(2))-1/2*c^(3/4)*log(sqrt(b)+_
+     x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 3x \|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R          4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       3x \|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                           +-+4+-+ +-+   4+-+
+--R            4+-+3 +-+     \|2 \|c \|x  + \|b
+--R       - 6x \|c  \|x atan(-------------------)
+--R                                  4+-+
+--R                                  \|b
+--R     + 
+--R                           +-+4+-+ +-+   4+-+
+--R            4+-+3 +-+     \|2 \|c \|x  - \|b       +-+4+-+3
+--R       - 6x \|c  \|x atan(-------------------) - 4\|2 \|b
+--R                                  4+-+
+--R                                  \|b
+--R  /
+--R          +-+4+-+3 +-+
+--R     6b x\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 377
+
+--S 378 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 378
+
+)clear all
+
+--S 379 of 762
+t0:=1/(x^(3/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R            5      3  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 379
+
+--S 380 of 762
+r0:=(-2/5)/(b*x^(5/2))-c^(5/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(9/4)*sqrt(2))+c^(5/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(9/4)*sqrt(2))+1/2*c^(5/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(9/4)*sqrt(2))-1/2*c^(5/4)*log(sqrt(b)+x*_
+     sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*sqrt(2))+_
+     2*c/(b^2*sqrt(x))
+--R 
+--R
+--R   (2)
+--R             2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 5c x  \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           2 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       5c x  \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R            2 4+-+ +-+     \|2 \|c \|x  + \|b
+--R       10c x  \|c \|x atan(-------------------)
+--R                                   4+-+
+--R                                   \|b
+--R     + 
+--R                            +-+4+-+ +-+   4+-+
+--R            2 4+-+ +-+     \|2 \|c \|x  - \|b          2       +-+4+-+
+--R       10c x  \|c \|x atan(------------------- + (20c x  - 4b)\|2 \|b
+--R                                   4+-+
+--R                                   \|b
+--R  /
+--R        2 2 +-+4+-+ +-+
+--R     10b x \|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 380
+
+--S 381 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 381
+
+)clear all
+
+--S 382 of 762
+t0:=1/(x^(5/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R            6      4  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 382
+
+--S 383 of 762
+r0:=(-2/7)/(b*x^(7/2))+2/3*c/(b^2*x^(3/2))-c^(7/4)*atan(1-c^(1/4)*_
+     sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*sqrt(2))+c^(7/4)*atan(1+_
+     c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*sqrt(2))-1/2*c^(7/4)*_
+     log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*_
+     sqrt(2))+1/2*c^(7/4)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            3 4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       21c x  \|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              3 4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 21c x  \|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R            3 4+-+3 +-+     \|2 \|c \|x  + \|b
+--R       42c x  \|c  \|x atan(-------------------)
+--R                                    4+-+
+--R                                    \|b
+--R     + 
+--R                             +-+4+-+ +-+   4+-+
+--R            3 4+-+3 +-+     \|2 \|c \|x  - \|b          2        +-+4+-+3
+--R       42c x  \|c  \|x atan(------------------- + (28c x  - 12b)\|2 \|b
+--R                                    4+-+
+--R                                    \|b
+--R  /
+--R        2 3 +-+4+-+3 +-+
+--R     42b x \|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 383
+
+--S 384 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 384
+
+)clear all
+
+--S 385 of 762
+t0:=1/(x^(7/2)*(b*x^2+c*x^4))
+--R 
+--R
+--R                1
+--R   (1)  -----------------
+--R            7      5  +-+
+--R        (c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 385
+
+--S 386 of 762
+r0:=(-2/9)/(b*x^(9/2))+2/5*c/(b^2*x^(5/2))+c^(9/4)*atan(1-c^(1/4)*_
+     sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*sqrt(2))-c^(9/4)*atan(1+_
+     c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*sqrt(2))-1/2*c^(9/4)*_
+     log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*_
+     sqrt(2))+1/2*c^(9/4)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+     sqrt(x))/(b^(13/4)*sqrt(2))-2*c^2/(b^3*sqrt(x))
+--R 
+--R
+--R   (2)
+--R          2 4 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       45c x  \|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            2 4 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       - 45c x  \|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                              +-+4+-+ +-+   4+-+
+--R            2 4 4+-+ +-+     \|2 \|c \|x  + \|b
+--R       - 90c x  \|c \|x atan(-------------------)
+--R                                     4+-+
+--R                                     \|b
+--R     + 
+--R                              +-+4+-+ +-+   4+-+
+--R            2 4 4+-+ +-+     \|2 \|c \|x  - \|b
+--R       - 90c x  \|c \|x atan(-------------------)
+--R                                     4+-+
+--R                                     \|b
+--R     + 
+--R              2 4          2      2  +-+4+-+
+--R       (- 180c x  + 36b c x  - 20b )\|2 \|b
+--R  /
+--R        3 4 +-+4+-+ +-+
+--R     90b x \|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 386
+
+--S 387 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 387
+
+)clear all
+
+--S 388 of 762
+t0:=x^(19/2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                5 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 388
+
+--S 389 of 762
+r0:=9/10*x^(5/2)/c^2-1/2*x^(9/2)/(c*(b+c*x^2))-9/4*b^(5/4)*atan(1-c^(1/4)*_
+     sqrt(2)*sqrt(x)/b^(1/4))/(c^(13/4)*sqrt(2))+9/4*b^(5/4)*atan(1+_
+     c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(13/4)*sqrt(2))-9/8*b^(5/4)*_
+     log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(13/4)*_
+     sqrt(2))+9/8*b^(5/4)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(c^(13/4)*sqrt(2))-9/2*b*sqrt(x)/c^3
+--R 
+--R
+--R   (2)
+--R               2      2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45b c x  + 45b )\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 2      2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45b c x  - 45b )\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2      2 4+-+     \|2 \|c \|x  + \|b
+--R       (90b c x  + 90b )\|b atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2      2 4+-+     \|2 \|c \|x  - \|b
+--R       (90b c x  + 90b )\|b atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R           2 4           2       2  +-+4+-+ +-+
+--R       (16c x  - 144b c x  - 180b )\|2 \|c \|x
+--R  /
+--R         4 2        3  +-+4+-+
+--R     (40c x  + 40b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 389
+
+--S 390 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 390
+
+)clear all
+
+--S 391 of 762
+t0:=x^(17/2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                4 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 391
+
+--S 392 of 762
+r0:=7/6*x^(3/2)/c^2-1/2*x^(7/2)/(c*(b+c*x^2))+7/4*b^(3/4)*atan(1-c^(1/4)_
+     *sqrt(2)*sqrt(x)/b^(1/4))/(c^(11/4)*sqrt(2))-7/4*b^(3/4)*_
+     atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(11/4)*sqrt(2))-_
+     7/8*b^(3/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+     sqrt(x))/(c^(11/4)*sqrt(2))+7/8*b^(3/4)*log(sqrt(b)+x*sqrt(c)+_
+     b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2       4+-+3     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21c x  + 21b)\|b  log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               2       4+-+3       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21c x  - 21b)\|b  log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2       4+-+3     \|2 \|c \|x  + \|b
+--R       (- 42c x  - 42b)\|b  atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R                                  +-+4+-+ +-+   4+-+
+--R               2       4+-+3     \|2 \|c \|x  - \|b
+--R       (- 42c x  - 42b)\|b  atan(-------------------)
+--R                                         4+-+
+--R                                         \|b
+--R     + 
+--R             3          +-+4+-+3 +-+
+--R       (16c x  + 28b x)\|2 \|c  \|x
+--R  /
+--R         3 2        2  +-+4+-+3
+--R     (24c x  + 24b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 392
+
+--S 393 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 393
+
+)clear all
+
+--S 394 of 762
+t0:=x^(15/2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                3 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 394
+
+--S 395 of 762
+r0:=-1/2*x^(5/2)/(c*(b+c*x^2))+5/4*b^(1/4)*atan(1-c^(1/4)*sqrt(2)*_
+     sqrt(x)/b^(1/4))/(c^(9/4)*sqrt(2))-5/4*b^(1/4)*atan(1+c^(1/4)*_
+     sqrt(2)*sqrt(x)/b^(1/4))/(c^(9/4)*sqrt(2))+5/8*b^(1/4)*_
+     log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(c^(9/4)*_
+     sqrt(2))-5/8*b^(1/4)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(c^(9/4)*sqrt(2))+5/2*sqrt(x)/c^2
+--R 
+--R
+--R   (2)
+--R              2      4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5c x  - 5b)\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            2      4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5c x  + 5b)\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                 +-+4+-+ +-+   4+-+
+--R               2       4+-+     \|2 \|c \|x  + \|b
+--R       (- 10c x  - 10b)\|b atan(-------------------)
+--R                                        4+-+
+--R                                        \|b
+--R     + 
+--R                               +-+4+-+ +-+   4+-+
+--R             2       4+-+     \|2 \|c \|x  - \|b           2        +-+4+-+ +-+
+--R     (- 10c x  - 10b)\|b atan(-------------------) + (16c x  + 20b)\|2 \|c \|x
+--R                                      4+-+
+--R                                      \|b
+--R  /
+--R        3 2       2  +-+4+-+
+--R     (8c x  + 8b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 395
+
+--S 396 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 396
+
+)clear all
+
+--S 397 of 762
+t0:=x^(13/2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                2 +-+
+--R               x \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 397
+
+--S 398 of 762
+r0:=-1/2*x^(3/2)/(c*(b+c*x^2))-3/4*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+     b^(1/4))/(b^(1/4)*c^(7/4)*sqrt(2))+3/4*atan(1+c^(1/4)*sqrt(2)*_
+     sqrt(x)/b^(1/4))/(b^(1/4)*c^(7/4)*sqrt(2))+3/8*log(sqrt(b)+_
+     x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*c^(7/4)*_
+     sqrt(2))-3/8*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+     sqrt(x))/(b^(1/4)*c^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R              2           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3c x  - 3b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            2             +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3c x  + 3b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|c \|x  + \|b
+--R       (6c x  + 6b)atan(-------------------)
+--R                                4+-+
+--R                                \|b
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|c \|x  - \|b        +-+4+-+4+-+3 +-+
+--R       (6c x  + 6b)atan(-------------------) - 4x\|2 \|b \|c  \|x
+--R                                4+-+
+--R                                \|b
+--R  /
+--R        2 2         +-+4+-+4+-+3
+--R     (8c x  + 8b c)\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 398
+
+--S 399 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 399
+
+)clear all
+
+--S 400 of 762
+t0:=x^(11/2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                 +-+
+--R               x\|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 400
+
+--S 401 of 762
+r0:=-1/4*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(5/4)*_
+     sqrt(2))+1/4*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*_
+     c^(5/4)*sqrt(2))-1/8*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(3/4)*c^(5/4)*sqrt(2))+1/8*log(sqrt(b)+_
+     x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*c^(5/4)*_
+     sqrt(2))-1/2*sqrt(x)/(c*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R           2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (c x  + b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R             2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- c x  - b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|c \|x  + \|b
+--R       (2c x  + 2b)atan(-------------------)
+--R                                4+-+
+--R                                \|b
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|c \|x  - \|b       +-+4+-+3 4+-+ +-+
+--R       (2c x  + 2b)atan(-------------------) - 4\|2 \|b   \|c \|x
+--R                                4+-+
+--R                                \|b
+--R  /
+--R        2 2         +-+4+-+3 4+-+
+--R     (8c x  + 8b c)\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 401
+
+--S 402 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 402
+
+)clear all
+
+--S 403 of 762
+t0:=x^(9/2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                 +-+
+--R                \|x
+--R   (1)  -------------------
+--R         2 4         2    2
+--R        c x  + 2b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 403
+
+--S 404 of 762
+r0:=1/2*x^(3/2)/(b*(b+c*x^2))-1/4*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/_
+     b^(1/4))/(b^(5/4)*c^(3/4)*sqrt(2))+1/4*atan(1+c^(1/4)*sqrt(2)*_
+     sqrt(x)/b^(1/4))/(b^(5/4)*c^(3/4)*sqrt(2))+1/8*log(sqrt(b)+_
+     x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*c^(3/4)*_
+     sqrt(2))-1/8*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+     sqrt(x))/(b^(5/4)*c^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2          +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- c x  - b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           2            +-+4+-+4+-+ +-+     +-+    +-+
+--R       (c x  + b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|c \|x  + \|b
+--R       (2c x  + 2b)atan(-------------------)
+--R                                4+-+
+--R                                \|b
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|c \|x  - \|b        +-+4+-+4+-+3 +-+
+--R       (2c x  + 2b)atan(-------------------) + 4x\|2 \|b \|c  \|x
+--R                                4+-+
+--R                                \|b
+--R  /
+--R            2     2  +-+4+-+4+-+3
+--R     (8b c x  + 8b )\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 404
+
+--S 405 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 405
+
+)clear all
+
+--S 406 of 762
+t0:=x^(7/2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                 +-+
+--R                \|x
+--R   (1)  --------------------
+--R         2 5         3    2
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 406
+
+--S 407 of 762
+r0:=-3/4*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(7/4)*c^(1/4)*_
+     sqrt(2))+3/4*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(7/4)*_
+     c^(1/4)*sqrt(2))-3/8*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(7/4)*c^(1/4)*sqrt(2))+3/8*log(sqrt(b)+_
+     x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*c^(1/4)*_
+     sqrt(2))+1/2*sqrt(x)/(b*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R            2           +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3c x  + 3b)log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              2             +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3c x  - 3b)log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|c \|x  + \|b
+--R       (6c x  + 6b)atan(-------------------)
+--R                                4+-+
+--R                                \|b
+--R     + 
+--R                         +-+4+-+ +-+   4+-+
+--R            2           \|2 \|c \|x  - \|b       +-+4+-+3 4+-+ +-+
+--R       (6c x  + 6b)atan(-------------------) + 4\|2 \|b   \|c \|x
+--R                                4+-+
+--R                                \|b
+--R  /
+--R            2     2  +-+4+-+3 4+-+
+--R     (8b c x  + 8b )\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 407
+
+--S 408 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 408
+
+)clear all
+
+--S 409 of 762
+t0:=x^(5/2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  +-+
+--R                 \|x
+--R   (1)  ---------------------
+--R         2 6         4    2 2
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 409
+
+--S 410 of 762
+r0:=5/4*c^(1/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(9/4)*_
+     sqrt(2))-5/4*c^(1/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(9/4)*sqrt(2))-5/8*c^(1/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*sqrt(2))+5/8*c^(1/4)*_
+     log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (b^(9/4)*sqrt(2))+(-5/2)/(b^2*sqrt(x))+1/2/(b*(b+c*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R            2      4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5c x  + 5b)\|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              2      4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5c x  - 5b)\|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R               2       4+-+ +-+     \|2 \|c \|x  + \|b
+--R       (- 10c x  - 10b)\|c \|x atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R               2       4+-+ +-+     \|2 \|c \|x  - \|b
+--R       (- 10c x  - 10b)\|c \|x atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R               2        +-+4+-+
+--R       (- 20c x  - 16b)\|2 \|b
+--R  /
+--R        2   2     3  +-+4+-+ +-+
+--R     (8b c x  + 8b )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 410
+
+--S 411 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 411
+
+)clear all
+
+--S 412 of 762
+t0:=x^(3/2)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  +-+
+--R                 \|x
+--R   (1)  ---------------------
+--R         2 7         5    2 3
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 412
+
+--S 413 of 762
+r0:=(-7/6)/(b^2*x^(3/2))+1/2/(b*x^(3/2)*(b+c*x^2))+7/4*c^(3/4)*_
+     atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*sqrt(2))-_
+     7/4*c^(3/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*_
+     sqrt(2))+7/8*c^(3/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(11/4)*sqrt(2))-7/8*c^(3/4)*log(sqrt(b)+_
+     x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3         4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21c x  - 21b x)\|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R             3         4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21c x  + 21b x)\|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R               3         4+-+3 +-+     \|2 \|c \|x  + \|b
+--R       (- 42c x  - 42b x)\|c  \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|b
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R               3         4+-+3 +-+     \|2 \|c \|x  - \|b
+--R       (- 42c x  - 42b x)\|c  \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|b
+--R     + 
+--R               2        +-+4+-+3
+--R       (- 28c x  - 16b)\|2 \|b
+--R  /
+--R         2   3      3   +-+4+-+3 +-+
+--R     (24b c x  + 24b x)\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 413
+
+--S 414 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 414
+
+)clear all
+
+--S 415 of 762
+t0:=sqrt(x)/(b*x^2+c*x^4)^2
+--R 
+--R
+--R                  +-+
+--R                 \|x
+--R   (1)  ---------------------
+--R         2 8         6    2 4
+--R        c x  + 2b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 415
+
+--S 416 of 762
+r0:=(-9/10)/(b^2*x^(5/2))+1/2/(b*x^(5/2)*(b+c*x^2))-9/4*c^(5/4)*_
+     atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*sqrt(2))+_
+     9/4*c^(5/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*_
+     sqrt(2))+9/8*c^(5/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(13/4)*sqrt(2))-9/8*c^(5/4)*log(sqrt(b)+_
+     x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*sqrt(2))+_
+     9/2*c/(b^3*sqrt(x))
+--R 
+--R
+--R   (2)
+--R             2 4          2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45c x  - 45b c x )\|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           2 4          2 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45c x  + 45b c x )\|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R           2 4          2 4+-+ +-+     \|2 \|c \|x  + \|b
+--R       (90c x  + 90b c x )\|c \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|b
+--R     + 
+--R                                        +-+4+-+ +-+   4+-+
+--R           2 4          2 4+-+ +-+     \|2 \|c \|x  - \|b
+--R       (90c x  + 90b c x )\|c \|x atan(-------------------)
+--R                                               4+-+
+--R                                               \|b
+--R     + 
+--R            2 4           2      2  +-+4+-+
+--R       (180c x  + 144b c x  - 16b )\|2 \|b
+--R  /
+--R         3   4      4 2  +-+4+-+ +-+
+--R     (40b c x  + 40b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 416
+
+--S 417 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 417
+
+)clear all
+
+--S 418 of 762
+t0:=1/((b*x^2+c*x^4)^2*sqrt(x))
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R          2 8         6    2 4  +-+
+--R        (c x  + 2b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 418
+
+--S 419 of 762
+r0:=(-11/14)/(b^2*x^(7/2))+11/6*c/(b^3*x^(3/2))+1/2/(b*x^(7/2)*(b+c*x^2))-_
+     11/4*c^(7/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(15/4)*_
+     sqrt(2))+11/4*c^(7/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(15/4)*sqrt(2))-11/8*c^(7/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(b^(15/4)*sqrt(2))+11/8*c^(7/4)*_
+     log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (b^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            2 5           3 4+-+3 +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (231c x  + 231b c x )\|c  \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              2 5           3 4+-+3 +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 231c x  - 231b c x )\|c  \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                           +-+4+-+ +-+   4+-+
+--R            2 5           3 4+-+3 +-+     \|2 \|c \|x  + \|b
+--R       (462c x  + 462b c x )\|c  \|x atan(-------------------)
+--R                                                  4+-+
+--R                                                  \|b
+--R     + 
+--R                                           +-+4+-+ +-+   4+-+
+--R            2 5           3 4+-+3 +-+     \|2 \|c \|x  - \|b
+--R       (462c x  + 462b c x )\|c  \|x atan(-------------------)
+--R                                                  4+-+
+--R                                                  \|b
+--R     + 
+--R            2 4           2      2  +-+4+-+3
+--R       (308c x  + 176b c x  - 48b )\|2 \|b
+--R  /
+--R          3   5       4 3  +-+4+-+3 +-+
+--R     (168b c x  + 168b x )\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 419
+
+--S 420 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 420
+
+)clear all
+
+--S 421 of 762
+t0:=1/(x^(3/2)*(b*x^2+c*x^4)^2)
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R          2 9         7    2 5  +-+
+--R        (c x  + 2b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 421
+
+--S 422 of 762
+r0:=(-13/18)/(b^2*x^(9/2))+13/10*c/(b^3*x^(5/2))+1/2/(b*x^(9/2)*_
+     (b+c*x^2))+13/4*c^(9/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(17/4)*sqrt(2))-13/4*c^(9/4)*atan(1+c^(1/4)*sqrt(2)*_
+     sqrt(x)/b^(1/4))/(b^(17/4)*sqrt(2))-13/8*c^(9/4)*log(sqrt(b)+_
+     x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*sqrt(2))+_
+     13/8*c^(9/4)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+     sqrt(x))/(b^(17/4)*sqrt(2))-13/2*c^2/(b^4*sqrt(x))
+--R 
+--R
+--R   (2)
+--R            3 6         2 4 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (585c x  + 585b c x )\|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              3 6         2 4 4+-+ +-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 585c x  - 585b c x )\|c \|x log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                              +-+4+-+ +-+   4+-+
+--R               3 6          2 4 4+-+ +-+     \|2 \|c \|x  + \|b
+--R       (- 1170c x  - 1170b c x )\|c \|x atan(-------------------)
+--R                                                     4+-+
+--R                                                     \|b
+--R     + 
+--R                                              +-+4+-+ +-+   4+-+
+--R               3 6          2 4 4+-+ +-+     \|2 \|c \|x  - \|b
+--R       (- 1170c x  - 1170b c x )\|c \|x atan(-------------------)
+--R                                                     4+-+
+--R                                                     \|b
+--R     + 
+--R               3 6          2 4       2   2      3  +-+4+-+
+--R       (- 2340c x  - 1872b c x  + 208b c x  - 80b )\|2 \|b
+--R  /
+--R          4   6       5 4  +-+4+-+ +-+
+--R     (360b c x  + 360b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 422
+
+--S 423 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 423
+
+)clear all
+
+--S 424 of 762
+t0:=x^(23/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     5 +-+
+--R                    x \|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 424
+
+--S 425 of 762
+r0:=-1/4*x^(9/2)/(c*(b+c*x^2)^2)-9/16*x^(5/2)/(c^2*(b+c*x^2))+_
+     45/32*b^(1/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(c^(13/4)*_
+     sqrt(2))-45/32*b^(1/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (c^(13/4)*sqrt(2))+45/64*b^(1/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(c^(13/4)*sqrt(2))-45/64*b^(1/4)*_
+     log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (c^(13/4)*sqrt(2))+45/16*sqrt(x)/c^3
+--R 
+--R
+--R   (2)
+--R             2 4          2      2 4+-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 45c x  - 90b c x  - 45b )\|b log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           2 4          2      2 4+-+       +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45c x  + 90b c x  + 45b )\|b log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                              +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+     \|2 \|c \|x  + \|b
+--R       (- 90c x  - 180b c x  - 90b )\|b atan(-------------------)
+--R                                                     4+-+
+--R                                                     \|b
+--R     + 
+--R                                              +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+     \|2 \|c \|x  - \|b
+--R       (- 90c x  - 180b c x  - 90b )\|b atan(-------------------)
+--R                                                     4+-+
+--R                                                     \|b
+--R     + 
+--R            2 4           2       2  +-+4+-+ +-+
+--R       (128c x  + 324b c x  + 180b )\|2 \|c \|x
+--R  /
+--R         5 4         4 2      2 3  +-+4+-+
+--R     (64c x  + 128b c x  + 64b c )\|2 \|c
+--R                                                    Type: Expression(Integer)
+--E 425
+
+--S 426 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 426
+
+)clear all
+
+--S 427 of 762
+t0:=x^(21/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     4 +-+
+--R                    x \|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 427
+
+--S 428 of 762
+r0:=-1/4*x^(7/2)/(c*(b+c*x^2)^2)-7/16*x^(3/2)/(c^2*(b+c*x^2))-_
+     21/32*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(1/4)*_
+     c^(11/4)*sqrt(2))+21/32*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(1/4)*c^(11/4)*sqrt(2))+21/64*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(b^(1/4)*c^(11/4)*sqrt(2))-21/64*_
+     log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (b^(1/4)*c^(11/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R             2 4          2      2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21c x  - 42b c x  - 21b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R           2 4          2      2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21c x  + 42b c x  + 21b )log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|c \|x  + \|b
+--R       (42c x  + 84b c x  + 42b )atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|c \|x  - \|b
+--R       (42c x  + 84b c x  + 42b )atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R               3          +-+4+-+4+-+3 +-+
+--R       (- 44c x  - 28b x)\|2 \|b \|c  \|x
+--R  /
+--R         4 4         3 2      2 2  +-+4+-+4+-+3
+--R     (64c x  + 128b c x  + 64b c )\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 428
+
+--S 429 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 429
+
+)clear all
+
+--S 430 of 762
+t0:=x^(19/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     3 +-+
+--R                    x \|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 430
+
+--S 431 of 762
+r0:=-1/4*x^(5/2)/(c*(b+c*x^2)^2)-5/32*atan(1-c^(1/4)*sqrt(2)*_
+     sqrt(x)/b^(1/4))/(b^(3/4)*c^(9/4)*sqrt(2))+5/32*atan(1+c^(1/4)*_
+     sqrt(2)*sqrt(x)/b^(1/4))/(b^(3/4)*c^(9/4)*sqrt(2))-5/64*_
+     log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (b^(3/4)*c^(9/4)*sqrt(2))+5/64*log(sqrt(b)+x*sqrt(c)+b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(b^(3/4)*c^(9/4)*sqrt(2))-_
+     5/16*sqrt(x)/(c^2*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R          2 4          2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5c x  + 10b c x  + 5b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            2 4          2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5c x  - 10b c x  - 5b )log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|c \|x  + \|b
+--R       (10c x  + 20b c x  + 10b )atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|c \|x  - \|b
+--R       (10c x  + 20b c x  + 10b )atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R               2        +-+4+-+3 4+-+ +-+
+--R       (- 36c x  - 20b)\|2 \|b   \|c \|x
+--R  /
+--R         4 4         3 2      2 2  +-+4+-+3 4+-+
+--R     (64c x  + 128b c x  + 64b c )\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 431
+
+--S 432 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 432
+
+)clear all
+
+--S 433 of 762
+t0:=x^(17/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                     2 +-+
+--R                    x \|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 433
+
+--S 434 of 762
+r0:=-1/4*x^(3/2)/(c*(b+c*x^2)^2)+3/16*x^(3/2)/(b*c*(b+c*x^2))-_
+     3/32*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(5/4)*c^(7/4)*_
+     sqrt(2))+3/32*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(5/4)*c^(7/4)*sqrt(2))+3/64*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(b^(5/4)*c^(7/4)*sqrt(2))-3/64*_
+     log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (b^(5/4)*c^(7/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            2 4         2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3c x  - 6b c x  - 3b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R          2 4         2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3c x  + 6b c x  + 3b )log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|c \|x  + \|b
+--R       (6c x  + 12b c x  + 6b )atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|c \|x  - \|b
+--R       (6c x  + 12b c x  + 6b )atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R             3         +-+4+-+4+-+3 +-+
+--R       (12c x  - 4b x)\|2 \|b \|c  \|x
+--R  /
+--R           3 4       2 2 2      3   +-+4+-+4+-+3
+--R     (64b c x  + 128b c x  + 64b c)\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 434
+
+--S 435 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 435
+
+)clear all
+
+--S 436 of 762
+t0:=x^(15/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      +-+
+--R                    x\|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 436
+
+--S 437 of 762
+r0:=-3/32*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(7/4)*c^(5/4)*_
+     sqrt(2))+3/32*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(7/4)*_
+     c^(5/4)*sqrt(2))-3/64*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(7/4)*c^(5/4)*sqrt(2))+3/64*log(sqrt(b)+_
+     x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(7/4)*c^(5/4)*_
+     sqrt(2))-1/4*sqrt(x)/(c*(b+c*x^2)^2)+1/16*sqrt(x)/(b*c*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R          2 4         2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (3c x  + 6b c x  + 3b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R            2 4         2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 3c x  - 6b c x  - 3b )log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|c \|x  + \|b
+--R       (6c x  + 12b c x  + 6b )atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R                                     +-+4+-+ +-+   4+-+
+--R          2 4          2     2      \|2 \|c \|x  - \|b
+--R       (6c x  + 12b c x  + 6b )atan(-------------------)
+--R                                            4+-+
+--R                                            \|b
+--R     + 
+--R            2        +-+4+-+3 4+-+ +-+
+--R       (4c x  - 12b)\|2 \|b   \|c \|x
+--R  /
+--R           3 4       2 2 2      3   +-+4+-+3 4+-+
+--R     (64b c x  + 128b c x  + 64b c)\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 437
+
+--S 438 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 438
+
+)clear all
+
+--S 439 of 762
+t0:=x^(13/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      +-+
+--R                     \|x
+--R   (1)  -----------------------------
+--R         3 6       2 4     2   2    3
+--R        c x  + 3b c x  + 3b c x  + b
+--R                                                    Type: Expression(Integer)
+--E 439
+
+--S 440 of 762
+r0:=1/4*x^(3/2)/(b*(b+c*x^2)^2)+5/16*x^(3/2)/(b^2*(b+c*x^2))-_
+     5/32*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(9/4)*c^(3/4)*_
+     sqrt(2))+5/32*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(9/4)*_
+     c^(3/4)*sqrt(2))+5/64*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(9/4)*c^(3/4)*sqrt(2))-5/64*log(sqrt(b)+_
+     x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(9/4)*c^(3/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R            2 4          2     2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 5c x  - 10b c x  - 5b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R          2 4          2     2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (5c x  + 10b c x  + 5b )log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|c \|x  + \|b
+--R       (10c x  + 20b c x  + 10b )atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|c \|x  - \|b
+--R       (10c x  + 20b c x  + 10b )atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R             3          +-+4+-+4+-+3 +-+
+--R       (20c x  + 36b x)\|2 \|b \|c  \|x
+--R  /
+--R         2 2 4       3   2      4  +-+4+-+4+-+3
+--R     (64b c x  + 128b c x  + 64b )\|2 \|b \|c
+--R                                                    Type: Expression(Integer)
+--E 440
+
+--S 441 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 441
+
+)clear all
+
+--S 442 of 762
+t0:=x^(11/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                      +-+
+--R                     \|x
+--R   (1)  ------------------------------
+--R         3 7       2 5     2   3    3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 442
+
+--S 443 of 762
+r0:=-21/32*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(11/4)*c^(1/4)*_
+     sqrt(2))+21/32*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(11/4)*c^(1/4)*sqrt(2))-21/64*log(sqrt(b)+x*sqrt(c)-_
+     b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(11/4)*c^(1/4)*sqrt(2))+_
+     21/64*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (b^(11/4)*c^(1/4)*sqrt(2))+1/4*sqrt(x)/(b*(b+c*x^2)^2)+_
+     7/16*sqrt(x)/(b^2*(b+c*x^2))
+--R 
+--R
+--R   (2)
+--R           2 4          2      2      +-+4+-+4+-+ +-+     +-+    +-+
+--R       (21c x  + 42b c x  + 21b )log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R             2 4          2      2        +-+4+-+4+-+ +-+     +-+    +-+
+--R       (- 21c x  - 42b c x  - 21b )log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|c \|x  + \|b
+--R       (42c x  + 84b c x  + 42b )atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R                                       +-+4+-+ +-+   4+-+
+--R           2 4          2      2      \|2 \|c \|x  - \|b
+--R       (42c x  + 84b c x  + 42b )atan(-------------------)
+--R                                              4+-+
+--R                                              \|b
+--R     + 
+--R             2        +-+4+-+3 4+-+ +-+
+--R       (28c x  + 44b)\|2 \|b   \|c \|x
+--R  /
+--R         2 2 4       3   2      4  +-+4+-+3 4+-+
+--R     (64b c x  + 128b c x  + 64b )\|2 \|b   \|c
+--R                                                    Type: Expression(Integer)
+--E 443
+
+--S 444 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 444
+
+)clear all
+
+--S 445 of 762
+t0:=x^(9/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       +-+
+--R                      \|x
+--R   (1)  -------------------------------
+--R         3 8       2 6     2   4    3 2
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 445
+
+--S 446 of 762
+r0:=45/32*c^(1/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(13/4)*_
+     sqrt(2))-45/32*c^(1/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(13/4)*sqrt(2))-45/64*c^(1/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*_
+     c^(1/4)*sqrt(2)*sqrt(x))/(b^(13/4)*sqrt(2))+45/64*c^(1/4)*_
+     log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/_
+     (b^(13/4)*sqrt(2))+(-45/16)/(b^3*sqrt(x))+1/4/(b*(b+c*x^2)^2*_
+     sqrt(x))+9/16/(b^2*(b+c*x^2)*sqrt(x))
+--R 
+--R
+--R   (2)
+--R           2 4          2      2 4+-+ +-+     +-+4+-+4+-+ +-+     +-+    +-+
+--R       (45c x  + 90b c x  + 45b )\|c \|x log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R               2 4          2      2 4+-+ +-+
+--R         (- 45c x  - 90b c x  - 45b )\|c \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+ +-+     \|2 \|c \|x  + \|b
+--R       (- 90c x  - 180b c x  - 90b )\|c \|x atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|b
+--R     + 
+--R                                                  +-+4+-+ +-+   4+-+
+--R             2 4           2      2 4+-+ +-+     \|2 \|c \|x  - \|b
+--R       (- 90c x  - 180b c x  - 90b )\|c \|x atan(-------------------)
+--R                                                         4+-+
+--R                                                         \|b
+--R     + 
+--R              2 4           2       2  +-+4+-+
+--R       (- 180c x  - 324b c x  - 128b )\|2 \|b
+--R  /
+--R         3 2 4       4   2      5  +-+4+-+ +-+
+--R     (64b c x  + 128b c x  + 64b )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 446
+
+--S 447 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 447
+
+)clear all
+
+--S 448 of 762
+t0:=x^(7/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       +-+
+--R                      \|x
+--R   (1)  -------------------------------
+--R         3 9       2 7     2   5    3 3
+--R        c x  + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 448
+
+--S 449 of 762
+r0:=(-77/48)/(b^3*x^(3/2))+1/4/(b*x^(3/2)*(b+c*x^2)^2)+11/16/(b^2*x^(3/2)*_
+     (b+c*x^2))+77/32*c^(3/4)*atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(15/4)*sqrt(2))-77/32*c^(3/4)*atan(1+c^(1/4)*sqrt(2)*_
+     sqrt(x)/b^(1/4))/(b^(15/4)*sqrt(2))+77/64*c^(3/4)*log(sqrt(b)+_
+     x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(15/4)*sqrt(2))-_
+     77/64*c^(3/4)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*_
+     sqrt(x))/(b^(15/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                2 5           3       2  4+-+3 +-+
+--R         (- 231c x  - 462b c x  - 231b x)\|c  \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              2 5           3       2  4+-+3 +-+
+--R         (231c x  + 462b c x  + 231b x)\|c  \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R              2 5           3       2  4+-+3 +-+     \|2 \|c \|x  + \|b
+--R       (- 462c x  - 924b c x  - 462b x)\|c  \|x atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|b
+--R     + 
+--R                                                      +-+4+-+ +-+   4+-+
+--R              2 5           3       2  4+-+3 +-+     \|2 \|c \|x  - \|b
+--R       (- 462c x  - 924b c x  - 462b x)\|c  \|x atan(-------------------)
+--R                                                             4+-+
+--R                                                             \|b
+--R     + 
+--R              2 4           2       2  +-+4+-+3
+--R       (- 308c x  - 484b c x  - 128b )\|2 \|b
+--R  /
+--R          3 2 5       4   3       5   +-+4+-+3 +-+
+--R     (192b c x  + 384b c x  + 192b x)\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 449
+
+--S 450 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 450
+
+)clear all
+
+--S 451 of 762
+t0:=x^(5/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       +-+
+--R                      \|x
+--R   (1)  --------------------------------
+--R         3 10       2 8     2   6    3 4
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 451
+
+--S 452 of 762
+r0:=(-117/80)/(b^3*x^(5/2))+1/4/(b*x^(5/2)*(b+c*x^2)^2)+13/16/(b^2*_
+     x^(5/2)*(b+c*x^2))-117/32*c^(5/4)*atan(1-c^(1/4)*sqrt(2)*_
+     sqrt(x)/b^(1/4))/(b^(17/4)*sqrt(2))+117/32*c^(5/4)*atan(1+_
+     c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(17/4)*sqrt(2))+117/64*_
+     c^(5/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*sqrt(2)*_
+     sqrt(x))/(b^(17/4)*sqrt(2))-117/64*c^(5/4)*log(sqrt(b)+_
+     x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(17/4)*sqrt(2))+_
+     117/16*c/(b^4*sqrt(x))
+--R 
+--R
+--R   (2)
+--R                3 6          2 4       2   2 4+-+ +-+
+--R         (- 585c x  - 1170b c x  - 585b c x )\|c \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R              3 6          2 4       2   2 4+-+ +-+
+--R         (585c x  + 1170b c x  + 585b c x )\|c \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                         +-+4+-+ +-+   4+-+
+--R             3 6          2 4        2   2 4+-+ +-+     \|2 \|c \|x  + \|b
+--R       (1170c x  + 2340b c x  + 1170b c x )\|c \|x atan(-------------------)
+--R                                                                4+-+
+--R                                                                \|b
+--R     + 
+--R                                                         +-+4+-+ +-+   4+-+
+--R             3 6          2 4        2   2 4+-+ +-+     \|2 \|c \|x  - \|b
+--R       (1170c x  + 2340b c x  + 1170b c x )\|c \|x atan(-------------------)
+--R                                                                4+-+
+--R                                                                \|b
+--R     + 
+--R             3 6          2 4        2   2       3  +-+4+-+
+--R       (2340c x  + 4212b c x  + 1664b c x  - 128b )\|2 \|b
+--R  /
+--R          4 2 6       5   4       6 2  +-+4+-+ +-+
+--R     (320b c x  + 640b c x  + 320b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 452
+
+--S 453 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 453
+
+)clear all
+
+--S 454 of 762
+t0:=x^(3/2)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                       +-+
+--R                      \|x
+--R   (1)  --------------------------------
+--R         3 11       2 9     2   7    3 5
+--R        c x   + 3b c x  + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 454
+
+--S 455 of 762
+r0:=(-165/112)/(b^3*x^(7/2))+55/16*c/(b^4*x^(3/2))+1/4/(b*x^(7/2)*_
+     (b+c*x^2)^2)+15/16/(b^2*x^(7/2)*(b+c*x^2))-165/32*c^(7/4)*_
+     atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(19/4)*sqrt(2))+_
+     165/32*c^(7/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(19/4)*sqrt(2))-165/64*c^(7/4)*log(sqrt(b)+x*sqrt(c)-_
+     b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(19/4)*sqrt(2))+_
+     165/64*c^(7/4)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(19/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R               3 7          2 5        2   3 4+-+3 +-+
+--R         (1155c x  + 2310b c x  + 1155b c x )\|c  \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 3 7          2 5        2   3 4+-+3 +-+
+--R         (- 1155c x  - 2310b c x  - 1155b c x )\|c  \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                                                          +-+4+-+ +-+   4+-+
+--R             3 7          2 5        2   3 4+-+3 +-+     \|2 \|c \|x  + \|b
+--R       (2310c x  + 4620b c x  + 2310b c x )\|c  \|x atan(-------------------)
+--R                                                                 4+-+
+--R                                                                 \|b
+--R     + 
+--R                                                          +-+4+-+ +-+   4+-+
+--R             3 7          2 5        2   3 4+-+3 +-+     \|2 \|c \|x  - \|b
+--R       (2310c x  + 4620b c x  + 2310b c x )\|c  \|x atan(-------------------)
+--R                                                                 4+-+
+--R                                                                 \|b
+--R     + 
+--R             3 6          2 4       2   2       3  +-+4+-+3
+--R       (1540c x  + 2420b c x  + 640b c x  - 128b )\|2 \|b
+--R  /
+--R          4 2 7       5   5       6 3  +-+4+-+3 +-+
+--R     (448b c x  + 896b c x  + 448b x )\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 455
+
+--S 456 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 456
+
+)clear all
+
+--S 457 of 762
+t0:=sqrt(x)/(b*x^2+c*x^4)^3
+--R 
+--R
+--R                        +-+
+--R                       \|x
+--R   (1)  ---------------------------------
+--R         3 12       2 10     2   8    3 6
+--R        c x   + 3b c x   + 3b c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 457
+
+--S 458 of 762
+r0:=(-221/144)/(b^3*x^(9/2))+221/80*c/(b^4*x^(5/2))+1/4/(b*x^(9/2)*_
+     (b+c*x^2)^2)+17/16/(b^2*x^(9/2)*(b+c*x^2))+221/32*c^(9/4)*_
+     atan(1-c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(21/4)*sqrt(2))-_
+     221/32*c^(9/4)*atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/_
+     (b^(21/4)*sqrt(2))-221/64*c^(9/4)*log(sqrt(b)+x*sqrt(c)-_
+     b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(21/4)*sqrt(2))+_
+     221/64*c^(9/4)*log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(21/4)*sqrt(2))-221/16*c^2/(b^5*sqrt(x))
+--R 
+--R
+--R   (2)
+--R               4 8           3 6        2 2 4 4+-+ +-+
+--R         (9945c x  + 19890b c x  + 9945b c x )\|c \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                 4 8           3 6        2 2 4 4+-+ +-+
+--R         (- 9945c x  - 19890b c x  - 9945b c x )\|c \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  4 8           3 6         2 2 4 4+-+ +-+
+--R         (- 19890c x  - 39780b c x  - 19890b c x )\|c \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                  4 8           3 6         2 2 4 4+-+ +-+
+--R         (- 19890c x  - 39780b c x  - 19890b c x )\|c \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                4 8           3 6         2 2 4        3   2       4  +-+4+-+
+--R       (- 39780c x  - 71604b c x  - 28288b c x  + 2176b c x  - 640b )\|2 \|b
+--R  /
+--R           5 2 8        6   6        7 4  +-+4+-+ +-+
+--R     (2880b c x  + 5760b c x  + 2880b x )\|2 \|b \|x
+--R                                                    Type: Expression(Integer)
+--E 458
+
+--S 459 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 459
+
+)clear all
+
+--S 460 of 762
+t0:=1/((b*x^2+c*x^4)^3*sqrt(x))
+--R 
+--R
+--R                           1
+--R   (1)  ---------------------------------------
+--R          3 12       2 10     2   8    3 6  +-+
+--R        (c x   + 3b c x   + 3b c x  + b x )\|x
+--R                                                    Type: Expression(Integer)
+--E 460
+
+--S 461 of 762
+r0:=(-285/176)/(b^3*x^(11/2))+285/112*c/(b^4*x^(7/2))-95/16*c^2/_
+     (b^5*x^(3/2))+1/4/(b*x^(11/2)*(b+c*x^2)^2)+19/16/_
+     (b^2*x^(11/2)*(b+c*x^2))+285/32*c^(11/4)*atan(1-c^(1/4)*_
+     sqrt(2)*sqrt(x)/b^(1/4))/(b^(23/4)*sqrt(2))-285/32*c^(11/4)*_
+     atan(1+c^(1/4)*sqrt(2)*sqrt(x)/b^(1/4))/(b^(23/4)*sqrt(2))+_
+     285/64*c^(11/4)*log(sqrt(b)+x*sqrt(c)-b^(1/4)*c^(1/4)*_
+     sqrt(2)*sqrt(x))/(b^(23/4)*sqrt(2))-285/64*c^(11/4)*_
+     log(sqrt(b)+x*sqrt(c)+b^(1/4)*c^(1/4)*sqrt(2)*sqrt(x))/(b^(23/4)*sqrt(2))
+--R 
+--R
+--R   (2)
+--R                  4 9           3 7         2 2 5 4+-+3 +-+
+--R         (- 21945c x  - 43890b c x  - 21945b c x )\|c  \|x
+--R      *
+--R              +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(\|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                4 9           3 7         2 2 5 4+-+3 +-+
+--R         (21945c x  + 43890b c x  + 21945b c x )\|c  \|x
+--R      *
+--R                +-+4+-+4+-+ +-+     +-+    +-+
+--R         log(- \|2 \|b \|c \|x  + x\|c  + \|b )
+--R     + 
+--R                  4 9           3 7         2 2 5 4+-+3 +-+
+--R         (- 43890c x  - 87780b c x  - 43890b c x )\|c  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  + \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                  4 9           3 7         2 2 5 4+-+3 +-+
+--R         (- 43890c x  - 87780b c x  - 43890b c x )\|c  \|x
+--R      *
+--R               +-+4+-+ +-+   4+-+
+--R              \|2 \|c \|x  - \|b
+--R         atan(-------------------)
+--R                      4+-+
+--R                      \|b
+--R     + 
+--R                4 8           3 6         2 2 4        3   2       4  +-+4+-+3
+--R       (- 29260c x  - 45980b c x  - 12160b c x  + 2432b c x  - 896b )\|2 \|b
+--R  /
+--R           5 2 9        6   7        7 5  +-+4+-+3 +-+
+--R     (4928b c x  + 9856b c x  + 4928b x )\|2 \|b  \|x
+--R                                                    Type: Expression(Integer)
+--E 461
+
+--S 462 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 462
+
+)clear all
+
+--S 463 of 762
+t0:=x^(9/2)*(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R               +-----------+
+--R         4 +-+ |   4      2
+--R   (1)  x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 463
+
+--S 464 of 762
+--r0:=4/77*b^(17/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--  sqrt((b+c*x^2)/b)/((-c)^(13/4)*sqrt(b*x^2+c*x^4))-12/385*b^2*x^(3/2)*_
+-- sqrt(b*x^2+c*x^4)/c^2+4/165*b*x^(7/2)*sqrt(b*x^2+c*x^4)/c+_
+-- 2/15*x^(11/2)*sqrt(b*x^2+c*x^4)+4/77*b^3*sqrt(b*x^2+c*x^4)/(c^3*sqrt(x))
+--E 464
+
+--S 465 of 762
+--d0:=t0-D(r0,x)
+--E 465
+
+)clear all
+
+--S 466 of 762
+t0:=x^(7/2)*(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R               +-----------+
+--R         3 +-+ |   4      2
+--R   (1)  x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 466
+
+--S 467 of 762
+--r0:=28/195*b^(15/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(11/4)*sqrt(b*x^2+c*x^4))-28/195*b^(15/4)*_
+--   x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(11/4)*sqrt(b*x^2+c*x^4))+4/117*b*x^(5/2)*_
+--   sqrt(b*x^2+c*x^4)/c+2/13*x^(9/2)*sqrt(b*x^2+c*x^4)-28/585*b^2*_
+--   sqrt(x)*sqrt(b*x^2+c*x^4)/c^2
+--E 467
+
+--S 468 of 762
+--d0:=t0-D(r0,x)
+--E 468
+
+)clear all
+
+--S 469 of 762
+t0:=x^(5/2)*(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R               +-----------+
+--R         2 +-+ |   4      2
+--R   (1)  x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 469
+
+--S 470 of 762
+--r0:=20/231*b^(13/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(9/4)*sqrt(b*x^2+c*x^4))+4/77*b*x^(3/2)*_
+--   sqrt(b*x^2+c*x^4)/c+2/11*x^(7/2)*sqrt(b*x^2+c*x^4)-20/231*b^2*_
+--   sqrt(b*x^2+c*x^4)/(c^2*sqrt(x))
+--E 470
+
+--S 471 of 762
+--d0:=t0-D(r0,x)
+--E 471
+
+)clear all
+
+--S 472 of 762
+t0:=x^(3/2)*(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R              +-----------+
+--R          +-+ |   4      2
+--R   (1)  x\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 472
+
+--S 473 of 762
+--r0:=4/15*b^(11/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(7/4)*sqrt(b*x^2+c*x^4))-4/15*b^(11/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(7/4)*sqrt(b*x^2+c*x^4))+2/9*x^(5/2)*sqrt(b*x^2+c*x^4)+_
+--   4/45*b*sqrt(x)*sqrt(b*x^2+c*x^4)/c
+--E 473
+
+--S 474 of 762
+--d0:=t0-D(r0,x)
+--E 474
+
+)clear all
+
+--S 475 of 762
+t0:=x^(1/2)*(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R             +-----------+
+--R         +-+ |   4      2
+--R   (1)  \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 475
+
+--S 476 of 762
+--r0:=4/21*b^(9/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(5/4)*sqrt(b*x^2+c*x^4))+2/7*x^(3/2)*_
+--   sqrt(b*x^2+c*x^4)+4/21*b*sqrt(b*x^2+c*x^4)/(c*sqrt(x))
+--E 476
+
+--S 477 of 762
+--d0:=t0-D(r0,x)
+--E 477
+
+)clear all
+
+--S 478 of 762
+t0:=(b*x^2+c*x^4)^(1/2)/x^(1/2)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R              +-+
+--R             \|x
+--R                                                    Type: Expression(Integer)
+--E 478
+
+--S 479 of 762
+--r0:=4/5*b^(7/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(3/4)*sqrt(b*x^2+c*x^4))-4/5*b^(7/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(3/4)*sqrt(b*x^2+c*x^4))+2/5*sqrt(x)*sqrt(b*x^2+c*x^4)
+--E 479
+
+--S 480 of 762
+--d0:=t0-D(r0,x)
+--E 480
+
+)clear all
+
+--S 481 of 762
+t0:=(b*x^2+c*x^4)^(1/2)/x^(3/2)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R               +-+
+--R             x\|x
+--R                                                    Type: Expression(Integer)
+--E 481
+
+--S 482 of 762
+--r0:=4/3*b^(5/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(1/4)*sqrt(b*x^2+c*x^4))+2/3*sqrt(b*x^2+_
+--   c*x^4)/sqrt(x)
+--E 482
+
+--S 483 of 762
+--d0:=t0-D(r0,x)
+--E 483
+
+)clear all
+
+--S 484 of 762
+t0:=(b*x^2+c*x^4)^(1/2)/x^(5/2)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R             2 +-+
+--R            x \|x
+--R                                                    Type: Expression(Integer)
+--E 484
+
+--S 485 of 762
+--r0:=-4*b^(3/4)*(-c)^(1/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/_
+--   b^(1/4)),-1)*sqrt((b+c*x^2)/b)/sqrt(b*x^2+c*x^4)+4*b^(3/4)*_
+--   (-c)^(1/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/sqrt(b*x^2+c*x^4)-2*sqrt(b*x^2+c*x^4)/x^(3/2)
+--E 485
+
+--S 486 of 762
+--d0:=t0-D(r0,x)
+--E 486
+
+)clear all
+
+--S 487 of 762
+t0:=(b*x^2+c*x^4)^(1/2)/x^(7/2)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R             3 +-+
+--R            x \|x
+--R                                                    Type: Expression(Integer)
+--E 487
+
+--S 488 of 762
+--r0:=-4/3*b^(1/4)*(-c)^(3/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/_
+--   b^(1/4)),-1)*sqrt((b+c*x^2)/b)/sqrt(b*x^2+c*x^4)-2/3*_
+--   sqrt(b*x^2+c*x^4)/x^(5/2)
+--E 488
+
+--S 489 of 762
+--d0:=t0-D(r0,x)
+--E 489
+
+)clear all
+
+--S 490 of 762
+t0:=(b*x^2+c*x^4)^(1/2)/x^(9/2)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R             4 +-+
+--R            x \|x
+--R                                                    Type: Expression(Integer)
+--E 490
+
+--S 491 of 762
+--r0:=4/5*(-c)^(5/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/(b^(1/4)*sqrt(b*x^2+c*x^4))-4/5*(-c)^(5/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(1/4)*sqrt(b*x^2+c*x^4))-2/5*sqrt(b*x^2+c*x^4)/x^(7/2)-4/5*c*_
+--   sqrt(b*x^2+c*x^4)/(b*x^(3/2))
+--E 491
+
+--S 492 of 762
+--d0:=t0-D(r0,x)
+--E 492
+
+)clear all
+
+--S 493 of 762
+t0:=(b*x^2+c*x^4)^(1/2)/x^(11/2)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R             5 +-+
+--R            x \|x
+--R                                                    Type: Expression(Integer)
+--E 493
+
+--S 494 of 762
+--r0:=-4/21*(-c)^(7/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/(b^(3/4)*sqrt(b*x^2+c*x^4))-2/7*sqrt(b*x^2+_
+--   c*x^4)/x^(9/2)-4/21*c*sqrt(b*x^2+c*x^4)/(b*x^(5/2))
+--E 494
+
+--S 495 of 762
+--d0:=t0-D(r0,x)
+--E 495
+
+)clear all
+
+--S 496 of 762
+t0:=(b*x^2+c*x^4)^(1/2)/x^(13/2)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R             6 +-+
+--R            x \|x
+--R                                                    Type: Expression(Integer)
+--E 496
+
+--S 497 of 762
+--r0:=4/15*(-c)^(9/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/(b^(5/4)*sqrt(b*x^2+c*x^4))-4/15*(-c)^(9/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(5/4)*sqrt(b*x^2+c*x^4))-2/9*sqrt(b*x^2+c*x^4)/x^(11/2)-_
+--   4/45*c*sqrt(b*x^2+c*x^4)/(b*x^(7/2))+4/15*c^2*sqrt(b*x^2+c*x^4)/_
+--   (b^2*x^(3/2))
+--E 497
+
+--S 498 of 762
+--d0:=t0-D(r0,x)
+--E 498
+
+)clear all
+
+--S 499 of 762
+t0:=(b*x^2+c*x^4)^(1/2)/x^(15/2)
+--R 
+--R
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R   (1)  --------------
+--R             7 +-+
+--R            x \|x
+--R                                                    Type: Expression(Integer)
+--E 499
+
+--S 500 of 762
+--r0:=-20/231*(-c)^(11/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/(b^(7/4)*sqrt(b*x^2+c*x^4))-2/11*sqrt(b*x^2+c*x^4)/_
+--   x^(13/2)-4/77*c*sqrt(b*x^2+c*x^4)/(b*x^(9/2))+20/231*c^2*sqrt(b*x^2+_
+--   c*x^4)/(b^2*x^(5/2))
+--E 500
+
+--S 501 of 762
+--d0:=t0-D(r0,x)
+--E 501
+
+)clear all
+
+--S 502 of 762
+t0:=x^(5/2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          +-----------+
+--R            6      4  +-+ |   4      2
+--R   (1)  (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 502
+
+--S 503 of 762
+--r0:=2/19*x^(7/2)*(b*x^2+c*x^4)^(3/2)+24/1463*b^(21/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(13/4)*sqrt(b*x^2+c*x^4))-72/7315*b^3*x^(3/2)*sqrt(b*x^2+_
+--   c*x^4)/c^2+8/1045*b^2*x^(7/2)*sqrt(b*x^2+c*x^4)/c+4/95*b*x^(11/2)*_
+--   sqrt(b*x^2+c*x^4)+24/1463*b^4*sqrt(b*x^2+c*x^4)/(c^3*sqrt(x))
+--E 503
+
+--S 504 of 762
+--d0:=t0-D(r0,x)
+--E 504
+
+)clear all
+
+--S 505 of 762
+t0:=x^(3/2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          +-----------+
+--R            5      3  +-+ |   4      2
+--R   (1)  (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 505
+
+--S 506 of 762
+--r0:=2/17*x^(5/2)*(b*x^2+c*x^4)^(3/2)+56/1105*b^(19/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(11/4)*sqrt(b*x^2+c*x^4))-56/1105*b^(19/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(11/4)*sqrt(b*x^2+c*x^4))+8/663*b^2*x^(5/2)*sqrt(b*x^2+_
+--   c*x^4)/c+12/221*b*x^(9/2)*sqrt(b*x^2+c*x^4)-56/3315*b^3*sqrt(x)*_
+--   sqrt(b*x^2+c*x^4)/c^2
+--E 506
+
+--S 507 of 762
+--d0:=t0-D(r0,x)
+--E 507
+
+)clear all
+
+--S 508 of 762
+t0:=x^(1/2)*(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                          +-----------+
+--R            4      2  +-+ |   4      2
+--R   (1)  (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 508
+
+--S 509 of 762
+--r0:=2/15*x^(3/2)*(b*x^2+c*x^4)^(3/2)+8/231*b^(17/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(9/4)*sqrt(b*x^2+c*x^4))+8/385*b^2*x^(3/2)*sqrt(b*x^2+c*x^4)/_
+--   c+4/55*b*x^(7/2)*sqrt(b*x^2+c*x^4)-8/231*b^3*sqrt(b*x^2+c*x^4)/_
+--   (c^2*sqrt(x))
+--E 509
+
+--S 510 of 762
+--d0:=t0-D(r0,x)
+--E 510
+
+)clear all
+
+--S 511 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(1/2)
+--R 
+--R
+--R                      +-----------+
+--R            4      2  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R   (1)  ---------------------------
+--R                     +-+
+--R                    \|x
+--R                                                    Type: Expression(Integer)
+--E 511
+
+--S 512 of 762
+--r0:=2/13*(b*x^2+c*x^4)^(3/2)*sqrt(x)+8/65*b^(15/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(7/4)*sqrt(b*x^2+c*x^4))-8/65*b^(15/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(7/4)*sqrt(b*x^2+c*x^4))+4/39*b*x^(5/2)*sqrt(b*x^2+c*x^4)+_
+--   8/195*b^2*sqrt(x)*sqrt(b*x^2+c*x^4)/c
+--E 512
+
+--S 513 of 762
+--d0:=t0-D(r0,x)
+--E 513
+
+)clear all
+
+--S 514 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(3/2)
+--R 
+--R
+--R                     +-----------+
+--R            3        |   4      2
+--R        (c x  + b x)\|c x  + b x
+--R   (1)  --------------------------
+--R                    +-+
+--R                   \|x
+--R                                                    Type: Expression(Integer)
+--E 514
+
+--S 515 of 762
+--r0:=2/11*(b*x^2+c*x^4)^(3/2)/sqrt(x)+8/77*b^(13/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(5/4)*sqrt(b*x^2+c*x^4))+12/77*b*x^(3/2)*sqrt(b*x^2+c*x^4)+_
+--   8/77*b^2*sqrt(b*x^2+c*x^4)/(c*sqrt(x))
+--E 515
+
+--S 516 of 762
+--d0:=t0-D(r0,x)
+--E 516
+
+)clear all
+
+--S 517 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(5/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                   +-+
+--R                  \|x
+--R                                                    Type: Expression(Integer)
+--E 517
+
+--S 518 of 762
+--r0:=2/9*(b*x^2+c*x^4)^(3/2)/x^(3/2)+8/15*b^(11/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(3/4)*sqrt(b*x^2+c*x^4))-8/15*b^(11/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(3/4)*sqrt(b*x^2+c*x^4))+4/15*b*sqrt(x)*sqrt(b*x^2+c*x^4)
+--E 518
+
+--S 519 of 762
+--d0:=t0-D(r0,x)
+--E 519
+
+)clear all
+
+--S 520 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(7/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                    +-+
+--R                  x\|x
+--R                                                    Type: Expression(Integer)
+--E 520
+
+--S 521 of 762
+--r0:=2/7*(b*x^2+c*x^4)^(3/2)/x^(5/2)+8/7*b^(9/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(1/4)*sqrt(b*x^2+c*x^4))+4/7*b*sqrt(b*x^2+c*x^4)/sqrt(x)
+--E 521
+
+--S 522 of 762
+--d0:=t0-D(r0,x)
+--E 522
+
+)clear all
+
+--S 523 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(9/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                  2 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 523
+
+--S 524 of 762
+--r0:=-2*(b*x^2+c*x^4)^(3/2)/x^(7/2)-24/5*b^(7/4)*(-c)^(1/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   sqrt(b*x^2+c*x^4)+24/5*b^(7/4)*(-c)^(1/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   sqrt(b*x^2+c*x^4)+12/5*c*sqrt(x)*sqrt(b*x^2+c*x^4)
+--E 524
+
+--S 525 of 762
+--d0:=t0-D(r0,x)
+--E 525
+
+)clear all
+
+--S 526 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(11/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                  3 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 526
+
+--S 527 of 762
+--r0:=-2/3*(b*x^2+c*x^4)^(3/2)/x^(9/2)-8/3*b^(5/4)*(-c)^(3/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   sqrt(b*x^2+c*x^4)+4/3*c*sqrt(b*x^2+c*x^4)/sqrt(x)
+--E 527
+
+--S 528 of 762
+--d0:=t0-D(r0,x)
+--E 528
+
+)clear all
+
+--S 529 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(13/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                  4 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 529
+
+--S 530 of 762
+--r0:=-2/5*(b*x^2+c*x^4)^(3/2)/x^(11/2)+24/5*b^(3/4)*(-c)^(5/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   sqrt(b*x^2+c*x^4)-24/5*b^(3/4)*(-c)^(5/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   sqrt(b*x^2+c*x^4)-12/5*c*sqrt(b*x^2+c*x^4)/x^(3/2)
+--E 530
+
+--S 531 of 762
+--d0:=t0-D(r0,x)
+--E 531
+
+)clear all
+
+--S 532 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(15/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                  5 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 532
+
+--S 533 of 762
+--r0:=-2/7*(b*x^2+c*x^4)^(3/2)/x^(13/2)+8/7*b^(1/4)*(-c)^(7/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   sqrt(b*x^2+c*x^4)-4/7*c*sqrt(b*x^2+c*x^4)/x^(5/2)
+--E 533
+
+--S 534 of 762
+--d0:=t0-D(r0,x)
+--E 534
+
+)clear all
+
+--S 535 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(17/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                  6 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 535
+
+--S 536 of 762
+--r0:=-2/9*(b*x^2+c*x^4)^(3/2)/x^(15/2)-8/15*(-c)^(9/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(1/4)*sqrt(b*x^2+c*x^4))+8/15*(-c)^(9/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(1/4)*sqrt(b*x^2+c*x^4))-4/15*c*sqrt(b*x^2+c*x^4)/x^(7/2)-_
+--   8/15*c^2*sqrt(b*x^2+c*x^4)/(b*x^(3/2))
+--E 536
+
+--S 537 of 762
+--d0:=t0-D(r0,x)
+--E 537
+
+)clear all
+
+--S 538 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(19/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                  7 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 538
+
+--S 539 of 762
+--r0:=-2/11*(b*x^2+c*x^4)^(3/2)/x^(17/2)+8/77*(-c)^(11/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(3/4)*sqrt(b*x^2+c*x^4))-12/77*c*sqrt(b*x^2+c*x^4)/x^(9/2)-_
+--   8/77*c^2*sqrt(b*x^2+c*x^4)/(b*x^(5/2))
+--E 539
+
+--S 540 of 762
+--d0:=t0-D(r0,x)
+--E 540
+
+)clear all
+
+--S 541 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(21/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                  8 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 541
+
+--S 542 of 762
+--r0:=-2/13*(b*x^2+c*x^4)^(3/2)/x^(19/2)-8/65*(-c)^(13/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(5/4)*sqrt(b*x^2+c*x^4))+8/65*(-c)^(13/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(5/4)*sqrt(b*x^2+c*x^4))-4/39*c*sqrt(b*x^2+c*x^4)/x^(11/2)-_
+--   8/195*c^2*sqrt(b*x^2+c*x^4)/(b*x^(7/2))+8/65*c^3*sqrt(b*x^2+c*x^4)/_
+--   (b^2*x^(3/2))
+--E 542
+
+--S 543 of 762
+--d0:=t0-D(r0,x)
+--E 543
+
+)clear all
+
+--S 544 of 762
+t0:=(b*x^2+c*x^4)^(3/2)/x^(23/2)
+--R 
+--R
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R   (1)  ------------------------
+--R                  9 +-+
+--R                 x \|x
+--R                                                    Type: Expression(Integer)
+--E 544
+
+--S 545 of 762
+--r0:=-2/15*(b*x^2+c*x^4)^(3/2)/x^(21/2)+8/231*(-c)^(15/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(7/4)*sqrt(b*x^2+c*x^4))-4/55*c*sqrt(b*x^2+c*x^4)/x^(13/2)-_
+--   8/385*c^2*sqrt(b*x^2+c*x^4)/(b*x^(9/2))+8/231*c^3*sqrt(b*x^2+_
+--   c*x^4)/(b^2*x^(5/2))
+--E 545
+
+--S 546 of 762
+--d0:=t0-D(r0,x)
+--E 546
+
+)clear all
+
+--S 547 of 762
+t0:=x^(13/2)/(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R             6 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 547
+
+--S 548 of 762
+--r0:=30/77*b^(13/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(13/4)*sqrt(b*x^2+c*x^4))-18/77*b*x^(3/2)*_
+--   sqrt(b*x^2+c*x^4)/c^2+2/11*x^(7/2)*sqrt(b*x^2+c*x^4)/c+30/77*b^2*_
+--   sqrt(b*x^2+c*x^4)/(c^3*sqrt(x))
+--E 548
+
+--S 549 of 762
+--d0:=t0-D(r0,x)
+--E 549
+
+)clear all
+
+--S 550 of 762
+t0:=x^(11/2)/(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R             5 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 550
+
+--S 551 of 762
+--r0:=14/15*b^(11/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(11/4)*sqrt(b*x^2+c*x^4))-14/15*b^(11/4)*_
+--   x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(11/4)*sqrt(b*x^2+c*x^4))+2/9*x^(5/2)*_
+--   sqrt(b*x^2+c*x^4)/c-14/45*b*sqrt(x)*sqrt(b*x^2+c*x^4)/c^2
+--E 551
+
+--S 552 of 762
+--d0:=t0-D(r0,x)
+--E 552
+
+)clear all
+
+--S 553 of 762
+t0:=x^(9/2)/(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R             4 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 553
+
+--S 554 of 762
+--r0:=10/21*b^(9/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(9/4)*sqrt(b*x^2+c*x^4))+2/7*x^(3/2)*_
+--   sqrt(b*x^2+c*x^4)/c-10/21*b*sqrt(b*x^2+c*x^4)/(c^2*sqrt(x))
+--E 554
+
+--S 555 of 762
+--d0:=t0-D(r0,x)
+--E 555
+
+)clear all
+
+--S 556 of 762
+t0:=x^(7/2)/(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R             3 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 556
+
+--S 557 of 762
+--r0:=6/5*b^(7/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(7/4)*sqrt(b*x^2+c*x^4))-6/5*b^(7/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(7/4)*sqrt(b*x^2+c*x^4))+2/5*sqrt(x)*sqrt(b*x^2+c*x^4)/c
+--E 557
+
+--S 558 of 762
+--d0:=t0-D(r0,x)
+--E 558
+
+)clear all
+
+--S 559 of 762
+t0:=x^(5/2)/(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R             2 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 559
+
+--S 560 of 762
+--r0:=2/3*b^(5/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(5/4)*sqrt(b*x^2+c*x^4))+2/3*sqrt(b*x^2+_
+--   c*x^4)/(c*sqrt(x))
+--E 560
+
+--S 561 of 762
+--d0:=t0-D(r0,x)
+--E 561
+
+)clear all
+
+--S 562 of 762
+t0:=x^(3/2)/(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R               +-+
+--R             x\|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 562
+
+--S 563 of 762
+--r0:=2*b^(3/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(3/4)*sqrt(b*x^2+c*x^4))-2*b^(3/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(3/4)*sqrt(b*x^2+c*x^4))
+--E 563
+
+--S 564 of 762
+--d0:=t0-D(r0,x)
+--E 564
+
+)clear all
+
+--S 565 of 762
+t0:=x^(1/2)/(b*x^2+c*x^4)^(1/2)
+--R 
+--R
+--R              +-+
+--R             \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      2
+--R        \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 565
+
+--S 566 of 762
+--r0:=2*b^(1/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/((-c)^(1/4)*sqrt(b*x^2+c*x^4))
+--E 566
+
+--S 567 of 762
+--d0:=t0-D(r0,x)
+--E 567
+
+)clear all
+
+--S 568 of 762
+t0:=1/(x^(1/2)*(b*x^2+c*x^4)^(1/2))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R             +-----------+
+--R         +-+ |   4      2
+--R        \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 568
+
+--S 569 of 762
+--r0:=-2*(-c)^(1/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/(b^(1/4)*sqrt(b*x^2+c*x^4))+2*(-c)^(1/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(1/4)*sqrt(b*x^2+c*x^4))-2*sqrt(b*x^2+c*x^4)/(b*x^(3/2))
+--E 569
+
+--S 570 of 762
+--d0:=t0-D(r0,x)
+--E 570
+
+)clear all
+
+--S 571 of 762
+t0:=1/(x^(3/2)*(b*x^2+c*x^4)^(1/2))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R              +-----------+
+--R          +-+ |   4      2
+--R        x\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 571
+
+--S 572 of 762
+--r0:=2/3*(-c)^(3/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/(b^(3/4)*sqrt(b*x^2+c*x^4))-2/3*sqrt(b*x^2+_
+--   c*x^4)/(b*x^(5/2))
+--E 572
+
+--S 573 of 762
+--d0:=t0-D(r0,x)
+--E 573
+
+)clear all
+
+--S 574 of 762
+t0:=1/(x^(5/2)*(b*x^2+c*x^4)^(1/2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         2 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 574
+
+--S 575 of 762
+--r0:=-6/5*(-c)^(5/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/(b^(5/4)*sqrt(b*x^2+c*x^4))+6/5*(-c)^(5/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(5/4)*sqrt(b*x^2+c*x^4))-2/5*sqrt(b*x^2+c*x^4)/(b*x^(7/2))+_
+--   6/5*c*sqrt(b*x^2+c*x^4)/(b^2*x^(3/2))
+--E 575
+
+--S 576 of 762
+--d0:=t0-D(r0,x)
+--E 576
+
+)clear all
+
+--S 577 of 762
+t0:=1/(x^(7/2)*(b*x^2+c*x^4)^(1/2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         3 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 577
+
+--S 578 of 762
+--r0:=10/21*(-c)^(7/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/(b^(7/4)*sqrt(b*x^2+c*x^4))-2/7*sqrt(b*x^2+c*x^4)/_
+--   (b*x^(9/2))+10/21*c*sqrt(b*x^2+c*x^4)/(b^2*x^(5/2))
+--E 578
+
+--S 579 of 762
+--d0:=t0-D(r0,x)
+--E 579
+
+)clear all
+
+--S 580 of 762
+t0:=1/(x^(9/2)*(b*x^2+c*x^4)^(1/2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         4 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 580
+
+--S 581 of 762
+--r0:=-14/15*(-c)^(9/4)*x*elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/(b^(9/4)*sqrt(b*x^2+c*x^4))+14/15*(-c)^(9/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(9/4)*sqrt(b*x^2+c*x^4))-2/9*sqrt(b*x^2+c*x^4)/(b*x^(11/2))+_
+--   14/45*c*sqrt(b*x^2+c*x^4)/(b^2*x^(7/2))-14/15*c^2*sqrt(b*x^2+_
+--   c*x^4)/(b^3*x^(3/2))
+--E 581
+
+--S 582 of 762
+--d0:=t0-D(r0,x)
+--E 582
+
+)clear all
+
+--S 583 of 762
+t0:=1/(x^(11/2)*(b*x^2+c*x^4)^(1/2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         5 +-+ |   4      2
+--R        x \|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 583
+
+--S 584 of 762
+--r0:=30/77*(-c)^(11/4)*x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*_
+--   sqrt((b+c*x^2)/b)/(b^(11/4)*sqrt(b*x^2+c*x^4))-2/11*sqrt(b*x^2+_
+--   c*x^4)/(b*x^(13/2))+18/77*c*sqrt(b*x^2+c*x^4)/(b^2*x^(9/2))-_
+--   30/77*c^2*sqrt(b*x^2+c*x^4)/(b^3*x^(5/2))
+--E 584
+
+--S 585 of 762
+--d0:=t0-D(r0,x)
+--E 585
+
+)clear all
+
+--S 586 of 762
+t0:=x^(17/2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  6 +-+
+--R                 x \|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 586
+
+--S 587 of 762
+--r0:=-x^(11/2)/(c*sqrt(b*x^2+c*x^4))-15/7*b^(9/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(13/4)*sqrt(b*x^2+c*x^4))+9/7*x^(3/2)*sqrt(b*x^2+c*x^4)/c^2-_
+--   15/7*b*sqrt(b*x^2+c*x^4)/(c^3*sqrt(x))
+--E 587
+
+--S 588 of 762
+--d0:=t0-D(r0,x)
+--E 588
+
+)clear all
+
+--S 589 of 762
+t0:=x^(15/2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  5 +-+
+--R                 x \|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 589
+
+--S 590 of 762
+--r0:=-x^(9/2)/(c*sqrt(b*x^2+c*x^4))-21/5*b^(7/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(11/4)*sqrt(b*x^2+c*x^4))+21/5*b^(7/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(11/4)*sqrt(b*x^2+c*x^4))+7/5*sqrt(x)*sqrt(b*x^2+c*x^4)/c^2
+--E 590
+
+--S 591 of 762
+--d0:=t0-D(r0,x)
+--E 591
+
+)clear all
+
+--S 592 of 762
+t0:=x^(13/2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  4 +-+
+--R                 x \|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 592
+
+--S 593 of 762
+--r0:=-x^(7/2)/(c*sqrt(b*x^2+c*x^4))-5/3*b^(5/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(9/4)*sqrt(b*x^2+c*x^4))+5/3*sqrt(b*x^2+c*x^4)/(c^2*sqrt(x))
+--E 593
+
+--S 594 of 762
+--d0:=t0-D(r0,x)
+--E 594
+
+)clear all
+
+--S 595 of 762
+t0:=x^(11/2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  3 +-+
+--R                 x \|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 595
+
+--S 596 of 762
+--r0:=-x^(5/2)/(c*sqrt(b*x^2+c*x^4))-3*b^(3/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(7/4)*sqrt(b*x^2+c*x^4))+3*b^(3/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   ((-c)^(7/4)*sqrt(b*x^2+c*x^4))
+--E 596
+
+--S 597 of 762
+--d0:=t0-D(r0,x)
+--E 597
+
+)clear all
+
+--S 598 of 762
+t0:=x^(9/2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                  2 +-+
+--R                 x \|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 598
+
+--S 599 of 762
+--r0:=-x^(3/2)/(c*sqrt(b*x^2+c*x^4))-b^(1/4)*x*elliptic_f(asin((-c)^(1/4)*_
+--   sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/((-c)^(5/4)*sqrt(b*x^2+c*x^4))
+--E 599
+
+--S 600 of 762
+--d0:=t0-D(r0,x)
+--E 600
+
+)clear all
+
+--S 601 of 762
+t0:=x^(7/2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    +-+
+--R                  x\|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 601
+
+--S 602 of 762
+--r0:=x^(5/2)/(b*sqrt(b*x^2+c*x^4))-x*elliptic_e(asin((-c)^(1/4)*_
+--   sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(1/4)*(-c)^(3/4)*_
+--   sqrt(b*x^2+c*x^4))+x*elliptic_f(asin((-c)^(1/4)*sqrt(x)/_
+--   b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(1/4)*(-c)^(3/4)*sqrt(b*x^2+c*x^4))
+--E 602
+
+--S 603 of 762
+--d0:=t0-D(r0,x)
+--E 603
+
+)clear all
+
+--S 604 of 762
+t0:=x^(5/2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                   +-+
+--R                  \|x
+--R   (1)  ------------------------
+--R                   +-----------+
+--R            2      |   4      2
+--R        (c x  + b)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 604
+
+--S 605 of 762
+--r0:=x^(3/2)/(b*sqrt(b*x^2+c*x^4))+x*elliptic_f(asin((-c)^(1/4)*_
+--   sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/(b^(3/4)*(-c)^(1/4)*_
+--   sqrt(b*x^2+c*x^4))
+--E 605
+
+--S 606 of 762
+--d0:=t0-D(r0,x)
+--E 606
+
+)clear all
+
+--S 607 of 762
+t0:=x^(3/2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                    +-+
+--R                   \|x
+--R   (1)  --------------------------
+--R                     +-----------+
+--R            3        |   4      2
+--R        (c x  + b x)\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 607
+
+--S 608 of 762
+--r0:=sqrt(x)/(b*sqrt(b*x^2+c*x^4))-3*(-c)^(1/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(5/4)*sqrt(b*x^2+c*x^4))+3*(-c)^(1/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(5/4)*sqrt(b*x^2+c*x^4))-3*sqrt(b*x^2+c*x^4)/(b^2*x^(3/2))
+--E 608
+
+--S 609 of 762
+--d0:=t0-D(r0,x)
+--E 609
+
+)clear all
+
+--S 610 of 762
+t0:=x^(1/2)/(b*x^2+c*x^4)^(3/2)
+--R 
+--R
+--R                     +-+
+--R                    \|x
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            4      2  |   4      2
+--R        (c x  + b x )\|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 610
+
+--S 611 of 762
+--r0:=1/(b*sqrt(x)*sqrt(b*x^2+c*x^4))+5/3*(-c)^(3/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(7/4)*sqrt(b*x^2+c*x^4))-5/3*sqrt(b*x^2+c*x^4)/(b^2*x^(5/2))
+--E 611
+
+--S 612 of 762
+--d0:=t0-D(r0,x)
+--E 612
+
+)clear all
+
+--S 613 of 762
+t0:=1/(x^(1/2)*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            4      2  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 613
+
+--S 614 of 762
+--r0:=1/(b*x^(3/2)*sqrt(b*x^2+c*x^4))-21/5*(-c)^(5/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(9/4)*sqrt(b*x^2+c*x^4))+21/5*(-c)^(5/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(9/4)*sqrt(b*x^2+c*x^4))-7/5*sqrt(b*x^2+c*x^4)/(b^2*x^(7/2))+_
+--   21/5*c*sqrt(b*x^2+c*x^4)/(b^3*x^(3/2))
+--E 614
+
+--S 615 of 762
+--d0:=t0-D(r0,x)
+--E 615
+
+)clear all
+
+--S 616 of 762
+t0:=1/(x^(3/2)*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            5      3  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 616
+
+--S 617 of 762
+--r0:=1/(b*x^(5/2)*sqrt(b*x^2+c*x^4))+15/7*(-c)^(7/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(11/4)*sqrt(b*x^2+c*x^4))-9/7*sqrt(b*x^2+c*x^4)/(b^2*x^(9/2))+_
+--   15/7*c*sqrt(b*x^2+c*x^4)/(b^3*x^(5/2))
+--E 617
+
+--S 618 of 762
+--d0:=t0-D(r0,x)
+--E 618
+
+)clear all
+
+--S 619 of 762
+t0:=1/(x^(5/2)*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            6      4  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 619
+
+--S 620 of 762
+--r0:=1/(b*x^(7/2)*sqrt(b*x^2+c*x^4))-77/15*(-c)^(9/4)*x*_
+--   elliptic_e(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(13/4)*sqrt(b*x^2+c*x^4))+77/15*(-c)^(9/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(13/4)*sqrt(b*x^2+c*x^4))-11/9*sqrt(b*x^2+c*x^4)/_
+--   (b^2*x^(11/2))+77/45*c*sqrt(b*x^2+c*x^4)/(b^3*x^(7/2))-_
+--   77/15*c^2*sqrt(b*x^2+c*x^4)/(b^4*x^(3/2))
+--E 620
+
+--S 621 of 762
+--d0:=t0-D(r0,x)
+--E 621
+
+)clear all
+
+--S 622 of 762
+t0:=1/(x^(7/2)*(b*x^2+c*x^4)^(3/2))
+--R 
+--R
+--R                       1
+--R   (1)  -------------------------------
+--R                          +-----------+
+--R            7      5  +-+ |   4      2
+--R        (c x  + b x )\|x \|c x  + b x
+--R                                                    Type: Expression(Integer)
+--E 622
+
+--S 623 of 762
+--r0:=1/(b*x^(9/2)*sqrt(b*x^2+c*x^4))+195/77*(-c)^(11/4)*x*_
+--   elliptic_f(asin((-c)^(1/4)*sqrt(x)/b^(1/4)),-1)*sqrt((b+c*x^2)/b)/_
+--   (b^(15/4)*sqrt(b*x^2+c*x^4))-13/11*sqrt(b*x^2+c*x^4)/(b^2*x^(13/2))+_
+--   117/77*c*sqrt(b*x^2+c*x^4)/(b^3*x^(9/2))-195/77*c^2*sqrt(b*x^2+_
+--   c*x^4)/(b^4*x^(5/2))
+--E 623
+
+--S 624 of 762
+--d0:=t0-D(r0,x)
+--E 624
+
+)clear all
+
+--S 625 of 762
+t0:=x^6/sqrt(a*x^2+b*x^5)
+--R 
+--R
+--R               6
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 625
+
+--S 626 of 762
+r0:=-4/9*a*sqrt(a*x^2+b*x^5)/(b^2*x)+2/9*x^2*sqrt(a*x^2+b*x^5)/b
+--R 
+--R
+--R                     +-----------+
+--R             3       |   5      2
+--R        (2b x  - 4a)\|b x  + a x
+--R   (2)  --------------------------
+--R                     2
+--R                   9b x
+--R                                                    Type: Expression(Integer)
+--E 626
+
+--S 627 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 627
+
+)clear all
+
+--S 628 of 762
+t0:=x^4/sqrt(a*x^2+b*x^5)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 628
+
+--S 629 of 762
+--r0:=2/5*sqrt(a*x^2+b*x^5)/b-2/5*a^(7/6)*x*elliptic_f(asin(b^(1/6)*_
+--   sqrt(2)*sqrt(a^(1/3)+b^(1/3)*x)/(a^(1/6)*sqrt(3*b^(1/3)-sqrt(3)*_
+--   sqrt(-b^(2/3))))),(3*b^(1/3)-sqrt(3)*sqrt(-b^(2/3)))/(3*b^(1/3)+_
+--   sqrt(3)*sqrt(-b^(2/3))))*sqrt(2)*sqrt(a^(1/3)+b^(1/3)*x)*_
+--   sqrt(3*b^(1/3)-sqrt(3)*sqrt(-b^(2/3)))*sqrt((2*b^(2/3)*x+a^(1/3)*_
+--   (-b^(1/3)+sqrt(3)*sqrt(-b^(2/3))))/(a^(1/3)*(-3*b^(1/3)+sqrt(3)*_
+--   sqrt(-b^(2/3)))))*sqrt((-2*b^(2/3)*x+a^(1/3)*(b^(1/3)+sqrt(3)*_
+--   sqrt(-b^(2/3))))/(a^(1/3)*(3*b^(1/3)+sqrt(3)*sqrt(-b^(2/3)))))/_
+--   (b^(3/2)*sqrt(a*x^2+b*x^5))
+--E 629
+
+--S 630 of 762
+--d0:=t0-D(r0,x)
+--E 630
+
+)clear all
+
+--S 631 of 762
+t0:=x^3/sqrt(a*x^2+b*x^5)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 631
+
+--S 632 of 762
+r0:=2/3*sqrt(a*x^2+b*x^5)/(b*x)
+--R 
+--R
+--R          +-----------+
+--R          |   5      2
+--R        2\|b x  + a x
+--R   (2)  ---------------
+--R              3b x
+--R                                                    Type: Expression(Integer)
+--E 632
+
+--S 633 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 633
+
+)clear all
+
+--S 634 of 762
+t0:=x^2/sqrt(a*x^2+b*x^5)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 634
+
+--S 635 of 762
+--r0:=-a^(1/6)*x*elliptic_e(asin(b^(1/6)*sqrt(2)*sqrt(a^(1/3)+b^(1/3)*x)/_
+--   (a^(1/6)*sqrt(3*b^(1/3)-sqrt(3)*sqrt(-b^(2/3))))),(3*b^(1/3)-_
+--   sqrt(3)*sqrt(-b^(2/3)))/(3*b^(1/3)+sqrt(3)*sqrt(-b^(2/3))))*_
+--   (-2*b^(2/3)*x+a^(1/3)*(b^(1/3)+sqrt(3)*sqrt(-b^(2/3))))*_
+--   sqrt(a^(1/3)+b^(1/3)*x)*sqrt(3*b^(1/3)-sqrt(3)*sqrt(-b^(2/3)))*_
+--   sqrt((2*b^(2/3)*x+a^(1/3)*(-b^(1/3)+sqrt(3)*sqrt(-b^(2/3))))/_
+--   (a^(1/3)*(-3*b^(1/3)+sqrt(3)*sqrt(-b^(2/3)))))/(b^(7/6)*sqrt(2)*_
+--   sqrt(a*x^2+b*x^5)*sqrt((-2*b^(2/3)*x+a^(1/3)*(b^(1/3)+sqrt(3)*_
+--   sqrt(-b^(2/3))))/(a^(1/3)*(3*b^(1/3)+sqrt(3)*sqrt(-b^(2/3))))))+x*_
+--   elliptic_f(asin(b^(1/6)*sqrt(2)*sqrt(a^(1/3)+b^(1/3)*x)/(a^(1/6)*_
+--   sqrt(3*b^(1/3)-sqrt(3)*sqrt(-b^(2/3))))),(3*b^(1/3)-sqrt(3)*_
+--   sqrt(-b^(2/3)))/(3*b^(1/3)+sqrt(3)*sqrt(-b^(2/3))))*sqrt(a)*_
+--   sqrt(-b^(2/3))*(3*b^(1/3)-sqrt(3)*sqrt(-b^(2/3)))^(3/2)*_
+--   sqrt(a^(1/3)+b^(1/3)*x)*sqrt((2*b^(2/3)*x+a^(1/3)*(-b^(1/3)+_
+--   sqrt(3)*sqrt(-b^(2/3))))/(a^(1/3)*(-3*b^(1/3)+sqrt(3)*_
+--   sqrt(-b^(2/3)))))*sqrt((-2*b^(2/3)*x+a^(1/3)*(b^(1/3)+sqrt(3)*_
+--   sqrt(-b^(2/3))))/(a^(1/3)*(3*b^(1/3)+sqrt(3)*sqrt(-b^(2/3)))))/_
+--   (b^(3/2)*sqrt(6)*sqrt(a*x^2+b*x^5))
+--E 635
+
+--S 636 of 762
+--d0:=t0-D(r0,x)
+--E 636
+
+)clear all
+
+--S 637 of 762
+t0:=x/sqrt(a*x^2+b*x^5)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 637
+
+--S 638 of 762
+--r0:=a^(1/6)*x*elliptic_f(asin(b^(1/6)*sqrt(2)*sqrt(a^(1/3)+b^(1/3)*x)/_
+--   (a^(1/6)*sqrt(3*b^(1/3)-sqrt(3)*sqrt(-b^(2/3))))),(3*b^(1/3)-_
+--   sqrt(3)*sqrt(-b^(2/3)))/(3*b^(1/3)+sqrt(3)*sqrt(-b^(2/3))))*_
+--   sqrt(2)*sqrt(a^(1/3)+b^(1/3)*x)*sqrt(3*b^(1/3)-sqrt(3)*_
+--   sqrt(-b^(2/3)))*sqrt((2*b^(2/3)*x+a^(1/3)*(-b^(1/3)+sqrt(3)*_
+--   sqrt(-b^(2/3))))/(a^(1/3)*(-3*b^(1/3)+sqrt(3)*sqrt(-b^(2/3)))))*_
+--   sqrt((-2*b^(2/3)*x+a^(1/3)*(b^(1/3)+sqrt(3)*sqrt(-b^(2/3))))/_
+--   (a^(1/3)*(3*b^(1/3)+sqrt(3)*sqrt(-b^(2/3)))))/(sqrt(b)*sqrt(a*x^2+b*x^5))
+--E 638
+
+--S 639 of 762
+--d0:=t0-D(r0,x)
+--E 639
+
+)clear all
+
+--S 640 of 762
+t0:=1/sqrt(a*x^2+b*x^5)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 640
+
+--S 641 of 762
+r0:=-2/3*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^5))/sqrt(a)
+--R 
+--R
+--R                        +-+
+--R                      x\|a
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |   5      2
+--R                 \|b x  + a x
+--R   (2)  - ----------------------
+--R                     +-+
+--R                   3\|a
+--R                                                    Type: Expression(Integer)
+--E 641
+
+--S 642 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 642
+
+)clear all
+
+--S 643 of 762
+t0:=1/(x^2*sqrt(a*x^2+b*x^5))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         2 |   5      2
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 643
+
+--S 644 of 762
+--r0:=-1/2*sqrt(a*x^2+b*x^5)/(a*x^3)-1/2*x*elliptic_f(asin(b^(1/6)*_
+--   sqrt(2)*sqrt(a^(1/3)+b^(1/3)*x)/(a^(1/6)*sqrt(3*b^(1/3)-sqrt(3)*_
+--   sqrt(-b^(2/3))))),(3*b^(1/3)-sqrt(3)*sqrt(-b^(2/3)))/(3*b^(1/3)+_
+--   sqrt(3)*sqrt(-b^(2/3))))*sqrt(b)*sqrt(a^(1/3)+b^(1/3)*x)*_
+--   sqrt(3*b^(1/3)-sqrt(3)*sqrt(-b^(2/3)))*sqrt((2*b^(2/3)*x+a^(1/3)*_
+--   (-b^(1/3)+sqrt(3)*sqrt(-b^(2/3))))/(a^(1/3)*(-3*b^(1/3)+sqrt(3)*_
+--   sqrt(-b^(2/3)))))*sqrt((-2*b^(2/3)*x+a^(1/3)*(b^(1/3)+sqrt(3)*_
+--   sqrt(-b^(2/3))))/(a^(1/3)*(3*b^(1/3)+sqrt(3)*sqrt(-b^(2/3)))))/_
+--   (a^(5/6)*sqrt(2)*sqrt(a*x^2+b*x^5))
+--E 644
+
+--S 645 of 762
+--d0:=t0-D(r0,x)
+--E 645
+
+)clear all
+
+--S 646 of 762
+t0:=1/(x^3*sqrt(a*x^2+b*x^5))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         3 |   5      2
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 646
+
+--S 647 of 762
+r0:=1/3*b*atanh(x*sqrt(a)/sqrt(a*x^2+b*x^5))/a^(3/2)-_
+     1/3*sqrt(a*x^2+b*x^5)/(a*x^4)
+--R 
+--R
+--R                         +-+             +-----------+
+--R           4           x\|a          +-+ |   5      2
+--R        b x atanh(--------------) - \|a \|b x  + a x
+--R                   +-----------+
+--R                   |   5      2
+--R                  \|b x  + a x
+--R   (2)  ----------------------------------------------
+--R                               4 +-+
+--R                           3a x \|a
+--R                                                    Type: Expression(Integer)
+--E 647
+
+--S 648 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 648
+
+)clear all
+
+--S 649 of 762
+t0:=x^(13/2)/(a*x^2+b*x^5)^(1/2)
+--R 
+--R
+--R             6 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 649
+
+--S 650 of 762
+--r0:=1/5*x^(5/2)*sqrt(a*x^2+b*x^5)/b-7/20*a*sqrt(a*x^2+b*x^5)/(b^2*_
+--   sqrt(x))+7/40*a^(5/3)*x^(3/2)*(a^(1/3)+b^(1/3)*x)*_
+--   elliptic_f(acos((a^(1/3)+b^(1/3)*x*(1-sqrt(3)))/(a^(1/3)+b^(1/3)*_
+--   x*(1+sqrt(3)))),1/4*(2+sqrt(3)))*sqrt((a^(2/3)-a^(1/3)*b^(1/3)*x+_
+--   b^(2/3)*x^2)/(a^(1/3)+b^(1/3)*x*(1+sqrt(3)))^2)/(3^(1/4)*b^2*_
+--   sqrt(a*x^2+b*x^5)*sqrt(b^(1/3)*x*(a^(1/3)+b^(1/3)*x)/(a^(1/3)+_
+--   b^(1/3)*x*(1+sqrt(3)))^2))
+--E 650
+
+--S 651 of 762
+--d0:=t0-D(r0,x)
+--E 651
+
+)clear all
+
+--S 652 of 762
+t0:=x^(11/2)/(a*x^2+b*x^5)^(1/2)
+--R 
+--R
+--R             5 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 652
+
+--S 653 of 762
+--r0:=-1/4*a*x^(7/2)*hypergeometric(1/2,5/6,11/6,-b*x^3/a)*_
+--   sqrt((a+b*x^3)/a)/(b*sqrt(a*x^2+b*x^5))+1/4*x^(3/2)*sqrt(a*x^2+b*x^5)/b
+--E 653
+
+--S 654 of 762
+--d0:=t0-D(r0,x)
+--E 654
+
+)clear all
+
+--S 655 of 762
+t0:=x^(9/2)/(a*x^2+b*x^5)^(1/2)
+--R 
+--R
+--R             4 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 655
+
+--S 656 of 762
+r0:=-1/3*a*atanh(x^(5/2)*sqrt(b)/sqrt(a*x^2+b*x^5))/b^(3/2)+_
+     1/3*sqrt(x)*sqrt(a*x^2+b*x^5)/b
+--R 
+--R
+--R                     2 +-+ +-+               +-----------+
+--R                    x \|b \|x        +-+ +-+ |   5      2
+--R        - a atanh(--------------) + \|b \|x \|b x  + a x
+--R                   +-----------+
+--R                   |   5      2
+--R                  \|b x  + a x
+--R   (2)  --------------------------------------------------
+--R                                 +-+
+--R                              3b\|b
+--R                                                    Type: Expression(Integer)
+--E 656
+
+--S 657 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 657
+
+)clear all
+
+--S 658 of 762
+t0:=x^(7/2)/(a*x^2+b*x^5)^(1/2)
+--R 
+--R
+--R             3 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 658
+
+--S 659 of 762
+--r0:=1/2*sqrt(a*x^2+b*x^5)/(b*sqrt(x))-1/4*a^(2/3)*x^(3/2)*(a^(1/3)+_
+--   b^(1/3)*x)*elliptic_f(acos((a^(1/3)+b^(1/3)*x*(1-sqrt(3)))/(a^(1/3)+_
+--   b^(1/3)*x*(1+sqrt(3)))),1/4*(2+sqrt(3)))*sqrt((a^(2/3)-a^(1/3)*_
+--   b^(1/3)*x+b^(2/3)*x^2)/(a^(1/3)+b^(1/3)*x*(1+sqrt(3)))^2)/(3^(1/4)*_
+--   b*sqrt(a*x^2+b*x^5)*sqrt(b^(1/3)*x*(a^(1/3)+b^(1/3)*x)/(a^(1/3)+_
+--   b^(1/3)*x*(1+sqrt(3)))^2))
+--E 659
+
+--S 660 of 762
+--d0:=t0-D(r0,x)
+--E 660
+
+)clear all
+
+--S 661 of 762
+t0:=x^(5/2)/(a*x^2+b*x^5)^(1/2)
+--R 
+--R
+--R             2 +-+
+--R            x \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 661
+
+--S 662 of 762
+--r0:=2/5*x^(7/2)*hypergeometric(1/2,5/6,11/6,-b*x^3/a)*_
+--   sqrt((a+b*x^3)/a)/sqrt(a*x^2+b*x^5)
+--E 662
+
+--S 663 of 762
+--d0:=t0-D(r0,x)
+--E 663
+
+)clear all
+
+--S 664 of 762
+t0:=x^(3/2)/(a*x^2+b*x^5)^(1/2)
+--R 
+--R
+--R               +-+
+--R             x\|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 664
+
+--S 665 of 762
+r0:=2/3*atanh(x^(5/2)*sqrt(b)/sqrt(a*x^2+b*x^5))/sqrt(b)
+--R 
+--R
+--R                  2 +-+ +-+
+--R                 x \|b \|x
+--R        2atanh(--------------)
+--R                +-----------+
+--R                |   5      2
+--R               \|b x  + a x
+--R   (2)  ----------------------
+--R                   +-+
+--R                 3\|b
+--R                                                    Type: Expression(Integer)
+--E 665
+
+--S 666 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 666
+
+)clear all
+
+--S 667 of 762
+t0:=x^(1/2)/(a*x^2+b*x^5)^(1/2)
+--R 
+--R
+--R              +-+
+--R             \|x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   5      2
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 667
+
+--S 668 of 762
+--r0:=x^(3/2)*(a^(1/3)+b^(1/3)*x)*elliptic_f(acos((a^(1/3)+b^(1/3)*x*_
+--   (1-sqrt(3)))/(a^(1/3)+b^(1/3)*x*(1+sqrt(3)))),1/4*(2+sqrt(3)))*_
+--   sqrt((a^(2/3)-a^(1/3)*b^(1/3)*x+b^(2/3)*x^2)/(a^(1/3)+b^(1/3)*x*_
+--   (1+sqrt(3)))^2)/(3^(1/4)*a^(1/3)*sqrt(a*x^2+b*x^5)*sqrt(b^(1/3)*_
+--   x*(a^(1/3)+b^(1/3)*x)/(a^(1/3)+b^(1/3)*x*(1+sqrt(3)))^2))
+--E 668
+
+--S 669 of 762
+--d0:=t0-D(r0,x)
+--E 669
+
+)clear all
+
+--S 670 of 762
+t0:=1/(x^(1/2)*(a*x^2+b*x^5)^(1/2))
+--R 
+--R
+--R                 1
+--R   (1)  ------------------
+--R             +-----------+
+--R         +-+ |   5      2
+--R        \|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 670
+
+--S 671 of 762
+--r0:=4/5*b*x^(7/2)*hypergeometric(1/2,5/6,11/6,-b*x^3/a)*_
+--   sqrt((a+b*x^3)/a)/(a*sqrt(a*x^2+b*x^5))-2*sqrt(a*x^2+b*x^5)/(a*x^(3/2))
+--E 671
+
+--S 672 of 762
+--d0:=t0-D(r0,x)
+--E 672
+
+)clear all
+
+--S 673 of 762
+t0:=1/(x^(3/2)*(a*x^2+b*x^5)^(1/2))
+--R 
+--R
+--R                 1
+--R   (1)  -------------------
+--R              +-----------+
+--R          +-+ |   5      2
+--R        x\|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 673
+
+--S 674 of 762
+r0:=-2/3*sqrt(a*x^2+b*x^5)/(a*x^(5/2))
+--R 
+--R
+--R            +-----------+
+--R            |   5      2
+--R          2\|b x  + a x
+--R   (2)  - ---------------
+--R                 2 +-+
+--R             3a x \|x
+--R                                                    Type: Expression(Integer)
+--E 674
+
+--S 675 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 675
+
+)clear all
+
+--S 676 of 762
+t0:=1/(x^(5/2)*(a*x^2+b*x^5)^(1/2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         2 +-+ |   5      2
+--R        x \|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 676
+
+--S 677 of 762
+--r0:=-2/5*sqrt(a*x^2+b*x^5)/(a*x^(7/2))-2/5*b*x^(3/2)*(a^(1/3)+b^(1/3)*x)*_
+--   elliptic_f(acos((a^(1/3)+b^(1/3)*x*(1-sqrt(3)))/(a^(1/3)+b^(1/3)*_
+--   x*(1+sqrt(3)))),1/4*(2+sqrt(3)))*sqrt((a^(2/3)-a^(1/3)*b^(1/3)*x+_
+--   b^(2/3)*x^2)/(a^(1/3)+b^(1/3)*x*(1+sqrt(3)))^2)/(3^(1/4)*a^(4/3)*_
+--   sqrt(a*x^2+b*x^5)*sqrt(b^(1/3)*x*(a^(1/3)+b^(1/3)*x)/(a^(1/3)+_
+--   b^(1/3)*x*(1+sqrt(3)))^2))
+--E 677
+
+--S 678 of 762
+--d0:=t0-D(r0,x)
+--E 678
+
+)clear all
+
+--S 679 of 762
+t0:=1/(x^(7/2)*(a*x^2+b*x^5)^(1/2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         3 +-+ |   5      2
+--R        x \|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 679
+
+--S 680 of 762
+--r0:=-16/35*b^2*x^(7/2)*hypergeometric(1/2,5/6,11/6,-b*x^3/a)*_
+--   sqrt((a+b*x^3)/a)/(a^2*sqrt(a*x^2+b*x^5))-2/7*sqrt(a*x^2+b*x^5)/_
+--   (a*x^(9/2))+8/7*b*sqrt(a*x^2+b*x^5)/(a^2*x^(3/2))
+--E 680
+
+--S 681 of 762
+--d0:=t0-D(r0,x)
+--E 681
+
+)clear all
+
+--S 682 of 762
+t0:=1/(x^(9/2)*(a*x^2+b*x^5)^(1/2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         4 +-+ |   5      2
+--R        x \|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 682
+
+--S 683 of 762
+r0:=-2/9*sqrt(a*x^2+b*x^5)/(a*x^(11/2))+4/9*b*sqrt(a*x^2+b*x^5)/(a^2*x^(5/2))
+--R 
+--R
+--R                     +-----------+
+--R             3       |   5      2
+--R        (4b x  - 2a)\|b x  + a x
+--R   (2)  --------------------------
+--R                   2 5 +-+
+--R                 9a x \|x
+--R                                                    Type: Expression(Integer)
+--E 683
+
+--S 684 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 684
+
+)clear all
+
+--S 685 of 762
+t0:=1/(x^(11/2)*(a*x^2+b*x^5)^(1/2))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R               +-----------+
+--R         5 +-+ |   5      2
+--R        x \|x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 685
+
+--S 686 of 762
+--r0:=-2/11*sqrt(a*x^2+b*x^5)/(a*x^(13/2))+16/55*b*sqrt(a*x^2+b*x^5)/_
+--   (a^2*x^(7/2))+16/55*b^2*x^(3/2)*(a^(1/3)+b^(1/3)*x)*_
+--   elliptic_f(acos((a^(1/3)+b^(1/3)*x*(1-sqrt(3)))/(a^(1/3)+b^(1/3)*_
+--   x*(1+sqrt(3)))),1/4*(2+sqrt(3)))*sqrt((a^(2/3)-a^(1/3)*b^(1/3)*x+_
+--   b^(2/3)*x^2)/(a^(1/3)+b^(1/3)*x*(1+sqrt(3)))^2)/(3^(1/4)*a^(7/3)*_
+--   sqrt(a*x^2+b*x^5)*sqrt(b^(1/3)*x*(a^(1/3)+b^(1/3)*x)/(a^(1/3)+_
+--   b^(1/3)*x*(1+sqrt(3)))^2))
+--E 686
+
+--S 687 of 762
+--d0:=t0-D(r0,x)
+--E 687
+
+)clear all
+
+--S 688 of 762
+t0:=x/(a*x^3+b*x^4)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           3      2
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 688
+
+--S 689 of 762
+r0:=(-1)/(a*x)-b*log(x)/a^2+b*log(a+b*x)/a^2
+--R 
+--R
+--R        b x log(b x + a) - b x log(x) - a
+--R   (2)  ---------------------------------
+--R                        2
+--R                       a x
+--R                                                    Type: Expression(Integer)
+--E 689
+
+--S 690 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 690
+
+)clear all
+
+--S 691 of 762
+t0:=1/(a*x^3+b*x^4)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R           4      3
+--R        b x  + a x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 691
+
+--S 692 of 762
+r0:=(-1/2)/(a*x^2)+b/(a^2*x)+b^2*log(x)/a^3-b^2*log(a+b*x)/a^3
+--R 
+--R
+--R            2 2                 2 2                   2
+--R        - 2b x log(b x + a) + 2b x log(x) + 2a b x - a
+--R   (2)  -----------------------------------------------
+--R                               3 2
+--R                             2a x
+--R                                                    Type: Expression(Integer)
+--E 692
+
+--S 693 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 693
+
+)clear all
+
+--S 694 of 762
+t0:=x^4/sqrt(a*x^3+b*x^4)
+--R 
+--R
+--R               4
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 694
+
+--S 695 of 762
+r0:=-5/8*a^3*atanh(x^2*sqrt(b)/sqrt(a*x^3+b*x^4))/b^(7/2)-_
+     5/12*a*sqrt(a*x^3+b*x^4)/b^2+5/8*a^2*sqrt(a*x^3+b*x^4)/_
+     (b^3*x)+1/3*x*sqrt(a*x^3+b*x^4)/b
+--R 
+--R
+--R   (2)
+--R                      2 +-+                                     +-----------+
+--R        3            x \|b            2 2                2  +-+ |   4      3
+--R   - 15a x atanh(--------------) + (8b x  - 10a b x + 15a )\|b \|b x  + a x
+--R                  +-----------+
+--R                  |   4      3
+--R                 \|b x  + a x
+--R   --------------------------------------------------------------------------
+--R                                       3  +-+
+--R                                    24b x\|b
+--R                                                    Type: Expression(Integer)
+--E 695
+
+--S 696 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 696
+
+)clear all
+
+--S 697 of 762
+t0:=x^3/sqrt(a*x^3+b*x^4)
+--R 
+--R
+--R               3
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 697
+
+--S 698 of 762
+r0:=3/4*a^2*atanh(x^2*sqrt(b)/sqrt(a*x^3+b*x^4))/b^(5/2)+_
+     1/2*sqrt(a*x^3+b*x^4)/b-3/4*a*sqrt(a*x^3+b*x^4)/(b^2*x)
+--R 
+--R
+--R                        2 +-+                        +-----------+
+--R          2            x \|b                     +-+ |   4      3
+--R        3a x atanh(--------------) + (2b x - 3a)\|b \|b x  + a x
+--R                    +-----------+
+--R                    |   4      3
+--R                   \|b x  + a x
+--R   (2)  ----------------------------------------------------------
+--R                                   2  +-+
+--R                                 4b x\|b
+--R                                                    Type: Expression(Integer)
+--E 698
+
+--S 699 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 699
+
+)clear all
+
+--S 700 of 762
+t0:=x^2/sqrt(a*x^3+b*x^4)
+--R 
+--R
+--R               2
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 700
+
+--S 701 of 762
+r0:=-a*atanh(x^2*sqrt(b)/sqrt(a*x^3+b*x^4))/b^(3/2)+sqrt(a*x^3+b*x^4)/(b*x)
+--R 
+--R
+--R                         2 +-+             +-----------+
+--R                        x \|b          +-+ |   4      3
+--R        - a x atanh(--------------) + \|b \|b x  + a x
+--R                     +-----------+
+--R                     |   4      3
+--R                    \|b x  + a x
+--R   (2)  ------------------------------------------------
+--R                                 +-+
+--R                             b x\|b
+--R                                                    Type: Expression(Integer)
+--E 701
+
+--S 702 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 702
+
+)clear all
+
+--S 703 of 762
+t0:=x/sqrt(a*x^3+b*x^4)
+--R 
+--R
+--R               x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 703
+
+--S 704 of 762
+r0:=2*atanh(x^2*sqrt(b)/sqrt(a*x^3+b*x^4))/sqrt(b)
+--R 
+--R
+--R                    2 +-+
+--R                   x \|b
+--R        2atanh(--------------)
+--R                +-----------+
+--R                |   4      3
+--R               \|b x  + a x
+--R   (2)  ----------------------
+--R                  +-+
+--R                 \|b
+--R                                                    Type: Expression(Integer)
+--E 704
+
+--S 705 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 705
+
+)clear all
+
+--S 706 of 762
+t0:=1/sqrt(a*x^3+b*x^4)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |   4      3
+--R        \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 706
+
+--S 707 of 762
+r0:=-2*sqrt(a*x^3+b*x^4)/(a*x^2)
+--R 
+--R
+--R            +-----------+
+--R            |   4      3
+--R          2\|b x  + a x
+--R   (2)  - ---------------
+--R                   2
+--R                a x
+--R                                                    Type: Expression(Integer)
+--E 707
+
+--S 708 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 708
+
+)clear all
+
+--S 709 of 762
+t0:=1/(x*sqrt(a*x^3+b*x^4))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R          +-----------+
+--R          |   4      3
+--R        x\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 709
+
+--S 710 of 762
+r0:=-2/3*sqrt(a*x^3+b*x^4)/(a*x^3)+4/3*b*sqrt(a*x^3+b*x^4)/(a^2*x^2)
+--R 
+--R
+--R                    +-----------+
+--R                    |   4      3
+--R        (4b x - 2a)\|b x  + a x
+--R   (2)  -------------------------
+--R                    2 3
+--R                  3a x
+--R                                                    Type: Expression(Integer)
+--E 710
+
+--S 711 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 711
+
+)clear all
+
+--S 712 of 762
+t0:=1/(x^2*sqrt(a*x^3+b*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         2 |   4      3
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 712
+
+--S 713 of 762
+r0:=-2/5*sqrt(a*x^3+b*x^4)/(a*x^4)+8/15*b*sqrt(a*x^3+b*x^4)/(a^2*x^3)-_
+     16/15*b^2*sqrt(a*x^3+b*x^4)/(a^3*x^2)
+--R 
+--R
+--R                                  +-----------+
+--R              2 2              2  |   4      3
+--R        (- 16b x  + 8a b x - 6a )\|b x  + a x
+--R   (2)  ---------------------------------------
+--R                            3 4
+--R                         15a x
+--R                                                    Type: Expression(Integer)
+--E 713
+
+--S 714 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 714
+
+)clear all
+
+--S 715 of 762
+t0:=1/(x^3*sqrt(a*x^3+b*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         3 |   4      3
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 715
+
+--S 716 of 762
+r0:=-2/7*sqrt(a*x^3+b*x^4)/(a*x^5)+12/35*b*sqrt(a*x^3+b*x^4)/(a^2*x^4)-_
+     16/35*b^2*sqrt(a*x^3+b*x^4)/(a^3*x^3)+32/35*b^3*_
+     sqrt(a*x^3+b*x^4)/(a^4*x^2)
+--R 
+--R
+--R                                             +-----------+
+--R            3 3        2 2      2         3  |   4      3
+--R        (32b x  - 16a b x  + 12a b x - 10a )\|b x  + a x
+--R   (2)  --------------------------------------------------
+--R                                 4 5
+--R                              35a x
+--R                                                    Type: Expression(Integer)
+--E 716
+
+--S 717 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 717
+
+)clear all
+
+--S 718 of 762
+t0:=1/(x^4*sqrt(a*x^3+b*x^4))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           +-----------+
+--R         4 |   4      3
+--R        x \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 718
+
+--S 719 of 762
+r0:=-2/9*sqrt(a*x^3+b*x^4)/(a*x^6)+16/63*b*sqrt(a*x^3+b*x^4)/(a^2*x^5)-_
+     32/105*b^2*sqrt(a*x^3+b*x^4)/(a^3*x^4)+128/315*b^3*_
+     sqrt(a*x^3+b*x^4)/(a^4*x^3)-256/315*b^4*sqrt(a*x^3+b*x^4)/(a^5*x^2)
+--R 
+--R
+--R                                                            +-----------+
+--R               4 4         3 3      2 2 2      3         4  |   4      3
+--R        (- 256b x  + 128a b x  - 96a b x  + 80a b x - 70a )\|b x  + a x
+--R   (2)  -----------------------------------------------------------------
+--R                                         5 6
+--R                                     315a x
+--R                                                    Type: Expression(Integer)
+--E 719
+
+--S 720 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 720
+
+)clear all
+
+--S 721 of 762
+t0:=1/(a*x+b*x)
+--R 
+--R
+--R            1
+--R   (1)  --------
+--R        (b + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 721
+
+--S 722 of 762
+r0:=log(x)/(a+b)
+--R 
+--R
+--R        log(x)
+--R   (2)  ------
+--R         b + a
+--R                                                    Type: Expression(Integer)
+--E 722
+
+--S 723 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 723
+
+)clear all
+
+--S 724 of 762
+t0:=1/(x^3+b*x^5)
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R           5    3
+--R        b x  + x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 724
+
+--S 725 of 762
+r0:=(-1/2)/x^2+b*atanh(1+2*b*x^2)
+--R 
+--R
+--R            2          2
+--R        2b x atanh(2b x  + 1) - 1
+--R   (2)  -------------------------
+--R                     2
+--R                   2x
+--R                                                    Type: Expression(Integer)
+--E 725
+
+--S 726 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 726
+
+)clear all
+
+--S 727 of 762
+t0:=1/(-x^3+b*x^5)
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R           5    3
+--R        b x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 727
+
+--S 728 of 762
+r0:=1/2/x^2+b*atanh(1-2*b*x^2)
+--R 
+--R
+--R              2          2
+--R        - 2b x atanh(2b x  - 1) + 1
+--R   (2)  ---------------------------
+--R                      2
+--R                    2x
+--R                                                    Type: Expression(Integer)
+--E 728
+
+--S 729 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 729
+
+)clear all
+
+--S 730 of 762
+t0:=1/(-x^3+x^6)
+--R 
+--R
+--R           1
+--R   (1)  -------
+--R         6    3
+--R        x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 730
+
+--S 731 of 762
+r0:=1/2/x^2+1/3*log(1-x)-1/6*log(1+x+x^2)-atan((1+2*x)/sqrt(3))/sqrt(3)
+--R 
+--R
+--R   (2)
+--R                                                                    +-+
+--R      2 +-+     2              2 +-+                 2     (2x + 1)\|3       +-+
+--R   - x \|3 log(x  + x + 1) + 2x \|3 log(- x + 1) - 6x atan(------------) + 3\|3
+--R                                                                 3
+--R   -----------------------------------------------------------------------------
+--R                                        2 +-+
+--R                                      6x \|3
+--R                                                    Type: Expression(Integer)
+--E 731
+
+--S 732 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 732
+
+)clear all
+
+--S 733 of 762
+t0:=x^11/(a*x^2+b*x^5)^3
+--R 
+--R
+--R                       5
+--R                      x
+--R   (1)  -----------------------------
+--R         3 9       2 6     2   3    3
+--R        b x  + 3a b x  + 3a b x  + a
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 733
+
+--S 734 of 762
+r0:=1/6*x^6/(a*(a+b*x^3)^2)
+--R 
+--R
+--R                 1  6
+--R                 - x
+--R                 6
+--R   (2)  ---------------------
+--R           2 6     2   3    3
+--R        a b x  + 2a b x  + a
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 734
+
+--S 735 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 735
+
+)clear all
+
+--S 736 of 762
+t0:=1/(x^2*sqrt(a/x^2+b*x^n))
+--R 
+--R
+--R               1
+--R   (1)  ---------------
+--R           +----------+
+--R           |   2 n
+--R         2 |b x x  + a
+--R        x  |----------
+--R           |     2
+--R          \|    x
+--R                                                    Type: Expression(Integer)
+--E 736
+
+--S 737 of 762
+r0:=-2*atanh(sqrt(a)/(x*sqrt(a/x^2+b*x^n)))/((2+n)*sqrt(a))
+--R 
+--R
+--R                       +-+
+--R                      \|a
+--R          2atanh(--------------)
+--R                   +----------+
+--R                   |   2 n
+--R                   |b x x  + a
+--R                 x |----------
+--R                   |     2
+--R                  \|    x
+--R   (2)  - ----------------------
+--R                        +-+
+--R                (n + 2)\|a
+--R                                                    Type: Expression(Integer)
+--E 737
+
+--S 738 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 738
+
+)clear all
+
+--S 739 of 762
+t0:=sqrt(b/x^2+a*x^r)
+--R 
+--R
+--R         +----------+
+--R         |   2 r
+--R         |a x x  + b
+--R   (1)   |----------
+--R         |     2
+--R        \|    x
+--R                                                    Type: Expression(Integer)
+--E 739
+
+--S 740 of 762
+r0:=-2*atanh(sqrt(b)/(x*sqrt(b/x^2+a*x^r)))*sqrt(b)/(2+r)+_
+     2*x*sqrt(b/x^2+a*x^r)/(2+r)
+--R 
+--R
+--R                                          +----------+
+--R                           +-+            |   2 r
+--R            +-+           \|b             |a x x  + b
+--R        - 2\|b atanh(--------------) + 2x |----------
+--R                       +----------+       |     2
+--R                       |   2 r           \|    x
+--R                       |a x x  + b
+--R                     x |----------
+--R                       |     2
+--R                      \|    x
+--R   (2)  ----------------------------------------------
+--R                             r + 2
+--R                                                    Type: Expression(Integer)
+--E 740
+
+--S 741 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 741
+
+)clear all
+
+--S 742 of 762
+t0:=sqrt((a+b*x)/x^2)
+--R 
+--R
+--R         +-------+
+--R         |b x + a
+--R   (1)   |-------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 742
+
+--S 743 of 762
+r0:=-2*atanh(sqrt(a)/(x*sqrt(a/x^2+b/x)))*sqrt(a)+2*x*sqrt(a/x^2+b/x)
+--R 
+--R
+--R                          +-+          +-------+
+--R            +-+          \|a           |b x + a
+--R   (2)  - 2\|a atanh(-----------) + 2x |-------
+--R                       +-------+       |    2
+--R                       |b x + a       \|   x
+--R                     x |-------
+--R                       |    2
+--R                      \|   x
+--R                                                    Type: Expression(Integer)
+--E 743
+
+--S 744 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 744
+
+)clear all
+
+--S 745 of 762
+t0:=sqrt((a+b*x^2)/x^2)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R         |b x  + a
+--R   (1)   |--------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 745
+
+--S 746 of 762
+r0:=-atanh(sqrt(a)/(x*sqrt(b+a/x^2)))*sqrt(a)+x*sqrt(b+a/x^2)
+--R 
+--R
+--R                                      +--------+
+--R                         +-+          |   2
+--R           +-+          \|a           |b x  + a
+--R   (2)  - \|a atanh(------------) + x |--------
+--R                      +--------+      |    2
+--R                      |   2          \|   x
+--R                      |b x  + a
+--R                    x |--------
+--R                      |    2
+--R                     \|   x
+--R                                                    Type: Expression(Integer)
+--E 746
+
+--S 747 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 747
+
+)clear all
+
+--S 748 of 762
+t0:=sqrt((a+b*x^3)/x^2)
+--R 
+--R
+--R         +--------+
+--R         |   3
+--R         |b x  + a
+--R   (1)   |--------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 748
+
+--S 749 of 762
+r0:=-2/3*atanh(sqrt(a)/(x*sqrt(a/x^2+b*x)))*sqrt(a)+2/3*x*sqrt(a/x^2+b*x)
+--R 
+--R
+--R                                        +--------+
+--R                          +-+           |   3
+--R            +-+          \|a            |b x  + a
+--R        - 2\|a atanh(------------) + 2x |--------
+--R                       +--------+       |    2
+--R                       |   3           \|   x
+--R                       |b x  + a
+--R                     x |--------
+--R                       |    2
+--R                      \|   x
+--R   (2)  ------------------------------------------
+--R                             3
+--R                                                    Type: Expression(Integer)
+--E 749
+
+--S 750 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 750
+
+)clear all
+
+--S 751 of 762
+t0:=sqrt((a+b*x^n)/x^2)
+--R 
+--R
+--R         +--------+
+--R         |   n
+--R         |b x  + a
+--R   (1)   |--------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 751
+
+--S 752 of 762
+r0:=-2*atanh(sqrt(a)/(x*sqrt(a/x^2+b*x^(-2+n))))*sqrt(a)/n+_
+     2*x*sqrt(a/x^2+b*x^(-2+n))/n
+--R 
+--R
+--R                                              +--------------+
+--R                             +-+              |   2 n - 2
+--R            +-+             \|a               |b x x      + a
+--R        - 2\|a atanh(------------------) + 2x |--------------
+--R                       +--------------+       |       2
+--R                       |   2 n - 2           \|      x
+--R                       |b x x      + a
+--R                     x |--------------
+--R                       |       2
+--R                      \|      x
+--R   (2)  ------------------------------------------------------
+--R                                   n
+--R                                                    Type: Expression(Integer)
+--E 752
+
+--S 753 of 762
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 753
+
+)clear all
+
+--S 754 of 762
+t0:=sqrt((-a+b*x)/x^2)
+--R 
+--R
+--R         +-------+
+--R         |b x - a
+--R   (1)   |-------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 754
+
+--S 755 of 762
+r0:=2*atan(sqrt(a)/(x*sqrt(-a/x^2+b/x)))*sqrt(a)+2*x*sqrt(-a/x^2+b/x)
+--R 
+--R
+--R                       +-+          +-------+
+--R          +-+         \|a           |b x - a
+--R   (2)  2\|a atan(-----------) + 2x |-------
+--R                    +-------+       |    2
+--R                    |b x - a       \|   x
+--R                  x |-------
+--R                    |    2
+--R                   \|   x
+--R                                                    Type: Expression(Integer)
+--E 755
+
+--S 756 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 756
+
+)clear all
+
+--S 757 of 762
+t0:=sqrt((-a+b*x^2)/x^2)
+--R 
+--R
+--R         +--------+
+--R         |   2
+--R         |b x  - a
+--R   (1)   |--------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 757
+
+--S 758 of 762
+r0:=atan(sqrt(a)/(x*sqrt(b-a/x^2)))*sqrt(a)+x*sqrt(b-a/x^2)
+--R 
+--R
+--R                                   +--------+
+--R                      +-+          |   2
+--R         +-+         \|a           |b x  - a
+--R   (2)  \|a atan(------------) + x |--------
+--R                   +--------+      |    2
+--R                   |   2          \|   x
+--R                   |b x  - a
+--R                 x |--------
+--R                   |    2
+--R                  \|   x
+--R                                                    Type: Expression(Integer)
+--E 758
+
+--S 759 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 759
+
+)clear all
+
+--S 760 of 762
+t0:=sqrt((-a+b*x^3)/x^2)
+--R 
+--R
+--R         +--------+
+--R         |   3
+--R         |b x  - a
+--R   (1)   |--------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 760
+
+--S 761 of 762
+r0:=2/3*atan(sqrt(a)/(x*sqrt(-a/x^2+b*x)))*sqrt(a)+2/3*x*sqrt(-a/x^2+b*x)
+--R 
+--R
+--R                                     +--------+
+--R                       +-+           |   3
+--R          +-+         \|a            |b x  - a
+--R        2\|a atan(------------) + 2x |--------
+--R                    +--------+       |    2
+--R                    |   3           \|   x
+--R                    |b x  - a
+--R                  x |--------
+--R                    |    2
+--R                   \|   x
+--R   (2)  ---------------------------------------
+--R                           3
+--R                                                    Type: Expression(Integer)
+--E 761
+
+--S 762 of 762
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 762
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/richder8d.input.pamphlet b/src/input/richder8d.input.pamphlet
new file mode 100644
index 0000000..28f9e79
--- /dev/null
+++ b/src/input/richder8d.input.pamphlet
@@ -0,0 +1,3729 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input richder8d.input}
+\author{Albert Rich and Timothy Daly}
+\maketitle
+\begin{abstract}
+\verb|x^m (a x^q+b x^n)^p|
+
+1 derivative did not match.
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)sys rm -f richder8d.output
+)spool richder8d.output
+)set message test on
+)set message auto off
+)clear all
+
+
+--S 1 of 324
+t0:=sqrt((-a+b*x^n)/x^2)
+--R 
+--R
+--R         +--------+
+--R         |   n
+--R         |b x  - a
+--R   (1)   |--------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 1
+
+--S 2 of 324
+r0:=2*atan(sqrt(a)/(x*sqrt(-a/x^2+b*x^(-2+n))))*sqrt(a)/n+_
+     2*x*sqrt(-a/x^2+b*x^(-2+n))/n
+--R 
+--R
+--R                                           +--------------+
+--R                          +-+              |   2 n - 2
+--R          +-+            \|a               |b x x      - a
+--R        2\|a atan(------------------) + 2x |--------------
+--R                    +--------------+       |       2
+--R                    |   2 n - 2           \|      x
+--R                    |b x x      - a
+--R                  x |--------------
+--R                    |       2
+--R                   \|      x
+--R   (2)  ---------------------------------------------------
+--R                                 n
+--R                                                    Type: Expression(Integer)
+--E 2
+
+--S 3 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 3
+
+)clear all
+
+--S 4 of 324
+t0:=x^(-1+1/2*(1-n))*sqrt(a*x^(-1+n)+b*x^n)
+--R 
+--R
+--R         - n - 1
+--R         ------- +---------------+
+--R            2    |   n      n - 1
+--R   (1)  x       \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 4
+
+--S 5 of 324
+r0:=-2*atanh(x^(1/2*(-1+n))*sqrt(a)/sqrt(a*x^(-1+n)+b*x^n))*sqrt(a)+_
+     2*x^(1/2*(1-n))*sqrt(a*x^(-1+n)+b*x^n)
+--R 
+--R
+--R                          n - 1
+--R                          -----              - n + 1
+--R                            2   +-+          ------- +---------------+
+--R            +-+          x     \|a              2    |   n      n - 1
+--R   (2)  - 2\|a atanh(------------------) + 2x       \|b x  + a x
+--R                      +---------------+
+--R                      |   n      n - 1
+--R                     \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 5
+
+--S 6 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 6
+
+)clear all
+
+--S 7 of 324
+t0:=sqrt((1+x)/x^5)
+--R 
+--R
+--R         +-----+
+--R         |x + 1
+--R   (1)   |-----
+--R         |   5
+--R        \|  x
+--R                                                    Type: Expression(Integer)
+--E 7
+
+--S 8 of 324
+r0:=-2/3*(1/x^5+1/x^4)^(3/2)*x^6
+--R 
+--R
+--R                     +-----+
+--R             2       |x + 1
+--R        (- 2x  - 2x) |-----
+--R                     |   5
+--R                    \|  x
+--R   (2)  --------------------
+--R                  3
+--R                                                    Type: Expression(Integer)
+--E 8
+
+--S 9 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 9
+
+)clear all
+
+--S 10 of 324
+t0:=sqrt(x+x^(5/2))
+--R 
+--R
+--R         +----------+
+--R         | 2 +-+
+--R   (1)  \|x \|x  + x
+--R                                                    Type: Expression(Integer)
+--E 10
+
+--S 11 of 324
+r0:=4/9*(x+x^(5/2))^(3/2)/x^(3/2)
+--R 
+--R
+--R                     +----------+
+--R            +-+      | 2 +-+
+--R        (4x\|x  + 4)\|x \|x  + x
+--R   (2)  -------------------------
+--R                    +-+
+--R                  9\|x
+--R                                                    Type: Expression(Integer)
+--E 11
+
+--S 12 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 12
+
+)clear all
+
+--S 13 of 324
+t0:=1/(x^(3/2)+sqrt(x))
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R                +-+
+--R        (x + 1)\|x
+--R                                                    Type: Expression(Integer)
+--E 13
+
+--S 14 of 324
+r0:=2*atan(sqrt(x))
+--R 
+--R
+--R               +-+
+--R   (2)  2atan(\|x )
+--R                                                    Type: Expression(Integer)
+--E 14
+
+--S 15 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 15
+
+)clear all
+
+--S 16 of 324
+t0:=x*sqrt(x^2*(a+b*x^3))
+--R 
+--R
+--R          +-----------+
+--R          |   5      2
+--R   (1)  x\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 16
+
+--S 17 of 324
+r0:=2/9*(a*x^2+b*x^5)^(3/2)/(b*x^3)
+--R 
+--R
+--R                     +-----------+
+--R             3       |   5      2
+--R        (2b x  + 2a)\|b x  + a x
+--R   (2)  --------------------------
+--R                   9b x
+--R                                                    Type: Expression(Integer)
+--E 17
+
+--S 18 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 18
+
+)clear all
+
+--S 19 of 324
+t0:=x*sqrt(a*x^2+b*x^5)
+--R 
+--R
+--R          +-----------+
+--R          |   5      2
+--R   (1)  x\|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 19
+
+--S 20 of 324
+r0:=2/9*(a*x^2+b*x^5)^(3/2)/(b*x^3)
+--R 
+--R
+--R                     +-----------+
+--R             3       |   5      2
+--R        (2b x  + 2a)\|b x  + a x
+--R   (2)  --------------------------
+--R                   9b x
+--R                                                    Type: Expression(Integer)
+--E 20
+
+--S 21 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 21
+
+)clear all
+
+--S 22 of 324
+t0:=1/(b/x+a*x)
+--R 
+--R
+--R            x
+--R   (1)  --------
+--R           2
+--R        a x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 22
+
+--S 23 of 324
+r0:=1/2*log(b+a*x^2)/a
+--R 
+--R
+--R               2
+--R        log(a x  + b)
+--R   (2)  -------------
+--R              2a
+--R                                                    Type: Expression(Integer)
+--E 23
+
+--S 24 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 24
+
+)clear all
+
+--S 25 of 324
+t0:=1/(b/x^2+a*x)
+--R 
+--R
+--R            2
+--R           x
+--R   (1)  --------
+--R           3
+--R        a x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 25
+
+--S 26 of 324
+r0:=1/3*log(b+a*x^3)/a
+--R 
+--R
+--R               3
+--R        log(a x  + b)
+--R   (2)  -------------
+--R              3a
+--R                                                    Type: Expression(Integer)
+--E 26
+
+--S 27 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 27
+
+)clear all
+
+--S 28 of 324
+t0:=1/(b/x^3+a*x)
+--R 
+--R
+--R            3
+--R           x
+--R   (1)  --------
+--R           4
+--R        a x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 28
+
+--S 29 of 324
+r0:=1/4*log(b+a*x^4)/a
+--R 
+--R
+--R               4
+--R        log(a x  + b)
+--R   (2)  -------------
+--R              4a
+--R                                                    Type: Expression(Integer)
+--E 29
+
+--S 30 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 30
+
+)clear all
+
+--S 31 of 324
+t0:=1/(b/x+a*x)^3
+--R 
+--R
+--R                       3
+--R                      x
+--R   (1)  -----------------------------
+--R         3 6     2   4       2 2    3
+--R        a x  + 3a b x  + 3a b x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 31
+
+--S 32 of 324
+r0:=1/4*x^4/(b*(b+a*x^2)^2)
+--R 
+--R
+--R                 1  4
+--R                 - x
+--R                 4
+--R   (2)  ---------------------
+--R         2   4       2 2    3
+--R        a b x  + 2a b x  + b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 32
+
+--S 33 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 33
+
+)clear all
+
+--S 34 of 324
+t0:=1/(b/x^3+a*x^2)^3
+--R 
+--R
+--R                        9
+--R                       x
+--R   (1)  -------------------------------
+--R         3 15     2   10       2 5    3
+--R        a x   + 3a b x   + 3a b x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 34
+
+--S 35 of 324
+r0:=1/10*x^10/(b*(b+a*x^5)^2)
+--R 
+--R
+--R                 1  10
+--R                -- x
+--R                10
+--R   (2)  ----------------------
+--R         2   10       2 5    3
+--R        a b x   + 2a b x  + b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 35
+
+--S 36 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 36
+
+)clear all
+
+--S 37 of 324
+t0:=1/(b/x^5+a*x^3)^3
+--R 
+--R
+--R                       15
+--R                      x
+--R   (1)  -------------------------------
+--R         3 24     2   16       2 8    3
+--R        a x   + 3a b x   + 3a b x  + b
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 37
+
+--S 38 of 324
+r0:=1/16*x^16/(b*(b+a*x^8)^2)
+--R 
+--R
+--R                 1  16
+--R                -- x
+--R                16
+--R   (2)  ----------------------
+--R         2   16       2 8    3
+--R        a b x   + 2a b x  + b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 38
+
+--S 39 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 39
+
+)clear all
+
+--S 40 of 324
+t0:=(a/x+b*x)^2
+--R 
+--R
+--R         2 4         2    2
+--R        b x  + 2a b x  + a
+--R   (1)  -------------------
+--R                  2
+--R                 x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 40
+
+--S 41 of 324
+r0:=-a^2/x+2*a*b*x+1/3*b^2*x^3
+--R 
+--R
+--R         2 4         2     2
+--R        b x  + 6a b x  - 3a
+--R   (2)  --------------------
+--R                 3x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 41
+
+--S 42 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 42
+
+)clear all
+
+--S 43 of 324
+t0:=(a/x+b*x)^3
+--R 
+--R
+--R         3 6       2 4     2   2    3
+--R        b x  + 3a b x  + 3a b x  + a
+--R   (1)  -----------------------------
+--R                       3
+--R                      x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 43
+
+--S 44 of 324
+r0:=-1/2*a^3/x^2+3/2*a*b^2*x^2+1/4*b^3*x^4+3*a^2*b*log(x)
+--R 
+--R
+--R           2   2          3 6       2 4     3
+--R        12a b x log(x) + b x  + 6a b x  - 2a
+--R   (2)  -------------------------------------
+--R                           2
+--R                         4x
+--R                                                    Type: Expression(Integer)
+--E 44
+
+--S 45 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 45
+
+)clear all
+
+--S 46 of 324
+t0:=(a/x+b*x)^4
+--R 
+--R
+--R         4 8       3 6     2 2 4     3   2    4
+--R        b x  + 4a b x  + 6a b x  + 4a b x  + a
+--R   (1)  ---------------------------------------
+--R                            4
+--R                           x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 46
+
+--S 47 of 324
+r0:=-1/3*a^4/x^3-4*a^3*b/x+6*a^2*b^2*x+4/3*a*b^3*x^3+1/5*b^4*x^5
+--R 
+--R
+--R        1  4 8   4    3 6     2 2 4     3   2   1  4
+--R        - b x  + - a b x  + 6a b x  - 4a b x  - - a
+--R        5        3                              3
+--R   (2)  --------------------------------------------
+--R                              3
+--R                             x
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 47
+
+--S 48 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 48
+
+)clear all
+
+--S 49 of 324
+t0:=1/(1/x^2+x^3)
+--R 
+--R
+--R           2
+--R          x
+--R   (1)  ------
+--R         5
+--R        x  + 1
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 49
+
+--S 50 of 324
+r0:=1/5*log(1+x)-1/20*log(2+2*x^2-x*(1+sqrt(5)))*(1-sqrt(5))-_
+     1/20*log(2+2*x^2-x*(1-sqrt(5)))*(1+sqrt(5))+_
+     atan((1-4*x-sqrt(5))/sqrt(2*(5+sqrt(5))))*sqrt(2/5/(5+sqrt(5)))-_
+     1/5*atan(1/2*(1-4*x+sqrt(5))*sqrt(1/10*(5+sqrt(5))))*sqrt(1/2*(5+sqrt(5)))
+--R 
+--R
+--R   (2)
+--R                                                   +----------+
+--R         +----------+               +-+            |  +-+
+--R         |   +-+          ((2x - 3)\|5  - 10x + 5)\|2\|5  + 10
+--R       4\|- \|5  + 5 atan(-------------------------------------)
+--R                                            20
+--R     + 
+--R                                          +--------+
+--R           +--------+       +-+           | +-+
+--R           | +-+          (\|5  - 4x + 1)\|\|5  + 5
+--R       - 4\|\|5  + 5 atan(--------------------------)
+--R                                      +--+
+--R                                    2\|10
+--R     + 
+--R           +-+ +-+    +-+       +-+     2              +-+
+--R       (- \|2 \|5  - \|2 )log(x\|5  + 2x  - x + 2) + 4\|2 log(x + 1)
+--R     + 
+--R         +-+ +-+    +-+         +-+     2
+--R       (\|2 \|5  - \|2 )log(- x\|5  + 2x  - x + 2)
+--R  /
+--R        +-+
+--R     20\|2
+--R                                                    Type: Expression(Integer)
+--E 50
+
+--S 51 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)
+--R                                         +----------+ +----------+
+--R            +-+ +-+      2          +-+  |   +-+      |  +-+
+--R       (- x\|2 \|5  + (2x  - x + 2)\|2 )\|- \|5  + 5 \|2\|5  + 10
+--R     + 
+--R             +-+ +-+        2           +-+  +--+
+--R       (- 2x\|2 \|5  + (- 4x  + 2x - 4)\|2 )\|10  + 40x
+--R  /
+--R        4      3      2
+--R     80x  - 80x  + 80x  - 80x + 80
+--R                                                    Type: Expression(Integer)
+--E 51
+
+)clear all
+
+--S 52 of 324
+t0:=(b*x^n+a*x^q)^(3/2)
+--R 
+--R
+--R                      +-----------+
+--R            q      n  |   q      n
+--R   (1)  (a x  + b x )\|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 52
+
+--S 53 of 324
+--r0:=2*x*(b*x^n+a*x^q)^(3/2)/(2+3*n)+6*a*(n-q)*x^(1+q)*_
+--     sqrt(b*x^n+a*x^q)/((2+3*n)*(2+n+2*q))+6*a^2*(n-q)^2*_
+--     x^(1+2*q)*hypergeometric(1/2,(1+3/2*q)/(n-q),1/2*(2+2*n+q)/_
+--     (n-q),-b*x^(n-q)/a)*sqrt((b*x^n+a*x^q)/(a*x^q))/((2+3*n)*_
+--     (2+n+2*q)*(2+3*q)*sqrt(b*x^n+a*x^q))
+--E 53
+
+--S 54 of 324
+--d0:=t0-D(r0,x)
+--E 54
+
+)clear all
+
+--S 55 of 324
+t0:=(b*x^n+a*x^q)^(1/2)
+--R 
+--R
+--R         +-----------+
+--R         |   q      n
+--R   (1)  \|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 55
+
+--S 56 of 324
+--r0:=2*x*sqrt(b*x^n+a*x^q)/(2+n)+2*a*(n-q)*x^(1+q)*_
+--  hypergeometric(1/2,1/2*(2+q)/(n-q),1+(2+q)/(2*n-2*q),_
+--  -b*x^(n-q)/a)*sqrt((b*x^n+a*x^q)/(a*x^q))/((2+n)*(2+q)*sqrt(b*x^n+a*x^q))
+--E 56
+
+--S 57 of 324
+--d0:=t0-D(r0,x)
+--E 57
+
+)clear all
+
+--S 58 of 324
+t0:=1/(b*x^n+a*x^q)^(1/2)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |   q      n
+--R        \|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 58
+
+--S 59 of 324
+--r0:=2*x*hypergeometric(1/2,1/2*(2-q)/(n-q),1/2*(2+(2-q)/(n-q)),_
+--  -b*x^(n-q)/a)*sqrt((b*x^n+a*x^q)/(a*x^q))/((2-q)*sqrt(b*x^n+a*x^q))
+--E 59
+
+--S 60 of 324
+--d0:=t0-D(r0,x)
+--E 60
+
+)clear all
+
+--S 61 of 324
+t0:=1/(b*x^n+a*x^q)^(3/2)
+--R 
+--R
+--R                     1
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            q      n  |   q      n
+--R        (a x  + b x )\|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 61
+
+--S 62 of 324
+--r0:=2*x^(1-q)/(a*(n-q)*sqrt(b*x^n+a*x^q))-2*(2-n-2*q)*x^(1-q)*_
+--  hypergeometric(1/2,(1-3/2*q)/(n-q),1+(2-3*q)/(2*n-2*q),_
+--  -b*x^(n-q)/a)*sqrt((b*x^n+a*x^q)/(a*x^q))/(a*(2-3*q)*(n-q)*_
+--  sqrt(b*x^n+a*x^q))
+--E 62
+
+--S 63 of 324
+--d0:=t0-D(r0,x)
+--E 63
+
+)clear all
+
+--S 64 of 324
+t0:=1/(b*x^n+a*x^q)^(5/2)
+--R 
+--R
+--R                              1
+--R   (1)  ---------------------------------------------
+--R                                        +-----------+
+--R          2  q 2         n q    2  n 2  |   q      n
+--R        (a (x )  + 2a b x x  + b (x ) )\|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 64
+
+--S 65 of 324
+--r0:=2/3*x^(1-q)/(a*(n-q)*(b*x^n+a*x^q)^(3/2))-2/3*(2-3*n-2*q)*_
+--  x^(1-2*q)/(a^2*(n-q)^2*sqrt(b*x^n+a*x^q))+2/3*(2-n-4*q)*_
+--  (2-3*n-2*q)*x^(1-2*q)*hypergeometric(1/2,(1-5/2*q)/(n-q),_
+--  1+(2-5*q)/(2*n-2*q),-b*x^(n-q)/a)*sqrt((b*x^n+a*x^q)/_
+--  (a*x^q))/(a^2*(2-5*q)*(n-q)^2*sqrt(b*x^n+a*x^q))
+--E 65
+
+--S 66 of 324
+--d0:=t0-D(r0,x)
+--E 66
+
+)clear all
+
+--S 67 of 324
+t0:=x^m*(b*x^n+a*x^q)^(3/2)
+--R 
+--R
+--R                          +-----------+
+--R            m q      m n  |   q      n
+--R   (1)  (a x x  + b x x )\|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 67
+
+--S 68 of 324
+--r0:=2*x^(1+m)*(b*x^n+a*x^q)^(3/2)/(2+2*m+3*n)+6*a*(n-q)*x^(1+m+q)*_
+--  sqrt(b*x^n+a*x^q)/((2+2*m+3*n)*(2+2*m+n+2*q))+6*a^2*(n-q)^2*_
+--  x^(1+m+2*q)*hypergeometric(1/2,(1+m+3/2*q)/(n-q),1+(1+m+_
+--  3/2*q)/(n-q),-b*x^(n-q)/a)*sqrt((b*x^n+a*x^q)/(a*x^q))/_
+--  ((2+2*m+3*n)*(2+2*m+n+2*q)*(2+2*m+3*q)*sqrt(b*x^n+a*x^q))
+--E 68
+
+--S 69 of 324
+--d0:=t0-D(r0,x)
+--E 69
+
+)clear all
+
+--S 70 of 324
+t0:=x^m*(b*x^n+a*x^q)^(1/2)
+--R 
+--R
+--R           +-----------+
+--R         m |   q      n
+--R   (1)  x \|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 70
+
+--S 71 of 324
+--r0:=2*x^(1+m)*sqrt(b*x^n+a*x^q)/(2+2*m+n)+2*a*(n-q)*x^(1+m+q)*_
+--  hypergeometric(1/2,(1+m+1/2*q)/(n-q),1+(2+2*m+q)/(2*n-2*q),_
+--  -b*x^(n-q)/a)*sqrt((b*x^n+a*x^q)/(a*x^q))/((2+2*m+n)*(2+_
+--  2*m+q)*sqrt(b*x^n+a*x^q))
+--E 71
+
+--S 72 of 324
+--d0:=t0-D(r0,x)
+--E 72
+
+)clear all
+
+--S 73 of 324
+t0:=x^m/(b*x^n+a*x^q)^(1/2)
+--R 
+--R
+--R               m
+--R              x
+--R   (1)  --------------
+--R         +-----------+
+--R         |   q      n
+--R        \|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 73
+
+--S 74 of 324
+--r0:=2*x^(1+m)*hypergeometric(1/2,(1+m-1/2*q)/(n-q),1+(1+m-1/2*q)/(n-q),_
+--  -b*x^(n-q)/a)*sqrt((b*x^n+a*x^q)/(a*x^q))/((2+2*m-q)*sqrt(b*x^n+a*x^q))
+--E 74
+
+--S 75 of 324
+--d0:=t0-D(r0,x)
+--E 75
+
+)clear all
+
+--S 76 of 324
+t0:=x^m/(b*x^n+a*x^q)^(3/2)
+--R 
+--R
+--R                      m
+--R                     x
+--R   (1)  ---------------------------
+--R                      +-----------+
+--R            q      n  |   q      n
+--R        (a x  + b x )\|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 76
+
+--S 77 of 324
+--r0:=2*x^(1+m-q)/(a*(n-q)*sqrt(b*x^n+a*x^q))-2*(2+2*m-n-2*q)*x^(1+m-q)*_
+--  hypergeometric(1/2,(1+m-3/2*q)/(n-q),1+(1+m-3/2*q)/(n-q),_
+--  -b*x^(n-q)/a)*sqrt((b*x^n+a*x^q)/(a*x^q))/(a*(2+2*m-3*q)*_
+--  (n-q)*sqrt(b*x^n+a*x^q))
+--E 77
+
+--S 78 of 324
+--d0:=t0-D(r0,x)
+--E 78
+
+)clear all
+
+--S 79 of 324
+t0:=x^m/(b*x^n+a*x^q)^(5/2)
+--R 
+--R
+--R                               m
+--R                              x
+--R   (1)  ---------------------------------------------
+--R                                        +-----------+
+--R          2  q 2         n q    2  n 2  |   q      n
+--R        (a (x )  + 2a b x x  + b (x ) )\|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 79
+
+--S 80 of 324
+--r0:=2/3*x^(1+m-q)/(a*(n-q)*(b*x^n+a*x^q)^(3/2))-2/3*(2+2*m-3*n-2*q)*_
+--  x^(1+m-2*q)/(a^2*(n-q)^2*sqrt(b*x^n+a*x^q))+2/3*(2+2*m-n-4*q)*_
+--  (2+2*m-3*n-2*q)*x^(1+m-2*q)*hypergeometric(1/2,(1+m-5/2*q)/(n-q),_
+--  1+(1+m-5/2*q)/(n-q),-b*x^(n-q)/a)*sqrt((b*x^n+a*x^q)/(a*x^q))/_
+--  (a^2*(2+2*m-5*q)*(n-q)^2*sqrt(b*x^n+a*x^q))
+--E 80
+
+--S 81 of 324
+--d0:=t0-D(r0,x)
+--E 81
+
+)clear all
+
+--S 82 of 324
+t0:=x^m*(b*x^n+a*x^q)^p
+--R 
+--R
+--R         m    q      n p
+--R   (1)  x (a x  + b x )
+--R                                                    Type: Expression(Integer)
+--E 82
+
+--S 83 of 324
+--r0:=x^(1+m)*(b*x^n+a*x^q)^p*hypergeometric(-p,(1+m+p*q)/(n-q),_
+--  1+(1+m+p*q)/(n-q),-b*x^(n-q)/a)/((1+m+p*q)*((b*x^n+a*x^q)/(a*x^q))^p)
+--E 83
+
+--S 84 of 324
+--d0:=t0-D(r0,x)
+--E 84
+
+)clear all
+
+--S 85 of 324
+t0:=x^(-1-p*q)*(b*x^n+a*x^q)^p
+--R 
+--R
+--R         - p q - 1    q      n p
+--R   (1)  x         (a x  + b x )
+--R                                                    Type: Expression(Integer)
+--E 85
+
+--S 86 of 324
+--r0:=(b*x^n+a*x^q)^p*hypergeometric(-p,-p,1-p,-a*x^(-n+q)/b)/(p*(n-q)*_
+--  x^(p*q)*((b*x^n+a*x^q)/(b*x^n))^p)
+--E 86
+
+--S 87 of 324
+--d0:=t0-D(r0,x)
+--E 87
+
+)clear all
+
+--S 88 of 324
+t0:=x^(-1-n*p)*(b*x^n+a*x^q)^p
+--R 
+--R
+--R         - n p - 1    q      n p
+--R   (1)  x         (a x  + b x )
+--R                                                    Type: Expression(Integer)
+--E 88
+
+--S 89 of 324
+--r0:=-(b*x^n+a*x^q)^p*hypergeometric(-p,-p,1-p,-b*x^(n-q)/a)/(p*(n-q)*_
+--  x^(n*p)*((b*x^n+a*x^q)/(a*x^q))^p)
+--E 89
+
+--S 90 of 324
+--d0:=t0-D(r0,x)
+--E 90
+
+)clear all
+
+--S 91 of 324
+t0:=x^(-1-n-(-1+p)*q)*(b*x^n+a*x^q)^p
+--R 
+--R
+--R         (- p + 1)q - n - 1    q      n p
+--R   (1)  x                  (a x  + b x )
+--R                                                    Type: Expression(Integer)
+--E 91
+
+--S 92 of 324
+--r0:=-x^(-n-p*q)*(b*x^n+a*x^q)^(1+p)/(a*(n-q))+b*(b*x^n+a*x^q)^p*_
+--  hypergeometric(-p,-p,1-p,-a*x^(-n+q)/b)/(a*(n-q)*x^(p*q)*_
+--  ((b*x^n+a*x^q)/(b*x^n))^p)
+--E 92
+
+--S 93 of 324
+--d0:=t0-D(r0,x)
+--E 93
+
+)clear all
+
+--S 94 of 324
+t0:=x^(-1-n*(-1+p)-q)*(b*x^n+a*x^q)^p
+--R 
+--R
+--R         - q - n p + n - 1    q      n p
+--R   (1)  x                 (a x  + b x )
+--R                                                    Type: Expression(Integer)
+--E 94
+
+--S 95 of 324
+--r0:=x^(-n*p-q)*(b*x^n+a*x^q)^(1+p)/(b*(n-q))-a*(b*x^n+a*x^q)^p*_
+--  hypergeometric(-p,-p,1-p,-b*x^(n-q)/a)/(b*(n-q)*x^(n*p)*_
+--  ((b*x^n+a*x^q)/(a*x^q))^p)
+--E 95
+
+--S 96 of 324
+--d0:=t0-D(r0,x)
+--E 96
+
+)clear all
+
+--S 97 of 324
+t0:=(a*x^m+b*x^(1+m+m*p))^p
+--R 
+--R
+--R            m p + m + 1      m p
+--R   (1)  (b x            + a x )
+--R                                                    Type: Expression(Integer)
+--E 97
+
+--S 98 of 324
+r0:=(a*x^m+b*x^(1+m+m*p))^(1+p)/(b*(1+p)*(1+m*p)*x^(m*(1+p)))
+--R 
+--R
+--R               m p + m + 1      m p + 1
+--R           (b x            + a x )
+--R   (2)  ---------------------------------
+--R              2                   m p + m
+--R        (b m p  + (b m + b)p + b)x
+--R                                                    Type: Expression(Integer)
+--E 98
+
+--S 99 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 99
+
+)clear all
+
+--S 100 of 324
+t0:=(x^m*(a+b*x^(1+m*p)))^p
+--R 
+--R
+--R            m m p + 1      m p
+--R   (1)  (b x x        + a x )
+--R                                                    Type: Expression(Integer)
+--E 100
+
+--S 101 of 324
+r0:=(a*x^m+b*x^(1+m+m*p))^(1+p)/(b*(1+p)*(1+m*p)*x^(m*(1+p)))
+--R 
+--R
+--R               m p + m + 1      m p + 1
+--R           (b x            + a x )
+--R   (2)  ---------------------------------
+--R              2                   m p + m
+--R        (b m p  + (b m + b)p + b)x
+--R                                                    Type: Expression(Integer)
+--E 101
+
+--S 102 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 102
+
+)clear all
+
+--S 103 of 324
+t0:=x^n*(x^m*(a+b*x^(1+n+m*p)))^p
+--R 
+--R
+--R         n    m m p + n + 1      m p
+--R   (1)  x (b x x            + a x )
+--R                                                    Type: Expression(Integer)
+--E 103
+
+--S 104 of 324
+r0:=(a*x^m+b*x^(1+m+n+m*p))^(1+p)/(b*(1+p)*(1+n+m*p)*x^(m*(1+p)))
+--R 
+--R
+--R                   m p + n + m + 1      m p + 1
+--R               (b x                + a x )
+--R   (2)  ---------------------------------------------
+--R              2                               m p + m
+--R        (b m p  + (b n + b m + b)p + b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 104
+
+--S 105 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 105
+
+)clear all
+
+--S 106 of 324
+t0:=x^n*(a*x^m+b*x^(1+m+n+m*p))^p
+--R 
+--R
+--R         n    m p + n + m + 1      m p
+--R   (1)  x (b x                + a x )
+--R                                                    Type: Expression(Integer)
+--E 106
+
+--S 107 of 324
+r0:=(a*x^m+b*x^(1+m+n+m*p))^(1+p)/(b*(1+p)*(1+n+m*p)*x^(m*(1+p)))
+--R 
+--R
+--R                   m p + n + m + 1      m p + 1
+--R               (b x                + a x )
+--R   (2)  ---------------------------------------------
+--R              2                               m p + m
+--R        (b m p  + (b n + b m + b)p + b n + b)x
+--R                                                    Type: Expression(Integer)
+--E 107
+
+--S 108 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 108
+
+)clear all
+
+--S 109 of 324
+t0:=sqrt(x^4*(a+b*x^3))
+--R 
+--R
+--R         +-----------+
+--R         |   7      4
+--R   (1)  \|b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 109
+
+--S 110 of 324
+r0:=2/9*(a*x^4+b*x^7)^(3/2)/(b*x^6)
+--R 
+--R
+--R                     +-----------+
+--R             3       |   7      4
+--R        (2b x  + 2a)\|b x  + a x
+--R   (2)  --------------------------
+--R                       2
+--R                   9b x
+--R                                                    Type: Expression(Integer)
+--E 110
+
+--S 111 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 111
+
+)clear all
+
+--S 112 of 324
+t0:=(x^(2*(-1+n))*(a+b*x^n))^(1/2)
+--R 
+--R
+--R         +-----------------+
+--R         |    n      2n - 2
+--R   (1)  \|(b x  + a)x
+--R                                                    Type: Expression(Integer)
+--E 112
+
+--S 113 of 324
+r0:=2/3*x^(3*(1-n))*(a/x^(2*(1-n))+b*x^(-2+3*n))^(3/2)/(b*n)
+--R 
+--R
+--R                                                      +----------------------+
+--R                                                      |   - 2n + 2 3n - 2
+--R             - 3n + 3 - 2n + 2 3n - 2       - 3n + 3  |b x        x       + a
+--R        (2b x        x        x       + 2a x        ) |----------------------
+--R                                                      |        - 2n + 2
+--R                                                     \|       x
+--R   (2)  ----------------------------------------------------------------------
+--R                                          - 2n + 2
+--R                                    3b n x
+--R                                                    Type: Expression(Integer)
+--E 113
+
+--S 114 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 114
+
+)clear all
+
+--S 115 of 324
+t0:=(x^(3*(-1+n))*(a+b*x^n))^(1/3)
+--R 
+--R
+--R         +-----------------+
+--R        3|    n      3n - 3
+--R   (1)  \|(b x  + a)x
+--R                                                    Type: Expression(Integer)
+--E 115
+
+--S 116 of 324
+r0:=3/4*x^(4*(1-n))*(a/x^(3*(1-n))+b*x^(-3+4*n))^(4/3)/(b*n)
+--R 
+--R
+--R                                                       +----------------------+
+--R                                                       |   - 3n + 3 4n - 3
+--R             - 4n + 4 - 3n + 3 4n - 3       - 4n + 4   |b x        x       + a
+--R        (3b x        x        x       + 3a x        )  |----------------------
+--R                                                      3|        - 3n + 3
+--R                                                      \|       x
+--R   (2)  ----------------------------------------------------------------------
+--R                                          - 3n + 3
+--R                                    4b n x
+--R                                                    Type: Expression(Integer)
+--E 116
+
+--S 117 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 117
+
+)clear all
+
+--S 118 of 324
+t0:=(x^(4*(-1+n))*(a+b*x^n))^(1/4)
+--R 
+--R
+--R         +-----------------+
+--R        4|    n      4n - 4
+--R   (1)  \|(b x  + a)x
+--R                                                    Type: Expression(Integer)
+--E 118
+
+--S 119 of 324
+r0:=4/5*x^(5*(1-n))*(a/x^(4*(1-n))+b*x^(-4+5*n))^(5/4)/(b*n)
+--R 
+--R
+--R                                                       +----------------------+
+--R                                                       |   - 4n + 4 5n - 4
+--R             - 5n + 5 - 4n + 4 5n - 4       - 5n + 5   |b x        x       + a
+--R        (4b x        x        x       + 4a x        )  |----------------------
+--R                                                      4|        - 4n + 4
+--R                                                      \|       x
+--R   (2)  ----------------------------------------------------------------------
+--R                                          - 4n + 4
+--R                                    5b n x
+--R                                                    Type: Expression(Integer)
+--E 119
+
+--S 120 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 120
+
+)clear all
+
+--S 121 of 324
+t0:=(x^((-1+n)*p)*(a+b*x^n))^(1/p)
+--R 
+--R
+--R                             1
+--R                             -
+--R             n      (n - 1)p p
+--R   (1)  ((b x  + a)x        )
+--R                                                    Type: Expression(Integer)
+--E 121
+
+--S 122 of 324
+r0:=p*x^((1-n)*(1+p))*(a/x^((1-n)*p)+b*x^(n-(1-n)*p))^(1+1/p)/(b*n*(1+p))
+--R 
+--R
+--R                                                             p + 1
+--R                                                             -----
+--R                                 (- n + 1)p (n - 1)p + n       p
+--R           (- n + 1)p - n + 1 b x          x             + a
+--R        p x                  (------------------------------)
+--R                                         (- n + 1)p
+--R                                        x
+--R   (2)  ----------------------------------------------------------
+--R                                b n p + b n
+--R                                                    Type: Expression(Integer)
+--E 122
+
+--S 123 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 123
+
+)clear all
+
+--S 124 of 324
+t0:=(x^((-1+n)/p)*(a+b*x^n))^p
+--R 
+--R
+--R            n - 1        n - 1 p
+--R            -----        -----
+--R              p   n        p
+--R   (1)  (b x     x  + a x     )
+--R                                                    Type: Expression(Integer)
+--E 124
+
+--S 125 of 324
+r0:=x^((1-n)*(1+p)/p)*(b*x^(n+(-1+n)/p)+a/x^((1-n)/p))^(1+p)/(b*n*(1+p))
+--R 
+--R
+--R                               - n + 1 n p + n - 1     p + 1
+--R         (- n + 1)p - n + 1    ------- -----------
+--R         ------------------       p         p
+--R                  p         b x       x            + a
+--R        x                  (--------------------------)
+--R                                      - n + 1
+--R                                      -------
+--R                                         p
+--R                                     x
+--R   (2)  ----------------------------------------------------
+--R                             b n p + b n
+--R                                                    Type: Expression(Integer)
+--E 125
+
+--S 126 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 126
+
+)clear all
+
+--S 127 of 324
+t0:=(a*x+b*x^14)^12
+--R 
+--R
+--R   (1)
+--R      12 168        11 155      2 10 142       3 9 129       4 8 116
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 103       6 6 90       7 5 77       8 4 64       9 3 51
+--R     792a b x    + 924a b x   + 792a b x   + 495a b x   + 220a b x
+--R   + 
+--R        10 2 38      11   25    12 12
+--R     66a  b x   + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 127
+
+--S 128 of 324
+r0:=1/169*(a+b*x^13)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 169    1    12 156    6  2 11 143   22  3 10 130   55  4 9 117
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       169           13             13             13             13
+--R     + 
+--R       99  5 8 104   132  6 7 91   132  7 6 78   99  8 5 65   55  9 4 52
+--R       -- a b x    + --- a b x   + --- a b x   + -- a b x   + -- a b x
+--R       13             13            13           13           13
+--R     + 
+--R       22  10 3 39    6  11 2 26    1  12   13    1   13
+--R       -- a  b x   + -- a  b x   + -- a  b x   + --- a
+--R       13            13            13            169
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 128
+
+--S 129 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 129
+
+)clear all
+
+--S 130 of 324
+t0:=x^12*(a*x+b*x^26)^12
+--R 
+--R
+--R   (1)
+--R      12 324        11 299      2 10 274       3 9 249       4 8 224
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 199       6 6 174       7 5 149       8 4 124       9 3 99
+--R     792a b x    + 924a b x    + 792a b x    + 495a b x    + 220a b x
+--R   + 
+--R        10 2 74      11   49    12 24
+--R     66a  b x   + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 130
+
+--S 131 of 324
+r0:=1/325*(a+b*x^25)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 325    1    12 300    6  2 11 275   22  3 10 250   11  4 9 225
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       325           25             25             25              5
+--R     + 
+--R       99  5 8 200   132  6 7 175   132  7 6 150   99  8 5 125   11  9 4 100
+--R       -- a b x    + --- a b x    + --- a b x    + -- a b x    + -- a b x
+--R       25             25             25            25             5
+--R     + 
+--R       22  10 3 75    6  11 2 50    1  12   25    1   13
+--R       -- a  b x   + -- a  b x   + -- a  b x   + --- a
+--R       25            25            25            325
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 131
+
+--S 132 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 132
+
+)clear all
+
+--S 133 of 324
+t0:=x^24*(a*x+b*x^38)^12
+--R 
+--R
+--R   (1)
+--R      12 480        11 443      2 10 406       3 9 369       4 8 332
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 295       6 6 258       7 5 221       8 4 184       9 3 147
+--R     792a b x    + 924a b x    + 792a b x    + 495a b x    + 220a b x
+--R   + 
+--R        10 2 110      11   73    12 36
+--R     66a  b x    + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 133
+
+--S 134 of 324
+r0:=1/481*(a+b*x^37)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 481    1    12 444    6  2 11 407   22  3 10 370   55  4 9 333
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       481           37             37             37             37
+--R     + 
+--R       99  5 8 296   132  6 7 259   132  7 6 222   99  8 5 185   55  9 4 148
+--R       -- a b x    + --- a b x    + --- a b x    + -- a b x    + -- a b x
+--R       37             37             37            37            37
+--R     + 
+--R       22  10 3 111    6  11 2 74    1  12   37    1   13
+--R       -- a  b x    + -- a  b x   + -- a  b x   + --- a
+--R       37             37            37            481
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 134
+
+--S 135 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 135
+
+)clear all
+
+--S 136 of 324
+t0:=x^(12*(-1+m))*(a*x+b*x^(2+12*m))^12
+--R 
+--R
+--R   (1)
+--R      12 12m - 12  12m + 2 12        11   12m - 12  12m + 2 11
+--R     b  x        (x       )   + 12a b  x x        (x       )
+--R   + 
+--R        2 10 2 12m - 12  12m + 2 10       3 9 3 12m - 12  12m + 2 9
+--R     66a b  x x        (x       )   + 220a b x x        (x       )
+--R   + 
+--R         4 8 4 12m - 12  12m + 2 8       5 7 5 12m - 12  12m + 2 7
+--R     495a b x x        (x       )  + 792a b x x        (x       )
+--R   + 
+--R         6 6 6 12m - 12  12m + 2 6       7 5 7 12m - 12  12m + 2 5
+--R     924a b x x        (x       )  + 792a b x x        (x       )
+--R   + 
+--R         8 4 8 12m - 12  12m + 2 4       9 3 9 12m - 12  12m + 2 3
+--R     495a b x x        (x       )  + 220a b x x        (x       )
+--R   + 
+--R        10 2 10 12m - 12  12m + 2 2      11   11 12m - 12 12m + 2
+--R     66a  b x  x        (x       )  + 12a  b x  x        x
+--R   + 
+--R      12 12 12m - 12
+--R     a  x  x
+--R                                                    Type: Expression(Integer)
+--E 136
+
+--S 137 of 324
+r0:=1/13*(a+b*x^(1+12*m))^13/(b*(1+12*m))
+--R 
+--R
+--R   (2)
+--R        13  12m + 1 13        12  12m + 1 12      2 11  12m + 1 11
+--R       b  (x       )   + 13a b  (x       )   + 78a b  (x       )
+--R     + 
+--R           3 10  12m + 1 10       4 9  12m + 1 9        5 8  12m + 1 8
+--R       286a b  (x       )   + 715a b (x       )  + 1287a b (x       )
+--R     + 
+--R            6 7  12m + 1 7        7 6  12m + 1 6        8 5  12m + 1 5
+--R       1716a b (x       )  + 1716a b (x       )  + 1287a b (x       )
+--R     + 
+--R           9 4  12m + 1 4       10 3  12m + 1 3      11 2  12m + 1 2
+--R       715a b (x       )  + 286a  b (x       )  + 78a  b (x       )
+--R     + 
+--R          12   12m + 1    13
+--R       13a  b x        + a
+--R  /
+--R     156b m + 13b
+--R                                                    Type: Expression(Integer)
+--E 137
+
+--S 138 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 138
+
+)clear all
+
+--S 139 of 324
+t0:=(a*x+b*x^14)^12
+--R 
+--R
+--R   (1)
+--R      12 168        11 155      2 10 142       3 9 129       4 8 116
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 103       6 6 90       7 5 77       8 4 64       9 3 51
+--R     792a b x    + 924a b x   + 792a b x   + 495a b x   + 220a b x
+--R   + 
+--R        10 2 38      11   25    12 12
+--R     66a  b x   + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 139
+
+--S 140 of 324
+r0:=1/169*(a+b*x^13)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 169    1    12 156    6  2 11 143   22  3 10 130   55  4 9 117
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       169           13             13             13             13
+--R     + 
+--R       99  5 8 104   132  6 7 91   132  7 6 78   99  8 5 65   55  9 4 52
+--R       -- a b x    + --- a b x   + --- a b x   + -- a b x   + -- a b x
+--R       13             13            13           13           13
+--R     + 
+--R       22  10 3 39    6  11 2 26    1  12   13    1   13
+--R       -- a  b x   + -- a  b x   + -- a  b x   + --- a
+--R       13            13            13            169
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 140
+
+--S 141 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 141
+
+)clear all
+
+--S 142 of 324
+t0:=(a*x^2+b*x^27)^12
+--R 
+--R
+--R   (1)
+--R      12 324        11 299      2 10 274       3 9 249       4 8 224
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 199       6 6 174       7 5 149       8 4 124       9 3 99
+--R     792a b x    + 924a b x    + 792a b x    + 495a b x    + 220a b x
+--R   + 
+--R        10 2 74      11   49    12 24
+--R     66a  b x   + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 142
+
+--S 143 of 324
+r0:=1/325*(a+b*x^25)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 325    1    12 300    6  2 11 275   22  3 10 250   11  4 9 225
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       325           25             25             25              5
+--R     + 
+--R       99  5 8 200   132  6 7 175   132  7 6 150   99  8 5 125   11  9 4 100
+--R       -- a b x    + --- a b x    + --- a b x    + -- a b x    + -- a b x
+--R       25             25             25            25             5
+--R     + 
+--R       22  10 3 75    6  11 2 50    1  12   25    1   13
+--R       -- a  b x   + -- a  b x   + -- a  b x   + --- a
+--R       25            25            25            325
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 143
+
+--S 144 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 144
+
+)clear all
+
+--S 145 of 324
+t0:=(a*x^3+b*x^40)^12
+--R 
+--R
+--R   (1)
+--R      12 480        11 443      2 10 406       3 9 369       4 8 332
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 295       6 6 258       7 5 221       8 4 184       9 3 147
+--R     792a b x    + 924a b x    + 792a b x    + 495a b x    + 220a b x
+--R   + 
+--R        10 2 110      11   73    12 36
+--R     66a  b x    + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 145
+
+--S 146 of 324
+r0:=1/481*(a+b*x^37)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 481    1    12 444    6  2 11 407   22  3 10 370   55  4 9 333
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       481           37             37             37             37
+--R     + 
+--R       99  5 8 296   132  6 7 259   132  7 6 222   99  8 5 185   55  9 4 148
+--R       -- a b x    + --- a b x    + --- a b x    + -- a b x    + -- a b x
+--R       37             37             37            37            37
+--R     + 
+--R       22  10 3 111    6  11 2 74    1  12   37    1   13
+--R       -- a  b x    + -- a  b x   + -- a  b x   + --- a
+--R       37             37            37            481
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 146
+
+--S 147 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 147
+
+)clear all
+
+--S 148 of 324
+t0:=(a*x^m+b*x^(1+13*m))^12
+--R 
+--R
+--R   (1)
+--R      12  13m + 1 12        11 m  13m + 1 11      2 10  m 2  13m + 1 10
+--R     b  (x       )   + 12a b  x (x       )   + 66a b  (x ) (x       )
+--R   + 
+--R         3 9  m 3  13m + 1 9       4 8  m 4  13m + 1 8       5 7  m 5  13m + 1 7
+--R     220a b (x ) (x       )  + 495a b (x ) (x       )  + 792a b (x ) (x       )
+--R   + 
+--R         6 6  m 6  13m + 1 6       7 5  m 7  13m + 1 5       8 4  m 8  13m + 1 4
+--R     924a b (x ) (x       )  + 792a b (x ) (x       )  + 495a b (x ) (x       )
+--R   + 
+--R         9 3  m 9  13m + 1 3      10 2  m 10  13m + 1 2      11    m 11 13m + 1
+--R     220a b (x ) (x       )  + 66a  b (x )  (x       )  + 12a  b (x )  x
+--R   + 
+--R      12  m 12
+--R     a  (x )
+--R                                                    Type: Expression(Integer)
+--E 148
+
+--S 149 of 324
+r0:=1/13*(a+b*x^(1+12*m))^13/(b*(1+12*m))
+--R 
+--R
+--R   (2)
+--R        13  12m + 1 13        12  12m + 1 12      2 11  12m + 1 11
+--R       b  (x       )   + 13a b  (x       )   + 78a b  (x       )
+--R     + 
+--R           3 10  12m + 1 10       4 9  12m + 1 9        5 8  12m + 1 8
+--R       286a b  (x       )   + 715a b (x       )  + 1287a b (x       )
+--R     + 
+--R            6 7  12m + 1 7        7 6  12m + 1 6        8 5  12m + 1 5
+--R       1716a b (x       )  + 1716a b (x       )  + 1287a b (x       )
+--R     + 
+--R           9 4  12m + 1 4       10 3  12m + 1 3      11 2  12m + 1 2
+--R       715a b (x       )  + 286a  b (x       )  + 78a  b (x       )
+--R     + 
+--R          12   12m + 1    13
+--R       13a  b x        + a
+--R  /
+--R     156b m + 13b
+--R                                                    Type: Expression(Integer)
+--E 149
+
+--S 150 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 150
+
+)clear all
+
+--S 151 of 324
+t0:=(a*x^m+b*x^(1+6*m))^5
+--R 
+--R
+--R   (1)
+--R      5  6m + 1 5       4 m  6m + 1 4      2 3  m 2  6m + 1 3
+--R     b (x      )  + 5a b x (x      )  + 10a b (x ) (x      )
+--R   + 
+--R        3 2  m 3  6m + 1 2     4    m 4 6m + 1    5  m 5
+--R     10a b (x ) (x      )  + 5a b (x ) x       + a (x )
+--R                                                    Type: Expression(Integer)
+--E 151
+
+--S 152 of 324
+r0:=1/6*(a+b*x^(1+5*m))^6/(b*(1+5*m))
+--R 
+--R
+--R   (2)
+--R        6  5m + 1 6       5  5m + 1 5      2 4  5m + 1 4      3 3  5m + 1 3
+--R       b (x      )  + 6a b (x      )  + 15a b (x      )  + 20a b (x      )
+--R     + 
+--R          4 2  5m + 1 2     5   5m + 1    6
+--R       15a b (x      )  + 6a b x       + a
+--R  /
+--R     30b m + 6b
+--R                                                    Type: Expression(Integer)
+--E 152
+
+--S 153 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 153
+
+)clear all
+
+--S 154 of 324
+t0:=1/(b*x^(1-2*m)+a*x^m)^3
+--R 
+--R
+--R                                          1
+--R   (1)  --------------------------------------------------------------------
+--R         3  m 3     2   - 2m + 1  m 2       2  - 2m + 1 2 m    3  - 2m + 1 3
+--R        a (x )  + 3a b x        (x )  + 3a b (x        ) x  + b (x        )
+--R                                                    Type: Expression(Integer)
+--E 154
+
+--S 155 of 324
+r0:=(-1/2)/(b*(1-3*m)*(a+b*x^(1-3*m))^2)
+--R 
+--R
+--R                                          1
+--R   (2)  ---------------------------------------------------------------------
+--R           3      3   - 3m + 1 2         2        2  - 3m + 1     2        2
+--R        (6b m - 2b )(x        )  + (12a b m - 4a b )x         + 6a b m - 2a b
+--R                                                    Type: Expression(Integer)
+--E 155
+
+--S 156 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 156
+
+)clear all
+
+--S 157 of 324
+t0:=x^p*(a*x^n+b*x^(1+13*n+p))^12
+--R 
+--R
+--R   (1)
+--R      12 p  p + 13n + 1 12        11 n p  p + 13n + 1 11
+--R     b  x (x           )   + 12a b  x x (x           )
+--R   + 
+--R        2 10  n 2 p  p + 13n + 1 10       3 9  n 3 p  p + 13n + 1 9
+--R     66a b  (x ) x (x           )   + 220a b (x ) x (x           )
+--R   + 
+--R         4 8  n 4 p  p + 13n + 1 8       5 7  n 5 p  p + 13n + 1 7
+--R     495a b (x ) x (x           )  + 792a b (x ) x (x           )
+--R   + 
+--R         6 6  n 6 p  p + 13n + 1 6       7 5  n 7 p  p + 13n + 1 5
+--R     924a b (x ) x (x           )  + 792a b (x ) x (x           )
+--R   + 
+--R         8 4  n 8 p  p + 13n + 1 4       9 3  n 9 p  p + 13n + 1 3
+--R     495a b (x ) x (x           )  + 220a b (x ) x (x           )
+--R   + 
+--R        10 2  n 10 p  p + 13n + 1 2      11    n 11 p p + 13n + 1    12  n 12 p
+--R     66a  b (x )  x (x           )  + 12a  b (x )  x x            + a  (x )  x
+--R                                                    Type: Expression(Integer)
+--E 157
+
+--S 158 of 324
+r0:=1/13*(a+b*x^(1+12*n+p))^13/(b*(1+12*n+p))
+--R 
+--R
+--R   (2)
+--R        13  p + 12n + 1 13        12  p + 12n + 1 12      2 11  p + 12n + 1 11
+--R       b  (x           )   + 13a b  (x           )   + 78a b  (x           )
+--R     + 
+--R           3 10  p + 12n + 1 10       4 9  p + 12n + 1 9
+--R       286a b  (x           )   + 715a b (x           )
+--R     + 
+--R            5 8  p + 12n + 1 8        6 7  p + 12n + 1 7
+--R       1287a b (x           )  + 1716a b (x           )
+--R     + 
+--R            7 6  p + 12n + 1 6        8 5  p + 12n + 1 5
+--R       1716a b (x           )  + 1287a b (x           )
+--R     + 
+--R           9 4  p + 12n + 1 4       10 3  p + 12n + 1 3      11 2  p + 12n + 1 2
+--R       715a b (x           )  + 286a  b (x           )  + 78a  b (x           )
+--R     + 
+--R          12   p + 12n + 1    13
+--R       13a  b x            + a
+--R  /
+--R     13b p + 156b n + 13b
+--R                                                    Type: Expression(Integer)
+--E 158
+
+--S 159 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 159
+
+)clear all
+
+--S 160 of 324
+t0:=x^12*(a+b*x^13)^12
+--R 
+--R
+--R   (1)
+--R      12 168        11 155      2 10 142       3 9 129       4 8 116
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 103       6 6 90       7 5 77       8 4 64       9 3 51
+--R     792a b x    + 924a b x   + 792a b x   + 495a b x   + 220a b x
+--R   + 
+--R        10 2 38      11   25    12 12
+--R     66a  b x   + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 160
+
+--S 161 of 324
+r0:=1/169*(a+b*x^13)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 169    1    12 156    6  2 11 143   22  3 10 130   55  4 9 117
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       169           13             13             13             13
+--R     + 
+--R       99  5 8 104   132  6 7 91   132  7 6 78   99  8 5 65   55  9 4 52
+--R       -- a b x    + --- a b x   + --- a b x   + -- a b x   + -- a b x
+--R       13             13            13           13           13
+--R     + 
+--R       22  10 3 39    6  11 2 26    1  12   13    1   13
+--R       -- a  b x   + -- a  b x   + -- a  b x   + --- a
+--R       13            13            13            169
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 161
+
+--S 162 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 162
+
+)clear all
+
+--S 163 of 324
+t0:=x^12*(a*x+b*x^26)^12
+--R 
+--R
+--R   (1)
+--R      12 324        11 299      2 10 274       3 9 249       4 8 224
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 199       6 6 174       7 5 149       8 4 124       9 3 99
+--R     792a b x    + 924a b x    + 792a b x    + 495a b x    + 220a b x
+--R   + 
+--R        10 2 74      11   49    12 24
+--R     66a  b x   + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 163
+
+--S 164 of 324
+r0:=1/325*(a+b*x^25)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 325    1    12 300    6  2 11 275   22  3 10 250   11  4 9 225
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       325           25             25             25              5
+--R     + 
+--R       99  5 8 200   132  6 7 175   132  7 6 150   99  8 5 125   11  9 4 100
+--R       -- a b x    + --- a b x    + --- a b x    + -- a b x    + -- a b x
+--R       25             25             25            25             5
+--R     + 
+--R       22  10 3 75    6  11 2 50    1  12   25    1   13
+--R       -- a  b x   + -- a  b x   + -- a  b x   + --- a
+--R       25            25            25            325
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 164
+
+--S 165 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 165
+
+)clear all
+
+--S 166 of 324
+t0:=x^12*(a*x^2+b*x^39)^12
+--R 
+--R
+--R   (1)
+--R      12 480        11 443      2 10 406       3 9 369       4 8 332
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 295       6 6 258       7 5 221       8 4 184       9 3 147
+--R     792a b x    + 924a b x    + 792a b x    + 495a b x    + 220a b x
+--R   + 
+--R        10 2 110      11   73    12 36
+--R     66a  b x    + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 166
+
+--S 167 of 324
+r0:=1/481*(a+b*x^37)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 481    1    12 444    6  2 11 407   22  3 10 370   55  4 9 333
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       481           37             37             37             37
+--R     + 
+--R       99  5 8 296   132  6 7 259   132  7 6 222   99  8 5 185   55  9 4 148
+--R       -- a b x    + --- a b x    + --- a b x    + -- a b x    + -- a b x
+--R       37             37             37            37            37
+--R     + 
+--R       22  10 3 111    6  11 2 74    1  12   37    1   13
+--R       -- a  b x    + -- a  b x   + -- a  b x   + --- a
+--R       37             37            37            481
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 167
+
+--S 168 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 168
+
+)clear all
+
+--S 169 of 324
+t0:=x^24*(a+b*x^25)^12
+--R 
+--R
+--R   (1)
+--R      12 324        11 299      2 10 274       3 9 249       4 8 224
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 199       6 6 174       7 5 149       8 4 124       9 3 99
+--R     792a b x    + 924a b x    + 792a b x    + 495a b x    + 220a b x
+--R   + 
+--R        10 2 74      11   49    12 24
+--R     66a  b x   + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 169
+
+--S 170 of 324
+r0:=1/325*(a+b*x^25)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 325    1    12 300    6  2 11 275   22  3 10 250   11  4 9 225
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       325           25             25             25              5
+--R     + 
+--R       99  5 8 200   132  6 7 175   132  7 6 150   99  8 5 125   11  9 4 100
+--R       -- a b x    + --- a b x    + --- a b x    + -- a b x    + -- a b x
+--R       25             25             25            25             5
+--R     + 
+--R       22  10 3 75    6  11 2 50    1  12   25    1   13
+--R       -- a  b x   + -- a  b x   + -- a  b x   + --- a
+--R       25            25            25            325
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 170
+
+--S 171 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 171
+
+)clear all
+
+--S 172 of 324
+t0:=x^24*(a*x+b*x^38)^12
+--R 
+--R
+--R   (1)
+--R      12 480        11 443      2 10 406       3 9 369       4 8 332
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 295       6 6 258       7 5 221       8 4 184       9 3 147
+--R     792a b x    + 924a b x    + 792a b x    + 495a b x    + 220a b x
+--R   + 
+--R        10 2 110      11   73    12 36
+--R     66a  b x    + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 172
+
+--S 173 of 324
+r0:=1/481*(a+b*x^37)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 481    1    12 444    6  2 11 407   22  3 10 370   55  4 9 333
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       481           37             37             37             37
+--R     + 
+--R       99  5 8 296   132  6 7 259   132  7 6 222   99  8 5 185   55  9 4 148
+--R       -- a b x    + --- a b x    + --- a b x    + -- a b x    + -- a b x
+--R       37             37             37            37            37
+--R     + 
+--R       22  10 3 111    6  11 2 74    1  12   37    1   13
+--R       -- a  b x    + -- a  b x   + -- a  b x   + --- a
+--R       37             37            37            481
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 173
+
+--S 174 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 174
+
+)clear all
+
+--S 175 of 324
+t0:=x^36*(a+b*x^37)^12
+--R 
+--R
+--R   (1)
+--R      12 480        11 443      2 10 406       3 9 369       4 8 332
+--R     b  x    + 12a b  x    + 66a b  x    + 220a b x    + 495a b x
+--R   + 
+--R         5 7 295       6 6 258       7 5 221       8 4 184       9 3 147
+--R     792a b x    + 924a b x    + 792a b x    + 495a b x    + 220a b x
+--R   + 
+--R        10 2 110      11   73    12 36
+--R     66a  b x    + 12a  b x   + a  x
+--R                                                    Type: Polynomial(Integer)
+--E 175
+
+--S 176 of 324
+r0:=1/481*(a+b*x^37)^13/b
+--R 
+--R
+--R   (2)
+--R        1   13 481    1    12 444    6  2 11 407   22  3 10 370   55  4 9 333
+--R       --- b  x    + -- a b  x    + -- a b  x    + -- a b  x    + -- a b x
+--R       481           37             37             37             37
+--R     + 
+--R       99  5 8 296   132  6 7 259   132  7 6 222   99  8 5 185   55  9 4 148
+--R       -- a b x    + --- a b x    + --- a b x    + -- a b x    + -- a b x
+--R       37             37             37            37            37
+--R     + 
+--R       22  10 3 111    6  11 2 74    1  12   37    1   13
+--R       -- a  b x    + -- a  b x   + -- a  b x   + --- a
+--R       37             37            37            481
+--R  /
+--R     b
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 176
+
+--S 177 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                Type: Fraction(Polynomial(Fraction(Integer)))
+--E 177
+
+)clear all
+
+--S 178 of 324
+t0:=1/(a*x+b*x^n)
+--R 
+--R
+--R             1
+--R   (1)  ----------
+--R           n
+--R        b x  + a x
+--R                                                    Type: Expression(Integer)
+--E 178
+
+--S 179 of 324
+r0:=log(b+a*x^(1-n))/(a*(1-n))
+--R 
+--R
+--R                 - n + 1
+--R          log(a x        + b)
+--R   (2)  - -------------------
+--R                a n - a
+--R                                                    Type: Expression(Integer)
+--E 179
+
+--S 180 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 180
+
+)clear all
+
+--S 181 of 324
+t0:=1/(a*x+b*x^(1+n))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R           n + 1
+--R        b x      + a x
+--R                                                    Type: Expression(Integer)
+--E 181
+
+--S 182 of 324
+r0:=log(x)/a-log(a+b*x^n)/(a*n)
+--R 
+--R
+--R                 n
+--R        - log(b x  + a) + n log(x)
+--R   (2)  --------------------------
+--R                    a n
+--R                                                    Type: Expression(Integer)
+--E 182
+
+--S 183 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 183
+
+)clear all
+
+--S 184 of 324
+t0:=1/(a*x+b*x^(1-n))
+--R 
+--R
+--R                1
+--R   (1)  ----------------
+--R           - n + 1
+--R        b x        + a x
+--R                                                    Type: Expression(Integer)
+--E 184
+
+--S 185 of 324
+r0:=log(b+a*x^n)/(a*n)
+--R 
+--R
+--R               n
+--R        log(a x  + b)
+--R   (2)  -------------
+--R             a n
+--R                                                    Type: Expression(Integer)
+--E 185
+
+--S 186 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 186
+
+)clear all
+
+--S 187 of 324
+t0:=1/(2*x+3*x^(1+n))
+--R 
+--R
+--R              1
+--R   (1)  ------------
+--R          n + 1
+--R        3x      + 2x
+--R                                                    Type: Expression(Integer)
+--E 187
+
+--S 188 of 324
+r0:=-atanh(1+3*x^n)/n
+--R 
+--R
+--R                  n
+--R          atanh(3x  + 1)
+--R   (2)  - --------------
+--R                 n
+--R                                                    Type: Expression(Integer)
+--E 188
+
+--S 189 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 189
+
+)clear all
+
+--S 190 of 324
+t0:=1/(2*x+3*x^(1-n))
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R          - n + 1
+--R        3x        + 2x
+--R                                                    Type: Expression(Integer)
+--E 190
+
+--S 191 of 324
+r0:=1/2*log(3+2*x^n)/n
+--R 
+--R
+--R              n
+--R        log(2x  + 3)
+--R   (2)  ------------
+--R             2n
+--R                                                    Type: Expression(Integer)
+--E 191
+
+--S 192 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 192
+
+)clear all
+
+--S 193 of 324
+t0:=1/(x-sqrt(x))
+--R 
+--R
+--R              1
+--R   (1)  - --------
+--R           +-+
+--R          \|x  - x
+--R                                                    Type: Expression(Integer)
+--E 193
+
+--S 194 of 324
+r0:=2*log(1-sqrt(x))
+--R 
+--R
+--R                +-+
+--R   (2)  2log(- \|x  + 1)
+--R                                                    Type: Expression(Integer)
+--E 194
+
+--S 195 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 195
+
+)clear all
+
+--S 196 of 324
+t0:=1/(-x^(3/5)+x)
+--R 
+--R
+--R              1
+--R   (1)  - ---------
+--R          5+-+3
+--R          \|x   - x
+--R                                                    Type: Expression(Integer)
+--E 196
+
+--S 197 of 324
+r0:=5/2*log(1-x^(2/5))
+--R 
+--R
+--R               5+-+2
+--R        5log(- \|x   + 1)
+--R   (2)  -----------------
+--R                2
+--R                                                    Type: Expression(Integer)
+--E 197
+
+--S 198 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 198
+
+)clear all
+
+--S 199 of 324
+t0:=1/(1/x^(1/3)+x)
+--R 
+--R
+--R           3+-+
+--R           \|x
+--R   (1)  ---------
+--R         3+-+
+--R        x\|x  + 1
+--R                                                    Type: Expression(Integer)
+--E 199
+
+--S 200 of 324
+r0:=3/4*log(1+x^(4/3))
+--R 
+--R
+--R              3+-+
+--R        3log(x\|x  + 1)
+--R   (2)  ---------------
+--R               4
+--R                                                    Type: Expression(Integer)
+--E 200
+
+--S 201 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 201
+
+)clear all
+
+--S 202 of 324
+t0:=1/(x+x^sqrt(2))
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R          +-+
+--R         \|2
+--R        x     + x
+--R                                                    Type: Expression(Integer)
+--E 202
+
+--S 203 of 324
+r0:=-2*atanh(1+2*x^(-1+sqrt(2)))*(1+sqrt(2))
+--R 
+--R
+--R                              +-+
+--R             +-+             \|2  - 1
+--R   (2)  (- 2\|2  - 2)atanh(2x         + 1)
+--R                                                    Type: Expression(Integer)
+--E 203
+
+--S 204 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 204
+
+)clear all
+
+--S 205 of 324
+t0:=x^(-1+n-p*(1+q))*(a*x^n+b*x^p)^q
+--R 
+--R
+--R         - p q - p + n - 1    p      n q
+--R   (1)  x                 (b x  + a x )
+--R                                                    Type: Expression(Integer)
+--E 205
+
+--S 206 of 324
+r0:=(a*x^n+b*x^p)^(1+q)/(a*(n-p)*(1+q)*x^(p*(1+q)))
+--R 
+--R
+--R                      p      n q + 1
+--R                  (b x  + a x )
+--R   (2)  - ----------------------------------
+--R                                     p q + p
+--R          ((a p - a n)q + a p - a n)x
+--R                                                    Type: Expression(Integer)
+--E 206
+
+--S 207 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 207
+
+)clear all
+
+--S 208 of 324
+t0:=x^(-1-n*q-p*(1+q))*(x^n*(a+b*x^p))^q
+--R 
+--R
+--R         (- p - n)q - p - 1    n p      n q
+--R   (1)  x                  (b x x  + a x )
+--R                                                    Type: Expression(Integer)
+--E 208
+
+--S 209 of 324
+r0:=-(a*x^n+b*x^(n+p))^(1+q)/(a*p*(1+q)*x^((n+p)*(1+q)))
+--R 
+--R
+--R                  p + n      n q + 1
+--R              (b x      + a x )
+--R   (2)  - ------------------------------
+--R                        (p + n)q + p + n
+--R          (a p q + a p)x
+--R                                                    Type: Expression(Integer)
+--E 209
+
+--S 210 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 210
+
+)clear all
+
+--S 211 of 324
+t0:=1/(a*x^2+b*x^2)
+--R 
+--R
+--R            1
+--R   (1)  ---------
+--R                2
+--R        (b + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 211
+
+--S 212 of 324
+r0:=(-1)/((a+b)*x)
+--R 
+--R
+--R              1
+--R   (2)  - --------
+--R          (b + a)x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 212
+
+--S 213 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 213
+
+)clear all
+
+--S 214 of 324
+t0:=1/sqrt(b*x^2+a*x^r)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |   r      2
+--R        \|a x  + b x
+--R                                                    Type: Expression(Integer)
+--E 214
+
+--S 215 of 324
+r0:=2*atanh(x*sqrt(b)/sqrt(b*x^2+a*x^r))/((2-r)*sqrt(b))
+--R 
+--R
+--R                        +-+
+--R                      x\|b
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |   r      2
+--R                 \|a x  + b x
+--R   (2)  - ----------------------
+--R                        +-+
+--R                (r - 2)\|b
+--R                                                    Type: Expression(Integer)
+--E 215
+
+--S 216 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 216
+
+)clear all
+
+--S 217 of 324
+t0:=1/sqrt(-b*x^2+a*x^r)
+--R 
+--R
+--R               1
+--R   (1)  --------------
+--R         +-----------+
+--R         |   r      2
+--R        \|a x  - b x
+--R                                                    Type: Expression(Integer)
+--E 217
+
+--S 218 of 324
+r0:=2*atan(x*sqrt(b)/sqrt(-b*x^2+a*x^r))/((2-r)*sqrt(b))
+--R 
+--R
+--R                       +-+
+--R                     x\|b
+--R          2atan(--------------)
+--R                 +-----------+
+--R                 |   r      2
+--R                \|a x  - b x
+--R   (2)  - ---------------------
+--R                       +-+
+--R               (r - 2)\|b
+--R                                                    Type: Expression(Integer)
+--E 218
+
+--S 219 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 219
+
+)clear all
+
+--S 220 of 324
+t0:=1/sqrt((a+b*x^3)/x)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         |   3
+--R         |b x  + a
+--R         |--------
+--R        \|    x
+--R                                                    Type: Expression(Integer)
+--E 220
+
+--S 221 of 324
+r0:=2/3*atanh(x*sqrt(b)/sqrt(a/x+b*x^2))/sqrt(b)
+--R 
+--R
+--R                    +-+
+--R                  x\|b
+--R        2atanh(-----------)
+--R                +--------+
+--R                |   3
+--R                |b x  + a
+--R                |--------
+--R               \|    x
+--R   (2)  -------------------
+--R                 +-+
+--R               3\|b
+--R                                                    Type: Expression(Integer)
+--E 221
+
+--S 222 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 222
+
+)clear all
+
+--S 223 of 324
+t0:=1/sqrt((a+b*x^4)/x^2)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         |   4
+--R         |b x  + a
+--R         |--------
+--R         |    2
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 223
+
+--S 224 of 324
+r0:=1/2*atanh(x*sqrt(b)/sqrt(a/x^2+b*x^2))/sqrt(b)
+--R 
+--R
+--R                   +-+
+--R                 x\|b
+--R        atanh(-----------)
+--R               +--------+
+--R               |   4
+--R               |b x  + a
+--R               |--------
+--R               |    2
+--R              \|   x
+--R   (2)  ------------------
+--R                 +-+
+--R               2\|b
+--R                                                    Type: Expression(Integer)
+--E 224
+
+--S 225 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 225
+
+)clear all
+
+--S 226 of 324
+t0:=1/sqrt((a+b*x^5)/x^3)
+--R 
+--R
+--R             1
+--R   (1)  -----------
+--R         +--------+
+--R         |   5
+--R         |b x  + a
+--R         |--------
+--R         |    3
+--R        \|   x
+--R                                                    Type: Expression(Integer)
+--E 226
+
+--S 227 of 324
+r0:=2/5*atanh(x*sqrt(b)/sqrt(a/x^3+b*x^2))/sqrt(b)
+--R 
+--R
+--R                    +-+
+--R                  x\|b
+--R        2atanh(-----------)
+--R                +--------+
+--R                |   5
+--R                |b x  + a
+--R                |--------
+--R                |    3
+--R               \|   x
+--R   (2)  -------------------
+--R                 +-+
+--R               5\|b
+--R                                                    Type: Expression(Integer)
+--E 227
+
+--S 228 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 228
+
+)clear all
+
+--S 229 of 324
+t0:=1/sqrt(x^(2-n)*(a+b*x^n))
+--R 
+--R
+--R                      1
+--R   (1)  ----------------------------
+--R         +-------------------------+
+--R         |   - n + 2 n      - n + 2
+--R        \|b x       x  + a x
+--R                                                    Type: Expression(Integer)
+--E 229
+
+--S 230 of 324
+r0:=2*atanh(x*sqrt(b)/sqrt(b*x^2+a*x^(2-n)))/(n*sqrt(b))
+--R 
+--R
+--R                         +-+
+--R                       x\|b
+--R        2atanh(--------------------)
+--R                +-----------------+
+--R                |   - n + 2      2
+--R               \|a x        + b x
+--R   (2)  ----------------------------
+--R                      +-+
+--R                    n\|b
+--R                                                    Type: Expression(Integer)
+--E 230
+
+--S 231 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 231
+
+)clear all
+
+--S 232 of 324
+t0:=1/sqrt((a-b*x^3)/x)
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         +----------+
+--R         |     3
+--R         |- b x  + a
+--R         |----------
+--R        \|     x
+--R                                                    Type: Expression(Integer)
+--E 232
+
+--S 233 of 324
+r0:=2/3*atan(x*sqrt(b)/sqrt(a/x-b*x^2))/sqrt(b)
+--R 
+--R
+--R                    +-+
+--R                  x\|b
+--R        2atan(-------------)
+--R               +----------+
+--R               |     3
+--R               |- b x  + a
+--R               |----------
+--R              \|     x
+--R   (2)  --------------------
+--R                  +-+
+--R                3\|b
+--R                                                    Type: Expression(Integer)
+--E 233
+
+--S 234 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 234
+
+)clear all
+
+--S 235 of 324
+t0:=1/sqrt((a-b*x^4)/x^2)
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         +----------+
+--R         |     4
+--R         |- b x  + a
+--R         |----------
+--R         |     2
+--R        \|    x
+--R                                                    Type: Expression(Integer)
+--E 235
+
+--S 236 of 324
+r0:=1/2*atan(x*sqrt(b)/sqrt(a/x^2-b*x^2))/sqrt(b)
+--R 
+--R
+--R                   +-+
+--R                 x\|b
+--R        atan(-------------)
+--R              +----------+
+--R              |     4
+--R              |- b x  + a
+--R              |----------
+--R              |     2
+--R             \|    x
+--R   (2)  -------------------
+--R                 +-+
+--R               2\|b
+--R                                                    Type: Expression(Integer)
+--E 236
+
+--S 237 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 237
+
+)clear all
+
+--S 238 of 324
+t0:=1/sqrt((a-b*x^5)/x^3)
+--R 
+--R
+--R              1
+--R   (1)  -------------
+--R         +----------+
+--R         |     5
+--R         |- b x  + a
+--R         |----------
+--R         |     3
+--R        \|    x
+--R                                                    Type: Expression(Integer)
+--E 238
+
+--S 239 of 324
+r0:=2/5*atan(x*sqrt(b)/sqrt(a/x^3-b*x^2))/sqrt(b)
+--R 
+--R
+--R                    +-+
+--R                  x\|b
+--R        2atan(-------------)
+--R               +----------+
+--R               |     5
+--R               |- b x  + a
+--R               |----------
+--R               |     3
+--R              \|    x
+--R   (2)  --------------------
+--R                  +-+
+--R                5\|b
+--R                                                    Type: Expression(Integer)
+--E 239
+
+--S 240 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 240
+
+)clear all
+
+--S 241 of 324
+t0:=1/sqrt(x^(2-n)*(a-b*x^n))
+--R 
+--R
+--R                       1
+--R   (1)  ------------------------------
+--R         +---------------------------+
+--R         |     - n + 2 n      - n + 2
+--R        \|- b x       x  + a x
+--R                                                    Type: Expression(Integer)
+--E 241
+
+--S 242 of 324
+r0:=2*atan(x*sqrt(b)/sqrt(-b*x^2+a*x^(2-n)))/(n*sqrt(b))
+--R 
+--R
+--R                        +-+
+--R                      x\|b
+--R        2atan(--------------------)
+--R               +-----------------+
+--R               |   - n + 2      2
+--R              \|a x        - b x
+--R   (2)  ---------------------------
+--R                     +-+
+--R                   n\|b
+--R                                                    Type: Expression(Integer)
+--E 242
+
+--S 243 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 243
+
+)clear all
+
+--S 244 of 324
+t0:=1/sqrt(x^n*(a+b*x^(2-n)))
+--R 
+--R
+--R                  1
+--R   (1)  ---------------------
+--R         +------------------+
+--R         |    - n + 2      n
+--R        \|(b x        + a)x
+--R                                                    Type: Expression(Integer)
+--E 244
+
+--S 245 of 324
+r0:=2*atanh(x*sqrt(b)/sqrt(b*x^2+a*x^n))/((2-n)*sqrt(b))
+--R 
+--R
+--R                        +-+
+--R                      x\|b
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |   n      2
+--R                 \|a x  + b x
+--R   (2)  - ----------------------
+--R                        +-+
+--R                (n - 2)\|b
+--R                                                    Type: Expression(Integer)
+--E 245
+
+--S 246 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 246
+
+)clear all
+
+--S 247 of 324
+t0:=1/sqrt(x^2*(b+a*x^(-2+n)))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-----------------+
+--R         |   2 n - 2      2
+--R        \|a x x      + b x
+--R                                                    Type: Expression(Integer)
+--E 247
+
+--S 248 of 324
+r0:=2*atanh(x*sqrt(b)/sqrt(b*x^2+a*x^n))/((2-n)*sqrt(b))
+--R 
+--R
+--R                        +-+
+--R                      x\|b
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |   n      2
+--R                 \|a x  + b x
+--R   (2)  - ----------------------
+--R                        +-+
+--R                (n - 2)\|b
+--R                                                    Type: Expression(Integer)
+--E 248
+
+--S 249 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 249
+
+)clear all
+
+--S 250 of 324
+t0:=1/sqrt(x*(b*x+a*x^(-1+n)))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-----------------+
+--R         |     n - 1      2
+--R        \|a x x      + b x
+--R                                                    Type: Expression(Integer)
+--E 250
+
+--S 251 of 324
+r0:=2*atanh(x*sqrt(b)/sqrt(b*x^2+a*x^n))/((2-n)*sqrt(b))
+--R 
+--R
+--R                        +-+
+--R                      x\|b
+--R          2atanh(--------------)
+--R                  +-----------+
+--R                  |   n      2
+--R                 \|a x  + b x
+--R   (2)  - ----------------------
+--R                        +-+
+--R                (n - 2)\|b
+--R                                                    Type: Expression(Integer)
+--E 251
+
+--S 252 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 252
+
+)clear all
+
+--S 253 of 324
+t0:=1/sqrt(x^n*(a-b*x^(2-n)))
+--R 
+--R
+--R                   1
+--R   (1)  -----------------------
+--R         +--------------------+
+--R         |      - n + 2      n
+--R        \|(- b x        + a)x
+--R                                                    Type: Expression(Integer)
+--E 253
+
+--S 254 of 324
+r0:=2*atan(x*sqrt(b)/sqrt(-b*x^2+a*x^n))/((2-n)*sqrt(b))
+--R 
+--R
+--R                       +-+
+--R                     x\|b
+--R          2atan(--------------)
+--R                 +-----------+
+--R                 |   n      2
+--R                \|a x  - b x
+--R   (2)  - ---------------------
+--R                       +-+
+--R               (n - 2)\|b
+--R                                                    Type: Expression(Integer)
+--E 254
+
+--S 255 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 255
+
+)clear all
+
+--S 256 of 324
+t0:=1/sqrt(x^2*(-b+a*x^(-2+n)))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-----------------+
+--R         |   2 n - 2      2
+--R        \|a x x      - b x
+--R                                                    Type: Expression(Integer)
+--E 256
+
+--S 257 of 324
+r0:=2*atan(x*sqrt(b)/sqrt(-b*x^2+a*x^n))/((2-n)*sqrt(b))
+--R 
+--R
+--R                       +-+
+--R                     x\|b
+--R          2atan(--------------)
+--R                 +-----------+
+--R                 |   n      2
+--R                \|a x  - b x
+--R   (2)  - ---------------------
+--R                       +-+
+--R               (n - 2)\|b
+--R                                                    Type: Expression(Integer)
+--E 257
+
+--S 258 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 258
+
+)clear all
+
+--S 259 of 324
+t0:=1/sqrt(x*(-b*x+a*x^(-1+n)))
+--R 
+--R
+--R                  1
+--R   (1)  --------------------
+--R         +-----------------+
+--R         |     n - 1      2
+--R        \|a x x      - b x
+--R                                                    Type: Expression(Integer)
+--E 259
+
+--S 260 of 324
+r0:=2*atan(x*sqrt(b)/sqrt(-b*x^2+a*x^n))/((2-n)*sqrt(b))
+--R 
+--R
+--R                       +-+
+--R                     x\|b
+--R          2atan(--------------)
+--R                 +-----------+
+--R                 |   n      2
+--R                \|a x  - b x
+--R   (2)  - ---------------------
+--R                       +-+
+--R               (n - 2)\|b
+--R                                                    Type: Expression(Integer)
+--E 260
+
+--S 261 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 261
+
+)clear all
+
+--S 262 of 324
+t0:=(4+3*x^4)/(5*x+2*x^5)
+--R 
+--R
+--R           4
+--R         3x  + 4
+--R   (1)  --------
+--R          5
+--R        2x  + 5x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 262
+
+--S 263 of 324
+r0:=4/5*log(x)+7/40*log(5+2*x^4)
+--R 
+--R
+--R               4
+--R        7log(2x  + 5) + 32log(x)
+--R   (2)  ------------------------
+--R                   40
+--R                                                    Type: Expression(Integer)
+--E 263
+
+--S 264 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 264
+
+)clear all
+
+--S 265 of 324
+t0:=(1+x^6)/(x-x^7)
+--R 
+--R
+--R           6
+--R        - x  - 1
+--R   (1)  --------
+--R          7
+--R         x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 265
+
+--S 266 of 324
+r0:=log(x)-1/3*log(1-x^6)
+--R 
+--R
+--R                         6
+--R        3log(x) - log(- x  + 1)
+--R   (2)  -----------------------
+--R                   3
+--R                                                    Type: Expression(Integer)
+--E 266
+
+--S 267 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 267
+
+)clear all
+
+--S 268 of 324
+t0:=(8+5*x^10)/(2*x-x^11)
+--R 
+--R
+--R            10
+--R        - 5x   - 8
+--R   (1)  ----------
+--R          11
+--R         x   - 2x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 268
+
+--S 269 of 324
+r0:=4*log(x)-9/10*log(2-x^10)
+--R 
+--R
+--R                           10
+--R        40log(x) - 9log(- x   + 2)
+--R   (2)  --------------------------
+--R                    10
+--R                                                    Type: Expression(Integer)
+--E 269
+
+--S 270 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 270
+
+)clear all
+
+--S 271 of 324
+t0:=(-3+2*x)/(-x^2+x^3)
+--R 
+--R
+--R         2x - 3
+--R   (1)  -------
+--R         3    2
+--R        x  - x
+--R                                          Type: Fraction(Polynomial(Integer))
+--E 271
+
+--S 272 of 324
+r0:=(-3)/x-log(1-x)+log(x)
+--R 
+--R
+--R        x log(x) - x log(- x + 1) - 3
+--R   (2)  -----------------------------
+--R                      x
+--R                                                    Type: Expression(Integer)
+--E 272
+
+--S 273 of 324
+d0:=t0-D(r0,x)
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 273
+
+)clear all
+
+--S 274 of 324
+t0:=(a*x^m+b*x^n)/(c*x^m+d*x^n)
+--R 
+--R
+--R           n      m
+--R        b x  + a x
+--R   (1)  -----------
+--R           n      m
+--R        d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 274
+
+--S 275 of 324
+--r0:=a*x/c+(b*c-a*d)*x*hypergeometric(1,1/(m-n),1+1/(m-n),-c*x^(m-n)/d)/(c*d)
+--E 275
+
+--S 276 of 324
+--d0:=t0-D(r0,x)
+--E 276
+
+)clear all
+
+--S 277 of 324
+t0:=x^m*(a+b*x^n)^p*(a*(1+m+q)*x^q+b*(1+m+n*(1+p)+q)*x^(n+q))
+--R 
+--R
+--R   (1)
+--R                                  m q + n                   m q     n     p
+--R   ((b q + b n p + b n + b m + b)x x      + (a q + a m + a)x x )(b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 277
+
+--S 278 of 324
+r0:=x^(1+m+q)*(a+b*x^n)^(1+p)
+--R 
+--R
+--R         q + m + 1    n     p + 1
+--R   (2)  x         (b x  + a)
+--R                                                    Type: Expression(Integer)
+--E 278
+
+--S 279 of 324
+d0:=normalize(t0-D(r0,x))
+--R 
+--R
+--R   (3)  0
+--R                                                    Type: Expression(Integer)
+--E 279
+
+)clear all
+
+--S 280 of 324
+t0:=(a+b/x)^n*x^m/(c+d*x)
+--R 
+--R
+--R         a x + b n m
+--R        (-------) x
+--R            x
+--R   (1)  ------------
+--R           d x + c
+--R                                                    Type: Expression(Integer)
+--E 280
+
+--S 281 of 324
+--r0:=(a+b/x)^n*x^(1+m)*AppellF1(1+m-n,-n,1,2+m-n,-a*x/b,-d*x/c)/_
+--  (c*(1+m-n)*((b+a*x)/b)^n)
+--E 281
+
+--S 282 of 324
+--d0:=t0-D(r0,x)
+--E 282
+
+)clear all
+
+--S 283 of 324
+t0:=(a+b/x)^n*x^2/(c+d*x)
+--R 
+--R
+--R         2 a x + b n
+--R        x (-------)
+--R              x
+--R   (1)  ------------
+--R           d x + c
+--R                                                    Type: Expression(Integer)
+--E 283
+
+--S 284 of 324
+--r0:=-c*(a+b/x)^(1+n)*x/(a*d^2)-1/2*b*(1-n)*(a+b/x)^(1+n)*x/(a^2*d)+_
+--  1/2*(a+b/x)^(1+n)*x^2/(a*d)+c^2*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,(a+b/x)/a)/(a*d^3*(1+n))-_
+--  b*c*n*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,(a+b/x)/a)/_
+--  (a^2*d^2*(1+n))-1/2*b^2*(1-n)*n*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,(a+b/x)/a)/(a^3*d*(1+n))-_
+--  c^3*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,c*(a+b/x)/_
+--  (a*c-b*d))/(d^3*(a*c-b*d)*(1+n))
+--E 284
+
+--S 285 of 324
+--d0:=t0-D(r0,x)
+--E 285
+
+)clear all
+
+--S 286 of 324
+t0:=(a+b/x)^n*x/(c+d*x)
+--R 
+--R
+--R           a x + b n
+--R        x (-------)
+--R              x
+--R   (1)  ------------
+--R           d x + c
+--R                                                    Type: Expression(Integer)
+--E 286
+
+--S 287 of 324
+--r0:=(a+b/x)^(1+n)*x/(a*d)-c*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,_
+--  (a+b/x)/a)/(a*d^2*(1+n))+b*n*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,(a+b/x)/a)/(a^2*d*(1+n))+_
+--  c^2*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,c*(a+b/x)/_
+--  (a*c-b*d))/(d^2*(a*c-b*d)*(1+n))
+--E 287
+
+--S 288 of 324
+--d0:=t0-D(r0,x)
+--E 288
+
+)clear all
+
+--S 289 of 324
+t0:=(a+b/x)^n/(c+d*x)
+--R 
+--R
+--R         a x + b n
+--R        (-------)
+--R            x
+--R   (1)  ----------
+--R          d x + c
+--R                                                    Type: Expression(Integer)
+--E 289
+
+--S 290 of 324
+--r0:=(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,(a+b/x)/a)/(a*d*(1+n))-_
+--  c*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,c*(a+b/x)/_
+--  (a*c-b*d))/(d*(a*c-b*d)*(1+n))
+--E 290
+
+--S 291 of 324
+--d0:=t0-D(r0,x)
+--E 291
+
+)clear all
+
+--S 292 of 324
+t0:=(a+b/x)^n/(x*(c+d*x))
+--R 
+--R
+--R         a x + b n
+--R        (-------)
+--R            x
+--R   (1)  ----------
+--R           2
+--R        d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 292
+
+--S 293 of 324
+--r0:=(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,c*(a+b/x)/(a*c-b*d))/_
+--  ((a*c-b*d)*(1+n))
+--E 293
+
+--S 294 of 324
+--d0:=t0-D(r0,x)
+--E 294
+
+)clear all
+
+--S 295 of 324
+t0:=(a+b/x)^n/(x^2*(c+d*x))
+--R 
+--R
+--R          a x + b n
+--R         (-------)
+--R             x
+--R   (1)  -----------
+--R           3      2
+--R        d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 295
+
+--S 296 of 324
+--r0:=-(a+b/x)^(1+n)/(b*c*(1+n))-d*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,c*(a+b/x)/(a*c-b*d))/(c*(a*c-b*d)*(1+n))
+--E 296
+
+--S 297 of 324
+--d0:=t0-D(r0,x)
+--E 297
+
+)clear all
+
+--S 298 of 324
+t0:=(a+b/x)^n/(x^3*(c+d*x))
+--R 
+--R
+--R          a x + b n
+--R         (-------)
+--R             x
+--R   (1)  -----------
+--R           4      3
+--R        d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 298
+
+--S 299 of 324
+--r0:=(a*c+b*d*(2+n))*(a+b/x)^(1+n)/(b^2*c^2*(1+n)*(2+n))-_
+--  (a+b/x)^(1+n)/(b*c*(2+n)*x)+d^2*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,c*(a+b/x)/(a*c-b*d))/(c^2*(a*c-b*d)*(1+n))
+--E 299
+
+--S 300 of 324
+--d0:=t0-D(r0,x)
+--E 300
+
+)clear all
+
+--S 301 of 324
+t0:=(a+b/x)^n/(x^5*(c+d*x))
+--R 
+--R
+--R          a x + b n
+--R         (-------)
+--R             x
+--R   (1)  -----------
+--R           6      5
+--R        d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 301
+
+--S 302 of 324
+--r0:=a^3*(a+b/x)^(1+n)/(b^4*c*(1+n))+a^2*d*(a+b/x)^(1+n)/(b^3*c^2*(1+n))+_
+--  a*d^2*(a+b/x)^(1+n)/(b^2*c^3*(1+n))+d^3*(a+b/x)^(1+n)/_
+--  (b*c^4*(1+n))-3*a^2*(a+b/x)^(2+n)/(b^4*c*(2+n))-_
+--  2*a*d*(a+b/x)^(2+n)/(b^3*c^2*(2+n))-d^2*(a+b/x)^(2+n)/_
+--  (b^2*c^3*(2+n))+3*a*(a+b/x)^(3+n)/(b^4*c*(3+n))+d*_
+--  (a+b/x)^(3+n)/(b^3*c^2*(3+n))-(a+b/x)^(4+n)/(b^4*c*(4+n))+_
+--  d^4*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,c*(a+b/x)/_
+--  (a*c-b*d))/(c^4*(a*c-b*d)*(1+n))
+--E 302
+
+--S 303 of 324
+--d0:=t0-D(r0,x)
+--E 303
+
+)clear all
+
+--S 304 of 324
+t0:=(a+b/x)^n*x^m/(c+d*x)^2
+--R 
+--R
+--R            a x + b n m
+--R           (-------) x
+--R               x
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 304
+
+--S 305 of 324
+--r0:=(a+b/x)^n*x^(1+m)*AppellF1(1+m-n,-n,2,2+m-n,-a*x/b,-d*x/c)/_
+--  (c^2*(1+m-n)*((b+a*x)/b)^n)
+--E 305
+
+--S 306 of 324
+--d0:=t0-D(r0,x)
+--E 306
+
+)clear all
+
+--S 307 of 324
+t0:=(a+b/x)^n*x^2/(c+d*x)^2
+--R 
+--R
+--R            2 a x + b n
+--R           x (-------)
+--R                 x
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 307
+
+--S 308 of 324
+--r0:=c^2*(a+b/x)^(1+n)/(d^2*(a*c-b*d)*(d+c/x))+(a+b/x)^(1+n)*x/(a*d^2)-_
+--  2*c*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,(a+b/x)/a)/_
+--  (a*d^3*(1+n))+b*n*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,_
+--  (a+b/x)/a)/(a^2*d^2*(1+n))+2*c^2*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,c*(a+b/x)/(a*c-b*d))/(d^3*(a*c-b*d)*(1+n))+_
+--  b*c^2*n*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,c*(a+b/x)/_
+--  (a*c-b*d))/(d^2*(a*c-b*d)^2*(1+n))
+--E 308
+
+--S 309 of 324
+--d0:=t0-D(r0,x)
+--E 309
+
+)clear all
+
+--S 310 of 324
+t0:=(a+b/x)^n*x/(c+d*x)^2
+--R 
+--R
+--R              a x + b n
+--R           x (-------)
+--R                 x
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 310
+
+--S 311 of 324
+--r0:=-c*(a+b/x)^(1+n)/(d*(a*c-b*d)*(d+c/x))+(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,(a+b/x)/a)/(a*d^2*(1+n))-_
+--  c*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,c*(a+b/x)/(a*c-b*d))/_
+--  (d^2*(a*c-b*d)*(1+n))-b*c*n*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,c*(a+b/x)/(a*c-b*d))/(d*(a*c-b*d)^2*(1+n))
+--E 311
+
+--S 312 of 324
+--d0:=t0-D(r0,x)
+--E 312
+
+)clear all
+
+--S 313 of 324
+t0:=(a+b/x)^n/(c+d*x)^2
+--R 
+--R
+--R             a x + b n
+--R            (-------)
+--R                x
+--R   (1)  ------------------
+--R         2 2             2
+--R        d x  + 2c d x + c
+--R                                                    Type: Expression(Integer)
+--E 313
+
+--S 314 of 324
+--r0:=(a+b/x)^(1+n)/((a*c-b*d)*(d+c/x))+b*n*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,c*(a+b/x)/(a*c-b*d))/((a*c-b*d)^2*(1+n))
+--E 314
+
+--S 315 of 324
+--d0:=t0-D(r0,x)
+--E 315
+
+)clear all
+
+--S 316 of 324
+t0:=(a+b/x)^n/(x*(c+d*x)^2)
+--R 
+--R
+--R              a x + b n
+--R             (-------)
+--R                 x
+--R   (1)  --------------------
+--R         2 3         2    2
+--R        d x  + 2c d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 316
+
+--S 317 of 324
+--r0:=-d*(a+b/x)^(1+n)/(c*(a*c-b*d)*(d+c/x))+(a*c-b*d*(1+n))*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,c*(a+b/x)/(a*c-b*d))/(c*(a*c-b*d)^2*(1+n))
+--E 317
+
+--S 318 of 324
+--d0:=t0-D(r0,x)
+--E 318
+
+)clear all
+
+--S 319 of 324
+t0:=(a+b/x)^n/(x^2*(c+d*x)^2)
+--R 
+--R
+--R               a x + b n
+--R              (-------)
+--R                  x
+--R   (1)  ---------------------
+--R         2 4         3    2 2
+--R        d x  + 2c d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 319
+
+--S 320 of 324
+--r0:=-(a+b/x)^(1+n)/(b*c^2*(1+n))+d^2*(a+b/x)^(1+n)/(c^2*(a*c-b*d)*(d+c/x))-_
+--  d*(2*a*c-b*d*(2+n))*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,c*(a+b/x)/(a*c-b*d))/(c^2*(a*c-b*d)^2*(1+n))
+--E 320
+
+--S 321 of 324
+--d0:=t0-D(r0,x)
+--E 321
+
+)clear all
+
+--S 322 of 324
+t0:=(a+b/x)^n/(x^3*(c+d*x)^2)
+--R 
+--R
+--R               a x + b n
+--R              (-------)
+--R                  x
+--R   (1)  ---------------------
+--R         2 5         4    2 3
+--R        d x  + 2c d x  + c x
+--R                                                    Type: Expression(Integer)
+--E 322
+
+--S 323 of 324
+--r0:=a*(a+b/x)^(1+n)/(b^2*c^2*(1+n))+2*d*(a+b/x)^(1+n)/(b*c^3*(1+n))-_
+--  (a+b/x)^(2+n)/(b^2*c^2*(2+n))-d^3*(a+b/x)^(1+n)/(c^3*(a*c-b*d)*_
+--  (d+c/x))+3*d^2*(a+b/x)^(1+n)*hypergeometric(1,1+n,2+n,c*(a+b/x)/_
+--  (a*c-b*d))/(c^3*(a*c-b*d)*(1+n))-b*d^3*n*(a+b/x)^(1+n)*_
+--  hypergeometric(1,1+n,2+n,c*(a+b/x)/(a*c-b*d))/(c^3*(a*c-b*d)^2*(1+n))
+--E 323
+
+--S 324 of 324
+--d0:=t0-D(r0,x)
+--E 324
+
+)spool
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/input/romnum.as.pamphlet b/src/input/romnum.as.pamphlet
index 22a2645..3389744 100644
--- a/src/input/romnum.as.pamphlet
+++ b/src/input/romnum.as.pamphlet
@@ -11,7 +11,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 -- Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 -- All rights reserved.
 --
@@ -43,9 +43,9 @@
 -- NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 -- SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
+
 #pile
 #include "axiom.as"
 
@@ -61,7 +61,7 @@ RomanNumber : IntegerNumberSystem  == Integer add
             message FormatRoman(n::PositiveInteger)
 
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/input/series3.input.pamphlet b/src/input/series3.input.pamphlet
new file mode 100644
index 0000000..7f4a2b5
--- /dev/null
+++ b/src/input/series3.input.pamphlet
@@ -0,0 +1,53 @@
+\documentclass{article}
+\usepackage{axiom}
+\begin{document}
+\title{\$SPAD/src/input series3.input}
+\author{Nicolas Francois and Martin Rubey}
+\maketitle
+\begin{abstract}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)spool series3.output
+)set message test on
+)set message auto off
+)clear all
+ 
+\end{chunk}
+Question by Nicolas Francois \verb|<nicolas.francois@free.fr>|: 
+Is there any way to obtain the decomposition
+in simple elements of a fraction of the form:
+\[\frac{1}{(1-x)(1-x^2)(1-x^5)}\]
+
+\noindent
+Martin Rubey \verb|<martin.rubey@math.uni-hannover.de>| replied:
+\begin{chunk}{*}
+
+--S 1 of 4
+SAEs5 := SAE(FRAC INT, UP(s5,FRAC INT),s5^2-5)
+--E 1
+
+--S 2 of 4
+p:UP(x,SAEs5) := (x^5-1)*(x^2-1)*(x-1)
+--E 2
+
+--S 3 of 4
+factor p
+--E 3
+
+--S 4 of 4
+partialFraction(1/p,x)
+--E 4
+
+)spool 
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/interp/Makefile.pamphlet b/src/interp/Makefile.pamphlet
index 01619ba..eced320 100644
--- a/src/interp/Makefile.pamphlet
+++ b/src/interp/Makefile.pamphlet
@@ -38,40 +38,40 @@ final ship doc/src/ directory. Since they are system independent
 but machine generated and part of the final ship they will exist 
 in {\bf \$SPAD/mnt/sys/doc/src/interp}.
 
-<<environment>>=
+\begin{chunk}{environment}
 IN=${SRC}/interp
 MID=${INT}/interp
 OUT=${OBJ}/${SYS}/interp
 DOC=${MNT}/${SYS}/doc/src/interp
 BOOK=${MNT}/${SYS}/doc
 
-@
+\end{chunk}
 
 In order to minimize the size of the Axiom image at load time
 we put some of the compiled files into a separate directory
 that will be autoloaded on demand. This directory of code
 will be shipped with the final system and so it belongs in
 the {\bf \$SPAD/mnt} subtree.
-<<environment>>=
+\begin{chunk}{environment}
 AUTO=${MNT}/${SYS}/autoload
 
-@
+\end{chunk}
 
 We need a raw lisp image that we can use as a base to construct
 the other images. This is called {\bf LISPSYS} and is 
 system-dependent and machine-generated.
 It belongs in the {\bf \$SPAD/obj} subtree.
-<<environment>>=
+\begin{chunk}{environment}
 LISPSYS= ${OBJ}/${SYS}/bin/lisp
 
-@
+\end{chunk}
 
 We need to extract the Numerics chunk from bookvol10.5. We do 
 this using the tangle function in the lisp image.
-<<environment>>=
+\begin{chunk}{environment}
 LISPTANGLE= ${OBJ}/${SYS}/bin/lisp
 
-@
+\end{chunk}
 
 Most of the interpreter is written in {\bf boot} \cite{2}.
 Thus we need a program to translate {\bf boot} to Common
@@ -79,10 +79,10 @@ Lisp. This is called the {\bf BOOTSYS} image (because the
 translator is written in {\bf boot} and needs to translate
 itself to bootstrap the system). This image is assumed to
 have been built by a previous step in the make process.
-<<environment>>=
+\begin{chunk}{environment}
 BOOTSYS= ${OBJ}/${SYS}/bin/bootsys    
 
-@
+\end{chunk}
 
 Some of the Common Lisp code we compile uses macros which
 are assumed to be available at compile time. The {\bf DEPSYS}
@@ -90,10 +90,11 @@ image is created to contain the compile time environment
 and saved. We pipe compile commands into this environment
 to compile from Common Lisp to machine dependent code.
 
-<<environment>>=
+\begin{chunk}{environment}
 DEPSYS=	${OBJ}/${SYS}/bin/depsys
 
-@
+\end{chunk}
+
 The {\bf DEP} variable contains the list of files that
 will be loaded into {\bf DEPSYS}. Notice that these files
 are loaded in interpreted form. We are not concerned about
@@ -101,22 +102,23 @@ the compile time performance so we can use interpreted code.
 We do, however, care about the macros as these will be
 expanded in later compiles. All macros are assumed to be
 in this list of files.
-<<environment>>=
+\begin{chunk}{environment}
 DEP= ${MID}/vmlisp.lisp
 
-@
+\end{chunk}
 
 Once we've compile all of the Common Lisp files we fire up
 a clean lisp image called {\bf LOADSYS}, load all of the
 final executable code and save it out as {\bf SAVESYS}.
-The {\bf SAVESYS} image is copied to the [[${MNT}/${SYS}/bin]]
+The {\bf SAVESYS} image is copied to the \verb|${MNT}/${SYS}/bin|
 subdirectory and becomes the axiom executable image.
-<<environment>>=
+\begin{chunk}{environment}
 LOADSYS= ${OBJ}/${SYS}/bin/lisp
 SAVESYS= ${OBJ}/${SYS}/bin/interpsys
 AXIOMSYS= ${MNT}/${SYS}/bin/AXIOMsys
 
-@
+\end{chunk}
+
 Occasionally we need to really get into the system internals.
 The best way to do this is to run almost all of the lisp code
 interpreted rather than compiled (note that cfuns.lisp and sockio.lisp
@@ -125,10 +127,10 @@ loader to link with lisp internals). This image is nothing more
 than a load of the file src/interp/debugsys.lisp.pamphlet. If
 you need to make test modifications you can add code to that
 file and it will show up here.
-<<environment>>=
+\begin{chunk}{environment}
 DEBUGSYS=${OBJ}/${SYS}/bin/debugsys
 
-@
+\end{chunk}
 
 These are the files that need to be compiled (in {\bf BOOTSYS}),
 loaded into a clean lisp image ({\bf LOADSYS}) and saved as
@@ -143,7 +145,7 @@ by being compiled.
 
 The file http.lisp contains code to enable browser-based hyperdoc
 and graphics.
-<<environment>>=
+\begin{chunk}{environment}
 OBJS= ${OUT}/vmlisp.${O}      \
       ${OUT}/buildom.${O} \
       ${OUT}/cattable.${O}    \
@@ -188,18 +190,17 @@ OBJS= ${OUT}/vmlisp.${O}      \
       ${OUT}/nruncomp.${O} \
       ${OUT}/htcheck.${O}
 
-
-@
+\end{chunk}
 
 Before we save the {\bf SAVESYS} image we need to run some
 initialization code. These files perform initialization
 for various parts of the system. The {\bf patches.lisp} \cite{5}
 file contains last-minute changes to various functions and
 constants.
-<<environment>>=
+\begin{chunk}{environment}
 INOBJS=	 ${OUT}/interop.${O}     ${OUT}/patches.${O}
 
-@
+\end{chunk}
 
 Certain functions do not need to be in the running system.
 If the running image never calls the compiler or does not
@@ -214,31 +215,31 @@ The {\bf OPOBJS} list contains files from the old parser. The use of
 ``old'' is something of a subtle concept as there were several
 generations of ``old'' and all meaning of the term is lost.
 
-<<environment>>=
+\begin{chunk}{environment}
 # These are autloaded old parser files
 OPOBJS=	
-@
+\end{chunk}
 
 The {\bf OCOBJS} list contains files from the old compiler. Again,
 ``old'' is meaningless. These files should probably be autoloaded.
-<<environment>>=
+\begin{chunk}{environment}tpdhere
 OCOBJS=	
-@
+\end{chunk}
 
 The {\bf BROBJS} list contains files only used by the hypertex
 browser. These files should probably be autoloaded.
-<<environment>>=
+\begin{chunk}{environment}
 BROBJS=	${AUTO}/br-con.${O}	\
 	${AUTO}/topics.${O}     
 
-@
+\end{chunk}
 
 The {\bf NAGBROBJS} list contains files used to access the 
 Numerical Algorithms Group (NAG) fortran libraries. 
 These files should probably be autoloaded.
-Note that [[${AUTO}/nag-e02a.${O}]] is not included in this
-list as it is a subset of [[${AUTO}/nag-e02.${O}]].
-<<environment>>=
+Note that \verb|${AUTO}/nag-e02a.${O}| is not included in this
+list as it is a subset of \verb|${AUTO}/nag-e02.${O}|.
+\begin{chunk}{environment}
 NAGBROBJS= ${AUTO}/nag-c02.${O}   ${AUTO}/nag-c05.${O} \
            ${AUTO}/nag-c06.${O}   ${AUTO}/nag-d01.${O} \
            ${AUTO}/nag-d02.${O}   ${AUTO}/nag-d03.${O} \
@@ -247,13 +248,13 @@ NAGBROBJS= ${AUTO}/nag-c02.${O}   ${AUTO}/nag-c05.${O} \
            ${AUTO}/nag-f02.${O}   ${AUTO}/nag-f04.${O} \
            ${AUTO}/nag-f07.${O}   ${AUTO}/nag-s.${O} 
 
-@
+\end{chunk}
 The {\bf ASCOMP} list contains files used by the {\bf Aldor}
 \cite{5} compiler. These files should probably be autoloaded.
-<<environment>>=
+\begin{chunk}{environment}
 ASCOMP= ${OUT}/hashcode.${O}
 
-@
+\end{chunk}
 
 Axiom versions are given as a string of the form:
 "Sunday September 21, 2003 at 20:38:05 "
@@ -264,28 +265,28 @@ a tar file of all of the date/time stamps of all of the source files
 and use the MD5 hash of that file as the version stamp. Ultimately
 though, this would be chasing the elusive "perfect information" idea.
 
-A new variable [[boot::*build-version*]] is set and used by the
+A new variable \verb|boot::*build-version*| is set and used by the
 {\tt yearweek} function to display the version number of the Axiom build.
 This information is set by hand in the top level Makefile.
-<<environment>>=
+\begin{chunk}{environment}
 TIMESTAMP=${MNT}/${SYS}/timestamp
 YEARWEEK=(progn (setq timestamp "${TIMESTAMP}") \
                 (setq boot::*build-version* "${VERSION}") \
                 (yearweek))
 
-@
+\end{chunk}
 The {\bf .PRECIOUS} setting will keep make from deleting these
 images if the build is stopped. Since once they are built they
 are likely to be useable we don't need to redo the work if they
 exist.
-<<environment>>=
+\begin{chunk}{environment}
 
 .PRECIOUS:	${BOOTSYS}
 .PRECIOUS:	${DEPSYS}
 .PRECIOUS:	${SAVESYS}
 .PRECIOUS:	${AXIOMSYS}
 
-@
+\end{chunk}
 \section{Proclaim optimization}
 GCL, and possibly other common lisps, can generate much better
 code if the function argument types and return values are proclaimed.
@@ -297,7 +298,7 @@ allow the compiler to optimize function calling.
 
 GCL has an approximation to this scanning which we use here. 
 
-The first step is to build a version of GCL that includes [[gcl_collectfn]].
+The first step is to build a version of GCL that includes \verb|gcl_collectfn|.
 This file contains code that enhances the lisp compiler and creates a
 hash table of structs. Each struct in the hash table describes information
 that about the types of the function being compiled and the types of its
@@ -305,7 +306,7 @@ arguments. At the end of the compile-file this hash table is written out
 to a ".fn" file. 
 
 The second step is to build axiom images (depsys, interpsys, AXIOMsys)
-which contain the [[gcl_collectfn]] code.
+which contain the \verb|gcl_collectfn| code.
 
 The third step is to build the system. This generates a .fn file for 
 each lisp file that gets compiled.
@@ -332,24 +333,24 @@ The fifth step is to copy the newly constructed proclaims file back
 into the src/interp diretory (or boot, algebra).
 
 In order for this information to be used during compiles we define
-<<environment>>=
+\begin{chunk}{environment}
 PROCLAIMS=(progn (load "${OUT}/sys-pkg.lsp") \
                  (load "${IN}/interp-proclaims.lisp"))
 
-@
+\end{chunk}
 
 \section{The warm.data file}
 This is a file of commands that will be loaded into interpsys
 at the last minute. It execute functions that will likely be
 used in a running system so all of the required routines will
 be in the lisp image thus minimizing their startup time.
-<<warm.data.stanza>>=
+\begin{chunk}{warm.data.stanza}
 ${INT}/algebra/warm.data: 
 	@ echo si001 building warm.data
-	@ ${TANGLE} -Rwarm.data ${IN}/Makefile.pamphlet >${INT}/algebra/warm.data
+	@ ${BOOKS}/tangle ${IN}/Makefile.pamphlet warm.data >${INT}/algebra/warm.data
 
-@
-<<warm.data>>=
+\end{chunk}
+\begin{chunk}{warm.data}
 (in-package 'boot)
 (setq |$topicHash| (make-hash-table))
 (setf (gethash '|basic| |$topicHash|) 2)
@@ -366,7 +367,7 @@ ${INT}/algebra/warm.data:
 (setf (gethash '|predicate| |$topicHash|) 8)
 (setf (gethash '|trignometric| |$topicHash|) 11)
 
-@
+\end{chunk}
 \section{Building DEPSYS}
 The depsys image proceeds all else. it is the compile-time environment
 for all interpreter code. 
@@ -392,17 +393,17 @@ see the file load. The collectfn.lsp code is used by GCL to generate
 the ``.fn'' files which are used to optimize function calling.
 
 \subsection{save depsys image}
-Once the appropriate commands are in the [[${OUT}/makedep.lisp]] file
+Once the appropriate commands are in the \verb|${OUT}/makedep.lisp| file
 we can load the file into a fresh image and save it. At least that's
 how it used to work. In freebsd we cannot do this so we have to use
 a much more complicated procedure.
 This code used to read:
 \begin{verbatim}
-<<save depsys image>>=
+\begin{chunk}{save depsys image}
 	@ (cd ${MNT}/${SYS}/bin ; \
 	   echo '(progn (load "${OUT}/makedep.lisp")' \
                 '(spad-save "${DEPSYS}"))' | ${LISPSYS})
-@
+\end{chunk}
 \end{verbatim}
 
 Now game is much more difficult. 
@@ -412,9 +413,9 @@ Now game is much more difficult.
 
 \end{verbatim}
 
-[[si::*collect-binary-modules*]] instructs GCL to build a list of 
+\verb|si::*collect-binary-modules*| instructs GCL to build a list of 
 binary object modules loaded into the current session with (load ...)
-The list will be stored in [[si::*binary-modules*]].
+The list will be stored in \verb|si::*binary-modules*|.
 \begin{verbatim}
 
 	       (setq si::*collect-binary-modules* t) \
@@ -422,8 +423,8 @@ The list will be stored in [[si::*binary-modules*]].
 
 \end{verbatim}
 
-[[compiler::link]] is a lisp interface to the ``ld'' C-based system linker.
-The first argumet is a list of [[.o]] binary object modules to link into a
+\verb|compiler::link| is a lisp interface to the ``ld'' C-based system linker.
+The first argumet is a list of .o binary object modules to link into a
 fresh gcl image. The second argument is the name of the new output
 image.  The third argument is a string containing an initialization
 command to run in the new image to reinitialize the heap.  The fourth
@@ -441,7 +442,7 @@ maxima, have no such complex initialization sequence.
 \begin{verbatim}
   (compiler::link \
 \end{verbatim}
-[[si::*binary-modules*]] here has the list of compiled lisp binary module
+\verb|si::*binary-modules*| here has the list of compiled lisp binary module
 .o files loaded by makedep.lsp above.
 \begin{verbatim}
    (remove-duplicates si::*binary-modules* \
@@ -465,7 +466,7 @@ purposes.
      (setq si::*collect-binary-modules* t) \
 \end{verbatim}
 
-We need to find [[gcl_collectfn.lsp]], so set the [[*load-path*]], and make
+We need to find \verb|gcl_collectfn.lsp|, so set the *load-path*, and make
 sure the source, not the binary, form is loaded here, as we're only
 using this entire sequence on machines which cannot load binary object
 modules and preserve them in saved images.
@@ -474,7 +475,7 @@ modules and preserve them in saved images.
            (si::*load-types* ~S))\
 \end{verbatim}
 
-Turn on function analyzation and autoload thereby [[gcl_collectfn.lsp]].
+Turn on function analyzation and autoload thereby \verb|gcl_collectfn.lsp|.
 \begin{verbatim}
       (compiler::emit-fn t))\
 \end{verbatim}
@@ -547,7 +548,7 @@ initialization sequence.
      nil))' | $(LISPSYS))
 \end{verbatim}
 
-The [[save depsys image]] was supposed to read:
+The save depsys image was supposed to read:
 \begin{verbatim}
  @ (cd ${OBJ}/${SYS}/bin ; \
    echo '(progn' \
@@ -586,7 +587,7 @@ of the form:
 /home/axiom33/obj/linux/interp/postpar.o(.text+0x4e78): 
   first defined here
 \end{verbatim}
-<<depsys>>=
+\begin{chunk}{depsys}
 ${DEPSYS}:	${DEP} ${OUT}/sys-pkg.${LISP} ${OUT}/nocompil.${LISP} \
 	        ${OUT}/bookvol5.${LISP} ${OUT}/bookvol9.${LISP} \
                 ${OUT}/util.${LISP} \
@@ -629,17 +630,18 @@ ${DEPSYS}:	${DEP} ${OUT}/sys-pkg.${LISP} ${OUT}/nocompil.${LISP} \
 	@ echo '(unless (probe-file "${OUT}/g-util.${O}")' \
           '(compile-file "${OUT}/g-util.lisp"' \
           ':output-file "${OUT}/g-util.${O}"))' >> ${OUT}/makedep.lisp
+
 	@ echo '(load "${OUT}/g-util")' >> ${OUT}/makedep.lisp
-<<save depsys image>>
+\getchunk{save depsys image}
 	@ echo si003 ${DEPSYS} created
 
-@
+\end{chunk}
 \section{Building SAVESYS and AXIOMSYS}
 GCL likes to tell you when it has replaced a function call by a 
 tail-recursive call. This happens when the last form in a function
 is a call to the same function. In general, we don't care so we set
 compiler::*suppress-compiler-notes* to true in order to reduce the noise.
-<<savesys>>=
+\begin{chunk}{savesys}
 ${SAVESYS}:	${DEPSYS} ${OBJS} ${OUT}/bookvol5.${O} ${OUT}/util.${O} \
                 ${OUT}/nocompil.${LISP} ${OUT}/sys-pkg.${LISP} \
 	        ${OUTINTERP} ${BROBJS} \
@@ -698,13 +700,13 @@ ${SAVESYS}:	${DEPSYS} ${OBJS} ${OUT}/bookvol5.${O} ${OUT}/util.${O} \
 	@ cp ${SAVESYS} ${AXIOMSYS}
 	@ echo si006 ${AXIOMSYS} created
 
-@
+\end{chunk}
 
 \section{Building debugsys}
 Note that we assume you've already built interpsys so all of the
 files are known to exist and be up to date. We don't list any of
 the preconditions here. 
-<<debugsys>>=
+\begin{chunk}{debugsys}
 ${DEBUGSYS}: ${MID}/debugsys.lisp
 	@ echo si007 building debugsys
 	@ (cd ${OBJ}/${SYS}/bin ; \
@@ -712,7 +714,7 @@ ${DEBUGSYS}: ${MID}/debugsys.lisp
                  '(user::spad-save "${DEBUGSYS}"))' | ${LISPSYS} )
 	@ echo si008 ${DEBUGSYS} created
 
-@
+\end{chunk}
 
 \section{The Interpreter files}
 
@@ -729,14 +731,14 @@ interpsys. See the echo lines in the {\bf SAVESYS} block above. These
 are echoed into a temporary file which gets loaded into the lisp image.
 We simply captured that temporary file, replaced the .o files with .lisp
 files (or .lsp or .clisp) and saved it here.
-<<debugsys.lisp (MID from IN)>>=
+\begin{chunk}{debugsys.lisp (MID from IN)}
 ${MID}/debugsys.lisp: ${IN}/debugsys.lisp.pamphlet
 	@ echo si011 making ${MID}/debugsys.lisp from ${IN}/debugsys.lisp.pamphlet
 	@ (cd ${MID} ; \
           echo '(tangle "${IN}/debugsys.lisp.pamphlet" "*" "debugsys.lisp")' \
         | ${OBJ}/${SYS}/bin/lisp  1>/dev/null 2>/dev/null)
 
-@
+\end{chunk}
 
 \section{The databases}
 \subsection{autoload dependencies}
@@ -761,17 +763,17 @@ should trigger the autoload
 \end{enumerate}
 database.date is a marker file used to force a rebuild of interpsys if the
 database is rebuilt (src/algebra/Makefile).
-<<databases>>=
+\begin{chunk}{databases}
 ${OUT}/database.date:
 	@ echo 617 the database was updated...remaking interpsys
 	@ touch ${OUT}/database.date
 
-@
+\end{chunk}
 
 \section{The Makefile}
-<<*>>=
+\begin{chunk}{*}
 
-<<environment>>
+\getchunk{environment}
 
 all: announce ${SAVESYS} # ${DEBUGSYS} 
 	@echo 618 finished ${IN}
@@ -784,14 +786,14 @@ announce:
 clean:
 	@echo 619 cleaning ${SRC}/interp
 
-<<savesys>>
-<<depsys>>
-<<debugsys>>
-<<databases>>
+\getchunk{savesys}
+\getchunk{depsys}
+\getchunk{debugsys}
+\getchunk{databases}
 
-<<debugsys.lisp (MID from IN)>>
+\getchunk{debugsys.lisp (MID from IN)}
 
-<<warm.data.stanza>>
+\getchunk{warm.data.stanza}
 
 ${MID}/bookvol5.${LISP}: ${IN}/bookvol5.pamphlet
 	@ echo si125 making ${MID}/bookvol5.${LISP} from ${IN}/bookvol5.pamphlet
@@ -866,7 +868,7 @@ ${OUT}/%.${O}: ${MID}/%.${LISP}
               1>/dev/null 2>/dev/null ; \
 	  fi 
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \end{thebibliography}
diff --git a/src/lib/Makefile.pamphlet b/src/lib/Makefile.pamphlet
index 772bb8e..48acce5 100644
--- a/src/lib/Makefile.pamphlet
+++ b/src/lib/Makefile.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{environment}
-<<environment>>=
+\begin{chunk}{environment}
 IN=${SRC}/lib
 MID=${INT}/lib
 OUT=${OBJ}/${SYS}/lib
@@ -27,41 +27,43 @@ AR=	${OUT}/bsdsignal.o  ${OUT}/cursor.o ${OUT}/edin.o     \
 OTHER=	${OUT}/cfuns-c.o ${OUT}/hash.o
 
 DOCFILES=\
- ${DOCMNT}/bsdsignal.c.dvi  ${DOCMNT}/cfuns-c.c.dvi  ${DOCMNT}/cursor.c.dvi \
- ${DOCMNT}/edin.c.dvi       ${DOCMNT}/fnct-key.c.dvi ${DOCMNT}/halloc.c.dvi \
- ${DOCMNT}/hash.c.dvi       ${DOCMNT}/openpty.c.dvi  ${DOCMNT}/pixmap.c.dvi \
- ${DOCMNT}/prt.c.dvi        ${DOCMNT}/sockio-c.c.dvi ${DOCMNT}/Makefile.dvi \
- ${DOCMNT}/spadcolors.c.dvi ${DOCMNT}/util.c.dvi     ${DOCMNT}/wct.c.dvi    \
- ${DOCMNT}/xdither.c.dvi    ${DOCMNT}/xshade.c.dvi   ${DOCMNT}/xspadfill.c.dvi 
-
-@
+ ${DOCMNT}/bsdsignal.c.pdf  ${DOCMNT}/cfuns-c.c.pdf  ${DOCMNT}/cursor.c.pdf \
+ ${DOCMNT}/edin.c.pdf       ${DOCMNT}/fnct-key.c.pdf ${DOCMNT}/halloc.c.pdf \
+ ${DOCMNT}/hash.c.pdf       ${DOCMNT}/openpty.c.pdf  ${DOCMNT}/pixmap.c.pdf \
+ ${DOCMNT}/prt.c.pdf        ${DOCMNT}/sockio-c.c.pdf ${DOCMNT}/Makefile.pdf \
+ ${DOCMNT}/spadcolors.c.pdf ${DOCMNT}/util.c.pdf     ${DOCMNT}/wct.c.pdf    \
+ ${DOCMNT}/xdither.c.pdf    ${DOCMNT}/xshade.c.pdf   ${DOCMNT}/xspadfill.c.pdf 
+
+\end{chunk}
 \section{Files}
 \subsection{bsdsignal.c \cite{1}}
 
-<<bsdsignal>>=
+\begin{chunk}{bsdsignal}
 ${MID}/bsdsignal.c: ${IN}/bsdsignal.c.pamphlet
 	@echo sl01 making ${MID}/bsdsignal.c from ${IN}/bsdsignal.c.pamphlet
-	@${TANGLE} bsdsignal.c.pamphlet >${MID}/bsdsignal.c
+	@${BOOKS}/tangle bsdsignal.c.pamphlet >${MID}/bsdsignal.c
 
 ${OUT}/bsdsignal.o: ${MID}/bsdsignal.c
 	@echo sl02 making ${OUT}/bsdsignal.o from ${MID}/bsdsignal.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/bsdsignal.c )
 
-${DOCINT}/bsdsignal.c.dvi: ${IN}/bsdsignal.c.pamphlet 
-	@echo sl03 making ${DOCINT}/bsdsignal.c.dvi from ${IN}/bsdsignal.c.pamphlet
+${DOCINT}/bsdsignal.c.pdf: ${IN}/bsdsignal.c.pamphlet 
+	@echo sl03 making ${DOCINT}/bsdsignal.c.pdf \
+                     from ${IN}/bsdsignal.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/bsdsignal.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} bsdsignal.c ; \
+	${EXTRACT} bsdsignal.c.pamphlet ; \
 	rm -f ${DOCINT}/bsdsignal.c.pamphlet ; \
 	rm -f ${DOCINT}/bsdsignal.c.tex ; \
 	rm -f ${DOCINT}/bsdsignal.c )
 
-${DOCMNT}/bsdsignal.c.dvi: ${DOCINT}/bsdsignal.c.dvi 
-	@echo sl04 making ${DOCMNT}/bsdsignal.c.dvi from ${DOCINT}/bsdsignal.c.dvi
-	@cp ${DOCINT}/bsdsignal.c.dvi ${DOCMNT}/bsdsignal.c.dvi 
+${DOCMNT}/bsdsignal.c.pdf: ${DOCINT}/bsdsignal.c.pdf
+	@echo sl12 making ${DOCMNT}/bsdsignal.c.pdf from \
+                          ${DOCINT}/bsdsignal.c.pdf
+	@cp ${DOCINT}/bsdsignal.c.pdf ${DOCMNT}/bsdsignal.c.pdf 
 
-@
+\end{chunk}
 
 \subsection{cfuns-c.c \cite{2}}
 The cfuns-c file contains socket primitives used by Axiom.
@@ -70,233 +72,234 @@ In GCL this link happens thru setting a shell variable called
 {\bf EXTRAS} in the {\bf h/386-linux.defs} file. This file
 gets included as part of the final system build of GCL.
 
-<<cfuns-c>>=
+\begin{chunk}{cfuns-c}
 ${MID}/cfuns-c.c: ${IN}/cfuns-c.c.pamphlet
 	@echo sl05 making ${MID}/cfuns-c.c from ${IN}/cfuns-c.c.pamphlet
-	@${TANGLE} cfuns-c.c.pamphlet >${MID}/cfuns-c.c
+	@${BOOKS}/tangle cfuns-c.c.pamphlet >${MID}/cfuns-c.c
 
 ${OUT}/cfuns-c.o: ${MID}/cfuns-c.c
 	@echo sl06 making ${OUT}/cfuns-c.o from ${MID}/cfuns-c.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/cfuns-c.c )
 
-${DOCINT}/cfuns-c.c.dvi: ${IN}/cfuns-c.c.pamphlet 
-	@echo sl07 making ${DOCINT}/cfuns-c.c.dvi from ${IN}/cfuns-c.c.pamphlet
+${DOCINT}/cfuns-c.c.pdf: ${IN}/cfuns-c.c.pamphlet 
+	@echo sl07 making ${DOCINT}/cfuns-c.c.pdf from ${IN}/cfuns-c.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/cfuns-c.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} cfuns-c.c ; \
+	${EXTRACT} cfuns-c.c.pamphlet ; \
 	rm -f ${DOCINT}/cfuns-c.c.pamphlet ; \
 	rm -f ${DOCINT}/cfuns-c.c.tex ; \
 	rm -f ${DOCINT}/cfuns-c.c )
 
-${DOCMNT}/cfuns-c.c.dvi: ${DOCINT}/cfuns-c.c.dvi
-	@echo sl08 making ${DOCMNT}/cfuns-c.c.dvi from ${DOCINT}/cfuns-c.c.dvi
-	@cp ${DOCINT}/cfuns-c.c.dvi ${DOCMNT}/cfuns-c.c.dvi 
+${DOCMNT}/cfuns-c.c.pdf: ${DOCINT}/cfuns-c.c.pdf
+	@echo sl04 making ${DOCMNT}/cfuns-c.c.pdf from \
+                          ${IN}/cfuns-c.c.pamphlet
+	@cp ${DOCINT}/cfuns-c.c.pdf ${DOCMNT}/cfuns-c.c.pdf 
 
-@
+\end{chunk}
 \subsection{cursor.c \cite{3}}
-<<cursor>>=
+\begin{chunk}{cursor}
 ${MID}/cursor.c: ${IN}/cursor.c.pamphlet
 	@echo sl09 making ${MID}/cursor.c from ${IN}/cursor.c.pamphlet
-	@${TANGLE} cursor.c.pamphlet >${MID}/cursor.c
+	@${BOOKS}/tangle cursor.c.pamphlet >${MID}/cursor.c
 
 ${OUT}/cursor.o: ${MID}/cursor.c
 	@echo sl10 making ${OUT}/cursor.o from ${MID}/cursor.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/cursor.c )
 
-${DOCINT}/cursor.c.dvi: ${IN}/cursor.c.pamphlet 
-	@echo sl11 making ${DOCINT}/cursor.c.dvi from ${IN}/cursor.c.pamphlet
+${DOCINT}/cursor.c.pdf: ${IN}/cursor.c.pamphlet 
+	@echo sl11 making ${DOCINT}/cursor.c.pdf from ${IN}/cursor.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/cursor.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} cursor.c ; \
+	${EXTRACT} cursor.c.pamphlet ; \
 	rm -f ${DOCINT}/cursor.c.pamphlet ; \
 	rm -f ${DOCINT}/cursor.c.tex ; \
 	rm -f ${DOCINT}/cursor.c )
 
-${DOCMNT}/cursor.c.dvi: ${DOCINT}/cursor.c.dvi
-	@echo sl12 making ${DOCMNT}/cursor.c.dvi from ${DOCINT}/cursor.c.dvi
-	@cp ${DOCINT}/cursor.c.dvi ${DOCMNT}/cursor.c.dvi 
+${DOCMNT}/cursor.c.pdf: ${DOCINT}/cursor.c.pdf
+	@echo sl12 making ${DOCMNT}/cursor.c.pdf from ${DOCINT}/cursor.c.pdf
+	@cp ${DOCINT}/cursor.c.pdf ${DOCMNT}/cursor.c.pdf 
 
-@
+\end{chunk}
 \subsection{edin.c \cite{4}}
-<<edin>>=
+\begin{chunk}{edin}
 ${MID}/edin.c: ${IN}/edin.c.pamphlet
 	@echo sl13 making ${MID}/edin.c from ${IN}/edin.c.pamphlet
-	@${TANGLE} edin.c.pamphlet >${MID}/edin.c
+	@${BOOKS}/tangle edin.c.pamphlet >${MID}/edin.c
 
 ${OUT}/edin.o: ${MID}/edin.c
 	@echo sl14 making ${OUT}/edin.o from ${MID}/edin.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/edin.c )
 
-${DOCINT}/edin.c.dvi: ${IN}/edin.c.pamphlet 
-	@echo sl15 making ${DOCINT}/edin.c.dvi from ${IN}/edin.c.pamphlet
+${DOCINT}/edin.c.pdf: ${IN}/edin.c.pamphlet 
+	@echo sl15 making ${DOCINT}/edin.c.pdf from ${IN}/edin.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/edin.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} edin.c ; \
+	${EXTRACT} edin.c.pamphlet ; \
 	rm -f ${DOCINT}/edin.c.pamphlet ; \
 	rm -f ${DOCINT}/edin.c.tex ; \
 	rm -f ${DOCINT}/edin.c )
 
-${DOCMNT}/edin.c.dvi: ${DOCINT}/edin.c.dvi
-	@echo sl16 making ${DOCMNT}/edin.c.dvi from ${DOCINT}/edin.c.dvi
-	@cp ${DOCINT}/edin.c.dvi ${DOCMNT}/edin.c.dvi 
+${DOCMNT}/edin.c.pdf: ${DOCINT}/edin.c.pdf
+	@echo sl16 making ${DOCMNT}/edin.c.pdf from ${DOCINT}/edin.c.pdf
+	@cp ${DOCINT}/edin.c.pdf ${DOCMNT}/edin.c.pdf 
 
-@
+\end{chunk}
 \subsection{fnct-key.c \cite{5}}
-<<fnctkey>>=
+\begin{chunk}{fnctkey}
 ${MID}/fnct-key.c: ${IN}/fnct-key.c.pamphlet
 	@echo sl17 making ${MID}/fnct-key.c from ${IN}/fnct-key.c.pamphlet
-	@${TANGLE} fnct-key.c.pamphlet >${MID}/fnct-key.c
+	@${BOOKS}/tangle fnct-key.c.pamphlet >${MID}/fnct-key.c
 
 ${OUT}/fnct-key.o: ${MID}/fnct-key.c
 	@echo sl18 making ${OUT}/fnct-key.o from ${MID}/fnct-key.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/fnct-key.c )
 
-${DOCINT}/fnct-key.c.dvi: ${IN}/fnct-key.c.pamphlet 
-	@echo sl19 making ${DOCINT}/fnct-key.c.dvi from ${IN}/fnct-key.c.pamphlet
+${DOCINT}/fnct-key.c.pdf: ${IN}/fnct-key.c.pamphlet 
+	@echo sl19 making ${DOCINT}/fnct-key.c.pdf from ${IN}/fnct-key.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/fnct-key.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} fnct-key.c ; \
+	${EXTRACT} fnct-key.c.pamphlet ; \
 	rm -f ${DOCINT}/fnct-key.c.pamphlet ; \
 	rm -f ${DOCINT}/fnct-key.c.tex ; \
 	rm -f ${DOCINT}/fnct-key.c )
 
-${DOCMNT}/fnct-key.c.dvi: ${DOCINT}/fnct-key.c.dvi
-	@echo sl20 making ${DOCMNT}/fnct-key.c.dvi from ${DOCINT}/fnct-key.c.dvi
-	@cp ${DOCINT}/fnct-key.c.dvi ${DOCMNT}/fnct-key.c.dvi 
+${DOCMNT}/fnct-key.c.pdf: ${DOCINT}/fnct-key.c.pdf
+	@echo sl20 making ${DOCMNT}/fnct-key.c.pdf from ${DOCINT}/fnct-key.c.pdf
+	@cp ${DOCINT}/fnct-key.c.pdf ${DOCMNT}/fnct-key.c.pdf 
 
-@
+\end{chunk}
 \subsection{halloc.c \cite{6}}
-<<halloc>>=
+\begin{chunk}{halloc}
 ${MID}/halloc.c: ${IN}/halloc.c.pamphlet
 	@echo sl21 making ${MID}/halloc.c from ${IN}/halloc.c.pamphlet
-	@${TANGLE} halloc.c.pamphlet >${MID}/halloc.c
+	@${BOOKS}/tangle halloc.c.pamphlet >${MID}/halloc.c
 
 ${OUT}/halloc.o: ${MID}/halloc.c
 	@echo sl22 making ${OUT}/halloc.o from ${MID}/halloc.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/halloc.c )
 
-${DOCINT}/halloc.c.dvi: ${IN}/halloc.c.pamphlet 
-	@echo sl23 making ${DOCINT}/halloc.c.dvi from ${IN}/halloc.c.pamphlet
+${DOCINT}/halloc.c.pdf: ${IN}/halloc.c.pamphlet 
+	@echo sl23 making ${DOCINT}/halloc.c.pdf from ${IN}/halloc.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/halloc.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} halloc.c ; \
+	${EXTRACT} halloc.c.pamphlet ; \
 	rm -f ${DOCINT}/halloc.c.pamphlet ; \
 	rm -f ${DOCINT}/halloc.c.tex ; \
 	rm -f ${DOCINT}/halloc.c )
 
-${DOCMNT}/halloc.c.dvi: ${DOCINT}/halloc.c.dvi
-	@echo sl24 making ${DOCMNT}/halloc.c.dvi from ${DOCINT}/halloc.c.dvi
-	@cp ${DOCINT}/halloc.c.dvi ${DOCMNT}/halloc.c.dvi 
+${DOCMNT}/halloc.c.pdf: ${DOCINT}/halloc.c.pdf
+	@echo sl24 making ${DOCMNT}/halloc.c.pdf from ${DOCINT}/halloc.c.pdf
+	@cp ${DOCINT}/halloc.c.pdf ${DOCMNT}/halloc.c.pdf 
 
-@
+\end{chunk}
 \subsection{hash.c \cite{6}}
 This a a string-based hash table that is used both in the graph
 and hyper functions. It is included here because we need it built
 earlier so the graph and hyper routines can refer to it.
-<<hash>>=
+\begin{chunk}{hash}
 ${MID}/hash.c: ${IN}/hash.c.pamphlet
 	@echo sl25 making ${MID}/hash.c from ${IN}/hash.c.pamphlet
-	@${TANGLE} hash.c.pamphlet >${MID}/hash.c
+	@${BOOKS}/tangle hash.c.pamphlet >${MID}/hash.c
 
 ${OUT}/hash.o: ${MID}/hash.c
 	@echo sl26 making ${OUT}/hash.o from ${MID}/hash.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/hash.c )
 
-${DOCINT}/hash.c.dvi: ${IN}/hash.c.pamphlet 
-	@echo sl27 making ${DOCINT}/hash.c.dvi from ${IN}/hash.c.pamphlet
+${DOCINT}/hash.c.pdf: ${IN}/hash.c.pamphlet 
+	@echo sl27 making ${DOCINT}/hash.c.pdf from ${IN}/hash.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/hash.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} hash.c ; \
+	${EXTRACT} hash.c.pamphlet ; \
 	rm -f ${DOCINT}/hash.c.pamphlet ; \
 	rm -f ${DOCINT}/hash.c.tex ; \
 	rm -f ${DOCINT}/hash.c )
 
-${DOCMNT}/hash.c.dvi: ${DOCINT}/hash.c.dvi
-	@echo sl28 making ${DOCMNT}/hash.c.dvi from ${DOCINT}/hash.c.dvi
-	@cp ${DOCINT}/hash.c.dvi ${DOCMNT}/hash.c.dvi 
+${DOCMNT}/hash.c.pdf: ${DOCINT}/hash.c.pdf
+	@echo sl28 making ${DOCMNT}/hash.c.pdf from ${DOCINT}/hash.c.pdf
+	@cp ${DOCINT}/hash.c.pdf ${DOCMNT}/hash.c.pdf 
 
-@
+\end{chunk}
 \subsection{openpty.c \cite{7}}
-<<openpty>>=
+\begin{chunk}{openpty}
 ${MID}/openpty.c: ${IN}/openpty.c.pamphlet
 	@echo sl29 making ${MID}/openpty.c from ${IN}/openpty.c.pamphlet
-	@${TANGLE} openpty.c.pamphlet >${MID}/openpty.c
+	@${BOOKS}/tangle openpty.c.pamphlet >${MID}/openpty.c
 
 ${OUT}/openpty.o: ${MID}/openpty.c
 	@echo sl30 making ${OUT}/openpty.o from ${MID}/openpty.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/openpty.c )
 
-${DOCINT}/openpty.c.dvi: ${IN}/openpty.c.pamphlet 
-	@echo sl31 making ${DOCINT}/openpty.c.dvi from ${IN}/openpty.c.pamphlet
+${DOCINT}/openpty.c.pdf: ${IN}/openpty.c.pamphlet 
+	@echo sl31 making ${DOCINT}/openpty.c.pdf from ${IN}/openpty.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/openpty.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} openpty.c ; \
+	${EXTRACT} openpty.c.pamphlet ; \
 	rm -f ${DOCINT}/openpty.c.pamphlet ; \
 	rm -f ${DOCINT}/openpty.c.tex ; \
 	rm -f ${DOCINT}/openpty.c )
 
-${DOCMNT}/openpty.c.dvi: ${DOCINT}/openpty.c.dvi
-	@echo sl32 making ${DOCMNT}/openpty.c.dvi from ${DOCINT}/openpty.c.dvi
-	@cp ${DOCINT}/openpty.c.dvi ${DOCMNT}/openpty.c.dvi 
+${DOCMNT}/openpty.c.pdf: ${DOCINT}/openpty.c.pdf
+	@echo sl32 making ${DOCMNT}/openpty.c.pdf from ${DOCINT}/openpty.c.pdf
+	@cp ${DOCINT}/openpty.c.pdf ${DOCMNT}/openpty.c.pdf 
 
-@
+\end{chunk}
 \subsection{pixmap.c \cite{8}}
-<<pixmap>>=
+\begin{chunk}{pixmap}
 ${MID}/pixmap.c: ${IN}/pixmap.c.pamphlet
 	@echo sl33 making ${MID}/pixmap.c from ${IN}/pixmap.c.pamphlet
-	@${TANGLE} pixmap.c.pamphlet >${MID}/pixmap.c
+	@${BOOKS}/tangle pixmap.c.pamphlet >${MID}/pixmap.c
 
 ${OUT}/pixmap.o: ${MID}/pixmap.c
 	@echo sl34 making ${OUT}/pixmap.o from ${MID}/pixmap.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/pixmap.c )
 
-${DOCINT}/pixmap.c.dvi: ${IN}/pixmap.c.pamphlet 
-	@echo sl35 making ${DOCINT}/pixmap.c.dvi from ${IN}/pixmap.c.pamphlet
+${DOCINT}/pixmap.c.pdf: ${IN}/pixmap.c.pamphlet 
+	@echo sl35 making ${DOCINT}/pixmap.c.pdf from ${IN}/pixmap.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/pixmap.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} pixmap.c ; \
+	${EXTRACT} pixmap.c.pamphlet ; \
 	rm -f ${DOCINT}/pixmap.c.pamphlet ; \
 	rm -f ${DOCINT}/pixmap.c.tex ; \
 	rm -f ${DOCINT}/pixmap.c )
 
-${DOCMNT}/pixmap.c.dvi: ${DOCINT}/pixmap.c.dvi
-	@echo sl36 making ${DOCMNT}/pixmap.c.dvi from ${DOCINT}/pixmap.c.dvi
-	@cp ${DOCINT}/pixmap.c.dvi ${DOCMNT}/pixmap.c.dvi 
+${DOCMNT}/pixmap.c.pdf: ${DOCINT}/pixmap.c.pdf
+	@echo sl36 making ${DOCMNT}/pixmap.c.pdf from ${DOCINT}/pixmap.c.pdf
+	@cp ${DOCINT}/pixmap.c.pdf ${DOCMNT}/pixmap.c.pdf 
 
-@
+\end{chunk}
 \subsection{prt.c \cite{9}}
-<<prt>>=
+\begin{chunk}{prt}
 ${MID}/prt.c: ${IN}/prt.c.pamphlet
 	@echo sl37 making ${MID}/prt.c from ${IN}/prt.c.pamphlet
-	@${TANGLE} prt.c.pamphlet >${MID}/prt.c
+	@${BOOKS}/tangle prt.c.pamphlet >${MID}/prt.c
 
 ${OUT}/prt.o: ${MID}/prt.c
 	@echo sl38 making ${OUT}/prt.o from ${MID}/prt.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/prt.c )
 
-${DOCINT}/prt.c.dvi: ${IN}/prt.c.pamphlet 
-	@echo sl39 making ${DOCINT}/prt.c.dvi from ${IN}/prt.c.pamphlet
+${DOCINT}/prt.c.pdf: ${IN}/prt.c.pamphlet 
+	@echo sl39 making ${DOCINT}/prt.c.pdf from ${IN}/prt.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/prt.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} prt.c ; \
+	${EXTRACT} prt.c.pamphlet ; \
 	rm -f ${DOCINT}/prt.c.pamphlet ; \
 	rm -f ${DOCINT}/prt.c.tex ; \
 	rm -f ${DOCINT}/prt.c )
 
-${DOCMNT}/prt.c.dvi: ${DOCINT}/prt.c.dvi
-	@echo sl40 making ${DOCMNT}/prt.c.dvi from ${DOCINT}/prt.c.dvi
-	@cp ${DOCINT}/prt.c.dvi ${DOCMNT}/prt.c.dvi 
+${DOCMNT}/prt.c.pdf: ${DOCINT}/prt.c.pdf
+	@echo sl40 making ${DOCMNT}/prt.c.pdf from ${DOCINT}/prt.c.pdf
+	@cp ${DOCINT}/prt.c.pdf ${DOCMNT}/prt.c.pdf 
 
-@
+\end{chunk}
 \subsection{sockio-c.c \cite{10}}
 The sockio-c file contains socket primitives used by Axiom.
 They must be linked into and visible from the inferior lisp.
@@ -304,204 +307,204 @@ In GCL this link happens thru setting a shell variable called
 {\bf EXTRAS} in the {\bf h/386-linux.defs} file. This file
 gets included as part of the final system build of GCL.
 
-<<sockio-c>>=
+\begin{chunk}{sockio-c}
 ${MID}/sockio-c.c: ${IN}/sockio-c.c.pamphlet
 	@echo sl41 making ${MID}/sockio-c.c from ${IN}/sockio-c.c.pamphlet
-	@${TANGLE} sockio-c.c.pamphlet >${MID}/sockio-c.c
+	@${BOOKS}/tangle sockio-c.c.pamphlet >${MID}/sockio-c.c
 
 ${OUT}/sockio-c.o: ${MID}/sockio-c.c
 	@echo sl42 making ${OUT}/sockio-c.o from ${MID}/sockio-c.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/sockio-c.c )
 
-${DOCINT}/sockio-c.c.dvi: ${IN}/sockio-c.c.pamphlet 
-	@echo sl43 making ${DOCINT}/sockio-c.c.dvi from ${IN}/sockio-c.c.pamphlet
+${DOCINT}/sockio-c.c.pdf: ${IN}/sockio-c.c.pamphlet 
+	@echo sl43 making ${DOCINT}/sockio-c.c.pdf from ${IN}/sockio-c.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/sockio-c.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} sockio-c.c ; \
+	${EXTRACT} sockio-c.c.pamphlet ; \
 	rm -f ${DOCINT}/sockio-c.c.pamphlet ; \
 	rm -f ${DOCINT}/sockio-c.c.tex ; \
 	rm -f ${DOCINT}/sockio-c.c )
 
-${DOCMNT}/sockio-c.c.dvi: ${DOCINT}/sockio-c.c.dvi
-	@echo sl44 making ${DOCMNT}/sockio-c.c.dvi from ${DOCINT}/sockio-c.c.dvi
-	@cp ${DOCINT}/sockio-c.c.dvi ${DOCMNT}/sockio-c.c.dvi 
+${DOCMNT}/sockio-c.c.pdf: ${DOCINT}/sockio-c.c.pdf
+	@echo sl44 making ${DOCMNT}/sockio-c.c.pdf from ${DOCINT}/sockio-c.c.pdf
+	@cp ${DOCINT}/sockio-c.c.pdf ${DOCMNT}/sockio-c.c.pdf 
 
-@
+\end{chunk}
 \subsection{spadcolors.c \cite{11}}
-<<spadcolors>>=
+\begin{chunk}{spadcolors}
 ${MID}/spadcolors.c: ${IN}/spadcolors.c.pamphlet
 	@echo sl45 making ${MID}/spadcolors.c from ${IN}/spadcolors.c.pamphlet
-	@${TANGLE} spadcolors.c.pamphlet >${MID}/spadcolors.c
+	@${BOOKS}/tangle spadcolors.c.pamphlet >${MID}/spadcolors.c
 
 ${OUT}/spadcolors.o: ${MID}/spadcolors.c
 	@echo sl46 making ${OUT}/spadcolors.o from ${MID}/spadcolors.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/spadcolors.c )
 
-${DOCINT}/spadcolors.c.dvi: ${IN}/spadcolors.c.pamphlet 
-	@echo sl47 making ${DOCINT}/spadcolors.c.dvi from \
+${DOCINT}/spadcolors.c.pdf: ${IN}/spadcolors.c.pamphlet 
+	@echo sl47 making ${DOCINT}/spadcolors.c.pdf from \
           ${IN}/spadcolors.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/spadcolors.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} spadcolors.c ; \
+	${EXTRACT} spadcolors.c.pamphlet ; \
 	rm -f ${DOCINT}/spadcolors.c.pamphlet ; \
 	rm -f ${DOCINT}/spadcolors.c.tex ; \
 	rm -f ${DOCINT}/spadcolors.c )
 
-${DOCMNT}/spadcolors.c.dvi: ${DOCINT}/spadcolors.c.dvi
-	@echo sl48 making ${DOCMNT}/spadcolors.c.dvi from ${DOCINT}/spadcolors.c.dvi
-	@cp ${DOCINT}/spadcolors.c.dvi ${DOCMNT}/spadcolors.c.dvi 
+${DOCMNT}/spadcolors.c.pdf: ${DOCINT}/spadcolors.c.pdf
+	@echo sl48 making ${DOCMNT}/spadcolors.c.pdf from ${DOCINT}/spadcolors.c.pdf
+	@cp ${DOCINT}/spadcolors.c.pdf ${DOCMNT}/spadcolors.c.pdf
 
-@
+\end{chunk}
 \subsection{util.c \cite{12}}
-<<util>>=
+\begin{chunk}{util}
 ${MID}/util.c: ${IN}/util.c.pamphlet
 	@echo sl49 making ${MID}/util.c from ${IN}/util.c.pamphlet
-	@${TANGLE} util.c.pamphlet >${MID}/util.c
+	@${BOOKS}/tangle util.c.pamphlet >${MID}/util.c
 
 ${OUT}/util.o: ${MID}/util.c
 	@echo sl50 making ${OUT}/util.o from ${MID}/util.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/util.c )
 
-${DOCINT}/util.c.dvi: ${IN}/util.c.pamphlet 
-	@echo sl51 making ${DOCINT}/util.c.dvi from ${IN}/util.c.pamphlet
+${DOCINT}/util.c.pdf: ${IN}/util.c.pamphlet 
+	@echo sl51 making ${DOCINT}/util.c.pdf from ${IN}/util.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/util.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} util.c ; \
+	${EXTRACT} util.c.pamphlet ; \
 	rm -f ${DOCINT}/util.c.pamphlet ; \
 	rm -f ${DOCINT}/util.c.tex ; \
 	rm -f ${DOCINT}/util.c )
 
-${DOCMNT}/util.c.dvi: ${DOCINT}/util.c.dvi
-	@echo sl52 making ${DOCMNT}/util.c.dvi from ${DOCINT}/util.c.dvi
-	@cp ${DOCINT}/util.c.dvi ${DOCMNT}/util.c.dvi 
+${DOCMNT}/util.c.pdf: ${DOCINT}/util.c.pdf
+	@echo sl52 making ${DOCMNT}/util.c.pdf from ${DOCINT}/util.c.pdf
+	@cp ${DOCINT}/util.c.pdf ${DOCMNT}/util.c.pdf
 
-@
+\end{chunk}
 \subsection{wct.c \cite{13}}
-<<wct>>=
+\begin{chunk}{wct}
 ${MID}/wct.c: ${IN}/wct.c.pamphlet
 	@echo sl53 making ${MID}/wct.c from ${IN}/wct.c.pamphlet
-	@${TANGLE} wct.c.pamphlet >${MID}/wct.c
+	@${BOOKS}/tangle wct.c.pamphlet >${MID}/wct.c
 
 ${OUT}/wct.o: ${MID}/wct.c
 	@echo sl54 making ${OUT}/wct.o from ${MID}/wct.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/wct.c )
 
-${DOCINT}/wct.c.dvi: ${IN}/wct.c.pamphlet 
-	@echo sl55 making ${DOCINT}/wct.c.dvi from ${IN}/wct.c.pamphlet
+${DOCINT}/wct.c.pdf: ${IN}/wct.c.pamphlet 
+	@echo sl55 making ${DOCINT}/wct.c.pdf from ${IN}/wct.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/wct.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} wct.c ; \
+	${EXTRACT} wct.c.pamphlet ; \
 	rm -f ${DOCINT}/wct.c.pamphlet ; \
 	rm -f ${DOCINT}/wct.c.tex ; \
 	rm -f ${DOCINT}/wct.c )
 
-${DOCMNT}/wct.c.dvi: ${DOCINT}/wct.c.dvi
-	@echo sl56 making ${DOCMNT}/wct.c.dvi from ${DOCINT}/wct.c.dvi
-	@cp ${DOCINT}/wct.c.dvi ${DOCMNT}/wct.c.dvi 
+${DOCMNT}/wct.c.pdf: ${DOCINT}/wct.c.pdf
+	@echo sl56 making ${DOCMNT}/wct.c.pdf from ${DOCINT}/wct.c.pdf
+	@cp ${DOCINT}/wct.c.pdf ${DOCMNT}/wct.c.pdf
 
-@
+\end{chunk}
 \subsection{xdither.c \cite{14}}
-<<xdither>>=
+\begin{chunk}{xdither}
 ${MID}/xdither.c: ${IN}/xdither.c.pamphlet
 	@echo sl57 making ${MID}/xdither.c from ${IN}/xdither.c.pamphlet
-	@${TANGLE} xdither.c.pamphlet >${MID}/xdither.c
+	@${BOOKS}/tangle xdither.c.pamphlet >${MID}/xdither.c
 
 ${OUT}/xdither.o: ${MID}/xdither.c
 	@echo sl58 making ${OUT}/xdither.o from ${MID}/xdither.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/xdither.c )
 
-${DOCINT}/xdither.c.dvi: ${IN}/xdither.c.pamphlet 
-	@echo sl59 making ${DOCINT}/xdither.c.dvi from ${IN}/xdither.c.pamphlet
+${DOCINT}/xdither.c.pdf: ${IN}/xdither.c.pamphlet 
+	@echo sl59 making ${DOCINT}/xdither.c.pdf from ${IN}/xdither.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/xdither.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} xdither.c ; \
+	${EXTRACT} xdither.c.pamphlet ; \
 	rm -f ${DOCINT}/xdither.c.pamphlet ; \
 	rm -f ${DOCINT}/xdither.c.tex ; \
 	rm -f ${DOCINT}/xdither.c )
 
-${DOCMNT}/xdither.c.dvi: ${DOCINT}/xdither.c.dvi
-	@echo sl60 making ${DOCMNT}/xdither.c.dvi from ${DOCINT}/xdither.c.dvi
-	@cp ${DOCINT}/xdither.c.dvi ${DOCMNT}/xdither.c.dvi 
+${DOCMNT}/xdither.c.pdf: ${DOCINT}/xdither.c.pdf
+	@echo sl60 making ${DOCMNT}/xdither.c.pdf from ${DOCINT}/xdither.c.pdf
+	@cp ${DOCINT}/xdither.c.pdf ${DOCMNT}/xdither.c.pdf
 
-@
+\end{chunk}
 \subsection{xshade.c \cite{15}}
-<<xshade>>=
+\begin{chunk}{xshade}
 ${MID}/xshade.c: ${IN}/xshade.c.pamphlet
 	@echo sl61 making ${MID}/xshade.c from ${IN}/xshade.c.pamphlet
-	@${TANGLE} xshade.c.pamphlet >${MID}/xshade.c
+	@${BOOKS}/tangle xshade.c.pamphlet >${MID}/xshade.c
 
 ${OUT}/xshade.o: ${MID}/xshade.c
 	@echo sl62 making ${OUT}/xshade.o from ${MID}/xshade.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/xshade.c )
 
-${DOCINT}/xshade.c.dvi: ${IN}/xshade.c.pamphlet 
-	@echo sl63 making ${DOCINT}/xshade.c.dvi from ${IN}/xshade.c.pamphlet
+${DOCINT}/xshade.c.pdf: ${IN}/xshade.c.pamphlet 
+	@echo sl63 making ${DOCINT}/xshade.c.pdf from ${IN}/xshade.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/xshade.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} xshade.c ; \
+	${EXTRACT} xshade.c.pamphlet ; \
 	rm -f ${DOCINT}/xshade.c.pamphlet ; \
 	rm -f ${DOCINT}/xshade.c.tex ; \
 	rm -f ${DOCINT}/xshade.c )
 
-${DOCMNT}/xshade.c.dvi: ${DOCINT}/xshade.c.dvi
-	@echo sl64 making ${DOCMNT}/xshade.c.dvi from ${DOCINT}/xshade.c.dvi
-	@cp ${DOCINT}/xshade.c.dvi ${DOCMNT}/xshade.c.dvi 
+${DOCMNT}/xshade.c.pdf: ${DOCINT}/xshade.c.pdf
+	@echo sl64 making ${DOCMNT}/xshade.c.pdf from ${DOCINT}/xshade.c.pdf
+	@cp ${DOCINT}/xshade.c.pdf ${DOCMNT}/xshade.c.pdf
 
-@
+\end{chunk}
 \subsection{xspadfill.c \cite{16}}
-<<xspadfill>>=
+\begin{chunk}{xspadfill}
 ${MID}/xspadfill.c: ${IN}/xspadfill.c.pamphlet
 	@echo sl65 making ${MID}/xspadfill.c from ${IN}/xspadfill.c.pamphlet
-	@${TANGLE} xspadfill.c.pamphlet >${MID}/xspadfill.c
+	@${BOOKS}/tangle xspadfill.c.pamphlet >${MID}/xspadfill.c
 
 ${OUT}/xspadfill.o: ${MID}/xspadfill.c
 	@echo sl66 making ${OUT}/xspadfill.o from ${MID}/xspadfill.c
 	@( cd ${OUT} ; \
 	${CC} ${CCF} -c -I${INC} ${MID}/xspadfill.c )
 
-${DOCINT}/xspadfill.c.dvi: ${IN}/xspadfill.c.pamphlet 
-	@echo sl67 making ${DOCINT}/xspadfill.c.dvi from ${IN}/xspadfill.c.pamphlet
+${DOCINT}/xspadfill.c.pdf: ${IN}/xspadfill.c.pamphlet 
+	@echo sl67 making ${DOCINT}/xspadfill.c.pdf from ${IN}/xspadfill.c.pamphlet
 	@(cd ${DOCINT} ; \
 	cp ${IN}/xspadfill.c.pamphlet ${DOCINT} ; \
-	${DOCUMENT} ${NOISE} xspadfill.c ; \
+	${EXTRACT} xspadfill.c.pamphlet ; \
 	rm -f ${DOCINT}/xspadfill.c.pamphlet ; \
 	rm -f ${DOCINT}/xspadfill.c.tex ; \
 	rm -f ${DOCINT}/xspadfill.c )
 
-${DOCMNT}/xspadfill.c.dvi: ${DOCINT}/xspadfill.c.dvi
-	@echo sl68 making ${DOCMNT}/xspadfill.c.dvi from ${DOCINT}/xspadfill.c.dvi
-	@cp ${DOCINT}/xspadfill.c.dvi ${DOCMNT}/xspadfill.c.dvi 
+${DOCMNT}/xspadfill.c.pdf: ${DOCINT}/xspadfill.c.pdf
+	@echo sl68 making ${DOCMNT}/xspadfill.c.pdf from ${DOCINT}/xspadfill.c.pdf
+	@cp ${DOCINT}/xspadfill.c.pdf ${DOCMNT}/xspadfill.c.pdf
 
-@
+\end{chunk}
 \section{The document stanza}
-<<document>>=
+\begin{chunk}{document}
 document: ${DOCFILES}
 	@echo sl69 documenting ${IN}
 
-@
+\end{chunk}
 \section{The clean stanza}
-<<clean>>=
+\begin{chunk}{clean}
 clean:
 	@echo sl70 cleaning ${IN}
 	@rm -rf ${MID} ${OUT} ${DOCINT} ${DOCMNT}
-	@rm -f Makefile Makefile.dvi
+	@rm -f Makefile Makefile.pdf
 
-@
+\end{chunk}
 \subsection{Makefile documentation}
-<<Makefile.dvi>>=
-${DOCMNT}/Makefile.dvi: ${IN}/Makefile.dvi
-	@echo sl71 making ${DOCMNT}/Makefile.dvi from ${IN}/Makefile.dvi
-	@cp ${IN}/Makefile.dvi ${DOCMNT}/Makefile.dvi 
+\begin{chunk}{Makefile.pdf}
+${DOCMNT}/Makefile.pdf: ${IN}/Makefile.pdf
+	@echo sl71 making ${DOCMNT}/Makefile.pdf from ${IN}/Makefile.pdf
+	@cp ${IN}/Makefile.pdf ${DOCMNT}/Makefile.pdf
 
-@
-<<*>>=
-<<environment>>
+\end{chunk}
+\begin{chunk}{*}
+\getchunk{environment}
 
 all: announce ${OUT}/libspad.a ${OTHER} ${DOCFILES}
 	@echo sl72 finished making ${IN}
@@ -517,27 +520,27 @@ ${OUT}/libspad.a: ${AR}
 	ar ru ${OUT}/libspad.a ${AR} ; \
 	${RANLIB} ${OBJ}/${SYS}/lib/libspad.a )
 
-<<Makefile.dvi>>
-<<bsdsignal>>
-<<cfuns-c>>
-<<cursor>>
-<<edin>>
-<<fnctkey>>
-<<halloc>>
-<<hash>>
-<<openpty>>
-<<pixmap>>
-<<prt>>
-<<sockio-c>>
-<<spadcolors>>
-<<util>>
-<<wct>>
-<<xdither>>
-<<xshade>>
-<<xspadfill>>
-<<document>>
-<<clean>>
-@
+\getchunk{Makefile.pdf}
+\getchunk{bsdsignal}
+\getchunk{cfuns-c}
+\getchunk{cursor}
+\getchunk{edin}
+\getchunk{fnctkey}
+\getchunk{halloc}
+\getchunk{hash}
+\getchunk{openpty}
+\getchunk{pixmap}
+\getchunk{prt}
+\getchunk{sockio-c}
+\getchunk{spadcolors}
+\getchunk{util}
+\getchunk{wct}
+\getchunk{xdither}
+\getchunk{xshade}
+\getchunk{xspadfill}
+\getchunk{document}
+\getchunk{clean}
+\end{chunk}
 
 \eject
 \begin{thebibliography}{99}
diff --git a/src/lib/bsdsignal.c.pamphlet b/src/lib/bsdsignal.c.pamphlet
index f2d9ea1..056cb47 100644
--- a/src/lib/bsdsignal.c.pamphlet
+++ b/src/lib/bsdsignal.c.pamphlet
@@ -11,17 +11,20 @@
 \newpage
 \section{Executive Overview}
 \section{Signals}
-The system defines a set of signals that may be delivered to a process. Signal 
-delivery resembles the occurrence of a hardware interrupt: the signal is 
-normally blocked from further occurrence, the current process context is saved, 
-and a new one is built. A process may specify a {\sl handler} to which a signal 
-is delivered, or specify that a signal is to be {\sl ignored}. A process may 
-also specify that a default action is to be taken by the system when a signal 
-occurs. A signal may also be {\sl blocked}, in which case its delivery is 
-postponed until it is {\sl unblocked}. The action to be taken on delivery is 
-determined at the time of delivery. Normally, signal handlers execute on the 
-current stack of the process. This may be changed, on a per-handler basis, so 
-that signals are taken on a special {\sl signal stack}.
+
+The system defines a set of signals that may be delivered to a
+process. Signal delivery resembles the occurrence of a hardware
+interrupt: the signal is normally blocked from further occurrence, the
+current process context is saved, and a new one is built. A process
+may specify a {\sl handler} to which a signal is delivered, or specify
+that a signal is to be {\sl ignored}. A process may also specify that
+a default action is to be taken by the system when a signal occurs. A
+signal may also be {\sl blocked}, in which case its delivery is
+postponed until it is {\sl unblocked}. The action to be taken on
+delivery is determined at the time of delivery. Normally, signal
+handlers execute on the current stack of the process. This may be
+changed, on a per-handler basis, so that signals are taken on a
+special {\sl signal stack}.
 
 Signal routines normally execute with the signal that caused their invocation 
 {\sl blocked}, but other signals may yet occur. A global {\sl signal mask} 
@@ -30,45 +33,48 @@ The signal mask for a process is initialized from that of its parent
 (normally empty). It may be changed with a {\bf sigprocmask(2)} call, or 
 when a signal is delivered to the process.
 
-When a signal condition arises for a process, the signal is added to a set of 
-signals pending for the process. If the signal is not currently {\sl blocked} 
-by the process then it is delivered to the process. Signals may be delivered 
-any time a process enters the operating system (e.g., during a system call, 
-page fault or trap, or clock interrupt). If muliple signals are ready to be 
-delivered at the same time, any signals that could be caused by traps are 
-delivered first. Additional signals may be processed at the same time, with 
-each appearing to interrupt the handlers for the previous signals before 
-their first instructions. The set of pending signals is retuned by the 
-{\bf sigpending(2)} system call. When a caught signal is delivered, the current 
-state of the process is saved, a new signal mask is calculated (as described 
-below), and the signal handler is invoked. The call to the handler is arranged 
-so that if the signal handling routine returns normally the process will resume 
-execution in the context from before the signal's delivery. If the process 
-wishes to resume in a different context, then it must arrange to restore 
-the previous context itself.
-
-When a signal is delivered to a proces a new signal mask is installed for the 
-duration of the process's signal handler (or until a {\bf sigprocmask(2)} 
-system call is made). This mask is formed by taking the union of the current 
-signal mask set, the signal to be delivered, and the signal mask associated 
-with the handler to be invoked.
-
-The {\bf sigaction()} system call assigns an action for a signal specified by 
-{\sl sig}. If {\sl act} is non-zero, it specifies an action (SIG\_DFL, SIG\_IGN, 
-or a handler routine) and mask to be used when delivering the specified signal. 
-If {\sl oact} is non-zero, the previous handling information for the signal is 
-returned to the user.
-
-Once a signal handler is installed, it normally  remains installed until another 
-{\bf sigaction()} system call is made, or an {\sl execve(2)} is performed. A 
-signal-specific default action may be reset by setting {\sl sa\_handler} to 
-SIG\_DFL. The defaults are process termination, possibly with core dump; 
-no action; stopping the process; or continuing the process. See the signal 
-list below for each signal's default action. If {\sl sa\_handler} is SIG\_DFL, 
-the default action for the signal is to discard the signal, and if a signal 
-is pending, the pending signal is discarded even if the signal is masked. If 
-{\sl sa\_handler} is set to SIG\_IGN current and pending instances of the signal 
-are ignored and discarded.
+When a signal condition arises for a process, the signal is added to a
+set of signals pending for the process. If the signal is not currently
+{\sl blocked} by the process then it is delivered to the
+process. Signals may be delivered any time a process enters the
+operating system (e.g., during a system call, page fault or trap, or
+clock interrupt). If muliple signals are ready to be delivered at the
+same time, any signals that could be caused by traps are delivered
+first. Additional signals may be processed at the same time, with each
+appearing to interrupt the handlers for the previous signals before
+their first instructions. The set of pending signals is retuned by the
+{\bf sigpending(2)} system call. When a caught signal is delivered,
+the current state of the process is saved, a new signal mask is
+calculated (as described below), and the signal handler is
+invoked. The call to the handler is arranged so that if the signal
+handling routine returns normally the process will resume execution in
+the context from before the signal's delivery. If the process wishes
+to resume in a different context, then it must arrange to restore the
+previous context itself.
+
+When a signal is delivered to a proces a new signal mask is installed
+for the duration of the process's signal handler (or until a {\bf
+sigprocmask(2)} system call is made). This mask is formed by taking
+the union of the current signal mask set, the signal to be delivered,
+and the signal mask associated with the handler to be invoked.
+
+The {\bf sigaction()} system call assigns an action for a signal
+specified by {\sl sig}. If {\sl act} is non-zero, it specifies an
+action (SIG\_DFL, SIG\_IGN, or a handler routine) and mask to be used
+when delivering the specified signal.  If {\sl oact} is non-zero, the
+previous handling information for the signal is returned to the user.
+
+Once a signal handler is installed, it normally remains installed
+until another {\bf sigaction()} system call is made, or an {\sl
+execve(2)} is performed. A signal-specific default action may be reset
+by setting {\sl sa\_handler} to SIG\_DFL. The defaults are process
+termination, possibly with core dump; no action; stopping the process;
+or continuing the process. See the signal list below for each signal's
+default action. If {\sl sa\_handler} is SIG\_DFL, the default action
+for the signal is to discard the signal, and if a signal is pending,
+the pending signal is discarded even if the signal is masked. If {\sl
+sa\_handler} is set to SIG\_IGN current and pending instances of the
+signal are ignored and discarded.
 
 Options may be specified by setting {\sl sa\_flags}. 
 The meaning of the various bits is as follows:
@@ -207,19 +213,20 @@ is not a valid part of the process address space
 for SIGKILL or SIGSTOP
 \end{itemize}
 \section{MAC OSX and BSD platform change}
-<<*>>=
-<<license>>
+\begin{chunk}{*}
 
 #include "bsdsignal.h"
 
-@
+\end{chunk}
+
 The MACOSX platform is broken because no matter what you do it seems to
 include files from [[/usr/include/sys]] ahead of [[/usr/include]]. On linux
 systems these files include themselves which causes an infinite regression
 of includes that fails. GCC gracefully steps over that problem but the
 build fails anyway. On MACOSX the [[/usr/include/sys]] versions 
 of files are badly broken with respect to the [[/usr/include]] versions.
-<<*>>=
+
+\begin{chunk}{*}
 #if defined(MACOSXplatform)
 #include "/usr/include/signal.h"
 #else
@@ -237,11 +244,13 @@ bsdSignal(int sig,SignalHandlerFunc action,int restartSystemCall)
   struct sigaction in,out;
   in.sa_handler = action;
   /* handler is reinstalled - calls are restarted if restartSystemCall */
-@
+\end{chunk}
+
 We needed to change [[SIGCLD]] to [[SIGCHLD]] for the [[MAC OSX]] platform
 and we need to create a new platform variable. This change is made to 
 propogate that platform variable.
-<<*>>=
+
+\begin{chunk}{*}
 #if defined(LINUXplatform)
  if(restartSystemCall) in.sa_flags = SA_RESTART;
   else in.sa_flags = 0;
@@ -283,10 +292,9 @@ propogate that platform variable.
 
 }
 
-
-@
+\end{chunk}
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -319,7 +327,7 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
+\end{verbatim}
 \newpage
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/cfuns-c.c.pamphlet b/src/lib/cfuns-c.c.pamphlet
index 92a4d77..486fe09 100644
--- a/src/lib/cfuns-c.c.pamphlet
+++ b/src/lib/cfuns-c.c.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,19 +43,21 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
 
 #include <stdio.h>
-@
+\end{chunk}
+
 The MACOSX platform is broken because no matter what you do it seems to
 include files from [[/usr/include/sys]] ahead of [[/usr/include]]. On linux
 systems these files include themselves which causes an infinite regression
 of includes that fails. GCC gracefully steps over that problem but the
 build fails anyway. On MACOSX the [[/usr/include/sys]] versions 
 of files are badly broken with respect to the [[/usr/include]] versions.
-<<*>>=
+
+\begin{chunk}{*}
+
 #if defined(MACOSXplatform)
 #include "/usr/include/unistd.h"
 #else
@@ -71,10 +73,11 @@ of files are badly broken with respect to the [[/usr/include]] versions.
 
 #include "cfuns-c.h1"
 
-@
+\end{chunk}
 The {\tt addtopath} function is used in {\tt interp/i-toplev.boot} 
 as part of the {\tt start} function.
-<<*>>=
+\begin{chunk}{*}
+
 int addtopath(char *dir) {
     char *path, *newpath;
     path = getenv("PATH");
@@ -88,20 +91,24 @@ int addtopath(char *dir) {
     return putenv(newpath);
 }
 
-@
+\end{chunk}
+
 Test whether the path is the name of a directory.  
 Returns 1 if so, 0 if not, -1 if it doesn't exist.
-<<*>>=
+
+\begin{chunk}{*}
 int directoryp(char *path) {
     struct stat buf;
     int code = stat(path, &buf);
     return(code == -1 ? -1 : S_ISDIR(buf.st_mode));
 }
 
-@
+\end{chunk}
+
 This function is only used internal to this file.
 Axiom lisp code does not depend on it.
-<<*>>=
+
+\begin{chunk}{*}
 int make_path_from_file(char *s, char *t) {
     char *pos = "";
     char *c;
@@ -120,11 +127,13 @@ int make_path_from_file(char *s, char *t) {
     return 1;
 }
 
-@
+\end{chunk}
+
 This function is used in {\tt interp/fname.lisp} to support the
 {\tt myWriteable?} function, which is called by {\tt fnameWriteable?}.
 It supports a test called {\tt writeable?} in {\tt algebra/fname.spad}. 
-<<*>>=
+
+\begin{chunk}{*}
 int writeablep(char *path) {
     struct stat buf;
     char newpath[100];
@@ -160,7 +169,8 @@ int writeablep(char *path) {
     }
 }
 
-@
+\end{chunk}
+
 This function does not appear to be used anywhere
 \begin{verbatim}
 int CLgetpid(void) {
@@ -219,6 +229,7 @@ int copyEnvValue(char *varName, char *buffer) {
     strcpy(buffer, s);
     return strlen(s);
 }
+
 \end{verbatim}
 \eject
 \begin{thebibliography}{99}
diff --git a/src/lib/cursor.c.pamphlet b/src/lib/cursor.c.pamphlet
index 16941b5..16d66ee 100644
--- a/src/lib/cursor.c.pamphlet
+++ b/src/lib/cursor.c.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,9 +43,8 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
 
 #include <stdlib.h>
 
@@ -151,11 +150,7 @@ Cursor_shape(int shape)
 }
 #endif
 
-
-
-
-
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/edin.c.pamphlet b/src/lib/edin.c.pamphlet
index 2d4c07f..54db72d 100644
--- a/src/lib/edin.c.pamphlet
+++ b/src/lib/edin.c.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,21 +43,22 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
 
 /* #define debug 1 */
 
 #include <stdlib.h>
-@
+\end{chunk}
+
 The MACOSX platform is broken because no matter what you do it seems to
 include files from [[/usr/include/sys]] ahead of [[/usr/include]]. On linux
 systems these files include themselves which causes an infinite regression
 of includes that fails. GCC gracefully steps over that problem but the
 build fails anyway. On MACOSX the [[/usr/include/sys]] versions 
 of files are badly broken with respect to the [[/usr/include]] versions.
-<<*>>=
+
+\begin{chunk}{*}
 #if defined(MACOSXplatform)
 #include "/usr/include/unistd.h"
 #else
@@ -962,7 +963,7 @@ send_buff_to_child(int chann)
   return;
 }
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/emupty.c.pamphlet b/src/lib/emupty.c.pamphlet
index 95f707c..1213222 100644
--- a/src/lib/emupty.c.pamphlet
+++ b/src/lib/emupty.c.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,10 +43,8 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
-
+\end{verbatim}
+\begin{chunk}{*}
 
 /*
   Here is some code taken from Nick Simicich. It takes an escape sequence
@@ -233,7 +231,7 @@ static int _ThatsAll_(int x)
 {
 return x;
 }
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/fnct-key.c.pamphlet b/src/lib/fnct-key.c.pamphlet
index ce69114..2618130 100644
--- a/src/lib/fnct-key.c.pamphlet
+++ b/src/lib/fnct-key.c.pamphlet
@@ -14,15 +14,15 @@ On the MAC OSX the signal [[SIGCLD]] has been renamed to [[SIGCHLD]].
 In order to handle this change we need to ensure that the platform
 variable is set properly and that the platform variable is changed
 everywhere.
-<<mac os signal rename>>=
+\begin{chunk}{mac os signal rename}
 #if defined(MACOSXplatform) || defined(BSDplatform)
         bsdSignal(SIGCHLD, null_fnct,RestartSystemCalls);
 #else
         bsdSignal(SIGCLD, null_fnct,RestartSystemCalls);
 #endif
-@
+\end{chunk}
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -55,18 +55,16 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
+\end{verbatim}
 
-@
 The MACOSX platform is broken because no matter what you do it seems to
 include files from [[/usr/include/sys]] ahead of [[/usr/include]]. On linux
 systems these files include themselves which causes an infinite regression
 of includes that fails. GCC gracefully steps over that problem but the
 build fails anyway. On MACOSX the [[/usr/include/sys]] versions 
 of files are badly broken with respect to the [[/usr/include]] versions.
-<<*>>=
+
+\begin{chunk}{*}
 #if defined(MACOSXplatform)
 #include "/usr/include/unistd.h"
 #else
@@ -344,7 +342,7 @@ handle_function_key(int key,int  chann)
                 close(fd);
             }
         }
-<<mac os signal rename>>
+\getchunk{mac os signal rename}
         switch (id = fork()) {
           case -1:
             perror("Special key");
@@ -385,7 +383,7 @@ handle_function_key(int key,int  chann)
     return;
 
 }
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/halloc.c.pamphlet b/src/lib/halloc.c.pamphlet
index 4efcd0b..1f7c670 100644
--- a/src/lib/halloc.c.pamphlet
+++ b/src/lib/halloc.c.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,10 +43,8 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
-
+\end{verbatim}
+\begin{chunk}{*}
 
 /* memory allocation used by HyperDoc and addfile */
 
@@ -70,7 +68,7 @@ halloc(int bytes,char * msg)
     }
     return result;
 }
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/hash.c.pamphlet b/src/lib/hash.c.pamphlet
index c4800bb..baaad0e 100644
--- a/src/lib/hash.c.pamphlet
+++ b/src/lib/hash.c.pamphlet
@@ -9,7 +9,7 @@
 \eject
 \tableofcontents
 \eject
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,9 +43,8 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
 
 #define _HASH_C
 #include "debug.h"
@@ -231,7 +230,7 @@ alloc_string(char *str)
     strcpy(result,str);
     return (result);
 }
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/openpty.c.pamphlet b/src/lib/openpty.c.pamphlet
index 4362b3a..61f46ce 100644
--- a/src/lib/openpty.c.pamphlet
+++ b/src/lib/openpty.c.pamphlet
@@ -72,7 +72,7 @@ preallocate
 a lot of device nodes./cite{1}
 
 \section{include files}
-<<*>>=
+\begin{chunk}{*}
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -86,9 +86,9 @@ a lot of device nodes./cite{1}
 
 #include "openpty.h1"
 
-@
+\end{chunk}
 \section{{\tt openpty}}
-<<*>>=
+\begin{chunk}{*}
 
 int  
 ptyopen(int *controller,int * server, char *controllerPath,char * serverPath)
@@ -139,7 +139,8 @@ ptyopen(int *controller,int * server, char *controllerPath,char * serverPath)
   return(fdm);
 #endif
 
-@
+\end{chunk}
+
 Note that since we have no other information we are adding the
 MACOSXplatform variable to the list everywhere we find
 LINUXplatform. This may not be correct but we have no way to know
@@ -147,7 +148,7 @@ yet. We have also added the BSDplatform variable.  MAC OSX is some
 variant of BSD. These should probably be merged but we cannot yet
 prove that.
 
-<<*>>=
+\begin{chunk}{*}
 #if defined(SUN4OS5platform) ||\
  defined(ALPHAplatform) ||\
  defined(HP10platform) ||\
@@ -208,14 +209,16 @@ extern char* ptsname(int);
 #endif
 }
 
-@
+\end{chunk}
+
 Prior to using the Unix 98 pty naming scheme the naming scheme
 used 16 ptyp/ttyp names, ttyp0-ttypF (where F is a hex number).
 Later this was extended to ttyq0-ttyqF and so on, eventually
 wrapping around to ttya0-ttyaF. Linux also allows larger numbers
 such as ttypNNN.\cite{2}
+
 \section{{\tt makeNextPtyNames}}
-<<*>>=
+\begin{chunk}{*}
 
 void 
 makeNextPtyNames(char *cont,char * serv)
@@ -226,9 +229,11 @@ makeNextPtyNames(char *cont,char * serv)
 	sprintf(serv, "/dev/ttyp%02x", channelNo);
 	channelNo++;
 #endif
-@
+\end{chunk}
+
 See the note above about the MACOS platform change.
-<<*>>=
+
+\begin{chunk}{*}
 #if defined(SUNplatform) ||\
  defined(HP9platform) ||\
  defined(LINUXplatform) ||\
@@ -249,9 +254,10 @@ See the note above about the MACOS platform change.
 #endif
 }
 
-@
+\end{chunk}
+
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -284,7 +290,7 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
+\end{verbatim}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} {\tt ptmx(4)} - Linux man page\\
diff --git a/src/lib/pixmap.c.pamphlet b/src/lib/pixmap.c.pamphlet
index 7bb4302..3000d95 100644
--- a/src/lib/pixmap.c.pamphlet
+++ b/src/lib/pixmap.c.pamphlet
@@ -12,15 +12,15 @@
 \section{MAC OSX zopen redefinition}
 On the [[MAC OSX]] platform they defined [[zopen]]. Since the function
 is only used in this file we simply rename it to [[zzopen]].
-<<mac zopen redefinition 1>>=
+\begin{chunk}{mac zopen redefinition 1}
 FILE *
 zzopen(char *file,char * mode)
-@
-<<mac zopen redefinition 2>>=
+\end{chunk}
+\begin{chunk}{mac zopen redefinition 2}
     file = zzopen(filename, "r");
-@
+\end{chunk}
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -53,10 +53,8 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
-
+\end{verbatim}
+\begin{chunk}{*}
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -92,7 +90,7 @@ file_exists(char *file)
     return 0;
 }
 
-<<mac zopen redefinition 1>>
+\getchunk{mac zopen redefinition 1}
 {
     char com[512], zfile[512];
 
@@ -217,7 +215,7 @@ read_pixmap_file(Display *display, int screen, char *filename,
     if ((num_colors = makeColors(display, screen, &cmap, &spadColors, &ts)) < 0) {
         return(-1);
     }
-<<mac zopen redefinition 2>>
+\getchunk{mac zopen redefinition 2}
     if (file == NULL) {
         printf("couldn't open %s\n", filename);
         return BitmapOpenFailed;
@@ -340,10 +338,7 @@ write_pixmap_file(Display *dsp, int scr, char  *fn,
 
 
 #endif
-
-
-
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/prt.c.pamphlet b/src/lib/prt.c.pamphlet
index fcaca7f..23faacf 100644
--- a/src/lib/prt.c.pamphlet
+++ b/src/lib/prt.c.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,9 +43,8 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
 
 #include <string.h>
 #include <stdio.h>
@@ -420,7 +419,7 @@ back_over_current_char(void)
     return;
 }
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/sockio-c.c.pamphlet b/src/lib/sockio-c.c.pamphlet
index 698adf8..6841293 100644
--- a/src/lib/sockio-c.c.pamphlet
+++ b/src/lib/sockio-c.c.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,23 +43,24 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
 
 /* socket i/o primitives */
 
 
 #include <stdio.h>
 #include <stdlib.h>
-@
+\end{chunk}
+
 The MACOSX platform is broken because no matter what you do it seems to
 include files from [[/usr/include/sys]] ahead of [[/usr/include]]. On linux
 systems these files include themselves which causes an infinite regression
 of includes that fails. GCC gracefully steps over that problem but the
 build fails anyway. On MACOSX the [[/usr/include/sys]] versions 
 of files are badly broken with respect to the [[/usr/include]] versions.
-<<*>>=
+
+\begin{chunk}{*}
 #if defined(MACOSXplatform)
 #include "/usr/include/unistd.h"
 #else
@@ -1072,7 +1073,7 @@ NANQ(void)
   }
   return nanq.f;
 }
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/spadcolors.c.pamphlet b/src/lib/spadcolors.c.pamphlet
index c4cf82a..6e5e12c 100644
--- a/src/lib/spadcolors.c.pamphlet
+++ b/src/lib/spadcolors.c.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,9 +43,8 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
 
 #include "spadcolors.h"
 
@@ -517,10 +516,12 @@ FreePixels(Display *dsply, Colormap colorMap, int num)
 
 int
 AllocCells(Display *dsply, Colormap colorMap, int smoothHue)
-@
+\end{chunk}
+
 This routine used to have the following code block. However this
 code block makes no sense. To see why you need to know that an
 XColor object looks like:
+
 \begin{verbatim}
 /*
  * Data structure used by color operations
@@ -576,7 +577,7 @@ it a value. I've rewritten that code.
     }
 }
 \end{verbatim}
-<<*>>=
+\begin{chunk}{*}
 {
     unsigned long plane_masks[1];
     int i, count;
@@ -601,10 +602,12 @@ it a value. I've rewritten that code.
         fprintf(stderr,"%d\t%d\t%d\n"
                 ,xcolor.red,xcolor.green,xcolor.blue);
         */
-@
+\end{chunk}
+
 Here I've modified the code to actually as for the pixel (colormap index) that
 most closely matches our requested RGB values.
-<<*>>=
+
+\begin{chunk}{*}
         if (XAllocColor(dsply, colorMap, &xcolor)) { 
             pixels[count] = xcolor.pixel;
             count++;
@@ -624,7 +627,7 @@ most closely matches our requested RGB values.
         return (0);
     }
 }
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/util.c.pamphlet b/src/lib/util.c.pamphlet
index f1559ff..d6b6522 100644
--- a/src/lib/util.c.pamphlet
+++ b/src/lib/util.c.pamphlet
@@ -9,19 +9,19 @@
 \eject
 \tableofcontents
 \newpage
-<<*>>=
-<<license>>
-
+\begin{chunk}{*}
 
 #include <stdlib.h>
-@
+\end{chunk}
+
 The MACOSX platform is broken because no matter what you do it seems to
 include files from [[/usr/include/sys]] ahead of [[/usr/include]]. On linux
 systems these files include themselves which causes an infinite regression
 of includes that fails. GCC gracefully steps over that problem but the
 build fails anyway. On MACOSX the [[/usr/include/sys]] versions 
 of files are badly broken with respect to the [[/usr/include]] versions.
-<<*>>=
+
+\begin{chunk}{*}
 #if defined(MACOSXplatform)
 #include "/usr/include/unistd.h"
 #else
@@ -127,9 +127,9 @@ getWindowSizeXY(Display *display,Window w)
   size.y = (short) windowAttrib.height;
   return (size);
 }
-@
+\end{chunk}
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -162,7 +162,7 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
+\end{verbatim}
 \newpage
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/wct.c.pamphlet b/src/lib/wct.c.pamphlet
index 65ac8d5..b88f880 100644
--- a/src/lib/wct.c.pamphlet
+++ b/src/lib/wct.c.pamphlet
@@ -9,8 +9,8 @@
 \eject
 \tableofcontents
 \newpage
-<<*>>=
-<<license>>
+\begin{chunk}{*}
+
 /*
  * Word completion.
  *
@@ -23,14 +23,16 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-@
+\end{chunk}
+
 The MACOSX platform is broken because no matter what you do it seems to
 include files from [[/usr/include/sys]] ahead of [[/usr/include]]. On linux
 systems these files include themselves which causes an infinite regression
 of includes that fails. GCC gracefully steps over that problem but the
 build fails anyway. On MACOSX the [[/usr/include/sys]] versions 
 of files are badly broken with respect to the [[/usr/include]] versions.
-<<*>>=
+
+\begin{chunk}{*}
 #if defined(MACOSXplatform)
 #include "/usr/include/unistd.h"
 #else
@@ -724,9 +726,9 @@ find_wct(void)
 
 
 }
-@
+\end{chunk}
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -759,7 +761,7 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
+\end{verbatim}
 \newpage
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/xdither.c.pamphlet b/src/lib/xdither.c.pamphlet
index 911d72c..d78cec0 100644
--- a/src/lib/xdither.c.pamphlet
+++ b/src/lib/xdither.c.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,9 +43,9 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
+
 #ifndef MSYSplatform
 
 #include <stdio.h>
@@ -244,7 +244,7 @@ XDitherArcs(Display *display,Drawable  drawable, GC gc, XArc *arcs,int narcs)
     XFillArcs(display, drawable, gc, arcs, narcs);
 }
 #endif /* MSYSplatform */
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/xshade.c.pamphlet b/src/lib/xshade.c.pamphlet
index d3924a5..bc77646 100644
--- a/src/lib/xshade.c.pamphlet
+++ b/src/lib/xshade.c.pamphlet
@@ -10,7 +10,7 @@
 \tableofcontents
 \eject
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -43,9 +43,9 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
+
 #ifndef MSYSplatform
 
 #include <stdio.h>
@@ -226,7 +226,7 @@ XShadeArcs(Display *display, Drawable drawable, XArc *arcs, int narcs)
 
 #endif /* MSYSplatform */
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/lib/xspadfill.c.pamphlet b/src/lib/xspadfill.c.pamphlet
index e610b56..41e9e0f 100644
--- a/src/lib/xspadfill.c.pamphlet
+++ b/src/lib/xspadfill.c.pamphlet
@@ -24,7 +24,7 @@ job of Initializing the dithering routines, and getting the colors all
 into place.
 
 \section{License}
-<<license>>=
+\begin{verbatim}
 /*
 Copyright (c) 1991-2002, The Numerical ALgorithms Group Ltd.
 All rights reserved.
@@ -57,9 +57,8 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
-@
-<<*>>=
-<<license>>
+\end{verbatim}
+\begin{chunk}{*}
 
 #ifndef MSYSplatform
 
@@ -313,7 +312,7 @@ XSpadFillArcs(Display *dsply, Drawable drawable, XArc * arcs, int narcs,
 
 #endif /* MSYSplatform */
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/scripts/Makefile.pamphlet b/src/scripts/Makefile.pamphlet
index 94229df..da2de1b 100644
--- a/src/scripts/Makefile.pamphlet
+++ b/src/scripts/Makefile.pamphlet
@@ -13,7 +13,7 @@
 This Makefile checks to make sure that the command line scripts
 exist in the bin subdirectory. We depend on the ``document'' 
 script to exist and prevent duplicate copying.
-<<*>>=
+\begin{chunk}{*}
 OUT=${MNT}/${SYS}/bin
 OUT1=${MNT}/${SYS}/lib
 
@@ -39,7 +39,7 @@ ${OUT1}/SPADEDIT:
 clean:
 	@echo 2 cleaning ${SRC}/scripts
 
-@
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/share/Makefile.pamphlet b/src/share/Makefile.pamphlet
index fa9f731..df6d841 100644
--- a/src/share/Makefile.pamphlet
+++ b/src/share/Makefile.pamphlet
@@ -15,13 +15,13 @@ The [[command.list]] file contains command completion strings used by
 the [[clef]] command line editor function. In the NAG version this 
 lived in the share subdirectory but the open source version moves it
 back to the [[lib]] directory where it originally lived.
-<<command.list>>=
+\begin{chunk}{command.list}
 ${LIB}/command.list: ${IN}/algebra/command.list
 	@ echo ssh01 making ${LIB}/command.list from ${IN}/algebra/command.list
 	@ cp ${IN}/algebra/command.list ${LIB}/command.list
 
-@
-<<*>>=
+\end{chunk}
+\begin{chunk}{*}
 IN=${SRC}/share
 LIB=${MNT}/${SYS}/lib
 
@@ -38,8 +38,8 @@ announce:
 clean:
 	@echo ssh3 cleaning ${SRC}/share
 
-<<command.list>>
-@
+\getchunk{command.list}
+\end{chunk}
 \eject
 \begin{thebibliography}{99}
 \bibitem{1} nothing
diff --git a/src/sman/Makefile.pamphlet b/src/sman/Makefile.pamphlet
deleted file mode 100644
index 40f0018..0000000
--- a/src/sman/Makefile.pamphlet
+++ /dev/null
@@ -1,157 +0,0 @@
-\documentclass{article}
-\usepackage{axiom}
-\begin{document}
-\title{\$SPAD/src/sman Makefile}
-\author{Timothy Daly}
-\maketitle
-\begin{abstract}
-\end{abstract}
-\eject
-\tableofcontents
-\eject
-\section{Environment variables}
-<<environment>>=
-# this is where we are compiling from
-IN=     ${SRC}/sman
-
-# this is the intermediate place 
-MID=    ${INT}/sman
-
-# this is the intermediate place 
-MIDOBJ=    ${OBJ}/${SYS}/sman
-
-# this is where to put the various commands
-OUT=	${MNT}/${SYS}/bin
-OUTLIB=	${MNT}/${SYS}/lib
-
-# this is where the include files live
-INC=    ${SRC}/include
-
-# this is where we hid the libspad library
-LIB=	${OBJ}/${SYS}/lib
-
-# this is where the documentation ends up
-DOC=    ${MNT}/${SYS}/doc
-CFLAGS=	${CCF} 
-LDFLAGS= -L${LIB} -lspad ${LDF}
-
-DOCFILES=${DOC}/bookvol6.dvi
-SMANOBJS= ${LIB}/libspad.a
-
-@
-\section{The axiom command}
-<<axiomcmd>>=
-${OUT}/axiom: ${IN}/bookvol6.pamphlet
-	@echo ss01 making ${OUT}/axiom from ${IN}/bookvol6.pamphlet
-	@ (cd ${OUT} ; \
-           ${TANGLE} -R"axiomcmd" ${IN}/bookvol6.pamphlet >axiom )
-	@chmod +x ${OUT}/axiom
-	@ cp ${OUT}/axiom ${MID}
-
-@
-\section{session}
-<<session>>=
-${OUTLIB}/session: ${SMANOBJS} ${MIDOBJ}/session.o
-	@ echo ss02 linking session
-	@ ${CC} -o ${OUTLIB}/session ${MIDOBJ}/session.o ${SMANOBJS} 
-
-${MID}/session.c: ${IN}/bookvol6.pamphlet
-	@ echo ss03 making ${MID}/session.c from ${IN}/bookvol6.pamphlet
-	@ (cd ${MID} ; \
-          ${TANGLE} -R"session" ${IN}/bookvol6.pamphlet >session.c )
-
-${MIDOBJ}/session.o: ${MID}/session.c ${INC}/session.h1
-	@ echo ss04 making ${MIDOBJ}/session.o from ${MID}/session.c
-	@ ( cd ${MIDOBJ} ; ${CC} -c ${CFLAGS} ${MID}/session.c -I${INC} )
-
-@
-\section{nagman}
-Note that we do not build the nagman component as we do not have the
-necessary code (for instance, [[callnag]]).
-<<nagman>>=
-${OUT}/nagman:	${SMANOBJS} ${MIDOBJ}/nagman.o
-	@ echo ss05 linking nagman
-	@ ${CC} -o ${OUT}/nagman ${MIDOBJ}/nagman.o ${SMANOBJS} 
-
-${MID}/nagman.c: ${IN}/bookvol6.pamphlet
-	@ echo ss06 making ${MID}/nagman.c from ${IN}/bookvol6.pamphlet
-	@ (cd ${MID} ; \
-           ${TANGLE} -R"nagman" ${IN}/bookvol6.pamphlet >nagman.c )
-
-${MIDOBJ}/nagman.o: ${MID}/nagman.c ${INC}/nagman.h1
-	@ echo ss07 making ${MIDOBJ}/nagman.o from ${MID}/nagman.c
-	@ ( cd ${MIDOBJ} ; ${CC} -c ${CFLAGS} ${MID}/nagman.c -I${INC} )
-
-@
-\section{spadclient}
-<<spadclient>>=
-${OUTLIB}/spadclient: ${SMANOBJS} ${MIDOBJ}/spadclient.o
-	@ echo ss08 linking spadclient
-	@ ${CC} -o ${OUTLIB}/spadclient ${MIDOBJ}/spadclient.o  ${SMANOBJS} 
-
-${MID}/spadclient.c: ${IN}/bookvol6.pamphlet
-	@ echo ss09 making ${MID}/spadclient.c from ${IN}/bookvol6.pamphlet
-	@ (cd ${MID} ; \
-           ${TANGLE} -R"spadclient" ${IN}/bookvol6.pamphlet >spadclient.c )
-
-${MIDOBJ}/spadclient.o: ${MID}/spadclient.c ${INC}/spadclient.h1
-	@ echo ss10 making ${MIDOBJ}/spadclient.o from ${MID}/spadclient.c
-	@ ( cd ${MIDOBJ} ; ${CC} -c ${CFLAGS} ${MID}/spadclient.c -I${INC} )
-
-@
-\section{sman}
-<<sman>>=
-${OUT}/sman: ${SMANOBJS} ${MIDOBJ}/sman.o
-	@ echo ss11 linking sman
-	@ ${CC} -o ${OUT}/sman ${MIDOBJ}/sman.o ${SMANOBJS} 
-
-${MID}/sman.h: ${IN}/bookvol6.pamphlet
-	@ echo ss12 making ${MID}/sman.h from ${IN}/bookvol6.pamphlet
-	@ (cd ${MID} ; \
-           ${TANGLE} -R"sman.h" ${IN}/bookvol6.pamphlet >sman.h )
-
-${MID}/sman.c: ${MID}/sman.h ${IN}/bookvol6.pamphlet
-	@ echo ss13 making ${MID}/sman.c from ${IN}/bookvol6.pamphlet
-	@ (cd ${MID} ; \
-           ${TANGLE} -R"sman" ${IN}/bookvol6.pamphlet >sman.c )
-
-${MIDOBJ}/sman.o: ${MID}/sman.c ${INC}/sman.h1
-	@ echo ss14 making ${MIDOBJ}/sman.o from ${MID}/sman.c
-	@ ( cd ${MIDOBJ} ; ${CC} -I${INC} -I${MID} -c ${CFLAGS} ${MID}/sman.c )
-
-${DOC}/bookvol6.dvi: ${IN}/bookvol6.pamphlet 
-	@ echo ss15 making ${DOC}/bookvol6.dvi from ${IN}/bookvol6.pamphlet
-	@ (cd ${DOC} ; \
-	cp ${IN}/bookvol6.pamphlet ${DOC} ; \
-	${DOCUMENT} ${NOISE} bookvol6 ; \
-	rm -f ${DOC}/bookvol6.pamphlet ; \
-	rm -f ${DOC}/bookvol6.idx ; \
-	rm -f ${DOC}/bookvol6.tex ; \
-	rm -f ${DOC}/bookvol6 )
-
-@
-<<*>>=
-<<environment>>
-all:	announce ${OUTLIB}/session ${OUTLIB}/spadclient ${OUT}/sman \
-        ${OUT}/axiom ${DOCFILES}
-	@ echo ss16 finished ${IN}
-
-announce:
-	@ echo ======================================
-	@ echo src/sman BUILDING SMAN
-	@ echo ======================================
-
-clean:
-	@echo ss17 cleaning ${SRC}/sman
-
-<<axiomcmd>>
-<<sman>>
-<<session>>
-<<spadclient>>
-<<nagman>>
-@
-\eject
-\begin{thebibliography}{99}
-\bibitem{1} nothing
-\end{thebibliography}
-\end{document}
diff --git a/zips/noweb-2.10a.tgz b/zips/noweb-2.10a.tgz
deleted file mode 100644
index 1227617..0000000
Binary files a/zips/noweb-2.10a.tgz and /dev/null differ
diff --git a/zips/noweb.modules.c.patch b/zips/noweb.modules.c.patch
deleted file mode 100644
index 233a4a0..0000000
--- a/zips/noweb.modules.c.patch
+++ /dev/null
@@ -1,264 +0,0 @@
---- modules.c	Wed Mar 28 13:49:22 2001
-+++ modules.c.tpd	Mon Nov 18 22:26:35 2002
-@@ -11,18 +10,14 @@
- #include "columns.h"
- #include "strsave.h"
- 
--#line 110 "modules.nw"
- static struct modpart *
- newmodpart(int type, char *s, Location *loc);   /* create a new module part */
- 
- static
- void append(Module mp, struct modpart *p);
--#line 227 "modules.nw"
- static int seekcycle(Module mp, Parent parent);
--#line 132 "modules.nw"
- static char *lastfilename = 0;
- static int lastlineno = -1;
--#line 41 "modules.nw"
- Module newmodule (char *modname) {
-     Module p = (Module) malloc (sizeof (struct module));
-     checkptr(p);
-@@ -31,12 +26,10 @@
-     p->head = p->tail = NULL;
-     return p;
- }
--#line 74 "modules.nw"
- void add_part (Module mp, char *s, Parttype type, Location *loc) {
-     struct modpart *p = newmodpart(type,s,loc);
-     append (mp,p);
- }
--#line 79 "modules.nw"
- static struct modpart *
- newmodpart(int type, char *s, Location *loc) {
-     struct modpart *p = (struct modpart *) malloc (sizeof (struct modpart));
-@@ -44,19 +37,15 @@
-     p->ptype = type;
-     if (s) {
-         p->contents = strsave(s);
--        
--#line 104 "modules.nw"
--{ int k = strlen(p->contents)-1;
--  if (p->contents[k] == '\n') p->contents[k] = '\0';
--  else impossible("input line doesn't end with newline");
--}
--#line 87 "modules.nw"
-+        { int k = strlen(p->contents)-1;
-+          if (p->contents[k] == '\n') p->contents[k] = '\0';
-+          else impossible("input line doesn't end with newline");
-+        }
-     }
-     if (loc) p->loc = *loc;
-     p->next = NULL;
-     return p;
- }
--#line 93 "modules.nw"
- static
- void append(Module mp, struct modpart *p) {
-     /* append p to mp's list of modparts */
-@@ -67,12 +56,10 @@
-         mp->tail = p;
-     }
- }
--#line 137 "modules.nw"
- void resetloc(void) {
-   lastfilename = 0;
-   lastlineno = -1;
- }
--#line 145 "modules.nw"
- int expand (Module mp, int indent, int partial_distance, Parent parent,  
-             char *locformat, FILE *out) {
-     struct modpart *p;
-@@ -80,69 +67,51 @@
-     int error=Normal;
-     struct parent thismodule; /* the value only matters when we're expanding a module */
- 
--    
--#line 219 "modules.nw"
--thismodule.this = mp;
--thismodule.parent = parent;
--#line 153 "modules.nw"
--    
--#line 222 "modules.nw"
--if (seekcycle(mp, parent)) {
--    errormsg(Error, "<<%s>>", mp->name);
--    return Error;
--}
-+    thismodule.this = mp;
-+    thismodule.parent = parent;
-+    if (seekcycle(mp, parent)) {
-+        errormsg(Error, "<<%s>>", mp->name);
-+        return Error;
-+    }
- 
--#line 155 "modules.nw"
-     for (p=mp->head; p!=NULL; p=p->next) {
-         switch (p->ptype) {
--            case STRING:  
--#line 176 "modules.nw"
--if (*(p->contents) != '\0') {
--    if (*locformat) {
--        if (printloc(out,locformat,p->loc,partial_distance) && (p != mp->head))
--              indent_for(partial_distance, out);
--    } else if (partial_distance == 0) {
--        indent_for(indent, out);
--        partial_distance = indent;
--    }
--    fprintf(out,"%s",p->contents);
--    partial_distance = limitcolumn(p->contents, partial_distance);
--}
--#line 157 "modules.nw"
--                                            ;  break;
--            case MODULE:  
--#line 201 "modules.nw"
--newmod = lookup(p->contents);
--if (newmod==NULL) {
--    errormsg (Error, "undefined chunk name: <<%s>>", p->contents);
--    error=Error;
--} else {
--    int retcode;
--    if (*locformat == 0 && partial_distance == 0) {
--        indent_for(indent, out);
--        partial_distance = indent;
--    }
--    retcode = expand (newmod, partial_distance, partial_distance,
--                      &thismodule, locformat, out);
--    if (retcode > error) error = retcode;
--}
--partial_distance = limitcolumn(p->contents, partial_distance + 2) + 2; 
--                                /* account for surrounding brackets */
--#line 158 "modules.nw"
--                                             ; break;
--            case NEWLINE: 
--#line 188 "modules.nw"
--partial_distance = 0;
--putc('\n', out);
--lastlineno++;
--#line 159 "modules.nw"
--                                             ; break;
-+            case STRING:  if (*(p->contents) != '\0') {
-+                              if (*locformat) {
-+                                  if (printloc(out,locformat,p->loc,partial_distance) && (p != mp->head))
-+                                        indent_for(partial_distance, out);
-+                              } else if (partial_distance == 0) {
-+                                  indent_for(indent, out);
-+                                  partial_distance = indent;
-+                              }
-+                              fprintf(out,"%s",p->contents);
-+                              partial_distance = limitcolumn(p->contents, partial_distance);
-+                          };  break;
-+            case MODULE:  newmod = lookup(p->contents);
-+                          if (newmod==NULL) {
-+                              errormsg (Error, "ignoring undefined chunk name: <<%s>>", p->contents);
-+                              error=Error;
-+                              printf("<<%s>>",p->contents);
-+                          } else {
-+                              int retcode;
-+                              if (*locformat == 0 && partial_distance == 0) {
-+                                  indent_for(indent, out);
-+                                  partial_distance = indent;
-+                              }
-+                              retcode = expand (newmod, partial_distance, partial_distance,
-+                                                &thismodule, locformat, out);
-+                              if (retcode > error) error = retcode;
-+                          }
-+                          partial_distance = limitcolumn(p->contents, partial_distance + 2) + 2; 
-+                                                          /* account for surrounding brackets */; break;
-+            case NEWLINE: partial_distance = 0;
-+                          putc('\n', out);
-+                          lastlineno++;; break;
-             default: impossible("bad part type");
-         }
-     }
-     return error;
- }
--#line 229 "modules.nw"
- static int seekcycle(Module mp, Parent parent) {
-     if (parent == NULL) {
-         return 0;
-@@ -155,57 +124,45 @@
-         return 0;
-     }
- }
--#line 251 "modules.nw"
- int printloc(FILE *fp, char *fmt, Location loc, int partial) {
-     char *p;
-     if (*fmt
-     && (loc.filename!=lastfilename || lastlineno != loc.lineno)) {
-         if (partial) putc('\n',fp);
--        
--#line 263 "modules.nw"
--for (p = fmt; *p; p++) {
--    if (*p == '%') {
--        switch (*++p) {
--            case '%': putc('%', fp);                             break;
--            case 'N': putc('\n', fp);                            break;
--            case 'F': fprintf(fp, "%s", loc.filename);           break;
--            case 'L': fprintf(fp, "%d", loc.lineno);             break;
--            case '-': case '+': 
--                        if (isdigit(p[1]) && p[2] == 'L') {
--                          fprintf(fp, "%d", *p == '+' ? loc.lineno + (p[1] - '0')
--                                                      : loc.lineno - (p[1] - '0'));
--                          p += 2;
--                        } else
--                          
--#line 283 "modules.nw"
--{ static int complained = 0;
--  if (!complained) {
--    errormsg(Error,"Bad format sequence ``%%%c'' in -L%s",*p,fmt);
--    complained = 1;
--  }
--}
--#line 277 "modules.nw"
--                      break;            
--            default:  
--#line 283 "modules.nw"
--{ static int complained = 0;
--  if (!complained) {
--    errormsg(Error,"Bad format sequence ``%%%c'' in -L%s",*p,fmt);
--    complained = 1;
--  }
--}
--#line 278 "modules.nw"
--                                                                break;
-+        for (p = fmt; *p; p++) {
-+            if (*p == '%') {
-+                switch (*++p) {
-+                    case '%': putc('%', fp);                             break;
-+                    case 'N': putc('\n', fp);                            break;
-+                    case 'F': fprintf(fp, "%s", loc.filename);           break;
-+                    case 'L': fprintf(fp, "%d", loc.lineno);             break;
-+                    case '-': case '+': 
-+                                if (isdigit(p[1]) && p[2] == 'L') {
-+                                  fprintf(fp, "%d", *p == '+' ? loc.lineno + (p[1] - '0')
-+                                                              : loc.lineno - (p[1] - '0'));
-+                                  p += 2;
-+                                } else
-+                                  { static int complained = 0;
-+                                    if (!complained) {
-+                                      errormsg(Error,"Bad format sequence ``%%%c'' in -L%s",*p,fmt);
-+                                      complained = 1;
-+                                    }
-+                                  }
-+                              break;            
-+                    default:  { static int complained = 0;
-+                                if (!complained) {
-+                                  errormsg(Error,"Bad format sequence ``%%%c'' in -L%s",*p,fmt);
-+                                  complained = 1;
-+                                }
-+                              }   break;
-+                }
-+            } else putc(*p, fp);
-         }
--    } else putc(*p, fp);
--}
--#line 257 "modules.nw"
-         lastfilename = loc.filename;
-         lastlineno = loc.lineno;
-         return 1;
-     } else return 0;
- }
--#line 309 "modules.nw"
- void remove_final_newline (Module mp) {
-         /* remove trailing newline that must be in module */
-     if (mp->tail==NULL) /* module has no text */
diff --git a/zips/noweb.modules.nw.patch b/zips/noweb.modules.nw.patch
deleted file mode 100644
index 83dc77d..0000000
--- a/zips/noweb.modules.nw.patch
+++ /dev/null
@@ -1,21 +0,0 @@
---- modules.nw.tpd	Mon Nov 18 20:56:03 2002
-+++ modules.nw	Mon Nov 18 21:59:57 2002
-@@ -197,11 +197,17 @@
- out as a special case.
- This change probably blows the case where the module being expanded is
- empty.
-+
-+If the lookup fails then the module (or chunk) is an undefined name.
-+We complain about it but want to output the original source.
-+We just wrap it in the bogus chunk name in the angle brackets 
-+that it must have had in the input and output it. (Tim Daly Nov 13, 2002)
- <<expand a module>>=
- newmod = lookup(p->contents);
- if (newmod==NULL) {
--    errormsg (Error, "undefined chunk name: @<<%s@>>", p->contents);
-+    errormsg (Error, "ignoring undefined chunk name: @<<%s@>>", p->contents);
-     error=Error;
-+    printf("@<<%s@>>",p->contents);
- } else {
-     int retcode;
-     if (*locformat == 0 && partial_distance == 0) {
diff --git a/zips/noweb.src.Makefile.nw.patch b/zips/noweb.src.Makefile.nw.patch
deleted file mode 100644
index 45027f6..0000000
--- a/zips/noweb.src.Makefile.nw.patch
+++ /dev/null
@@ -1,74 +0,0 @@
---- Makefile.nw	Wed Mar 28 13:40:21 2001
-+++ noweb.src.Makefile.nw	Wed Nov 27 16:56:48 2002
-@@ -22,14 +22,14 @@
- # MANEXT is the extension for your commands' man pages (usually 1 or l)
- # MAN7EXT is the extension for the nowebstyle man page (usually 7)
- # TEXINPUTS is the directory for TeX macro files
--# ELISP is the directory for emacs lisp files, or /dev/null not to install
-+# ELISP is the directory for emacs lisp files, or ${TMP}/null not to install
- BIN=/usr/local/noweb
- LIB=/usr/local/noweb/lib
- MAN=/usr/local/noweb/man
- MANEXT=1
- MAN7EXT=7
- TEXINPUTS=/usr/local/tex/inputs
--ELISP=/dev/null
-+ELISP=${TMP}/null
- 
- # change WEAVE if you want a different version of noweave to be installed
- WEAVE=noweave		
-@@ -61,13 +61,13 @@
- install: install-code install-man install-tex install-elisp
- 
- install-shell:
--	-mkdir $(BIN) $(LIB) 2>/dev/null
-+	-mkdir $(BIN) $(LIB) 2>${TMP}/null
- 	<<shell binaries>>
- 	cp shell/tmac.w $(LIB)
- 
- install-code: install-shell
--	-mkdir $(BIN) $(LIB) 2>/dev/null
--	strip c/nt c/markup c/mnt c/finduses
-+	-mkdir $(BIN) $(LIB) 2>${TMP}/null
-+	#strip c/nt c/markup c/mnt c/finduses
- 	cp c/nt c/markup c/mnt c/finduses $(LIB)
- 	cd $(LIBSRC); make ICONT=$(ICONT) ICONC=$(ICONC) LIB=$(LIB) BIN=$(BIN) install
- 	cd lib; make LIB=$(LIB) install
-@@ -90,19 +90,19 @@
- done
- <<*>>=
- install-man:
--	-mkdir $(MAN) $(MANDIR) $(MAN7DIR) 2>/dev/null
-+	-mkdir $(MAN) $(MANDIR) $(MAN7DIR) 2>${TMP}/null
- 	<<ordinary pages>>
- @ 
- Slackware no longer uses preformatted compressed pages, just
- compressed pages.
- <<*>>=
- install-gzipped-man:
--	-mkdir $(MAN) $(MANDIR) $(MAN7DIR) 2>/dev/null
-+	-mkdir $(MAN) $(MANDIR) $(MAN7DIR) 2>${TMP}/null
- 	<<compressed pages>>
- <<*>>=
- install-preformat-man:
- 	-echo "Warning: install-preformat-man is obsolete, even on Slackware systems" 1>&2
--	-mkdir $(MAN) $(CATDIR) $(CAT7DIR) 2>/dev/null
-+	-mkdir $(MAN) $(CATDIR) $(CAT7DIR) 2>${TMP}/null
- 	<<preformatted compressed pages>>
- <<generate chunks>>=
- NORMALPAGES="cpif nodefs noroots noweb noindex nuweb2noweb notangle noroff sl2h htmltoc"
-@@ -158,12 +158,12 @@
- done
- <<*>>=
- install-tex:
--	-mkdir $(TEXINPUTS) 2>/dev/null
-+	-mkdir $(TEXINPUTS) 2>${TMP}/null
- 	cp tex/nwmac.tex tex/noweb.sty $(TEXINPUTS)
- 	-texhash || echo "Program texhash not found or failed"
- 
- install-elisp:
--	-mkdir $(ELISP) 2>/dev/null
-+	-mkdir $(ELISP) 2>${TMP}/null
- 	cp elisp/noweb-mode.el $(ELISP)
- 
- <<*>>=
diff --git a/zips/noweb.src.Makefile.patch b/zips/noweb.src.Makefile.patch
deleted file mode 100644
index 34a7c7e..0000000
--- a/zips/noweb.src.Makefile.patch
+++ /dev/null
@@ -1,233 +0,0 @@
---- Makefile	2001-03-28 13:40:26.000000000 -0500
-+++ Makefile.tpd	2005-05-18 13:27:36.000000000 -0400
-@@ -17,14 +17,16 @@
- # MANEXT is the extension for your commands' man pages (usually 1 or l)
- # MAN7EXT is the extension for the nowebstyle man page (usually 7)
- # TEXINPUTS is the directory for TeX macro files
--# ELISP is the directory for emacs lisp files, or /dev/null not to install
--BIN=/usr/local/noweb
--LIB=/usr/local/noweb/lib
--MAN=/usr/local/noweb/man
-+# ELISP is the directory for emacs lisp files, or ${TMP}/null not to install
-+# We have to go thru a bit of cheese here to get the $ to show up in the
-+# final file. 
-+BIN:=${AXIOM}/bin/lib
-+LIB:=${AXIOM}/bin/lib
-+MAN:=${AXIOM}/bin/man
- MANEXT=1
- MAN7EXT=7
- TEXINPUTS=/usr/local/tex/inputs
--ELISP=/dev/null
-+ELISP=${TMP}/null
- 
- # change WEAVE if you want a different version of noweave to be installed
- WEAVE=noweave		
-@@ -37,13 +39,13 @@
- MAN7DIR=$(MAN)/man$(MAN7EXT)
- CATDIR=$(MAN)/cat$(MANEXT)
- CAT7DIR=$(MAN)/cat$(MAN7EXT)
--LIBNAME=$(LIB)
-+LIBNAME:=${AXIOM}/bin/lib
- TEXNAME=$(TEXINPUTS)
- 
- all: 
--	cd c; make "CC=$(CC)" "CFLAGS=$(CFLAGS)" all 
--	for i in shell lib xdoc tex; do (cd $$i; make all); done
--	cd $(LIBSRC); make "ICONT=$(ICONT)" "ICONC=$(ICONC)" all
-+	cd c; ${MAKE} "CC=$(CC)" "CFLAGS=$(CFLAGS)" all 
-+	for i in shell lib xdoc tex; do (cd $$i; ${MAKE} all); done
-+	cd $(LIBSRC); ${MAKE} "ICONT=$(ICONT)" "ICONC=$(ICONC)" all
- 
- FAQ: FAQ.html
- 	sleep 1; html2ascii FAQ.html > FAQ
-@@ -55,121 +57,127 @@
- 
- install: install-code install-man install-tex install-elisp
- 
-+# There is an unreasonable line here. We want to put the string
-+# containing the AXIOM variable into the file without expanding
-+# the variable. So we put it into the file with an embedded space
-+# to prevent make from recognizing and replacing it. Then we
-+# remove the embedded space. I'm sure there must be an easier
-+# way but I can't find it.
- install-shell:
--	-mkdir $(BIN) $(LIB) 2>/dev/null
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/noweb > $(BIN)/noweb
-+	-mkdir $(BIN) $(LIB) 2>${TMP}/null
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/noweb > $(BIN)/noweb
- 	chmod +x $(BIN)/noweb
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/notangle > $(BIN)/notangle
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/notangle > $(BIN)/notangle
- 	chmod +x $(BIN)/notangle
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/$(WEAVE) > $(BIN)/$(WEAVE)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/$(WEAVE) > $(BIN)/$(WEAVE)
- 	chmod +x $(BIN)/$(WEAVE)
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/nountangle > $(BIN)/nountangle
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/nountangle > $(BIN)/nountangle
- 	chmod +x $(BIN)/nountangle
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/nodefs > $(BIN)/nodefs
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/nodefs > $(BIN)/nodefs
- 	chmod +x $(BIN)/nodefs
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/noroots > $(BIN)/noroots
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/noroots > $(BIN)/noroots
- 	chmod +x $(BIN)/noroots
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/nuweb2noweb > $(BIN)/nuweb2noweb
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/nuweb2noweb > $(BIN)/nuweb2noweb
- 	chmod +x $(BIN)/nuweb2noweb
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/cpif > $(BIN)/cpif
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/cpif > $(BIN)/cpif
- 	chmod +x $(BIN)/cpif
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/htmltoc > $(BIN)/htmltoc
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/htmltoc > $(BIN)/htmltoc
- 	chmod +x $(BIN)/htmltoc
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/noroff > $(BIN)/noroff
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/noroff > $(BIN)/noroff
- 	chmod +x $(BIN)/noroff
--	sed "s@|LIBDIR|@$(LIBNAME)@" shell/toroff > $(LIB)/toroff
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" shell/toroff > $(LIB)/toroff
- 	chmod +x $(LIB)/toroff
- 	cp shell/tmac.w $(LIB)
- 
- install-code: install-shell
--	-mkdir $(BIN) $(LIB) 2>/dev/null
--	strip c/nt c/markup c/mnt c/finduses
-+	-mkdir $(BIN) $(LIB) 2>${TMP}/null
-+	#strip c/nt c/markup c/mnt c/finduses
- 	cp c/nt c/markup c/mnt c/finduses $(LIB)
--	cd $(LIBSRC); make ICONT=$(ICONT) ICONC=$(ICONC) LIB=$(LIB) BIN=$(BIN) install
--	cd lib; make LIB=$(LIB) install
-+	cd $(LIBSRC); ${MAKE} ICONT=$(ICONT) ICONC=$(ICONC) LIB=$(LIB) BIN=$(BIN) install
-+	cd lib; ${MAKE} LIB=$(LIB) install
- install-man:
--	-mkdir $(MAN) $(MANDIR) $(MAN7DIR) 2>/dev/null
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/cpif.1 > $(MANDIR)/cpif.$(MANEXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nodefs.1 > $(MANDIR)/nodefs.$(MANEXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroots.1 > $(MANDIR)/noroots.$(MANEXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noweb.1 > $(MANDIR)/noweb.$(MANEXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noindex.1 > $(MANDIR)/noindex.$(MANEXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nuweb2noweb.1 > $(MANDIR)/nuweb2noweb.$(MANEXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/notangle.1 > $(MANDIR)/notangle.$(MANEXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroff.1 > $(MANDIR)/noroff.$(MANEXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/sl2h.1 > $(MANDIR)/sl2h.$(MANEXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/htmltoc.1 > $(MANDIR)/htmltoc.$(MANEXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebstyle.7 > $(MAN7DIR)/nowebstyle.$(MAN7EXT)
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebfilters.7 > $(MAN7DIR)/nowebfilters.$(MAN7EXT)
-+	-mkdir $(MAN) $(MANDIR) $(MAN7DIR) 2>${TMP}/null
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/cpif.1 > $(MANDIR)/cpif.$(MANEXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nodefs.1 > $(MANDIR)/nodefs.$(MANEXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroots.1 > $(MANDIR)/noroots.$(MANEXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noweb.1 > $(MANDIR)/noweb.$(MANEXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noindex.1 > $(MANDIR)/noindex.$(MANEXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nuweb2noweb.1 > $(MANDIR)/nuweb2noweb.$(MANEXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/notangle.1 > $(MANDIR)/notangle.$(MANEXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroff.1 > $(MANDIR)/noroff.$(MANEXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/sl2h.1 > $(MANDIR)/sl2h.$(MANEXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/htmltoc.1 > $(MANDIR)/htmltoc.$(MANEXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebstyle.7 > $(MAN7DIR)/nowebstyle.$(MAN7EXT)
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebfilters.7 > $(MAN7DIR)/nowebfilters.$(MAN7EXT)
- 	rm -f $(MANDIR)/noweave.$(MANEXT)
- 	(cd $(MANDIR); ln notangle.$(MANEXT) noweave.$(MANEXT))
- 	rm -f $(MANDIR)/nountangle.$(MANEXT)
- 	(cd $(MANDIR); ln notangle.$(MANEXT) nountangle.$(MANEXT))
- install-gzipped-man:
--	-mkdir $(MAN) $(MANDIR) $(MAN7DIR) 2>/dev/null
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/cpif.1  | gzip -9 > $(MANDIR)/cpif.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nodefs.1  | gzip -9 > $(MANDIR)/nodefs.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroots.1  | gzip -9 > $(MANDIR)/noroots.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noweb.1  | gzip -9 > $(MANDIR)/noweb.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noindex.1  | gzip -9 > $(MANDIR)/noindex.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nuweb2noweb.1  | gzip -9 > $(MANDIR)/nuweb2noweb.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/notangle.1  | gzip -9 > $(MANDIR)/notangle.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroff.1  | gzip -9 > $(MANDIR)/noroff.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/sl2h.1  | gzip -9 > $(MANDIR)/sl2h.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/htmltoc.1  | gzip -9 > $(MANDIR)/htmltoc.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebstyle.7  | gzip -9 > $(MAN7DIR)/nowebstyle.$(MAN7EXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebfilters.7  | gzip -9 > $(MAN7DIR)/nowebfilters.$(MAN7EXT).gz
-+	-mkdir $(MAN) $(MANDIR) $(MAN7DIR) 2>${TMP}/null
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/cpif.1  | gzip -9 $(MANDIR)/cpif.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nodefs.1  | gzip -9 $(MANDIR)/nodefs.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroots.1  | gzip -9 $(MANDIR)/noroots.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noweb.1  | gzip -9 $(MANDIR)/noweb.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noindex.1  | gzip -9 $(MANDIR)/noindex.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nuweb2noweb.1  | gzip -9 $(MANDIR)/nuweb2noweb.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/notangle.1  | gzip -9 $(MANDIR)/notangle.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroff.1  | gzip -9 $(MANDIR)/noroff.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/sl2h.1  | gzip -9 $(MANDIR)/sl2h.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/htmltoc.1  | gzip -9 $(MANDIR)/htmltoc.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebstyle.7  | gzip -9 > $(MAN7DIR)/nowebstyle.$(MAN7EXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebfilters.7  | gzip -9 > $(MAN7DIR)/nowebfilters.$(MAN7EXT).gz
- 	rm -f $(MANDIR)/noweave.$(MANEXT).gz
- 	(cd $(MANDIR); ln notangle.$(MANEXT).gz noweave.$(MANEXT).gz)
- 	rm -f $(MANDIR)/nountangle.$(MANEXT).gz
- 	(cd $(MANDIR); ln notangle.$(MANEXT).gz nountangle.$(MANEXT).gz)
- install-preformat-man:
- 	-echo "Warning: install-preformat-man is obsolete, even on Slackware systems" 1>&2
--	-mkdir $(MAN) $(CATDIR) $(CAT7DIR) 2>/dev/null
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/cpif.txt  | gzip > $(CATDIR)/cpif.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nodefs.txt  | gzip > $(CATDIR)/nodefs.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroots.txt  | gzip > $(CATDIR)/noroots.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noweb.txt  | gzip > $(CATDIR)/noweb.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noindex.txt  | gzip > $(CATDIR)/noindex.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nuweb2noweb.txt  | gzip > $(CATDIR)/nuweb2noweb.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/notangle.txt  | gzip > $(CATDIR)/notangle.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroff.txt  | gzip > $(CATDIR)/noroff.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/sl2h.txt  | gzip > $(CATDIR)/sl2h.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/htmltoc.txt  | gzip > $(CATDIR)/htmltoc.$(MANEXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebstyle.txt  | gzip > $(CAT7DIR)/nowebstyle.$(MAN7EXT).gz
--	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebfilters.txt  | gzip > $(CAT7DIR)/nowebfilters.$(MAN7EXT).gz
-+	-mkdir $(MAN) $(CATDIR) $(CAT7DIR) 2>${TMP}/null
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/cpif.txt  | gzip > $(CATDIR)/cpif.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nodefs.txt  | gzip > $(CATDIR)/nodefs.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroots.txt  | gzip > $(CATDIR)/noroots.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noweb.txt  | gzip > $(CATDIR)/noweb.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noindex.txt  | gzip > $(CATDIR)/noindex.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nuweb2noweb.txt  | gzip > $(CATDIR)/nuweb2noweb.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/notangle.txt  | gzip > $(CATDIR)/notangle.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroff.txt  | gzip > $(CATDIR)/noroff.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/sl2h.txt  | gzip > $(CATDIR)/sl2h.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/htmltoc.txt  | gzip > $(CATDIR)/htmltoc.$(MANEXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebstyle.txt  | gzip > $(CAT7DIR)/nowebstyle.$(MAN7EXT).gz
-+	sed -e "s@|LIBDIR|@$$ AXIOM/bin/lib@" -e "s@ AXIOM@AXIOM@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebfilters.txt  | gzip > $(CAT7DIR)/nowebfilters.$(MAN7EXT).gz
- 	rm -f $(CATDIR)/noweave.$(MANEXT).gz
- 	(cd $(CATDIR); ln notangle.$(MANEXT).gz noweave.$(MANEXT).gz)
- 	rm -f $(CATDIR)/nountangle.$(MANEXT).gz
- 	(cd $(CATDIR); ln notangle.$(MANEXT).gz nountangle.$(MANEXT).gz)
- install-tex:
--	-mkdir $(TEXINPUTS) 2>/dev/null
-+	-mkdir $(TEXINPUTS) 2>${TMP}/null
- 	cp tex/nwmac.tex tex/noweb.sty $(TEXINPUTS)
- 	-texhash || echo "Program texhash not found or failed"
- 
- install-elisp:
--	-mkdir $(ELISP) 2>/dev/null
-+	-mkdir $(ELISP) 2>${TMP}/null
- 	cp elisp/noweb-mode.el $(ELISP)
- 
- checkin:
--	for i in lib tex xdoc; do (cd $$i; make "CINAME=$(CINAME)" "CIMSG=$(CIMSG)" checkin); done
-+	for i in lib tex xdoc; do (cd $$i; ${MAKE} "CINAME=$(CINAME)" "CIMSG=$(CIMSG)" checkin); done
- 	for i in c icon awk; do (cd $$i; ci -l $(CINAME) $(CIMSG) *.nw Makefile); done
- 	(cd elisp; ci -l $(CINAME) $(CIMSG) *.el)
- 	ci -l $(CINAME) $(CIMSG) Makefile.nw INSTALL INSTALL.DOS README FAQ COPYRIGHT nwmake *.nw
- 
- source: FAQ
--	for i in c shell lib xdoc icon awk tex; do (cd $$i; make CPIF=">" source); done
-+	for i in c shell lib xdoc icon awk tex; do (cd $$i; ${MAKE} CPIF=">" source); done
- 	sleep 1
--	for i in c shell lib xdoc icon awk tex; do (cd $$i; make touch); done
-+	for i in c shell lib xdoc icon awk tex; do (cd $$i; ${MAKE} touch); done
- touch:
- 	touch FAQ
--	for i in c shell lib xdoc icon awk tex; do (cd $$i; make touch); done
-+	for i in c shell lib xdoc icon awk tex; do (cd $$i; ${MAKE} touch); done
- clean:
--	for i in c shell lib xdoc icon awk tex; do (cd $$i; make clean); done
-+	for i in c shell lib xdoc icon awk tex; do (cd $$i; ${MAKE} clean); done
- 	rm -f nwsrcfilter *~ */*~
- 
- clobber: clean
--	for i in c lib icon awk xdoc; do (cd $$i; make clobber); done
-+	for i in c lib icon awk xdoc; do (cd $$i; ${MAKE} clobber); done
- 
- Makefile: Makefile.nw
- 	chmod +w Makefile
diff --git a/zips/noweb.src.awk.totex.nw.patch b/zips/noweb.src.awk.totex.nw.patch
deleted file mode 100644
index 5ebf67b..0000000
--- a/zips/noweb.src.awk.totex.nw.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- totex.nw	Mon Mar 27 18:52:13 2000
-+++ totex.nw.tpd	Sun Apr 16 15:46:01 2006
-@@ -23,8 +23,11 @@
- nawk '<<awk program for conversion to {\TeX}>>' delay=$delay noindex=$noindex
- @
- On an ugly system, we have to put it in a file.
-+
-+The awkfile has been changed to use tempfile because creating files
-+directly in tmp creates an insecure hole.
- <<invoke awk program using file>>=
--awkfile=/tmp/totex$$.awk
-+awkfile=$(tempfile -p totex)
- trap 'rm -f $awkfile; exit 1' 0 1 2 15	# clean up files
- cat > $awkfile << 'EOF'
- <<awk program for conversion to {\TeX}>>
diff --git a/zips/noweb.src.awkname.patch b/zips/noweb.src.awkname.patch
deleted file mode 100644
index 56d49f7..0000000
--- a/zips/noweb.src.awkname.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- awkname	Fri Jun 16 16:26:42 2000
-+++ awkname.tpd	Sun Apr 16 15:40:19 2006
-@@ -5,7 +5,7 @@
- esac
- 
- rc=0
--new=/tmp/$$.new; old=/tmp/$$.old
-+new=$(tempfile -p new); old=$(tempfile -p old)
- 
- for file in lib/emptydefn lib/unmarkup lib/toascii lib/btdefn \
-                         awk/noidx awk/totex awk/tohtml awk/noindex \
diff --git a/zips/noweb.src.lib.toascii.nw.patch b/zips/noweb.src.lib.toascii.nw.patch
deleted file mode 100644
index 1af4131..0000000
--- a/zips/noweb.src.lib.toascii.nw.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- toascii.nw	Mon Mar 27 18:52:17 2000
-+++ toascii.nw.tpd	Sun Apr 16 16:59:59 2006
-@@ -28,9 +28,9 @@
- Also arranged here is a temporary file for storage of the awk program on an
- ugly system, as discussed below.
- <<arrange temporary files>>=
--awkfile="tmp/awk$$.tmp"
--textfile="/tmp/text$$.tmp"
--tagsfile="/tmp/tags$$.tmp"
-+awkfile=$(tempfile -p awk -s .tmp) || { echo "$0: Cannot create temporary file" >&2; exit 1;  }
-+textfile=$(tempfile -p text -s .tmp) || { echo "$0: Cannot create temporary file" >&2; exit 1;  }
-+tagsfile=$(tempfile -p tags -s .tmp) || { echo "$0: Cannot create temporary file" >&2; exit 1;  }
- export awkfile textfile tagsfile
- trap 'rm -f $awkfile $textfile $tagsfile' 0 1 2 10 14 15
- @ %def textfile tagsfile awkfile
diff --git a/zips/noweb.src.lib.toascii.patch b/zips/noweb.src.lib.toascii.patch
deleted file mode 100644
index 6049035..0000000
--- a/zips/noweb.src.lib.toascii.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- toascii	Wed Mar 28 13:49:22 2001
-+++ toascii.tpd	Sun Apr 16 15:48:52 2006
-@@ -7,9 +7,9 @@
-                 *)      echo "This can't happen -- $i passed to toascii" 1>&2 ; exit 1 ;;
-         esac
- done
--awkfile="tmp/awk$$.tmp"
--textfile="/tmp/text$$.tmp"
--tagsfile="/tmp/tags$$.tmp"
-+awkfile=$(tempfile -p awk -s .tmp)
-+textfile=$(tempfile -p text -s .tmp)
-+tagsfile=$(tempfile -p tags -s .tmp)
- export awkfile textfile tagsfile
- trap 'rm -f $awkfile $textfile $tagsfile' 0 1 2 10 14 15
- nawk 'BEGIN { textfile=ENVIRON["textfile"]
diff --git a/zips/noweb.src.shell.cpif.patch b/zips/noweb.src.shell.cpif.patch
deleted file mode 100644
index f130c09..0000000
--- a/zips/noweb.src.shell.cpif.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- cpif	Mon Mar 27 18:52:19 2000
-+++ cpif.tpd	Sun Apr 16 16:42:48 2006
-@@ -17,7 +17,7 @@
- 0)		echo 'Usage: '`basename $0`' [ -eq -ne ] file...' 1>&2; exit 2
- esac
- 
--new=/tmp/$$
-+new=$(tempfile)
- trap 'rm -f $new; exit 1' 1 2 15	# clean up files
- 
- cat >$new
diff --git a/zips/noweb.src.shell.nonu.patch b/zips/noweb.src.shell.nonu.patch
deleted file mode 100644
index f4062df..0000000
--- a/zips/noweb.src.shell.nonu.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- nonu	Mon Mar 27 18:52:19 2000
-+++ nonu.tpd	Sun Apr 16 16:45:55 2006
-@@ -2,7 +2,7 @@
- LIB=/usr/public/pkg/noweb/lib
- # attempt to convert nuweb to noweb using sam
- 
--tmp=/tmp/nonu$$
-+tmp=$(tempfile -p nonu)
- trap '/bin/rm -f $tmp; exit 1' 1 2 15	# clean up files
- cp $1 $tmp || exit 1
- 
diff --git a/zips/noweb.src.shell.noroff.patch b/zips/noweb.src.shell.noroff.patch
deleted file mode 100644
index bacc226..0000000
--- a/zips/noweb.src.shell.noroff.patch
+++ /dev/null
@@ -1,22 +0,0 @@
---- noroff	Wed Mar 28 13:49:22 2001
-+++ noroff.tpd	Sun Apr 16 16:53:49 2006
-@@ -37,7 +37,7 @@
- tagsfile="$base.nwt"
- (echo ".so $macrodir/tmac.w"
- if [ -r "$tagsfile" ]; then 
--   cp $tagsfile /tmp/tags.$$
-+   cp $tagsfile $tmpfile
-    $AWK '{
- 	     if      (sub(/^###TAG### /       , "")) tags[$1] = $2
- 	     else if (sub(/^###BEGINCHUNKS###/, "")) printf ".de CLIST\n.CLISTBEGIN\n"
-@@ -88,8 +88,8 @@
- 	 #	print str3
- 	 #	print convquote(str3)
- 	 # }
--	 function tag(s) { if (s in tags) return tags[s]; else return "???" }' /tmp/tags.$$
--   rm -f /tmp/tags.$$
-+	 function tag(s) { if (s in tags) return tags[s]; else return "???" }' $tmpfile
-+   rm -f $tmpfile
-  fi
-  cat "$@") |
- ($ROFF $opts 2>$tagsfile)
diff --git a/zips/noweb.src.shell.roff.mm.patch b/zips/noweb.src.shell.roff.mm.patch
deleted file mode 100644
index 7cf0ba4..0000000
--- a/zips/noweb.src.shell.roff.mm.patch
+++ /dev/null
@@ -1,30 +0,0 @@
---- roff.mm	Mon Mar 27 18:52:19 2000
-+++ roff.mm.tpd	Sun Apr 16 17:06:44 2006
-@@ -214,7 +214,7 @@
- .ADDLIST 1a
- .PRINTLIST
- 
--awkfile="/tmp/noweb$$.awk"
-+awkfile=$(tempfile -p noweb -s .awk) || { echo "$0: Cannot create temporary file" >&2; exit 1;  }
- trap 'rm -f $awkfile' 0 1 2 10 14 15
- cat > $awkfile \&<< 'EOF'
- \c
-@@ -1628,14 +1628,15 @@
- tagsfile="$base.nwt"
- (echo ".so $macrodir/tmac.w"
- if [ -r "$tagsfile" ]; then 
--   cp $tagsfile /tmp/tags.$$
-+   tagstemp=$(tempfile -p tags) || { echo "$0: Cannot create temporary file" >&2; exit 1;  }
-+   cp $tagsfile $tagstemp
-    $AWK '\c
- .USE "action for \*[BEGINCONVQUOTE]tags\*[ENDCONVQUOTE] line" 11c
- \&
-          \c
- .USE "functions" 8a
--\&' /tmp/tags.$$
--   rm -f /tmp/tags.$$
-+\&' $tagstemp
-+   rm -f $tagstemp
-  fi
-  cat "$@") |
- ($ROFF $opts 2>$tagsfile)
diff --git a/zips/noweb.src.shell.roff.nw.patch b/zips/noweb.src.shell.roff.nw.patch
deleted file mode 100644
index 9a41eee..0000000
--- a/zips/noweb.src.shell.roff.nw.patch
+++ /dev/null
@@ -1,28 +0,0 @@
---- roff.nw	Mon Mar 27 18:52:19 2000
-+++ roff.nw.tpd	Sun Apr 16 16:50:27 2006
-@@ -80,7 +80,7 @@
- other, and quoting each quote is ugly.  The pragmatic solution is to
- copy the awk program into a temporary file, using a shell here-document.
- <<invoke awk program>>=
--awkfile="/tmp/noweb$$.awk"
-+awkfile=$(tempfile -p noweb -s .awk)
- trap 'rm -f $awkfile' 0 1 2 10 14 15
- cat > $awkfile << 'EOF'
- <<awk program>>
-@@ -662,12 +662,13 @@
- 
- base="`basename $1 | sed '/\./s/\.[^.]*$//'`"
- tagsfile="$base.nwt"
-+tmpfile=$(tempfile -p tags)
- (echo ".so $macrodir/tmac.w"
- if [ -r "$tagsfile" ]; then 
--   cp $tagsfile /tmp/tags.$$
-+   cp $tagsfile $tmpfile
-    $AWK '<<action for [[tags]] line>>
--         <<functions>>' /tmp/tags.$$
--   rm -f /tmp/tags.$$
-+         <<functions>>' $tmpfile
-+   rm -f $tmpfile
-  fi
-  cat "$@") |
- ($ROFF $opts 2>$tagsfile)
diff --git a/zips/noweb.src.shell.toroff.patch b/zips/noweb.src.shell.toroff.patch
deleted file mode 100644
index 966a25c..0000000
--- a/zips/noweb.src.shell.toroff.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- toroff	Wed Mar 28 13:49:22 2001
-+++ toroff.tpd	Sun Apr 16 16:56:35 2006
-@@ -9,7 +9,7 @@
-            exit 1;;
-     esac
- done
--awkfile="/tmp/noweb$$.awk"
-+awkfile=$(tempfile -p noweb -s .awk)
- trap 'rm -f $awkfile' 0 1 2 10 14 15
- cat > $awkfile << 'EOF'
- /^@begin docs 0$/ { if (delay) next }
